%%
%% This is file `localise-xepersian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% xepersian.dtx  (with options: `table,localise-xepersian.def')
%% 
%%   __________________________________________________
%%   Vafa Khalighi
%% 
%%   Copyright (c) 2008--2022  Vafa Khalighi
%%   Copyright (c) 2018--2020 bidi-tex GitHub Organization
%% 
%%   It may be distributed and/or modified under the LaTeX Project Public License,
%%   version 1.3c or higher (your choice). The latest version of
%%   this license is at: http://www.latex-project.org/lppl.txt
%% 
%%   This work is “author-maintained” (as per LPPL maintenance status)
%%   by Vafa Khalighi.
%% 
%% 
%% \CheckSum{11192}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\ProvidesFile{localise-xepersian.def}[2022/06/06 v0.2c Persian localisation of LaTeX2e]
\newcommand{\makezwnjletter}{\catcode`‌=11\relax}
\makezwnjletter
\newcommand*{\eqcommand}[2]{\if@bidi@csprimitive{#2}{\bidi@csletcs{#1}{#2}}{\bidi@csdefcs{#1}{#2}}}
\newcommand*{\eqenvironment}[2]{\newenvironment{#1}{%
\if@bidi@csdef{verbatim@}{\let\verbatim@\xepersian@localize@verbatim@}{}\csname#2\endcsname}{\csname end#2\endcsname}}
\newcommand*{\EqEnvironment}[2]{%
  \expandafter\let\csname #1\expandafter\endcsname\csname #2\endcsname
  \expandafter\let\csname end#1\expandafter\endcsname\csname end#2\endcsname
}
\@ifpackageloaded{keyval}{%
\newcommand*\keyval@eq@alias@key[4][KV]{%
  \bidi@csletcs{#1@#2@#3}{#1@#2@#4}%
  \bidi@csletcs{#1@#2@#3@default}{#1@#2@#4@default}}%
}{\@ifpackageloaded{xkeyval}{%
\newcommand*\keyval@eq@alias@key[4][KV]{%
  \bidi@csletcs{#1@#2@#3}{#1@#2@#4}%
  \bidi@csletcs{#1@#2@#3@default}{#1@#2@#4@default}}%
}{}}
\input{latex-localise-commands-xepersian.def}
\input{xepersian-localise-commands-xepersian.def}
\input{latex-localise-environments-xepersian.def}
\input{xepersian-localise-environments-xepersian.def}
\input{latex-localise-messages-xepersian.def}
\input{latex-localise-misc-xepersian.def}
\input{packages-localise-xepersian.def}
\aliasfontfeature{ExternalLocation}{مکان‌خارجی}
\aliasfontfeature{Path}{مسیر}
\aliasfontfeature{Renderer}{تحویل‌دهنده}
\aliasfontfeature{BoldFont}{قلم‌سیاه}
\aliasfontfeature{Language}{زبان}
\aliasfontfeature{Script}{خط}
\aliasfontfeature{UprightFont}{قلم‌عمودی}
\aliasfontfeature{ItalicFont}{قلم‌ایتالیک}
\aliasfontfeature{BoldItalicFont}{قلم‌ایتالیک‌سیاه}
\aliasfontfeature{SlantedFont}{قلم‌خوابیده}
\aliasfontfeature{BoldSlantedFont}{قلم‌خوابیده‌سیاه}
\aliasfontfeature{SmallCapsFont}{قلم‌کلاه‌کوچک}
\aliasfontfeature{UprightFeatures}{ویژگی‌های‌قلم‌عمودی}
\aliasfontfeature{BoldFeatures}{ویژگی‌های‌قلم‌سیاه}
\aliasfontfeature{ItalicFeatures}{ویژگی‌های‌قلم‌ایتالیک}
\aliasfontfeature{BoldItalicFeatures}{ویژگی‌های‌قلم‌ایتالیک‌سیاه}
\aliasfontfeature{SlantedFeatures}{ویژگی‌های‌قلم‌خوابیده}
\aliasfontfeature{BoldSlantedFeatures}{ویژگی‌های‌قلم‌خوابیده‌سیاه}
\aliasfontfeature{SmallCapsFeatures}{ویژگی‌های‌قلم‌کلاه‌کوچک}
\aliasfontfeature{SizeFeatures}{ویژگی‌های‌اندازه}
\aliasfontfeature{Scale}{ضریب}
\aliasfontfeature{WordSpace}{فضای‌کلمه}
\aliasfontfeature{PunctuationSpace}{فضای‌نقطه‌گذاری}
\aliasfontfeature{FontAdjustment}{تنظیم‌قلم}
\aliasfontfeature{LetterSpace}{فضای‌حرف}
\aliasfontfeature{HyphenChar}{نویسه‌تیره}
\aliasfontfeature{Color}{رنگ}
\aliasfontfeature{Opacity}{کدری}
\aliasfontfeature{Mapping}{نگاشت}
\aliasfontfeature{Weight}{سنگینی}
\aliasfontfeature{Width}{پهنا}
\aliasfontfeature{OpticalSize}{اندازه‌چشمی}
\aliasfontfeature{FakeSlant}{خوابیده‌تقلبی}
\aliasfontfeature{FakeStretch}{کشش‌تقلبی}
\aliasfontfeature{FakeBold}{سیاه‌تقلبی}
\aliasfontfeature{AutoFakeSlant}{خوابیده‌تقلبی‌خودکار}
\aliasfontfeature{AutoFakeBold}{سیاه‌تقلبی‌خودکار}
\aliasfontfeature{Ligatures}{دویاچندحرف‌متصل‌به‌هم}
\aliasfontfeature{Alternate}{متناوب}
\aliasfontfeature{Variant}{گوناگون}
\aliasfontfeature{Variant}{مجموعه‌سبکی}
\aliasfontfeature{CharacterVariant}{گوناگونی‌نویسه}
\aliasfontfeature{Style}{سبک}
\aliasfontfeature{Annotation}{یادداشت}
\aliasfontfeature{RawFeature}{ویژگی‌های‌کال}
\aliasfontfeature{CharacterWidth}{پهنای‌نویسه}
\aliasfontfeature{Numbers}{ارقام}
\aliasfontfeature{Contextuals}{متنی}
\aliasfontfeature{Diacritics}{تفکیک‌کننده‌ها}
\aliasfontfeature{Letters}{حروف}
\aliasfontfeature{Kerning}{دوری}
\aliasfontfeature{VerticalPosition}{موقعیت‌عمودی}
\aliasfontfeature{Fractions}{کسر}
\aliasfontfeatureoption{Language}{Default}{پیش‌فرض}
\aliasfontfeatureoption{Language}{Persian}{پارسی}
\aliasfontfeatureoption{Script}{Persian}{پارسی}
\aliasfontfeatureoption{Script}{Latin}{لاتین}
\aliasfontfeatureoption{Style}{MathScript}{اسکریپت‌ریاضی}
\aliasfontfeatureoption{Style}{MathScriptScript}{اسکریپت‌اسکریپت‌ریاضی}
\endinput
%%
%% End of file `localise-xepersian.def'.
