%%
%% This is file `hyperref-xepersian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% xepersian.dtx  (with options: `table,hyperref-xepersian.def')
%% 
%%   __________________________________________________
%%   Vafa Khalighi
%% 
%%   Copyright (c) 2008--2022  Vafa Khalighi
%%   Copyright (c) 2018--2020 bidi-tex GitHub Organization
%% 
%%   It may be distributed and/or modified under the LaTeX Project Public License,
%%   version 1.3c or higher (your choice). The latest version of
%%   this license is at: http://www.latex-project.org/lppl.txt
%% 
%%   This work is “author-maintained” (as per LPPL maintenance status)
%%   by Vafa Khalighi.
%% 
%% 
%% \CheckSum{11192}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\ProvidesFile{hyperref-xepersian.def}[2022/10/30 v0.8 xepersian adaptations for hyperref package]
  \def\equationautorefname{\if@RTL معادله\else Equation\fi}%
  \def\footnoteautorefname{\if@RTL زیرنویس\else footnote\fi}%
  \def\itemautorefname{\if@RTL فقره\else item\fi}%
  \def\figureautorefname{\if@RTL شکل\else Figure\fi}%
  \def\tableautorefname{\if@RTL جدول\else Table\fi}%
  \def\partautorefname{\if@RTL بخش\else Part\fi}%
  \def\appendixautorefname{\if@RTL ضمیمه\else Appendix\fi}%
  \def\chapterautorefname{\if@RTL فصل\else chapter\fi}%
  \def\sectionautorefname{\if@RTL قسمت\else section\fi}%
  \def\subsectionautorefname{\if@RTL زیرقسمت\else subsection\fi}%
  \def\subsubsectionautorefname{\if@RTL زیرزیرقسمت\else subsubsection\fi}%
  \def\paragraphautorefname{\if@RTL پاراگراف\else paragraph\fi}%
  \def\subparagraphautorefname{\if@RTL زیرپاراگراف\else subparagraph\fi}%
  \def\FancyVerbLineautorefname{\if@RTL سطر\else line\fi}%
  \def\theoremautorefname{\if@RTL قضیه\else Theorem\fi}%
  \def\pageautorefname{\if@RTL صفحه\else page\fi}%
\ifHy@implicit
  \AtBeginDocument{%
    \let\HyOrg@appendix\appendix
      \def\appendix{%
        \ltx@IfUndefined{chapter}%
          {\gdef\theHsection{\Alph{section}}}%
          {\gdef\theHchapter{\Alph{chapter}}}%
        \xdef\Hy@chapapp{\Hy@appendixstring}%
        \HyOrg@appendix
      }%
    }%
\fi
\pdfstringdefDisableCommands{%
  \let\lr\@firstofone
  \let\rl\@firstofone
  \def\XePersian{XePersian}%
}
\ltx@IfUndefined{@resets@pp}{%
}{%
  \let\HyOrg@resets@pp\@resets@pp
  \def\@resets@pp{%
    \ltx@IfUndefined{chapter}{%
      \gdef\theHsection{\Hy@AlphNoErr{section}}%
    }{%
      \gdef\theHchapter{\Hy@AlphNoErr{chapter}}%
    }%
    \xdef\Hy@chapapp{\Hy@appendixstring}%
    \HyOrg@resets@pp
  }%
}
\endinput
%%
%% End of file `hyperref-xepersian.def'.
