% \iffalse meta-comment
%
% Copyright 2006      Youssef Jabri
% 
% 
% This file is part of the `Arabi' system.
% -------------------------------------------
% 
% It may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3b
% of this license or (at your option) any later version.
% The latest version of this license is in
%    http://www.latex-project.org/lppl.txt
% and version 1.3b or later is part of all distributions of LaTeX 
% version 2005/12/01 or later.
% 
% This file has the LPPL maintenance status "maintained".
% 
% 
% \fi
%
% Filename: cp1256.def
%% 
 \ProvidesFile{cp1256.def}
        [2006/01/01 v0.1 CP1256 Arabic input encoding file]


\makeatletter
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\newsheqel}
   {\TextSymbolUnavailable\newsheqel}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\ProvideTextCommandDefault{\textperthousand}
   {\TextSymbolUnavailable\textperthousand}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathtwosuperior}{{^2}}
%%
%% Digits and Punctuation characters are "set" in their
%% corresponding part in the Latin scripts
%%
\DeclareInputText{160}{\nobreakspace}
\DeclareInputMath{161}{,}   %arabic comma
\DeclareInputText{164}{}    %what is this ?? ;)
\DeclareInputText{186}{;}   %arabic semicolon 
\DeclareInputText{191}{?}   %arabic question mark
\DeclareInputText{193}{\hamza}
\DeclareInputText{194}{\alefmadda}
\DeclareInputText{195}{\alefhamza}
\DeclareInputText{196}{\wawhamza}
\DeclareInputText{197}{\aleflowerhamza}
\DeclareInputText{198}{\yahamza}
\DeclareInputText{199}{\alef}
\DeclareInputText{200}{\baa}
\DeclareInputText{201}{\T}   %taa marbuuta
\DeclareInputText{202}{\taa}
\DeclareInputText{203}{\thaa}
\DeclareInputText{204}{\jeem}  %geem
\DeclareInputText{205}{\Haa}
\DeclareInputText{206}{\kha}
\DeclareInputText{207}{\dal}
\DeclareInputText{208}{\dhal}
\DeclareInputText{209}{\ra}
\DeclareInputText{210}{\zay}
\DeclareInputText{211}{\seen}
\DeclareInputText{212}{\sheen}
\DeclareInputText{213}{\sad}
\DeclareInputText{214}{\dad}
%
\DeclareInputText{216}{\Ta}
\DeclareInputText{217}{\za}
\DeclareInputText{218}{\ayn}
\DeclareInputText{219}{\ghayn}
\DeclareInputText{220}{\tatweel}
\DeclareInputText{221}{\fa}
\DeclareInputText{222}{\qaf}
\DeclareInputText{223}{\kaf}
%
\DeclareInputText{225}{\lam}
%
\DeclareInputText{227}{\meem}
\DeclareInputText{228}{\nun}
\DeclareInputText{229}{\ha}
\DeclareInputText{230}{\waw}
%
\DeclareInputText{236}{\alefmaqsura}
\DeclareInputText{237}{\ya}
%
\DeclareInputText{187}{\closguill}%Opening guillemet!!
\DeclareInputText{171}{\openguill}%Closing guillemet!!
\DeclareInputText{175}{-}% High --
\DeclareInputText{151}{\textemdash}%---
\DeclareInputText{150}{\textendash}%--
% Farsi characters
\DeclareInputText{129}{\peh}
\DeclareInputText{141}{\tcheh}
\DeclareInputText{142}{\jeh}
\DeclareInputText{144}{\gaf}
\DeclareInputText{152}{\farsikaf}% FARSI KAF
\DeclareInputText{157}{\ZWNJ}
\DeclareInputText{158}{\noboundary}%%200C;ZWNJ%<< * is a local trick in our font to force final form
                           %and the {} to force initial form of the next character

%
\DeclareInputText{240}{\nasb}
\DeclareInputText{241}{\raff}
\DeclareInputText{242}{\jarr}
\DeclareInputText{243}{\fatha}
\DeclareInputText{245}{\damma}
\DeclareInputText{246}{\kasra}
\DeclareInputText{248}{\shadda}
\DeclareInputText{250}{\sukun}%247
%
% Special characters to be ignored
%
\DeclareInputText{160}{}%NSP
\DeclareInputText{173}{}%SHY
\DeclareInputText{252}{}%LRO
\DeclareInputText{253}{}%RLO
\makeatother
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
\endinput
