%%
%% This is file `8859-8.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hebinp.dtx  (with options: `8859-8')
%% 
%% This is a generated file.
%% 
%% Copyright 1997-2004 Boris Lavva and any individual authors
%% listed elsewhere in this file. All rights reserved.
%% 
%% This is a generated file.
%% 
%% Copyright 1989-2005 Johannes L. Braams and any individual authors
%% listed elsewhere in this file.  All rights reserved.
%% 
%% This file was generated from file(s) of the Babel system.
%% ---------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer of this work is Johannes Braams.
%% 
%% This file may only be distributed together with a copy of the Babel
%% system. You may however distribute the Babel system without
%% such generated files.
%% 
%% The list of all files belonging to the Babel distribution is
%% given in the file `manifest.bbl'. See also `legal.bbl for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.
 \ProvidesFile{8859-8.def}
        [2004/02/20 v1.1b Hebrew input encoding file]
%% File `hebinp.dtx' for installing the input hebrew encodings.
%% Copyright (C) 1997 -- 2005 Boris Lavva.
%% Babel package for LaTeX version 2e
%% Copyright (C) 1989 -- 2005 by Johannes Braams,
%%                            TeXniek
%%                            All rights reserved.
\makeatletter
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathtwosuperior}{{^2}}
%% The SI-960 or ``old-code'' encoding only allows characters in the
%% range 32--127, so we only need to provide an empty |si960.def| file.
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{162}{\textcent}
\DeclareInputText{163}{\pounds}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{165}{\textyen}
\DeclareInputText{166}{\textbrokenbar}
\DeclareInputText{167}{\S}
\DeclareInputText{168}{\"{}}
\DeclareInputText{169}{\textcopyright}
\DeclareInputMath{170}{\times}
\DeclareInputText{171}{\guillemotleft}
\DeclareInputMath{172}{\lnot}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\textregistered}
\DeclareInputText{175}{\@tabacckludge={}}
\DeclareInputText{176}{\textdegree}
\DeclareInputMath{177}{\pm}
\DeclareInputMath{178}{\mathtwosuperior}
\DeclareInputMath{179}{\maththreesuperior}
\DeclareInputText{180}{\@tabacckludge'{}}
\DeclareInputMath{181}{\mu}
\DeclareInputText{182}{\P}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{184}{\c\ }
\DeclareInputMath{185}{\mathonesuperior}
\DeclareInputMath{186}{\div}
\DeclareInputText{187}{\guillemotright}
\DeclareInputText{188}{\textonequarter}
\DeclareInputText{189}{\textonehalf}
\DeclareInputText{190}{\textthreequarters}
\DeclareInputText{224}{\hebalef}
\DeclareInputText{225}{\hebbet}
\DeclareInputText{226}{\hebgimel}
\DeclareInputText{227}{\hebdalet}
\DeclareInputText{228}{\hebhe}
\DeclareInputText{229}{\hebvav}
\DeclareInputText{230}{\hebzayin}
\DeclareInputText{231}{\hebhet}
\DeclareInputText{232}{\hebtet}
\DeclareInputText{233}{\hebyod}
\DeclareInputText{234}{\hebfinalkaf}
\DeclareInputText{235}{\hebkaf}
\DeclareInputText{236}{\heblamed}
\DeclareInputText{237}{\hebfinalmem}
\DeclareInputText{238}{\hebmem}
\DeclareInputText{239}{\hebfinalnun}
\DeclareInputText{240}{\hebnun}
\DeclareInputText{241}{\hebsamekh}
\DeclareInputText{242}{\hebayin}
\DeclareInputText{243}{\hebfinalpe}
\DeclareInputText{244}{\hebpe}
\DeclareInputText{245}{\hebfinaltsadi}
\DeclareInputText{246}{\hebtsadi}
\DeclareInputText{247}{\hebqof}
\DeclareInputText{248}{\hebresh}
\DeclareInputText{249}{\hebshin}
\DeclareInputText{250}{\hebtav}
\newcommand{\DisableNikud}{%
  \DeclareInputText{192}{}%
  \DeclareInputText{193}{}%
  \DeclareInputText{194}{}%
  \DeclareInputText{195}{}%
  \DeclareInputText{196}{}%
  \DeclareInputText{197}{}%
  \DeclareInputText{198}{}%
  \DeclareInputText{199}{}%
  \DeclareInputText{200}{}%
  \DeclareInputText{201}{}%
  \DeclareInputText{203}{}%
  \DeclareInputText{204}{}%
  \DeclareInputText{205}{}%
  \DeclareInputText{206}{}%
  \DeclareInputText{207}{}%
  \DeclareInputText{208}{}%
  \DeclareInputText{209}{}%
  \DeclareInputText{210}{}%
  \DeclareInputText{211}{}%
  \DeclareInputText{212}{}%
  \DeclareInputText{213}{}%
  \DeclareInputText{214}{}%
}
\makeatother
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
\endinput
%%
%% End of file `8859-8.def'.
