%%
%% This is file `latex-localise-commands-xepersian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% xepersian.dtx  (with options: `table,latex-localise-commands-xepersian.def')
%% 
%%   __________________________________________________
%%   Vafa Khalighi
%% 
%%   Copyright (c) 2008--2022  Vafa Khalighi
%%   Copyright (c) 2018--2020 bidi-tex GitHub Organization
%% 
%%   It may be distributed and/or modified under the LaTeX Project Public License,
%%   version 1.3c or higher (your choice). The latest version of
%%   this license is at: http://www.latex-project.org/lppl.txt
%% 
%%   This work is “author-maintained” (as per LPPL maintenance status)
%%   by Vafa Khalighi.
%% 
%% 
%% \CheckSum{11192}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\ProvidesFile{latex-localise-commands-xepersian.def}[2014/02/05 v0.3 Persian localisation of LaTeX2e commands]
\eqcommand{شمع‌جدول}{@arstrut}
\eqcommand{فوق}{above}
\eqcommand{فاصله‌کوتاه‌بالای‌نمایش}{abovedisplayshortskip}
\eqcommand{فاصله‌بالای‌نمایش}{abovedisplayskip}
\eqcommand{عنوان‌چکیده}{abstractname}
\eqcommand{اکسنت}{accent}
\eqcommand{فعال}{active}
\eqcommand{بیفزاسطرفهرست}{addcontentsline}
\eqcommand{اضافه‌برجریمه}{addpenalty}
\eqcommand{نشانی}{address}
\eqcommand{بیفزابه‌فهرست}{addtocontents}
\eqcommand{اضافه‌برشمارنده}{addtocounter}
\eqcommand{اضافه‌بربعد}{addtolength}
\eqcommand{بیفزافضای‌و}{addvspace}
\eqcommand{تنظیم‌بدنمایی}{adjdemerits}
\eqcommand{بیفزابر}{advance}
\eqcommand{بعدازانتساب}{afterassignment}
\eqcommand{بعدازگروه}{aftergroup}
\eqcommand{الف}{aleph}
\eqcommand{خصیصه‌مستعارقلم}{aliasfontfeature}
\eqcommand{انتخاب‌خصیصه‌مستعارقلم}{aliasfontfeatureoption}
\eqcommand{شکستنی}{allowbreak}
\eqcommand{تخصی@}{alloc@}
\eqcommand{تخصیص‌یافته}{allocationnumber}
\eqcommand{شکست‌نمایش‌مجاز}{allowdisplaybreaks}
\eqcommand{حروف‌بزرگ}{Alph}
\eqcommand{حروف‌کوچک}{alph}
\eqcommand{نام‌همچنین}{alsoname}
\eqcommand{و}{and}
\eqcommand{زاویه}{angle}
\eqcommand{عنوان‌پیوست}{appendixname}
\eqcommand{تقریب}{approx}
\eqcommand{عربی}{arabic}
\eqcommand{آرگ}{arg}
\eqcommand{رنگ‌خط‌جدول}{arrayrulecolor}
\eqcommand{فاصله‌ستونهای‌آرایه}{arraycolsep}
\eqcommand{ضخامت‌خط‌جدول}{arrayrulewidth}
\eqcommand{کشیدگی‌آرایه}{arraystretch}
\eqcommand{درآغازنوشتار}{AtBeginDocument}
\eqcommand{درپایان‌نوشتار}{AtEndDocument}
\eqcommand{درانتهای‌طبقه}{AtEndOfClass}
\eqcommand{درانتهای‌سبک}{AtEndOfPackage}
\eqcommand{نویسنده}{author}
\eqcommand{مطلب‌پشت}{backmatter}
\eqcommand{شکاف‌پشت}{backslash}
\eqcommand{بدنمایی}{badness}
\eqcommand{میله}{bar}
\eqcommand{فاصله‌کرسی}{baselineskip}
\eqcommand{کشش‌فاصله‌کرسی}{baselinestretch}
\eqcommand{پردازش‌دسته‌ای}{batchmode}
\eqcommand{شروع}{begin}
\eqcommand{شروع‌چپ}{beginL}
\eqcommand{شروع‌راست}{beginR}
\eqcommand{شروع‌گروه}{begingroup}
\eqcommand{فاصله‌کوتاه‌پایین‌نمایش}{belowdisplayshortskip}
\eqcommand{فاصله‌پایین‌نمایش}{belowdisplayskip}
\eqcommand{سیاه}{bf}
\eqcommand{پیش‌فرض‌سیاه}{bfdefault}
\eqcommand{شمایل‌سیاه}{bfseries}
\eqcommand{شرگروه}{bgroup}
\eqcommand{مرجوع}{bibitem}
\eqcommand{کتاب‌نامه}{bibliography}
\eqcommand{سبک‌کتاب‌نامه}{bibliographystyle}
\eqcommand{عنوان‌کتاب‌نامه}{bibname}
\eqcommand{پرش‌بلند}{bigskip}
\eqcommand{مقدارپرش‌بلند}{bigskipamount}
\eqcommand{خط‌پایین‌شناور}{botfigrule}
\eqcommand{علامت‌پایین}{botmark}
\eqcommand{کادرتاپایین}{bottompageskip}
\eqcommand{نسبت‌پایین}{bottomfraction}
\eqcommand{کادر}{box}
\eqcommand{حداکثرعمق‌کادر}{boxmaxdepth}
\eqcommand{بشکن}{break}
\eqcommand{گلوله}{bullet}
\eqcommand{دوپن@پنج}{@cclv}
\eqcommand{دوپن@شش}{@cclvi}
\eqcommand{شرح}{caption}
\eqcommand{کدرده}{catcode}
\eqcommand{رونوشت}{cc}
\eqcommand{نام‌رونوشت}{ccname}
\eqcommand{نقطه‌وسط}{cdot}
\eqcommand{نقاط‌وسط}{cdots}
\eqcommand{تنظیم‌ازوسط}{centering}
\eqcommand{خط‌وسط}{centerline}
\eqcommand{چک@ن}{ch@ck}
\eqcommand{فصل}{chapter}
\eqcommand{عنوان‌فصل}{chaptername}
\eqcommand{نویسه}{char}
\eqcommand{تعریف‌نویسه}{chardef}
\eqcommand{برسی‌فرمان}{CheckCommand}
\eqcommand{مرجع}{cite}
\eqcommand{خطای‌طبقه}{ClassError}
\eqcommand{اطلاع‌طبقه}{ClassInfo}
\eqcommand{هشدارطبقه}{ClassWarning}
\eqcommand{هشدارطبقه‌بی‌سطر}{ClassWarningNoLine}
\eqcommand{نشانگرمرکزی}{cleaders}
\eqcommand{دوصفحه‌پاک}{cleardoublepage}
\eqcommand{صفحه‌پاک}{clearpage}
\eqcommand{خط‌ناپر}{cline}
\eqcommand{ببندورودی}{closein}
\eqcommand{ببندخروجی}{closeout}
\eqcommand{بستن}{closing}
\eqcommand{جریمه‌سربند}{clubpenalty}
\eqcommand{خاج}{clubsuit}
\eqcommand{علامت‌پایین‌ستون‌اول}{colbotmark}
\eqcommand{علامت‌اول‌ستون‌اول}{colfirstmark}
\eqcommand{رنگ}{color}
\eqcommand{کادررنگ}{colorbox}
\eqcommand{علامت‌بالای‌ستون‌اول}{coltopmark}
\eqcommand{رنگ‌ستون}{columncolor}
\eqcommand{بین‌ستون}{columnsep}
\eqcommand{پهنای‌ستون}{columnwidth}
\eqcommand{خط‌بین‌ستون}{columnseprule}
\eqcommand{سطرفهرست}{contentsline}
\eqcommand{عنوان‌فهرست‌مطالب}{contentsname}
\eqcommand{کپی}{copy}
\eqcommand{حق‌تالیف}{copyright}
\eqcommand{شمار}{count}
\eqcommand{شمار@}{count@}
\eqcommand{تعریف‌شمار}{countdef}
\eqcommand{سخ}{cr}
\eqcommand{سخ‌سخ}{crcr}
\eqcommand{نام‌فرمان}{csname}
\eqcommand{گزینه‌جاری}{CurrentOption}
\eqcommand{کادربینابین}{dashbox}
\eqcommand{بینابین‌ع}{dashv}
\eqcommand{@تاریخ}{@date}
\eqcommand{تاریخ}{date}
\eqcommand{روز}{day}
\eqcommand{خط‌پایین‌شناورپهن}{dblbotfigrule}
\eqcommand{نسبت‌پهن‌پایین}{dblbottomfraction}
\eqcommand{خط‌بالای‌شناورپهن}{dblfigrule}
\eqcommand{نسبت‌صفحه‌شناورپهن}{dblfloatpagefraction}
\eqcommand{فاصله‌بین‌شناورپهن}{dblfloatsep}
\eqcommand{کدمکان‌غیرهمانطور}{dblfntlocatecode}
\eqcommand{فاصله‌متن‌وشناورپهن}{dbltextfloatsep}
\eqcommand{نسبت‌پهن‌بالا}{dbltopfraction}
\eqcommand{اعلان‌قلم‌ثابت}{DeclareFixedFont}
\eqcommand{اعلان‌پسوندگرافیک}{DeclareGraphicsExtensions}
\eqcommand{اعلان‌دستورگرافیک}{DeclareGraphicsRule}
\eqcommand{اعلان‌فرمان‌قلم‌قدیمی}{DeclareOldFontCommand}
\eqcommand{اعلان‌گزینه}{DeclareOption}
\eqcommand{اعلان‌فرمان‌قوی}{DeclareRobustCommand}
\eqcommand{اعلان‌قلم‌علائم}{DeclareSymbolFont}
\eqcommand{دوربسته}{deadcycles}
\eqcommand{تر}{def}
\eqcommand{تعریف@کلید}{define@key}
\eqcommand{تعریف‌رنگ}{definecolor}
\eqcommand{درجه}{deg}
\eqcommand{کدجداساز}{delcode}
\eqcommand{جداساز}{delimiter}
\eqcommand{ضریب‌جداساز}{delimiterfactor}
\eqcommand{گودی}{depth}
\eqcommand{خشت}{diamondsuit}
\eqcommand{ابعاد}{dim}
\eqcommand{بعد}{dimen}
\eqcommand{بعد@}{dimen@}
\eqcommand{بعد@یک}{dimen@i}
\eqcommand{بعد@دو}{dimen@ii}
\eqcommand{تعریف‌بعد}{dimendef}
\eqcommand{تیره‌گذاری}{discretionary}
\eqcommand{شکست‌نمایش}{displaybreak}
\eqcommand{تورفتگی‌نمایش}{displayindent}
\eqcommand{سبک‌نمایش}{displaystyle}
\eqcommand{عرض‌نمایش}{displaywidth}
\eqcommand{تقسیم}{divide}
\eqcommand{طبقه‌نوشتار}{documentclass}
\eqcommand{کن}{do}
\eqcommand{تعویض‌کدها}{dospecials}
\eqcommand{نقطه}{dot}
\eqcommand{نقطه‌مساوی}{doteq}
\eqcommand{پرنقطه‌ا}{dotfill}
\eqcommand{نقاط}{dots}
\eqcommand{کادردولا}{doublebox}
\eqcommand{رنگ‌فاصله‌دوخط‌جدول}{doublerulesepcolor}
\eqcommand{فاصله‌بین‌دوخط}{doublerulesep}
\eqcommand{فلش‌پایین}{downarrow}
\eqcommand{عمق}{dp}
\eqcommand{تخلیه}{dump}
\eqcommand{ترگ}{edef}
\eqcommand{پاگروه}{egroup}
\eqcommand{انتهای‌فاصله}{eject}
\eqcommand{گرنه}{else}
\eqcommand{تاکید}{em}
\eqcommand{کشش‌لاجرم}{emergencystretch}
\eqcommand{موکد}{emph}
\eqcommand{@پوچ}{@empty}
\eqcommand{پوچ}{empty}
\eqcommand{مجموعه‌پوچ}{emptyset}
\eqcommand{پایان}{end}
\eqcommand{پایان‌چپ}{endL}
\eqcommand{پایان‌راست}{endR}
\eqcommand{پایان‌نام‌فرمان}{endcsname}
\eqcommand{پایان‌اولین‌سر}{endfirsthead}
\eqcommand{پایان‌پا}{endfoot}
\eqcommand{ته‌بند}{endgraf}
\eqcommand{پایان‌گروه}{endgroup}
\eqcommand{پایان‌سر}{endhead}
\eqcommand{پایان‌ورودی}{endinput}
\eqcommand{پایان‌آخرین‌پا}{endlastfoot}
\eqcommand{گسترش‌این‌صفحه}{enlargethispage}
\eqcommand{ته‌سطر}{endline}
\eqcommand{نویسه‌ته‌سطر}{endlinechar}
\eqcommand{ان‌دوری}{enspace}
\eqcommand{ان‌فاصله}{enskip}
\eqcommand{فرمان‌جانشین}{eqcommand}
\eqcommand{محیط‌جانشین}{eqenvironment}
\eqcommand{ارجاع‌فر}{eqref}
\eqcommand{کمک‌خطا}{errhelp}
\eqcommand{پیام‌خطا}{errmessage}
\eqcommand{سطرمتن‌خطا}{errorcontextlines}
\eqcommand{پردازش‌توقف‌خطا}{errorstopmode}
\eqcommand{نویسه‌ویژه}{escapechar}
\eqcommand{یورو}{euro}
\eqcommand{حاشیه‌زوج}{evensidemargin}
\eqcommand{هرسخ}{everycr}
\eqcommand{هرنمایش}{everydisplay}
\eqcommand{هرکادرا}{everyhbox}
\eqcommand{هرکار}{everyjob}
\eqcommand{هرریاضی}{everymath}
\eqcommand{هربند}{everypar}
\eqcommand{هرکادرو}{everyvbox}
\eqcommand{اجرای‌گزینه‌ها}{ExecuteOptions}
\eqcommand{جریمه‌اضافی‌تیره‌بندی}{exhyphenpenalty}
\eqcommand{بگسترپس‌از}{expandafter}
\eqcommand{فاصله‌اضافی‌بین‌ستونها}{extracolsep}
\eqcommand{@اولی‌ازیک}{@firstofone}
\eqcommand{@اولی‌ازدو}{@firstoftwo}
\eqcommand{چ@ار}{f@ur}
\eqcommand{خانواده}{fam}
\eqcommand{صفحه‌تجملی}{fancypage}
\eqcommand{کادربا}{fbox}
\eqcommand{ضخامت‌کادربا}{fboxrule}
\eqcommand{حاشیه‌کادربا}{fboxsep}
\eqcommand{کادربارنگ}{fcolorbox}
\eqcommand{رگ}{fi}
\eqcommand{عنوان‌شکل}{figurename}
\eqcommand{پرشکن}{filbreak}
\eqcommand{پر}{fill}
\eqcommand{علامت‌اول}{firstmark}
\eqcommand{پهن}{flat}
\eqcommand{نسبت‌صفحه‌شناور}{floatpagefraction}
\eqcommand{جریمه‌شناور}{floatingpenalty}
\eqcommand{فاصله‌بین‌شناور}{floatsep}
\eqcommand{تنظیم‌ازپایین}{flushbottom}
\eqcommand{شکلبندی}{fmtname}
\eqcommand{رده‌شکلبندی}{fmtversion}
\eqcommand{نشانه}{fnsymbol}
\eqcommand{قلم}{font}
\eqcommand{بعدقلم}{fontdimen}
\eqcommand{رمزینه‌قلم}{fontencoding}
\eqcommand{فامیل‌قلم}{fontfamily}
\eqcommand{نام‌قلم}{fontname}
\eqcommand{شمایل‌قلم}{fontseries}
\eqcommand{شکل‌قلم}{fontshape}
\eqcommand{اندازه‌قلم}{fontsize}
\eqcommand{بلندای‌پایین‌صفحه}{footheight}
\eqcommand{درج‌زیرنویس}{footins}
\eqcommand{زیرنویس}{footnote}
\eqcommand{علامت‌زیرنویس}{footnotemark}
\eqcommand{خط‌زیرنویس}{footnoterule}
\eqcommand{فاصله‌تازیرنویس}{footnotesep}
\eqcommand{اندازه‌زیرنویس}{footnotesize}
\eqcommand{متن‌زیرنویس}{footnotetext}
\eqcommand{فاصله‌تاپایین‌صفحه}{footskip}
\eqcommand{فریم}{frame}
\eqcommand{کادرباخط}{framebox}
\eqcommand{فواصل‌یکنواخت‌لاتین}{frenchspacing}
\eqcommand{مطلب‌پیش}{frontmatter}
\eqcommand{بعدبگذار}{futurelet}
\eqcommand{@خورحریصانه}{@gobble}
\eqcommand{@خورحریصانه‌دو}{@gobbletwo}
\eqcommand{@خورحریصانه‌چهار}{@gobblefour}
\eqcommand{@عاقت‌آ}{@gtempa}
\eqcommand{@عاقت‌ب}{@gtempb}
\eqcommand{ترع}{gdef}
\eqcommand{الگوی‌اطلاع}{GenericInfo}
\eqcommand{الگوی‌هشدار}{GenericWarning}
\eqcommand{الگوی‌خطا}{GenericError}
\eqcommand{عام}{global}
\eqcommand{تعاریف‌عام}{globaldefs}
\eqcommand{لغت‌نامه}{glossary}
\eqcommand{فقره‌فرهنگ}{glossaryentry}
\eqcommand{خوش‌شکن}{goodbreak}
\eqcommand{کاغذگراف}{graphpaper}
\eqcommand{گیومه‌چپ}{guillemotleft}
\eqcommand{گیومه‌راست}{guillemotright}
\eqcommand{گیومه‌تکی‌چپ}{guilsinglleft}
\eqcommand{گیومه‌تکی‌راست}{guilsinglright}
\eqcommand{ردیف‌ا}{halign}
\eqcommand{بروتو}{hang}
\eqcommand{بعدازسطر}{hangafter}
\eqcommand{تورفتگی‌ثابت}{hangindent}
\eqcommand{بدنمایی‌ا}{hbadness}
\eqcommand{کادرا}{hbox}
\eqcommand{بلندای‌سرصفحه}{headheight}
\eqcommand{فاصله‌ازسرصفحه}{headsep}
\eqcommand{سربه‌نام}{headtoname}
\eqcommand{دل}{heartsuit}
\eqcommand{بلندا}{height}
\eqcommand{پرا}{hfil}
\eqcommand{پررا}{hfill}
\eqcommand{رفع‌پرا}{hfilneg}
\eqcommand{پرزافقی}{hfuzz}
\eqcommand{فاصله‌مخفی}{hideskip}
\eqcommand{عرض‌پنهان}{hidewidth}
\bidi@csletcs{خط‌پر}{hline}% this is an exception
\eqcommand{حاشیه‌ا}{hoffset}
\eqcommand{حفظ‌درج}{holdinginserts}
\eqcommand{فاصله‌اگرد}{hrboxsep}
\eqcommand{خط‌ا}{hrule}
\eqcommand{پرخط‌ا}{hrulefill}
\eqcommand{طول‌سطر}{hsize}
\eqcommand{فاصله‌ا}{hskip}
\eqcommand{فضای‌ا}{hspace}
\eqcommand{هردوا}{hss}
\eqcommand{ارتفاع}{ht}
\eqcommand{بزرگ}{huge}
\eqcommand{بزرگ‌تر}{Huge}
\eqcommand{ابرپیوند}{hyperlink}
\eqcommand{بارگذاری‌ابر}{hypersetup}
\eqcommand{هدف‌ابر}{hypertarget}
\eqcommand{تیره‌بندی}{hyphenation}
\eqcommand{نویسه‌تیره}{hyphenchar}
\eqcommand{جریمه‌تیره‌بندی}{hyphenpenalty}
\eqcommand{@گرکلاس‌فراخوانی‌شده}{@ifclassloaded}
\eqcommand{@گرترشدنی}{@ifdefinable}
\eqcommand{@گرنویسه‌بعدی}{@ifnextchar}
\eqcommand{@گرسبک‌فراخوانی‌شده}{@ifpackageloaded}
\eqcommand{@گرستاره}{@ifstar}
\eqcommand{@گرتعریف‌نشده}{@ifundefined}
\eqcommand{گر}{if}
\eqcommand{گر@سواقت‌آ}{if@tempswa}
\eqcommand{گرانواع}{ifcase}
\eqcommand{گررده}{ifcat}
\eqcommand{گرتعریف‌شده}{ifdefined}
\eqcommand{گربعد}{ifdim}
\eqcommand{گرته‌پرونده}{ifeof}
\eqcommand{گرر}{iff}
\eqcommand{گرنادرست}{iffalse}
\eqcommand{گرپرونده‌موجود}{IfFileExists}
\eqcommand{گرکادرا}{ifhbox}
\eqcommand{گرحالت‌ا}{ifhmode}
\eqcommand{گردرونی}{ifinner}
\eqcommand{گرحالت‌ریاضی}{ifmmode}
\eqcommand{گرعدد}{ifnum}
\eqcommand{گرفرد}{ifodd}
\eqcommand{گرآنگاه‌دیگر}{ifthenelse}
\eqcommand{گردرست}{iftrue}
\eqcommand{گرکادرو}{ifvbox}
\eqcommand{گرحالت‌و}{ifvmode}
\eqcommand{گرتهی}{ifvoid}
\eqcommand{گرتام}{ifx}
\eqcommand{فاصله‌خالی‌راندیده‌بگیر}{ignorespaces}
\eqcommand{فوری}{immediate}
\eqcommand{شامل}{include}
\eqcommand{درج‌تصویر}{includegraphics}
\eqcommand{مشمولین}{includeonly}
\eqcommand{تورفتگی}{indent}
\eqcommand{درنمایه}{index}
\eqcommand{استعلام}{indexentry}
\eqcommand{عنوان‌نمایه}{indexname}
\eqcommand{فاصله‌رهنما}{indexspace}
\eqcommand{ورودی}{input}
\eqcommand{ورودپرونده‌گرموجود}{InputIfFileExists}
\eqcommand{شماره‌سطرورودی}{inputlineno}
\eqcommand{درج}{insert}
\eqcommand{جریمه‌درج}{insertpenalties}
\eqcommand{جریمه‌بین‌سطرهای‌زیرنویس}{interfootnotelinepenalty}
\eqcommand{جریمه‌بین‌سطرهای‌نمایش}{interdisplaylinepenalty}
\eqcommand{جریمه‌بین‌سطرها}{interlinepenalty}
\eqcommand{متن‌داخلی}{intertext}
\eqcommand{فاصله‌شناوردرمتن}{intertextsep}
\eqcommand{مخفی}{invisible}
\eqcommand{پیش‌فرض‌ای}{itdefault}
\eqcommand{شکل‌ایتالیک}{itshape}
\eqcommand{فقره}{item}
\eqcommand{تورفتگی‌فقره}{itemindent}
\eqcommand{فاصله‌فقره}{itemsep}
\eqcommand{تکرارکن}{iterate}
\eqcommand{شکل‌ای}{itshape}
\eqcommand{نام‌کار}{jobname}
\eqcommand{قلپ}{jot}
\eqcommand{دوری}{kern}
\eqcommand{الگو}{kill}
\eqcommand{برچسب}{label}
\eqcommand{برچسب‌شمارش‌یک}{labelenumi}
\eqcommand{برچسب‌شمارش‌دو}{labelenumii}
\eqcommand{برچسب‌شمارش‌سه}{labelenumiii}
\eqcommand{برچسب‌شمارش‌چهار}{labelenumiv}
\eqcommand{برچسب‌فقره‌یک}{labelitemi}
\eqcommand{برچسب‌فقره‌دو}{labelitemii}
\eqcommand{برچسب‌فقره‌سه}{labelitemiii}
\eqcommand{برچسب‌فقره‌چهار}{labelitemiv}
\eqcommand{فاصله‌ازبرچسب}{labelsep}
\eqcommand{پهنای‌برچسب}{labelwidth}
\eqcommand{زبان}{language}
\eqcommand{درشت}{large}
\eqcommand{درشت‌تر}{Large}
\eqcommand{درشت‌درشت}{LARGE}
\eqcommand{آخرین‌کادر}{lastbox}
\eqcommand{آخرین‌دوری}{lastkern}
\eqcommand{آخرین‌جریمه}{lastpenalty}
\eqcommand{آخرین‌فاصله}{lastskip}
\eqcommand{لاتک}{LaTeX}
\eqcommand{لاتک‌ای}{LaTeXe}
\eqcommand{کدکوچک}{lccode}
\eqcommand{نقاط‌خ}{ldots}
\eqcommand{نشانگر}{leaders}
\eqcommand{ترک‌و}{leavevmode}
\eqcommand{چپ}{left}
\eqcommand{حاشیه‌چپ}{leftmargin}
\eqcommand{حاشیه‌چپ‌یک}{leftmargini}
\eqcommand{حاشیه‌چپ‌دو}{leftmarginii}
\eqcommand{حاشیه‌چپ‌سه}{leftmarginiii}
\eqcommand{حاشیه‌چپ‌چهار}{leftmarginiv}
\eqcommand{حاشیه‌چپ‌پنج}{leftmarginv}
\eqcommand{حاشیه‌چپ‌شش}{leftmarginvi}
\eqcommand{علامت‌چپ}{leftmark}
\eqcommand{کادرتاچپ}{leftpageskip}
\eqcommand{فاصله‌ابتدای‌سطر}{leftskip}
\eqcommand{بگذار}{let}
\eqcommand{سطر}{line}
\eqcommand{سطرشکن}{linebreak}
\eqcommand{جریمه‌سطر}{linepenalty}
\eqcommand{فاصله‌سطرها}{lineskip}
\eqcommand{حدفاصله‌سطر}{lineskiplimit}
\eqcommand{کشش‌فاصله‌سطر}{linespread}
\eqcommand{ضخامت‌خط}{linethickness}
\eqcommand{پهنای‌سطر}{linewidth}
\eqcommand{عنوان‌فهرست‌اشکال}{listfigurename}
\eqcommand{لیست‌پرونده‌ها}{listfiles}
\eqcommand{فهرست‌اشکال}{listoffigures}
\eqcommand{فهرست‌جداول}{listoftables}
\eqcommand{تورفتگی‌بندلیست}{listparindent}
\eqcommand{عنوان‌فهرست‌جداول}{listtablename}
\eqcommand{بارکن‌طبقه}{LoadClass}
\eqcommand{بارکن‌طبقه‌باگزینه}{LoadClassWithOptions}
\eqcommand{مکان}{location}
\eqcommand{بلند}{long}
\eqcommand{گسیختگی}{looseness}
\eqcommand{انتقال‌بپایین}{lower}
\eqcommand{@دیگر}{@makeother}
\eqcommand{@زار}{@m}
\eqcommand{ده@زار}{@M}
\eqcommand{ده@زاریک}{@Mi}
\eqcommand{ده@زاردو}{@Mii}
\eqcommand{ده@زارسه}{@Miii}
\eqcommand{ده@زارچهار}{@Miv}
\eqcommand{بیس@زار}{@MM}
\eqcommand{من@ا}{m@ne}
\eqcommand{بزرگ‌نمایی}{mag}
\eqcommand{گام}{magstep}
\eqcommand{نیم‌گام}{magstephalf}
\eqcommand{مطلب‌اصلی}{mainmatter}
\eqcommand{ات‌حرف}{makeatletter}
\eqcommand{ات‌دیگر}{makeatother}
\eqcommand{کادربی‌خط}{makebox}
\eqcommand{ساخت‌فرهنگ}{makeglossary}
\eqcommand{تهیه‌نمایه}{makeindex}
\eqcommand{ساخت‌برچسب}{makelabel}
\eqcommand{ساخت‌برچسب‌ها}{makelabels}
\eqcommand{ساخت‌حروف‌کوچک}{MakeLowercase}
\eqcommand{عنوان‌ساز}{maketitle}
\eqcommand{ساخت‌حروف‌بزرگ}{MakeUppercase}
\eqcommand{درحاشیه}{marginpar}
\eqcommand{فاصله‌دوحاشیه}{marginparpush}
\eqcommand{فاصله‌تاحاشیه}{marginparsep}
\eqcommand{پهنای‌حاشیه}{marginparwidth}
\eqcommand{علامت}{mark}
\eqcommand{علامت‌دردوطرف}{markboth}
\eqcommand{علامت‌درراست}{markright}
\eqcommand{اعراب‌ریاضی}{mathaccent}
\eqcommand{نویسه‌ریاضی}{mathchar}
\eqcommand{تعریف‌نویسه‌ریاضی}{mathchardef}
\eqcommand{کدریاضی}{mathcode}
\eqcommand{ریاضی‌رومن}{mathrm}
\eqcommand{حداکثرتکرار}{maxdeadcycles}
\eqcommand{حداکثرعمق‌صفحه}{maxdepth}
\eqcommand{بعدبیشین}{maxdimen}
\eqcommand{کادربی}{mbox}
\eqcommand{شمایل‌نازک}{mdseries}
\eqcommand{معنا}{meaning}
\eqcommand{نازک}{mediumseries}
\eqcommand{فاصله‌متوسط‌ریاضی}{medmuskip}
\eqcommand{پرش‌متوسط}{medskip}
\eqcommand{مقدارپرش‌متوسط}{medskipamount}
\eqcommand{فضای‌متوسط}{medspace}
\eqcommand{پیام}{message}
\eqcommand{پیام‌شکن}{MessageBreak}
\eqcommand{حداقل‌فاصله‌ردیف}{minrowclearance}
\eqcommand{دوری‌ریاضی}{mkern}
\eqcommand{ماه}{month}
\eqcommand{انتقال‌بچپ}{moveleft}
\eqcommand{انتقال‌براست}{moveright}
\eqcommand{فاصله‌ریاضی}{mskip}
\eqcommand{ری@ضی}{m@th}
\eqcommand{چندستونی}{multicolumn}
\eqcommand{ضرب}{multiply}
\eqcommand{چندادغام}{multispan}
\eqcommand{میوفاصله}{muskip}
\eqcommand{تعریف‌میوفاصله}{muskipdef}
\eqcommand{@ترنام}{@namedef}
\eqcommand{@کاربردنام}{@nameuse}
\eqcommand{یک@}{@ne}
\eqcommand{نام}{name}
\eqcommand{طبیعی}{natural}
\eqcommand{باریک}{nearrow}
\eqcommand{باریکتر}{nearrower}
\eqcommand{شکلبندی‌موردنیاز}{NeedsTeXFormat}
\eqcommand{منفی}{neg}
\eqcommand{فضای‌متوسط‌منفی}{negmedspace}
\eqcommand{فضای‌ضخیم‌منفی}{negthickspace}
\eqcommand{دوری‌کوچک‌منفی}{negthinspace}
\eqcommand{بولی‌نو}{newboolean}
\eqcommand{کادرجدید}{newbox}
\eqcommand{فرمان‌نو}{newcommand}
\eqcommand{شمارجدید}{newcount}
\eqcommand{شمارنده‌جدید}{newcounter}
\eqcommand{بعدجدید}{newdimen}
\eqcommand{محیط‌نو}{newenvironment}
\eqcommand{خانواده‌جدید}{newfam}
\eqcommand{قلم‌نو}{newfont}
\eqcommand{کمک‌جدید}{newhelp}
\eqcommand{درج‌جدید}{newinsert}
\eqcommand{برچسب‌جدید}{newlabel}
\eqcommand{تعریف‌بعدجدید}{newlength}
\eqcommand{سطرجدید}{newline}
\eqcommand{نویسه‌سطرجدید}{newlinechar}
\eqcommand{میوفاصله‌جدید}{newmuskip}
\eqcommand{صفحه‌جدید}{newpage}
\eqcommand{بخوان‌جدید}{newread}
\eqcommand{تعریف‌کادرجدید}{newsavebox}
\eqcommand{فاصله‌جدید}{newskip}
\eqcommand{قضیه‌جدید}{newtheorem}
\eqcommand{جزءجدید}{newtoks}
\eqcommand{بنویس‌جدید}{newwrite}
\eqcommand{بی‌ردیف}{noalign}
\eqcommand{نشکن}{nobreak}
\eqcommand{فاصله‌نشکستنی}{nobreakspace}
\eqcommand{بدون‌سند}{nocite}
\eqcommand{نگستر}{noexpand}
\eqcommand{بدون‌پرونده}{nofiles}
\eqcommand{بدون‌تورفتگی}{noindent}
\eqcommand{بی‌فاصله‌سطر}{nointerlineskip}
\eqcommand{بدون‌حد}{nolimits}
\eqcommand{سطرنشکن}{nolinebreak}
\eqcommand{پردازش‌بدون‌توقف}{nonstopmode}
\eqcommand{فواصل‌متعارف‌لاتین}{nonfrenchspacing}
\eqcommand{بدون‌شماره}{nonumber}
\eqcommand{صفحه‌نشکن}{nopagebreak}
\eqcommand{کرسیهای‌متعارف}{normalbaselines}
\eqcommand{فاصله‌کرسی‌متعارف}{normalbaselineskip}
\eqcommand{رنگ‌عادی}{normalcolor}
\eqcommand{قلم‌عادی}{normalfont}
\eqcommand{فاصله‌سطرمتعارف}{normallineskip}
\eqcommand{حدفاصله‌سطرمتعارف}{normallineskiplimit}
\eqcommand{درحاشیه‌عادی}{normalmarginpar}
\eqcommand{اندازه‌عادی}{normalsize}
\eqcommand{بدون‌اتیکت}{notag}
\eqcommand{نول}{null}
\eqcommand{قلم‌تهی}{nullfont}
\eqcommand{عدد}{number}
\eqcommand{سطرعددی}{numberline}
\eqcommand{شماره‌مطابق}{numberwithin}
\eqcommand{پایین‌صفحه‌زوج}{@evenfoot}
\eqcommand{بالای‌صفحه‌زوج}{@evenhead}
\eqcommand{پایین‌صفحه‌فرد}{@oddfoot}
\eqcommand{بالای‌صفحه‌فرد}{@oddhead}
\eqcommand{شماره‌بیرون‌درست}{@outeqntrue}
\eqcommand{شماره‌بیرون‌نادرست}{@outeqnfalse}
\eqcommand{سطربه‌سطر}{obeylines}
\eqcommand{فضافعال}{obeyspaces}
\eqcommand{حاشیه‌فرد}{oddsidemargin}
\eqcommand{سطوربی‌فاصله}{offinterlineskip}
\eqcommand{حذف}{omit}
\eqcommand{@تنهادرپیش‌درآمد}{@onlypreamble}
\eqcommand{یک‌ستون}{onecolumn}
\eqcommand{تنها‌یادداشت‌ها}{onlynotes}
\eqcommand{تنهااسلایدها}{onlyslides}
\eqcommand{بازکن‌ورودی}{openin}
\eqcommand{بازکن‌خروجی}{openout}
\eqcommand{گزینه‌مصرف‌نشده}{OptionNotUsed}
\eqcommand{یا}{or}
\eqcommand{برونی}{outer}
\eqcommand{صفحه‌بندی}{output}
\eqcommand{جریمه‌صفحه‌بندی}{outputpenalty}
\eqcommand{علامت‌سرریز}{overfullrule}
\eqcommand{@فرمان‌های‌پیش‌درآمد}{@preamblecmds}
\eqcommand{@پو}{p@}
\eqcommand{خطای‌سبک}{PackageError}
\eqcommand{اطلاع‌سبک}{PackageInfo}
\eqcommand{هشدارسبک}{PackageWarning}
\eqcommand{هشدارسبک‌بی‌سطر}{PackageWarningNoLine}
\eqcommand{صفحه‌شکن}{pagebreak}
\eqcommand{رنگ‌صفحه}{pagecolor}
\eqcommand{عمق‌صفحه}{pagedepth}
\eqcommand{کشش‌پرررصفحه}{pagefilllstretch}
\eqcommand{کشش‌پررصفحه}{pagefillstretch}
\eqcommand{کشش‌پرصفحه}{pagefilstretch}
\eqcommand{غایت‌صفحه}{pagegoal}
\eqcommand{نام‌صفحه}{pagename}
\eqcommand{شماره‌گذاری‌صفحه}{pagenumbering}
\eqcommand{رجوع‌صفحه}{pageref}
\eqcommand{ضخامت‌خط‌صفحه}{pagerulewidth}
\eqcommand{فشردگی‌صفحه}{pageshrink}
\eqcommand{کشش‌صفحه}{pagestretch}
\eqcommand{سبک‌صفحه}{pagestyle}
\eqcommand{جمع‌صفحه}{pagetotal}
\eqcommand{بلندای‌کاغذ}{paperheight}
\eqcommand{پهنای‌کاغذ}{paperwidth}
\bidi@csdefcs{بند}{par}% this is an exception since \par is redefined only in some circumstances
\eqcommand{پاراگراف}{paragraph}
\eqcommand{موازی}{parallel}
\eqcommand{کادرپار}{parbox}
\eqcommand{فاصله‌ته‌بند}{parfillskip}
\eqcommand{تورفتگی‌سربند}{parindent}
\eqcommand{فاصله‌بندلیست}{parsep}
\eqcommand{شکل‌بند}{parshape}
\eqcommand{فاصله‌بند}{parskip}
\eqcommand{بخش}{part}
\eqcommand{عنوان‌بخش}{partname}
\eqcommand{فاصله‌بالای‌لیست‌بند}{partopsep}
\eqcommand{ارسال‌گزینه‌به‌کلاس}{PassOptionToClass}
\eqcommand{ارسال‌گزینه‌به‌پکیج}{PassOptionToPackage}
\eqcommand{مسیر}{path}
\eqcommand{الگوها}{patterns}
\eqcommand{مکث}{pausing}
\eqcommand{جریمه}{penalty}
\eqcommand{غیب}{phantom}
\eqcommand{الگوی‌قبلی}{poptabs}
\eqcommand{جریمه‌پس‌نمایش}{postdisplaypenalty}
\eqcommand{جهت‌پیش‌نمایش}{predisplaydirection}
\eqcommand{جریمه‌پیش‌نمایش}{predisplaypenalty}
\eqcommand{اندازه‌پیش‌نمایش}{predisplaysize}
\eqcommand{پیش‌حدبدنمایی}{pretolerance}
\eqcommand{عمق‌قبلی}{prevdepth}
\eqcommand{بندقبلی}{prevgraf}
\eqcommand{نمایه‌دراینجا}{printindex}
\eqcommand{پردازش‌گزینه‌ها}{ProcessOptions}
\eqcommand{تامین}{protect}
\eqcommand{تهیه‌فرمان}{providecommand}
\eqcommand{آماده‌سازی‌طبقه}{ProvidesClass}
\eqcommand{آماده‌سازی‌پرونده}{ProvidesFile}
\eqcommand{آماده‌سازی‌سبک}{ProvidesPackage}
\eqcommand{ثبت‌الگو}{pushtabs}
\eqcommand{کواد}{quad}
\eqcommand{کوکواد}{qquad}
\eqcommand{@بازآیی‌خروج‌صفحه}{@outputpagerestore}
\eqcommand{رادیکال}{radical}
\eqcommand{پایین‌بی‌تنظیم}{raggedbottom}
\eqcommand{تنظیم‌ازراست}{raggedleft}
\eqcommand{تنظیم‌ازچپ}{raggedright}
\eqcommand{انتقال‌ببالا}{raise}
\eqcommand{بالابر}{raisebox}
\eqcommand{ترفیع‌اتیکت}{raisetag}
\eqcommand{زاویه‌ر}{rangle}
\eqcommand{سقف‌ر}{rceil}
\eqcommand{بخوان}{read}
\eqcommand{رجوع}{ref}
\eqcommand{کادرقرینه}{reflectbox}
\eqcommand{عنوان‌مراجع}{refname}
\eqcommand{گام‌شمارنده‌مرجع}{refstepcounter}
\eqcommand{راحت}{relax}
\eqcommand{رفع‌آخرین‌فاصله}{removelastskip}
\eqcommand{فرمان‌ازنو}{renewcommand}
\eqcommand{محیط‌ازنو}{renewenvironment}
\eqcommand{سبک‌موردنیاز}{RequirePackage}
\eqcommand{سبک‌موردنیازباگزینه}{RequirePackageWithOptions}
\eqcommand{کادرکشیده}{resizebox}
\eqcommand{درحاشیه‌معکوس}{reversemarginpar}
\eqcommand{کف‌ر}{rfloor}
\eqcommand{راست}{right}
\eqcommand{حاشیه‌راست}{rightmargin}
\eqcommand{علامت‌راست}{rightmark}
\eqcommand{کادرتاراست}{rightpageskip}
\eqcommand{فاصله‌انتهای‌سطر}{rightskip}
\eqcommand{رومن‌عادی}{rmdefault}
\eqcommand{فامیل‌رومن}{rmfamily}
\eqcommand{رومن‌بزرگ}{Roman}
\eqcommand{رومن‌کوچک}{roman}
\eqcommand{عددرومی}{romannumeral}
\eqcommand{کادرچرخان}{rotatebox}
\eqcommand{رنگ‌ردیف}{rowcolor}
\eqcommand{خط}{rule}
\eqcommand{@دومی‌ازدو}{@secondoftwo}
\eqcommand{@فضاها}{@spaces}
\eqcommand{همین‌صفحه}{samepage}
\eqcommand{مقدارکادر}{savebox}
\eqcommand{مقکادر}{sbox}
\eqcommand{کادراندازه}{scalebox}
\eqcommand{پیش‌فرض‌تمام‌بزرگ}{scdefault}
\eqcommand{شکل‌تمام‌بزرگ}{scshape}
\eqcommand{مقدارکلیدها}{setkeys}
\eqcommand{قلم‌توان}{scriptfont}
\eqcommand{قلم‌توان‌توان}{scriptscriptfont}
\eqcommand{سبک‌ته‌نوشت‌ته‌نوشت}{scriptscriptstyle}
\eqcommand{اندازه‌پانویس}{scriptsize}
\eqcommand{سبک‌ته‌نوشت}{scripstyle}
\eqcommand{پردازش‌گذری}{scrollmode}
\eqcommand{قسمت}{section}
\eqcommand{تعریف‌قسمت}{secdef}
\eqcommand{ببینید}{see}
\eqcommand{نیزببینید}{seealso}
\eqcommand{نام‌ببینید}{seename}
\eqcommand{قلم‌بردار}{selectfont}
\eqcommand{تنظیم‌بولی}{setboolean}
\eqcommand{درکادر}{setbox}
\eqcommand{مقدارشمارنده}{setcounter}
\eqcommand{مقداربعد}{setlength}
\eqcommand{تنظیم‌منها}{setminus}
\eqcommand{تعریف‌قلم‌علائم}{SetSymbolFont}
\eqcommand{تنظیم‌به‌عمق}{settodepth}
\eqcommand{تنظیم‌به‌ارتفاع}{settoheight}
\eqcommand{مقداربعدبه‌اندازه}{settowidth}
\eqcommand{کدضریب‌فاصله}{sfcode}
\eqcommand{پیش‌فرض‌س‌ف}{sfdefault}
\eqcommand{فامیل‌سن‌سریف}{sffamily}
\eqcommand{کادرسایه‌دار}{shadowbox}
\eqcommand{تیز}{sharp}
\eqcommand{بفرست}{shipout}
\eqcommand{پشته‌کوتاه}{shortstack}
\eqcommand{نمایش‌بده}{show}
\eqcommand{نمایش‌بده‌کادر}{showbox}
\eqcommand{میزان‌نمایش‌کادر}{showboxbreadth}
\eqcommand{عمق‌نمایش‌کادر}{showboxdepth}
\eqcommand{نمایش‌بده‌لیستها}{showlists}
\eqcommand{نمایش‌بده‌محتوای}{showthe}
\eqcommand{حالت‌ساده‌قلم}{simplefontmode}
\eqcommand{شانزد@}{sixt@@n}
\eqcommand{نویسه‌اریب}{skewchar}
\eqcommand{فاصله}{skip}
\eqcommand{فاصل@}{skip@}
\eqcommand{تعریف‌فاصله}{skipdef}
\eqcommand{خوابیده}{sl}
\eqcommand{پیش‌فرض‌خو}{sldefault}
\eqcommand{شکل‌خوابیده}{slshape}
\eqcommand{راحت‌چین}{sloppy}
\eqcommand{شمایل‌خو}{slshape}
\eqcommand{کوچک}{small}
\eqcommand{پرش‌کوتاه}{smallskip}
\eqcommand{مقدارپرش‌کوتاه}{smallskipamount}
\eqcommand{کوب}{smash}
\eqcommand{لبخند}{smile}
\eqcommand{کدمکان‌همانطور}{snglfntlocatecode}
\eqcommand{فضا}{space}
\eqcommand{ضریب‌فاصله}{spacefactor}
\eqcommand{فاصله‌کلمات}{spaceskip}
\eqcommand{پیک}{spadesuit}
\eqcommand{ادغام}{span}
\eqcommand{ویژه}{special}
\eqcommand{حداکثرعمق‌ستون}{splitmaxdepth}
\eqcommand{فاصله‌بالای‌ستون}{splittopskip}
\eqcommand{ستاره}{star}
\eqcommand{گام‌شمارنده}{stepcounter}
\eqcommand{کشی}{stretch}
\eqcommand{رشته}{string}
\eqcommand{شمع}{strut}
\eqcommand{کادرشمع}{strutbox}
\eqcommand{زیربند}{subitem}
\eqcommand{زیرپاراگراف}{subparagraph}
\eqcommand{زیرقسمت}{subsection}
\eqcommand{زیرپشته}{substack}
\eqcommand{زیرزیربند}{subsubitem}
\eqcommand{زیرزیرقسمت}{subsubsection}
\eqcommand{زیرمجموعه}{subset}
\eqcommand{زیرمجموعه‌مس}{subseteq}
\eqcommand{منتهای‌صفحه}{supereject}
\eqcommand{حذف‌مکان‌شناور}{suppressfloats}
\eqcommand{@موقت‌آ}{@tempa}
\eqcommand{@موقت‌ب}{@tempb}
\eqcommand{@موقت‌پ}{@tempc}
\eqcommand{@موقت‌ت}{@tempd}
\eqcommand{@موقت‌ث}{@tempe}
\eqcommand{@کادرقت‌آ}{@tempboxa}
\eqcommand{@شماقت‌آ}{@tempcnta}
\eqcommand{@شماقت‌ب}{@tempcntb}
\eqcommand{@بعدقت‌آ}{@tempdima}
\eqcommand{@بعدقت‌ب}{@tempdimb}
\eqcommand{@بعدقت‌پ}{@tempdimc}
\eqcommand{@فاقت‌آ}{@tempskipa}
\eqcommand{@فاقت‌ب}{@tempskipb}
\eqcommand{@سواقت‌آنادرست}{@tempswafalse}
\eqcommand{@سواقت‌آدرست}{@tempswatrue}
\eqcommand{@جزقت‌آ}{@temptokena}
\eqcommand{انگ‌زیرنویس}{@thefnmark}
\eqcommand{@سومی‌ازسه}{@thirdofthree}
\eqcommand{فاصله‌جاگذاری}{tabbingsep}
\eqcommand{فاصله‌بین‌ستونها}{tabcolsep}
\eqcommand{فهرست‌مطالب}{tableofcontents}
\eqcommand{عنوان‌جدول}{tablename}
\eqcommand{فاصله‌ستونها}{tabskip}
\eqcommand{ته‌سطرجدول}{tabularnewline}
\eqcommand{اتیکت}{tag}
\eqcommand{تلفن}{telephone}
\eqcommand{تک}{TeX}
\eqcommand{متن}{text}
\eqcommand{گلوله‌متنی}{textbullet}
\eqcommand{قلم‌متن}{textfont}
\eqcommand{ام‌دش‌متنی}{textemdash}
\eqcommand{ان‌دش‌متنی}{textendash}
\eqcommand{تعجب‌وارونه‌متنی}{textexclamdown}
\eqcommand{نقطه‌وسط‌متنی}{textperiodcentered}
\eqcommand{سوال‌وارونه‌متنی}{textquestiondown}
\eqcommand{نقل‌چپ‌متنی‌دولا}{textquotedblleft}
\eqcommand{نقل‌راست‌متنی‌دولا}{textquotedblright}
\eqcommand{نقل‌متنی‌چپ}{textquoteleft}
\eqcommand{نقل‌متنی‌راست}{textquoteright}
\eqcommand{فضای‌نمایان‌متنی‌}{textvisiblespace}
\eqcommand{شکافت‌پشت‌متنی}{textbackslash}
\eqcommand{میله‌متنی}{textbar}
\eqcommand{بزرگ‌تر‌متنی}{textgreater}
\eqcommand{کمتر‌متنی}{textless}
\eqcommand{متن‌سیاه}{textbf}
\eqcommand{مدور‌متنی}{textcircled}
\eqcommand{رنگ‌متن}{textcolor}
\eqcommand{نشان‌کلمه‌مرکب‌متن}{textcompwordmark}
\eqcommand{فاصله‌متن‌وشناور}{textfloatsep}
\eqcommand{نسبت‌متن}{textfraction}
\eqcommand{بلندای‌متن}{textheight}
\eqcommand{متن‌تورفته}{textindent}
\eqcommand{متن‌ایتالیک}{textit}
\eqcommand{متن‌نازک}{textmd}
\eqcommand{متن‌نرمال}{textnormal}
\eqcommand{ثبتی‌متنی}{textregistered}
\eqcommand{متن‌رومن}{textrm}
\eqcommand{متن‌تمام‌بزرگ}{textsc}
\eqcommand{متن‌سن‌سریف}{textsf}
\eqcommand{متن‌خوابیده}{textsl}
\eqcommand{سبک‌متنی}{textstyle}
\eqcommand{بالانویس‌متنی}{textsuperscript}
\eqcommand{علامت‌تجاری‌متنی}{texttrademark}
\eqcommand{متن‌تایپ}{texttt}
\eqcommand{متن‌ایستاده}{textup}
\eqcommand{پهنای‌متن}{textwidth}
\eqcommand{زیر‌نویس‌عنوان}{thanks}
\eqcommand{محتوای}{the}
\eqcommand{این‌زیرنویس}{thempfn}
\eqcommand{خط‌هاضخیم}{thicklines}
\eqcommand{فاصله‌زیادریاضی}{thickmuskip}
\eqcommand{فاصله‌کم‌ریاضی}{thinmuskip}
\eqcommand{فضاضخیم}{thickspace}
\eqcommand{خط‌هانازک}{thinlines}
\eqcommand{دوری‌کوچک}{thinspace}
\eqcommand{این‌صفحه‌تجملی}{thisfancypage}
\eqcommand{سبک‌این‌صفحه}{thispagestyle}
\eqcommand{سه@}{thr@@}
\eqcommand{مد}{tilde}
\eqcommand{ظریف}{tiny}
\eqcommand{زمان}{time}
\eqcommand{ضرب‌در}{times}
\eqcommand{عنوان}{title}
\eqcommand{به}{to}
\eqcommand{امروز}{today}
\eqcommand{جزء}{toks}
\eqcommand{تعریف‌جزء}{toksdef}
\eqcommand{حدبدنمایی}{tolerance}
\eqcommand{بالا}{top}
\eqcommand{خط‌بالای‌شناور}{topfigrule}
\eqcommand{نسبت‌بالا}{topfraction}
\eqcommand{حاشیه‌بالا}{topmargin}
\eqcommand{علامت‌بالا}{topmark}
\eqcommand{کادرتابالا}{toppageskip}
\eqcommand{فاصله‌بالای‌لیست}{topsep}
\eqcommand{فاصله‌بالا}{topskip}
\eqcommand{بلندای‌کل}{totalheight}
\eqcommand{ردگیری‌کل}{tracingall}
\eqcommand{ردگیری‌فرامین}{tracingcommands}
\eqcommand{ردگیری‌حروف}{tracinglostchars}
\eqcommand{ردگیری‌ماکروها}{tracingmacros}
\eqcommand{ردگیری‌نمایشی}{tracingonline}
\eqcommand{ردگیری‌صفحه‌بندی}{tracingoutput}
\eqcommand{ردگیری‌صفحات}{tracingpages}
\eqcommand{ردگیری‌بندها}{tracingparagraphs}
\eqcommand{ردگیری‌بازگردانی}{tracingrestores}
\eqcommand{ردگیری‌آمارها}{tracingstats}
\eqcommand{مثلث}{triangle}
\eqcommand{پیش‌فرض‌تایپ}{ttdefault}
\eqcommand{فامیل‌تایپ}{ttfamily}
\eqcommand{دو@}{tw@}
\eqcommand{دوستون}{twocolumn}
\eqcommand{درنویس}{typein}
\eqcommand{برنویس}{typeout}
\eqcommand{کدبزرگ}{uccode}
\eqcommand{تیره‌بندی‌بزرگ}{uchyph}
\eqcommand{زیرخط}{underline}
\eqcommand{بی‌کادرا}{unhbox}
\eqcommand{بی‌کپی‌ا}{unhcopy}
\eqcommand{واحدطول}{unitlength}
\eqcommand{برگشت‌دوری}{unkern}
\eqcommand{برگشت‌جریمه}{unpenalty}
\eqcommand{برگشت‌فاصله}{unskip}
\eqcommand{بی‌کادرو}{unvbox}
\eqcommand{بی‌کپی‌و}{unvcopy}
\eqcommand{پیش‌فرض‌ایستاده}{updefault}
\eqcommand{شکل‌ایستاده}{upshape}
\eqcommand{ازکادر}{usebox}
\eqcommand{باشمارشگر}{usecounter}
\eqcommand{گزینش‌قلم}{usefont}
\eqcommand{سبک‌لازم}{usepackage}
\eqcommand{@فضاهای‌فعال}{@vobeyspaces}
\eqcommand{@تهی}{@void}
\eqcommand{تنظیم‌و}{vadjust}
\eqcommand{ردیف‌و}{valign}
\eqcommand{محتوای‌شمارنده}{value}
\eqcommand{بدنمایی‌و}{vbadness}
\eqcommand{کادرو}{vbox}
\eqcommand{کادروسط}{vcenter}
\eqcommand{همانطور}{verb}
\eqcommand{پرو}{vfil}
\eqcommand{پررو}{vfill}
\eqcommand{رفع‌پرو}{vfilneg}
\eqcommand{پرزعمودی}{vfuzz}
\eqcommand{نمایان}{visible}
\eqcommand{خط‌عمود}{vline}
\eqcommand{حاشیه‌و}{voffset}
\eqcommand{ک@درتهی}{voidb@x}
\eqcommand{ارجاع‌صفحه‌ع}{vpageref}
\eqcommand{فاصله‌وگرد}{vrboxsep}
\eqcommand{ارجاع‌ع}{vref}
\eqcommand{خط‌و}{vrule}
\eqcommand{طول‌صفحه}{vsize}
\eqcommand{فاصله‌و}{vskip}
\eqcommand{فضای‌و}{vspace}
\eqcommand{شکست‌و}{vsplit}
\eqcommand{هردوو}{vss}
\eqcommand{کادرگود}{vtop}
\eqcommand{عرض}{wd}
\eqcommand{مادام‌بکن}{whiledo}
\eqcommand{کلاه‌پهن}{widehat}
\eqcommand{مدپهن}{widetilde}
\eqcommand{جریمه‌ته‌بند}{widowpenalty}
\eqcommand{پهنا}{width}
\eqcommand{درکارنامه}{wlog}
\eqcommand{بنویس}{write}
\eqcommand{@فضای‌لاتین}{@xobeysp}
\eqcommand{سی@دو}{@xxxii}
\eqcommand{ترگع}{xdef}
\eqcommand{نشانگرگسترشی}{xleaders}
\eqcommand{فاصله‌اضافی‌کلمات}{xspaceskip}
\eqcommand{سال}{year}
\eqcommand{@فر}{z@}
\eqcommand{@فرفاصله}{z@skip}
\endinput
%%
%% End of file `latex-localise-commands-xepersian.def'.
