%%
%% This is file `xepersian-localise-commands-xepersian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% xepersian.dtx  (with options: `table,xepersian-localise-commands-xepersian.def')
%% 
%%   __________________________________________________
%%   Vafa Khalighi
%% 
%%   Copyright (c) 2008--2022  Vafa Khalighi
%%   Copyright (c) 2018--2020 bidi-tex GitHub Organization
%% 
%%   It may be distributed and/or modified under the LaTeX Project Public License,
%%   version 1.3c or higher (your choice). The latest version of
%%   this license is at: http://www.latex-project.org/lppl.txt
%% 
%%   This work is “author-maintained” (as per LPPL maintenance status)
%%   by Vafa Khalighi.
%% 
%% 
%% \CheckSum{11192}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\ProvidesFile{xepersian-localise-commands-xepersian.def}[2012/07/25 v0.2 Persian localisation of XePersian commands]
\eqcommand{خط‌زیرنویس‌خودکار}{autofootnoterule}
\eqcommand{اعدادفرمولهاخودکار}{AutoMathDigits}
\eqcommand{اعدادفرمولهالاتین}{DefaultMathDigits}
\eqcommand{معادل@کلید}{keyval@eq@alias@key}
\eqcommand{تعریف‌قلم‌لاتین}{deflatinfont}
\eqcommand{تعریف‌قلم‌پارسی}{defpersianfont}
\eqcommand{کادراچپ}{hboxL}
\eqcommand{کادراست}{hboxR}
\eqcommand{مرجع‌لاتین}{Latincite}
\eqcommand{قلم‌لاتین}{latinfont}
\eqcommand{امروزلاتین}{latintoday}
\eqcommand{خط‌زیرنویس‌چپ}{leftfootnoterule}
\eqcommand{متن‌لاتین}{lr}
\eqcommand{چپ‌براست}{LRE}
\eqcommand{دوستونی‌چپ}{LTRdblcol}
\eqcommand{پانویس}{LTRfootnote}
\eqcommand{متن‌پانویس}{LTRfootnotetext}
\eqcommand{پانویس‌عنوان}{LTRthanks}
\eqcommand{روزپارسی}{persianday}
\eqcommand{قلم‌پارسی}{persianfont}
\eqcommand{اعدادفرمولهاپارسی}{PersianMathDigits}
\eqcommand{ماه‌پارسی}{persianmonth}
\eqcommand{سال‌پارسی}{persianyear}
\eqcommand{علامت‌چپ‌نقل‌قول‌پارسی}{plq}
\eqcommand{علامت‌راست‌نقل‌قول‌پارسی}{prq}
\eqcommand{خط‌زیرنویس‌راست}{rightfootnoterule}
\eqcommand{متن‌پارسی}{rl}
\eqcommand{راست‌بچپ}{RLE}
\eqcommand{دوستونی‌راست}{RTLdblcol}
\eqcommand{پانوشت}{RTLfootnote}
\eqcommand{متن‌پانوشت}{RTLfootnotetext}
\eqcommand{پانوشت‌عنوان}{RTLthanks}
\eqcommand{@علامت‌بین}{@SepMark}
\eqcommand{علامت‌بین}{SepMark}
\eqcommand{بگذارمرجوعات‌عادی}{setdefaultbibitems}
\eqcommand{بگذاردرحاشیه‌عادی}{setdefaultmarginpar}
\eqcommand{گزینش‌قلم‌اعدادفرمولها}{setmathdigitfont}
\eqcommand{بگذارزیرنویس‌چپ}{setfootnoteLR}
\eqcommand{بگذارزیرنویس‌راست}{setfootnoteRL}
\eqcommand{گزینش‌قلم‌لاتین‌متن}{setlatintextfont}
\eqcommand{بگذارمتن‌چپ}{setLTR}
\eqcommand{بگذارمرجوعات‌چپ}{setLTRbibitems}
\eqcommand{بگذاردرحاشیه‌چپ}{setLTRmarginpar}
\eqcommand{بگذارمتن‌راست}{setRTL}
\eqcommand{بگذارمرجوعات‌راست}{setRTLbibitems}
\eqcommand{بگذاردرحاشیه‌راست}{setRTLmarginpar}
\eqcommand{گزینش‌قلم‌متن}{settextfont}
\eqcommand{خط‌زیرنویس‌پهنای‌متن}{textwidthfootnoterule}
\eqcommand{فهرست‌مطالب‌دوستونی}{twocolumnstableofcontents}
\eqcommand{نگذارزیرنویس‌راست}{unsetfootnoteRL}
\eqcommand{نگذارمتن‌چپ}{unsetLTR}
\eqcommand{نگذارمتن‌راست}{unsetRTL}
\eqcommand{کادروازچپ}{vboxL}
\eqcommand{کادروازراست}{vboxR}
\eqcommand{زی‌لاتک}{XeLaTeX}
\eqcommand{زی‌پرشین}{XePersian}
\eqcommand{گونه‌زی‌پرشین}{xepersianversion}
\eqcommand{تاریخ‌گونه‌زی‌پرشین}{xepersiandate}
\eqcommand{زی‌تک}{XeTeX}
\endinput
%%
%% End of file `xepersian-localise-commands-xepersian.def'.
