%%
%% This is file `packages-localise-xepersian.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% xepersian.dtx  (with options: `table,packages-localise-xepersian.def')
%% 
%%   __________________________________________________
%%   Vafa Khalighi
%% 
%%   Copyright (c) 2008--2022  Vafa Khalighi
%%   Copyright (c) 2018--2020 bidi-tex GitHub Organization
%% 
%%   It may be distributed and/or modified under the LaTeX Project Public License,
%%   version 1.3c or higher (your choice). The latest version of
%%   this license is at: http://www.latex-project.org/lppl.txt
%% 
%%   This work is “author-maintained” (as per LPPL maintenance status)
%%   by Vafa Khalighi.
%% 
%% 
%% \CheckSum{11192}
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\آماده‌سازی‌پرونده{packages-localise-xepersian.def}[2013/04/24 v0.2 localising LaTeX2e Packages]
\@گرسبک‌فراخوانی‌شده{color}{\ورودی{color-localise-xepersian.def}}{}
\@ifpackageloaded{multicol}{%
\newenvironment{چندستونی‌ها}{\begin{multicols}}{\end{multicols}}%
\newenvironment{چندستونی‌ها*}{\begin{multicols*}}{\end{multicols*}}%
}{}
\@ifpackageloaded{verbatim}{%
\begingroup
 \vrb@catcodes
 \lccode`\!=`\\ \lccode`\[=`\{ \lccode`\]=`\}
 \catcode`\~=\active \lccode`\~=`\^^M
 \lccode`\C=`\C
 \lowercase{\endgroup
    \def\xepersian@localize@verbatim@start#1{%
      \verbatim@startline
      \if\noexpand#1\noexpand~%
        \let\next\xepersian@localize@verbatim@
      \else \def\next{\xepersian@localize@verbatim@#1}\fi
      \next}%
    \def\xepersian@localize@verbatim@#1~{\xepersian@localize@verbatim@@#1!پایان\@nil}%
    \def\xepersian@localize@verbatim@@#1!پایان{%
       \verbatim@addtoline{#1}%
       \futurelet\next\xepersian@localize@verbatim@@@}%
    \def\xepersian@localize@verbatim@@@#1\@nil{%
       \ifx\next\@nil
         \verbatim@processline
         \verbatim@startline
         \let\next\xepersian@localize@verbatim@
       \else
         \def\@tempa##1!پایان\@nil{##1}%
         \@temptokena{!پایان}%
         \def\next{\expandafter\xepersian@localize@verbatim@test\@tempa#1\@nil~}%
       \fi \next}%
    \def\xepersian@localize@verbatim@test#1{%
           \let\next\xepersian@localize@verbatim@test
           \if\noexpand#1\noexpand~%
             \expandafter\verbatim@addtoline
               \expandafter{\the\@temptokena}%
             \verbatim@processline
             \verbatim@startline
             \let\next\xepersian@localize@verbatim@
           \else \if\noexpand#1
             \@temptokena\expandafter{\the\@temptokena#1}%
           \else \if\noexpand#1\noexpand[%
             \let\@tempc\@empty
             \let\next\xepersian@localize@verbatim@testend
           \else
             \expandafter\verbatim@addtoline
               \expandafter{\the\@temptokena}%
             \def\next{\xepersian@localize@verbatim@#1}%
           \fi\fi\fi
           \next}%
    \def\xepersian@localize@verbatim@testend#1{%
         \if\noexpand#1\noexpand~%
           \expandafter\verbatim@addtoline
             \expandafter{\the\@temptokena[}%
           \expandafter\verbatim@addtoline
             \expandafter{\@tempc}%
           \verbatim@processline
           \verbatim@startline
           \let\next\xepersian@localize@verbatim@
         \else\if\noexpand#1\noexpand]%
           \let\next\xepersian@localize@verbatim@@testend
         \else\if\noexpand#1\noexpand!%
           \expandafter\verbatim@addtoline
             \expandafter{\the\@temptokena[}%
           \expandafter\verbatim@addtoline
             \expandafter{\@tempc}%
           \def\next{\xepersian@localize@verbatim@!}%
         \else \expandafter\def\expandafter\@tempc\expandafter
           {\@tempc#1}\fi\fi\fi
         \next}%
    \def\xepersian@localize@verbatim@@testend{%
       \ifx\@tempc\@currenvir
         \verbatim@finish
         \edef\next{\noexpand\end{\@currenvir}%
                    \noexpand\xepersian@localize@verbatim@rescan{\@currenvir}}%
       \else
         \expandafter\verbatim@addtoline
           \expandafter{\the\@temptokena[}%
           \expandafter\verbatim@addtoline
             \expandafter{\@tempc]}%
         \let\next\xepersian@localize@verbatim@
       \fi
       \next}%
    \def\xepersian@localize@verbatim@rescan#1#2~{\if\noexpand~\noexpand#2~\else
        \@warning{Characters dropped after `\string\end{#1}'}\fi}}%
\def\همانطورکه‌هست{\begingroup\@verbatim \frenchspacing\@vobeyspaces
              \xepersian@localize@verbatim@start}
\@namedef{همانطورکه‌هست*}{\begingroup\@verbatim\xepersian@localize@verbatim@start}
\def\endهمانطورکه‌هست{\endtrivlist\endgroup\@doendpe}
\expandafter\let\csname endهمانطورکه‌هست*\endcsname =\endهمانطورکه‌هست
}{}
\ExplSyntaxOn
\AtBeginDocument{
  \xepersian_localize_patch_verbatim:
}
\cs_set:Npn \xepersian_localize_patch_verbatim: {
  \@ifpackageloaded{verbatim}{
    \cs_set:cpn {همانطورکه‌هست*} {
      \group_begin: \@verbatim \fontspec_print_visible_spaces: \xepersian@localize@verbatim@start
    }
  }{
  }
}
\ExplSyntaxOff
\@ifpackageloaded{graphicx}{%
\def\Gin@boolkey#1#2{%
\expandafter\@ifdefinable  \csname Gin@#2درست\endcsname{%
\expandafter\let\csname Gin@#2درست\expandafter\endcsname\csname Gin@#2true\endcsname}%
\expandafter\@ifdefinable  \csname Gin@#2نادرست\endcsname{%
\expandafter\let\csname Gin@#2نادرست\expandafter\endcsname\csname Gin@#2false\endcsname}%
  \csname Gin@#2\ifx\relax#1\relax true\else#1\fi\endcsname}
\define@key{Grot}{origin}[c]{%
 \@tfor\@tempa:=#1\do{%
    \if l\@tempa \Grot@x\z@\else
    \if چ\@tempa \Grot@x\z@\else
    \if r\@tempa \Grot@x\width\else
    \if ر\@tempa \Grot@x\width\else
    \if t\@tempa \Grot@y\height\else
    \if ب\@tempa \Grot@y\height\else
    \if b\@tempa \Grot@y-\depth\else
    \if ز\@tempa \Grot@y-\depth\else
    \if B\@tempa \Grot@y\z@\else
    \if ک\@tempa \Grot@y\z@\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi}}
\معادل@کلید{Gin}{پیش‌نویس}{draft}
\معادل@کلید{Gin}{مبدا}{origin}
\معادل@کلید{Grot}{مبدا}{origin}
\معادل@کلید{Gin}{بی‌اضافه}{clip}
\معادل@کلید{Gin}{حفظ‌تناسب}{keepaspectratio}
\معادل@کلید{Gin}{پهنای‌طبیعی}{natwidth}
\معادل@کلید{Gin}{بلندای‌طبیعی}{natheight}
\معادل@کلید{Gin}{مختصات}{bb}
\معادل@کلید{Gin}{محدوده‌نمایش}{viewport}
\معادل@کلید{Gin}{حذف‌اطراف}{trim}
\معادل@کلید{Gin}{زاویه}{angle}
\معادل@کلید{Gin}{پهنا}{width}
\معادل@کلید{Gin}{بلندا}{height}
\معادل@کلید{Gin}{بلندای‌کل}{totalheight}
\معادل@کلید{Gin}{ضریب}{scale}
\معادل@کلید{Gin}{نوع}{type}
\معادل@کلید{Gin}{پسوند}{ext}
\معادل@کلید{Gin}{خواندنی}{read}
\معادل@کلید{Gin}{فرمان}{command}
\معادل@کلید{Grot}{طول}{x}
\معادل@کلید{Grot}{عرض}{y}
\معادل@کلید{Grot}{واحد}{units}
}{}
\endinput
%%
%% End of file `packages-localise-xepersian.def'.
