% Copyright 2000-2005 Werner Lemberg <wl@gnu.org> and
%                     Han The Thanh <hanthethanh@gmx.net>.
% This file is part of vntex.  License: LPPL, version 1.3 or newer,
% according to http://www.latex-project.org/lppl.txt
%
%
% This is the file vps.def which provides VPS input encoding for
% Vietnamese.
%
% written by Werner Lemberg <wl@gnu.org> and
%            Han The Thanh <hanthethanh@gmx.net>
%
% History
%
%   1.0  2000/01/28
%
%     Initial release.
%
%   post 1.0  ?
%
%     Don't rely on dblaccnt.sty.
%
%   1.1  2005/04/21
%
%     Add copyright message and history.

\ProvidesFile{vps.def}[2005/04/21 v1.1 VPS Vietnamese input encoding]

\makeatletter

\DeclareInputText{2}{\d A}
\DeclareInputText{3}{\d\ACIRCUMFLEX}
\DeclareInputText{4}{\d\ABREVE}
\DeclareInputText{5}{\d E}
\DeclareInputText{6}{\d\ECIRCUMFLEX}
\DeclareInputText{16}{\d I}
\DeclareInputText{17}{\d O}
\DeclareInputText{18}{\d\OCIRCUMFLEX}
\DeclareInputText{19}{\d\OHORN}
\DeclareInputText{20}{\d U}
\DeclareInputText{21}{\d\UHORN}
\DeclareInputText{25}{\d Y}
\DeclareInputText{28}{\~\ACIRCUMFLEX}
\DeclareInputText{29}{\~\UHORN}

\DeclareInputText{128}{\@tabacckludge`A}
\DeclareInputText{129}{\h A}
\DeclareInputText{130}{\~A}
\DeclareInputText{131}{\@tabacckludge'\ACIRCUMFLEX}
\DeclareInputText{132}{\@tabacckludge`\ACIRCUMFLEX}
\DeclareInputText{133}{\h\ACIRCUMFLEX}
\DeclareInputText{134}{\d o}
\DeclareInputText{135}{\~\ocircumflex}
\DeclareInputText{136}{\ABREVE}
\DeclareInputText{137}{\@tabacckludge'\ecircumflex}
\DeclareInputText{138}{\@tabacckludge`\ecircumflex}
\DeclareInputText{139}{\h\ecircumflex}
\DeclareInputText{140}{\d\ecircumflex}
\DeclareInputText{141}{\@tabacckludge'\ABREVE}
\DeclareInputText{142}{\@tabacckludge`\ABREVE}
\DeclareInputText{143}{\h\ABREVE}

\DeclareInputText{144}{\@tabacckludge'\ECIRCUMFLEX}
\DeclareInputText{147}{\@tabacckludge`\ECIRCUMFLEX}
\DeclareInputText{148}{\h\ECIRCUMFLEX}
\DeclareInputText{149}{\~\ECIRCUMFLEX}
\DeclareInputText{150}{\@tabacckludge'\OCIRCUMFLEX}
\DeclareInputText{151}{\@tabacckludge`\OCIRCUMFLEX}
\DeclareInputText{152}{\h\OCIRCUMFLEX}
\DeclareInputText{153}{\~\OCIRCUMFLEX}
\DeclareInputText{154}{\@tabacckludge'y}
\DeclareInputText{155}{\h y}
\DeclareInputText{156}{\d y}
\DeclareInputText{157}{\@tabacckludge'\OHORN}
\DeclareInputText{158}{\@tabacckludge`\OHORN}
\DeclareInputText{159}{\h\OHORN}

\DeclareInputText{161}{\@tabacckludge'\abreve}
\DeclareInputText{162}{\@tabacckludge`\abreve}
\DeclareInputText{163}{\h\abreve}
\DeclareInputText{164}{\~\abreve}
\DeclareInputText{165}{\d\abreve}
\DeclareInputText{166}{\~\OHORN}
\DeclareInputText{167}{\@tabacckludge'\ohorn}
\DeclareInputText{168}{\@tabacckludge`U}
\DeclareInputText{169}{\@tabacckludge`\ohorn}
\DeclareInputText{170}{\h\ohorn}
\DeclareInputText{171}{\~\ohorn}
\DeclareInputText{172}{\~U}
\DeclareInputText{173}{\@tabacckludge'\UHORN}
\DeclareInputText{174}{\d\ohorn}
\DeclareInputText{175}{\@tabacckludge`\UHORN}

\DeclareInputText{176}{\h\ocircumflex}
\DeclareInputText{177}{\h\UHORN}
\DeclareInputText{178}{\@tabacckludge`Y}
\DeclareInputText{179}{\~Y}
\DeclareInputText{180}{\@tabacckludge'I}
\DeclareInputText{181}{\@tabacckludge`I}
\DeclareInputText{182}{\d\ocircumflex}
\DeclareInputText{183}{\h I}
\DeclareInputText{184}{\~I}
\DeclareInputText{185}{\@tabacckludge'O}
\DeclareInputText{186}{\h\uhorn}
\DeclareInputText{187}{\~\uhorn}
\DeclareInputText{188}{\@tabacckludge`O}
\DeclareInputText{189}{\h O}
\DeclareInputText{190}{\~O}
\DeclareInputText{191}{\d\uhorn}

\DeclareInputText{192}{\@tabacckludge`\acircumflex}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{194}{\ACIRCUMFLEX}
\DeclareInputText{195}{\@tabacckludge'\acircumflex}
\DeclareInputText{196}{\h\acircumflex}
\DeclareInputText{197}{\~\acircumflex}
\DeclareInputText{198}{\d\acircumflex}
\DeclareInputText{199}{\dj}
\DeclareInputText{200}{\h e}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{202}{\ECIRCUMFLEX}
\DeclareInputText{203}{\d e}
\DeclareInputText{204}{\h i}
\DeclareInputText{205}{\~\ecircumflex}
\DeclareInputText{206}{\d i}
\DeclareInputText{207}{\~y}

\DeclareInputText{208}{\UHORN}
\DeclareInputText{209}{\h U}
\DeclareInputText{210}{\@tabacckludge`\ocircumflex}
\DeclareInputText{211}{\@tabacckludge'\ocircumflex}
\DeclareInputText{212}{\OCIRCUMFLEX}
\DeclareInputText{213}{\h o}
\DeclareInputText{214}{\ohorn}
\DeclareInputText{215}{\@tabacckludge`E}
\DeclareInputText{216}{\@tabacckludge`\uhorn}
\DeclareInputText{217}{\@tabacckludge'\uhorn}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{219}{\~u}
\DeclareInputText{220}{\uhorn}
\DeclareInputText{221}{\@tabacckludge'Y}
\DeclareInputText{222}{\h E}

\DeclareInputText{224}{\@tabacckludge`a}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{226}{\acircumflex}
\DeclareInputText{227}{\~a}
\DeclareInputText{228}{\h a}
\DeclareInputText{229}{\d a}
\DeclareInputText{230}{\abreve}
\DeclareInputText{232}{\@tabacckludge`e}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{234}{\ecircumflex}
\DeclareInputText{235}{\~e}
\DeclareInputText{236}{\@tabacckludge`i}
\DeclareInputText{237}{\@tabacckludge'i}
\DeclareInputText{239}{\~i}

\DeclareInputText{240}{\~\ABREVE}
\DeclareInputText{241}{\DJ}
\DeclareInputText{242}{\@tabacckludge`o}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{244}{\ocircumflex}
\DeclareInputText{245}{\~o}
\DeclareInputText{247}{\OHORN}
\DeclareInputText{248}{\d u}
\DeclareInputText{249}{\@tabacckludge`u}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{251}{\h u}
\DeclareInputText{253}{\h Y}
\DeclareInputText{254}{\~E}
\DeclareInputText{255}{\@tabacckludge`y}

\makeatother

\endinput

% end of vps.def
