%% This file is luabidi-autofootnoterule.def
%% This is part of the luabidi package
%%
%% Copyright © 2009 Vafa Khalighi, 2013--2019 Arthur Reutenauer, 2019 Jürgen Spitzmüller
%%
%%%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.


%
% Determine first footnote on current page
%

\RequirePackage{perpage}
\newcounter{pagefnt}
\setcounter{pagefnt}{0}
\MakePerPage[0]{pagefnt}


%
% Footnote redefinitions
%

% Save original definitions
\let\FnppOrigFootnote=\footnote
\let\FnppOrigFootnotemark=\footnotemark

% Default: left-aligned rule
\leftfootnoterule

% \footnote
\def\footnote{%
    \@ifnextchar[%			% ] (Editor)
	\@xfootnote
	{\stepcounter\@mpfn\stepcounter{pagefnt}%
         \ifnum\value{pagefnt}=0%
             \if@RTL%
                 \rightfootnoterule%
             \else%
                 \leftfootnoterule%
             \fi%
         \fi%
         \@xfootnote[\the\c@footnote]%
        }%
}

% \RTLfootnote
\def\footnotemarkRL{%
    \@ifnextchar[%			% ] (Editor)
	\@xfootnotemark
	{\stepcounter\@mpfn\stepcounter{pagefnt}%
         \ifnum\value{pagefnt}=0%
             \rightfootnoterule%
         \fi%
         \@xfootnotemark[\the\c@footnote]%
        }%
}

% \LTRfootnote
\def\footnotemarkLR{%
    \@ifnextchar[%			% ] (Editor)
	\@xfootnotemark
	{\stepcounter\@mpfn\stepcounter{pagefnt}%
         \ifnum\value{pagefnt}=0%
            \leftfootnoterule%
         \fi%
         \@xfootnotemark[\the\c@footnote]%
        }%
}

% Finis
