\qt@newcmd\qurantrans@ur@i{(شروع کرتا ہوں) اللہ کے نام سے جو بڑا مہربان نہایت رحم والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ii{ہر قسم کی تعریف اس اللہ کے لیے جو سب جہانوں کا پروردگار ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@iii{جو (سب پر) بڑا مہربان (اور خاص بندوں پر) نہایت رحم کرنے والا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@iv{جزا و سزا کے دن کا مالک (و مختار) ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@v{(اے اللہ!) ہم تیری ہی عبادت کرتے ہیں اور تجھ ہی سے مدد مانگتے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@vi{ہمیں سیدھے راستے کی (اور اس پر چلنے کی) ہدایت کرتا رہ۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@vii{راستہ ان لوگوں کا جن پر تو نے انعام و احسان کیا نہ ان کا (راستہ) جن پر تیرا قہر و غضب نازل ہوا۔ اور نہ ان کا جو گمراہ ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@viii{\basmalahur الف۔ لام۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ix{یہ (قرآن) وہ کتاب ہے جس (کے کلام اللہ ہونے) میں کوئی شک و شبہ نہیں ہے۔ (یہ) ہدایت ہے ان پرہیزگاروں کے لیے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@x{جو غیب پر ایمان رکھتے ہیں اور پورے اہتمام سے نماز ادا کرتے ہیں اور جو کچھ ہم نے ان کو دیا ہے اس میں سے کچھ (میری راہ میں) خرچ کرتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@xi{اور جو ایمان رکھتے ہیں اس پر جو آپ پر نازل کیا گیا ہے اور اس پر بھی جو آپ سے پہلے (سابقہ انبیاء) پر نازل کیا گیا۔ اور آخرت پر یقین رکھتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@xii{یہی لوگ اپنے پروردگار کی ہدایت پر (قائم) ہیں اور یہی وہ ہیں جو (آخرت میں) فوز و فلاح پانے والے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@xiii{(اے رسول) جن لوگوں نے کفر اختیار کیا۔ ان کے لیے برابر ہے۔ آپ انہیں ڈرائیں یا نہ ڈرائیں۔ بہرحال وہ ایمان نہیں لائیں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@xiv{خدا نے ان کے دلوں اور ان کے کانوں پر مہر لگا دی ہے اور ان کی آنکھوں پر پردہ پڑ گیا ہے۔ اور (آخرت میں) ان کے لیے بڑا عذاب ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@xv{اور کچھ لوگ ایسے بھی ہیں جو کہتے ہیں کہ ہم اللہ اور روزِ آخرت پر ایمان لائے ہیں۔ حالانکہ وہ مؤمن نہیں ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@xvi{خدا اور اہل ایمان کو دھوکہ دے رہے ہیں حالانکہ وہ خود اپنے سوا کسی کو دھوکہ نہیں دیتے۔ مگر انہیں اس کا (احساس) نہیں ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@xvii{ان کے دلوں میں (نفاق) کی ایک بیماری ہے۔ سو اللہ نے ان کی بیماری اور بڑھا دی ہے اور ان کے (مسلسل) جھوٹ بولنے کی وجہ سے ان کے لیے دردناک عذاب ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@xviii{اور جب ان سے کہا جائے کہ زمین میں فساد نہ پھیلاؤ۔ تو کہتے ہیں کہ ہم تو اصلاح کرنے والے ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@xix{خبردار۔ درحقیقت وہی فساد پھیلانے والے ہیں۔ لیکن انہیں شعور نہیں ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@xx{اور جب ان سے کہا جاتا ہے کہ تم بھی اسی طرح ایمان لاؤ جس طرح اور لوگ ایمان لائے ہیں تو وہ کہتے ہیں کہ کیا ہم بیوقوفوں کی طرح ایمان لائیں؟ خبردار۔ یہی لوگ خود بیوقوف ہیں لیکن جانتے نہیں ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@xxi{اور یہ لوگ جب اہل ایمان سے ملتے ہیں تو کہتے ہیں کہ ہم بھی ایمان لائے ہیں اور جب علیحدگی میں اپنے شیطانوں سے ملتے ہیں تو کہتے ہیں کہ ہم تو تمہارے ساتھ ہیں ان (مسلمانوں) سے تو ہم صرف مذاق کر رہے ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@xxii{خود اللہ ان سے مذاق کر رہا ہے اور انہیں ڈھیل دے رہا ہے اور وہ اپنی سرکشی میں اندھوں کی طرح بھٹک رہے ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@xxiii{یہی وہ لوگ ہیں جنہوں نے ہدایت کے بدلے گمراہی خریدلی۔ سو نہ تو ان کی تجارت سود مند ہوئی اور نہ ہی انہیں ہدایت نصیب ہوئی۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@xxiv{ان کی مثال اس شخص کی سی ہے جس نے آگ روشن کی۔ اور جب آگ نے اس کے گرد و نواح کو روشن کر دیا تو اللہ نے ان کی روشنی (بینائی) سلب کر لی اور ان کو اندھیروں میں چھوڑ دیا اب انہیں کچھ سجھائی نہیں دیتا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@xxv{پس وہ ایسے بہرے، گونگے اور اندھے ہیں کہ اب (گمراہی سے راہِ ہدایت کی طرف) نہیں لوٹیں گے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@xxvi{یا (پھر ان کی مثال ایسی ہے جیسے) آسمان سے زور دار بارش برس رہی ہو جس میں تاریکیاں ہوں۔ اور گرج چمک بھی۔ اور وہ گرنے والی بجلیوں سے مرنے کے ڈر سے اپنی انگلیاں اپنے کانوں میں ٹھونس لیں۔ حالانکہ اللہ ہر طرف سے کافروں کو گھیرے ہوئے ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@xxvii{قریب ہے کہ بجلی (کی چمک) ان کی آنکھوں کو اچک لے (انہیں خیرہ کر دے) جب بجلی ان کے لئے اجالا کرتی ہے تو وہ اس کی روشنی میں چلنے لگتے ہیں اور جب اندھیرا چھا جاتا ہے تو کھڑے رہ جاتے ہیں اگر اللہ چاہتا تو ان کی سماعت و بصارت (سننے اور دیکھنے کی طاقت) کو زائل کر دیتا۔ بے شک اللہ ہر چیز پر قادر ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@xxviii{اے لوگو! اپنے اس پروردگار کی عبادت (پرستش) کرو جس نے تمہیں بھی پیدا کیا اور انہیں بھی جو تم سے پہلے ہو گزرے تاکہ تم پرہیزگار بن جاؤ۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@xxix{وہی (پروردگار) جس نے تمہارے لئے زمین کا فرش بچھایا اور آسمان کا شامیانہ لگایا (اور اسے چھت بنایا) اور آسمان (بلندی) سے پانی برسایا۔ اس سے تمہاری روزی کے لئے کچھ پھل برآمد کئے سو جان بوجھ کر (کسی کو) اللہ کا ہمسر و شریک نہ بناؤ۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@xxx{اور جو کچھ (قرآن) ہم نے اپنے بندہ (خاص) پر نازل کیا ہے اگر تمہیں اس (کے کلام اللہ ہونے) میں شک ہے تو تم اس کے مانند ایک ہی سورہ لے آؤ۔ اور اگر تم سچے ہو تو ایک اللہ کو چھوڑ کر اپنے سب حمایتیوں و ہم نواؤں کو بھی بلا لو۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@xxxi{لیکن اگر تم یہ کام نہ کر سکو اور ہرگز ایسا نہیں کر سکوگے تو پھر (دوزخ کی) اس آگ سے ڈرو۔ جس کا ایندھن آدمی اور پتھر ہیں جو کافروں کے لئے تیار کی گئی ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@xxxii{اور (اے رسول) ان لوگوں کو خوشخبری دے دو جو ایمان لائے اور نیک عمل کئے۔ کہ ان کے لئے (بہشت کے) ایسے باغ ہیں کہ جن کے نیچے سے نہریں جاری ہیں۔ جب بھی انہیں ان (باغات) سے کوئی پھل کھانے کو ملے گا تو وہ (اس کی صورت دیکھ کر) کہیں گے کہ یہ تو وہی ہے جو اس سے پہلے ہمیں (دنیا میں) کھانے کو مل چکا ہے۔ حالانکہ انہیں جو دیا گیا ہے وہ (صورت میں دنیا کے پھل سے) ملتا جلتا ہے (مگر ذائقہ الگ ہوگا) اور ان کے لئے وہاں پاکیزہ بیویاں ہوں گی اور وہ ان (بہشتوں) میں ہمیشہ ہمیشہ رہیں گے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@xxxiii{بے شک اللہ اس بات سے ہرگز نہیں شرماتا کہ (کسی مطلب کی وضاحت کے لئے) مچھر اور اس سے بھی بڑھ کر (کسی حقیر چیز) کی مثال بیان کرے۔ پس جو لوگ مؤمن ہیں وہ تو جانتے ہیں کہ یہ (مثال یقینا) حق ہے ان کے پروردگار کی طرف سے اور جو کافر ہیں وہ کہتے ہیں کہ ایسی مثال سے اللہ کا کیا مقصد ہے؟ اللہ ایسی مثال سے بہت سوں کو گمراہی میں چھوڑ دیتا ہے اور بہت سوں کو ہدایت کرتا ہے اور وہ گمراہی میں نہیں چھوڑتا مگر فاسقوں (نافرمانوں) کو۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@xxxiv{جو خدا سے مستحکم عہد و پیمان کرنے کے بعد اسے توڑ دیتے ہیں اور جس (رشتہ) کے جوڑنے کا اللہ نے حکم دیا ہے وہ اسے توڑتے ہیں۔ اور زمین میں فساد پھیلاتے ہیں (دراصل) یہی لوگ ہیں جو نقصان اٹھانے والے ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@xxxv{بھلا تم کس طرح اللہ کا انکار کرتے ہو۔ حالانکہ تم مردہ (بے جان) تھے تو اسی نے تمہیں زندہ کیا (جاندار بنایا) پھر وہی تمہیں موت دے گا پھر وہی تمہیں زندگی دے گا۔ پھر تم اسی کی طرف لوٹائے جاؤگے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@xxxvi{وہی تو وہ (اللہ) ہے جس نے تمہارے لئے پیدا کیا وہ سب کچھ جو زمین میں ہے پھر آسمان کی طرف توجہ فرمائی تو سات آسمان ہموار و استوار کر دیئے۔ اور وہ ہر چیز کا جاننے والا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@xxxvii{(اے رسول وہ وقت یاد کرو) جب تمہارے پروردگار نے فرشتوں سے کہا کہ میں زمین پر ایک خلیفہ (جانشین) بنانے والا ہوں تو انہوں نے کہا کیا تو اس میں اس کو (خلیفہ) بنائے گا جو اس میں فساد پھیلائے گا اور خون ریزی کرے گا۔ حالانکہ ہم تیری حمد و ثنائ کے ساتھ تسبیح کرتے ہیں اور تیری تقدیس (پاکیزگی بیان) کرتے ہیں۔ فرمایا: یقینا میں وہ کچھ جانتا ہوں جو تم نہیں جانتے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@xxxviii{اور اس (اللہ) نے آدم (ع) کو (تمام چیزوں کے) نام سکھائے۔ پھر ان کو (جن کے نام سکھائے تھے) فرشتوں کے سامنے پیش کیا اور فرمایا اگر تم سچے ہو (کہ تم خلافت کے زیادہ حقدار ہو) تو مجھے ان اشخاص کے نام بتاؤ۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@xxxix{انہوں نے کہا (ہر نقص و عیب سے) تیری ذات پاک ہے۔ ہمیں اس کے سوا جو تو نے ہمیں تعلیم دیا ہے (سکھایا ہے) اور مزید کچھ علم نہیں ہے۔ بے شک تو بڑا علم والا اور بڑی حکمت والا ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@xl{فرمایا: اے آدم تم ان کو ان کے نام بتاؤ۔ تو جب آدم نے ان (فرشتوں) کو ان کے نام بتا دیئے تو خدا نے فرمایا کیا میں نے تم سے نہیں کہا تھا کہ میں آسمانوں اور زمین کے سب مخفی رازوں کو جانتا ہوں اور وہ بھی جانتا ہوں جو تم ظاہر کر رہے ہو اور وہ بھی جو تم (اندرونِ دل) چھپائے ہوئے تھے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@xli{اور (وہ وقت یاد کرو) جب ہم نے فرشتوں سے کہا کہ آدم کے سامنے سجدہ میں گر جاؤ ابلیس کے سوا سب سجدہ میں گر گئے۔ اس نے انکار و تکبر کیا اور کافروں میں سے ہوگیا۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@xlii{اور ہم نے کہا: اے آدم! تم اور تمہاری بیوی دونوں بہشت میں رہو۔ اور اس سے جہاں سے تمہارا دل چاہے مزے اور فراغت کے ساتھ کھاؤ۔ لیکن اس (مخصوص) درخت کے پاس نہ جانا (اس کا پھل نہ کھانا) ورنہ تم زیاں کاروں میں سے ہو جاؤگے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@xliii{تب شیطان نے (اس درخت کے باعث) ان کے قدم پھسلائے۔ اور انہیں اس (عیش و آرام) سے نکلوا دیا جس میں وہ تھے اور ہم نے کہا اب تم (زمین پر) اتر جاؤ۔ ایک دوسرے کے دشمن ہو کر۔ اور تمہارے لئے زمین میں ایک (خاص) وقت تک ٹھہرنے اور فائدہ ا ٹھانے کا سامان موجود ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@xliv{اس کے بعد آدم نے اپنے پروردگار سے کچھ دعا کے کلمات (حاصل کئے) تو اس نے ان کی توبہ قبول کی کیونکہ وہ بڑا توبہ قبول کرنے والا اور بڑا رحم کرنے والا ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@xlv{ہم نے کہا تم سب اس سے اتر جاؤ۔ اس کے بعد اگر تمہارے پاس میری طرف سے کوئی ہدایت پہنچے تو جو لوگ میری اس ہدایت کی پیروی کریں گے۔ تو ان کے لئے نہ کوئی خوف ہوگا اور نہ ہی وہ غمگین ہوں گے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@xlvi{اور جو کفر اختیار کریں گے اور ہماری آیتوں (نشانیوں) کو جھٹلائیں گے وہی لوگ دوزخ والے ہوں گے۔ وہ اس میں ہمیشہ ہمیشہ رہیں گے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@xlvii{اے بنی اسرائیل (اولادِ یعقوب) میری وہ نعمت یاد کرو جو میں نے تم کو عطا کی تھی اور تم مجھ سے کئے ہوئے عہد و پیمان کو پورا کرو میں بھی تم سے کئے ہوئے اپنے عہد کو پورا کروں گا اور تم مجھ سے ڈرتے رہو۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@xlviii{اور اس کتاب (قرآن) پر ایمان لاؤ جو میں نے (اب) نازل کی ہے۔ جو اس (توراۃ) کی تصدیق کرتی ہے جو تمہارے پاس ہے اور تم اس کے اولین منکر نہ بنو اور آیتوں کو (ان میں تحریف کرکے) تھوڑی قیمت (دنیوی مفاد) پر فروخت نہ کرو۔ اور مجھ ہی سے (میری نافرمانی سے) ڈرو۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@xlix{اور حق کو باطل کے ساتھ خلط ملط نہ کرو اور جانتے بوجھتے ہوئے حق کو نہ چھپاؤ۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@l{اور نماز قائم کرو اور زکوٰۃ ادا کرو۔ اور (میری بارگاہ میں) رکوع کرنے (جھکنے) والوں کے ساتھ رکوع کرو (باجماعت نماز ادا کرو)۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@li{کیا تم دوسرے لوگوں کو تو نیکی کا حکم دیتے ہو مگر اپنے آپ کو بھول جاتے ہو؟ حالانکہ تم کتابِ خدا کی تلاوت کرتے رہتے ہو کیا تم عقل سے کام نہیں لیتے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@lii{اور (مشکلات و مصائب کے وقت) صبر (روزہ) اور نماز کے ذریعہ (خدا سے) مدد مانگو اور یہ (نماز یقینا بہت گراں ہے سوائے ان بندوں کے جو خشوع و خضوع رکھنے والے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@liii{اور (بارگاہِ خداوندی میں) عاجزی کرنے والے ہیں جو سمجھتے ہیں کہ انہیں اپنے پروردگار کا سامنا کرنا ہے (اس کے حضور پیش ہونا ہے) اور (آخرکار) اسی کی طرف پلٹ کر جانے والے ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@liv{اے بنی اسرائیل! میری وہ نعمت یاد کرو جس سے میں نے تمہیں نوازا تھا اور یہ کہ میں نے تمہیں دنیا جہاں کے لوگوں پر فضیلت دی۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@lv{اور اس دن (قیامت) سے ڈرو جب کوئی کسی کو فائدہ نہیں پہنچا سکے گا اور نہ ہی کسی کی طرف سے کوئی سفارش قبول ہوگی۔ اور نہ کسی سے کوئی معاوضہ لیا جائے گا۔ اور نہ ان کی کوئی مدد کی جائے گی۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@lvi{اور (وہ وقت یاد کرو) جب ہم نے تمہیں فرعونیوں سے نجات دی تھی۔ جو تمہیں بدترین عذاب کا مزہ چکھاتے تھے (یعنی) تمہارے لڑکوں کو قتل کر ڈالتے تھے اور تمہاری عورتوں (بیٹیوں) کو (اپنی خدمت گزاری کے لئے) زندہ رہنے دیتے تھے اور اس میں تمہارے پروردگار کی بڑی سخت آزمائش تھی۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@lvii{اور (وہ وقت یاد کرو) جب ہم نے تمہارے لئے سمندر کو شگافتہ کیا (اسے پھاڑ کر تمہارے لئے راستہ بنایا) اور تمہیں نجات دی اور تمہارے دیکھتے دیکھتے فرعونیوں کو غرق کر دیا۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@lviii{اور (وہ وقت یاد کرو) جب ہم نے موسیٰ سے (توراۃ دینے کے لئے) چالیس راتوں کا وعدہ کیا تھا پھر تم نے ان کے بعد گو سالہ (بچھڑے) کو (معبود) بنا لیا۔ جبکہ تم ظالم تھے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@lix{پھر ہم نے اس (ظلم) کے بعد بھی معاف کر دیا۔ تاکہ تم شکر گزار بنو۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@lx{اور (وہ وقت یاد کرو) جب فرعونی (تم پر ظلم کر رہے تھے تو) ہم نے موسیٰ کو کتاب فرقان عطا کی تاکہ تم ہدایت حاصل کرو۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@lxi{اور (وہ وقت یاد کرو) جب (موسیٰ نے اپنی قوم سے کہا) اے میری قوم! یقینا تم نے گو سالہ کو (معبود) بنا کر اپنی جانوں پر بڑا ظلم کیا ہے۔ لہٰذا تم اپنے خالق کی بارگاہ میں (اس طرح) توبہ کرو۔ کہ اپنی جانوں کو قتل کرو۔ یہی (طریقہ کار) تمہارے خالق کے نزدیک تمہارے لئے بہتر ہے۔ اس صورت میں اس نے تمہاری توبہ قبول کی۔ بے شک وہ بڑا توبہ قبول کرنے والا، نہایت رحم والا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@lxii{اور (وہ وقت یاد کرو) جب تم نے کہا اے موسیٰ! اس وقت تک ہم ہرگز ایمان نہیں لائیں گے جب تک ظاہر بظاہر (اعلانیہ) خدا کو دیکھ نہ لیں۔ سو (اس پر) تمہارے دیکھتے بجلی نے تمہیں اپنی گرفت میں لے لیا۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@lxiii{پھر ہم نے تمہاری موت کے بعد تمہیں زندہ کیا تاکہ (اس احسان کے بعد) تم شکرگزار بن جاؤ۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@lxiv{اور ہم نے (صحراء میں) تمہارے اوپر ابر کا سایہ کیا اور تم پر من و سلویٰ نازل کیا (اور کہا) کہ ان پاکیزہ چیزوں میں سے کھاؤ جو ہم نے تم کو عطا کی ہیں۔ اور ان لوگوں نے (ناشکری کرکے) ہم پر کوئی زیادتی نہیں کی بلکہ وہ اپنی ہی جانوں پر ظلم کرتے رہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@lxv{اور (یاد کرو وہ وقت) جب ہم نے کہا کہ اس بستی (بیت المقدس یا اریحا) میں داخل ہو جاؤ اور اس میں سے جہاں سے چاہو (اور جو چاہو) مزے سے بافراغت کھاؤ۔ (پیو) اور دروازے سے سجدہ کرتے ہوے حطہ (بخشش) کہتے ہوئے داخل ہو جاؤ۔ ہم تمہاری خطائیں معاف کر دیں گے اور ہم نیکی کرنے والوں کو کچھ زیادہ ہی (ثواب) عطا کریں گے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@lxvi{مگر ان ظالموں نے وہ بات (حطہ) جو ان سے کہی گئی تھی اسے ایک اور بات سے بدل دیا (اور حطۃ کی بجائے حنطۃ کہا) لہٰذا ہم نے ان کی نافرمانیوں کی وجہ سے ان پر آسمان سے بڑا عذاب نازل کیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@lxvii{اور (وہ وقت بھی یاد کرو) جب موسیٰ نے اپنی قوم کے لئے (خدا سے) پانی مانگا۔ تو ہم نے کہا اپنا عصا چٹان پر مارو جس کے نتیجہ میں بارہ چشمے پھوٹ نکلے اس طرح ہر گروہ نے اپنا اپنا گھاٹ معلوم کر لیا۔ (ہم نے کہا) خدا کے دیئے ہوئے رزق سے کھاؤ پیو اور زمین میں فساد پھیلاتے نہ پھرو۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@lxviii{اور (وہ وقت بھی یاد کرو) جب تم نے کہا اے موسیٰ! ہم ایک ہی (قسم کے) کھانے پر ہرگز صبر نہیں کر سکتے۔ اس لئے آپ اپنے پروردگار سے ہمارے لئے دعا کیجئے کہ وہ (من و سلویٰ کی بجائے) ہمارے لئے وہ چیزیں نکالے (پیدا کرے) جو زمین اگاتی ہے جیسے ساگ پات، ترکاری، کھیرا، ککڑی، مسور اور لہسن پیاز۔ موسیٰ نے کہا کیا تم کمتر و کہتر چیز لینا چاہتے ہو اس کے بدلہ میں جو برتر و بہتر ہے۔ اچھا شہر میں اتر پڑو۔ بے شک (وہاں) تمہیں وہ کچھ مل جائے گا جو تم مانگتے ہو۔ اور (انجام کار) ان پر ذلت و خواری اور افلاس و ناداری مسلط ہوگئی۔ اور وہ (اللہ کی نشانیوں کا ) انکار کرتے تھے اور انبیاء کو ناحق قتل کرتے تھے (اور یہ اس لئے بھی ہوا) کہ وہ نافرمانی کرتے تھے اور حد سے بڑھ بڑھ جاتے تھے (سرکشی کرتے تھے)۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@lxix{بے شک جو لوگ مؤمن یہودی نصرانی اور صابی (ستارہ پرست) کہلاتے ہیں (غرض) جو کوئی بھی (واقعی) اللہ اور آخرت پر ایمان لائے اور نیک عمل کرے۔ تو ان (سب) کے لئے ان کے پروردگار کے پاس ان کا اجر و ثواب (محفوظ) ہے اور ان کے لئے نہ کوئی خوف ہے اور نہ ہی وہ غمگین ہوں گے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@lxx{اور (اس وقت کو یاد کرو) جب ہم نے (کوہ) طور کو تم پر اٹھا کر (اور لٹکا کر) یہ عہد و پیمان لیا تھا کہ ہم نے جو کچھ تم کو دیا ہے (توراۃ) اسے مضبوطی سے پکڑو۔ اور جو کچھ اس میں ہے اسے یاد رکھو (اس پر عمل کرو) تاکہ تم پرہیزگار بن جاؤ۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@lxxi{پھر تم اس (پختہ عہد) کے بعد پھر گئے۔ سو اگر تم پر اللہ کا خاص فضل و کرم اور اس کی خاص رحمت نہ ہوتی تو تم سخت خسارہ (گھاٹا) اٹھانے والوں میں ہو جاتے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@lxxii{اور یقینا تمہیں ان لوگوں کا تو علم ہے جنہوں نے تم میں سے یوم السبت (ہفتہ کے دن) کے بارے میں زیادتی کی۔ (اور اس دن شکار کرکے قانون شکنی کی) تو ہم نے ان سے کہا کہ تم دھتکارے ہوئے بندر بن جاؤ۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@lxxiii{پس ہم نے اس واقعہ کو اس زمانہ کے لوگوں اور بعد میں آنے والوں کے لئے (سامان) عبرت اور پرہیزگاروں کے لئے نصیحت بنا دیا۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@lxxiv{اور (اس وقت کو یاد کرو) جب موسیٰ نے اپنی قوم سے کہا کہ اللہ تمہیں حکم دیتا ہے کہ ایک گائے ذبح کرو۔ کہنے لگے آپ ہم سے مذاق کرتے ہیں فرمایا: میں اس سے خدا کی پناہ مانگتا ہوں کہ میں جاہلوں میں سے ہو جاؤں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@lxxv{انہوں نے کہا ہماری خاطر اپنے پروردگار سے التجا کیجئے کہ وہ ہمیں کھول کر بتائے کہ گائے کیسی ہو؟ (موسیٰ نے) کہا وہ (اللہ) فرماتا ہے کہ وہ نہ بالکل بوڑھی ہو اور نہ بالکل بن بیاہی بچھڑی۔ بلکہ ان دونوں کے بین (اوسط عمر کی ہو) جو حکم تمہیں دیا جا رہا ہے اس کی تعمیل کرو۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@lxxvi{کہنے لگے کہ ہماری طرف سے اپنے پروردگار سے درخواست کیجئے کہ وہ ہمیں کھول کر بتائے کہ اس کا رنگ کیسا ہو؟ کہا وہ (اللہ) فرماتا ہے کہ وہ ایسے شوخ گہرے زرد رنگ کی ہو کہ دیکھنے والے کا جی خوش کر دے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@lxxvii{وہ بولے ہماری طرف سے اپنے پروردگار سے عرض کیجئے کہ وہ ہمیں کھول کر بتائے کہ وہ گائے کیسی ہو چونکہ یہ گائے ہم پر مشتبہ ہوگئی ہے؟ اور اگر اللہ نے چاہا تو ہم (اس گائے تک) صحیح راستہ پا جائیں گے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@lxxviii{(موسیٰ نے) کہا وہ (پروردگار) فرماتا ہے کہ وہ ایسی گائے ہے جو سدھائی ہوئی نہیں ہے۔ نہ زمین کو جوتتی ہے اور نہ کھیتی کو پانی دیتی ہے۔ وہ صحیح سالم اور بے عیب ہے (اور ایسی یک رنگی ہے کہ) اس میں کوئی داغ دھبہ نہیں ہے اس پر پکار اٹھے اب آپ ٹھیک بات لائے غرض اب انہوں نے اسے ذبح کیا جبکہ وہ ایسا کرتے معلوم نہیں ہوتے تھے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@lxxix{اور (وہ وقت یاد کرو) جب تم نے ایک شخص کو قتل کر ڈالا تھا۔ اور پھر اس کے بارے میں باہم جھگڑنے لگے (ایک دوسرے پر قتل کا الزام لگانے لگے) اور اللہ اس چیز کو ظاہر کرنے والا تھا جسے تم چھپا رہے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@lxxx{(اس لئے) ہم نے کہا کہ اس گائے کا کوئی ٹکڑا اس (مقتول کی لاش) پر مارو۔ اسی طرح اللہ مردوں کو زندہ کرتا ہے۔ اور تمہیں اپنی قدرت کی نشانیاں دکھاتا ہے تاکہ تم عقل سے کام لو۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@lxxxi{(اے بنی اسرائیل) پھر اس کے بعد تمہارے دل ایسے سخت ہوگئے کہ گویا وہ پتھر ہیں بلکہ اس سے بھی زیادہ سخت کیونکہ پتھروں میں سے کچھ ایسے بھی ہوتے ہیں جن سے نہریں پھوٹ نکلتی ہیں۔ اور کچھ ایسے بھی ہوتے ہیں جو پھٹ جاتے ہیں اور ان سے پانی نکل آتا ہے۔ اور کچھ ایسے بھی ہیں کہ جو خدا کے خوف و خشیہ سے گر پڑتے ہیں۔ اور تم لوگ جو کچھ بھی کرتے ہو اللہ اس سے غافل (بے خبر) نہیں ہے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@lxxxii{(اے مسلمانو) کیا تم یہ توقع رکھتے ہو کہ یہ (یہودی) تمہارے کہنے سے ایمان لائیں گے حالانکہ ان میں سے ایک گروہ ایسا بھی گزرا ہے جو اللہ کا کلام سنتا تھا اور پھر اسے سمجھنے کے بعد دیدہ و دانستہ اس میں تحریف (رد و بدل) کر دیتا تھا۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@lxxxiii{اور (یہ منافق لوگ) جب اہل ایمان سے ملتے ہیں تو کہتے ہیں ہم بھی ایمان لائے ہیں اور جب آپس میں تنہا ہوتے ہیں تو کہتے ہیں کہ کیا تم ان (مسلمانوں) کو وہ باتیں بتاتے ہو جو اللہ نے (توراۃ میں) تم پر ظاہر کی ہیں۔ تاکہ وہ انہیں تمہارے پروردگار کے حضور تمہارے خلاف بطور حجت پیش کریں۔ کیا تم عقل سے کام نہیں لیتے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@lxxxiv{کہا یہ لوگ اتنا بھی نہیں جانتے کہ اللہ وہ سب کچھ جانتا ہے جو کچھ یہ چھپاتے ہیں اور جو کچھ ظاہر کرتے ہیں۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@lxxxv{اور ان (یہود) میں کچھ ایسے ان پڑھ بھی ہیں جو بے بنیاد امیدوں اور جھوٹی آرزوؤں کے سوا کتاب (توراۃ) کا کچھ بھی علم نہیں رکھتے۔ اور وہ صرف خام خیالیوں میں پڑے رہتے ہیں۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@lxxxvi{سو خرابی و بربادی ہے ان لوگوں کے لئے جو اپنے ہاتھوں سے (جعلی) کتاب (تحریر) لکھتے ہیں اور پھر کہتے ہیں کہ یہ اللہ کی طرف سے (آئی) ہے تاکہ اس کے عوض تھوڑی سی قیمت (دنیوی فائدہ) حاصل کریں پس خرابی ہے ان کے لئے ان کے ہاتھوں کی لکھائی پر اور بربادی ہے۔ ان کے لئے ان کی اس کمائی پر ۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@lxxxvii{اور یہ لوگ کہتے ہیں کہ گنتی کے چند دنوں کے سوا دوزخ کی آگ ہمیں چھو بھی نہیں سکتی (اے رسول) آپ ان سے کہیے! کیا تم نے خدا سے کوئی عہد و پیمان لے لیا ہے کہ خدا کبھی اپنے عہد کی خلاف ورزی نہیں کرے گا؟ یا اللہ کے ذمہ وہ بات لگا رہے ہو جس کا تمہیں کوئی علم نہیں ہے۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@lxxxviii{کیوں نہیں (چھوئے گی) جو بھی برا کام کرے گا اور اس کا گناہ (چاروں طرف سے) اسے گھیر لے گا یہی لوگ دوزخی ہیں جس میں وہ ہمیشہ ہمیشہ رہیں گے۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@lxxxix{اور جو لوگ ایمان لائے اور (اس کے ساتھ ساتھ) نیک عمل بھی کئے یہی لوگ بہشتی ہیں جس میں وہ ہمیشہ ہمیشہ رہیں گے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@xc{اور (وہ وقت یاد کرو) جب ہم نے بنی اسرائیل سے یہ پختہ عہد لیا تھا کہ اللہ کے سوا کسی کی عبادت نہ کرنا۔ ماں باپ سے (خصوصاً) رشتہ داروں، یتیموں اور مسکینوں سے (عموماً) نیک سلوک کرنا اور سب سے اچھی بات کہنا، نماز قائم کرنا اور زکوٰۃ ادا کرنا۔ مگر تم میں سے تھوڑے آدمیوں کے سوا باقی سب اس (عہد) سے پھر گئے۔ اور تم ہو ہی روگردانی کرنے والے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@xci{اور (وہ وقت یاد کرو) جب ہم نے تم سے پختہ عہد لیا تھا کہ آپس میں ایک دوسرے کا خون نہ بہانا، ایک دوسرے کو اپنے وطن سے (نکال کر) بے وطن نہ کرنا۔ پھر تم نے اس کا اقرار کیا اور تم خود اس کے گواہ ہو۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@xcii{پھر تم ہی وہ ہو۔ جو اپنوں کو قتل کرتے ہو۔ اور اپنے بھائی بندوں کے کچھ لوگوں کو ان کے وطن سے نکال بھی دیتے ہو اور ان کے خلاف گناہ اور ظلم و زیادتی کے ساتھ سازش کرتے ہو اور جتھے بندی کرتے ہو (ان کے مخالفین کی مدد کرتے ہو) اور (پھر لطف یہ ہے کہ) اگر وہی لوگ دشمنوں کے ہاتھوں قید ہو کر تمہارے پاس آجائیں۔ تو تم ہی فدیہ دے کر انہیں چھڑا لیتے ہو۔ حالانکہ ان کا وطن سے نکالنا تم پر حرام تھا۔ کیا تم کتاب (توراۃ) کے ایک حصہ (فدیہ دینے) پر ایمان لاتے ہو۔ اور دوسرے حصہ (جلا وطن کرنے کی حرمت) کا انکار کرتے ہو؟ تم میں سے جو ایسا کرے اس کی سزا اس کے سوا اور کیا ہے کہ دنیا کی زندگی میں ذلیل و خوار ہو اور قیامت کے دن سخت ترین عذاب کی طرف لوٹا دیئے جائیں اور تم جو کچھ بھی کرتے ہو اللہ اس سے غافل (بے خبر) نہیں ہے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@xciii{یہ وہ (بدقسمت) لوگ ہیں جنہوں نے آخرت کی (ابدی زندگی) کے عوض دنیوی (فانی) زندگی خرید لی ہے پس نہ ہی ان کے عذاب میں کوئی تخفیف کی جائے گی اور نہ ہی ان کی کوئی مدد کی جائے گی۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@xciv{البتہ ہم نے موسیٰ کو کتاب (توراۃ) عطا کی۔ اور ان کے بعد ہم نے پے در پے رسول بھیجے اور عیسیٰ بن مریم کو کھلی نشانیاں عطا کیں اور روح القدس کے ذریعہ سے ان کی تائید کی۔ (اس کے باوجود جب بھی کوئی رسول تمہاری خواہشات نفسی کے خلاف کوئی حکم لے کر تمہارے پاس آیا تو تم نے تکبر کیا سو بعض کو جھٹلایا اور بعض کو قتل کر ڈالا۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@xcv{اور وہ کہتے ہیں کہ ہمارے دلوں پر (قدرتی) غلاف چڑھے ہوئے ہیں (ہماری سمجھ میں کچھ نہیں آتا)۔ نہیں۔ بلکہ اللہ نے ان کے کفر کی وجہ سے ان پر لعنت کی ہے (اپنی رحمت سے دور کر دیا ہے) اس لئے وہ کم ہی ایمان لائیں گے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@xcvi{اور جب ان کے پاس اللہ کی طرف سے وہ کتاب آئی جو ان کے پاس والی کتاب (توراۃ) کی تصدیق کرتی ہے باوجودیکہ اس کے آنے سے پہلے خود یہ لوگ کافروں کے خلاف اس کے ذریعہ سے فتح و ظفر طلب کیا کرتے تھے۔ مگر جب وہ (کتاب) ان کے پاس آگئی جسے وہ پہچانتے تھے تو اس کا انکار کر دیا۔ پس کافروں (منکروں) پر اللہ کی لعنت ہو۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@xcvii{سو کس قدر بری ہے وہ چیز جس کے عوض ان لوگوں نے اپنی جانوں کا سودا کیا ہے کہ محض اس ضد اور سرکشی کی بناء پر اللہ کی نازل کردہ کتاب کا انکار کر دیا کہ اس نے اپنے بندوں میں سے ایک خاص بندہ (نبی خاتم (ع)) پر اپنے فضل و کرم سے کیوں (وحی نبوت و کتاب) نازل کر دی؟ پس وہ اس روش کے نتیجہ میں (خدا کے) غضب بالائے غضب کے سزاوار ہوئے اور کافروں کے لئے ذلت آمیز عذاب ہے۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@xcviii{اور جب ان سے کہا جاتا ہے کہ جو (قرآن) اللہ نے نازل کیا ہے اس پر ایمان لاؤ۔ تو وہ کہتے ہیں کہ ہم اس پر تو ایمان رکھتے ہیں جو ہم (بنی اسرائیل) پر نازل کیا گیا ہے مگر اس کے علاوہ جو کچھ (قرآن، انجیل وغیرہ) ہے اس کا انکار کرتے ہیں حالانکہ وہ حق ہے اور جو ان کے پاس موجود ہے (توراۃ) اس کی بھی تصدیق کرتا ہے (اے رسول) آپ ان سے کہیے کہ اگر تم (توراۃ پر) ایمان رکھتے تھے تو اس سے پہلے (اگلے زمانہ) میں اللہ کے نبیوں کو کیوں قتل کرتے رہے ہو؟ ۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@xcix{اور یقینا موسیٰ تمہارے پاس کھلے ہوئے معجزے لے کر آئے پھر بھی تم ایسے ظالم تھے کہ ان کے (کوہ طور پر جانے کے) بعد گوسالہ کو (معبود) بنا لیا۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@c{اور (وہ وقت یاد کرو) کہ جب ہم نے تم سے عہد و پیمان لیا اور تمہارے اوپر کوہِ طور کو بلند کیا (اور کہا تھا کہ جو کچھ ہم نے تمہیں دیا ہے اسے مضبوطی سے پکڑو۔ اور جو کچھ اس میں ہے اسے غور سے) سنو تو (تمہارے اسلاف) نے زبان سے کہا کہ ہم نے سن تو لیا اور دل میں کہا ہم عمل نہیں کریں گے اور ان کے کفر کی وجہ سے ان کے دلوں میں گوسالہ کی محبت بیٹھ گئی تھی۔ (اے رسول) کہیے! اگر تم مؤمن ہو تو تمہارا ایمان تمہیں بہت ہی برے کاموں کا حکم دیتا ہے (یہ عجیب ایمان ہے)۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ci{نیز ان سے کہیے کہ اگر خدا کے نزدیک آخرت کا گھر (جنت) دوسرے لوگوں کو چھوڑ کر صرف تمہارے لئے مخصوص ہے تو پھر موت کی آرزو کرو۔ اگر تم اپنے اس دعویٰ میں سچے ہو (تاکہ جلدی بہشت میں داخل ہو جاؤ)۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@cii{اور (سن لو) کہ یہ لوگ ان (اعمالِ بد) کی وجہ سے جو ان کے ہاتھ آگے بھیج چکے ہیں کبھی بھی موت کی آرزو نہیں کریں گے اور خدائے تعالیٰ ظالموں کو خوب جانتا ہے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ciii{اور (اے نبی!) تم ان کو سب لوگوں سے حتیٰ کہ مشرکوں سے بھی بڑھ کر زندگی کا حریص پاؤ گے ان میں ہر ایک چاہتا ہے کہ کاش اسے ایک ہزار سال کی عمر ملے حالانکہ اس قدر عمر کا مل جانا بھی اسے خدا کے عذاب سے نہیں بچا سکتا اور یہ لوگ جو کچھ کر رہے ہیں اللہ اسے خوب دیکھ رہا ہے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@civ{(اے رسول(ص)) کہہ دیجیئے! کہ جو شخص جبرئیل کا دشمن ہے (ہوا کرے) اس نے تو وہ (قرآن) خدا کے حکم سے آپ کے دل میں اتارا ہے، جو اپنے سے پہلے (نازل شدہ) کتابوں کی تصدیق کرتا ہے اور اہل ایمان کے لئے ہدایت اور کامیابی کی بشارت ہے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cv{جو کوئی اللہ، اس کے فرشتوں، اس کے رسولوں اور (خاص کر) جبرئیل و میکائیل کا دشمن ہو تو بے شک اللہ بھی کافروں کا دشمن ہے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cvi{(اے رسول(ص)) بالیقین ہم نے تمہاری طرف واضح آیتیں نازل کی ہیں اور ان کا انکار نہیں کرتے مگر وہی جو فاسق (نافرمان) ہیں۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cvii{اور کیا (ہمیشہ ایسا نہیں ہوا کہ) جب بھی انہوں (یہود) نے کوئی عہد کیا۔ تو انہی کے ایک گروہ نے اسے پس پشت ڈال دیا (توڑ دیا) بلکہ ان میں سے اکثر بے ایمان ہیں۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cviii{اور جب ان کے پاس اللہ کی طرف سے وہ رسول (حضرت محمد(ص)) آیا جو ان کے پاس والی کتاب کی تصدیق کرنے والا ہے تو انہی اہل کتاب میں سے ایک گروہ نے کتابِ خدا (توراۃ) کو اس طرح پس پشت ڈال دیا کہ جیسے کہ وہ اسے جانتے ہی نہیں۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cix{اور (یہ لوگ) ان (بے بنیاد) چیزوں کی پیروی کرنے لگے جو شیاطین سلیمان کے عہد سلطنت میں پڑھ کر سنایا کرتے تھے۔ حالانکہ سلیمان نے کبھی کفر نہیں کیا۔ بلکہ ان شیطانوں نے کفر کیا جو لوگوں کو جادو کی تعلیم دیتے تھے (نیز) وہ اس چیز (جادو) کی پیروی کرنے لگے جو بابل کے مقام پر ہاروت و ماروت نامی دو فرشتوں پر اتاری گئی۔ حالانکہ یہ دونوں فرشتے اس وقت تک کسی کو کچھ تعلیم نہیں دیتے تھے جب تک پہلے یہ نہیں کہتے تھے کہ ہم محض آزمائش ہیں۔ لہٰذا (اس علم کو غلط استعمال کرکے) کافر نہ ہو جانا (بایں ہمہ) لوگ ان سے وہ کچھ سیکھتے تھے جس سے مرد اور اس کی بیوی میں جدائی ڈال دیں۔ حالانکہ وہ اذنِ خدا کے بغیر کسی کو کوئی نقصان نہیں پہنچا سکتے تھے۔ الغرض وہ لوگ ان سے وہ چیز سیکھتے تھے جو ان کو ضرر پہنچاتی تھی اور کوئی فائدہ نہیں پہنچاتی تھی۔ اور وہ اچھی طرح جانتے تھے کہ جو شخص (دین کے بدلے) ان چیزوں کو خریدے گا۔ اس کا آخرت میں کوئی حصہ نہیں ہے اور کس قدر برا (معاوضہ) ہے جس پر انہوں نے اپنی جانوں کا سودا کیا۔ کاش انہیں اس کا علم ہوتا۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cx{اور اگر یہ لوگ ایمان لاتے اور پرہیزگاری اختیار کرتے تو خدا کی بارگاہ سے انہیں جو ثواب ملتا وہ (اس سے) بہتر ہوتا کاش انہیں اس کا علم ہوتا۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cxi{اے ایمان والو (پیغمبر (ع) سے) راعنا نہ کہا کرو (بلکہ) انظرنا کہا کرو اور (توجہ سے ان کی بات) سنا کرو اور کافروں کے لئے دردناک عذاب ہے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cxii{جو لوگ کافر ہیں (خواہ) اہل کتاب میں سے ہوں یا مشرکین میں سے وہ ہرگز پسند نہیں کرتے کہ تمہارے پروردگار کی طرف سے تمہارے لئے کوئی بھلائی نازل ہو۔ حالانکہ اللہ جسے چاہتا ہے اپنی رحمت کے لئے مخصوص کر لیتا ہے اور اللہ بڑے فضل و کرم والا ہے۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cxiii{ہم جس آیت کو منسوخ کر دیتے ہیں یا اسے بھلا دیتے ہیں تو اس سے بہتر یا اس جیسی لاتے ہیں۔ کیا تم نہیں جانتے کہ اللہ ہر چیز پر بڑی قدرت رکھتا ہے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cxiv{کیا تمہیں معلوم ہے کہ آسمانوں اور زمین کی سلطنت اللہ ہی کے لئے ہے۔ اور اللہ کے سوا تمہارا کوئی سرپرست اور مددگار نہیں ہے۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cxv{(اے مسلمانو) کیا تم چاہتے ہو کہ اپنے رسول سے ویسے ہی (احمقانہ) سوال کرو۔ جیسے اس سے پہلے موسیٰ سے کئے گئے تھے؟ اور جس شخص نے ایمان کے عوض کفر اختیار کیا وہ راہِ راست سے بھٹک گیا۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cxvi{(اے مسلمانو!) بہت سے اہل کتاب اپنے ذاتی حسد کی وجہ سے چاہتے ہیں کہ ایمان لانے کے بعد تمہیں پھر کافر بنا دیں باوجودیکہ ان پر حق واضح ہو چکا ہے سو تم عفو و درگزر سے کام لو یہاں تک کہ اللہ ان کے بارے میں اپنا حکم بھیجے یقینا اللہ ہر چیز پر قادر ہے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cxvii{اور نماز قائم کرو۔ اور زکوٰۃ ادا کرو۔ اور جو کچھ نیکی اور بھلائی اپنے لئے (زادِ راہ کے طور پر) آگے بھیج دوگے اسے اللہ کے یہاں موجود پاؤگے جو کچھ تم کرتے ہو اللہ اسے دیکھ رہا ہے۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cxviii{اور وہ (یہود و نصاریٰ) کہتے ہیں کہ کوئی ہرگز جنت میں داخل نہیں ہوگا مگر وہی جو یہودی و نصرانی ہوگا۔ یہ ان کی خیال بندیاں اور خالی تمنائیں ہیں۔ ان سے کہہ دیجئے کہ اگر تم (اپنے دعویٰ میں) سچے ہو تو اپنی کوئی دلیل پیش کرو۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cxix{ہاں۔ (کسی کی کوئی خصوصیت نہیں ہے) جو شخص (حق سن کر) اپنا سر تسلیم خدا کے سامنے خم کر دے اور (مقام عمل میں) نیکوکار بھی ہو تو اس کے پروردگار کے پاس اس کا اجر و ثواب ہے اور (قیامت کے دن) ایسے لوگوں کو کوئی خوف نہ ہوگا اور نہ وہ غمگین ہوں گے۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cxx{یہودی کہتے ہیں کہ نصرانی کسی چیز (راہ راست) پر نہیں اور نصرانی کہتے ہیں کہ یہودی کسی چیز (راہ راست) پر نہیں حالانکہ یہ سب (آسمانی) کتاب کے پڑھنے والے ہیں اسی طرح (بے بنیاد) باتیں ان لوگوں (کفار و مشرکین) نے بھی کی ہیں جو کچھ بھی علم نہیں رکھتے۔ پس جن باتوں میں یہ لوگ آپس میں جھگڑ رہے ہیں قیامت کے دن اللہ ان کے درمیان فیصلہ کر دے گا۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cxxi{اور اس شخص سے بڑھ کر ظالم کون ہو سکتا ہے جو اللہ کی مسجدوں میں اللہ کے ذکر سے (اللہ کے بندوں کو) روکے اور ان کی ویرانی و بربادی کی کوشش کرے حالانکہ (روکنے والوں) کو یہ حق نہیں پہنچتا کہ وہ مسجدوں میں داخل ہوں مگر ڈرتے ڈرتے۔ ان لوگوں کے لئے دنیا میں ذلت و رسوائی اور آخرت میں بڑا عذاب ہے۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cxxii{اور مشرق و مغرب (پورب و پچھم) سب اللہ کے ہی ہیں سو تم جدھر بھی رخ کرو ادھر ہی اللہ کی ذات موجود ہے یقینا اللہ بڑی وسعت والا، بڑا علم والا ہے۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cxxiii{اور وہ (اہل کتاب) کہتے ہیں کہ اللہ نے کوئی بیٹا بنا لیا ہے۔ وہ (ایسی باتوں سے) پاک ہے۔ بلکہ جو کچھ آسمانوں اور زمین میں ہے وہ سب کچھ اسی کا ہے سب اسی کے مطیع و فرمانبردار ہیں۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cxxiv{(وہی) آسمانوں اور زمین کا موجد ہے۔ جب وہ کسی کام کے کرنے کا فیصلہ کر لیتا ہے۔ تو اسے بس اتنا ہی کہتا ہے کہ ہو جا اور وہ ہو جاتا ہے۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cxxv{جاہل و ناداں کہتے ہیں کہ اللہ ہم سے (براہ راست) کلام کیوں نہیں کرتا۔ یا ہمارے پاس (اس کی) کوئی نشانی کیوں نہیں آتی؟ جو لوگ ان سے پہلے گزر چکے ہیں وہ بھی اسی طرح کی (بے پرکی) باتیں کیا کرتے تھے ان سب کے دل (اور ذہن) ملتے جلتے ہیں۔ بے شک ہم نے یقین کرنے والے لوگوں کے لئے (اپنی نشانیاں) کھول کر بیان کر دی ہیں۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cxxvi{(اے رسول) بے شک ہم نے آپ کو برحق بشیر و نذیر (خوشخبری دینے والا اور ڈرانے والا) بنا کر بھیجا ہے۔ اور (اس اتمام حجت کے بعد) دوزخ میں جانے والوں کے بارے میں آپ سے بازپرس نہیں کی جائے گی۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cxxvii{اے رسول یہود و نصاریٰ اس وقت تک آپ سے راضی نہیں ہوں گے جب تک آپ ان کے دین و مذہب کے پیرو نہ ہو جائیں۔ کہہ دیجئے کہ اللہ کی ہدایت ہی حقیقی ہدایت ہے (جو اس نے بتائی ہے) اور اگر آپ نے (اللہ کی طرف سے) علم آجانے کے بعد بھی ان لوگوں کی خواہشات و خیالات کی پیروی کی۔ تو پھر اللہ (کی گرفت) سے آپ کو بچانے والا نہ کوئی سرپرست ہوگا اور نہ کوئی یار و مددگار\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cxxviii{جن لوگوں کو ہم نے کتاب دی ہے وہ اسے اس طرح پڑھتے ہیں جس طرح پڑھنے کا حق ہے وہی لوگ ہیں جو اس پر ایمان لاتے ہیں اور جو اس کا انکار کرتے ہیں تو یہی لوگ نقصان اٹھانے والے ہیں۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cxxix{اے بنی اسرائیل! میری وہ نعمت یاد کرو جس سے میں نے تمہیں نوازا۔ اور یہ بھی کہ تمہیں دنیا و جہان والوں پر فضیلت دی۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cxxx{اور (قیامت کے) اس دن سے ڈرو۔ جب کوئی کسی کو کوئی فائدہ نہیں پہنچا سکے گا اور نہ کسی سے فدیہ قبول کیا جائے گا۔ اور نہ ہی سفارش کسی کو کچھ فائدہ پہنچا سکے گی اور نہ ہی (کسی اور طریقہ سے) ان کی امداد کی جائے گی۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cxxxi{(اور وہ وقت یاد کرو) جب ابراہیم کا ان کے پروردگار نے چند باتوں کے ساتھ امتحان لیا۔ اور جب انہوں نے پوری کر دکھائیں ارشاد ہوا۔ میں تمہیں تمام انسانوں کا امام بنانے والا ہوں۔ انہوں نے کہا اور میری اولاد (میں سے بھی(؟ ارشاد ہوا: میرا عہدہ (امامت) ظالموں تک نہیں پہنچے گا۔\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cxxxii{اور (وہ وقت یاد کرو) جب ہم نے اس گھر (خانہ کعبہ) کو تمام لوگوں کے لئے مرکز اور مقام امن قرار دیا۔ اور (حکم دیا کہ) مقام ابراہیم (جہاں عبادت کے لئے کھڑے ہوئے تھے) کو (اپنی) نماز کی جگہ بناؤ اور ہم نے ابراہیم و اسماعیل کو وصیت کی (حکم دیا) کہ تم دونوں میرے (اس) گھر کو طواف کرنے والوں، اعتکاف کرنے والوں اور رکوع کرنے والوں کے لئے پاک و صاف رکھو۔\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cxxxiii{اور (وہ وقت یاد کرو) جب ابراہیم (ع) نے کہا (دعا کی) اے میرے پروردگار اس شہر (مکہ) کو امن والا شہر بنا۔ اور اس کے رہنے والوں میں سے جو اللہ اور آخرت کے دن پر ایمان لائیں انہیں ہر قسم کے پھلوں سے روزی عطا فرما۔ ارشاد ہوا: اور جو کفر اختیار کرے گا اس کو بھی چند روزہ (زندگی میں) فائدہ اٹھانے دوں گا۔ اور پھر اسے کشاں کشاں دوزخ کے عذاب کی طرف لے جاؤں گا۔ اور وہ کیسا برا ٹھکانا ہے۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cxxxiv{اور (وہ وقت بھی یاد کرو) جب ابراہیم اور اسماعیل اس گھر (خانہ کعبہ) کی بنیادیں بلند کر رہے تھے۔ (اور اس کے ساتھ ساتھ یہ دعا کرتے جاتے تھے) اے ہمارے پروردگار ہم سے (یہ عمل) قبول فرما۔ بے شک تو بڑا سننے والا اور بڑا جاننے والا ہے۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cxxxv{اے ہمارے پروردگار! ہمیں اپنا (حقیقی) مسلمان (فرمانبردار بندہ) بنائے رکھ۔ اور ہماری اولاد میں سے بھی ایک امت مسلمہ (فرمانبردار امت) قرار دے۔ اور ہمیں ہماری عبادت کے طریقے بتا۔ اور ہماری توبہ قبول فرما بے شک تو بڑا توبہ قبول کرنے والا بڑا مہربان ہے۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cxxxvi{اے ہمارے پروردگار ان (امت مسلمہ) میں انہی میں سے ایک ایسا پیغمبر بھیج جو انہیں تیری آیتیں پڑھ کر سنائے اور ان کو کتاب و حکمت کی تعلیم دے اور ان کے نفوس کو پاکیزہ بنائے یقینا تو بڑا زبردست اور بڑی حکمت والا ہے۔\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cxxxvii{اور کون ہے جو ابراہیم (ع) کی ملت (و مذہب) سے روگردانی کرے سوا اس کے جو اپنے کو احمق بنائے اور ہم نے انہیں دنیا میں منتخب کیا اور آخرت میں بھی ان کا شمار نیکوکاروں میں ہوگا۔\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cxxxviii{(یہ انتخاب اس وقت ہوا) جب ان کے پروردگار نے ان سے فرمایا: ’’مسلم‘‘ ہو جا (سر تسلیم جھکا کر فرمانبردار ہو جا)۔ تو انہوں نے کہا میں نے تمام جہانوں کے رب کے سامنے سر جھکا دیا۔\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cxxxix{اور ابراہیم (ع) نے اپنے بیٹوں کو اسی (ملت پر قائم رہنے) کی وصیت کی اور یعقوب (ع) نے بھی۔ اے میرے فرزند! بے شک اللہ نے تمہارے لئے ایک خاص دین (اسلام) منتخب کیا ہے سو تم ہرگز نہ مرنا مگر اس حالت میں کہ تم (حقیقی) مسلمان ہو۔\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cxl{(اے یہود) کیا تم اس وقت موجود تھے جب یعقوب (ع) کی موت کا وقت آیا؟ اس وقت انہوں نے اپنے بیٹوں سے کہا (پوچھا) کہ تم میرے بعد کس کی عبادت کروگے؟ انہوں نے کہا کہ ہم آپ کے اور آپ کے آباء (و اجداد) ابراہیم (ع)، اسماعیل (ع) اور اسحاق (ع)کے واحد و یکتا معبود کی عبادت کریں گے۔ اور ہم اسی کے مسلمان (فرمانبردار) ہیں۔\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cxli{یہ ایک جماعت تھی جو گزر گئی اس کے لئے وہ ہے جو اس نے کمایا اور تمہارے لئے وہ ہے جو تم کماؤگے اور وہ جو کچھ کرتے تھے اس کے بارے میں تم سے پوچھ گچھ نہیں ہوگی۔\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cxlii{اور وہ (یہود و نصاریٰ) کہتے ہیں کہ یہودی ہو جاؤ یا نصرانی تاکہ ہدایت پا جاؤ۔ (اے رسول(ص)) کہہ دیجئے کہ (نہیں) بلکہ ہم ابراہیم (ع) کی ملت پر ہیں جو نرے کھرے موحد تھے اور مشرکوں میں سے نہیں تھے۔\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cxliii{(مسلمانو) کہو ہم تو ایمان لائے ہیں اللہ پر۔ اور اس (قرآن) پر جو ہماری طرف نازل ہوا ہے اور اس پر جو ابراہیم (ع)، اسماعیل (ع)، اسحاق (ع)، یعقوب (ع) اور اسباط (ع) پر اتارا گیا اور ہم ان (سب کے برحق ہونے میں اور ان پر ایمان لانے) میں کسی کے درمیان تفریق نہیں کرتے اور ہم اس (اللہ) کے مسلمان (فرمانبردار) ہیں۔\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cxliv{تو اگر یہ لوگ (اہل کتاب) اسی طرح ایمان لے آئیں جس طرح تم لائے ہو تو ہدایت پا گئے اور اگر روگردانی کریں تو وہ بڑی مخالفت اور ہٹ دھرمی میں پڑ گئے ہیں سو ان کے مقابلہ میں اللہ تمہارے لئے کافی ہے اور وہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cxlv{ہم نے اللہ کا رنگ اختیار کیا ہے اور اللہ کے رنگ (دین اسلام) سے بہتر کس کا رنگ ہے اور ہم اسی کے عبادت گزار ہیں۔\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cxlvi{(اے رسول(ص)) کہہ دیجئے کہ کیا تم ہم سے اللہ کے بارے میں جھگڑتے ہو؟ حالانکہ وہی ہمارا بھی پروردگار ہے اور تمہارا بھی پروردگار ہے اور ہمارے اعمال ہمارے لئے ہیں اور تمہارے اعمال تمہارے لئے اور ہم تو اخلاص کے ساتھ اسی کی عبادت کرنے والے ہیں۔\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cxlvii{کیا تم یہ کہتے ہو کہ ابراہیم (ع)، اسماعیل (ع)، اسحاق (ع)، یعقوب (ع) اور اسباط (ع) یہودی تھے؟ آپ کہیئے کیا تم زیادہ جانتے ہو یا اللہ؟ اور اس شخص سے بڑا ظالم کون ہوگا جس کے پاس اللہ کی کوئی گواہی ہو جسے وہ چھپائے اور اللہ تمہارے اعمال سے غافل نہیں ہے۔\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cxlviii{یہ ایک جماعت تھی جو گزر گئی اس کے لئے وہ ہے جو اس نے کمایا اور تمہارے لئے وہ ہے جو تم کماؤگے اور جو کچھ وہ کرتے تھے اس کے بارے میں تم سے پوچھ گچھ نہیں کی جائے گی۔\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cxlix{عنقریب بے وقوف لوگ کہیں گے کہ ان (مسلمانوں) کو کس چیز نے روگردان کر دیا۔ اس قبلہ (بیت المقدس) سے، جس پر وہ پہلے تھے (اے پیغمبر(ص)) کہہ دیجئے اللہ ہی کے لیے ہے مشرق اور مغرب بھی۔ وہ جسے چاہتا ہے سیدھے راستہ کی طرف ہدایت کرتا ہے (اس پر لگا دیتا ہے)۔\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cl{(مسلمانو! جس طرح ہم نے تم کو صحیح قبلہ بتا دیا ہے) اسی طرح ہم نے تم کو ایک درمیانی (میانہ رو) امت بنایا ہے تاکہ تم عام لوگوں پر گواہ ہو اور پیغمبر(ص) تم پر گواہ ہو اور تم پہلے جس قبلہ پر تھے، ہم نے اسے صرف اسی لیے قبلہ بنایا تھا کہ ہم جان لیں کہ رسول(ص) کی پیروی کون کرتا ہے، اور کون پچھلے پاؤں پلٹ جاتا ہے۔ اگرچہ یہ (تحویل قبلہ) ان لوگوں کے سوا، جنہیں اللہ نے خاص ہدایت دی ہے اور سب پر بہت گراں تھی۔ اور اللہ ایسا نہیں ہے کہ تمہارے ایمان کو ضائع کر دے۔ بے شک اللہ لوگوں پر بڑی شفقت اور بڑا رحم کرنے والا ہے۔\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cli{(اے رسول(ص)) تحویل قبلہ کی خاطر) تیرا بار بار آسمان کی طرف منہ کرنا ہم دیکھ رہے ہیں۔ تو ضرور اب ہم تمہیں موڑ دیں گے اس قبلہ کی طرف جو تمہیں پسند ہے۔ بس اپنا رخ مسجد الحرام کی طرف موڑ دیجئے۔ اور (اے اہل ایمان) تم جہاں کہیں بھی ہو اپنے منہ (نماز پڑھتے وقت) اسی طرف کیا کرو۔ جن لوگوں کو (آسمانی) کتاب (تورات وغیرہ) دی گئی ہے وہ بخوبی جانتے ہیں کہ یہ (تحویل قبلہ کا فیصلہ) ان کے پروردگار کی طرف سے ہے اور یہ حق ہے۔ اور جو کچھ (یہ لوگ) کر رہے ہیں اللہ اس سے بے خبر نہیں ہے۔\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@clii{اور اگر آپ اہل کتاب کے سامنے سارے معجزے (دنیا جہان کے سارے دلائل) پیش کر دیں۔ تب بھی وہ آپ کے قبلہ کی پیروی نہیں کریں گے۔ اور نہ ہی آپ ان کے قبلہ کی پیروی کریں گے۔ اور وہ خود بھی ایک دوسرے کے قبلہ کو نہ مانتے ہیں اور نہ پیروی کرتے ہیں۔ اور اس علم کے بعد جو (منجانب اللہ) تمہارے پاس آچکا ہے اگر ان لوگوں کی خواہشات کی پیروی کروگے تو تمہارا شمار ظالموں (حد سے تجاوز کرنے والوں) میں ہو جائے گا۔\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cliii{جن لوگوں کو ہم نے کتاب (تورات وغیرہ) دی ہے وہ اس (رسول(ص)) کو اس طرح پہچانتے ہیں، جس طرح اپنی اولاد کو پہچانتے ہیں (مگر اس کے باوجود) ان کا ایک گروہ جان بوجھ کر حق کو چھپا رہا ہے۔\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cliv{(اے رسول(ص)! تحویل قبلہ وغیرہ) برحق ہے اور تمہارے پروردگار کی طرف سے ہے لہٰذا ہرگز شک و شبہ کرنے والوں یا جھگڑا کرنے والوں میں سے نہ ہونا۔\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@clv{اور ہر ایک کے لئے ایک سمت ہے جدھر وہ (نماز کے لیے) منہ کرتا ہے (اے مسلمانو! تم اس نزاع کو چھوڑ دو) پس تم بڑھ چڑھ کر نیکیوں کی طرف سبقت کرو۔ تم جہاں بھی ہوگے اللہ تم سب کو (جزا و سزا کے لئے ایک جگہ) لے آئے گا۔ بے شک اللہ ہر چیز پر قادر ہے۔\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@clvi{اور (اے پیغمبر(ص)) آپ جب بھی کہیں نکلیں تو (نماز کے وقت) اپنا رخ مسجد حرام کی طرف رکھیں۔ بے شک یہ (تبدیلی قبلہ) آپ کے پروردگار کی طرف سے حق ہے اور اللہ تمہارے کاموں سے غافل و بے خبر نہیں ہے۔\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@clvii{اور آپ جب بھی کہیں نکلیں تو (نماز کے وقت) اپنا منہ مسجد الحرام کی طرف ہی موڑیں اور (اے مسلمانو!) تم بھی جہاں کہیں ہو (نماز کے وقت) اپنے مونہوں کو اسی (مسجد الحرام) کی طرف ہی کر لیا کرو۔ (اس حکم کی بار بار تکرار سے ایک غرض یہ ہے کہ) تاکہ لوگوں (مخالفین) کو تمہارے خلاف کوئی دلیل نہ ملے۔ سوا ان لوگوں کے لیے جو ظالم ہیں (کہ ان کی زبان تو کسی طرح بھی بند نہیں ہو سکتی)۔ تو تم ان سے نہ ڈرو بلکہ مجھ سے ڈرو (دوسری غرض یہ ہے) کہ تم پر میری نعمت تام و تمام ہو جائے (اور تیسری غرض یہ ہے) کہ شاید تم ہدایت یافتہ ہو جاؤ ۔\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@clviii{(اے مسلمانو!) یہ تحویل قبلہ تم پر ایسا احسان ہے جس طرح ہم نے تمہارے درمیان تم ہی میں سے ایک پیغمبر بھیجا ہے۔ جو تمہیں ہماری آیات پڑھ کر سناتا ہے اور تمہیں (بدعقیدتی، بدعملی اور بداخلاقی کی نجاست و کثافت) سے پاک کرتا ہے اور تمہیں کتاب و حکمت کی تعلیم دیتا ہے۔ اور تمہیں وہ باتیں سکھاتا ہے جو تم نہیں جانتے تھے ۔\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@clix{پس تم مجھے یاد رکھو۔ میں تمہیں یاد رکھوں گا۔ اور میرا شکر ادا کرو۔ اور میری ناشکری نہ کرو۔\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@clx{اے ایمان والو! (مصیبت کے وقت) صبر اور نماز (کے ذریعے خدا) سے مدد لیا کرو۔ بے شک اللہ تعالیٰ صبر کرنے والوں کے ساتھ ہے۔\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@clxi{اور جو لوگ اللہ تعالیٰ کی راہ میں قتل کیے جاتے ہیں، انہیں مردہ نہ کہو بلکہ وہ زندہ ہیں۔ مگر تمہیں (ان کی زندگی کی حقیقت کا) شعور (سمجھ) نہیں ہے۔\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@clxii{اور ہم ضرور تمہیں آزمائیں گے خوف و خطر، اور کچھ بھوک (و پیاس) اور کچھ مالوں، جانوں اور پھلوں کے نقصان کے ساتھ (یعنی ان میں سے کسی نہ کسی چیز کے ساتھ)۔ (اے رسول(ص)) خوشخبری دے دو ان صبر کرنے والوں کو۔\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@clxiii{کہ جب بھی ان پر کوئی مصیبت آپڑے تو وہ کہتے ہیں بے شک ہم صرف اللہ ہی کے لیے ہیں۔ اور اسی کی طرف پلٹ کر جانے والے ہیں۔\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@clxiv{یہی وہ (خوش نصیب) ہیں، جن پر ان کے پروردگار کی طرف سے درود (خاص عنایتیں اور نوازشیں) ہیں اور رحمت و مہربانی ہے۔ اور یہی لوگ ہدایت یافتہ ہیں۔\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@clxv{بیشک صفا و مروہ نامی دو پہاڑیاں اللہ تعالیٰ کی نشانیوں میں سے ہیں۔ لہٰذا جو شخص خانہ کعبہ کا حج یا عمرہ بجا لائے، اس پر کوئی گناہ نہیں ہے کہ ان دونوں کے درمیان چکر لگائے اور جو شخص برضا و رغبت کچھ (مزید) نیکی کرے تو اللہ تعالیٰ (نیکی کا) قدر دان ہے اور خوب جاننے والا ہے۔\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@clxvi{بالتحقیق جو لوگ چھپاتے ہیں ہماری نازل کردہ روشن تعلیمات و ہدایت کو جبکہ ہم تمام لوگوں کے لئے انہیں کتاب میں واضح طور پر بیان کر چکے ہیں یہی وہ لوگ ہیں جن پر اللہ لعنت کرتا ہے اور تمام لعنت کرنے والے بھی لعنت کرتے ہیں۔\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@clxvii{مگر وہ جنہوں نے (حق پر پردہ ڈالنے سے) توبہ کی اور اپنی اصلاح کر لی۔ اور (حق بات کو) ظاہر کر دیا یہ وہ ہیں جن کی میں توبہ قبول کروں گا (انہیں معاف کر دوں گا) اور میں بڑا توبہ قبول کرنے والا اور رحم کرنے والا (مہربان) ہوں۔\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@clxviii{بلاشبہ جن لوگوں نے کفر اختیار کیا اور پھر اسی کفر کی حالت میں مر گئے۔ یہی وہ لوگ ہیں جن پر اللہ، فرشتوں اور تمام انسانوں کی لعنت ہے۔\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@clxix{وہ اس (لعنت) میں ہمیشہ ہمیشہ رہیں گے نہ تو ان کے عذاب میں کوئی کمی کی جائے گی۔ اور نہ ہی انہیں کوئی مہلت دی جائے گی۔\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@clxx{اور تمہارا خدا بس ایک ہی خدا ہے۔ اس کے سوا کوئی خدا نہیں ہے۔ وہ بڑا مہربان بہت رحم والا ہے۔\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@clxxi{بے شک آسمانوں اور زمینوں کی پیدائش میں اور رات دن کی آمد و رفت (الٹ پھیر) میں اور ان کشتیوں میں جو لوگوں کو نفع پہنچانے والی چیزیں لے کر سمندر میں چلتی ہیں اور (بارش کے) اس پانی میں جسے خدا نے آسمان (بلندی) سے برسایا اور پھر اس کے ذریعہ زمین کو اس کے بے جان (بے کار) ہو جانے کے بعد جاندار بنا دیا (سرسبز و شاداب بنا دیا) اور اس میں ہر قسم کے چلنے پھرنے والے (جانور) پھیلا دیئے۔ اور ہواؤں کی گردش (ہیر پھیر) میں اور ان بادلوں میں جو آسمان و زمین کے درمیان مسخر کرکے (تابع فرمان بنا کے) رکھے گئے ہیں۔ (ان سب باتوں میں) خدا کے وجود اور اس کی قدرت کی بڑی نشانیاں ہیں ان لوگوں کے لئے جو عقل و خرد سے کام لیتے ہیں۔\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@clxxii{(ان حقائق کے باوجود) کچھ لوگ ایسے بھی ہیں جو خدا کے سوا اوروں کو اس کا ہمسر قرار دیتے ہیں اور ان سے اس طرح محبت کرتے ہیں جس طرح خدا سے کرنی چاہیے۔ مگر جو صاحب ایمان ہیں وہ سب سے بڑھ کر خدا سے محبت کرتے ہیں اور کاش یہ ظالم (اس وقت) وہ حقیقت دیکھ لیتے (سمجھ لیتے) جو عذاب دیکھتے وقت سمجھیں گے کہ ساری قوت و طاقت بس اللہ کے لئے ہی ہے اور یہ کہ اللہ سخت عذاب کرنے والا ہے۔\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@clxxiii{اور (وہ مرحلہ کتنا کھٹن ہوگا) جب وہ (پیر) لوگ جن کی (دنیا میں) پیروی کی گئی اپنے پیرؤوں (مریدوں) سے برأت اور لاتعلقی ظاہر کریں گے اور خدا کا عذاب ان سب کی آنکھوں کے سامنے ہوگا اور سب وسائل اور تعلقات بالکل قطع ہو چکے ہوں گے۔\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@clxxiv{اور پیروی کرنے والے (مرید) کہتے ہوں گے کہ کاش! ہمیں ایک بار (دنیا میں) واپسی کا موقع مل جاتا تو ہم بھی بالکل اسی طرح ان سے بیزاری اور بے تعلقی ظاہر کرتے جس طرح انہوں نے آج ہم سے بیزاری اور لاتعلقی ظاہر کی ہے اسی طرح خدا ان کے (برے) کاموں کو حسرت و یاس کی شکل میں دکھائے گا اور وہ کبھی دوزخ سے باہر نہیں نکل سکیں گے۔\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@clxxv{اے انسانو! زمین میں جو حلال اور پاکیزہ چیزیں ہیں وہ کھاؤ۔ اور شیطان کے نقش قدم پر نہ چلو۔ بلاشبہ وہ تمہارا کھلم کھلا دشمن ہے۔\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@clxxvi{وہ تو تمہیں برائی و بے حیائی اور بدکاری کا حکم دیتا ہے اور (چاہتا ہے کہ) تم خدا کے خلاف ایسی باتیں منسوب کرو جن کا تمہیں علم نہیں ہے۔\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@clxxvii{اور جب ان (کفار و مشرکین) سے کہا جاتا ہے کہ جو کچھ خدا نے اتارا ہے اس کی پیروی کرو تو کہتے ہیں کہ ہم تو اس کی پیروی کریں گے جس پر ہم نے اپنے باپ، دادا کو پایا ہے اگرچہ ان کے باپ، دادا بے عقل ہوں اور راہ راست پر بھی نہ ہوں (تو پھر بھی انہی کی پیروی کریں گے)۔\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@clxxviii{اور جن لوگوں نے کفر اختیار کیا ان کی مثال دعوت حق دینے میں اس شخص (چرواہے) کی سی ہے جو ایسے (جانور) کو پکارنے میں اپنا گلہ پھاڑے (چیخ و پکار مچائے) جو چیخ و پکار کی آواز کے سوا کچھ سنتا ہی نہیں ہے۔ (یہ کافر) ایسے بہرے، گونگے اور اندھے ہیں کہ عقل سے کچھ کام ہی نہیں لیتے۔\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@clxxix{اے ایمان والو! جو پاک و پاکیزہ چیزیں ہم نے تمہیں دی ہیں ان میں سے کھاؤ۔ اور اللہ کا شکر کرو۔ اگر تم اس کی عبادت و پرستش کرتے ہو۔\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@clxxx{اس نے (چوپایوں میں سے) صرف تمہارے او پر مردار، خون، سور کا گوشت اور وہ (ذبیحہ) جسے اللہ کے سوا کسی اور کا نام لے کر ذبح کیا گیا ہو۔ حرام قرار دیا ہے۔ پس جو شخص (شدت گرسنگی سے) مجبور ہو جائے درآنحالیکہ وہ بغاوت یا سرکشی کرنے والا نہ ہو۔ تو اس پر کوئی گناہ نہیں ہے بے شک خدا بڑا بخشنے والا، بڑا مہربان ہے۔\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@clxxxi{بالتحقیق جو لوگ کتابِ خدا میں سے ان باتوں کو چھپاتے ہیں جو خدا نے نازل کی ہیں اور ان کے عوض تھوڑی سی قیمت وصول کرتے ہیں وہ اپنے پیٹوں میں آگ کے سوا کچھ بھی نہیں بھر رہے ہیں قیامت کے دن وہ توجہ ربانی سے اس قدر محروم ہوں گے کہ خدائے تعالیٰ ان سے بات تک نہیں کرے گا۔ اور نہ ہی انہیں (گناہوں کی کثافت سے) پاک کرے گا۔ اور ان کے لیے دردناک عذاب ہے۔\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@clxxxii{یہی وہ لوگ ہیں جنہوں نے ہدایت کے عوض گمراہی اور بخشش کے عوض عذاب کو خرید لیا۔ یہ کس قدر صبر کرنے والے ہیں دوزخ پر۔\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@clxxxiii{یہ (سب کچھ) اس لئے ہے کہ خدا نے حق اور سچائی کے ساتھ کتاب اتاری تھی مگر وہ لوگ جنہوں نے اس میں اختلاف کیا (طرح طرح کی باتیں کیں) بے شک وہ بڑی تفرقہ اندازی اور فتنہ پروری میں پڑ گئے ہیں (اور ضد میں بہت دور جا چکے ہیں)۔\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@clxxxiv{نیکی صرف یہی تو نہیں ہے کہ تم (نماز میں) اپنے منہ مشرق اور مغرب کی طرف پھیر لو۔ بلکہ (حقیقی) نیکی تو یہ ہے کہ آدمی خدا پر، روزِ آخرت پر، فرشتوں پر، (اللہ کی) کتابوں پر اور سب پیغمبروں پر ایمان لائے۔ اور اس (خدا) کی محبت میں اپنا مال (باوجودِ مال کی محبت کے) رشتہ داروں، یتیموں، مسکینوں، مسافروں، مانگنے والوں اور (غلاموں، کنیزوں اور مقروضوں کی) گردنیں چھڑانے میں صرف کرے، نماز قائم کرے، زکوٰۃ ادا کرے (دراصل) نیک لوگ تو وہ ہوتے ہیں کہ جب کوئی عہد کر لیں تو اپنا عہد و پیمان پورا کرتے ہیں اور تنگ دستی ہو یا بیماری اور تکلیف ہو یا ہنگام جنگ ہو وہ بہرحال ثابت قدم رہتے ہیں، یہی وہ لوگ ہیں جو (سچے) ہیں اور یہی متقی و پرہیزگار ہیں۔\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@clxxxv{اے ایمان والو! ان کے بارے میں جو (ناحق قتل کر دیئے گئے ہوں) تم پر قصاص (خون کا بدلہ خون) لکھ دیا گیا ہے یعنی آزاد کے بدلے آزاد، غلام کے بدلے غلام اور عورت کے بدلے عورت۔ ہاں جس (قاتل) کے لیے اس کے (ایمانی) بھائی (مقتول کے ولی) کی جانب سے کچھ (قصاص) معاف کر دیا جائے تو اس (معاف کرنے والے) کو (چاہیے کہ) نیکی کا اتباع کرے (خون بہا کا مطالبہ کرنے میں سختی نہ کرے) اور (جسے معاف کیا گیا ہے اسے بھی چاہیے کہ) خوش اسلوبی کے ساتھ (خون بہا) ادا کرے۔ یہ تمہارے پروردگار کی طرف سے رعایت و رحمت (اور آسانی و مہربانی) ہے۔ پس اس کے بعد بھی جو زیادتی کرے تو اس کیلئے دردناک عذاب ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@clxxxvi{اے صاحبانِ عقل! تمہارے لئے قصاص یعنی جان کے بدلے جان والے قانون میں زندگی ہے تاکہ تم (خون ریزی سے) بچتے رہو۔\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@clxxxvii{تم پر لکھ دیا گیا ہے کہ جب تم میں سے کسی کے سامنے موت آکھڑی ہو۔ بشرطیکہ وہ کچھ مال چھوڑے جا رہا ہو تو مناسب وصیت کر جائے اپنے ماں، باپ اور زیادہ قریبی رشتہ داروں کیلئے۔ یہ پرہیزگاروں کے ذمہ حق ہے (لازم ہے)۔\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@clxxxviii{جو شخص اس (وصیت) کو سننے کے بعد اس میں رد و بدل کرے تو اس کا گناہ انہی لوگوں پر ہوگا جو رد و بدل کریں گے۔ بے شک خدا خوب سننے والا اور خوب جاننے والا ہے۔\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@clxxxix{اب جو شخص کسی وصیت کرنے والے کی طرف سے کسی (وارث) کی حق تلفی یا گناہ کا خوف محسوس کرے اور ان (ورثہ) کے درمیان اصلاح (سمجھوتہ) کرا دے، تو اس پر (اس ردوبدل کرنے کا) کوئی گناہ نہیں ہے۔ بے شک اللہ بڑا بخشنے والا اور رحم کرنے والا ہے۔\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cxc{اے ایمان والو! روزہ اس طرح تم پر لکھ دیا گیا ہے (فرض کر دیا گیا ہے) جس طرح تم سے پہلے والوں پر لکھ دیا گیا تھا۔ تاکہ تم پرہیزگار بن جاؤ۔\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cxci{یہ گنتی کے چند دن ہیں (اس کے باوجود) اگر تم میں سے کوئی شخص بیمار ہو جائے یا سفر میں ہو۔ تو اتنے ہی دن اور دنوں میں پورے کرے۔ اور جو اپنی پوری طاقت صرف کرکے بمشکل روزہ رکھ سکتے ہوں تو وہ فی روزہ ایک مسکین کی خوراک فدیہ ادا کریں۔ اور جو اپنی مرضی سے کچھ (زیادہ) بھلائی کرے تو وہ اس کیلئے بہتر ہے اور اگر تم (فدیہ دینے کی بجائے) روزہ رکھو تو یہ تمہارے لئے زیادہ بہتر ہے۔ اگر تم علم و واقفیت رکھتے ہو۔\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cxcii{ماہ رمضان وہ (مقدس) مہینہ ہے جس میں قرآن نازل کیا گیا جو تمام انسانوں کے لئے ہدایت ہے اور اس میں راہنمائی اور حق و باطل میں امتیاز کی کھلی ہوئی نشانیاں ہیں جو اس (مہینہ) میں (وطن میں) حاضر ہو (یا جو اسے پائے) تو وہ روزے رکھے اور جو بیمار ہو یا سفر میں ہو تو اتنے ہی روزے کسی اور وقت میں (رکھے)۔ اللہ تمہاری آسانی و آسائش چاہتا ہے تمہاری تنگی و سختی نہیں چاہتا اور یہ بھی (چاہتا ہے) کہ تم (روزوں کی) تعداد مکمل کرو۔ اور اس (احسان) پر کہ اس نے تمہیں سیدھا راستہ دکھایا تم اس کی کبریائی و بڑائی کا اظہار کرو۔ تاکہ تم شکر گزار (بندے) بن جاؤ۔\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cxciii{اور جب میرے بندے آپ سے میرے بارے میں سوال کریں تو (آپ کہہ دیں) میں یقینا قریب ہوں جب کوئی پکارنے والا مجھے پکارتا ہے تو میں اس کی دعا و پکار کو سنتا ہوں اور جواب دیتا ہوں۔ تو ان پر لازم ہے کہ وہ میری آواز پر لبیک کہیں اور مجھ پر ایمان لائیں (یقین رکھیں) تاکہ وہ نیک راستہ پر آجائیں۔\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cxciv{(اے مسلمانو) روزوں کی رات تمہارے لئے اپنی عورتوں سے مباشرت کرنا حلال کر دیا گیا ہے۔ وہ (عورتیں) تمہارا لباس ہیں اور تم ان کا لباس ہو خدا جانتا ہے کہ تم اپنی ذات کے ساتھ خیانت کرتے رہے ہو تو اس نے تمہاری توبہ قبول کی اور تمہیں معاف کر دیا۔ پس اب تم ان سے (روزوں کی راتوں میں) مباشرت کرو۔ اور جو کچھ (اولاد) خدا نے تمہارے مقدر میں لکھ دی ہے اسے طلب کرو۔ اور (رات کو) کھاؤ پیؤ۔ یہاں تک کہ صبح کا سفید ڈورا (رات کی) سیاہ ڈوری سے الگ ہو کر ظاہر ہو جائے پھر رات تک روزہ کو پورا کرو۔ اور جب تم مسجدوں میں اعتکاف (قیام) کئے ہوئے ہو تو (رات کو بھی) بیویوں سے مباشرت نہ کرو۔ یہ اللہ تعالیٰ کی مقرر کی ہوئی حدیں ہیں ان کے قریب نہ جاؤ اس طرح خدا اپنی آیتوں (احکام) کو لوگوں کے لئے بیان کرتا ہے تاکہ وہ پرہیزگار بن جائیں۔\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cxcv{اور تم آپس میں ایک دوسرے کا مال غلط طریقہ سے نہ کھاؤ۔ اور نہ ہی (رشوت کے طور پر) وہ (مال) اس غرض سے حکام تک پہنچاؤ تاکہ گناہ کے طور پر لوگوں کا کچھ مال تم بھی خوردبرد کر جاؤ۔ درآنحالیکہ تم جانتے ہو۔\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cxcvi{(اے رسول(ص)) لوگ آپ سے نئے چاندوں کے بارے میں پوچھتے ہیں (کہ وہ گھٹے بڑھتے کیوں ہیں؟) کہہ دیجئے کہ یہ لوگوں کے (دنیوی معاملات) کی تاریخیں اور حج کے لئے اوقات مقرر کرنے کا ذریعہ ہیں اور یہ کوئی اچھی بات نہیں ہے کہ تم گھروں میں پچھواڑے کی طرف سے (پھاند کر) آؤ۔ بلکہ نیکی تو یہ ہے کہ (آدمی غلط کاری سے) پرہیزگاری اختیار کرے۔ اور گھروں میں ان کے دروازوں سے داخل ہوا کرو۔ اور خدا سے ڈرو (اس کے قہر و غضب سے بچو) تاکہ تم فلاح پاؤ۔\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cxcvii{اور تم اللہ کی راہ میں ان لوگوں سے لڑو جو تم سے لڑیں۔ اور زیادتی نہ کرو۔ کیونکہ یقینا اللہ زیادتی کرنے والوں کو ہرگز دوست نہیں رکھتا۔\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cxcviii{اور ان (خواہ مخواہ لڑنے والے کفار و مشرکین) کو جہاں کہیں پاؤ۔ قتل کر دو۔ اور انہیں نکال دو جہاں (مکہ) سے انہوں نے تمہیں نکالا ہے اور فتنہ پروری قتل سے بھی بڑھ کر (بُری) ہے۔ اور مسجد الحرام میں، ان سے اس وقت تک نہ لڑو۔ جب تک وہ اس میں تم سے نہ لڑیں۔ اور اگر وہ (اس میں) تم سے لڑیں تو تم بھی انہیں قتل کرو یہی کافروں کی سزا ہے۔\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cxcix{پھر اگر وہ لوگ باز آجائیں تو یقینا اللہ بڑا بخشنے والا اور بڑا رحم کرنے والا ہے۔\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cc{اور ان سے اس وقت تک جنگ جاری رکھو جب تک تمام فتنہ و فساد ختم نہ ہو جائے اور دین (و اطاعت) صرف اللہ کے لئے نہ رہ جائے ہاں اگر وہ جنگ سے باز آجائیں تو پھر ظلم و زیادتی کرنے والوں کے سوا کسی پر زیادتی نہیں کی جا سکتی۔\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cci{حرمت والے مہینہ کا بدلہ حرمت والا مہینہ ہے اور حرمتوں میں بھی قصاص (ادلا بدلا) ہے لہٰذا جو شخص تم پر زیادتی کرے تو تم بھی اس کے ساتھ اسی طرح زیادتی کرو جس طرح اس نے تم پر زیادتی کی ہے اور خدا (کی نافرمانی) سے ڈرو۔ اور سمجھ لو کہ اللہ یقینا پرہیزگاروں کے ساتھ ہے۔\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@ccii{اور خدا کی راہ میں (مال و جان) خرچ کرو اور (اپنے آپ) کو اپنے ہاتھوں ہلاکت میں نہ ڈالو اور اچھا کام کرو۔ یقینا اللہ اچھے کام کرنے والوں سے محبت کرتا ہے۔\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cciii{اور خدا کی (خوشنودی) کے واسطے حج و عمرہ کو تمام کرو۔ اور اگر کسی مجبوری میں گھر جاؤ تو پھر جو قربانی میسر ہو وہی کرو مگر اپنے سر اس وقت تک نہ منڈواؤ جب تک قربانی اپنے ٹھکانہ تک نہ پہنچ جائے (جہاں اسے ذبح یا نحر کرنا ہے) اور جب تم میں سے کوئی شخص بیمار ہو یا اس کے سر میں کوئی تکلیف ہو اور سر منڈوالے تو اس کا فدیہ (بدلہ) روزہ، خیرات یا قربانی ہے۔ پھر جب تمہیں امن و اطمینان حاصل ہو جائے تو جو شخص (حج تمتع کا) عمرہ کرکے حج کے موقع تک لذائذ سے فائدہ اٹھائے۔ تو وہ لازمی طور پر ممکنہ قربانی کرے۔ اور جسے قربانی نہ مل سکے تو وہ تین روزے تو حج کے دوران رکھے اور سات اس وقت جب واپس جائے۔ یہ ہو جائیں گے مکمل دس (روزے) یہ (حج تمتع) اس کے لئے ہے جس کے اہل و عیال مسجد الحرام کے باشندہ نہ ہوں۔ (حدود حرم کے اندر نہ رہتے ہوں) اور اللہ (کی نافرمانی) سے ڈرو اور سمجھ لو کہ خدا سخت سزا دینے والا ہے۔\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cciv{حج کے چند خاص جانے پہچانے مقررہ مہینے ہیں۔ تو جو شخص ان (مہینوں) میں (اپنے اوپر) حج کی پابندی احرام باندھ کر فرض کر لے تو پھر حج کے دوران نہ (بیوی سے) مباشرت کرے۔ نہ (خدا کی) نافرمانی کرے اور نہ (کسی سے) لڑائی جھگڑا کرے اور تم جو کچھ نیکی کا کام کروگے تو خدا اسے جانتا ہے اور (آخرت کے سفر کے لئے) زادِ راہ مہیا کرو (اور سمجھ لو) کہ بہترین زادِ راہ تقویٰ (پرہیزگاری) ہے۔ اور اے عقل مندو! مجھ سے (میری نافرمانی سے) ڈرو۔\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@ccv{اس میں تمہارے لئے کوئی مضائقہ نہیں ہے کہ تم حج کے دوران اپنے پروردگار سے فضل (رزق) کے طلب گار رہو۔ ہاں تو جب عرفات سے روانہ ہو تو مشعر الحرام (مزدلفہ) کے پاس (اس کی حدود) میں اللہ کو یاد کرو اور یاد بھی اس طرح کرو جس طرح اس نے تمہیں ہدایت کی ہے اگرچہ اس سے پہلے تم گمراہوں میں سے تھے۔\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@ccvi{پھر جہاں سے اور لوگ چل کھڑے ہوں تم بھی چل کھڑے ہو اور خدا سے مغفرت و بخشش طلب کرو یقینا خدا بڑا بخشنے والا، بڑا مہربان ہے۔\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@ccvii{جب تم اپنے مناسک حج (اور اس کے اعمال و ارکان) کو بجا لا چکو۔ تو پھر اس طرح اللہ کو یاد کرو جس طرح اپنے باپ داداؤں کو یاد کرتے تھے بلکہ اس سے بھی بڑھ کر خدا کو یاد کرو اب لوگوں میں سے کچھ تو ایسے ہیں جو کہتے ہیں اے ہمارے پروردگار! ہمیں (جو کچھ دینا ہے) اسی دنیا ہی میں دے دے ایسے شخص کا آخرت میں کوئی حصہ نہیں ہے۔\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@ccviii{اور کچھ ایسے ہیں جو کہتے ہیں کہ ہمارے پروردگار ہمیں دنیا میں بھی بھلائی عطا کر اور آخرت میں بھی بھلائی عطا کر اور ہمیں دوزخ کی سزا سے بچا۔\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@ccix{یہ وہ لوگ ہیں جو کچھ انہوں نے کمایا ہے اس سے (دنیا و آخرت میں) ان کو حصہ ملے گا اور اللہ بہت جلد حساب بے باق کرنے والا ہے۔\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@ccx{اور گنتی کے چند دنوں میں خدا کو یاد کرو پس جو جلدی کرے گا اور (منٰی سے) دو ہی دن میں چلا جائے تو اس پر کوئی گناہ نہیں ہے۔ اور جو دیر کرے (تیسرے دن تک ٹھہرا رہے) اس پر بھی کوئی گناہ نہیں ہے مگر یہ (رعایت) اس کے لئے ہے جو (شکار سے) بچتا رہا ہو اور اللہ (کی نافرمانی سے) ڈرو اور یقین رکھو کہ تم اسی کے حضور اکھٹے کئے جاؤگے (پلٹ کر جاؤ گے)۔\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@ccxi{اور بعض لوگ (منافقین) ایسے بھی ہیں کہ جن کی (چکنی چپڑی) باتیں تمہیں زندگانی دنیا میں بہت اچھی لگتی ہیں اور وہ اپنی دلی حالت پر خدا کو گواہ بناتے ہیں حالانکہ وہ (تمہارے) بدترین دشمن ہیں۔\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@ccxii{اور جب آپ کے پاس سے منہ پھیرتے ہیں (یا برسر اقتدار آتے ہیں) تو زمین میں فساد برپا کرنے کے لیے دوڑتے پھرتے ہیں اور کھیتی اور نسل کو برباد کرتے ہیں جبکہ خدا فساد کو ہرگز پسند نہیں کرتا۔\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@ccxiii{اور جب ان سے کہا جاتا ہے کہ خدا (کی حکم عدولی) سے ڈرو تو ان کی (ظاہری) عزت اور غرورِ نفس ان کو گناہ پر ابھارتا اور اصرار کراتا ہے ایسے (بدبخت) لوگوں کے لیے دوزخ کافی ہے اور وہ بہت برا ٹھکانہ ہے۔\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@ccxiv{اور انسانوں میں سے کچھ ایسے (انسان) بھی ہیں جو خدا کی خوشنودی حاصل کرنے کی خاطر اپنی جان بیچ ڈالتے ہیں (خطرے میں ڈال دیتے ہیں) اور اللہ (ایسے جاں نثار) بندوں پر بڑا شفیق و مہربان ہے۔\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@ccxv{اے ایمان والو! تم سب کے سب امن و سلامتی (والے دین) میں مکمل طور پر داخل ہو جاؤ اور شیطان کے نقش قدم پر نہ چلو کیونکہ وہ تمہارا کھلا ہوا دشمن ہے۔\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@ccxvi{اور اگر روشن دلیلوں (واضح احکام) کے آجانے کے بعد بھی تم ڈگمگا گئے تو خوب جان لو کہ اللہ زبردست (سب پر غالب) اور بڑی حکمت والا ہے۔\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@ccxvii{کیا یہ لوگ اس بات کا انتظار کر رہے ہیں کہ خود اللہ اور فرشتے سفید بادلوں کے سایہ میں ان کے پاس آئیں اور ہر بات کا فیصلہ ہو جائے آخر سب امور کی بازگشت تو خدا ہی کی طرف ہے۔\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@ccxviii{(اے رسول) بنو اسرائیل سے پوچھو کہ ہم نے ان کو انبیاء کے ذریعے کس قدر کھلی ہوئی نشانیاں عنایت کیں اور جو (شخص و قوم) خدا کی نعمت کو اس کے پاس آجانے کے بعد بدل ڈالے (اسے برائی میں صرف کرے) تو خدا سخت عذاب والا ہے۔\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@ccxix{جن لوگوں نے کفر اختیار کیا ان کے لئے زندگانی دنیا بڑی آراستہ کر دی گئی ہے۔ اور وہ ایمان والوں کا مذاق اڑاتے ہیں۔ حالانکہ جنہوں نے پرہیزگاری اختیار کی وہ قیامت کے دن ان لوگوں (کافروں) سے بہت بلند مقام پر ہوں گے اور خدا جسے چاہتا ہے بے حساب روزی عطا کرتا ہے۔\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@ccxx{(پہلے) سب انسان ایک ہی دین (فطرت) پر تھے، (پھر جب ان میں باہمی اختلاف پیدا ہوئے) تو خدا نے انبیاء بھیجے۔ (جو نیکوکاروں کو) خوشخبری دینے والے (اور بدکاروں) کو ڈرانے والے تھے اور ان کے ساتھ برحق کتاب نازل کی (جس میں قانون تھا)۔ تاکہ لوگوں کے اختلاف کا فیصلہ کرے اور یہ اختلاف انہی لوگوں نے کیا جن کو وہ (کتاب) دی گئی تھی اور وہ بھی تب کہ جب کھلی ہوئی دلیلیں ان کے سامنے آچکی تھیں۔ محض بغاوت اور زیادتی کی بنا پر۔ تو خدا نے اپنے حکم سے ایمان والوں کو ان اختلافی باتوں میں راہِ حق کی طرف راہنمائی فرمائی۔ اور خدا جسے چاہتا ہے سیدھے راستے کی طرف راہنمائی فرماتا ہے۔\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@ccxxi{کیا تمہارا یہ خیال ہے کہ تم یوں ہی جنت میں داخل ہو جاؤگے حالانکہ ابھی تک تمہارے سامنے تم سے پہلے گزرے ہوئے (اہل ایمان) کی سی صورتیں (اور شکلیں) آئی ہی نہیں۔ جنہیں فقر و فاقہ اور سختیوں نے گھیر لیا تھا۔ اور انہیں (تکلیف و مصائب کے) اس قدر جھٹکے دیئے گئے کہ خود رسول اور ان پر ایمان لانے والے کہہ اٹھے کہ آخر اللہ کی مدد کب آئے گی؟ آگاہ ہو جاؤ کہ اللہ کی مدد یقینا نزدیک ہی ہے۔\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@ccxxii{لوگ آپ سے دریافت کرتے ہیں کہ وہ (راہِ خدا میں) کیا خرچ کریں؟ کہہ دیجیے! کہ تم جو مال بھی صرف کرو (اس میں تمہارے) ماں باپ کے رشتہ داروں، یتیموں، مسکینوں اور مسافروں کا حق ہے اور تم جو بھی نیک کام کرو اللہ اسے خوب جانتا ہے۔\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@ccxxiii{(اے مسلمانو!) تم پر جنگ کرنا فرض کیا گیا ہے جب کہ وہ تمہیں ناگوار ہے۔ اور یہ ممکن ہے کہ جس چیز کو تم ناپسند کرتے ہو وہ تمہارے لئے اچھی ہو۔ اور یہ بھی ممکن ہے کہ جس چیز کو تم پسند کرتے ہو وہ تمہارے لئے بری ہو (اچھی نہ ہو) اصل بات یہ ہے کہ اللہ بہتر جانتا ہے تم نہیں جانتے۔\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@ccxxiv{(مشرک) لوگ آپ سے حرمت والے مہینے میں جنگ کرنے کے متعلق سوال کرتے ہیں۔ کہہ دیجیے اس میں جنگ کرنا بڑا جرم ہے (مگر) خدا کی راہ سے روکنا، اور اس کا انکار کرنا اور مسجد (کی حرمت) کا انکار کرنا (اور لوگوں کو اس سے روکنا) اور اس کے باشندوں کو وہاں سے نکالنا۔ خدا کے نزدیک اس (جنگ) سے بھی بڑا جرم ہے۔ اور فتنہ گری قتل سے بھی زیادہ سنگین گناہ ہے۔ اور وہ لوگ برابر تم سے لڑتے رہیں گے یہاں تک کہ اگر ان کا بس چلے تو وہ تمہیں تمہارے دین سے ہی پلٹا دیں۔ (مگر یاد رکھو) کہ تم میں سے جو بھی اپنے دین سے پھر کر کفر کی حالت میں مرے گا۔ تو یہ وہ بدنصیب لوگ ہیں جن کے اعمال دنیا و آخرت میں رائیگاں ہو جائیں گے۔ یہی لوگ دوزخی ہیں جو ہمیشہ ہمیشہ اس میں رہیں گے۔\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@ccxxv{بے شک جو لوگ ایمان لائے اور جنہوں نے ہجرت کی اور خدا کی راہ میں جہاد کیا یہ ہیں وہ لوگ جو خدا کی رحمت کے امیدوار ہیں اور خدا بڑا بخشنے والا مہربان ہے۔\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@ccxxvi{لوگ آپ سے شراب اور جوئے کے متعلق دریافت کرتے ہیں۔ کہہ دیجئے کہ ان میں بڑا گناہ ہے۔ اگرچہ ان میں لوگوں کے لئے کچھ فائدے بھی ہیں مگر ان کا گناہ ان کے فائدے سے بہت بڑا ہے اور لوگ آپ سے پوچھتے ہیں کہ (راہِ خدا میں) کیا خرچ کریں؟ کہہ دیجیے جو کچھ (تمہاری ضروریات سے) زیادہ ہو! اس طرح خدا تمہارے لئے اپنی آیات و ہدایات واضح کرتا ہے۔ تاکہ تم دنیا و آخرت کے بارے میں غور و فکر کرو۔\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@ccxxvii{اور لوگ آپ سے یتیموں کے متعلق پوچھتے ہیں۔ تو کہہ دیجیے کہ ان کی ہر طرح اصلاح (احوال کرنا) بہتر ہے۔ اور اگر تم ان سے مل جل کر رہو (تو اس میں کوئی مضائقہ نہیں آخر) وہ تمہارے بھائی ہی تو ہیں۔ اور اللہ بہتر جانتا ہے کہ مفسد (خرابی کرنے والا) اور اصلاح کرنے والا کون ہے اور اگر خدا چاہتا تو تمہیں مشکل و مشقت میں ڈال دیتا یقینا خدا زبردست ہے اور بڑی حکمت والا ہے۔\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@ccxxviii{(اے مسلمانو!) خبردار مشرک عورتوں سے اس وقت تک نکاح نہ کرو۔ جب تک وہ ایمان نہ لے آئیں۔ (کیونکہ) ایک مؤمنہ کنیز مشرکہ (آزاد عورت) سے اچھی ہے اگرچہ (حسن و جمال میں) تمہیں کتنی ہی بھلی معلوم ہو۔ اور مشرک مردوں کے نکاح میں اس وقت تک نہ دو جب تک وہ ایمان نہ لے آئیں۔ بے شک مسلمان غلام مشرک (آزاد شوہر) سے بہتر ہے۔ اگرچہ وہ (مشرک) تمہیں کتنا ہی بھلا معلوم ہو۔ یہ لوگ تمہیں آگ کی طرف بلاتے ہیں اور خدا اپنے حکم سے (تمہیں) جنت اور مغفرت (بخشش) کی طرف بلاتا ہے۔ اور اپنے احکام کو لوگوں کے سامنے واضح طور پر بیان کرتا ہے تاکہ وہ نصیحت قبول کریں (اثر لیں)۔\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@ccxxix{اور لوگ آپ سے حیض کے بارے میں دریافت کرتے ہیں۔ کہہ دیجیے کہ وہ گندگی ہے، لہٰذا تم ایامِ حیض میں عورتوں سے الگ رہو اور جب تک وہ پاک نہ ہو جائیں اس وقت تک ان کے نزدیک نہ جاؤ۔ پھر جب وہ طہارت کر لیں تو جدھر سے خدا نے حکم دیا ہے ان کے پاس جاؤ۔ بے شک اللہ دوست رکھتا ہے توبہ کرنے والوں کو اور طہارت کرنے والوں کو۔\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@ccxxx{تمہاری عورتیں کھیتی ہیں۔ (اس لئے) اپنی کھیتی میں جس طرح چاہو آؤ۔ اور اپنے لئے (خدا کی بارگاہ میں) پیشگی (اعمال) بھیج دو۔ اور اللہ اور ایمان والوں کو خوشخبری (مبارکباد) دے دو۔\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@ccxxxi{اور اللہ کو اپنی قسموں کا نشانہ نہ بناؤ تاکہ تم نیکوکار، پرہیزگار بن سکو۔ اور لوگوں میں صلح کرا سکو اور اللہ سننے والا اور سب کچھ جاننے والا ہے۔\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@ccxxxii{خدا تمہاری لایعنی (غیر ارادی) قسموں پر تم سے مواخذہ نہیں کرے گا۔ لیکن جو قسمیں تم دل سے کروگے (کھاؤ گے) اس کا مواخذہ کرے گا اور خدا بڑا بخشنے والا اور بڑا برداشت کرنے والا ہے۔\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@ccxxxiii{جو لوگ اپنی بیویوں سے الگ رہنے (مباشرت نہ کرنے) کی قسم کھا لیتے ہیں (ان کے لیے) چار مہینے کی مہلت ہے۔ پس اگر اس کے بعد (اپنی قسم سے) رجوع کریں تو بے شک خدا بخشنے والا، بڑا مہربان ہے۔\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@ccxxxiv{اور وہ اگر طلاق دینے کا ہی عزم بالجزم کر لیں تو بے شک خدا (سب کچھ) سننے اور جاننے والا ہے۔\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@ccxxxv{اور جن عورتوں کو طلاق دی جائے تو وہ اپنے آپ کو (عقد ثانی) سے روکیں۔ تین مرتبہ ایام ماہواری سے پاک ہونے تک۔ اور اگر وہ خدا اور روزِ جزاء پر ایمان رکھتی ہیں تو ان کے لئے یہ جائز نہیں ہے کہ اسے چھپائیں۔ جوکہ خدا نے ان کے رحموں (شکموں) میں پیدا کیا ہے۔ اور اس دوران ان کے شوہر اگر تعلقات بحال کرنا چاہیں تو وہ انہیں واپس بلانے (اور اپنی زوجیت میں رکھنے کے) زیادہ حقدار ہیں اور اس دوران دستورِ شریعت کے مطابق عورتوں کے کچھ حقوق ہیں جس طرح کہ مردوں کے حقوق ہیں ہاں البتہ مردوں کو ان پر ایک درجہ فوقیت ہے۔ خدا زبردست (حاکم) اور حکمت والا ہے۔\qt@no{(228)}}%
\qt@newcmd\qurantrans@ur@ccxxxvi{اور طلاق (رجعی) دو ہی مرتبہ ہے اس کے بعد یا تو اچھے طریقہ سے روک لیا جائے گا یا بھلائی کے ساتھ رخصت کر دیا جائے گا۔ اور تمہارے لئے جائز نہیں ہے کہ جو کچھ انہیں (بطورِ زر مہر اور ہدیہ و تحفہ) دے چکے ہو اس میں سے کچھ واپس لو مگر یہ کہ ان دونوں (میاں بیوی) کو اندیشہ ہو کہ وہ خدا کی قائم کردہ حدود کو قائم نہیں رکھ سکیں گے تو پھر (اے مسلمانو!) تمہیں بھی یہ خوف ہو کہ وہ حدودِ الٰہیہ کو قائم نہیں رکھ سکیں گے تو (اس صورت میں) عورت کو (بطورِ فدیہ خلع) کچھ معاوضہ دینا چاہیے (اور دے کر اپنی جان چھڑانا چاہیے) تو اس میں دونوں پر کوئی گناہ نہیں ہے۔ یہ خدا کی مقرر کردہ حدیں ہیں ان سے آگے نہ بڑھو۔ اور جو لوگ خدا کی مقرر کی ہوئی حدوں سے آگے بڑھتے ہیں وہی لوگ ظالم ہیں۔\qt@no{(229)}}%
\qt@newcmd\qurantrans@ur@ccxxxvii{اب اگر (تیسری بار) طلاق (بائن) دے تو اس کے بعد (یہ عورت) اس مرد کے لئے اس وقت تک حلال نہ ہوگی جب تک کسی دوسرے شخص سے شادی نہ کرے۔ اب جب کہ وہ (دوسرا شوہر) اسے طلاق دے دے اور ان دونوں سابقہ میاں بیوی کا خیال ہو کہ وہ حدودِ الٰہیہ کو برقرار رکھ سکیں گے تو ان کے لئے کوئی گناہ نہیں ہے کہ وہ آپس میں (دوبارہ) شادی کر لیں۔ یہ خدا کی مقرر کردہ حدیں ہیں جنہیں وہ صاحبانِ علم کے لئے واضح طور پر بیان کرتا ہے۔\qt@no{(230)}}%
\qt@newcmd\qurantrans@ur@ccxxxviii{اور جب تم عورتوں کو طلاق دو اور وہ اپنی میعاد (عدت کے خاتمہ) کے قریب پہنچ جائیں تو یا تو انہیں اچھے طریقے سے (اپنے پاس) رکھو۔ یا اچھے طریقے سے انہیں رخصت کر دو اور انہیں ضرر و زیاں پہنچانے اور زیادتی کرنے کیلئے نہ روکو اور جو ایسا کرے گا وہ اپنے نفس پر ظلم کرے گا۔ اور خدا کے آیات و احکام کا ہنسی مذاق نہ بناؤ اور خدا کے اس انعام و احسان کو یاد کرو جو اس نے تم پر کیا ہے اور جو اس نے کتاب و حکمت تم پر نازل کی ہے۔ اس کے ذریعہ سے تمہیں نصیحت کرتا ہے اور اللہ (کی نافرمانی) سے ڈرو اور خوب جان لو کہ خدا ہر شی کا جاننے والا ہے۔\qt@no{(231)}}%
\qt@newcmd\qurantrans@ur@ccxxxix{اور جب تم عورتوں کو طلاق دو اور جب وہ اپنی (عدّت کی) مدت پوری کر لیں تو انہیں اپنے شوہروں سے نکاح کرنے سے نہ روکو۔ جب کہ وہ مناسب طریقے پر (شریعت کے مطابق) ایک دوسرے (نئے یا پرانے) سے نکاح کرنے پر راضی ہو جائیں۔ اس (حکم) کے ذریعہ سے اس شخص کو نصیحت کی جاتی ہے (اور وہی اسے قبول کرے گا) جو خدا اور جزاء پر ایمان رکھتا ہے۔ یہ (ان احکام پر عمل کرنا)۔ تمہارے لئے زیادہ تزکیہ و طہارت کا باعث ہے اللہ بہتر جانتا ہے۔\qt@no{(232)}}%
\qt@newcmd\qurantrans@ur@ccxl{اور (طلاق کے بعد) جو شخص (اپنی اولاد کو) پوری مدت تک دودھ پلوانا چاہے تو مائیں اپنی اولاد کو کامل دو برس تک دودھ پلائیں گی۔ اور بچہ کے باپ پر (اس دوران) ان (ماؤں) کا کھانا اور کپڑا مناسب و معروف طریقہ پر لازم ہوگا۔ کسی بھی شخص کو اس کی وسعت و آسائش سے زیادہ تکلیف نہیں دی جا سکتی۔ نہ تو ماں کو نقصان پہنچایا جائے اس کے بچہ کی وجہ سے اور نہ ہی باپ کو زیاں پہنچایا جائے اس کے بچہ کے سبب سے اور (اگر باپ نہ ہو تو پھر) وارث پر (دودھ پلانے اور نان و نفقہ کی) یہی ذمہ داری ہے۔ اور اگر دونوں (ماں باپ اس مدت سے پہلے) باہمی مشورہ و رضامندی سے بچہ کا دودھ چھڑانا چاہیں تو ان پر کوئی گناہ نہیں ہے۔ اور اگر تم اپنی اولاد کو (کسی دایہ سے) دودھ پلوانا چاہو تو اس میں کوئی جرم نہیں ہے بشرطیکہ جو مناسب طریقہ سے دینا ٹھہرایا ہے (ان کے) حوالے کر دو۔ اور خدا (کی نافرمانی سے) ڈرو اور خوب جان لو کہ تم جو کچھ کرتے ہو۔ اللہ اسے خوب دیکھ رہا ہے۔\qt@no{(233)}}%
\qt@newcmd\qurantrans@ur@ccxli{اور تم میں سے جو لو گ بیویاں چھوڑ کر مر جائیں تو وہ (بیویاں) چار مہینے دس دن تک اپنے کو (عقد ثانی سے) روکیں۔ اور جب یہ مدت (عدت) پوری کر لیں تو وہ اپنے حق میں جو مناسب کام (فیصلہ) کریں اس میں تم پر کوئی گناہ نہیں ہے۔ اور تم جو کچھ کرتے ہو خدا اس سے خوب باخبر ہے۔\qt@no{(234)}}%
\qt@newcmd\qurantrans@ur@ccxlii{اگر تم (عدت کے دوران) عورتوں کی اشارہ و کنایہ میں خواستگاری کرو (پیغام نکاح دو) یا اسے اپنے دلوں میں چھپائے رکھو تو اس میں تم پر کچھ گناہ نہیں ہے۔ اللہ کو معلوم ہے کہ تم جلد ان کو یاد کروگے (تو بے شک کرو) مگر ان سے کوئی خفیہ قول و قرار نہ کرو۔ سوا اس کے کہ مناسب طریقہ سے کوئی بات کرو۔ (اشارہ و کنایہ سے) اور جب تک مقررہ مدت پوری نہ ہو جائے۔ اس وقت تک عقد نکاح کا ارادہ بھی نہ کرو۔ اور خوب جان لو کہ خدا تمہارے دلوں کے اندر کی بات کو بھی خوب جانتا ہے۔ لہٰذا اس سے ڈرتے رہو اور خوب جان لو کہ خدا بخشنے والا اور حلیم و بردبار ہے۔\qt@no{(235)}}%
\qt@newcmd\qurantrans@ur@ccxliii{اگر تم (اپنی) عورتوں کو ہاتھ لگانے (خلوت صحیحہ کرنے) اور حق مہر مقرر کرنے سے پہلے ہی طلاق دے دو تو اس میں تم پر کوئی گناہ نہیں ہے ہاں البتہ (بطور خرچہ) انہیں کچھ مال و متاع دے دو۔ مالدار اپنی حیثیت کے مطابق اور غریب و نادار اپنے مقدور کے موافق مناسب متاع (خرچہ) دے۔ یہ نیکوکار لوگوں کے ذمہ ایک حق ہے۔\qt@no{(236)}}%
\qt@newcmd\qurantrans@ur@ccxliv{اور اگر تم عورتوں کو ہاتھ لگانے سے پہلے طلاق دے دو۔ لیکن تم ان کا کچھ حق مہر معین کر چکے ہو۔ تو (اس صورت میں) اس مقررہ حق مہر کا آدھا لازم ہوگا۔ مگر یہ کہ وہ (عورتیں) خود معاف کر دیں یا وہ (ولی) معاف کر دے جس کے ہاتھ میں نکاح کا معاملہ ہے۔ اور اگر تم درگزر کرو (معاف کر دو) تو یہ پرہیزگاری کے زیادہ قریب ہے۔ اور باہمی معاملات میں احسان اور بھلائی کو نہ بھولو۔ بے شک تم جو کچھ کر رہے ہو خدا اسے خوب دیکھ رہا ہے۔\qt@no{(237)}}%
\qt@newcmd\qurantrans@ur@ccxlv{اور تم تمام نمازوں کی پابندی کرو۔ خصوصاً نماز وسطی کی اور خدا کے سامنے قنوت پڑھتے ہوئے (ادب و نیاز سے) کھڑے ہو۔\qt@no{(238)}}%
\qt@newcmd\qurantrans@ur@ccxlvi{اور اگر تم خوف (کی حالت) میں ہو تو پھر پیدل ہو یا سوار (جس طرح بھی ممکن ہو نمازپڑھ لو) پھر جب تمہیں امن و اطمینان ہو جائے تو خدا کو اس طرح یاد کرو جس طرح اس نے تمہیں سکھا دیا ہے جو تم نہیں جانتے تھے۔\qt@no{(239)}}%
\qt@newcmd\qurantrans@ur@ccxlvii{اور جو تم میں سے اپنی بیویاں چھوڑ کر دنیا سے جا رہے ہوں تو ان کو اپنی بیویوں کے حق میں وصیت کرنا چاہیے کہ ان کو سال بھر تک نان و نفقہ (خرچہ) دیا جاتا رہے اور گھر سے بھی نہ نکالا جائے۔ ہاں اگر وہ خود نکل جائیں تو اور بات ہے اور اپنے بارے میں جو مناسب فیصلہ کریں اس میں تم پر کوئی گناہ نہیں ہے اور خدا زبردست اور حکمت والا ہے۔\qt@no{(240)}}%
\qt@newcmd\qurantrans@ur@ccxlviii{اور جن عورتوں کو (مہر مقرر کئے اور صحبت کئے بغیر) طلاق دی گئی ہے۔ انہیں مناسب مال و متاع (خرچہ) دینا لازم ہے۔ یہ پرہیزگاروں کے ذمہ ایک حق ہے۔\qt@no{(241)}}%
\qt@newcmd\qurantrans@ur@ccxlix{اسی طرح خدا تمہارے لئے اپنے آیات و احکام واضح طور پر بیان کرتا ہے تاکہ تم سمجھ بوجھ سے کام لو۔\qt@no{(242)}}%
\qt@newcmd\qurantrans@ur@ccl{کیا تم نے ان لوگوں کو نہیں دیکھا جو موت کے ڈر سے ہزاروں کی تعداد میں اپنے گھروں سے نکل پڑے۔ خدا نے ان سے کہا: مر جاؤ (پس وہ سب کے سب مر گئے) پھر انہیں زندہ کیا۔ بے شک خدا لوگوں پر بڑا لطف و کرم کرنے والا ہے۔ لیکن اکثر لوگ شکر ادا نہیں کرتے۔\qt@no{(243)}}%
\qt@newcmd\qurantrans@ur@ccli{اور خدا کی راہ میں جنگ کرو اور خوب جانتے رہو کہ خدا (سب کچھ) سننے اور جاننے والا ہے۔\qt@no{(244)}}%
\qt@newcmd\qurantrans@ur@cclii{ہے کوئی ایسا جو خدا کو قرض حسنہ دے تاکہ خدا اسے کئی گُنا کرکے واپس کرے۔ خدا ہی تنگی کرتا ہے اور وہی کشادگی دیتا ہے۔ اور (تم سب) اسی کی طرف پلٹائے جاؤگے۔\qt@no{(245)}}%
\qt@newcmd\qurantrans@ur@ccliii{کیا تم نے جناب موسیٰ کے بعد بنی اسرائیل کے سرداروں کو نہیں دیکھا کہ جب انہوں نے نبی(ص) سے کہا کہ ہمارے لئے ایک بادشاہ مقرر کر دیجئے تاکہ ہم (اس کی زیر قیادت) راہِ خدا میں جنگ کریں۔ اس نبی نے فرمایا کہیں ایسا نہ ہو کہ جب جنگ تم پر واجب ہو جائے۔ تو پھر تم جنگ نہ کرو۔ انہوں نے کہا کہ ہم کیونکر جنگ نہیں کریں گے؟ جبکہ ہمیں اپنے گھروں اور بال بچوں سے باہر نکال دیا گیا ہے۔ مگر جب جنگ ان پر واجب قرار دی گئی تو ان کے تھوڑے سے آدمیوں کے سوا باقی سب کے سب منحرف ہوگئے (پیٹھ پھیر گئے) اور خدا ظالموں کو خوب جانتا ہے۔\qt@no{(246)}}%
\qt@newcmd\qurantrans@ur@ccliv{اور ان کے پیغمبر نے ان سے کہا کہ بے شک خدا نے تمہارے لئے طالوت کو بادشاہ مقرر کیا ہے۔ ان لوگو ں نے کہا، اس کو ہم پر کس طرح حکومت کرنے کا حق ہو سکتا ہے۔ اس سے تو ہم حکومت کرنے کے زیادہ حقدار ہیں اسے تو مالی وسعت ملی ہی نہیں ہے (کوئی بڑا مالدار آدمی نہیں ہے)۔ نبی نے جواب دیا کہ اللہ نے اسے اس لئے تم پر فضیلت اور ترجیح دی ہے کہ اسے علم اور جسمانی طاقت میں زیادتی عطا کی ہے اور اللہ جسے چاہتا ہے۔ اپنا ملک عطا کرتا ہے۔ (کیونکہ) اللہ بڑی وسعت والا اور بڑا علم والا ہے۔\qt@no{(247)}}%
\qt@newcmd\qurantrans@ur@cclv{اور ان کے نبی نے ان سے یہ بھی کہا کہ اس کے بادشاہ ہونے کی نشانی یہ ہے کہ تمہارے پاس وہ صندوق آجائے گا۔ جس میں تمہارے پروردگار کی جانب سے سکون کا سامان ہو گا اور موسیٰ (ع) و ہارون (ع) کے خاندان کے بچے کچھے تبرکات و متروکات بھی اور اسے فرشتے اٹھائے ہوئے ہوں گے اس میں بے شک تمہارے لئے (خدا کی قدرت کی) بڑی نشانی ہے۔ اگر تم ایماندار ہو۔\qt@no{(248)}}%
\qt@newcmd\qurantrans@ur@cclvi{اب جو طالوت فوجیں لے کر چلے تو (اپنے ہمراہیوں سے) کہا کہ خدا ایک نہر کے ساتھ تمہاری آزمائش کرنے والا ہے (دیکھو) جو شخص اس سے پانی پی لے گا اس کا مجھ سے کوئی واسطہ نہ ہوگا اور جو اسے چکھے گا بھی نہیں اس کا مجھ سے تعلق ہوگا۔ مگر یہ کہ اپنے ہاتھ سے ایک چُلو بھر لے۔ (انجام کار وقت آنے پر) تھوڑے لوگوں کے سوا باقی سب نے اس (نہر) سے پانی پی لیا۔ پس جب وہ اور ان کے ساتھ ایمان لانے والے آگے بڑھے (نہر پار کی) تو (پانی پینے والے) کہنے لگے کہ آج ہم میں جالوت اور اس کی افواج سے لڑنے کی طاقت نہیں ہے (مگر) جن لوگوں کو خدا کو منہ دکھانے کا یقین تھا کہنے لگے خدا کے حکم سے کئی چھوٹی جماعتیں بڑی جماعتوں پر غالب آجاتی ہیں اور خدا صبر کرنے والوں کے ساتھ ہے۔\qt@no{(249)}}%
\qt@newcmd\qurantrans@ur@cclvii{(غرضیکہ) یہ لوگ جالوت اور اس کی افواج کے مقابلہ کے لئے باہر نکلے۔ تو (یوں) دعا کی: اے پروردگار! ہم پر صبر انڈیل دے (بے پناہ صبر عطا کر) اور (میدانِ جنگ میں) ہمارے قدم جمائے رکھ اور کافروں کے مقابلہ میں ہماری مدد و نصرت فرما۔\qt@no{(250)}}%
\qt@newcmd\qurantrans@ur@cclviii{پس ان لوگوں نے خدا کے حکم سے ان لوگوں (دشمنوں) کو شکست دے دی۔ اور داؤد (ع) نے جالوت کو قتل کر دیا۔ اور خدا نے انہیں سلطنت و حکمت عطا فرمائی۔ اور جس جس چیز کا چاہا علم عطا فرمایا۔ اور اگر خدا ایک گروہ کا دوسرے گروہ کے ذریعہ سے دفاع نہ کرے تو زمین تباہ و برباد ہو جائے۔ مگر خدا تمام جہانوں پر بڑا لطف و کرم کرنے والا ہے۔\qt@no{(251)}}%
\qt@newcmd\qurantrans@ur@cclix{یہ آیاتِ الٰہیہ (قدرتِ خدا کی نشانیاں) ہیں جنہیں ہم سچائی کے ساتھ بیان کرتے ہیں اور بے شک و شبہ آپ رسولوں میں سے ہیں۔\qt@no{(252)}}%
\qt@newcmd\qurantrans@ur@cclx{یہ سب پیغمبر ہیں جن میں سے ہم نے بعض کو بعض پر فضیلت دی ہے۔ ان میں سے بعض وہ ہیں جن سے خدا نے کلام کیا اور ان میں سے بعض کے درجے بلند کئے۔ اور ہم نے عیسیٰ بن مریم کو کئی معجزے دیئے۔ اور روح القدس کے ذریعہ سے ان کی تائید کی اور اگر خدا (جبراً) چاہتا تو ان (پیغمبروں) کے بعد آنے والے لوگ اپنے پاس معجزے آجانے کے بعد آپس میں نہ لڑتے۔ لیکن انہوں نے آپس میں اختلاف کیا۔ پھر ان میں سے کچھ ایمان لائے اور بعض نے کفر اختیار کیا۔ اور اگر خدا (جبراً) چاہتا تو یہ لوگ آپس میں نہ لڑتے۔ مگر خدا جو چاہتا ہے وہی کرتا ہے۔\qt@no{(253)}}%
\qt@newcmd\qurantrans@ur@cclxi{اے ایمان والو! جو کچھ ہم نے تمہیں رزق دیا ہے اس میں سے کچھ (راہِ خدا میں) خرچ کرو۔ قبل اس کے کہ وہ دن (قیامت) آجائے کہ جس میں نہ سودے بازی ہوگی، نہ دوستی (کام آئے گی) اور نہ ہی سفارش۔ اور جو کافر ہیں وہی دراصل ظالم ہیں۔\qt@no{(254)}}%
\qt@newcmd\qurantrans@ur@cclxii{اللہ (ہی وہ ذات) ہے۔ جس کے علاوہ کوئی الٰہ نہیں ہے۔ زندہ (جاوید) ہے۔ جو (ساری کائنات کا) بندوبست کرنے والا ہے۔ اسے نہ اونگھ آتی ہے اور نہ نیند۔ جو کچھ آسمانوں اور جو کچھ زمین میں ہے وہ سب اسی کا ہے۔ کون ہے جو اس کی (پیشگی) اجازت کے بغیر اس کی بارگاہ میں (کسی کی) سفارش کرے؟ جو کچھ بندوں کے سامنے ہے وہ اسے بھی جانتا ہے۔ اور جو کچھ ان کے پیچھے ہے اسے بھی جانتا ہے۔ اور وہ (بندے) اس کے علم میں سے کسی چیز (ذرا) پر بھی احاطہ نہیں کر سکتے۔ مگر جس قدر وہ چاہے۔ اس کی کرسی (علم و اقتدار) آسمان و زمین کو گھیرے ہوئے ہے۔ ان دونوں (آسمان و زمین) کی نگہداشت اس پر گراں نہیں گزرتی وہ برتر ہے اور بڑی عظمت والا ہے۔\qt@no{(255)}}%
\qt@newcmd\qurantrans@ur@cclxiii{دین کے معاملہ میں کوئی زبردستی نہیں ہے۔ ہدایت گمراہی سے الگ واضح ہو چکی ہے۔ اب جو شخص طاغوت (شیطان اور ہر باطل قوت) کا انکار کرے اور خدا پر ایمان لائے اس نے یقینا مضبوط رسی تھام لی ہے۔ جو کبھی ٹوٹنے والی نہیں ہے۔ اور خدا (سب کچھ) سننے والا اور خوب جاننے والا ہے۔\qt@no{(256)}}%
\qt@newcmd\qurantrans@ur@cclxiv{اللہ ان لوگوں کا سرپرست ہے جو ایمان لائے وہ انہیں (گمراہی کے) اندھیروں سے (ہدایت کی) روشنی کی طرف نکالتا ہے۔ اور جن لوگوں نے کفر اختیار کیا ان کے سرپرست طاغوت (شیطان اور باطل کی قوتیں) ہیں جو انہیں (ایمان کی) روشنی سے نکال کر (کفر کے) اندھیروں کی طرف لے جاتے ہیں۔ یہی دوزخی لوگ ہیں جو اس میں ہمیشہ ہمیشہ رہیں گے۔\qt@no{(257)}}%
\qt@newcmd\qurantrans@ur@cclxv{کیا تم نے اس شخص کو نہیں دیکھا (اس کے حال پر غور نہیں کیا) جس نے جناب ابراہیم سے ان کے پروردگار کے بارے میں صرف اس بنا پر بحث و تکرار کی تھی کہ خدا نے اسے سلطنت دے رکھی تھی۔ جب ابراہیم نے کہا تھا کہ میرا پروردگار وہ ہے جو جلاتا بھی ہے اور مارتا بھی ہے۔ اس (شخص) نے کہا میں بھی جلاتا اور مارتا ہوں (اس پر) ابراہیم نے کہا میرا خدا سورج کو مشرق سے نکالتا ہے تو اسے مغرب سے نکال۔ اس پر کافر مبہوت (ہکا بکا) ہوگیا۔ خدا ظالموں کو ہدایت نہیں کرتا (ان کو منزل مقصود تک نہیں پہنچاتا)۔\qt@no{(258)}}%
\qt@newcmd\qurantrans@ur@cclxvi{یا اسی طرح تم نے وہ آدمی نہیں دیکھا (اس کے حال پر غور نہیں کیا) جو ایک ایسے گاؤں سے گزرا جس کے در و دیوار کا ملبہ اس کی گری ہوئی چھتوں پر گر پڑا تھا۔ (اپنی چھتوں پر اوندھی گری پڑی تھی)۔ اس (آدمی) نے (یہ منظر دیکھ کر) کہا اللہ اس گاؤں (اس کے رہنے والوں) کو کیوں کر اس کی موت کے بعد زندہ کرے گا؟ اس پر اللہ نے اسے سو سال تک کے لئے موت دے دی۔ پھر اسے زندہ کیا۔ اور کہا (پوچھا) تم کتنی دیر اس طرح پڑے رہے ہو؟ کہا ایک دن یا دن کا کچھ حصہ! ۔ فرمایا بلکہ تم سو سال پڑے رہے ہو۔ ذرا اپنے کھانے پینے کی چیزوں کو دیکھو کہ ذرا بھی خراب نہیں ہوئی ہیں۔ (دوسری طرف) ذرا اپنے گدھے کو دیکھو (کہ کس طرح گل سڑ گیا ہے؟) یہ (سب کچھ) اس لئے کیا ہے کہ تمہیں لوگوں کے لئے (اپنی قدرت کی) نشانی بناؤں۔ اور (گدھے) کی سڑی گلی ہڈیوں کو ہم کس طرح انہیں (جوڑ جاڑ کر) کھڑا کرتے ہیں اور پھر کس طرح ان پر گوشت چڑھاتے ہیں۔ (اور اسے زندہ کرتے ہیں) جب اس (آدمی) پر یہ بات واضح ہوگئی۔ تو (بے ساختہ) کہا میں یقین سے جانتا ہوں کہ اللہ ہر شئی پر قادر ہے۔\qt@no{(259)}}%
\qt@newcmd\qurantrans@ur@cclxvii{(اے رسول(ص)) وہ واقعہ یاد کرو۔ جب ابراہیم (ع) نے کہا: اے پروردگار! مجھے دکھلا کہ تو مُردوں کو کیوں کر زندہ کرتا ہے؟ خدا نے فرمایا: کیا تمہارا (اس پر) ایمان نہیں ہے؟ کہا: کیوں نہیں؟ (ایمان تو ہے) مگر چاہتا ہوں کہ (آنکھوں سے دیکھوں) تاکہ (دل) کو اطمینان ہو جائے (اور اسے قرار آئے) فرمایا: چار پرندے لو۔ اور انہیں اپنے پاس اکٹھا کرو اور اپنے سے مانوس بناؤ۔ پھر (انہیں ٹکڑے ٹکڑے کرکے) ہر پہاڑ پر ایک ٹکڑا رکھ دو۔ پھر انہیں آواز دو۔ تو وہ دوڑتے ہوئے تمہارے پاس آئیں گے اور خوب جان لو کہ خدا زبردست اور حکمت والا ہے۔\qt@no{(260)}}%
\qt@newcmd\qurantrans@ur@cclxviii{جو لوگ خدا کی راہ میں اپنے مال خرچ کرتے ہیں ان کی مثال اس ایک دانے کے مثل ہے جس نے (اپنے بوئے جانے کے بعد) سات بالیاں اگائیں اور ہر بالی میں سو دانے ہیں اور خدا جس کے لئے چاہتا ہے اور بڑھا دیتا ہے (دونا کر دیتا ہے) خدا بڑی وسعت والا اور بڑا جاننے والا ہے۔\qt@no{(261)}}%
\qt@newcmd\qurantrans@ur@cclxix{جو لوگ راہِ خدا میں اپنے مال خرچ کرتے ہیں اور خرچ کرنے کے بعد نہ احسان جتاتے ہیں اور نہ ایذا پہنچاتے ہیں ان کا اجر و ثواب ان کے پروردگار کے یہاں ہے نہ انہیں کوئی خوف ہے اور نہ وہ غمگین ہوں گے۔\qt@no{(262)}}%
\qt@newcmd\qurantrans@ur@cclxx{(سائل کو) اچھائی سے جواب دینا اور بخش دینا۔ اس صدقہ و خیرات سے بہتر ہے۔ جس کے بعد (سائل کو) ایذا پہنچائی جائے۔ اور اللہ بے نیاز ہے اور بڑا بردبار ہے۔\qt@no{(263)}}%
\qt@newcmd\qurantrans@ur@cclxxi{اے ایمان والو! (سائل کو) احسان جتا کر اور ایذا پہنچا کر اپنے صدقہ و خیرات کو اس شخص کی طرح اکارت و برباد نہ کرو جو محض لوگوں کو دکھانے کیلئے اپنا مال خرچ کرتا ہے اور خدا اور روزِ آخرت پر ایمان نہیں رکھتا۔ اس کی (خیرات کی) مثال اس چکنی چٹان کی سی ہے۔ جس پر کچھ خاک پڑی ہوئی ہو اور اس پر بڑے دانے والی زور کی بارش برسے۔ اور (خاک کو بہا کر لے جائے) اور اس (چٹان) کو صاف چکنا چھوڑ جائے۔ اسی طرح یہ (ریاکار) لوگ جو کچھ (صدقہ و خیرات وغیرہ) کرتے ہیں اس سے کچھ بھی ان کے ہاتھ نہیں آئے گا اور خدا کافر لوگوں کو ہدایت نہیں کرتا (انہیں منزل مقصود تک نہیں پہنچاتا)۔\qt@no{(264)}}%
\qt@newcmd\qurantrans@ur@cclxxii{اور جو لوگ خدا کی خوشنودی کے لئے دل کے پورے ثبات و قرار کے ساتھ اپنے مال (راہِ خدا میں) خرچ کرتے ہیں ان کی مثال اس (ہرے بھرے اور گھنے) باغ کی مانند ہے جو کسی اونچی جگہ پر ہو۔ جس پر بڑی بڑی بوندوں والی زور کی بارش برسے اور وہ دوگنا پھل دے۔ اور اگر اس پر بڑے قطروں والا زور کا مینہ نہ برسے تو پھر ہلکی پھلکی بارش ہی کافی ہے۔ اور تم لوگ جو کچھ کرتے ہو خدا اسے دیکھ رہا ہے۔\qt@no{(265)}}%
\qt@newcmd\qurantrans@ur@cclxxiii{تم میں سے کوئی بھی یہ بات پسند کرے گا کہ اس کے پاس کھجوروں، انگوروں کا ہرا بھرا گھنا باغ ہو جس کے نیچے نہریں جاری ہوں اور اس کے لئے اس میں ہر قسم کے پھل اور میوے موجود ہوں اور اسے بڑھاپا گھیر لے۔ جبکہ اس کی (چھوٹی چھوٹی) کمزور و ناتواں اولاد ہو اور اچانک اس (باغ) کو ایک ایسا بگولہ اپنی لپیٹ میں لے لے جس میں آگ ہو جس سے وہ باغ جل کر رہ جائے۔ اس طرح خدا تمہارے لئے اپنے احکام کھول کر بیان کرتا ہے تاکہ تم غور و فکر کرو۔\qt@no{(266)}}%
\qt@newcmd\qurantrans@ur@cclxxiv{اے ایمان والو! اپنی کمائی میں سے پاک و پاکیزہ چیزوں سے اور ان چیزوں سے جو ہم نے زمین سے تمہارے لئے برآمد کی ہیں (خدا کی راہ میں) خرچ کرو۔ اور اس میں سے بری اور خراب چیز کے خیرات کرنے کا ارادہ بھی نہ کرو۔ جبکہ خود تم ایسی چیز کے لینے پر (خوشی سے) آمادہ نہیں ہو۔ مگر یہ کہ مروت کی وجہ سے چشم پوشی سے کام لو۔ اور خوب جان لو کہ خدا بے نیاز ہے اور حمد و ستائش کے قابل ہے۔\qt@no{(267)}}%
\qt@newcmd\qurantrans@ur@cclxxv{شیطان تمہیں مفلسی اور تنگدستی سے ڈراتا ہے۔ اور بے حیائی و غلط کاری کا تم کو حکم (ترغیب) دیتا ہے۔ اور اللہ تم سے اپنی بخشش اور اپنے فضل و کرم کا وعدہ کرتا ہے۔ خدا بڑی وسعت والا اور بڑا جاننے والا ہے۔\qt@no{(268)}}%
\qt@newcmd\qurantrans@ur@cclxxvi{جسے وہ چاہتا ہے حکمت و دانائی عطا فرماتا ہے اور جسے (منجانب اللہ) حکمت عطا ہوئی، بے شک اسے درحقیقت خیر کثیر (بڑی دولت) مل گئی۔ عقلمندوں کے سوا کوئی نصیحت قبول نہیں کرتا۔\qt@no{(269)}}%
\qt@newcmd\qurantrans@ur@cclxxvii{اور تم جو کچھ بھی خرچ کرتے ہو یا منت مانتے ہو تو یقینا اللہ اسے جانتا ہے اور ظالموں کا کوئی مددگار نہیں ہے۔\qt@no{(270)}}%
\qt@newcmd\qurantrans@ur@cclxxviii{اگر تم اپنی خیرات علانیہ طور پر دو تو بھی اچھا ہے اور اگر اسے پوشیدہ رکھو اور حاجتمندوں کو دو تو وہ تمہارے لئے زیادہ بہتر ہے اور تمہارے کچھ گناہوں اور برائیوں کا کفارہ ہو جائے گا (انہیں مٹا دے گا)۔ تم جو کچھ کرتے ہو اللہ اس سے پوری طرح باخبر ہے۔\qt@no{(271)}}%
\qt@newcmd\qurantrans@ur@cclxxix{(اے رسول!) ان لوگوں کو منزل مقصود تک پہنچانے کی آپ پر ذمہ داری نہیں ہے (تمہارا فرض صرف راستہ دکھانا ہے)۔ اللہ جسے چاہتا ہے منزل مقصود تک پہنچاتا ہے اور تم جو کچھ مال خرچ کرتے ہو۔ تو وہ تمہارے اپنے (فائدہ) کے لئے ہے اور تم جو بھی خرچ کرتے ہو وہ اللہ کی خوشنودی کے لئے کرتے ہو۔ اور تم جو مال و دولت خیرات میں دوگے۔ وہ پورا پورا تمہیں ادا کر دیا جائے گا اور تم پر ہرگز ظلم نہیں کیا جائے گا۔\qt@no{(272)}}%
\qt@newcmd\qurantrans@ur@cclxxx{(یہ خیرات) خاص طور پر ان حاجتمندوں کے لئے ہے جو اللہ کی راہ میں اس طرح گھر گئے ہیں کہ روئے زمین پر سفر نہیں کر سکتے، ناواقف انہیں خود داری برتنے اور رکھ رکھاؤ کی وجہ سے مالدار سمجھتا ہے۔ مگر تم انہیں ان کے چہروں سے پہچان سکتے ہو۔ وہ لوگوں سے لپٹ کر اور ان کے پیچھے پڑ کر سوال نہیں کرتے۔ اور تم جو کچھ مال و دولت (راہِ خدا میں) خرچ کروگے بے شک اللہ اسے جانتا ہے۔\qt@no{(273)}}%
\qt@newcmd\qurantrans@ur@cclxxxi{جو لوگ اپنے مال رات اور دن میں خفیہ و علانیہ (راہِ خدا میں) خرچ کرتے ہیں ان کا اجر و ثواب ان کے پروردگار کے پاس ہے۔ ان کے لئے نہ کوئی خوف ہے اور نہ وہ غمگین ہوں گے۔\qt@no{(274)}}%
\qt@newcmd\qurantrans@ur@cclxxxii{اور جو لوگ سود کھاتے ہیں وہ (قیامت کے دن) نہیں کھڑے ہوں گے مگر اس شخص کی طرح جسے شیطان نے اپنے آسیب سے مخبوط الحواس بنا دیا ہو۔ (جس سے وہ پہچانے جائیں گے کہ وہ سود خور ہیں)۔ یہ اس لئے ہے کہ وہ قائل ہیں کہ تجارت بھی تو سود کی مانند ہے۔ حالانکہ اللہ نے تجارت کو حلال اور سود کو حرام کیا ہے۔ پس جس شخص کے پاس اس کے پروردگار کی طرف سے نصیحت (فہمائش) آئی اور وہ (سودخوری سے) باز آگیا۔ تو جو پہلے ہو چکا وہ اس کا ہے اس کا معاملہ خدا کے حوالے ہے اور جو (ممانعت کے بعد) پھر ایسا کرے تو ایسے لوگ جہنمی ہیں جو ہمیشہ ہمیشہ اس میں رہیں گے۔\qt@no{(275)}}%
\qt@newcmd\qurantrans@ur@cclxxxiii{اللہ سود کو مٹاتا ہے اور خیر و خیرات کو بڑھاتا ہے اور جتنے ناشکرے اور گنہگار ہیں اللہ ان کو دوست نہیں رکھتا۔\qt@no{(276)}}%
\qt@newcmd\qurantrans@ur@cclxxxiv{بے شک جو لوگ ایمان لائے اور اچھے عمل کئے۔ اور نماز پڑھی اور زکوٰۃ ادا کی ان کا اجر و ثواب ان کے پروردگار کے پاس ہے۔ اور (قیامت کے دن) ان کے لئے نہ کوئی خوف ہوگا اور نہ وہ غمگین ہوں گے۔\qt@no{(277)}}%
\qt@newcmd\qurantrans@ur@cclxxxv{اے ایمان والو! خدا (کی نافرمانی) سے ڈرو۔ اور جو کچھ سود (لوگوں کے ذمے) باقی رہ گیا ہے۔ اسے چھوڑ دو اگر تم ایمان والے ہو۔\qt@no{(278)}}%
\qt@newcmd\qurantrans@ur@cclxxxvi{لیکن اگر تم نے ایسا نہ کیا تو پھر خدا اور اس کے رسول سے جنگ کرنے کے لئے تیار ہو جاؤ۔ اور اگر اب بھی تم توبہ کرلو۔ تو تمہارا اصل مال تمہارا ہوگا (جو تمہیں مل جائے گا)۔ نہ تم (زائد لے کر) کسی پر ظلم کروگے اور نہ (اصل مال خوردبرد کرکے) تم پر ظلم کیا جائے گا۔\qt@no{(279)}}%
\qt@newcmd\qurantrans@ur@cclxxxvii{اور اگر (مقروض) تنگ دست ہے تو اسے فراخ دستی تک مہلت دینا ہوگی۔ اور اگر (قرضہ معاف کرکے) خیرات کرو۔ تو یہ چیز تمہارے لئے بہتر ہے اگر تم جانتے ہو۔\qt@no{(280)}}%
\qt@newcmd\qurantrans@ur@cclxxxviii{اور اس دن (کی سزا اور رسوائی) سے ڈرو۔ جس دن اللہ کی طرف پلٹائے جاؤگے اور پھر جس شخص نے جو کچھ (نیکی یا بدی) کمائی ہوگی۔ وہ (اس کا بدلہ) اسے پورا پورا دیا جائے گا۔ اور (ان کی حق تلفی کرکے) ان پر ظلم نہیں کیا جائے گا۔\qt@no{(281)}}%
\qt@newcmd\qurantrans@ur@cclxxxix{اے ایمان والو! جب تم کسی مقررہ مدت تک آپس میں قرضہ کا لین دین کرو۔ تو اسے لکھ لیا کرو۔ اور چاہیے کہ کوئی لکھنے والا عدل و انصاف کے ساتھ تمہارے باہمی قول و قرار کو لکھے۔ اور جس طرح اللہ نے لکھنے والے کو (لکھنا پڑھنا) سکھایا ہے وہ لکھنے سے انکار نہ کرے (بلکہ) اسے چاہیے کہ لکھ دے۔ اور جس (مقروض) کے ذمہ (قرضہ کی ادائیگی) کا حق عائد ہوتا ہے اسے چاہیے کہ تحریر کا مضمون لکھوا دے اور اس (کاتب) کو چاہیے کہ اپنے پروردگار سے ڈرے اور اس میں کمی نہ کرے یااور اگر وہ شخص (مقروض) جس پر حق عائد ہو رہا ہے کم عقل ہو یا کمزور اور معذور ہو یا خود نہ لکھا سکتا ہو۔ تو پھر اس کا سرپرست (وکیل یا ولی) عدل و انصاف سے (تمسک کا مضمون) لکھوائے اور اپنے آدمیوں میں سے دو گواہوں کی گواہی کرالو۔ تاکہ اگر ان میں سے کوئی ایک بھولے تو دوسرا اسے یاد دلائے اور جب گواہوں کو (گواہی کے لئے) بلایا جائے تو وہ انکار نہ کریں۔ اور معاملہ چھوٹا ہو یا بڑا جس کی میعاد مقرر ہے۔ اس کے لکھنے میں سہل انگیزی نہ کرو۔ یہ (لکھا پڑھی) اللہ کے نزدیک زیادہ منصفانہ کاروائی ہے اور گواہی کے لئے تو زیادہ مضبوطی ہے۔ اور اس طرح زیادہ امکان ہے کہ تم شک و شبہ میں نہ پڑو۔ مگر جب نقدا نقد خرید و فروخت ہو کہ جو تم آپس میں ہاتھوں ہاتھ کرتے ہو تو اس صورت میں کوئی مضائقہ نہیں ہے کہ اسے نہ لکھو اور جب (اس طرح) خرید و فروخت کرو تو گواہ کر لیا کرو۔ اور (زبردستی کرکے) کاتب اور گواہ کو ضرر و زیاں نہ پہنچایا جائے اور اگر ایسا کروگے تو یہ تمہاری نافرمانی ہوگی (گناہ ہوگا) خدا (کی نافرمانی) سے ڈرو اللہ تمہیں (یہی) سکھاتا ہے اور اللہ ہر چیز کو خوب جانتا ہے۔\qt@no{(282)}}%
\qt@newcmd\qurantrans@ur@ccxc{اور اگر تم سفر میں ہو اور تمہیں کاتب نہ ملے تو رہن باقبضہ رکھ لو۔ اور اگر تم میں سے ایک کو دوسرے پر اعتبار ہو۔ تو جس پر اعتبار کیا گیا ہے۔ اسے چاہیے کہ اپنی امانت واپس کر دے اور اپنے پروردگار (کی مخالفت) سے ڈرے۔ اور گواہی کو نہ چھپاؤ۔ اور جو اسے چھپائے گا اس کا دل گنہگار ہوگا۔ اور تم جو کچھ کرتے ہو اللہ اس کو خوب جانتا ہے۔\qt@no{(283)}}%
\qt@newcmd\qurantrans@ur@ccxci{جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے (سب کچھ) خدا کا ہے۔ اور جو کچھ تمہارے دلوں میں ہے۔ خواہ تم اس کو ظاہر کرو یا اسے چھپاؤ۔ خدا سب کا تم سے محاسبہ کرے گا۔ اور پھر جسے چاہے گا۔ بخش دے گا اور جسے چاہے گا سزا دے گا۔ اللہ ہر چیز پر قادر ہے۔\qt@no{(284)}}%
\qt@newcmd\qurantrans@ur@ccxcii{رسول(ص) ان تمام باتوں پر ایمان رکھتا ہے جو ان کے پروردگار کی طرف سے ان پر اتاری گئی ہیں اور مؤمنین بھی (سب) خدا پر اس کے ملائکہ پر، اس کی کتابوں پر اور اس کے رسولوں پر ایمان رکھتے ہیں۔ (وہ کہتے ہیں کہ) ہم خدا کے رسولوں میں تفریق نہیں کرتے اور کہتے ہیں کہ ہم نے فرمانِ الٰہی سنا اور اس کی اطاعت کی! پروردگار ہمیں تیری مغفرت درکار ہے۔ اور تیری ہی طرف پلٹ کر آنا ہے۔\qt@no{(285)}}%
\qt@newcmd\qurantrans@ur@ccxciii{خدا کسی کو اس کی وسعت سے زیادہ تکلیف نہیں دیتا وہ جو (نیکی) کرے گا۔ اس کا نفع اس کو ہوگا اور وہ جو (برائی) کرے گا اس کا نقصان بھی اسی کو ہوگا۔ پروردگار! اگر ہم بھول جائیں یا چوک جائیں تو ہماری گرفت نہ کر۔ پروردگار! ہم پر ویسا بوجھ نہ ڈال جیسا ہم سے پہلے لوگوں پر ڈالا تھا۔ پروردگار! ہم پر وہ بار نہ ڈال جس کے اٹھانے کی ہم میں طاقت نہیں ہے۔ اور ہمیں (ہمارے قصور) معاف کر۔ اور ہمیں (ہمارے گناہ) بخش دے۔ اور ہم پر رحم فرما تو ہمارا مالک و سرپرست اعلیٰ ہے۔ کافروں کے مقابلہ میں تو ہی ہماری مدد فرما۔\qt@no{(286)}}%
\qt@newcmd\qurantrans@ur@ccxciv{\basmalahur الف۔ لام۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ccxcv{اللہ ہی (کی ذات) ہے جس کے علاوہ کوئی الٰہ نہیں ہے۔ زندہ (جاوید) ہے جو (ساری کائنات کا) بندوبست کرنے والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@ccxcvi{اسی نے آپ پر حق کے ساتھ وہ کتاب اتاری ہے جو اس سے پہلے موجود (آسمانی کتابوں) کی تصدیق کرتی ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@ccxcvii{اور اسی نے اس سے پہلے لوگوں کی ہدایت کے لئے تورات و انجیل نازل کی۔ اور (حق و باطل کا) فیصلہ کن کلام نازل کیا۔ بلاشبہ جو لوگ آیاتِ الٰہی کا انکار کرتے ہیں۔ ان کے لیے بڑا سخت عذاب ہے۔ خدا زبردست ہے (اور برائی کا) بدلہ لینے والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@ccxcviii{بے شک خدا پر کوئی چیز پوشیدہ نہیں ہے زمین میں اور نہ آسمان میں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@ccxcix{وہ (خدا) وہی ہے جو ماں کے پیٹ میں جس طرح چاہتا ہے، تمہاری صورتیں بناتا ہے۔ اس کے سوا کوئی الٰہ نہیں ہے۔ وہ زبردست اور بڑی حکمت والا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@ccc{وہ وہی ہے جس نے آپ پر ایسی کتاب نازل کی جس میں کچھ آیتیں تو محکم ہیں۔ جو کتاب کی اصل و بنیاد ہیں اور کچھ متشابہ ہیں اب جن لوگوں کے دلوں میں کجی (ٹیڑھ) ہے۔ تو وہ فتنہ برپا کرنے اور من مانی تاویلیں کرنے کی خاطر متشابہ آیتوں کے پیچھے پڑے رہتے ہیں۔ حالانکہ خدا اور ان لوگوں کے سوا جو علم میں مضبوط و پختہ کار ہیں اور کوئی ان کی تاویل (اصل معنی) کو نہیں جانتا۔ جو کہتے ہیں کہ ہم اس (کتاب) پر ایمان لائے ہیں یہ سب (آیتیں) ہمارے پروردگار کی طرف سے ہیں اور نصیحت کا اثر صرف عقل والے ہی لیتے ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@ccci{(جو دعا کرتے ہیں) اے ہمارے پروردگار! ہمیں سیدھے راستے پر لگانے کے بعد ہمارے دلوں کو ٹیڑھا نہ ہونے دے اور ہمیں اپنی جناب سے رحمت عطا فرما۔ یقینا تو بڑا عطا کرنے والا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cccii{اے ہمارے پروردگار! بے شک تو ایک دن سب لوگوں کو جمع کرنے والا ہے جس (کے آنے) میں کوئی شک نہیں ہے۔ بلاشبہ خدا کبھی وعدہ خلافی نہیں کرتا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@ccciii{بے شک جن لوگوں نے کفر اختیار کیا۔ اللہ کے یہاں ان کے مال اور اولاد ہرگز ان کو کوئی فائدہ نہیں پہنچا سکتے اور یہی لوگ جہنم کا ایندھن ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@ccciv{ان کا حال (معاملہ بھی وہی ہے) کہ جو فرعونی گروہ اور اس سے پہلے لوگوں کا تھا کہ انہوں نے ہماری نشانیوں کو جھٹلایا۔ تو اللہ نے ان کے گناہوں کی پاداش میں ان کو گرفت میں لے لیا اور اللہ سخت سزا دینے والا ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cccv{(اے رسول!) کافروں سے کہہ دو کہ عنقریب تم (اہل اسلام کے مقابلہ میں) مغلوب ہوگے اور جہنم کی طرف محشور ہوگے اور وہ کیا بری آرام گاہ ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cccvi{تمہارے لیے ان دو گروہوں (کے حالات) میں جن کی (میدانِ بدر میں) مڈبھیڑ ہوئی تھی (صداقت رسول(ص) کی) ایک بڑی نشانی (معجزہ) موجود ہے۔ ایک گروہ خدا کی راہ میں جنگ کر رہا تھا۔ اور دوسرا گروہ کافر تھا جن کو (مسلمان) اپنی آنکھوں سے دوگنا دیکھ رہے تھے اور اللہ اپنی مدد سے جس کی چاہتا ہے، تائید و تقویت کرتا ہے بے شک اس (واقعہ) میں بڑی عبرت و نصیحت ہے۔ نگاہ (عبرت رکھنے) والوں کے لیے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cccvii{لوگوں کے لیے خوش نما بنا دی گئی ہے عورتوں، بیٹوں اور ڈھیروں سونے و چاندی پر مشتمل مال کی محبت اور (عمدہ) گھوڑے، چوپائے اور کھیتی باڑی۔ یہ سب (چیزیں) دنیاوی زندگی کا اثاثہ اور متاع ہیں۔ جبکہ (آخرت کا) اچھا ٹھکانہ اور بہترین انجام خدا کے یہاں ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cccviii{(اے رسول(ص)) کہو۔ کیا میں تمہیں ان سب سے بہتر چیز بتاؤں؟ جن لوگوں نے پرہیزگاری اختیار کی ان کے لئے ان کے پروردگار کے یہاں ایسے بہشت ہیں جن کے نیچے نہریں جاری ہیں اور وہ ان میں ہمیشہ رہیں گے (ان کے علاوہ) پاک و پاکیزہ بیویاں ہیں اور (سب سے بڑی نعمت) خدا کی خوشنودی ہے۔ اور خدا (اپنے) بندوں کو خوب دیکھ رہا ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cccix{(ان متقیوں کی صفت یہ ہے کہ) کہتے ہیں (دعا کرتے ہیں) ہمارے پروردگار! بے شک ہم ایمان لائے ہیں تو ہمارے گناہوں کو بخش دے اور ہمیں آتش دوزخ کے عذاب سے بچا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cccx{یہ لوگ صبر کرنے والے ہیں (قول و فعل میں) سچ بولنے والے، اطاعت کرنے والے، راہِ خدا میں خیرات کرنے والے اور سحر کے وقت طلب مغفرت کرنے والے ہیں۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cccxi{خود اللہ، اس کے ملائکہ اور صاحبانِ علم گواہ ہیں کہ اس کے سوا کوئی خدا نہیں ہے اور وہ عدل و انصاف کے ساتھ قائم و برقرار ہے اس کے سوا کوئی خدا نہیں ہے جو زبردست، حکمت والا (دانا) ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cccxii{بے شک خدا کے نزدیک سچا دین صرف اسلام ہے اور اہل کتاب نے (دین حق میں) اختلاف نہیں کیا مگر اپنے پاس علم آجانے (اور اصل حقیقت معلوم ہو جانے) کے بعد۔ محض آپس کی شرارت و ضد اور ناحق کوشی کی بنا پر اور جو بھی آیاتِ الٰہیہ کا انکار کرے گا تو یقینا خدا بہت جلد حساب لینے والا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cccxiii{پس اگر یہ لوگ آپ سے خواہ مخواہ حجت بازی کریں۔ تو کہہ دو کہ میں نے اور میری پیروی کرنے والوں نے تو اپنا سر خدا کے سامنے جھکا دیا ہے (اپنے کو اس کے سپرد کر دیا ہے) اور اہل کتاب اور جو کسی کتاب کے پڑھنے والے نہیں ہیں سے کہو: کیا تم بھی اسلام لائے ہو؟ پس اگر انہوں نے اسلام کا اقرار کر لیا تو گویا ہدایت پا گئے اور اگر (اس سے) منہ موڑا تو آپ کا فرض تو صرف پہنچا دینا ہے (منوانا نہیں ہے)۔ اور اللہ (اپنے) بندوں کو خوب دیکھنے (اور پہچاننے والا ہے)۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cccxiv{جو لوگ اللہ کی آیات کا انکار کرتے ہیں اور پیغمبروں کو ناحق قتل کرتے ہیں اور ایسے لوگوں کو بھی قتل کرتے ہیں جو عدل و انصاف کا حکم دیتے ہیں انہیں دردناک عذاب کا مژدہ سناؤ۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cccxv{یہ وہ (بدنصیب) ہیں جن کے اعمال دنیا و آخرت میں اکارت و برباد ہوگئے۔ اور ان کے لئے کوئی مددگار نہیں ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cccxvi{کیا تم نے ان (علماءِ یہود) کو نہیں دیکھا جن کو کتاب (تورات کے علم) سے تھوڑا سا حصہ ملا ہے جب انہیں کتابِ خدا کی طرف بلایا جاتا ہے تاکہ وہ ان کے درمیان فیصلہ کرے اس پر ان کا ایک گروہ پیٹھ پھیر لیتا ہے۔ درآنحالیکہ وہ روگردانی کرنے والے ہوتے ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cccxvii{یہ (انداز) اس لئے ہے کہ وہ اس بات کے قائل ہیں کہ گنتی کے چند دنوں کے سوا ہمیں آتش جہنم چھوئے گی بھی نہیں۔ یہ لوگ جو افتراء پردازیاں کرتے رہتے ہیں۔ انہوں نے ان کو دین کے بارے میں دھوکہ دیا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cccxviii{اس وقت ان کی کیا حالت ہوگی جب ہم ان کو ایک دن (بروزِ قیامت) اکٹھا کریں گے جس (کے آنے) میں کوئی شک و شبہ نہیں ہے۔ اور ہر شخص کو جو کچھ اس نے کمایا ہوگا اس کا پورا پورا بدلہ دیا جائے گا۔ اور ان پر کوئی ظلم نہیں کیا جائے گا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cccxix{(اے رسول(ص)!) کہو: اے خدا تمام جہان کے مالک! تو جسے چاہتا ہے حکومت دیتا ہے اور جس سے چاہتا ہے حکومت چھین لیتا ہے۔ تو جسے چاہتا ہے عزت دیتا ہے اور جسے چاہتا ہے ذلیل کرتا ہے، ہر قسم کی بھلائی تیرے قبضہ میں ہے۔ بے شک تو ہر چیز پر قادر ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cccxx{تو ہی رات کو (بڑھا کر) دن میں اور دن کو (بڑھا کر) رات میں داخل کرتا ہے اور تو جاندار کو بے جان اور بے جان کو جاندار سے نکالتا ہے اور جسے چاہتا ہے، بے حساب روزی عطا کرتا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cccxxi{(خبردار) اہل ایمان، اہل ایمان کو چھوڑ کر کافروں کو دوست (اور سرپرست) نہ بنائیں۔ اور جو ایسا کرے گا۔ اس کا خدا سے کوئی تعلق اور سروکار نہیں ہوگا۔ مگر یہ کہ تمہیں ان (کافروں) سے خوف ہو تو پھر (بقصد تقیہ اور بچاؤ) ایسا کرنے میں کوئی حرج نہیں ہے۔ اور خدا تمہیں اپنی ذات سے ڈراتا ہے اور خدا ہی کی طرف پلٹ کر جانا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cccxxii{کہہ دیجئے! جو کچھ تمہارے سینوں میں ہے، تم اسے چھپاؤ یا اسے ظاہر کرو، بہرحال خدا اسے جانتا ہے۔ اور جو کچھ آسمانوں اور زمین میں ہے وہ سب کچھ جانتا ہے اور خدا ہر چیز پر قادر ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cccxxiii{اس دن کو یاد کرو جب ہر شخص اس بھلائی کو اپنے سامنے پائے گا جو اس نے کی ہوگی۔ اور برائی کو بھی (جنہیں دیکھ کر) خواہش کرے گا کہ کاش اس کے اور اس کے برے اعمال کے درمیان بڑا فاصلہ ہوتا۔ اور خدا تمہیں اپنی ذات (اپنے عذاب) سے ڈراتا ہے اور خدا اپنے بندوں پر بڑا مہربان ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cccxxiv{(اے رسول! میری محبت کے دعویداروں سے) کہہ دیں کہ اگر تم خدا سے (سچی) محبت رکھتے ہو تو میری پیروی کرو خدا بھی تم سے محبت کرے گا اور تمہارے گناہوں کو بخش دے گا اور اللہ بڑا بخشنے والا مہربان ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cccxxv{کہہ دیں خدا اور رسول(ص) کی اطاعت و فرماں برداری کرو اور اگر روگردانی کریں تو بے شک خدا کافروں (نافرمانوں) کو دوست نہیں رکھتا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cccxxvi{بے شک اللہ نے آدم، نو ح، خاندانِ ابراہیم اور خاندانِ عمران کو سارے جہانوں سے منتخب کیا ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cccxxvii{جو ایک نسل ہے جن کے بعض بعض سے ہیں (یہ اولاد ہے ایک دوسرے کی) اور خدا بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cccxxviii{(اس وقت کو یاد کرو) جب عمران کی بیوی نے کہا اے میرے پروردگار! جو بچہ میرے پیٹ میں ہے اسے میں (دنیا کے کاموں سے) آزاد کرکے (خانہ کعبہ کی) جاروب کشی اور تیری عبادت کے لئے تیری بارگاہ میں نذر کرتی ہوں تو میری (نذر) قبول فرما۔ بے شک تو بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cccxxix{پھر جب اس کے یہاں وہ (بچی) پیدا ہوئی۔ تو اس نے کہا: اے میرے پروردگار! میرے ہاں تو لڑکی پیدا ہوئی ہے (میں تو یہ لڑکی جنی ہوں) حالانکہ خدا خود خوب جانتا ہے کہ وہ کیا جنی ہے۔ اور وہ جانتا ہے کہ لڑکا، لڑکی یکساں نہیں ہوتے۔ اور میں نے اس کا نام مریم رکھا ہے اور میں اسے اور اس کی اولاد کو شیطان رجیم (کے شر) سے (بچنے کے لیے) تیری پناہ میں دیتی ہوں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cccxxx{تو اس کے پروردگار نے اس لڑکی (مریم) کو احسن طریقہ سے قبول فرما لیا۔ اور اچھی طرح اس کی نشوونما کا انتظام کیا (یعنی) جناب زکریا کو اس کا کفیل (اور سرپرست) بنایا۔ جب بھی زکریا محرابِ عبادت میں اس (مریم) کے پاس آتے تھے تو اس کے پاس کھانے کی کوئی چیز موجود پاتے۔ (اور) پوچھتے: اے مریم! یہ تمہارے پاس کہاں سے آیا ہے؟ وہ جواب دیتی۔ یہ خدا کے یہاں سے آیا ہے۔ بے شک خدا جسے چاہتا ہے اسے بے حساب رزق عطا فرماتا ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cccxxxi{اس موقع پر زکریا نے اپنے پروردگار سے دعا کی اور عرض کیا اے میرے پروردگار! مجھے اپنی طرف سے پاک و پاکیزہ اولاد عطا فرما۔ بے شک تو (ہر ایک کی) دعا کا سننے والا ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cccxxxii{تو فرشتوں نے انہیں اس حالت میں آواز دی جب کہ وہ محراب میں کھڑے ہوئے نماز پڑھ رہے تھے۔ کہ خدا آپ کو یحییٰ کی بشارت دیتا ہے جو اللہ کے ایک کلمہ (عیسیٰ) کی تصدیق کرنے والا ہوگا۔ سردار، ضبط نفس کرنے والا پارسا اور نیکوکار جماعت میں سے نبی ہوگا۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cccxxxiii{جناب زکریا نے (یہ خوشخبری سن کر) کہا: اے پروردگار! میرے یہاں لڑکا کس طرح ہوگا جبکہ میرا بڑھاپا آگیا۔ اور میری بیوی بانجھ ہے؟ ارشاد ہوا اسی طرح (خدا) جو چاہتا ہے وہ کرتا ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cccxxxiv{عرض کیا: اے میرے پروردگار! میرے (اطمینانِ قلب) کیلئے کوئی علامت مقرر فرما فرمایا: تمہاری علامت یہ ہے کہ تم تین دن رات تک لوگوں سے اشارہ کے سوا بات نہیں کر سکوگے۔ (شکرانۂ نعمت کے طور پر) اپنے پروردگار کا کثرت سے ذکر کرو۔ اور صبح و شام اسی کی تسبیح کرو۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cccxxxv{اور جب فرشتوں نے کہا اے مریم! بے شک اللہ نے تمہیں منتخب کر لیا ہے اور تمہیں پاک و پاکیزہ بنایا ہے۔ اور تمہیں تمام جہانوں کی عورتوں سے برگزیدہ بنا دیا ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cccxxxvi{اے مریم۔ اپنے پروردگار کی اطاعت کرو۔ اور سجدہ کرو۔ اور رکوع کرنے والوں کے ساتھ رکوع کرتی رہو۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cccxxxvii{(اے رسول(ص)) یہ (خبر) غیب کی خبروں میں سے ایک ہے جو وحی کے ذریعہ ہم آپ کی طرف بھیج رہے ہیں اور آپ ان (دعویداران سرپرستی) کے پاس موجود نہ تھے جب وہ (قرعہ اندازی کیلئے) اپنے قلم ڈال رہے تھے کہ مریم کی کفالت کون کرے؟ اور آپ ان کے پاس موجود نہ تھے جب وہ آپس میں جھگڑ رہے تھے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cccxxxviii{اور (وہ وقت یاد کرو) جب فرشتوں نے کہا اے مریم! بے شک خدا آپ کو اپنے کلمہ کی خوشخبری دیتا ہے۔ جس کا نام مسیح عیسیٰ بن مریم ہوگا۔ جو دنیا و آخرت میں عزت و آبرو والا ہوگا۔ اور (خدا کے) مقرب بندوں میں سے ہوگا۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@cccxxxix{اور وہ گہوارے میں بھی لوگوں سے باتیں کرے گا۔ اور ادھیڑ عمر میں بھی۔ اور نیکوکاروں میں سے ہوگا۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@cccxl{(یہ بشارت سن کر) مریم نے کہا: اے میرے پروردگار! میرے یہاں بچہ کہاں سے ہوگا۔ حالانکہ مجھے کسی انسان (مرد) نے ہاتھ تک نہیں لگایا؟ ارشاد ہوا: بات اسی طرح ہے مگر خدا جو چاہتا ہے (بلا اسباب بھی) پیدا کرتا ہے۔ جب وہ کسی کام کے کرنے کا فیصلہ کر لیتا ہے تو اسے حکم دیتا ہے کہ ہو جا تو بس وہ ہو جاتا ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@cccxli{اور خدا اس (بچہ) کو کتاب و حکمت اور توراۃ و انجیل کی تعلیم دے گا۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@cccxlii{اور اسے بنی اسرائیل کی طرف اپنا رسول بنائے گا۔ (اور جب وہ مبعوث ہوگا تو کہے گا کہ) میں تمہارے پاس تمہارے پروردگار کی طرف سے معجزہ لے کر آیا ہوں کہ میں تمہارے لئے مٹی سے پرندہ کی صورت بناتا ہوں اور اس میں پھونک مارتا ہوں تو وہ خدا کے حکم سے پرندہ بن جاتا ہے۔ اور میں خدا کے حکم سے مادر زاد اندھے اور کوڑھی کو شفا دیتا ہوں اور مردوں کو زندہ کرتا ہوں۔ اور جو کچھ تم کھاتے ہو۔ اور اپنے گھروں میں جمع کرتے ہو وہ تمہیں بتاتا ہوں بے شک اس میں تمہارے لئے (خدا کی قدرت اور میری نبوت کی) بڑی نشانی ہے اگر تم ایمان لانے والے ہو۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@cccxliii{اور جو مجھ سے پہلے (توراۃ) موجود ہے میں اس کی تصدیق کرتا ہوں اور (میرے آنے کا ایک مقصد یہ بھی ہے کہ) میں تمہارے لئے ان چیزوں میں سے بعض کو حلال کروں جو تم پر حرام تھیں۔ اور میں تمہارے پروردگار کی طرف سے اعجاز کے ساتھ تمہارے پاس آیا ہوں۔ لہٰذا اللہ (کی نافرمانی) سے ڈرو۔ اور میری اطاعت کرو۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@cccxliv{بے شک اللہ میرا اور تمہارا پروردگار ہے پس تم اس کی عبادت کرو۔ یہی سیدھا راستہ ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@cccxlv{پھر جب عیسیٰ نے ان (بنی اسرائیل) کی طرف سے کفر و انکار محسوس کیا۔ تو کہا کون ہے جو اللہ کی راہ میں میرا مددگار ہو؟ حواریوں نے کہا ہم اللہ کے مددگار ہیں۔ ہم اللہ پر ایمان لائے ہیں اور آپ گواہ رہیں کہ ہم مسلمان (فرمانبردار) ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@cccxlvi{اور کہا اے ہمارے پروردگار جو کچھ تو نے نازل کیا ہے ہم اس پر ایمان لائے ہیں اور ہم نے رسول (عیسیٰ) کی پیروی اختیار کی۔ لہٰذا ہمیں (حق کی) گواہی دینے والوں (کے دفتر) میں درج فرما۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@cccxlvii{انہوں (بنی اسرائیل) نے (عیسیٰ کے خلاف) مکاری کی اور اللہ نے بھی اپنی (جوابی) تدبیر و ترکیب کی۔ اور اللہ سب سے بہتر تدبیر و ترکیب کرنے والا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@cccxlviii{(اس وقت کو یاد کرو) جب اللہ نے کہا (اے عیسیٰ) میں تمہیں پورا قبض کرنے والا اور تمہیں اپنی جانب اٹھانے والا ہوں اور تمہیں کافروں سے پاک کرنے والا ہوں اور تمہاری پیروی کرنے والوں کو کافروں پر قیامت تک غالب اور برتر کرنے والا ہوں۔ پھر تم سب کی بازگشت میری طرف ہے تو اس وقت میں تمہارے درمیان ان باتوں کا فیصلہ کروں گا جن میں تم اختلاف کرتے تھے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@cccxlix{تو جن لوگوں نے کفر اختیار کیا انہیں دنیا و آخرت میں سخت سزا دوں گا۔ اور ان کا کوئی مددگار نہ ہوگا۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@cccl{اور جو لوگ ایمان لائے اور نیک عمل کئے تو خدا ان کو پورا پورا اجر و ثواب دے گا۔ اور اللہ ظالموں کو دوست نہیں رکھتا۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@cccli{(اے رسول) یہ جو ہم آپ کو پڑھ کر سنا رہے ہیں (کتابِ الٰہی کی) آیات ہیں (یا خدا کی قدرت اور آپ کی حقانیت کی نشانیاں ہیں) اور وہ دانائی سے لبریز تذکرے ہیں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@ccclii{بے شک اللہ کے نزدیک عیسیٰ کی مثال آدم کی سی ہے کہ اللہ نے انہیں مٹی سے پیدا کیا پھر حکم دیا کہ ہو جا سو وہ ہوگیا۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@cccliii{یہ بات تمہارے پروردگار کی طرف سے حق ہے تو تم شک کرنے والوں میں سے نہ ہونا۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@cccliv{(اے پیغمبر(ص)) اس معاملہ میں تمہارے پاس صحیح علم آجانے کے بعد جو آپ سے حجت بازی کرے تو آپ ان سے کہیں کہ آؤ ہم اپنے اپنے بیٹوں، اپنی اپنی عورتوں اور اپنے اپنے نفسوں کو بلائیں اور پھر مباہلہ کریں (بارگاہِ خدا میں دعا و التجا کریں) اور جھوٹوں پر خدا کی لعنت قرار دیں۔ (یعنی ہم اپنے بیٹوں کو بلائیں تم اپنے بیٹوں کو، ہم اپنی عورتوں کو بلائیں تم اپنی عورتوں کو اور ہم اپنے نفسوں کو بلائیں تم اپنے نفسوں کو پھر اللہ کے سامنے گڑگڑائیں اور جھوٹوں پر خدا کی لعنت کریں)۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@ccclv{(جناب عیسیٰ کی) یہ برحق سرگزشت ہے (وہ خدا یا خدا کے بیٹے نہیں بلکہ اس کے خاص بندے ہیں) اللہ کے سوا کوئی الٰہ نہیں ہے وہ توانا اور بڑا حکمت والا ہے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@ccclvi{اب اس کے بعد بھی یہ لوگ انحراف کریں تو خدا مفسدین کو خوب جانتا ہے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@ccclvii{(اے رسول) کہیے اے اہل کتاب! آؤ ایک ایسی بات کی طرف جو ہمارے اور تمہارے درمیان مشترک اور یکساں ہے (اور وہ یہ کہ) ہم اللہ کے سوا کسی کی عبادت نہ کریں۔ اور کسی کو اس کا شریک نہ بنائیں، اور ہم میں سے کوئی کسی کو اللہ کے سوا اپنا رب (مالک و مختار) نہ بنائے۔ اور اگر یہ لوگ اس (دعوت) سے منہ موڑیں تو (اے مسلمانو) تم کہہ دو کہ گواہ رہنا ہم مسلمان (خدا کے فرمانبردار و اطاعت گزار ہیں)۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@ccclviii{اے اہل کتاب! تم ابراہیم کے بارے میں کیوں (ہم سے) حجت بازی کرتے ہو۔ حالانکہ تورات اور انجیل ان کے بعد اتری ہیں کیا تم میں اتنی بھی عقل (سمجھ) نہیں ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@ccclix{تم وہی لوگ ہو۔ جو (ہم سے) ان باتوں کے بارے میں بحث و تکرار کرتے رہے جن کا تمہیں کچھ علم تھا۔ اب ان باتوں کے بارے میں کیوں حجت بازی کرتے ہو جن کا تمہیں کچھ علم نہیں (حقیقت حال) صرف اللہ جانتا ہے تم نہیں جانتے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@ccclx{ابراہیم نہ یہودی تھے اور نہ نصرانی بلکہ وہ تو نرے کھرے خالص مسلمان (خدا کے فرمانبردار بندے) تھے اور وہ مشرکوں میں سے نہیں تھے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@ccclxi{بے شک تمام لوگوں سے ابراہیم کے زیادہ قریب اور زیادہ تعلق رکھنے والے وہ ہیں جنہوں نے اُن کی پیروی کی اور یہ نبی اور وہ جو (ان پر) ایمان لائے ہیں اور اللہ ایمان والوں کا ساتھی و سرپرست ہے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@ccclxii{اہل کتاب کا ایک گروہ چاہتا ہے کہ کاش وہ تمہیں گمراہ کر سکے حالانکہ وہ اپنے سوا کسی کو بھی گمراہ نہیں کرتے مگر انہیں اس کا شعور نہیں۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@ccclxiii{اے اہل کتاب تم آیاتِ الٰہیہ کا کیوں انکار کرتے ہو؟ حالانکہ تم خود گواہ ہو (کہ وہ آیاتِ الٰہیہ ہیں) اور برحق ہیں۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@ccclxiv{اے اہل کتاب! حق کو باطل کے ساتھ کیوں گڈمڈ کرتے ہو؟ اور حق کو کیوں چھپاتے ہو حالانکہ تم جانتے ہو (کہ حق کیا ہے)۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@ccclxv{اہل کتاب کا ایک گروہ (اپنے لوگوں سے) کہتا ہے کہ جو کچھ مسلمانوں پر نازل ہوا ہے اس پر صبح کے وقت ایمان لے آؤ اور شام کے وقت انکار کر دو۔ شاید (اس ترکیب سے) وہ مسلمان (اپنے دین سے) پھر جائیں۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@ccclxvi{خبردار۔ صرف اسی کی بات مانو جو تمہارے دین کی پیروی کرے۔ کہہ دیجیے کہ حقیقی ہدایت تو اللہ کی ہدایت ہے (اور یہ اسی کی دین ہے) کہ کسی کو ویسی ہی چیز مل جائے جو (کبھی) تم کو دی گئی تھی۔ یا وہ دلیل و حجت میں تمہارے پروردگار کے ہاں تم پر غالب آجائیں۔ کہہ دیجیے کہ بے شک فضل و کرم اللہ کے ہاتھ میں ہے وہ جسے چاہتا ہے عطا کرتا ہے۔ وہ بڑی وسعت والا اور بڑا جاننے والا ہے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@ccclxvii{وہ جس کو چاہتا ہے اپنی رحمت کے لئے مخصوص کر لیتا ہے اللہ بڑے فضل و کرم والا ہے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@ccclxviii{اور اہل کتاب میں سے کوئی تو ایسا ہے۔ کہ اگر تم ڈھیر بھر روپیہ بھی بطور امانت اس کے پاس رکھو تو وہ تمہیں ادا کر دے گا۔ اور ان میں کوئی ایسا بھی ہے کہ اگر اس کے پاس ایک دینار (اشرفی) بھی بطور امانت رکھو تو جب تک تم اس کے سر پر کھڑے نہ رہو وہ تمہیں واپس نہیں کرے گا (یہ بدمعاملگی) اس وجہ سے ہے کہ ان کا قول ہے کہ ہم پر امیّون (ان پڑھ عربوں جوکہ اہل کتاب نہیں) کے بارے میں کوئی پابندی نہیں ہے۔ اور وہ جان بوجھ کر اللہ پر جھوٹ منڈھتے ہیں۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@ccclxix{ہاں جو شخص اپنے عہد و پیمان کو پورا کرے اور پرہیزگاری اختیار کرے تو بے شک خدا پرہیزگاروں سے محبت کرتا ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@ccclxx{جو لوگ اللہ سے کئے گئے عہد و پیمان اور قسم اقسام کو تھوڑی سی قیمت پر بیچ دیتے ہیں ان کا آخرت میں کوئی حصہ نہیں ہے۔ خدا قیامت کے دن نہ ان سے بات کرے گا اور نہ ان کی طرف نظر (رحمت) کرے گا اور نہ ان کو (گناہوں کی کثافت سے) پاک کرے گا۔ اور ان کے لئے دردناک عذاب ہے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@ccclxxi{بے شک ان (اہل کتاب) سے ایک گروہ ایسا بھی ہے۔ جو اپنی زبانوں کو کتاب (توراۃ وغیرہ) کے پڑھنے میں مروڑتا ہے اور کچھ کا کچھ پڑھتا ہے تاکہ تم یہ سمجھو کہ یہ (توڑ موڑ) بھی کتاب خدا میں سے ہے حالانکہ وہ کتاب میں سے نہیں ہے۔ اور کہتا ہے کہ وہ خدا کی طرف سے (آیا) ہے حالانکہ وہ خدا کی طرف سے نہیں ہے یہ جان بوجھ کر خدا پر جھوٹ باندھتا ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@ccclxxii{کسی ایسے انسان کو یہ بات زیب نہیں دیتی جسے خدا کتاب، حکمت (یا اقتدار) اور نبوت عطا فرمائے اور وہ لوگوں سے کہے کہ تم خدا کو چھوڑ کر میرے بندے بن جاؤ (میری عبادت کرو) بلکہ (وہ تو یہ کہے گا کہ) تم اللہ والے ہو جاؤ۔ اس بنا پر کہ تم کتابِ الٰہی کی تعلیم دیتے ہو۔ اور اسے پڑھتے بھی رہتے ہو۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@ccclxxiii{اور وہ کبھی تمہیں یہ حکم نہیں دے گا کہ تم فرشتوں اور نبیوں کو اپنا پروردگار بنا لو۔ بھلا وہ تمہیں کفر کا حکم دے گا۔ اس کے بعد کہ تم مسلمان ہو؟ ۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@ccclxxiv{اور (یاد کرو) جب خدا نے تمام پیغمبروں سے یہ عہد و اقرار لیا تھا کہ میں نے جو تمہیں کتاب و حکمت عطا کی ہے۔ اس کے بعد جب تمہارے پاس ایک عظیم رسول آئے جو تمہارے پاس کی چیزوں (کتابوں) کی تصدیق کرنے والا ہو تو تم اس پر ضرور ایمان لانا اور ضرور اس کی مدد کرنا ارشاد ہوا۔ کیا تم اقرار کرتے ہو؟ اور اس پر میرے عہد و پیمان کو قبول کرتے ہو اور یہ ذمہ داری اٹھاتے ہو؟ انہوں نے کہا ہاں ہم نے اقرار کیا۔ ارشاد ہوا۔ تم سب گواہ رہنا اور میں بھی تمہارے ساتھ گواہوں میں سے ہوں۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@ccclxxv{اب جو کوئی بھی اس (عہد) سے منہ پھیرے گا تو ایسے ہی لوگ فاسق (نافرمان) ہیں۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@ccclxxvi{کیا وہ اللہ کے دین (اسلام) کے سوا کسی اور (دین) کو تلاش کرتے ہیں حالانکہ جو آسمانوں میں ہیں یا زمین میں ہیں سب خوشی سے یا ناخوشی سے (چار و ناچار) اسی کی بارگاہ میں سر تسلیم خم کئے ہوئے ہیں اور بالآخر سب اسی کی طرف لوٹائے جائیں گے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@ccclxxvii{(اے رسول) کہہ دیجئے! کہ ہم اللہ پر ایمان لائے اور اس پر بھی جو ہم پر اتارا اور جو ابراہیم، اسماعیل، اسحاق، یعقوب اور اسباط پر اتارا گیا۔ اور اس پر بھی جو کچھ موسیٰ و عیسیٰ اور دوسرے پیغمبروں کو جو کچھ ان کے پروردگار کی طرف سے عطا ہوا۔ ہم (بحیثیت نبی ہونے کے) ان کے درمیان تفریق نہیں کرتے۔ اور ہم اسی (خدائے یکتا) کے مسلمان (اطاعت گزار بندے) ہیں۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@ccclxxviii{اور جو شخص اسلام کے علاوہ کوئی بھی دین اختیار کرے گا تو اس کا دین ہرگز قبول نہ کیا جائے گا اور وہ آخرت میں خسارہ پانے والوں میں سے ہوگا۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@ccclxxix{بھلا خدا ان لوگوں کو کیوں کر ہدایت دے گا (منزل مقصود پر پہنچائے گا) جو ایمان لانے کے بعد پھر کافر ہوگئے۔ حالانکہ وہ گواہی دے چکے تھے کہ رسول برحق ہے۔ اور ان کے پاس آیات بینات (واضح معجزات) بھی آچکے تھے۔ بے شک خدا ظلم و جور کرنے والوں کو ہدایت نہیں دیتا۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@ccclxxx{ایسے لوگوں کی سزا یہ ہے کہ ان پر اللہ، فرشتوں اور سب انسانوں کی لعنت ہے۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@ccclxxxi{وہ ہمیشہ اس لعنت (پھٹکار) میں گرفتار رہیں گے۔ نہ ان کے عذاب میں تخفیف (کمی) کی جائے گی اور نہ انہیں مہلت دی جائے گی۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@ccclxxxii{مگر وہ جنہوں نے اس کے بعد توبہ کرلی اور اپنی اصلاح کر لی تو بے شک خدا بڑا بخشنے والا اور بڑا رحم کرنے والا ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiii{بے شک وہ لوگ جو ایمان لانے کے بعد کافر ہوگئے اور کفر میں بڑھتے ہی چلے گئے ان کی توبہ قبول نہیں ہوگی اور یہی لوگ حقیقی گمراہ ہیں۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiv{بے شک جن لوگوں نے کفر اختیار کیا اور پھر کفر ہی کی حالت میں مر گئے تو ان میں سے کسی ایک سے ساری زمین بھر سونا بطور فدیہ و معاوضہ ہرگز قبول نہیں کیا جائے گا یہ وہ لوگ ہیں جن کے لئے دردناک عذاب ہے اور ان کے لئے کوئی مددگار نہیں ہوں گے۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@ccclxxxv{لوگو! تم ہرگز اس وقت تک نیکی (کو حاصل) نہیں کر سکتے جب تک اپنی پسندیدہ چیزوں میں سے کچھ راہِ خدا میں خرچ نہ کرو۔ اور تم (راہِ خدا میں) جو کچھ خرچ کرتے ہو خدا اس کو خوب جانتا ہے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvi{تورات نازل ہونے سے پہلے کھانے کی سب چیزیں (جو اسلام میں حلال ہیں) بنی اسرائیل کے لیے بھی حلال تھیں۔ سوائے اس کے جو اسرائیل (یعقوب) نے اپنے اوپر حرام کر رکھی تھی (یہود سے) کہو کہ اگر تم سچے ہو تو تورات لاؤ اور اسے پڑھو۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvii{پھر اس کے بعد جو شخص خدا پر بہتان باندھے۔ تو (سمجھ لو کہ) ایسے لوگ ہی ظالم ہیں۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@ccclxxxviii{(اے رسول(ص)) کہہ دیجیے خدا نے سچ فرمایا! پس تم ملت (دین) ابراہیم کی پیروی کرو جو باطل سے کنارہ کش ہوکر صرف اللہ کا ہو رہا تھا اور مشرکین میں سے نہ تھا۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ccclxxxix{بے شک سب سے پہلا گھر جو لوگوں (کی عبادت) کے لیے بنایا گیا یقینا وہی ہے جو مکہ میں ہے بڑی برکت والا اور عالمین کے لیے مرکز ہدایت ہے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@cccxc{اس گھر میں کھلی ہوئی نشانیاں ہیں (منجملہ ان کے ایک) مقام ابراہیم ہے۔ اور جو اس میں داخل ہوا اسے امن مل گیا۔ اور لوگوں پر واجب ہے کہ محض خدا کے لیے اس گھر کا حج کریں جو اس کی استطاعت (قدرت) رکھتے ہیں اور جو (باوجود قدرت) کفر کرے (انکار کرے) تو بے شک خدا تمام عالمین سے بے نیاز ہے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cccxci{(اے رسول(ص)) کہہ دیجیے! اے اہل کتاب تم آیاتِ الٰہیہ کا کیوں انکار کرتے ہو؟ حالانکہ تم جو کچھ کرتے ہو خدا اس کا گو اہ ہے (سب کچھ دیکھ رہا ہے) ۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cccxcii{کہیے۔ اے اہل کتاب! آخر تم اس شخص کو جو ایمان لانا چاہتا ہے کیوں خدا کی راہ سے روکتے ہو؟ اور چاہتے ہو کہ اس راہ (راست) کو ٹیڑھا بنا دو حالانکہ تم خود گواہ ہو (کہ سیدھی راہ یہی ہے) اور جو کچھ تم کرتے ہو خدا اس سے بے خبر نہیں ہے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cccxciii{اے ایمان والو! اگر تم نے اہل کتاب میں سے کسی گروہ کی بات مان لی تو یہ تمہیں ایمان کے بعد کفر کی طرف پلٹا دیں گے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cccxciv{اور بھلا تم کیوں کر کفر اختیار کر سکتے ہو۔ جبکہ تمہارے سامنے برابر خدا کی آیتیں پڑھی جا رہی ہیں اور تمہارے درمیان اس کا رسول موجود ہے۔ اور جو شخص خدا سے وابستہ ہوگیا وہ ضرور سیدھے راستے پر لگا دیا گیا۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cccxcv{اے ایمان والو! خدا سے اس طرح ڈرو جیساکہ ڈرنے کا حق ہے اور ہرگز نہ مرو مگر اس حالت میں کہ تم مسلمان ہو۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cccxcvi{اور سب مل کر اللہ کی رسی کو مضبوطی سے تھام لو اور آپس میں تفرقہ پیدا نہ کرو اور اللہ کے اس احسان کو یاد کرو جو اس نے تم پر کیا ہے کہ تم آپس میں دشمن تھے اس نے تمہارے دلوں میں الفت پیدا کر دی اور تم اس کی نعمت (فضل و کرم) سے بھائی بھائی ہوگئے۔ اور تم آگ کے بھرے ہوئے گڑھے (دوزخ) کے کنارے پر کھڑے تھے جو اس نے تمہیں اس سے بچا لیا اس طرح اللہ تمہارے لیے اپنی نشانیاں ظاہر کرتا ہے تاکہ تم ہدایت پا جاؤ۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cccxcvii{اور تم میں سے ایک گروہ ایسا ہونا چاہیے جو نیکی کی دعوت دے اور اچھے کاموں کا حکم دے اور برے کاموں سے منع کرے یہی وہ لوگ ہیں (جو دین و دنیا کے امتحان میں) کامیاب و کامران ہوں گے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cccxcviii{اور خبردار تم ان لوگوں کی طرح نہ بننا جو انتشار کا شکار ہوگئے اور کھلی ہوئی نشانیوں (دلیلوں) کے آجانے کے بعد اختلاف میں مبتلا ہوگئے۔ یہی وہ لوگ ہیں جن کے لیے بڑا عذاب ہے۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cccxcix{جس دن کچھ چہرے سفید (نورانی) ہوں گے اور کچھ چہرے سیاہ ہوں گے۔ تو جن کے چہرے سیاہ ہوں گے (ان سے کہا جائے گا) کہ تم نے ہی ایمان لانے کے بعد کفر کیا تھا؟ تو اب اپنے کفر کے نتیجہ میں عذاب کا مزا چکھو۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cd{اور جن کے چہرے سفید (نورانی) ہوں گے وہ خدا کی رحمت میں ہوں گے اور ہمیشہ ہمیشہ اس میں رہیں گے۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cdi{یہ آیاتِ الٰہیہ ہیں جو ہم سچائی کے ساتھ تمہیں پڑھ کر سنا رہے ہیں کیونکہ خدا جہان والوں پر ظلم کرنے کا ارادہ بھی نہیں کرتا۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cdii{اور جو کچھ آسمانوں میں ہے اور زمین میں ہے۔ سب اللہ کا ہے اور سب معاملات کی بازگشت اللہ ہی کی طرف ہوتی ہے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cdiii{تم بہترین امت ہو جسے لوگوں (کی راہنمائی) کے لیے پیدا کیا گیا ہے۔ تم اچھے کاموں کا حکم دیتے ہو اور برے کاموں سے منع کرتے ہو۔ اور اللہ پر ایمان رکھتے ہو۔ اور اگر اہل کتاب بھی ایمان لے آتے تو ان کے لئے بہتر ہوتا، ان میں سے کچھ تو ایمان لائے ہیں مگر بہت سے فاسق و نافرمان ہیں۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cdiv{یہ معمولی اذیت کے سوا ہرگز تمہیں کوئی نقصان نہیں پہنچا سکتے۔ اور اگر یہ تم سے جنگ کریں گے تو تمہیں پیٹھ دکھائیں گے پھر ان کی (کہیں سے) مدد نہ کی جائے گی۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cdv{یہ جہاں بھی پائے جائیں ان پر ذلت کی مار پڑ گئی مگر یہ کہ خدا کے کسی عہد پر یا انسانوں کے کسی معاہدہ کے سہارے کچھ پناہ مل جائے۔ اور یہ خدا کے قہر و غضب میں گھر گئے ہیں اور ان پر محتاجی کی مار پڑی یہ سب کچھ اس لئے ہے کہ وہ آیاتِ الٰہی کے ساتھ کفر کرتے رہے اور ناحق نبیوں کو قتل کرتے رہے نیز اس لئے کہ (خدا کی) نافرمانی اور زیادتیاں کیا کرتے تھے۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cdvi{یہ لوگ سب برابر نہیں ہیں۔ اہل کتاب میں ایسی ثابت قدم جماعت بھی ہے جو رات کے مختلف اوقات میں آیاتِ الٰہی کی تلاوت کرتی ہے۔ اور سجدہ ریز ہوتی ہے۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cdvii{اللہ اور روزِ آخرت پر ایمان رکھتے ہیں نیکی کا حکم دیتے ہیں اور برائی سے منع کرتے ہیں اور بھلائی کے کاموں میں تیزی کرتے ہیں اور یہ لوگ نیک لوگوں میں سے ہیں۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cdviii{یہ جو نیکی بھی کریں گے اس کی ہرگز ناقدری نہیں کی جائے گی۔ اور خدا پرہیزگاروں کو خوب جانتا ہے۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cdix{بے شک جن لوگوں نے کفر اختیار کیا انہیں ان کے اموال اور اولاد اللہ (کی گرفت) سے کچھ بھی نہیں بچا سکیں گے۔ وہ تو دوزخی ہیں اور وہ اس میں ہمیشہ ہمیشہ رہیں گے۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cdx{یہ لوگ جو کچھ اس دنیوی زندگی میں خرچ کرتے ہیں اس کی مثال اس ہوا کی سی ہے جس میں سخت سردی ہو اور وہ ایسے لوگوں کی کھیتی پر چلے جنہوں نے اپنے اوپر ظلم کیا ہے۔ اور اسے تباہ و برباد کرکے رکھ دے۔ اللہ نے ان پر کوئی ظلم نہیں کیا۔ بلکہ وہ خود اپنے اوپر ظلم کرتے ہیں۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cdxi{اے ایمان والو! اپنے (لوگوں کے) سوا دوسرے ایسے لوگوں کو اپنا جگری دوست (رازدار) نہ بناؤ جو تمہیں نقصان پہنچانے میں کوئی کسر اٹھا نہیں رکھتے۔ جو چیز تمہیں مصیبت و زحمت میں مبتلا کرے وہ اسے محبوب رکھتے ہیں بغض و عناد ان کے مونہوں سے ٹپکتا ہے۔ اور جو کچھ ان کے سینے چھپائے ہوئے ہیں وہ اس سے کہیں بڑھ کر ہے۔ ہم نے تمہارے لئے نشانیاں کھول کر بیان کر دی ہیں اگر تم عقل سے کام لو۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cdxii{تم ایسے (سیدھے) ہو کہ تم ان سے محبت کرتے ہو مگر وہ تم سے محبت نہیں کرتے۔ حالانکہ تم (آسمانی) کتاب پر ایمان رکھتے ہو۔ (ان کی حالت یہ ہے کہ) جب تم سے ملتے ہیں تو کہتے ہیں کہ ہم ایمان لائے۔ اور جب اکیلے ہوتے ہیں تو تمہارے خلاف غیظ و غضب سے اپنی انگلیاں چبانے لگتے ہیں۔ ان سے کہہ دو کہ اپنے غم و غصہ سے مر جاؤ۔ بے شک اللہ سینے کے اندر والی باتوں کو خوب جانتا ہے۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cdxiii{جب تمہیں کوئی بھلائی چھو بھی جائے تو ان کو برا لگتا ہے اور اگر تمہیں کوئی برائی پہنچے تو وہ اس سے خوش ہوتے ہیں اور اگر تم صبر سے کام کرو۔ اور پرہیزگاری اختیار کرو تو ان کی ترکیبیں اور چالیں تمہیں کچھ نقصان نہیں پہنچائیں گی۔ بے شک جو کچھ یہ لوگ کر رہے ہیں خدا اس کا علمی احاطہ کئے ہوئے ہے۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cdxiv{اور وہ موقع (یاد رکھنے کے لائق ہے کہ) جب تم صبح سویرے اپنے گھر سے نکلے تھے اور (احد کے مقام پر) مؤمنوں کو جنگی مورچوں پر بٹھا رہے تھے اور جگہ دے رہے تھے اور اللہ بڑا سننے والا اور بڑا جاننے والا ہے۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cdxv{جب تم میں سے دو گروہوں نے بزدلی دکھانے کا ارادہ کیا (مگر پھر سنبھل گئے) حالانکہ اللہ ان کا حامی و مددگار تھا اور مؤمنوں کو اللہ پر ہی بھروسہ کرنا چاہیے۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cdxvi{بے شک (اس سے پہلے) جنگ بدر میں اللہ تمہاری مدد کر چکا تھا حالانکہ تم (اس وقت) بہت کمزور تھے سو اللہ کی نافرمانی سے ڈرو۔ تاکہ تم شکرگزار بنو۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cdxvii{(اے پیغمبر(ص)) یاد کرو۔ جب تم مؤمنوں سے کہہ رہے تھے کہ کیا یہ بات تمہارے (اطمینان) کے لئے کافی نہیں ہے۔ کہ تمہارا پروردگار تین ہزار فرشتوں سے تمہاری مدد کرے جو (آسمان سے) اتارے گئے ہوں۔\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cdxviii{ہاں کیوں نہیں! اگر تم صبر کرو اور تقویٰ الٰہی اختیار کرو۔ اور وہ (دشمن جوش میں آکر) اس وقت فوری طور پر تم پر چڑھ آئے تو تمہارا پروردگار پانچ ہزار نشان زدہ فرشتوں سے تمہاری مدد کرے گا۔\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cdxix{اللہ نے اس (غیبی امداد) کو قرار نہیں دیا۔ مگر اس لئے کہ تمہارے لئے خوشخبری ہو۔ اور تمہارے دل مطمئن ہو جائیں اور (یہ بات تو واضح ہے کہ) مدد اور فتح و نصرت اللہ ہی کی طرف سے ہے جو زبردست ہے اور بڑی حکمت والا ہے۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cdxx{(اور یہ امداد اس لئے ہے) تاکہ کافروں کے ایک بڑے حصہ کو کاٹ دے (قلع قمع کر دے) یا ان کو ایسا ذلیل کرے کہ وہ ناکام و نامراد ہوکر واپس چلے جائیں۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cdxxi{اے رسول(ص)! خدا کے امر (فیصلہ) میں تمہیں کوئی اختیار نہیں ہے (بلکہ یہ اختیار اللہ کے پاس ہے) چاہے تو ان کی توبہ قبول کرے اور چاہے تو انہیں سزا دے۔ کیونکہ یہ لوگ بہرحال ظالم ہیں۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cdxxii{اور جو کچھ آسمانوں میں ہے اور جو کچھ زمینوں میں ہے سب اللہ ہی کا ہے۔ وہ جسے چاہتا ہے بخش دیتا ہے۔ اور جسے چاہتا ہے سزا دیتا ہے اور اللہ بڑا بخشنے والا مہربان ہے۔\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cdxxiii{اے ایمان والو! یہ دوگنا چوگنا بڑھتا چڑھتا سود نہ کھاؤ (اللہ کی نافرمانی) سے ڈرو تاکہ تم فلاح پاؤ۔\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cdxxiv{اور اس آگ سے بچو جو کافروں کے لئے تیار کی گئی ہے۔\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cdxxv{اور اللہ اور رسول(ص) کی فرمانبرداری کرو تاکہ تم پر رحم کیا جائے۔\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cdxxvi{اور تیزی سے دوڑو اپنے پروردگار کی طرف سے بخشش۔ اور اس کے بہشت کی طرف جس کی چوڑائی تمام آسمانوں اور زمین کے برابر ہے جو پرہیزگاروں کے لئے تیار کیا گیا ہے۔\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cdxxvii{وہ پرہیزگار جو خوشحالی اور بدحالی (غرضیکہ ہر حال میں راہِ خدا میں مال) خرچ کرتے ہیں جو غصے کو پی جاتے ہیں اور لوگوں (کے قصور) معاف کر دیتے ہیں۔ اور اللہ بھلائی کرنے والوں سے محبت کرتا ہے۔\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cdxxviii{یہ لوگ اگر (اتفاقاً) کوئی فحش کام (کوئی بڑا برا کام) کر بیٹھیں یا کوئی عام گناہ کرکے اپنے اوپر ظلم کر گذریں تو (فوراً) اللہ کو یاد کرکے اس سے اپنے گناہوں کی مغفرت طلب کرتے ہیں اور اللہ کے سوا کون ہے جو گناہوں کو معاف کرے۔\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cdxxix{اور وہ اپنے کئے پر دیدہ دانستہ اصرار نہیں کرتے ایسے لوگوں کی جزاء ان کے پروردگار کی طرف سے مغفرت و بخشش ہے اور وہ جنات (باغات) کہ جن کے نیچے سے نہریں جاری ہیں۔ وہ ہمیشہ ان میں رہیں گے اور کتنا اچھا صلہ ہے نیک عمل کرنے والوں کا۔\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cdxxx{تم سے پہلے بہت سے نمونے (اور دور) گزر چکے ہیں سو زمین میں چل پھر کر دیکھو کہ (احکام خداوندی) جھٹلانے والوں کا کیا انجام ہوا؟ ۔\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cdxxxi{یہ (عام) لوگوں کے لیے تو واضح تذکرہ اور تنبیہ ہے اور پرہیزگاروں کے لیے ہدایت اور نصیحت ہے۔\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cdxxxii{اے مسلمانو! کمزوری نہ دکھاؤ اور غمگین نہ ہو اگر تم مؤمن ہو تو تم ہی غالب و برتر ہوگے۔\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cdxxxiii{اگر تمہیں زخم لگا ہے تو اس جیسا زخم ان لوگوں (کافروں) کو بھی (جنگ بدر میں) لگ چکا ہے۔ یہ تو ایام (زمانہ کے اتفاقات اور نشیب و فراز) ہیں جنہیں ہم لوگوں میں باری باری ادلتے بدلتے رہتے ہیں (تمہیں یہ چوٹ اس لئے لگی) کہ خدا (خالص) ایمان والوں کو جان لے۔ اور بعض کو (چھانٹ کر) شہید (گواہ) بنائے اور اللہ ظالموں کو دوست نہیں رکھتا۔\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cdxxxiv{نیز اللہ اس (ابتلا و آزمائش) سے یہ چاہتا تھا کہ خالص اہل ایمان کو چھانٹ کر الگ کر دے اور کافروں کو رفتہ رفتہ مٹا دے۔\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cdxxxv{(اے مسلمانو!) کیا تم کو یہ خیال ہے کہ تم یونہی جنت میں داخل ہو جاؤگے حالانکہ ابھی تک اللہ نے (جانچ کر) معلوم ہی نہیں کیا کہ تم میں واقعی مجاہد کون ہیں؟ اور نہ ابھی یہ معلوم کیا ہے کہ صابر اور ثابت قدم کون ہیں؟ ۔\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cdxxxvi{اور تم لوگ موت کا سامنا کرنے سے پہلے تو اس کی بہت تمنا کیا کرتے تھے۔ لو اب تم نے اسے دیکھ لیا۔ اور اب بھی (اپنی آنکھوں سے دیکھ رہے ہو) (تو پھر اس سے کنّی کیوں کتراتے ہو؟)۔\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cdxxxvii{اور حضرت محمد (ص) نہیں ہیں مگر پیغمبر جن سے پہلے تمام پیغمبر گزر چکے ہیں تو کیا اگر وہ وفات پا جائیں یا قتل کر دیئے جائیں تو تم الٹے پاؤں (کفر کی طرف) پلٹ جاؤگے اور جو کوئی الٹے پاؤں پھرے گا تو وہ ہرگز اللہ تعالیٰ کو کوئی نقصان نہیں پہنچائے گا اور عنقریب خدا شکرگزار بندوں کو جزا دے گا۔\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cdxxxviii{کوئی ذی روح خدا کے حکم کے بغیر مر نہیں سکتا موت کا وقت تو لکھا ہوا (معیّن) ہے اور جو شخص (اپنے اعمال کا) بدلہ دنیا میں چاہتا ہے تو ہم اسی (دنیا) میں دے دیتے ہیں اور جو آخرت میں بدلہ چاہتا ہے تو ہم اسے آخرت میں دیتے ہیں اور ہم عنقریب شکرگزار بندوں کو جزا (خیر) عطا کریں گے۔\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cdxxxix{اور بہت سے ایسے نبی (گزر چکے) ہیں جن کے ساتھ مل کر بہت سے اللہ والوں نے جنگ کی تو اللہ کی راہ میں ان پر جو مصیبتیں پڑیں ان پر وہ نہ پست ہمت ہوئے اور نہ انہوں نے کمزوری دکھائی اور نہ (دشمن کے سامنے) سرنگوں ہوئے اور اللہ صبر و تحمل رکھنے والے (ثابت قدموں) سے محبت رکھتا ہے۔\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cdxl{(ایسے مواقع پر) ان کا قول اس (دعا) کے سوا کچھ نہیں تھا کہ اے ہمارے پروردگار ہمارے گناہ اور اپنے کام میں ہماری زیادتی معاف فرما اور ہمیں ثابت قدم رکھ اور ہمیں کافروں پر فتح و نصرت عطا فرما۔\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cdxli{تو خدا نے ان کو دنیا میں بھی صلہ عطا کیا اور آخرت کا بہترین ثواب بھی عنایت فرمایا۔ اور اللہ نیک کام کرنے والوں کو دوست رکھتا ہے۔\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cdxlii{اے ایمان والو! اگر تم نے ان لوگوں کی اطاعت کی جنہوں نے کفر اختیار کیا تو وہ تم کو الٹے پاؤں (کفر کی طرف) پھیر کر لے جائیں گے اور تم بڑا خسارہ اٹھا کر واپس ہوگے۔\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cdxliii{(تمہیں کسی کی اطاعت کی کیا ضرورت ہے) بلکہ تمہارا حامی و سرپرست خدا ہے اور وہ بہترین مددگار ہے۔\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cdxliv{(تم پریشان نہ ہو) ہم عنقریب کافروں کے دلوں میں (تمہارا) رعب ڈال دیں گے اس لئے کہ انہوں نے خدائی میں ان بتوں کو شریک بنایا ہے۔ جن کے بارے میں خدا نے کوئی دلیل نازل نہیں کی ہے اور ان کا انجام جہّنم ہوگا اور وہ ظالمین کا بدترین ٹھکانہ ہے۔\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cdxlv{خدا نے (جنگ احد میں) اپنا وعدہ (نصرت) اس وقت سچا کر دکھایا جب تم اس کے حکم سے ان (کافروں) کا قلع قمع کر رہے تھے یہاں تک کہ جب تم نے کمزوری دکھائی تو تم نے حکم عدولی کی۔ (یہ اس لئے کہ) تم میں کچھ دنیا کے طلب گار تھے اور کچھ آخرت کے طلبگار تھے پھر اس نے تمہیں ان کے مقابلے میں پسپا کر دیا تاکہ تمہارے ایمان و اخلاص کی آزمائش کرے۔ اور (پھر بھی) تمہیں معاف کر دیا۔ اور اللہ اہل ایمان پر بڑا فضل کرنے والا ہے۔\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cdxlvi{(اس وقت کو یاد کرو) جب تم بے تحاشا بھاگے چلے جا رہے تھے اور کسی کی طرف مڑ کر بھی نہیں دیکھتے تھے۔ حالانکہ پیغمبر(ص) تمہارے پیچھے سے تمہیں پکار رہے تھے۔ (تمہاری اس روش کی وجہ سے) خدا نے تمہیں ثواب کے بدلے رنج پر رنج دیا۔ تاکہ (آئندہ) جو چیز تمہارے ہاتھ سے نکل جائے اس پر ملول نہ ہو اور جو مصیبت درپیش ہو اس پر رنج نہ کرو۔ اور اللہ تمہارے سب اعمال سے خوب باخبر ہے۔\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cdxlvii{پھر اس (خدا) نے رنج و غم کے بعد نیند کی صورت میں تم پر سکون و اطمینان اتارا۔ جو تم میں سے ایک گروہ پر طاری ہوگئی۔ اور ایک گروہ ایسا تھا کہ جسے صرف اپنی جانوں کی فکر تھی وہ اللہ کے ساتھ ناحق زمانۂ جاہلیت والے گمان کر رہا تھا وہ کہہ رہا تھا۔ کہ آیا اس معاملہ میں ہمیں بھی کچھ اختیار ہے؟ کہہ دیجیے۔ ہر امر کا اختیار صرف اللہ کو ہے۔ یہ لوگ اپنے دلوں میں ایسی باتیں چھپائے ہوئے ہیں۔ جن کا آپ سے اظہار نہیں کرتے کہتے ہیں کہ اگر ہمارے ہاتھ میں بھی کچھ اختیار ہوتا تو ہم یہاں مارے نہ جاتے۔ کہہ دیجیے! اگر تم لوگ اپنے گھروں میں بھی ہوتے تو بھی جن کے لئے قتل ہونا لکھا جا چکا تھا وہ ضرور اپنے مقتل کی طرف نکل کر جاتے (یہ سب کچھ اس لئے ہوا) کہ خدا اسے آزمائے جو کچھ تمہارے سینوں کے اندر ہے اور نکھار کے سامنے لائے اس (کھوٹ) کو جو تمہارے دلوں میں ہے اور اللہ سینوں کے اندر کی باتوں کا خوب جاننے والا ہے۔\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cdxlviii{بے شک جن لوگو ں نے دو جماعتوں کی مڈبھیڑ کے دن پیٹھ پھرائی (اس کا سبب یہ تھا) کہ ان کی بعض بدعملیوں کے نتیجہ میں جو وہ کر بیٹھے تھے شیطان نے ان کے قدم ڈگمگائے تھے اور بے شک اللہ نے انہیں معاف کر دیا۔ یقینا اللہ بڑا بخشنے والا نہایت بردبار ہے۔\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cdxlix{اے ایمان والو! کافروں کی طرح نہ ہو جاؤ جو اپنے ان بھائی بندوں کے بارے میں کہتے ہیں جو سفر میں گئے۔ یا جہاد کے لیے نکلے (اور وہاں وفات پا گئے) کہ اگر وہ ہمارے پاس ہوتے تو نہ (طبعی موت) مرتے اور نہ قتل کئے جاتے۔ یہ لوگ یہ بات اس لئے کہتے ہیں کہ خدا اسے ان کے دلوں میں رنج و حسرت کا باعث بنا دے۔ حالانکہ اللہ ہی زندہ رکھتا ہے اور مارتا ہے۔ اور تم جو کچھ بھی کرتے ہو اللہ اسے خوب دیکھ رہا ہے۔\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cdl{اور اگر تم راہِ خدا میں قتل کئے جاؤ۔ یا اپنی موت سے مر جاؤ۔ تو بے شک اللہ کی بخشش اور اس کی رحمت بہت ہی بہتر ہے اس (مال و دولت) سے جو لوگ جمع کرتے ہیں۔\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cdli{اور تم اپنی موت مرو۔ یا قتل کئے جاؤ۔ بہرحال اللہ کے ہی حضور میں محشور کئے جاؤگے۔\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cdlii{(اے رسول(ص)) یہ اللہ کی بہت بڑی مہربانی ہے کہ تم ان لوگوں کے لیے اتنے نرم مزاج ہو۔ ورنہ اگر تم درشت مزاج اور سنگدل ہوتے تو یہ سب آپ کے گرد و پیش سے منتشر ہو جاتے۔ انہیں معاف کر دیا کریں۔ ان کے لیے دعائے مغفرت کیا کریں اور معاملات میں ان سے مشورہ بھی لے لیا کریں۔ مگر جب کسی کام کے کرنے کا حتمی ارادہ ہو جائے تو پھر خدا پر بھروسہ کریں بے شک اللہ بھروسہ کرنے والوں کو دوست رکھتا ہے۔\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cdliii{اگر اللہ تمہاری مدد کرے۔ تو کوئی بھی تم پر غالب نہیں آسکتا اور اگر وہ تمہیں چھوڑ دے (مدد نہ کرے) تو اس کے بعد کون ہے جو تمہاری مدد کرے اور اہل ایمان کو صرف خدا پر ہی بھروسہ کرنا چاہیے۔\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cdliv{کسی نبی کی یہ شان اور کام نہیں ہے کہ وہ خیانت کرے۔ اور جو خیانت کرے گا۔ وہ اپنی خیانت کردہ چیز سمیت قیامت کے دن حاضر ہو جائے گا۔ پھر ہر ایک شخص کو اس کی کمائی کا پورا پورا بدلہ دیا جائے گا اور ان پر ظلم نہیں ہوگا۔\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cdlv{بھلا وہ شخص جو ہمیشہ خدا کی رضا پر چلنے والا ہو۔ وہ اس شخص کی مانند ہو سکتا ہے جو خدا کے غضب میں گھر گیا ہو۔ اور جس کا آخری ٹھکانہ دوزخ ہو اور وہ کیا برا ٹھکانہ ہے؟ ۔\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cdlvi{(ان دو قسم کے لوگوں کے) اللہ کے یہاں (مختلف درجے ہیں)۔ اور وہ جو کچھ کرتے ہیں اللہ اسے خوب دیکھ رہا ہے۔\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cdlvii{اللہ نے ہمیشہ اہل ایمان پر یہ بہت بڑا احسان کیا ہے کہ ان میں انہی میں سے ایک پیغمبر بھیجا۔ جو ان کے سامنے آیات الٰہی کی تلاوت کرتا ہے۔ ان کو پاکیزہ کرتا ہے (ان کی اصلاح کرتا ہے) اور انہیں کتاب و حکمت کی تعلیم دیتا ہے اگرچہ وہ اس سے پہلے کھلی ہوئی گمراہی میں تھے۔\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cdlviii{(اے مسلمانو! تمہارا کیا حال ہے) کہ جب تم پر (جنگ احد میں) کوئی ایسی مصیبت آپڑی جس سے دگنی مصیبت تمہاری اپنی لائی ہوئی ہے۔ اللہ ہر چیز پر قادر ہے۔\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cdlix{اور جو دو جماعتوں کی مڈبھیڑ والے دن (جنگ احد میں) تم پر جو مصیبت آئی وہ خدا کے اذن سے آئی تاکہ اللہ دیکھ لے (مخلص) مؤمن کون ہیں۔\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@cdlx{اور منافق کون؟ جن سے جب کہا گیا کہ آؤ اللہ کی راہ میں جنگ کرو۔ یا (کم از کم) دفاع ہی کرو۔ تو انہوں نے کہا۔ کہ اگر ہمیں علم ہوتا کہ جنگ ہوگی تو تمہارے پیچھے آتے جب وہ یہ بات کہہ رہے تھے اس وقت وہ بہ نسبت ایمان کے کفر کے زیادہ قریب تھے۔ وہ اپنے منہ سے وہ باتیں کہتے ہیں جو ان کے دلوں میں نہیں ہوتیں۔ اور جو کچھ وہ چھپاتے ہیں اللہ اسے خوب جانتا ہے۔\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@cdlxi{یہی وہ لوگ ہیں جو خود تو (گھروں میں) بیٹھے رہے مگر اپنے (شہید ہونے والے) بھائی بندوں کے بارے میں کہا کہ اگر یہ لوگ ہماری پیروی کرتے (اور جہاد کرنے نہ جاتے) تو مارے نہ جاتے۔ (اے رسول) ان سے کہو۔ کہ اگر تم سچے ہو تو جب خود تمہاری موت آئے تو اسے ٹال کر دکھا دینا۔\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@cdlxii{اور جو لوگ اللہ کی راہ میں مارے گئے ہیں انہیں ہرگز مردہ نہ سمجھو بلکہ وہ زندہ ہیں اپنے پروردگار کے یہاں رزق پا رہے ہیں۔\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@cdlxiii{اللہ نے اپنے فضل و کرم سے انہیں جو کچھ دیا ہے وہ اس پر خوش و خرم ہیں۔ اور اپنے ان پسماندہ گان کے بارے میں بھی جو ہنوز ان کے پاس نہیں پہنچے خوش اور مطمئن ہیں کہ انہیں کوئی خوف نہیں ہے۔ اور نہ کوئی حزن و ملال ہے۔\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@cdlxiv{وہ اللہ کے فضل و انعام پر خوش اور شاداں ہیں اور اس بات پر فرحاں ہیں کہ اللہ اہل ایمان کے اجر و ثواب کو ضائع و برباد نہیں کرتا۔\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@cdlxv{اور جن لوگوں نے زخم کھانے کے بعد بھی اللہ اور رسول کی آواز پر لبیک کہی۔ ان میں سے جو نیکوکار اور پرہیزگار ہیں ان کے لیے بڑا اجر و ثواب ہے۔\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@cdlxvi{وہ کہ جن سے لوگوں نے کہا کہ لوگوں نے تمہارے خلاف بڑا لشکر جمع کیا ہے لہٰذا تم ان سے ڈرو۔ تو اس بات نے ان کے ایمان میں اور اضافہ کر دیا۔ اور انہوں نے کہا کہ ہمارے لئے اللہ کافی ہے اور وہ بڑا اچھا کارساز ہے۔\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@cdlxvii{پس یہ لوگ اللہ کی عنایت اور اس کے فضل و کرم سے اس طرح (اپنے گھروں کی طرف) لوٹے کہ انہیں کسی قسم کی تکلیف نے چھوا بھی نہیں تھا۔ اور وہ رضاءِ الٰہی کے تابع رہے اور اللہ بڑے فضل و کرم والا ہے۔\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@cdlxviii{دراصل یہ تمہارا شیطان تھا جو تمہیں اپنے حوالی موالی (دوستوں) سے ڈراتا ہے۔ اور تم ان سے نہ ڈرو اور صرف مجھ سے ڈرو۔ اگر سچے مؤمن ہو۔\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@cdlxix{(اے رسول) وہ لوگ جو کفر کی راہ میں بڑی بھاگ دوڑ کر رہے ہیں وہ تمہیں غمزدہ نہ کریں یہ اللہ کا کچھ نہیں بگاڑ سکیں گے۔ اللہ کا ارادہ ہے کہ آخرت میں ان کے لئے کوئی حصہ نہ رکھے۔ اور ان کے لئے بہت بڑا عذاب ہے۔\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@cdlxx{بے شک جن لوگوں نے ایمان کے بدلے کفر خرید لیا ہے وہ ہرگز اللہ کو کچھ نقصان نہیں پہنچائیں گے اور ان کے لیے دردناک عذاب (تیار) ہے۔\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@cdlxxi{اور کافر یہ ہرگز خیال نہ کریں کہ ہم جو انہیں ڈھیل دے رہے ہیں (ان کی رسی دراز رکھتے ہیں) یہ ان کے لیے کوئی اچھی بات ہے یہ ڈھیل تو ہم صرف اس لئے انہیں دے رہے ہیں کہ وہ زیادہ گناہ کر لیں۔ (آخرکار) ان کے لیے رسوا کرنے والا عذاب ہے۔\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@cdlxxii{اللہ مؤمنوں کو اس حال پر نہیں چھوڑے گا جس حال پر تم اب ہو۔ جب تک وہ ناپاک کو پاک سے الگ نہ کر دے اور اللہ کی یہ شان نہیں ہے کہ تمہیں غیب پر مطلع کرے۔ البتہ اللہ (غیب کی باتیں بتانے کے لیے) اپنے رسولوں میں سے جسے چاہتا ہے منتخب کرتا ہے۔ سو تم اللہ اور اس کے رسولوں پر ایمان لاؤ۔ اور اگر تم ایمان لاؤ۔ اور پرہیزگاری اختیار کرو تو تمہارے لئے بڑا اجر و ثواب ہے۔\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@cdlxxiii{اور جن لوگوں کو اللہ نے اپنے فضل و کرم سے (بہت کچھ) دے رکھا ہے۔ اور وہ بخل کرتے ہیں وہ ہرگز یہ خیال نہ کریں کہ یہ (بخل) ان کے لیے اچھا ہے بلکہ یہ ان کے لیے بہت برا ہے۔ عنقریب قیامت کے دن اس مال کا طوق انہیں پہنایا جائے گا جس میں وہ بخل کر رہے ہیں۔ اور آسمانوں اور زمین کی میراث اللہ ہی کے لیے ہے اور جو کچھ تم کرتے ہو اللہ اس سے خوب خبردار ہے ۔\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@cdlxxiv{بے شک اللہ نے ان لوگوں (یہودیوں) کا قول سن لیا ہے جنہوں نے کہا کہ خدا مفلس ہے اور ہم مالدار ہیں سو ان کی یہ باتیں ہم لکھ لیں گے نیز ان کا نبیوں کو ناحق قتل کرنا بھی لکھ لیں گے۔ اور (فیصلے کے وقت) ہم ان سے کہیں گے کہ اب آتش دوزخ کا مزہ چکھو۔\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@cdlxxv{یہ بدلہ ہے اس کا جو تمہارے ہاتھوں نے (زاد سفر کے طور پر) آگے بھیجا ہے اور یقینا اللہ اپنے بندوں پر ظلم کرنے والا نہیں ہے۔\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cdlxxvi{یہ وہ لوگ ہیں جو کہتے ہیں کہ اللہ نے ہم سے عہد و اقرار لیا ہے کہ ہم اس وقت تک کسی رسول پر ایمان نہ لائیں۔ جب تک وہ ہمارے سامنے ایسی قربانی پیش نہ کرے جسے (غیبی) آگ آکر کھا لے۔ ان سے کہیئے۔ مجھ سے پہلے تمہارے پاس بہت سے رسول(ص) روشن نشانیاں (معجزے) لے کر اور وہ (نشانی) بھی جو تم کہتے ہو لے کر آئے۔ تو اگر تم (اس شرط میں) سچے ہو تو تم نے ان کو کیوں قتل کیا تھا؟ ۔\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cdlxxvii{(اے رسول) اگر یہ آپ کو جھٹلاتے ہیں تو (آزردہ خاطر نہ ہوں) آپ سے پہلے بہت سے رسول(ص) جھٹلائے جا چکے ہیں جو معجزات، صحیفے اور روشن کتاب (آئین حیات) لے کر آئے تھے۔\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cdlxxviii{ہر جاندار نے (انجام کار) موت کا مزہ چکھنا ہے۔ اور تم سب کو قیامت کے دن تمہیں (اپنے اعمال کا) پورا پورا بدلہ دیا جائے گا پس جو شخص (اس دن) جہنم سے بچا لیا گیا۔ اور جنت میں داخل کیا گیا وہ کامیاب ہوگیا۔ اور دنیا کی زندگی تو محض دھوکے کا سامان اور سرمایہ فریب ہے۔\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cdlxxix{(مسلمانو) ضرور تمہیں تمہارے مالوں اور جانوں کے بارے میں آزمایا جائے گا اور تمہیں اہل کتاب مشرکین سے بڑي دل آزار باتیں سننا پڑیں گی۔ اور اگر تم صبر و ضبظ سے کام لو اور تقویٰ اختیار کرو۔ تو بے شک یہ بڑی ہمت اور حوصلے کا کام ہے۔\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cdlxxx{(اے رسول(ص)) وہ وقت یاد کرو۔ جب خدا نے اہل کتاب سے عہد و پیمان لیا تھا کہ تم اسے ضرور لوگوں کے سامنے کھول کر بیان کروگے۔ اور اسے ہرگز نہیں چھپاؤگے مگر انہوں نے اسے اپنے پس پشت ڈال دیا۔ اور اس کے عوض تھوڑی سی قیمت وصول کرلی۔ کتنا برا کاروبار ہے جو یہ کر رہے ہیں۔\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cdlxxxi{آپ ان لوگوں کے بارے میں خیال کریں جو اپنی کارستانیوں پر اتراتے ہیں اور چاہتے ہیں کہ جو کام انہوں نے نہیں کیا اس پر بھی ان کی تعریف و ستائش کی جائے۔ ان کے بارے میں خیال نہ کرنا کہ وہ عذاب سے محفوظ ہیں (نہیں بلکہ) ان کے لیے دردناک عذاب (تیار) ہے۔\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cdlxxxii{اللہ کے لیے ہی ہے آسمانوں اور زمین کی حکومت (اور وہی ان کا مالک ہے) اور اللہ ہر چیز پر قادر ہے۔\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiii{بے شک آسمانوں اور زمین کی پیدائش میں اور رات دن کی ادل بدل میں صاحبانِ عقل کے لیے بڑی نشانیاں ہیں۔\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiv{جو اٹھتے، بیٹھتے اور پہلوؤں پر لیٹے ہوئے (برابر) اللہ کو یاد کرتے ہیں اور آسمانوں و زمین کی تخلیق و ساخت میں غور و فکر کرتے ہیں (اور بے ساختہ بول اٹھتے ہیں) اے ہمارے پروردگار! تو نے یہ سب کچھ فضول و بیکار پیدا نہیں کیا۔ تو (عبث کام کرنے سے) پاک ہے ہمیں دوزخ کے عذاب سے بچا۔\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cdlxxxv{اے ہمارے پروردگار! بے شک جسے تو نے دوزخ میں داخل کر دیا اسے تو نے ذلیل و رسوا کر دیا۔ اور ظالموں کے لئے کوئی یار و مددگار نہیں ہیں۔\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvi{اے ہمارے پروردگار! ہمارے گناہوں کو بخش دے اور ہماری برائیاں مٹا اور دور فرما اور نیکوکاروں کے ساتھ ہمارا خاتمہ فرما۔\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvii{پروردگارا! تو نے ہم سے اپنے رسولوں کی زبانی جو وعدہ کیا ہے وہ ہمیں عطا فرما قیامت کے دن ہم کو رسوا نہ فرما تو کبھی وعدہ خلافی نہیں کرتا۔\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@cdlxxxviii{سو ان کے پروردگار نے ان کی دعا و پکار کو قبول کر لیا (اور فرمایا) میں کسی عمل کرنے والے کے عمل کو خواہ مرد ہو یا عورت کبھی ضائع نہیں کرتا۔ تم سب ایک دوسرے کے ہم جنس ہی تو ہو۔ سو جن لوگوں نے ہجرت کی اور اپنے گھروں سے نکالے گئے۔ اور میری راہ میں انہیں ایذائیں دی گئیں۔ اور (دین کی خاطر) لڑے اور مارے گئے، تو میں ان کی برائیاں مٹا دوں گا اور ان کو ایسے بہشتوں میں داخل کروں گا جن کے نیچے نہریں بہتی ہوں گی۔ یہ ہے اللہ کے ہاں ان کی جزا۔ اور اللہ کے پاس بہترین ثواب و جزاء ہے۔\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cdlxxxix{(اے رسول) کافروں کا مختلف شہروں میں چلنا پھرنا (اور دندناتے پھرنا) تمہیں ہرگز دھوکے میں نہ ڈال دے۔\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cdxc{یہ صرف چند روزہ فائدہ (بہار) ہے۔ پھر ان کا ٹھکانہ دوزخ ہے اور وہ کیسی بُری آرام گاہ ہے۔\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@cdxci{مگر وہ لوگ جنہوں نے تقویٰ اختیار کیا (واجبات ادا کئے اور محرمات سے اجتناب کیا) ان کے لیے ایسے بہشت ہیں جن کے نیچے نہریں جاری ہیں وہ ان میں ہمیشہ رہیں گے یہ اللہ کی طرف سے ان کی مہمان نوازی ہوگی اور جو کچھ اس کے پاس ہے وہ نیکوکاروں کے لیے بہت اچھا ہے۔\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@cdxcii{اور یقیناً اہل کتاب میں سے کچھ ایسے ہیں جو اللہ پر اور ان باتوں پر جو ہماری طرف اور جو ان کی طرف اتاری گئی ہیں پر ایمان رکھتے ہیں اللہ کے سامنے (نیازمندی سے) جھکے ہوئے ہیں اور آیاتِ الٰہیہ کو تھوڑی قیمت پر فروخت بھی نہیں کرتے یہ وہ ہیں جن کا اجر اپنے پروردگار کے پاس ہے بے شک اللہ بہت جلد حساب لینے والا ہے۔\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@cdxciii{اے ایمان والو! صبر و تحمل سے کام لو۔ اور (کفار کے) مقابلہ میں پامردی دکھاؤ۔ اور (خدمت دین کے لیے) کمربستہ رہو۔ تاکہ تم فوز و فلاح پاؤ (اور دنیا و آخرت میں کامیاب ہو جاؤ)۔\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@cdxciv{\basmalahur (اے انسانو!) اپنے اس پروردگار سے ڈرو۔ جس نے تمہیں ایک متنفس سے پیدا کیا اور اس کا جوڑا بھی اسی سے (اس کی جنس سے) پیدا کیا اور پھر انہی دونوں سے بہت سے مردوں اور عورتوں کو پھیلا دیا۔ اللہ سے ڈرو جس کا واسطہ دے کر ایک دوسرے سے سوال کرتے ہو۔ اور رشتہ قرابت کے بارے میں بھی ڈرو۔ بے شک اللہ تعالیٰ تم پر حاضر و ناظر ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cdxcv{اور یتیموں کے مال ان کے سپرد کرو۔ اور پاک مال کے بدلے ناپاک مال حاصل نہ کرو۔ اور ان کے مالوں کو اپنے مال کے ساتھ ملا کر نہ کھاؤ۔ بے شک یہ بہت بڑا گناہ ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cdxcvi{اور اگر تمہیں یہ خوف ہو کہ تم یتیموں کے ساتھ انصاف نہیں کر سکوگے۔ تو جو عورتیں تمہیں پسند ہوں ان سے نکاح کر لو دو دو، تین تین، چار چار سے اور اگر تمہیں اندیشہ ہو کہ (ان کے ساتھ) عدل نہ کر سکوگے تو پھر ایک ہی (بیوی) کرو۔ یا جو تمہاری ملکیت میں ہوں (ان پر اکتفا کرو) یہ زیادہ قریب ہے اس کے کہ بے انصافی نہ کرو۔ (ایک ہی طرف نہ جھک جاؤ)۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cdxcvii{اور عورتوں کے حق مہر خوشدلی سے ادا کرو اور اگر وہ اپنی خوشی سے اس میں سے تمہیں بخش دیں تو تم اسے شوق سے کھا سکتے ہو۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cdxcviii{اور اپنے وہ مال جنہیں اللہ نے تمہاری زندگی کا سامان اور اسے قائم رکھنے کا ذریعہ بنایا ہے ناسمجھ لوگوں کے حوالے نہ کرو۔ ہاں البتہ ان کو (کھانا و طعام) کھلاؤ اور (کپڑا) پہناؤ اور ان سے اچھی گفتگو کرو۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cdxcix{اور یتیموں کی جانچ پڑتال کرتے رہو۔ یہاں تک کہ جب وہ نکاح کی عمر تک پہنچ جائیں اور تم ان میں اہلیت و سمجھداری بھی پاؤ تو پھر ان کے مال ان کے حوالے کر دو۔ اور فضول خرچی سے کام لے کر اور اس جلد بازی میں کہ وہ کہیں بڑے نہ ہو جائیں ان کا مال مت کھاؤ۔ اور جو سرپرست مالدار ہو تو اسے تو بہرحال ان کے مال سے پرہیز ہی کرنا چاہیے۔ اور جو نادار ہو اسے معروف (مناسب) طریقہ سے کھانا چاہیے۔ پھر جب ان کے مال ان کے حوالے کرو۔ تو ان لوگوں کو گواہ بنا لو۔ اور یوں تو حساب کے لیے اللہ ہی کافی ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@d{مردوں کے لیے اس ترکہ سے حصہ ہے جو ماں باپ اور رشتہ دار چھوڑ جائیں۔ اور عورتوں کے لیے بھی حصہ ہے اس ترکہ سے جو ماں باپ اور رشتہ دار چھوڑ جائیں خواہ وہ (ترکہ) تھوڑا ہو یا زیادہ یہ حصہ (خدا کی طرف سے) لازمی مقرر ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@di{اور جب تقسیم کے موقع پر رشتہ دار، یتیم اور مسکین موجود ہوں تو انہیں بھی اس (مال) میں سے کچھ دے دو اور ان سے درست اور مناسب طریقہ سے بات کرو۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dii{اور ترکہ تقسیم کرنے والوں کو ڈرنا چاہیے کہ اگر وہ خود اپنے پیچھے بے بس و کمزور بچے چھوڑ جاتے۔ تو انہیں ان کی کس قدر فکر ہوتی۔ لہٰذا وہ دوسروں کے یتیموں کے بارے میں اللہ سے ڈریں اور بالکل درست اور سیدھی بات کریں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@diii{بے شک جو لوگ ظلم کے ساتھ یتیموں کا مال کھاتے ہیں وہ اپنے پیٹوں میں آگ بھر رہے ہیں اور عنقریب بھڑکتی ہوئی آگ میں داخل ہوں گے (واصل جہنم ہوں گے۔)\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@div{اللہ تمہاری اولاد کے بارے میں تمہیں ہدایت کرتا ہے کہ لڑکے کا حصہ برابر ہے دو لڑکیوں کے اب اگر لڑکیاں ہی وارث ہوں اور ہوں بھی دو سے اوپر تو ان کو دو تہائی ترکہ دیا جائے گا اور ایک لڑکی (وارث) ہو تو اسے آدھا ترکہ دیا جائے گا۔ اور اگر میت صاحب اولاد ہو تو اس کے والدین میں سے ہر ایک کے لئے ترکہ کا چھٹا حصہ ہوگا (اور باقی اولاد کا) اور اگر بے اولاد ہو۔ اور اس کے والدین ہی اس کے وارث ہوں تو اس کی ماں کو تیسرا حصہ ملے گا (باقی ۳/۲ باپ کو ملے گا) اور اگر اس (مرنے والے) کے بھائی (بہن) ہوں تو پھر اس کی ماں کو چھٹا حصہ ملے گا (باقی ۶/۵ بہن بھائیوں کو ملے گا) مگر یہ تقسیم اس وقت ہوگی، جب میت کی وصیت پوری کر دی جائے۔ جو وہ کر گیا ہو اور اس کا قرضہ ادا کر دیا جائے گا جو اس پر ہو۔ تم نہیں جانتے کہ تمہارے ماں باپ یا تمہاری اولاد میں سے نفع رسانی کے لحاظ سے کون تمہارے زیادہ قریب ہے۔ یہ حصے اللہ کی طرف سے مقرر ہیں، یقینا اللہ بڑا جاننے والا اور بڑا حکمت والا ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dv{اور جو ترکہ تمہاری بیویاں چھوڑ جائیں اس میں سے آدھا تمہارے لئے ہوگا اگر ان کی اولاد نہ ہو اور اگر ان کے اولاد ہو تو پھر تمہیں ان کے ترکہ کا چوتھا حصہ ملے گا۔ یہ تقسیم اس وصیت کو پورا کرنے کے بعد ہوگی، جو انہوں نے کی ہو اور اس قرضہ کی ادائیگی کے بعد جو ان کے ذمہ ہو۔ اور وہ (بیویاں) تمہارے ترکہ میں سے چوتھے حصہ کی حقدار ہوں گی۔ اگر تمہاری اولاد نہ ہو۔ اور اگر تمہارے اولاد ہو تو پھر ان کا آٹھواں حصہ ہوگا اور (یہ تقسیم) اس وصیت کو پورا کرنے کے بعد ہوگی جو تم نے کی ہو اور اس قرض کو ادا کرنے کے بعد جو تم نے چھوڑا ہو۔ اور اگر میت (جس کی وراثت تقسیم کی جانے والی ہے) کلالہ ہو یعنی مرد ہو یا عورت بے اولاد ہو اور اس کے ماں باپ نہ ہوں۔ مگر بھائی بہن ہوں تو اگر اس کا صرف ایک بھائی یا ایک بہن موجود ہو تو بھائی یا بہن کو چھٹا حصہ ملے گا۔ اور اگر بھائی بہن ایک سے زیادہ ہوں تو پھر وہ کل ترکہ کی ایک تہائی میں برابر کے شریک ہوں گے۔ مگر (یہ تقسیم) اس وصیت کو پورا کرنے اور قرضہ کے ادا کرنے کے بعد ہوگی جو کی گئی (جبکہ وصیت کرنے والا وارثوں کو) ضرر پہنچانے کے درپے نہ ہو۔ یہ اللہ کی طرف سے لازمی ہدایت ہے، اور اللہ بڑے علم و حلم والا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dvi{یہ اللہ کی مقرر کردہ حدیں ہیں جو خدا اور رسول کی اطاعت کرے گا اللہ اسے ان بہشتوں میں داخل کرے گا۔ جن کے نیچے سے نہریں جاری ہوں گی۔ جن میں وہ ہمیشہ ہمیشہ رہیں گے اور یہ بہت بڑی کامیابی ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dvii{اور جو اللہ اور اس کے رسول کی نافرمانی کرے گا اور اس کی مقرر کردہ حدوں سے تجاوز کرے گا۔ تو اللہ اسے آتش دوزخ میں داخل کرے گا۔ جس میں وہ ہمیشہ رہے گا۔ اور اس کے لیے ذلیل کرنے والا عذاب ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dviii{اور جو تمہاری عورتوں میں سے بدکاری کریں تو ان کی بدکاری پر اپنے میں سے چار آدمیوں کی گواہی لو۔ اور اگر وہ گواہی دے دیں تو انہیں گھروں میں بند کر دو یہاں تک کہ انہیں موت آجائے یا اللہ ان کے لیے کوئی اور راستہ مقرر کرے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dix{اور تم میں سے جو دو شخص (مرد و عورت) بدکاری کا ارتکاب کریں تو ان کو اذیت پہنچاؤ۔ پھر اگر وہ توبہ کر لیں اور اپنی اصلاح کرلیں۔ تو انہیں چھوڑ دو بے شک اللہ بہت توبہ قبول کرنے والا اور بہت رحم کرنے والا ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dx{توبہ قبول کرنے کا حق اللہ کے ذمہ صرف انہی لوگوں کا ہے جو جہالت (نادانی) کی وجہ سے کوئی برائی کرتے ہیں پھر جلدی توبہ کر لیتے ہیں یہ ہیں وہ لوگ جن کی توبہ خدا قبول کرتا ہے۔ اور اللہ بڑا جاننے والا اور بڑی حکمت والا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dxi{ان لوگوں کی توبہ (قبول) نہیں ہے۔ جو (زندگی بھر) برائیاں کرتے رہتے ہیں، یہاں تک کہ جب ان میں سے کسی کی موت کا وقت آجاتا ہے، تو وہ کہتا ہے، اس وقت میں توبہ کرتا ہوں۔ اور نہ ہی ان کے لیے توبہ ہے۔ جو کفر کی حالت میں مرتے ہیں۔ یہ وہ ہیں جن کے لیے ہم نے دردناک عذاب مہیا کر رکھا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dxii{اے ایمان والو! تمہارے لئے حلال نہیں ہے۔ کہ تم زبردستی عورتوں کے وارث بن جاؤ۔ اور نہ یہ جائز ہے۔ کہ ان پر سختی کرو اور روکے رکھو تاکہ جو کچھ تم نے (جہیز وغیرہ) انہیں دیا ہے اس میں سے کچھ حصہ لے اڑو مگر یہ کہ وہ صریح بدکاری کا ارتکاب کریں (کہ اس صورت میں سختی جائز ہے) اور عورتوں کے ساتھ عمدہ طریقہ سے زندگی گزارو۔ اور اگر تم انہیں ناپسند کرتے ہو تو ہو سکتا ہے کہ ایک چیز تمہیں پسند نہ ہو۔ مگر اللہ نے اس میں بہت کچھ بھلائی رکھ دی ہو۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dxiii{اور اگر تم ایک بیوی کو بدل کر اس کی جگہ دوسری لانا چاہو اور تم ان میں سے ایک کو (جسے فارغ کرنا چاہتے ہو) بہت سا مال دے چکے ہو۔ تو اس میں سے کچھ بھی واپس نہ لو کیا تم جھوٹا الزام لگا کر اور صریح گناہ کرکے (واپس) لینا چاہتے ہو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dxiv{اور بھلا تم وہ (مال) کیسے واپس لے سکتے ہو۔ جبکہ تم (مقاربت کرکے) ایک دوسرے سے لطف اندوز ہو چکے ہو؟ اور وہ تم سے پختہ عہد و پیمان لی چکی ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dxv{جن عورتوں سے تمہارے باپ دادا نکاح کر چکے ہوں۔ ان سے شادی (نکاح) نہ کرو۔ سوا اس کے جو پہلے ہو چکا۔ بے شک یہ کھلی بے حیائی اور (خدا کی) ناراضی کی بات ہے اور بہت برا طریقہ ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dxvi{تم پر حرام کر دی گئی ہیں تمہاری مائیں، تمہاری بیٹیاں، تمہاری بہنیں، تمہاری پھوپھیاں، تمہاری خالائیں، بھتیجیاں، بھانجیاں اور تمہاری وہ مائیں جنہوں نے تمہیں دودھ پلایا ہے۔ اور تمہاری رضاعی (دودھ شریک) بہنیں اور تمہاری بیویوں کی مائیں (خوشدامنیں) اور تمہاری ان بیویوں کی جن سے تم نے مباشرت کی ہے وہ لڑکیاں جو تمہاری گودوں میں پرورش پا رہی ہیں اور اگر صرف نکاح ہوا ہے مگر مباشرت نہیں ہوئی ہے۔ تو پھر (ان کی لڑکیوں سے نکاح کرنے میں) کوئی مضائقہ نہیں ہے۔ اور تمہارے صلبی بیٹوں کی بیویاں (بہوؤیں) اور یہ بھی حرام قرار دیا گیا کہ دو بہنوں کو ایک نکاح میں اکھٹا کرو۔ مگر جو پہلے ہو چکا ہے۔ بے شک اللہ بڑا بخشنے والا اور بڑا رحم کرنے والا ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dxvii{اور وہ عورتیں بھی تم پر حرام ہیں، جو شوہردار ہوں۔ مگر وہ ایسی عورتیں جو (شرعی جہاد میں) تمہاری ملکیت میں آئیں۔ یہ آئین ہے، اللہ کا جو تم پر لازم ہے۔ اور ان کے علاوہ جو عورتیں ہیں وہ تمہارے لئے حلال ہیں کہ اپنے مال (حق مہر) کے عوض ان سے شادی کرلو۔ بدکاری سے بچنے اور پاکدامنی کو قائم رکھنے کے لیے اور ان عورتوں میں سے جن سے تم متعہ کرو۔ تو ان کی مقررہ اجرتیں ادا کر دو۔ اور اگر زرِ مہر مقرر کرنے کے بعد تم آپس میں (کم و بیش پر) راضی ہو جاؤ تو اس میں کوئی حرج نہیں ہے۔ بے شک اللہ بہت جاننے والا اور بڑی رحمت والا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dxviii{اور تم میں سے جو شخص مالی حیثیت سے اس کی قدرت نہ رکھتا ہو کہ وہ (خاندانی) مسلمان آزاد عورتوں سے نکاح کر سکے۔ تو وہ ان مسلمان لونڈیوں سے (نکاح کرلے) جو تمہاری ملکیت میں ہوں اور اللہ تمہارے ایمان کو خوب جانتا ہے تم (اسلام کی حیثیت سے) سب ایک دوسرے سے ہو۔ پس ان (لونڈیوں) کے مالکوں کی اجازت سے نکاح کرو۔ اور بھلائی کے ساتھ ان کے حق مہر ادا کرو۔ تاکہ وہ (قید نکاح میں آکر) پاکدامن رہیں۔ اور شہوت رانی نہ کرتی پھریں۔ اور نہ ہی چوری چھپے آشنا بناتی پھریں۔ سو جب وہ قید نکاح میں محفوظ ہو جائیں تو اگر اب بدکاری کا ارتکاب کریں تو ان کے لئے آزاد عورتوں کی نصف سزا ہوگی۔ یہ رعایت (کہ خاندانی مسلمان آزاد عورت سے نکاح کرنے کی قدرت نہ ہو تو کنیز سے نکاح کرنے کا جواز) اس شخص کے لئے ہے جسے (نکاح نہ کرنے سے) بدکاری میں مبتلا ہونے کا اندیشہ ہو اور اگر ضبط سے کام لو تو یہ تمہارے لیے بہتر ہے اور اللہ بڑا بخشنے والا اور بڑا رحم کرنے والا ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dxix{اللہ چاہتا ہے کہ (تم سے اپنے احکام) کھول کر بیان کر دے اور تمہیں ان لوگوں کے طریقوں پر چلائے جو تم سے پہلے گزرے ہیں اور تمہاری توبہ قبول کرے اللہ بڑا جاننے والا اور بڑی حکمت والا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dxx{اور اللہ تو چاہتا ہے کہ تمہاری توبہ قبول کرے مگر وہ لوگ جو خواہشات نفس کی پیروی کرتے ہیں وہ چاہتے ہیں کہ تم (راہ راست سے بھٹک کر) بہت دور نکل جاؤ۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dxxi{اللہ چاہتا ہے کہ تمہارا بوجھ ہلکا کرے (کیونکہ) انسان کمزور پیدا کیا گیا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dxxii{اے ایمان والو! آپس میں ایک دوسرے کے مال باطل طریقہ سے نہ کھاؤ۔ مگر یہ کہ تمہاری باہمی رضامندی سے تجارتی معاملہ ہو۔ اور اپنے آپ کو قتل نہ کرو۔ بے شک اللہ تم پر بڑا مہربان ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dxxiii{اور جو شخص ظلم و تعدی سے ایسا کرے گا۔ تو ہم عنقریب اسے آتش (دوزخ) میں ڈالیں گے۔ اور یہ بات اللہ کے لیے بالکل آسان ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dxxiv{اگر تم ان بڑے (گناہوں) سے بچتے رہو، جن سے تمہیں منع کیا گیا ہے۔ تو ہم تمہاری (چھوٹی) برائیاں دور کر دیں گے (معاف کر دیں گے) اور تمہیں ایک معزز (جنت) میں داخل کریں گے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dxxv{اور اللہ نے تم سے بعض کو دوسرے بعض پر جو زیادتی (بڑائی) عطا کی ہے۔ تم اس کی تمنا نہ کرو۔ مردوں کا حصہ ہے (مال و اعمال وغیرہ سے) جو انہوں نے کمایا اور عورتوں کا حصہ ہے جو کچھ انہوں نے کمایا۔ اور اللہ سے اس کے فضل (مال اور اعمال وغیرہ کا) سوال کرو بے شک اللہ ہر چیز کا جاننے والا ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dxxvi{اور ہم نے ہر شخص کے لئے وارث مقرر کر دیئے ہیں، جو کچھ ماں، باپ اور قریب ترین رشتہ دار اور جن سے تم نے عہدوپیمان کر رکھا ہے۔ چھوڑ جائیں انہیں (وارثوں کو) ان کا حصہ دو۔ بے شک اللہ ہر چیز پر گواہ (مطلع) ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dxxvii{مرد عورتوں کے محافظ و منتظم (حاکم) ہیں (ایک) اس لئے کہ اللہ نے بعض (مردوں) کو بعض (عورتوں) پر فضیلت دی ہے اور (دوسرے) اس لئے کہ مرد (عورتوں پر) اپنے مال سے خرچ کرتے ہیں۔ سو نیک عورتیں تو اطاعت گزار ہوتی ہیں اور جس طرح اللہ نے (شوہروں کے ذریعہ) ان کی حفاظت کی ہے۔ اسی طرح پیٹھ پیچھے (شوہروں کے مال اور اپنی ناموس کی) حفاظت کرنے والی ہوتی ہیں اور وہ عورتیں جن کی سرکشی کا تمہیں اندیشہ ہو انہیں (نرمی سے) سمجھاؤ (بعد ازاں) انہیں ان کی خواب گاہوں میں چھوڑ دو اور (آخرکار)۔ انہیں مارو۔ پھر اگر وہ تمہاری اطاعت کرنے لگیں تو پھر ان کے خلاف کوئی اور اقدام کرنے کے راستے تلاش نہ کرو۔ یقینا اللہ (اپنی کبریائی میں) سب سے بالا اور بڑا ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dxxviii{اور اگر تمہیں دونوں (میاں بیوی) کی ناچاقی کا خوف دامنگیر ہو تو ایک ثالث مرد کے کنبے سے اور ایک ثالث عورت کے کنبے سے مقرر کرو۔ اگر دونوں اصلاح کا ارادہ کریں گے تو خدا ان دونوں میں موافقت پیدا کر دے گا۔ بے شک اللہ بڑا جاننے والا بڑا باخبر ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dxxix{اور اللہ کی عبادت کرو اور کسی چیز کو اس کا شریک نہ بناؤ۔ اور ماں باپ کے ساتھ نیکی کرو اور رشتہ داروں، یتیموں، مسکینوں اور قریبی ہمسایہ اور اجنبی ہمسایہ اور پہلو میں بیٹھنے والے رفیق اور مسافر، اپنے مملوکہ (غلاموں کنیزوں) کے ساتھ اچھا برتاؤ کرو۔ بے شک اللہ مغرور و متکبر اور شیخی بگھارنے والوں کو دوست نہیں رکھتا۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dxxx{جو خود کنجوسی سے کام لیتے ہیں اور دوسروں کو بھی کنجوسی کرنے کا حکم (ترغیب) دیتے ہیں۔ اور جو کچھ اللہ نے ان کو اپنے فضل و کرم سے دیا ہے وہ اسے چھپاتے ہیں ہم نے ایسے ناشکروں کے لئے رسوا کن عذاب مہیا کر رکھا ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dxxxi{اور جو اپنے مال صرف لوگوں کو دکھانے کے لیے خرچ کرتے ہیں دراصل وہ خدا اور روزِ جزا پر ایمان و یقین نہیں رکھتے (اللہ ایسے لوگوں کو دوست نہیں رکھتا)۔ اور جس کا مصاحب شیطان ہو۔ وہ اس کا بہت بُرا مصاحب ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dxxxii{اور ان کا کیا نقصان ہوتا اگر وہ اللہ اور روزِ آخرت پر ایمان لاتے اور جو کچھ اللہ نے انہیں عطا کیا ہے اس میں سے کچھ (راہِ خدا میں) خرچ کرتے اور اللہ ان سے خوب واقف ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dxxxiii{بے شک اللہ ذرہ برابر (کسی پر) ظلم نہیں کرتا اور اگر وہ (ذرہ برابر) نیکی ہو تو اسے دوگنا (بلکہ چوگنا) کر دیتا ہے اور اپنی طرف سے بہت بڑا اجر عطا فرماتا ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dxxxiv{اس وقت کیا حال ہوگا جب ہم ہر امت میں سے ایک گواہ لائیں گے اور آپ کو ان سب پر گواہ بنا کر لائیں گے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dxxxv{اس دن کافر اور پیغمبر کے نافرمان تمنا کریں گے کہ کاش وہ زمین کے برابر کر دیئے جاتے۔ اور وہ اللہ سے کوئی بات چھپا نہ سکیں گے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dxxxvi{اے ایمان والو۔ نماز کے قریب مت جاؤ جبکہ نشہ کی حالت میں ہو یہاں تک کہ (نشہ اتر جائے اور) تمہیں معلوم ہو کہ تم کیا کہہ رہے ہو؟ اور نہ ہی جنابت کی حالت میں (نماز کے قریب جاؤ) یہاں تک کہ غسل کر لو۔ الا یہ کہ تم راستے سے گزر رہے ہو (سفر میں ہو)۔ اور اگر تم بیمار ہو یا سفر میں ہو یا تم سے کوئی بیت الخلاء سے ہو کے آئے۔ یا تم نے عورتوں سے مباشرت کی ہو اور تمہیں پانی نہ ملے تو پھر پاک مٹی سے تیمم کر لو۔ کہ (اس سے) اپنے چہروں اور ہاتھوں کے کچھ حصہ پر مسح کرلو۔ بے شک اللہ بڑا معاف کرنے والا ہے، بڑا بخشنے والا ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dxxxvii{کیا تم نے ان لوگوں کی طرف نہیں دیکھا جن کو کتاب (الٰہی) کا کچھ حصہ دیا گیا کہ وہ گمراہی خرید رہے ہیں اور چاہتے ہیں کہ تم بھی سیدھے راستے سے بہک جاؤ۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dxxxviii{اور اللہ تمہارے دشمنوں کو خوب جانتا ہے اور اللہ تمہاری کارسازی و سرپرستی اور مددگاری کے لیے کافی ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dxxxix{یہودیوں میں سے کچھ ایسے بھی ہیں جو کلموں کو ان کے موقع و محل سے پھیر دیتے ہیں اور زبانوں کو توڑ موڑ کر اور دین پر اعتراض کرتے ہوئے کہتے ہیں کہ ’’سمعنا و عصینا‘‘ (ہم نے سنا مگر مانا نہیں) اور ’’اسمع غیر مسمع‘‘ (اور سنو تمہاری بات نہ سنی جائے) اور ’’راعنا‘‘ (ہمارا لحاظ کرو)۔ اگر وہ اس کی بجائے یوں کہتے ’’سمعنا و اطعنا‘‘ (ہم نے سنا اور مانا) اور ‘‘اسمع‘‘ (اور سنیئے) ‘‘وانظرنا‘‘ (اور ہماری طرف دیکھئے) تو یہ ان کے لئے بہتر اور زیادہ درست ہوتا۔ مگر اللہ نے کفر کی وجہ سے ان پر لعنت کی ہے (اپنی رحمت سے دور کر دیا ہے) اس لئے وہ بہت کم ایمان لائیں گے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dxl{اے اہل کتاب اس (قرآن) پر (ایمان لاؤ) اس سے پہلے کہ ہم کچھ چہروں کو بگاڑ دیں اور انہیں ان کی پیٹھ کی طرف پھیر دیں یا ان پر اس طرح لعنت کریں جس طرح ہم نے ہفتہ کے دن والوں پر لعنت کی تھی اور اللہ کا حکم نافذ ہوکر رہتا ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dxli{یقینا اللہ اس بات کو نہیں بخشتا کہ اس کے ساتھ شرک کیا جائے اور اس کے سوا (ہر گناہ) جس کے لئے چاہتا ہے بخش دیتا ہے اور جس نے کسی کو اللہ کا شریک ٹھہرایا اس نے بہت بڑے گناہ کے ساتھ بہتان باندھا۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dxlii{کیا تم نے ان لوگوں کو نہیں دیکھا جو اپنی پاکیزگی بیان کرتے ہیں (اور خود اپنی تعریف کرتے ہیں) حالانکہ اللہ جسے چاہتا ہے پاکیزگی عطا کرتا ہے (جس کی چاہتا ہے تعریف کرتا ہے)۔ اور ان پر سوت برابر (ذرہ برابر) ظلم نہیں کیا جائے گا۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dxliii{دیکھو کہ یہ کس طرح خدا پر جھوٹی تہمت لگاتے ہیں۔ اور ان کے گنہگار ہونے کے لیے یہی کھلا ہوا گناہ کافی ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dxliv{کیا تم نے ان لوگوں کو نہیں دیکھا جن کو کتاب (الٰہی) سے کچھ حصہ دیا گیا ہے وہ جبت (بت) اور طاغوت (شیطان) پر ایمان رکھتے ہیں (انہیں مانتے ہیں) اور کافروں کے متعلق کہتے ہیں کہ وہ ایمان لانے والوں سے زیادہ ہدایت یافتہ ہیں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dxlv{یہی وہ لوگ ہیں جن پر اللہ نے لعنت کی ہے اور جس پر اللہ لعنت کر دے تم اس کا ہرگز کوئی یار و مددگار نہیں پاؤگے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dxlvi{کیا ان کا سلطنت میں کوئی حصہ ہے؟ اگر ایسا ہوتا تو یہ لوگوں کو تل بھر بھی نہ دیتے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dxlvii{یا پھر وہ لوگوں پر اس لئے حسد کرتے ہیں کہ اللہ نے ان کو اپنے فضل و کرم سے نوازا ہے۔ (اگر یہ بات ہے) تو ہم نے آلِ ابراہیم (ع) کو کتاب و حکمت عطا کی ہے اور ان کو بہت بڑی سلطنت عطا کی۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dxlviii{پھر ان میں کچھ تو اس پر ایمان لائے اور کچھ روگردان ہوگئے اور (ایسوں کے لئے) دوزخ کی بھڑکتی ہوئی آگ کافی ہے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dxlix{بے شک جن لوگوں نے ہماری آیتوں کا انکار کیا ہم عنقریب انہیں (دوزخ) کی آگ میں جھونکیں گے۔ جب ان کی (پہلی) کھا لیں پک (جل) جائیں گی تو ہم ان کی کھالیں اور کھالوں سے بدل دیں گے تاکہ وہ عذاب کا مزہ چکھتے رہیں بے شک اللہ زبردست ہے اور بڑی حکمت والا ہے ۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dl{اور جو لوگ ایمان لائے اور نیک عمل کئے ہم عنقریب ان کو ان بہشتوں میں داخل کریں گے جن کے نیچے سے نہریں جاری ہوں گی اور وہ ان میں ہمیشہ ہمیشہ رہیں گے۔ ان کے لئے وہاں پاک و پاکیزہ بیویاں ہوں گی اور ہم انہیں (اپنی رحمت) کے گنجان سایہ (گھنی چھاؤں) میں اتاریں گے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dli{(اے مسلمانو) اللہ تمہیں حکم دیتا ہے کہ امانتیں اہل امانت کو ادا کرو۔ اور جب لوگوں کے درمیان فیصلہ کرو تو عدل کے ساتھ کرو۔ بے شک اللہ تمہیں بہت ہی اچھی بات کی نصیحت کرتا ہے۔ بے شک اللہ بڑا سننے والا، بڑا دیکھنے والا ہے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dlii{اے ایمان والو اطاعت کرو اللہ کی اور اطاعت کرو رسول کی اور ان لوگوں کی جو تم میں سے صاحبانِ امر ہیں (فرمان روائی کے حقدار ہیں)۔ پھر اگر تمہارے درمیان کسی بات میں نزاع (یا جھگڑا) ہو جائے تو اسے اللہ اور رسول کی طرف پلٹاؤ اگر تم اللہ اور آخرت کے روز پر ایمان رکھتے ہو تو یہ طریقہ کار تمہارے لئے اچھا ہے اور انجام کے اعتبار سے عمدہ ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dliii{کیا تم نے ان لوگوں کو نہیں دیکھا جن کا دعویٰ ہے کہ وہ اس پر ایمان لائے جو آپ پر نازل کیا گیا ہے اور اس پر جو آپ سے پہلے نازل کیا گیا۔ (اس کے باوجود) وہ چاہتے ہیں کہ طاغوت کی طرف رجوع کریں۔ (غیر شرعی عدالت میں مقدمہ لے جائیں) حالانکہ انہیں اس کا انکار کرنے کا حکم دیا گیا ہے۔ شیطان چاہتا ہے کہ انہیں بھٹکا کر گمراہی میں بہت دور لے جائے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dliv{اور جب ان سے کہا جائے کہ آؤ اس کی طرف جو اللہ نے اتارا ہے (قرآن) اور آؤ رسول (سنت) کی طرف تو آپ منافقین کو دیکھیں گے کہ وہ آپ سے بڑی سخت روگردانی کرتے ہیں۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dlv{پھر کیسی گزرتی ہے جب ان پر کوئی مصیبت آپڑتی ہے اپنے ہاتھوں کی لائی ہوئی (ان کے کرتوتوں کی وجہ سے) تو آپ کی خدمت میں اللہ کے نام کی قسمیں کھاتے ہوئے آتے ہیں اور کہتے ہیں کہ ہمارا مقصد تو بھلائی اور (فریقین میں) مصالحت کرانا تھا۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dlvi{یہ وہ ہیں کہ اللہ خوب جانتا ہے کہ جو کچھ ان کے دلوں میں ہے آپ ان سے چشم پوشی کریں اور انہیں نصیحت کریں اور ان سے مؤثر باتیں کریں۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dlvii{اور ہم نے کوئی رسول نہیں بھیجا مگر اس لئے کہ اللہ کے حکم سے اس کی اطاعت کی جائے کاش جب یہ لوگ (گناہ کرکے) اپنی جانوں پر ظلم کر بیٹھے تھے اگر آپ کے پاس آجاتے اور اللہ سے بخشش طلب کرتے اور رسول بھی ان کے لئے دعائے مغفرت کرتے تو یقینا اللہ کو بڑا توبہ قبول کرنے والا اور بڑا مہربان پاتے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dlviii{نہیں۔ آپ کے پروردگار کی قسم! یہ لوگ اس وقت تک مؤمن نہیں ہو سکتے۔ جب تک اپنے تمام باہمی جھگڑوں میں آپ کو حَکَم نہ مانیں۔ اور پھر آپ جو فیصلہ کریں (زبان سے اعتراض کرنا تو کجا) اپنے دلوں میں بھی تنگی محسوس نہ کریں اور اس طرح تسلیم کریں جس طرح تسلیم کرنے کا حق ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dlix{اور اگر ہم ان پر یہ فرض کر دیتے کہ اپنے آپ کو قتل کرو۔ یا اپنے گھروں سے نکل جاؤ۔ تو اس پر معدودے چند لوگوں کے سوا اور کوئی عمل نہ کرتا اور اگر یہ اس نصیحت پر عمل کرتے، جو ان کو کی جاتی ہے، تو یہ ان کے حق میں بہتر ہوتا۔ اور ثابت قدمی کا زیادہ موجب ہوتا۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dlx{اور اس وقت ہم انہیں اپنی طرف سے بڑا اجر دیتے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dlxi{اور انہیں سیدھے راستہ پر چلنے کی خاص توفیق عطا کرتے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dlxii{جو اللہ اور رسول(ص) کی اطاعت کرے گا۔ تو ایسے لوگ ان کے ساتھ ہوں گے جن پر اللہ نے خاص انعام کیا ہے۔ یعنی انبیاء، صدیقین، شہداء اور صالحین اور یہ بہت اچھے رفیق ہیں۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dlxiii{یہ اللہ کا خاص فضل ہے اور اللہ کا علم کافی ہے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dlxiv{اے ایمان والو! اپنی حفاظت کا سامان مکمل رکھو۔ ہر وقت تیار رہو پھر (موقع کی مناسبت سے) دستہ دستہ ہوکر نکلو یا اکھٹے ہوکر نکلو۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dlxv{اور تم میں سے کچھ ایسے بھی ہیں جو پیچھے رکا رہنا پسند کرتے ہیں پس اگر تم پر کوئی مصیبت نازل ہو تو کہتا ہے کہ یہ مجھ پر اللہ کا احسان تھا کہ ان کے ساتھ حاضر نہ تھا۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dlxvi{اور اگر تم پر اللہ کا فضل و کرم ہو (فتح ہو اور مالِ غنیمت مل جائے) تو کہتا ہے جیسے اس کے اور تمہارے درمیان کبھی محبت اور دوستی تھی ہی نہیں کہ کاش میں بھی ان کے ساتھ ہوتا تو بڑی کامیابی حاصل کرتا۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dlxvii{اللہ کی راہ میں ان لوگوں کو جنگ کرنا چاہیے جنہوں نے دنیا کی پست زندگی آخرت کے عوض فروخت کر دی ہے جو اللہ کی راہ میں جہاد کرے، پھر مارا جائے یا غالب آجائے تو ہم ضرور اسے اجر عظیم عطا کریں گے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dlxviii{آخر تمہیں کیا ہوگیا ہے؟ کہ تم جنگ نہیں کرتے راہ خدا میں اور ان کمزور مردوں، عورتوں اور بچوں کی خاطر جو فریاد کر رہے ہیں۔ پروردگار! ہمیں اس بستی سے نکال دے۔ جس کے باشندے ظالم ہیں اور اپنی طرف سے ہمارے لئے کوئی سرپرست اور حامی و مددگار بنا۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dlxix{جو لوگ ایمان لائے ہیں وہ تو اللہ کی راہ میں جنگ کرتے ہیں اور جو کافر ہیں وہ شیطان کی راہ میں جنگ کرتے ہیں۔ پس تم شیطان کے حوالی، موالی (حامیوں) سے جنگ کرو۔ یقینا شیطان کا مکر و فریب نہایت کمزور ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dlxx{کیا تم نے ان لوگوں کو نہیں دیکھا جن سے کہا گیا تھا کہ اپنے ہاتھ روکے رہو اور نماز پڑھو اور زکوٰۃ ادا کرو۔ پھر جب ان پر جدال و قتال فرض کر دیا گیا۔ تو ان میں سے ایک گروہ انسانوں سے اس طرح ڈرنے لگا، جیسے اللہ سے ڈرنا چاہیے یا اس سے بھی زیادہ۔ اور کہنے لگا پروردگار! تو نے کیوں (اتنا جلدی) ہم پر جہاد فرض کر دیا۔ اور تھوڑی مدت تک ہمیں مہلت کیوں نہ دی؟ (اے نبی) کہہ دیجیے کہ دنیا کا سامان بہت تھوڑا ہے اور جو متقی و پرہیزگار ہے اس کے لئے آخرت بہت بہتر ہے اور تم پر کھجور کی گھٹلی کے ریشہ برابر (ذرہ بھی) ظلم نہیں کیا جائے گا۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dlxxi{تم جہاں کہیں بھی ہوگے، موت تمہیں آئے گی اگرچہ تم مضبوط قلعوں میں کیوں نہ ہو اور جب انہیں بھلائی پہنچتی ہے۔ تو کہتے ہیں کہ یہ اللہ کی طرف سے ہے اور جب کوئی برائی اور تکلیف پہنچتی ہے تو کہتے ہیں کہ یہ آپ کی وجہ سے ہے۔ کہہ دیجیے کہ یہ سب کچھ اللہ ہی کی طرف سے ہے آخر ان لوگوں کو کیا ہوگیا ہے کہ کوئی بات سمجھتے ہی نہیں ہیں؟ ۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dlxxii{آپ کو جو بھلائی پہنچتی ہے۔ وہ تو اللہ کی طرف سے ہے اور آپ کو جو تکلیف پہنچتی ہے۔ وہ تمہاری وجہ سے ہے اور ہم نے آپ کو تمام لوگوں کی طرف رسول بنا کر بھیجا ہے اور گواہی کے لیے اللہ کافی ہے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dlxxiii{اور جس نے رسول کی اطاعت کی، اس نے اللہ کی اطاعت کی، اور جس نے روگردانی کی، تو ہم نے آپ کو ان پر نگران و پاسبان بنا کر نہیں بھیجا۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dlxxiv{اور وہ زبان سے اطاعت و فرمانبرداری کی لفظ کہتے ہیں اور جب آپ کے پاس سے باہر نکلتے ہیں۔ تو ان میں سے ایک گروہ آپ کے فرمان (یا اپنے قول و قرار کے) برعکس رات بھر تدبیریں کرتا ہے جو کچھ وہ رات کے وقت کرتے ہیں۔ اللہ وہ سب کچھ (ان کے صحیفۂ اعمال میں) لکھ رہا ہے۔ آپ ان کی طرف توجہ نہ کریں۔ اور اللہ پر توکل و بھروسہ کریں، کارسازی کے لیے اللہ کافی ہے۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dlxxv{آخر یہ لوگ قرآن میں غور و فکر کیوں نہیں کرتے۔ اگر یہ اللہ کے علاوہ کسی اور کی طرف سے ہوتا تو اس میں بہت کچھ اختلاف پاتے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dlxxvi{اور جب ان کے پاس امن یا خوف کی کوئی بات پہنچتی ہے تو اسے پھیلا دیتے ہیں حالانکہ اگر وہ اسے رسول اور اولی الامر کی طرف لوٹاتے تو (حقیقت کو) وہ لوگ جان لیتے جو استنباط کی صلاحیت رکھتے ہیں۔ اور اگر تم پر اللہ کا فضل اور اس کی رحمت نہ ہوتی، تو چند آدمیوں کے سوا باقی شیطان کی پیروی کرنے لگ جاتے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dlxxvii{تو آپ(ص) اللہ کی راہ میں جہاد کریں۔ آپ پر ذمہ داری نہیں ڈالی جاتی۔ سوائے اپنی ذات کے اور اہل ایمان کو (جہاد پر) آمادہ کریں۔ امید ہے کہ اللہ کافروں کا زور روک دے اور اللہ کا زور زبردست اور اس کی سزا بہت سخت ہے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dlxxviii{اور جو اچھی سفارش کرے گا۔ اسے اس میں سے حصہ ملے گا اور جو کوئی بری سفارش کرے گا۔ اسے بھی اس کا حصہ (وزر و بال) ملے گا۔ اور اللہ ہر شی پر قدرت رکھنے والا ہے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dlxxix{اور جب تمہیں سلام کیا جائے (یا کوئی تحفہ پیش کیا جائے) تو اس سے بہتر طریقہ پر جواب دو۔ یا (کم از کم) اسی کو لوٹادو۔ بے شک اللہ ہر چیز کا محاسبہ کرنے والا ہے۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dlxxx{اللہ وہ ہے جس کے سوا کوئی الٰہ نہیں ہے۔ وہ ضرور تمہیں قیامت کے دن اکٹھا کرے گا۔ جس میں کوئی شک نہیں ہے اور اللہ سے بڑھ کر کون بات میں سچا ہے۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dlxxxi{تمہیں کیا ہوگیا ہے کہ تم منافقین کے بارے میں دو گروہ ہوگئے ہو۔ حالانکہ اللہ نے انہیں ان کے کرتوتوں کی وجہ سے (ان کے کفر کی طرف) الٹا پھیر دیا ہے۔ کیا تم چاہتے ہو کہ اسے ہدایت دو جس سے اس کی بدعملی کی وجہ سے خدا نے توفیق ہدایت سلب کر لی ہے۔ اور جس سے اللہ توفیق ہدایت سلب کرے، تم اس کے لیے (ہدایت کا) راستہ نہیں پاؤگے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dlxxxii{وہ چاہتے ہیں کہ تم بھی اسی طرح کفر اختیار کرو جیسے انہوں نے کفر اختیار کیا ہے۔ تاکہ پھر تم سب برابر ہو جاؤ۔ لہٰذا تم انہیں اپنا حامی و سرپرست نہ بناؤ جب تک اللہ کی راہ میں ہجرت نہ کریں اور اگر وہ اس ہجرت کرنے سے روگردانی کریں تو انہیں پکڑو۔ اور جہاں کہیں انہیں پاؤ انہیں قتل کر ڈالو اور ان میں کسی کو اپنا سرپرست اور مددگار نہ بناؤ۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dlxxxiii{سوا ان کے جو ان لوگوں سے جا ملیں جن کے اور تمہارے درمیان (جنگ نہ کرنے کا) معاہدہ ہے یا اس حالت میں تمہارے پاس آئیں کہ ان کے سینے (دل) میں تمہارے ساتھ یا اپنی قوم کے ساتھ جنگ کرنے سے تنگ آچکے ہوں (ایسے منافق قتل کے اس حکم سے مستثنیٰ ہیں) اگر خدا چاہتا تو ان کو تم پر مسلط کر دیتا اور وہ ضرور تم سے لڑتے تو پھر اگر وہ تم سے کنارہ کشی کر لیں اور تمہارے ساتھ جنگ نہ کریں اور صلح کا پیغام بھیجیں تو اللہ نے تمہارے لئے ان کے خلاف کوئی قدم اٹھانے کی کوئی راہ نہیں رکھی ہے۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dlxxxiv{عنقریب تم کچھ ایسے لوگ (منافق) پاؤگے۔ جو چاہتے ہیں کہ تم سے بھی امن میں رہیں اور اپنی قوم سے بھی امن میں رہیں لیکن جب وہ کبھی فتنہ و فساد کی طرف بلائے جاتے ہیں تو اندھے منہ اس میں جا پڑتے ہیں۔ لہٰذا اگر یہ لوگ تم سے کنارہ کشی نہ کریں اور تمہاری طرف صلح و آشتی کا ہاتھ نہ بڑھائیں اور اپنے ہاتھ نہ روکیں تو پھر انہیں پکڑو۔ اور جہاں کہیں انہیں پاؤ۔ قتل کرو۔ یہی وہ لوگ ہیں! جن پر ہم نے تمہیں کھلا غلبہ عطا کیا ہے۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dlxxxv{کسی مسلمان کے لئے روا نہیں ہے کہ وہ کسی مسلمان کو قتل کرے مگر غلطی سے۔ اور جو کوئی کسی مؤمن کو غلطی سے قتل کرے (تو اس کا کفارہ یہ ہے کہ) ایک مؤمن غلام آزاد کیا جائے اور خون بہا اس کے گھر والوں (وارثوں) کو ادا کیا جائے، مگر یہ کہ وہ لوگ خود (خون بہا) معاف کر دیں۔ پھر اگر مقتول تمہاری دشمن قوم سے تعلق رکھتا ہو، مگر وہ خود مسلمان ہو تو پھر (اس کا کفارہ) ایک مؤمن غلام کا آزاد کرنا ہے اور اگر وہ (مقتول) ایسی (غیر مسلم) قوم کا فرد ہو جس کے اور تمہارے درمیان (جنگ نہ کرنے کا) معاہدہ ہے۔ تو (کفارہ میں) ایک خون بہا اس کے وارثوں کے حوالے کیا جائے گا۔ اور ایک مسلمان غلام بھی آزاد کیا جائے گا اور جس کو (غلام) میسر نہ ہو تو وہ مسلسل دو مہینے روزے رکھے گا۔ یہ اللہ کی طرف سے (اس گناہ کی) توبہ مقرر ہے۔ خدا بڑا جاننے والا اور بڑا حکمت والا ہے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dlxxxvi{اور جو کوئی مسلمان کو جان بوجھ کر قتل کرے، اس کی سزا دوزخ ہے۔ جس میں وہ ہمیشہ رہے گا اور اس پر اللہ کا غضب ہوگا۔ اور اللہ اس پر لعنت کرے گا اور اس نے اس کے لیے عذاب عظیم تیار کر رکھا ہے۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dlxxxvii{اے ایمان والو! جب خدا کی راہ میں (جہاد کے لیے) نکلو تو پہلے خوب تحقیق کر لیا کرو۔ اور جو تمہیں سلام کرے تم اسے نہ کہو کہ تو مسلمان نہیں ہے۔ تم دنیاوی زندگی کا سازوسامان حاصل کرنا چاہتے ہو تو اللہ کے پاس بڑی غنیمتیں ہیں۔ اس سے پہلے تم خود ایسے (کافر) ہی تھے۔ پھر اللہ نے تم پر احسان کیا (کہ تم مسلمان ہوگئے) پس خوب تحقیق کر لیا کرو۔ یقینا اللہ اس سے باخبر ہے۔ جو کچھ تم کرتے ہو۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dlxxxviii{مسلمانوں میں سے بلا عذر گھر میں بیٹھے رہنے والے اور راہِ خدا میں مالوں اور اپنی جانوں سے جہاد کرنے والے برابر نہیں ہو سکتے۔ اللہ نے مالوں اور اپنی جانوں سے جہاد کرنے والوں کو درجہ کے اعتبار سے بیٹھ رہنے والوں پر فضیلت دی ہے اور یوں تو اللہ نے ہر ایک سے بھلائی کا وعدہ کیا ہے۔ مگر اس نے جہاد کرنے والوں کو بیٹھ رہنے والوں پر اجر عظیم کے ساتھ فضیلت دی ہے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dlxxxix{یعنی اس کی طرف سے (ان کے لئے) بڑے درجے، بخشش اور رحمت ہے اور اللہ بڑا بخشنے والا بڑا رحم کرنے والا ہے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dxc{بے شک وہ لوگ جو اپنی جانوں پر ظلم کر رہے تھے۔ جب فرشتوں نے ان کی روحوں کو قبض کیا، تو ان سے کہا تم کس حال میں تھے؟ تو انہوں نے کہا کہ ہم زمین میں کمزور و بے بس تھے۔ فرشتوں نے کہا کہ اللہ کی زمین وسیع نہ تھی کہ تم اس میں ہجرت کرتے یہی وہ لوگ ہیں جن کا ٹھکانہ جہنم ہے اور وہ بُری جائے بازگشت ہے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dxci{علاوہ ان کمزور مردوں، عورتوں اور بچوں کے جن کے اختیار میں کوئی تدبیر نہ تھی اور وہ کوئی راستہ نہ نکال سکتے تھے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dxcii{یہی وہ لوگ ہیں جن کو عنقریب خدا معاف کر دے گا کہ وہ بڑا معاف کرنے والا اور بڑا بخشنے والا ہے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dxciii{اور جو کوئی راہِ خدا میں ہجرت کرے گا۔ وہ زمین میں بہت ہجرت گاہ، جائے پناہ اور بڑی کشائش پائے گا۔ اور جو شخص اپنے گھر سے خدا اور رسول(ص) کی طرف ہجرت کے ارادہ سے نکلے پھر اسے موت آجائے، تو اس کا اجر و ثواب اللہ کے ذمہ ہوگیا۔ اور اللہ بڑا بخشنے والا، رحم کرنے والا ہے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dxciv{اور جب تم زمین میں سفر کرو۔ تو اس میں کوئی مضائقہ نہیں ہے (بلکہ واجب ہے کہ) نماز میں قصر کر دو۔ (بالخصوص) جب تمہیں خوف ہو کہ کافر لوگ تمہیں کوئی تکلیف پہنچائیں گے۔ بے شک کافر تمہارے کھلے ہوئے دشمن ہیں۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dxcv{اے رسول(ص) جب آپ(ص) ان (مسلمانوں) میں ہوں اور انہیں نماز (باجماعت) پڑھانے لگیں تو چاہیے کہ ان کا ایک گروہ آپ کے ساتھ کھڑا ہو۔ اور وہ لوگ اپنے ہتھیار لئے رہیں۔ اور جب یہ سجدہ کر چکیں (نماز پڑھ چکیں) تو یہ (پشت پناہی کے لیے) تمہارے پیچھے چلے جائیں اور پھر وہ دوسرا گروہ جس نے ہنوز نماز نہیں پڑھی ہے۔ آجائے اور آپ کے ساتھ نماز پڑھے۔ اور چوکنا رہے اور اپنا اسلحہ لئے رہے، کفار کی تو یہ خواہش ہے کہ تم اپنے ہتھیاروں اور اپنے سازوسامان سے (ذرا) غافل ہو جاؤ اور وہ تم پر یکبارگی ٹوٹ پڑیں۔ اور اگر تمہیں بارش سے تکلیف ہو یا تم بیمار ہو تو کوئی مضائقہ نہیں ہے کہ تم اپنے ہتھیاروں کو رکھ دو۔ ہاں اپنی حفاظت کا خیال رکھو (چوکنا رہو) بے شک اللہ نے کافروں کے لئے رسوا کن عذاب مہیا کر رکھا ہے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dxcvi{پھر جب تم نماز ادا کر چکو تو اللہ کو یاد کرو کھڑے ہوئے، بیٹھے ہوئے، اور اپنے پہلوؤں پر (لیٹے ہوئے) اور جب تمہیں اطمینان ہو جائے تو نماز کو پورے طور پر ادا کرو۔ بے شک نماز اہل ایمان پر پابندی وقت کے ساتھ فرض کی گئی ہے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dxcvii{اس (مخالف) جماعت کی تلاش اور تعاقب میں سستی نہ دکھاؤ۔ اگر اس میں تمہیں تکلیف پہنچتی ہے۔ تو انہیں بھی اسی طرح تکلیف پہنچتی ہے۔ جس طرح تمہیں پہنچتی ہے اور تم اللہ سے اس چیز (ثواب) کے امیدوار ہو جس کے وہ امیدوار نہیں ہیں اور اللہ بڑا جاننے والا، بڑی حکمت والا ہے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dxcviii{بے شک ہم نے (یہ) کتاب حق کے ساتھ آپ پر اتاری ہے۔ تاکہ آپ لوگوں میں اس کے مطابق فیصلہ کریں، جو اللہ نے آپ کو بتا دیا ہے اور آپ خیانت کاروں کے طرفدار نہ بنیں۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dxcix{اور اللہ سے مغفرت طلب کریں، یقینا اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dc{اور جو لوگ اپنی ذات سے خیانت کرتے ہیں۔ آپ ان کی وکالت نہ کریں۔ بے شک اللہ اسے دوست نہیں رکھتا، جو بڑا خیانت کار اور بڑا گنہگار ہے۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dci{یہ لوگ (اپنی حرکات) لوگوں سے تو چھپا سکتے ہیں مگر اللہ سے نہیں چھپا سکتے، کیونکہ وہ تو اس وقت بھی ان کے ساتھ ہوتا ہے، جب وہ راتوں کو اس کی پسند کے خلاف گفتگوئیں (مشورے) کرتے ہیں اور وہ جو کچھ کرتے ہیں۔ اللہ اس کا احاطہ کئے ہوئے ہے۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcii{(اے مسلمانو!) یہ تم ہو جو دنیاوی زندگی میں ان کی طرف سے جھگڑتے ہو (ان کی طرفداری کرتے ہو)۔ تو قیامت کے دن ان کی طرف سے خدا سے کون بحث کرے گا؟ یا کون ان کا وکیل (نمائندہ) ہوگا؟ ۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dciii{اور جو کوئی برائی کرے یا قبیح کام کرے یا کوئی اپنے اوپر ظلم کرے (گناہ کا ارتکاب کرے) پھر اللہ سے مغفرت طلب کرے، تو وہ اللہ کو بڑا بخشنے والا اور بڑا رحم کرنے والا پائے گا۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dciv{اور جو گناہ کرتا ہے تو وہ اپنی ہی جان کے خلاف کرتا ہے۔ اور اللہ بڑا جاننے والا ہے اور بڑی حکمت والا ہے۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcv{اور جو کوئی غلطی یا گناہ کرے یا کسی بے قصور پر تہمت لگائے، تو اس نے ایک بڑے بہتان اور کھلے ہوئے گناہ کا بوجھ اٹھایا ہے۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcvi{اور اگر اللہ کا فضل و کرم اور اس کی خاص رحمت آپ(ص) کے شامل حال نہ ہوتی تو ان کے ایک گروہ نے تو یہ تہیّہ کر لیا تھا کہ آپ کو گمراہ کرکے رہے گا۔ حالانکہ وہ اپنے آپ کو ہی گمراہ کر رہے ہیں اور آپ کو کوئی نقصان نہیں پہنچا سکتے۔ اللہ نے آپ پر کتاب و حکمت نازل کی ہے اور آپ کو وہ کچھ پڑھا دیا ہے۔ جو آپ نہیں جانتے تھے اور آپ پر اللہ کا بڑا فضل و کرم ہے۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcvii{لوگوں کی زیادہ تر سرگوشیوں میں کوئی خیر و خوبی نہیں ہے سوا اس کے کہ کوئی صدقہ دینے، نیکی کرنے یا لوگوں کے درمیان صلح صفائی کرانے کی بات کرے اور جو شخص خدا کی خوشنودی حاصل کرنے کی خاطر ایسا کرے ہم اسے اجر عظیم عطا فرمائیں گے۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcviii{اور جو راہِ ہدایت کے واضح ہو جانے کے بعد رسول کی مخالفت کرے اور اہل ایمان کے راستے کے خلاف چلے، تو ہم اسے ادھر ہی جانے دیں گے، جدھر وہ گیا ہے (ہم اسے کرنے دیں گے جو کچھ وہ کرتا ہے)۔ اور اسے آتش دوزخ کا مزا چکھائیں گے اور یہ بہت بری جاءِ بازگشت ہے۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcix{بے شک اللہ اس جرم کو نہیں بخشتا کہ اس کے ساتھ شرک کیا جائے اور اس کے سوا (جو کم درجہ کے جرائم ہیں) جس کے لئے چاہتا ہے، بخش دیتا ہے۔ اور جو کسی کو اس کا شریک ٹھرائے، وہ گمراہ ہوا (اور اس میں) بہت دور نکل گیا۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcx{یہ (مشرک) لوگ اللہ کو چھوڑ کر نہیں پکارتے، مگر زنانی چیزوں (دیویوں) کو (ان کی عبادت کرتے ہیں) اور نہیں پکارتے، مگر سرکش شیطان کو (اس کی پرستش کرتے ہیں)۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcxi{جس پر اللہ نے لعنت کی ہے اور جس نے کہا کہ میں تیرے بندوں میں سے اپنا مقررہ حصہ لے کر رہوں گا۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcxii{اور انہیں ضرور گمراہ کروں گا اور میں انہیں مختلف آرزوؤں میں الجھاؤں گا (انہیں سبز باغ دکھاؤں گا) اور انہیں حکم دوں گا کہ وہ ضرور چوپاؤں کے کان شگافتہ کریں گے اور میں انہیں حکم دوں گا کہ وہ خدا کی خدائی ساخت کو ضرور بدل دیں گے اور جو اللہ کو چھوڑ کر شیطان کو اپنا سرپرست بنائے گا وہ کھلا ہوا نقصان اٹھائے گا۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcxiii{وہ شیطان لوگوں سے وعدے کرتا ہے اور انہیں (جھوٹی) امیدیں دلاتا ہے۔ اور ان سے شیطان وعدہ نہیں کرتا مگر فریب کے طور پر۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dcxiv{یہ وہ لوگ ہیں جن کا ٹھکانہ دوزخ ہے۔ جس سے وہ چھٹکارا کی راہ نہیں پائیں گے۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@dcxv{جو لوگ ایمان لائے اور نیک عمل کیے ہم عنقریب انہیں ان بہشتوں میں داخل کریں گے جن کے نیچے سے نہریں جاری ہوں گی۔ وہ ان میں ہمیشہ ہمیشہ رہیں گے (یہ) اللہ کا سچا وعدہ ہے اور اللہ سے بڑھ کر کون بات کا سچا ہے۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@dcxvi{(اے مسلمانو) نہ تمہاری تمناؤں سے کچھ ہوتا ہے اور نہ اہلِ کتاب کی تمناؤں سے۔ جو بھی برائی کرے گا، اس کو اس کی سزا دی جائے گی اور وہ اللہ کو چھوڑ کر اپنے لئے نہ کوئی سرپرست پائے گا اور نہ کوئی حامی و مددگار۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@dcxvii{اور جو کوئی نیک عمل کرے گا خواہ مرد ہو یا عورت درانحالیکہ وہ مؤمن ہو تو ایسے ہی لوگ جنت میں داخل ہوں گے اور ان پر تل برابر ظلم نہیں کیا جائے گا۔\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@dcxviii{اور اس شخص سے بڑھ کر کس کا دین اچھا ہوگا۔ جو اللہ کے لئے اپنا چہرہ جھکا دے (اپنے کو اللہ کے سپرد کر دے) اور وہ احسان کرنے والا ہو۔ اور اس ابراہیم حنیف کی ملت کا پیرو ہو۔ جسے اللہ نے اپنا خلیل بنایا تھا۔\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@dcxix{جو کچھ آسمانوں اور زمین میں ہے۔ وہ اللہ ہی کا ہے۔ اور اللہ ہر چیز کا احاطہ کئے ہوئے ہے۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@dcxx{اے رسول! لوگ عورتوں کے معاملہ میں آپ سے فتویٰ طلب کرتے ہیں کہہ دیجیے! کہ اللہ تمہیں ان کے بارے میں فتویٰ دیتا ہے اور متوجہ کرتا ہے ان آیات کی طرف جو کلام الٰہی کے اندر ہیں اور تمہیں ان یتیم لڑکیوں کے بارے میں پڑھ کر سنائی جا رہی ہیں۔ جن کا تم مقررہ حق تو ادا نہیں کرتے مگر چاہتے ہو کہ ان سے نکاح کرلو۔ اور متوجہ کرتا ہے ان (آیات) کی طرف جو ان کمزور و بے بس لڑکوں کے بارے میں ہیں۔ اور جو (آیات) اس بارے میں ہیں کہ یتیم بچوں کے بارے میں انصاف پر قائم رہو۔ اور تم جو بھلائی کروگے تو اللہ اس کا خوب علم رکھتا ہے۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@dcxxi{اور اگر کوئی عورت اپنے شوہر سے حق تلفی یا بے توجہی محسوس کرے تو ان دونوں کے لیے کوئی مضائقہ نہیں ہے کہ (کچھ لو کچھ دو کی بنا پر) آپس میں صلح کر لیں اور صلح بہرحال بہتر ہے اور نفوس میں بخل موجود رہتا ہے (تنگ دلی پر آمادہ رہتے ہیں) اور اگر تم بھلائی کرو۔ اور پرہیزگاری اختیار کرو۔ تو بے شک اللہ تمہارے اس طرزِ عمل سے باخبر ہے۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@dcxxii{یہ ٹھیک ہے کہ تم جس قدر چاہو مگر بیویوں میں پورا پورا عدل نہیں کر سکتے۔ مگر بالکل تو ایک طرف نہ جھک جاؤ۔ کہ (دوسری کو) بیچوں بیچ لٹکا چھوڑ دو۔ اور اگر تم اپنی اصلاح کر لو۔ اور تقویٰ اختیار کرو۔ تو خدا بڑا بخشنے والا، بڑا مہربان ہے۔\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@dcxxiii{اور اگر دونوں ایک دوسرے سے الگ ہو جائیں تو اللہ ہر ایک کو اپنے فضل و کرم کی وسعت سے بے نیاز کر دے گا۔ اور اللہ بڑی وسعت والا بڑی حکمت والا ہے۔\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@dcxxiv{اور جو کچھ آسمانوں اور زمین میں ہے سب اللہ ہی کا ہے اور ہم نے ان لوگوں کو بھی جن کو تم سے پہلے کتاب دی گئی تھی اور تمہیں بھی ہدایت کی ہے کہ تقویٰ و پرہیزگاری اختیار کرو۔ وہ تو آسمانوں اور زمین کی سب چیزوں کا مالک ہے۔ اللہ بڑا بے نیاز ہے حمد و ثناء کا حقدار ہے۔\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@dcxxv{جو کچھ آسمانوں اور زمین میں ہے۔ وہ سب اللہ کا ہے اور اللہ کارسازی کے لیے کافی ہے۔\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@dcxxvi{اے لوگو! اگر وہ چاہے، تو تم سب کو لے جائے (ختم کر دے) اور دوسروں کو لے آئے اور اللہ اس پر پوری قدرت رکھتا ہے۔\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@dcxxvii{جو شخص صرف دنیاوی صلہ و ثواب کا طلبگار ہو (تو اس کی مرضی ورنہ) اللہ کے پاس تو دنیا و آخرت دونوں کا صلہ و ثواب ہے اور اللہ بڑا سننے والا، بڑا دیکھنے والا ہے۔\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@dcxxviii{اے ایمان والو! مضبوطی کے ساتھ انصاف کے علمبردار ہو جاؤ۔ اور محض اللہ کے لئے گواہی دینے والے بنو۔ خواہ تمہیں اپنے یا والدین کے اور اپنے قریبی رشتہ داروں کے خلاف ہی گواہی دینا پڑے۔ وہ (جس کے خلاف گواہی دی جا رہی ہے) چاہے امیر ہو چاہے فقیر ہو بہرحال اللہ ان دونوں کا تم سے زیادہ خیرخواہ ہے پس اس طرح خواہش نفس کی پیروی نہ کرو کہ حق سے ہٹ جاؤ۔ اور اگر تم نے ہیرپھیر کیا یا (حق سے) منہ موڑا تو بے شک جو کہ تم کرتے ہو اللہ اس سے باخبر ہے۔\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@dcxxix{اے ایمان والو! اللہ پر، اس کے رسول(ص) پر اور اس کی کتاب پر ایمان لاؤ جو اس نے اپنے رسول(ص) پر نازل کی ہے۔ اور اس کتاب پر جو اس نے پہلے اتاری ہے اور جو کوئی اللہ کا، اس کے فرشتوں کا، اس کی کتابوں کا، اس کے رسولوں کا، اور آخرت کے دن کا انکار کرے۔ وہ گمراہ ہوا اور اس میں بہت دور نکل گیا۔\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@dcxxx{جو لوگ ایمان لائے پھر کافر ہوگئے پھر ایمان لائے پھر کافر ہوگئے۔ پھر کفر میں بڑھتے گئے۔ اللہ ہرگز نہ ان کی مغفرت فرمائے گا اور نہ انہیں سیدھی راہ تک پہنچائے گا۔\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@dcxxxi{منافقوں کو سنا دیجیے! کہ ان کے لئے دردناک عذاب ہے۔\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@dcxxxii{وہ (منافق) جو اہل ایمان کو چھوڑ کر کافروں کو اپنا دوست بناتے ہیں۔ کیا یہ ان کے پاس عزت تلاش کرتے ہیں۔ عزت تو ساری کی ساری اللہ ہی کے لئے ہے (اس کے اختیار میں ہے)۔\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@dcxxxiii{اور اس نے کتاب (قرآن) میں تم پر یہ حکم نازل کیا ہے کہ جب سنو کہ (کسی جگہ) آیات الٰہیہ کا انکار کیا جا رہا ہے اور ان کا مذاق اڑایا جا رہا ہے۔ تو ایسے لوگوں کے ساتھ مت بیٹھو۔ جب تک وہ کسی اور بات میں مشغول نہ ہو جائیں (ورنہ) اس حالت میں تم بھی انہی جیسے ہو جاؤگے۔ بے شک خدا سب منافقوں اور سب کافروں کو دوزخ میں اکھٹا کرنے والا ہے۔\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@dcxxxiv{یہ وہ لوگ ہیں جو تمہارے (انجام) کے منتظر رہتے ہیں۔ پھر اگر تمہیں اللہ کی طرف سے فتح و فیروزی حاصل ہوگئی تو کہتے ہیں کیا ہم تمہارے ساتھ نہ تھے؟ اور اگر کافروں کو (فتح کا) کچھ حصہ مل گیا تو (کافروں سے) کہتے ہیں۔ کیا ہم تم پر غالب نہیں آنے لگے تھے؟ اور کیا ہم نے تمہیں مسلمانوں سے نہیں بچایا؟ اب اللہ ہی قیامت کے دن تمہارے درمیان فیصلہ کرے گا۔ اور اللہ کبھی کافروں کے لیے مسلمانوں پر غالب آنے کا کوئی راستہ نہیں رکھے گا۔\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@dcxxxv{منافق (بزعم خود) خدا کو دھوکہ دے رہے ہیں۔ حالانکہ وہ انہیں دھوکے میں رکھ رہا ہے (انہیں ان کی دھوکہ بازی کی سزا دینے والا ہے) اور جب وہ نماز کے لئے کھڑے ہوتے ہیں۔ تو بے دلی اور کاہلی کے ساتھ وہ بھی خلوص نیت سے نہیں بلکہ محض لوگوں کو دکھانے کے لیے۔ اور اللہ کو یاد نہیں کرتے مگر تھوڑ۔\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@dcxxxvi{وہ (کفر و اسلام کے) درمیان ڈانواں ڈول ہیں نہ پورے اس طرف نہ پورے اس طرف جسے اللہ بھٹکنے دے (اس کی کج رفتاری کی وجہ سے توفیق ہدایت سلب کر لے) تو تو اس کے لئے ہدایت کا کوئی راستہ نہیں پائے گا۔\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@dcxxxvii{اے ایمان والو! اہل ایمان کو چھوڑ کر کافروں کو اپنا دوست نہ بناؤ۔ کیا تم چاہتے ہو کہ اپنے خلاف اللہ کو کھلی ہوئی دلیل مہیا کر دو۔\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@dcxxxviii{بے شک منافق دوزخ کے سب سے نیچے والے طبقہ میں ہوں گے۔ اور تم ان کے کوئی یار و مددگار نہیں پاؤگے۔\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@dcxxxix{سوا ان کے جنہوں نے توبہ کی، اپنی اصلاح کرلی۔ اور اللہ سے وابستہ ہوگئے اور اللہ کے لئے اپنا دین خالص کر دیا (خلوص کے ساتھ اس کی اطاعت کرنے لگے) تو یہ لوگ مؤمنین کے ساتھ ہوں گے اور اللہ اہل ایمان کو اجر عظیم عطا فرمائے گا۔\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@dcxl{اگر تم شکرگزار بن جاؤ۔ اور ایمان لے آؤ تو اللہ تمہیں عذاب کرکے کیا کرے گا؟ اور اللہ تو بڑا قدردان ہے (اور) بڑا جاننے والا ہے۔\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@dcxli{اللہ علانیہ بدگوئی کو پسند نہیں کرتا سوائے اس کے کہ جس پر ظلم ہوا ہو (کہ اس کے لیے ظالم کی بدگوئی جائز ہے) اللہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@dcxlii{اگر تم کوئی نیکی ظاہر کرو یا اسے چھپاؤ۔ یا کسی برائی سے درگزر کرو۔ تو بے شک اللہ (بھی) بڑا معاف کرنے والا، بڑا قدرت والا ہے۔\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@dcxliii{بے شک جو لوگ اللہ اور اس کے رسولوں کا انکار کرتے ہیں اور چاہتے ہیں کہ اللہ اور اس کے پیغمبروں کے درمیان تفریق کریں اور کہتے ہیں کہ ہم بعض پر ایمان لاتے ہیں اور بعض کا انکار کرتے ہیں اور وہ چاہتے ہیں کہ (ایمان و کفر کے) درمیان کوئی راستہ نکالیں۔\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@dcxliv{یہی وہ لوگ ہیں، جو حقیقی کافر ہیں اور ہم نے کافروں کے لیے رسوا کرنے والا عذاب مہیا کر رکھا ہے۔\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@dcxlv{اور جو لوگ اللہ اور اس کے رسولوں پر ایمان لائے اور ان میں سے کسی کے درمیان تفریق نہیں کی۔ یہی وہ لوگ ہیں جنہیں وہ (اللہ) ان کا اجر و ثواب عطا فرمائے گا۔ اور اللہ تو ہے ہی بڑا بخشنے والا، بڑا رحم کرنے والا۔\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@dcxlvi{آپ سے اہل کتاب مطالبہ کرتے ہیں کہ آپ ان پر آسمان سے کوئی (لکھی ہوئی) کتاب اتروا دیں سو یہ تو جناب موسیٰ سے اس سے بھی بڑا مطالبہ کر چکے ہیں یعنی کہا تھا کہ ہمیں کھلم کھلا اللہ دکھا دو تو ان کے (اسی) ظلم کی وجہ سے ان کو بجلی نے پکڑ لیا۔ اور پھر ان لوگوں نے آیات و معجزات آجانے کے بعد گوسالے کو (خدا) بنا لیا۔ مگر ہم نے انہیں معاف کر دیا اور موسیٰ کو کھلا ہوا غلبہ عطا کیا۔\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@dcxlvii{اور ہم نے ان سے (فرمانبرداری کا) پختہ عہد لینے کے لیے ان کے اوپر کوہ طور کو بلند کیا اور ہم نے ان سے کہا سجدہ ریز ہوکر دروازہ (شہر) میں داخل ہو جاؤ اور ان سے کہا کہ قانون سبت کے بارے میں زیادتی نہ کرو (حد سے نہ بڑھو) اور ہم نے ان سے پختہ عہد و پیمان لیا تھا۔\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@dcxlviii{سو (ان کو جو سزا ملی وہ) ان کے عہد شکنی کرنے، آیاتِ الٰہیہ کا انکار کرنے، نبیوں کو ناحق قتل کرنے اور ان کے اس کہنے کی وجہ سے کہ ہمارے دلوں پر غلاف چڑھے ہوئے ہیں۔ بلکہ ان کے کفر کی وجہ سے اللہ نے ان کے (دلوں) پر مہر لگا دی ہے۔ اس لیے وہ بہت کم ایمان لائیں گے۔\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@dcxlix{نیز ان کے ساتھ یہ جو کچھ ہوا یہ ان کے کفر کی وجہ سے ہوا۔ اور جناب مریم پر بہتان عظیم لگانے کی وجہ سے۔\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@dcl{اور ان کے اس کہنے کی وجہ سے کہ ہم نے خدا کے رسول مسیح عیسیٰ بن مریم کو قتل کر دیا ہے۔ حالانکہ انہوں نے نہ انہیں قتل کیا اور نہ سولی پر چڑھایا، بلکہ ان پر اصل معاملہ مشتبہ کر دیا گیا۔ اور جن لوگوں نے اس بارے میں اختلاف کیا ہے وہ یقینا اس کے متعلق شک میں ہیں اور انہیں گمان کی پیروی کرنے کے سوا کوئی علم نہیں ہے۔ اور انہوں نے یقینا ان کو قتل نہیں کیا۔\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@dcli{بلکہ اللہ تعالیٰ نے انہیں اپنی طرف اٹھا لیا اور اللہ زبردست ہے، بڑا حکمت والا ہے۔\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@dclii{اور اہل کتاب میں سے کوئی ایسا نہیں، جو اپنی موت (یا ان کی موت) سے پہلے ان پر ایمان نہ لائے اور وہ قیامت کے دن ان کے خلاف گواہ ہوں گے۔\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@dcliii{یہودیوں کے ایسے ہی مظالم اور زیادتیوں کیوجہ سے ہم نے وہ بہت سی پاکیزہ چیزیں ان پر حرام کر دیں، جو پہلے ان کے لئے حلال تھیں۔ نیز ان کے (لوگوں کو) اللہ کے راستہ سے بکثرت روکنے کی وجہ سے۔\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@dcliv{اور ان کے سود لینے کے سبب سے، حالانکہ انہیں اس سے منع کیا گیا تھا اور لوگوں کا ناحق مال کھانے کے باعث (یہ سب کچھ ہوا)۔ اور ان میں سے جو لوگ کافر ہیں، ہم نے ان کے لئے دردناک عذاب مہیا کر رکھا ہے۔\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@dclv{البتہ ان میں سے جو علم میں پختہ ہیں اور جو ایمان دار ہیں، وہ سب اس پر ایمان لاتے ہیں، جو کچھ آپ پر نازل کیا گیا اور اس پر بھی جو آپ سے پہلے نازل کیا گیا اور وہ نماز کو قائم کرتے ہیں، زکوٰۃ ادا کرتے ہیں اور اللہ اور آخرت کے دن پر ایمان رکھتے ہیں، یہ وہ لوگ ہیں جن کو ہم بہت بڑا اجر و ثواب عطا کریں گے۔\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@dclvi{بے شک ہم نے آپ کی طرف اسی طرح وحی بھیجی ہے۔ جس طرح (جناب) نوح اور ان کے بعد والے نبیوں کی طرف بھیجی تھی۔ اور ہم نے ابراہیم، اسماعیل، اسحاق، یعقوب، اولادِ یعقوب، عیسیٰ، ایوب، یونس، ہارون اور سلیمان کی طرف وحی بھیجی تھی اور ہم نے داؤد کو زبور عطا کی تھی۔\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@dclvii{کچھ پیغمبر وہ ہیں جن کے حالات ہم نے آپ سے پہلے بیان کر دیئے ہیں اور کچھ وہ ہیں جن کے واقعات ہم نے آپ سے بیان نہیں کئے اور اللہ نے موسیٰ سے اس طرح کلام کیا جیساکہ کلام کرنے کا حق ہے۔\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@dclviii{اور (ہم نے) رسولوں کو خوشخبری دینے والا اور ڈرانے والا بنا کر بھیجا تاکہ رسولوں کے آجانے کے بعد لوگوں کے لیے اللہ کے مقابلہ میں کوئی حجت باقی نہ رہ جائے اور اللہ زبردست، بڑا حکمت والا ہے۔\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@dclix{اللہ اس بات کی گواہی دیتا ہے کہ اس نے جو کچھ آپ پر نازل کیا۔ وہ اپنے علم سے نازل کیا ہے اور فرشتے (بھی) اس کی گواہی دیتے ہیں۔ اگرچہ گواہی کے لیے اللہ کافی ہے۔\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@dclx{بے شک جن لوگوں نے کفر اختیار کیا اور (دوسروں کو) اللہ کی راہ سے روکا گمراہی میں بہت دور نکل گئے۔\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@dclxi{بے شک جن لوگوں نے کفر اختیار کیا اور ظلم و ستم کیا، اللہ انہیں بخشنے والا نہیں ہے۔ اور نہ ہی انہیں کوئی راستہ دکھائے گا۔\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@dclxii{سوا جہنم کے راستہ کے جس میں وہ ہمیشہ ہمیشہ رہیں گے اور یہ بات اللہ کے لئے بالکل آسان ہے۔\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@dclxiii{اے لوگو! تمہارے پاس پروردگار کی طرف سے رسول حق لے کر آگیا ہے۔ پس ان پر ایمان لاؤ۔ یہ بات تمہارے لئے بہتر ہے۔ اور اگر انکار کروگے تو (اللہ کا کیا نقصان کروگے) جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے۔ وہ اللہ ہی کا ہے۔ اور اللہ بڑا علم والا، بڑا حکمت والا ہے۔\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@dclxiv{اے اہل کتاب اپنے دین میں غلو نہ کرو۔ اور اللہ کے بارے میں نہ کہو مگر سچی بات جناب عیسیٰ بن مریم اللہ کے رسول ہیں اور اس کا کلمہ جسے اس نے مریم کی طرف بھیجا۔ اور اللہ کی طرف سے ایک خاص روح ہیں۔ پس اللہ اور اس کے رسولوں پر ایمان لاؤ۔ اور تثلیث (یعنی تین خداؤں) کے قائل نہ ہو۔ (اس سے باز آجاؤ) (یہ) تمہارے لئے بہتر ہے۔ اللہ تو صرف ایک ہے۔ اس کی ذات اس سے پاک ہے کہ اس کی کوئی اولاد ہو۔ جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے۔ سب اسی کا ہے اور اللہ کارسازی کے لئے کافی ہے۔\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@dclxv{عیسیٰ مسیح اللہ کا بندہ ہونے میں اپنے لئے عار نہیں سمجھتے اور نہ ہی مقرب فرشتے اس میں اپنے لئے کوئی عار محسوس کرتے ہیں اور جو اس کی بندگی میں ننگ و عار محسوس کرے گا اور تکبر کرے گا۔ اللہ سب کو جلد اپنی طرف محشور فرمائے گا۔\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@dclxvi{پھر جو لوگ ایمان لائے ہوں گے اور نیک عمل کئے ہوں گے انہیں ان کا پورا پورا صلہ و ثواب دے گا اور اپنے فضل و کرم سے انہیں مزید بھی عطا فرمائے گا۔ اور جنہوں نے (اس کی بندگی سے) ننگ و عار محسوس کیا ہوگا اور تکبر کیا ہوگا ان کو دردناک عذاب کی سزا دے گا۔ اور وہ اللہ کے سوا نہ کوئی سرپرست پائیں گے اور نہ کوئی یار و مددگار۔\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@dclxvii{اے لوگو! تمہارے پاس تمہارے پروردگار کی طرف سے (روشن) دلیل آگئی ہے۔ اور ہم نے تمہاری طرف نمایاں نور اتارا ہے۔\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@dclxviii{سو جو لوگ اللہ پر ایمان لائے اور مضبوطی سے اس کا دامن پکڑا تو ضرور اللہ انہیں اپنی رحمت اور فضل میں داخل کرے گا۔ اور ان کو اپنے سیدھے راستہ پر لگا دے گا۔\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@dclxix{اے رسول یہ لوگ آپ سے فتویٰ پوچھتے ہیں۔ کہہ دیجیے! کہ اللہ تمہیں کلالہ کے بارے میں فتویٰ دیتا ہے کہ اگر کوئی ایسا شخص مر جائے جس کی اولاد نہ ہو اور اس کی ایک بہن ہو تو اس کا آدھا ترکہ اس کا ہوگا۔ اور اگر وہ (بہن) مر جائے اور اس کی کوئی اولاد نہ ہو (اور ایک بھائی ہو) تو وہ اس کے پورے ترکہ کا وارث ہوگا۔ اور اگر کسی مرنے والے کی دو بہنیں ہوں تو ان کا اس کے ترکہ میں سے دو تہائی حصہ ہوگا۔ اور اگر کئی بھائی بہن ہوں یعنی مرد عورت دونوں ہوں تو ایک مرد کو دو عورتوں کے برابر حصہ ملے گا۔ اللہ تعالیٰ تمہارے لئے کھول کر احکام بیان کرتا ہے۔ تاکہ تم گمراہ نہ ہو اور اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@dclxx{\basmalahur اے ایمان والو! اپنے عہدوں کو پورا کرو تمہارے لئے چوپائے، مویشی حلال کر دیئے گئے ہیں۔ سوائے ان کے جن کا ذکر تمہیں پڑھ کر سنایا جائے گا۔ ہاں جب تم احرام کی حالت میں ہو تو شکار کو حلال نہ سمجھو۔ بے شک اللہ جو چاہتا ہے وہ حکم دیتا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dclxxi{اے ایمان والو! خدا کی نشانیوں کی بے حرمتی نہ کرو۔ اور نہ حرمت والے مہینہ کی اور نہ قربانی والے جانور کی اور نہ گلے میں پٹے ڈالے ہوئے جانوروں کی اور نہ ان لوگوں کی (بے حرمتی کرو) جو اپنے پروردگار کا فضل و کرم اور اس کی رضامندی کے طلبگار بن کر بیت الحرام (مقدس گھر) کی طرف جا رہے ہیں اور جب احرام ختم ہو جائے (یا حرم سے باہر نکل جاؤ) تو شکار کر سکتے ہو۔ اور خبردار، تمہیں کسی قوم سے عداوت کہ اس نے تمہیں مسجد الحرام سے روک دیا تھا۔ اس بات پر آمادہ نہ کرے کہ تم (اس پر) ظلم و زیادتی کرو۔ اور نیکی و پرہیزگاری کے کاموں میں ایک دوسرے کی مدد کرو اور گناہ اور زیادتی کے کاموں میں ایک دوسرے کی مدد نہ کرو۔ اور اللہ (کی نافرمانی) سے ڈرو بے شک اللہ سخت سزا دینے والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dclxxii{تم پر حرام کیا گیا ہے۔ مردار، خون، خنزیر کا گوشت اور وہ جانور جس پر ذبح کے وقت غیر خدا کا نام لیا جائے۔ اور گلا گھوٹا ہوا، یا جو چوٹ لگنے سے یا بلندی سے گر کر، یا سینگ لگنے سے مر جائے یا جسے کسی درندہ نے کھایا ہو۔ سوائے اس کے جسے تم نے ذبح کر لیا ہو۔ اور وہ (بھی حرام ہے) جو قربان کیا جائے بتوں پر (یا کسی آستانے پر) نیز (وہ بھی حرام ہے) جو قرعہ کے تیروں سے تقسیم کیا جائے۔ یہ سب کام فسق (گناہ) ہیں۔ آج میں نے تمہارے لئے دین کو مکمل کر دیا ہے۔ اور اپنی نعمت تم پر تمام کر دی ہے اور تمہارے لئے دین کی حیثیت سے اسلام کو پسند کر لیا ہے ہاں جو بھوک کی شدت سے مجبور ہو جائے (اور حرام چیزوں سے کوئی کھا لے) جبکہ گناہ کی طرف راغب نہ ہو تو اللہ بڑا بخشنے والا بڑا رحم کرنے والا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dclxxiii{لوگ آپ سے پوچھتے ہیں کہ ان کے لئے کون سی چیزیں حلال کی گئی ہیں؟ کہہ دیجیئے کہ تمہارے لئے سب پاک و پاکیزہ چیزیں حلال کر دی گئیں اور جن شکاری جانوروں کو تم نے سدھایا ہو جن کو خدا کے سکھائے ہوئے طریقہ کے مطابق (شکار پکڑنے کا) طریقہ سکھایا ہو تو جسے وہ تمہارے لئے پکڑ رکھیں۔ اس میں سے بھی کھا سکتے ہو۔ اور اس پر (شکار پر چھوڑتے وقت) خدا کا نام لے لو۔ اور اللہ سے (اس کی معصیت کاری سے) ڈرو۔ بے شک اللہ بہت جلد حساب لینے والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dclxxiv{آج تمہارے لئے سب پاک و پاکیزہ چیزیں حلال کر دی گئی ہیں۔ اور اہل کتاب کا طعام (اناج) تمہارے لئے حلال ہے اور تمہارا طعام (اناج) ان کے لئے حلال ہے اور پاکدامن مسلمان عورتیں اور ان لوگوں (اہل کتاب) کی پاکدامن عورتیں جنہیں تم سے پہلے کتاب دی گئی ہے۔ (وہ تمہارے لئے حلال ہیں) بشرطیکہ تم ان کی اجرتیں (حق مہر) دے دو۔ اور وہ بھی اپنی پاکدامنی کے تحفظ کی خاطر نہ کہ آزاد شہوت رانی کی خاطر اور نہ ہی چوری چھپے ناجائز تعلقات قائم کرنے کے لیے۔ اور جو ایمان کا انکار کرے (اور کفر اختیار کرے) تو اس کے سب عمل اکارت ہوگئے اور وہ آخرت میں نقصان اٹھانے والوں میں ہوگا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dclxxv{اے ایمان والو! جب نماز کے لیے کھڑے ہونے لگو تو اپنے چہروں اور کہنیوں سمیت اپنے ہاتھوں کو دھوؤ۔ اور سروں کے بعض حصہ کا اور ٹخنوں تک پاؤں کا مسح کرو۔ اور اگر تم جنابت کی حالت میں ہو تو پھر غسل کرو اور اگر تم بیمار ہو یا سفر میں ہو یا تم میں سے کوئی بیت الخلاء سے آیا ہو۔ یا تم نے عورتوں سے مقاربت کی ہو۔ اور پھر تمہیں پانی نہ ملے تو پاک مٹی سے تیمم کر لو۔ یعنی اپنے چہروں اور ہاتھوں پر اس سے مسح کر لو (مَل لو) اللہ نہیں چاہتا کہ تم پر کوئی سختی کرے۔ وہ تو چاہتا ہے کہ تمہیں پاک صاف رکھے اور اپنی نعمت تم پر تمام کر دے تاکہ تم اس کا شکر ادا کرو۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dclxxvi{اور یاد کرو اللہ کا وہ احسان جو اس نے تم پر کیا۔ اور اس کے عہد و پیمان کو جو اس نے تم سے لیا۔ جب تم نے کہا تھا کہ ہم نے سنا اور مانا۔ اللہ سے ڈرو۔ بے شک اللہ دلوں کے رازوں کو خوب جانتا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dclxxvii{اے ایمان والو! اللہ کے لیے پوری پابندی کرنے والے اور راستی پر قائم رہنے والے۔ اور عدل و انصاف کے ساتھ گواہی دینے والے بنو (خبردار) کسی قوم سے دشمنی تمہیں اس بات پر آمادہ نہ کرے کہ تم انصاف نہ کرو۔ اور عدل سے پھر جاؤ۔ عدل کرو۔ کہ وہ تقویٰ کے زیادہ قریب ہے۔ اللہ سے ڈرو بے شک تم جو کچھ کرتے ہو اللہ اس سے پوری طرح باخبر ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dclxxviii{اللہ تعالیٰ نے ان لوگوں سے جو ایمان لائے اور نیک عمل کیے وعدہ کیا ہے کہ ان کے لیے بخشش اور بڑا اجر و ثواب ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dclxxix{اور جن لوگوں نے کفر اختیار کیا اور ہماری آیتوں کو جھٹلایا یہی دوزخ والے ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dclxxx{اے ایمان والو! اللہ کے اس احسان کو یاد کرو جو اس نے اس وقت تم پر کیا جب ایک گروہ نے ارادہ کیا تھا کہ وہ تمہاری طرف دست درازی کرے مگر اللہ نے (اپنی قدرت کاملہ سے) ان کو تم سے روک دیا۔ اللہ سے ڈرو۔ اور اہل ایمان کو اللہ پر ہی بھروسہ کرنا چاہیے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dclxxxi{اور بلاشبہ اللہ نے بنی اسرائیل سے عہدوپیمان لیا تھا اور ہم نے بھی بارہ نقیب (سردار) مقرر کئے تھے۔ اور اللہ نے (ان سے) کہا تھا کہ بے شک میں تمہارے ساتھ ہوں۔ تو اگر تم نماز قائم رکھوگے، اور زکوٰۃ دیتے رہوگے اور میرے رسولوں پر ایمان لاتے رہوگے، اور ان کی مدد کرتے رہوگے اور اللہ کو قرضہ حسنہ دیتے رہوگے تو میں ضرور تمہارے گناہ تم سے دور کر دوں گا۔ (معاف کر دوں گا) اور تمہیں ان بہشتوں میں داخل کروں گا۔ جن کے نیچے سے نہریں جاری ہوں گی مگر تم میں سے جس نے اس کے بعد کفر اختیار کیا وہ ضرور سیدھے راستے سے بھٹک گیا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dclxxxii{ان کی عہد شکنی کی وجہ سے ہم نے ان پر لعنت کی (اپنی رحمت سے دور کر دیا) اور ان کے دلوں کو سخت کر دیا کہ وہ اب کلامِ (الٰہی) کو اس کی اصلی جگہ سے ہٹا دیتے ہیں (تحریف کرتے ہیں) اور جس چیز کی ان کو نصیحت کی گئی تھی اس کا بڑا حصہ بھلا بیٹھے ہیں (اے پیغمبر(ص)) ان کے معدودے چند آدمیوں کے سوا برابر ان کی کسی نہ کسی خیانت پر مطلع ہوتے رہیں گے لہٰذا انہیں معاف کر دیجیے اور ان سے درگزر کیجیے بے شک اللہ معاف کرنے والوں کو دوست رکھتا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dclxxxiii{اور جو لوگ کہتے ہیں کہ ہم نصرانی ہیں ان سے بھی پختہ عہد لیا تھا۔ سو جو کچھ بھی انہیں نصیحت کی گئی تھی، جب وہ اس کا بڑا حصہ بھلا بیٹھے۔ تو ہم نے (بطورِ سزا) قیامت تک ان کے درمیان بغض و عناد ڈال دیا۔ اور عنقریب اللہ ان کو بتائے گا کہ وہ (دنیا میں کیا کرتے تھے)۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dclxxxiv{اے اہل کتاب! تمہارے پاس ہمارا وہ پیغمبر آگیا ہے جو بہت سی ان باتوں کو کھول کر بیان کر رہا ہے۔ جنہیں تم اس کتاب میں سے چھپاتے رہے ہو اور بہت سی باتوں کو نظر انداز بھی کر دیتا ہے۔ بے شک تمہارے پاس اللہ کی طرف سے نور (روشنی) اور واضح کتاب آگئی ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dclxxxv{جس کے ذریعہ سے خدا ان لوگوں کو سلامتی کے راستوں پر چلاتا ہے جو اس کی رضا کی اتباع و پیروی کرتے ہیں اور ان کو تاریکیوں (گمراہی) سے اپنے اذن و توفیق سے نور (ہدایت) کی طرف لاتا ہے اور انہیں سیدھے راستہ پر لگاتا ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dclxxxvi{یقینا وہ لوگ (نصرانی) کافر ہوگئے، جنہوں نے کہا کہ مسیح بن مریم ہی اللہ ہے۔ کہہ دیجیے کہ اگر اللہ مسیح مریم کو ان کی ماں اور تمام اہل زمین کو ہلاک کرنا چاہے۔ تو اس کے آگے کس کا ذرا بھی بس چل سکتا ہے (کہ اسے روک دے) آسمانوں پر، زمین پر اور جو کچھ ان کے درمیان ہے۔ ان سب پر، اللہ ہی کی حکومت ہے۔ وہ جو چاہتا ہے، پیدا کرتا ہے اور اللہ تو ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dclxxxvii{یہود و نصاریٰ کہتے ہیں کہ ہم اللہ کے بیٹے اور اس کے چہیتے ہیں۔ ان سے کہو (پوچھو) پھر خدا تمہیں تمہارے گناہوں پر سزا کیوں دیتا ہے؟ (نہیں) بلکہ تم بھی اس کی مخلوقات میں سے محض بشر (انسان) ہو۔ وہ جسے چاہتا ہے، بخش دیتا ہے اور جسے چاہتا ہے۔ سزا دیتا ہے اور اللہ ہی کے لئے ہے، سلطنت آسمانوں کی، زمین کی اور جو کچھ ان کے درمیان ہے اس کی اور سب کی بازگشت اسی کی طرف ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dclxxxviii{اے اہلِ کتاب، ہمارا رسول جو کھول کر (ہمارے احکام) بیان کرتا ہے۔ ایسے وقت تمہارے پاس آیا کہ جب کچھ عرصہ سے رسولوں کی آمد کا سلسلہ بند تھا، تاکہ تم یہ نہ کہہ سکو کہ ہمارے پاس کوئی خوشخبری دینے والا اور ڈرانے والا نہیں آیا، تو لو تمہارے پاس بشارت دینے والا اور ڈرانے والا آگیا ہے اور اللہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dclxxxix{وہ وقت یاد کرو۔ جب جناب موسیٰ نے اپنی قوم سے کہا اے میری قوم! تم اللہ کا وہ احسان یاد کرو۔ جو اس نے تم پر کیا۔ اس نے تم میں نبی بنائے اور تمہیں فرمانروا اور خودمختار بنایا۔ اور تمہیں وہ کچھ دیا جو دنیا جہان والوں میں سے کسی کو نہیں دیا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcxc{اے میری قوم! اس مقدس زمین میں داخل ہو جاؤ جو اللہ نے تمہارے لئے لکھ دی ہے اور (مقابلہ کے وقت) پیٹھ دکھا کر نہ بھاگنا۔ ورنہ نقصان اٹھا کر لوٹو گے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcxci{انہوں نے (جواب میں) کہا: اے موسیٰ اس زمین میں تو بڑے زبردست (جابر) لوگ رہتے ہیں اور ہم وہاں ہرگز داخل نہیں ہوں گے جب تک وہ وہاں سے نکل نہ جائیں۔ ہاں البتہ اگر وہ وہاں سے نکل جائیں تو پھر ہم ضرور داخل ہو جائیں گے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcxcii{اس وقت دو شخصوں نے جو (اللہ سے) ڈرنے والوں میں سے تھے۔ جنہیں اللہ نے (خصوصی) نعمت سے نوازا تھا۔ کہا۔ کہ تم ان (جباروں) پر چڑھائی کرکے دروازہ کے اندر گھس جاؤ اور جب تم اس کے اندر داخل ہوگے (تو وہ بھاگ کھڑے ہوں گے اور) تم غالب آجاؤگے اور اللہ پر بھروسہ کرو اگر تم ایمان دار ہو۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcxciii{انہوں نے کہا موسیٰ! ہم ہرگز اس میں داخل نہیں ہوں گے۔ جب تک وہ اس میں ہیں۔ لہٰذا آپ اور آپ کا خدا دونوں چلے جائیں اور جا کر لڑیں ہم تو یہیں بیٹھے ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcxciv{موسیٰ نے کہا پروردگار! میں اپنے اور اپنے بھائی کے سوا اور کسی پر کوئی قابو (اختیار) نہیں رکھتا۔ پس تو ہمارے اور اس نافرمان قوم کے درمیان فیصلہ کر دے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcxcv{ﷲ نے فرمایا! پھر اب وہ (زمین) چالیس سال تک حرام ہے وہ لق و دق صحراء میں سرگردان پھرتے رہیں گے پس آپ اس نافرمان قوم پر افسوس نہ کریں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcxcvi{(اے رسول(ص)) آپ انہیں آدم کے دونوں بیٹوں کا سچا قصہ پڑھ کر سنائیے۔ جب کہ ان دونوں نے قربانی پیش کی تو ایک کی تو قبول ہوگئی اور دوسرے کی قبول نہ ہوئی۔ اس (دوسرے) نے کہا میں تمہیں ضرور قتل کروں گا۔ پہلے نے کہا اللہ تو صرف متقیوں (پرہیزگاروں) کا عمل قبول کرتا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcxcvii{اگر تو مجھے قتل کرنے کے لئے ہاتھ بڑھائے گا۔ تو میں تمہیں قتل کرنے کے لئے ہاتھ نہیں بڑھاؤں گا۔ (کیونکہ) میں تو ڈرتا ہوں اس اللہ سے، جو تمام جہانوں کا پروردگار ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcxcviii{میں تو یہ چاہتا ہوں کہ تو میرا گناہ اور اپنا گناہ سمیٹ لے جائے اور پھر دوزخیوں میں سے ہو جائے کہ ظالموں کی یہی سزا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcxcix{تو (بالآخر) اس کے نفس نے اپنے بھائی کے قتل کو اس کے لئے آسان بنا دیا۔ چنانچہ اس نے اسے قتل کر دیا اور وہ نقصان اٹھانے والوں میں سے ہوگیا۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcc{پھر اللہ نے ایک کوا بھیجا جو زمین کھودتا تھا تاکہ اسے دکھائے کہ وہ کیونکر اپنے بھائی کی لاش چھپائے اس پر اس نے کہا، ہائے افسوس! کیا میں اس کوے سے بھی زیادہ گیا گزرا ہوں؟ کہ اپنے بھائی کی لاش چھپاؤں اب وہ پشیمان ہونے والوں میں سے ہوگیا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcci{اسی وجہ سے ہم نے بنی اسرائیل پر لکھ دیا کہ جس نے کسی انسان کو قتل کیا بغیر اس کے کہ اس نے کسی کی جان لی ہو، یا زمین میں فساد برپا کیا ہو، تو وہ ایسا ہے جیسے کہ اس نے تمام انسانوں کو قتل کر دیا اور جس نے کسی ایک جان کو بچا لیا، تو وہ ایسا ہے جیسے کہ اس نے تمام انسانوں کو بچا لیا اور بے شک ان (بنی اسرائیل) کے پاس ہمارے رسول کھلی ہوئی نشانیاں لے کر آئے۔ پھر بھی ان میں سے بہت سے لوگ اس کے بعد بھی زمین میں ظلم و تعدی کرنے والے ہی رہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dccii{بے شک جو لوگ خدا اور رسول سے لڑتے ہیں اور زمین میں فساد برپا کرنے کے لیے دوڑتے پھرتے ہیں، ان کی سزا یہ ہے کہ (۱) انہیں قتل کر دیا جائے۔ (۲) یا سولی پر چڑھا دیا جائے۔ (۳) یا ان کے ہاتھ پاؤں مخالف سمتوں سے کاٹ دیے جائیں۔ (۴) یا جلا وطن کر دیئے جائیں۔ یہ تو ہوئی ان کی رسوائی دنیا میں اور آخرت میں ان کے لئے بڑا عذاب ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcciii{مگر وہ لوگ جو توبہ کر لیں قبل اس کے کہ تم ان پر قابو پاؤ۔ تو جان لو کہ اللہ بڑا بخشنے والا بڑا مہربان ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcciv{اے ایمان والو اللہ سے ڈرو! اور اس تک پہنچنے کے لیے وسیلہ تلاش کرو۔ اور اس کی راہ میں جہاد کرو۔ تاکہ تم کامیاب ہو جاؤ۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dccv{بے شک وہ لوگ جنہوں نے کفر اختیار کیا اگر ان کے پاس وہ سب کچھ ہو جو زمین میں ہے اور اتنا اور بھی ہو، تاکہ اسے بطور فدیہ دیں اور قیامت کے دن عذاب سے بچ جائیں، تو وہ بھی ان سے قبول نہ کیا جائے گا۔ اور ان کے لئے دردناک عذاب ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dccvi{وہ چاہیں گے کہ آگ سے نکل جائیں، مگر وہ اس سے کبھی نہیں نکل پائیں گے۔ اور ان کے لئے دائمی عذاب ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dccvii{اور چور مرد ہو یا چور عورت دونوں کے ہاتھ کاٹ دو۔ ان کے کرتوتوں کے عوض میں اللہ کی طرف سے بطور عبرتناک سزا کے اللہ زبردست ہے، بڑا حکمت والا ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dccviii{پھر جو شخص توبہ کرلے اپنے ظلم سے اور (اپنی) اصلاح کر لے، تو یقینا اللہ اس کی توبہ قبول کرے گا۔ بیشک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dccix{کیا تم نہیں جانتے کہ اللہ کے لئے آسمانوں اور زمین کی حکومت ہے۔ جسے چاہتا ہے، سزا دیتا ہے، اور جسے چاہتا ہے بخش دیتا ہے۔ اور اللہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dccx{اے رسول! وہ لوگ آپ کو غمگین نہ کریں جو کفر کی طرف تیزگامی سے بڑھ رہے ہوں۔ خواہ یہ ان لوگوں میں سے ہوں جو منہ سے تو کہتے ہیں کہ ہم ایمان لائے، مگر ان کے دل ایمان نہیں لائے اور یا ان میں سے ہوں جو یہودی ہیں جھوٹ کے بڑے سننے والے ہیں اور سن گن لیتے ہیں دوسرے لوگوں کے لئے جو آپ کے پاس نہیں آئے۔ وہ (کتاب خدا کے) کلمات کو ان کے صحیح موقعوں سے ہٹا دیتے ہیں اور (تحریف کرنے کے بعد) کہتے ہیں کہ اگر تمہیں یہ حکم دیا جائے تو قبول کرو۔ اور اگر یہ نہ دیا جائے تو پرہیز کرو۔ اور اللہ جسے عذاب کرنا چاہے، تو آپ اس کے لئے کچھ نہیں کر سکتے۔ اللہ کے ہاں یہ وہ ہیں کہ اللہ نے (زبردستی) ان کے دلوں کو پاک کرنے کا ارادہ ہی نہیں کیا۔ ان کے لئے دنیا میں رسوائی ہے اور آخرت میں بہت بڑا عذاب ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dccxi{جھوٹ کے بڑے سننے والے ہیں، حرام مال کے بڑے کھانے والے ہیں اگر وہ تمہارے پاس آئیں تو (آپ کو اختیار ہے) خواہ ان کا فیصلہ کریں یا ان سے روگردانی کریں اور اگر آپ ان سے روگردانی کریں۔ تو وہ آپ کا کچھ نہیں بگاڑ سکتے اور اگر فیصلہ کریں تو پھر انصاف کے ساتھ کریں کیونکہ اللہ انصاف کرنے والوں کو دوست رکھتا ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dccxii{اور یہ لوگ آپ کو کس طرح حَکَم (ثالث) بناتے ہیں، حالانکہ ان کے پاس توراۃ موجود ہے جس میں اللہ کا حکم لکھا ہوا ہے اور پھر یہ (آپ کے فیصلہ کے) بعد اس سے منہ موڑ لیتے ہیں (بات دراصل یہ ہے کہ) یہ مؤمن ہی نہیں ہیں (ہرگز ماننے والے نہیں ہیں)۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dccxiii{ہم نے توراۃ نازل کی جس میں ہدایت اور نور (روشنی) تھی اس کے مطابق یہودیوں کے لئے فیصلے کرتے تھے۔ وہ تمام نبی جو اللہ کے مطیع و فرمانبردار تھے اللہ والے علماء و احبار بھی اس کے مطابق فیصلے کرتے تھے جس کی حفاظت کے وہ ذمہ دار بنائے گئے تھے اور جس کے وہ گواہ تھے۔ پس تم لوگوں سے نہ ڈرو۔ بلکہ مجھ سے ڈرو۔ اور میری آیات کو تھوڑی سی قیمت کے عوض فروخت نہ کرو اور جو اللہ کے نازل کردہ قانون کے مطابق فیصلہ نہ کریں، وہ کافر ہیں۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dccxiv{اور ہم نے اس (توراۃ) میں ان (یہودیوں) پر یہ حکم لکھ دیا تھا کہ جان کا بدلہ جان ہے اور آنکھ کے بدلے آنکھ، ناک کے بدلے ناک اور کان کے بدلے کان اور دانت کے بدلے دانت اور زخموں میں بھی برابر کا بدلہ ہے۔ پھر جو (قصاص) معاف کر دے، تو وہ اس کے لئے کفارہ ہوگا اور جو قانونِ خدا کے مطابق فیصلہ نہ کریں، وہ ظالم ہیں۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dccxv{ہم نے ان (انبیاء) کے نقش قدم پر عیسیٰ کو بھیجا اپنے سے پہلے موجود کتاب یعنی تورات کی تصدیق کرنے والا بنا کر اور ہم نے ان کو انجیل عطا کی۔ جس میں ہدایت ہے اور نور بھی جو تصدیق کرنے والی تھی۔ اپنے سے پہلے موجود کتاب یعنی تورات کی اور یہ (انجیل) صحیح رہنمائی اور نصیحت تھی پرہیزگاروں کے لیے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dccxvi{چاہیے کہ انجیل والے (نصرانی) اس (قانون) کے مطابق فیصلہ کریں، جو اللہ نے اس (انجیل) میں نازل کیا ہے اور جو اللہ کے نازل کردہ (قانون) کے مطابق فیصلہ نہیں کرتے وہی فاسق (نافرمان) ہیں۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dccxvii{اور (اے رسول(ص)) ہم نے آپ کی طرف حق کے ساتھ کتاب نازل کی ہے۔ جو تصدیق کرتی ہے۔ ان (آسمانی) کتابوں کی جو اس سے پہلے موجود ہیں اور ان کی محافظ و نگہبان ہے۔ لہٰذا آپ ان کے درمیان وہی فیصلہ کریں جو اللہ نے نازل کیا ہے اور اس حق سے منہ موڑ کر جو آپ کے پاس آگیا ہے۔ ان کی خواہشات کی پیروی نہ کریں، ہم نے تم میں سے ہر ایک کے لئے ایک شریعت اور ایک راہ مقرر کی ہے اور اگر خدا (زبردستی) چاہتا، تو تم سب کو ایک ہی (شریعت) کی ایک ہی امت بنا دیتا۔ مگر وہ چاہتا ہے کہ تمہیں آزمائے (ان احکام میں) جو (مختلف اوقات میں) تمہیں دیتا رہا ہے بس تم نیکیوں میں ایک دوسرے سے بڑھنے کی کوشش کرو۔ تم سب کی بازگشت اللہ ہی کی طرف ہے، پھر وہ تمہیں آگاہ کرے گا۔ ان باتوں سے جن میں تم اختلاف کرتے ہو۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dccxviii{اور ان کے درمیان اس کے مطابق فیصلہ کریں، جو اللہ نے تم پر نازل کیا ہے اور ان کی خواہشات کی پیروی نہ کریں اور ان سے ہوشیار رہیں کہ کہیں وہ آپ کو اللہ کے نازل کردہ کسی حکم سے بھٹکا نہ دیں اور اگر وہ روگردانی کریں، تو جان لیجیے کہ اللہ بس یہ چاہتا ہے کہ وہ انہیں ان کے بعض گناہوں کی سزا دے۔ بے شک زیادہ تر لوگ فاسق (نافرمان ہیں)۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dccxix{کیا وہ دورِ جاہلیت کے فیصلے چاہتے ہیں؟ حالانکہ یقین رکھنے والے لوگوں کے لئے اللہ سے بہتر فیصلہ کرنے والا کون ہے؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dccxx{اے ایمان والو! یہود و نصاریٰ کو اپنا دوست نہ بناؤ، وہ آپس میں ایک دوسرے کے دوست ہیں اور تم میں سے جو ان سے دوستی کرے گا وہ انہی میں سے شمار ہوگا۔ بے شک خدا ظالموں کو ہدایت نہیں کرتا۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dccxxi{(اے رسول(ص)) آپ دیکھیں گے کہ جن لوگوں کے دلوں میں نفاق کی بیماری ہے۔ وہ دوڑ دوڑ کر ان (یہود و نصاریٰ) کی طرف جاتے ہیں، کہتے ہیں کہ ہمیں اندیشہ ہے کہ کہیں ہم پر کوئی گردش زمانہ نہ آجائے سو قریب ہے کہ اللہ (تمہیں) فتح سے ہمکنار کر دے یا (کامیابی کی) کوئی اور صورت اپنی طرف سے ظاہر کر دے، تو پھر وہ اس پر جو انہوں نے اپنے دلوں میں چھپا رکھا ہے نادم و پشیمان ہوں گے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dccxxii{اور جو ایمان والے ہیں۔ وہ (حیرت سے) کہیں گے کیا یہ وہ لوگ ہیں۔ جنہوں نے بڑی سخت قسمیں کھائی تھیں کہ بے شک وہ تمہارے ساتھ ہیں۔ ان کے سب عمل ضائع ہوگئے اور وہ نقصان اٹھانے والے ہوگئے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dccxxiii{اے ایمان والو! جو تم میں سے اپنے دین سے مرتد ہو جائے (پھر جائے) تو خدا کو کیا پروا؟ ﷲ عنقریب ایسے لوگوں کو لے آئے گا جن سے وہ محبت کرتا ہوگا اور وہ اس سے محبت کرتے ہوں گے۔ وہ مؤمنوں پر نرم اور کافروں پر سخت ہوں گے وہ اللہ کی راہ میں جہاد کریں گے اور کسی ملامت کرنے والے کی ملامت کی پرواہ نہ کریں گے۔ یہ اللہ کا فضل ہے، جسے چاہتا ہے، عطا کرتا ہے اور اللہ بڑا وسعت والا بڑا جاننے والا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dccxxiv{اے ایمان والو! تمہارا حاکم و سرپرست اللہ ہے۔ اس کا رسول ہے اور وہ صاحبان ایمان ہیں۔ جو نماز پڑھتے ہیں اور حالت رکوع میں زکوٰۃ ادا کرتے ہیں۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dccxxv{اور جو تولاّ رکھے، اللہ سے، اس کے رسول سے اور صاحبانِ ایمان سے (وہ اللہ کا گروہ ہے) اور بے شک اللہ کا گروہ ہی غالب آنے والا ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dccxxvi{اے ایمان والو! وہ لوگ جنہیں تم سے پہلے کتاب دی گئی اور انہوں نے تمہارے دین کو مذاق اور کھیل بنا رکھا ہے۔ ان کو اور دوسرے عام کفار کو اپنا دوست نہ بناؤ اور اللہ سے ڈرو، اگر تم مؤمن ہو۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dccxxvii{اور جب تم (اذان دے کر لوگوں کو) نماز کی طرف بلاتے ہو تو وہ اسے مذاق اور کھیل بناتے ہیں۔ یہ اس لئے ہے کہ وہ بے وقوف ہیں، عقل سے کام نہیں لیتے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dccxxviii{(اے رسول(ص)) کہیے! اے اہل کتاب تم ہم پر کیا عیب لگاتے ہو؟ یہی کہ ہم اللہ پر، جو کچھ ہم پر اتارا گیا ہے۔ اس پر اور جو اس سے پہلے اتارا گیا، اس پر ایمان لائے ہیں (حقیقت یہ ہے کہ) تم میں سے زیادہ تر فاسق (نافرمان) ہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dccxxix{کہیئے! کیا میں بتاؤں؟ کہ اللہ کے نزدیک انجام کے اعتبار سے زیادہ بُرا کون ہے؟ وہ ہے جن پر اللہ نے لعنت کی ہے اور جس پر وہ غضبناک ہے۔ اور جس میں سے اس نے بعض کو بندر اور بعض کو سور بنایا ہے اور جس نے شیطان (معبود باطل) کی عبادت کی ہو یہی وہ لوگ ہیں جوکہ درجہ کے لحاظ سے بدترین ہیں اور راہِ راست سے زیادہ بھٹکے ہوئے ہیں۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dccxxx{اور وہ جب آپ لوگوں کے پاس آتے ہیں تو کہتے ہیں کہ ہم ایمان لائے ہیں حالانکہ وہ یہاں داخل ہوئے تو بھی کفر کے ساتھ اور یہاں سے نکلے تو بھی کفر کے ساتھ اور وہ لوگ جو (نفاق) چھپائے ہوئے ہیں اللہ اسے خوب جانتا ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dccxxxi{تم ان میں سے بہتوں کو دیکھوگے کہ وہ گناہ، ظلم و تعدی کرنے اور حرام خوری میں بڑی تیزی دکھاتے ہیں، کتنا برا ہے، وہ کام جو یہ کرتے ہیں۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccxxxii{خدا والے فضلاء اور علماء ان کو گناہ کی بات کرنے (جھوٹ بولنے) اور حرام کھانے سے منع کیوں نہیں کرتے؟ کتنا برا ہے وہ کام جو یہ (علماء) کر رہے ہیں۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dccxxxiii{یہودی کہتے ہیں کہ خدا کا ہاتھ بندھا ہوا ہے (کچھ نہیں کر سکتا) ان کے ہاتھ بندھیں اور اس (بے ادبانہ) قول کی وجہ سے ان پر لعنت ہو۔ بلکہ اس کے ہاتھ کھلے ہوئے ہیں۔ وہ جس طرح چاہتا ہے خرچ کرتا ہے اور جو آپ کے پروردگار کی طرف سے آپ پر نازل کیا گیا ہے۔ وہ ان میں سے بہت سوں کی سرکشی اور کفر میں اضافہ کرتا ہے اور ہم نے ان کے درمیان قیامت تک دشمنی اور بغض و کینہ ڈال دیا ہے۔ وہ جب بھی لڑائی کی آگ بھڑکاتے ہیں۔ تو اللہ اسے بجھا دیتا ہے اور یہ زمین میں فساد برپا کرنے کی سعی و کوشش کرتے ہیں اور اللہ فساد برپا کرنے والوں کو پسند نہیں کرتا۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dccxxxiv{اور اگر اہلِ کتاب (یہود و نصاریٰ) ایمان لاتے اور تقویٰ اختیار کرتے، تو ہم ان کی برائیاں دور کر دیتے اور انہیں نعمت و راحت والے بہشتوں میں داخل کرتے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccxxxv{اور اگر وہ (اہلِ کتاب) تورات، انجیل اور جو ان کے پروردگار کی طرف سے ان کی طرف نازل کیا گیا تھا کو قائم رکھتے، تو وہ اپنے اوپر اور نیچے سے کھاتے پیتے۔ ان میں سے ایک گروہ تو میانہ رو ہے۔ مگر ان میں سے زیادہ لوگ ایسے ہیں جو بہت برا کر رہے ہیں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccxxxvi{اے رسول! جو کچھ آپ کے پروردگار کی طرف سے آپ پر اتارا گیا ہے۔ اسے (لوگوں تک) پہنچا دیجیے اور اگر آپ نے ایسا نہ کیا تو (پھر یہ سمجھا جائے گا کہ) آپ نے اس کا کوئی پیغام پہنچایا ہی نہیں۔ اور اللہ آپ کی لوگوں (کے شر) سے حفاظت کرے گا بے شک خدا کافروں کو ہدایت نہیں کرتا۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccxxxvii{اے اہلِ کتاب تم کسی راہ (حق) پر نہیں ہو جب تک کہ تورات، انجیل کو اور جو کچھ پروردگار کی طرف سے نازل ہوا ہے۔ اس کو قائم نہ رکھو اور جو کچھ آپ کے پروردگار کی طرف سے آپ پر اتارا گیا ہے (قرآن) وہ ان میں سے بہت سوں کی سرکشی اور کفر میں اضافہ کرے گا آپ کافروں پر افسوس نہ کریں۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccxxxviii{بے شک جو لوگ مؤمن، یہودی، نصرانی اور صابی (ستارہ پرست) کہلاتے ہیں (غرض) جو کوئی بھی واقعی اللہ اور آخرت پر ایمان لائے اور نیک عمل کرے تو ان (سب) کے لئے ان کے پروردگار کے پاس ان کا اجر و ثواب (محفوظ) ہے اور ان کے لئے نہ کوئی خوف ہے۔ اور نہ ہی وہ غمگین ہوں گے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccxxxix{ہم نے بنی اسرائیل سے عہد لیا تھا اور ان کی طرف کئی رسول بھیجے تھے جب بھی کوئی رسول ان کے پاس کوئی ایسی بات لے کر آتا جسے ان کے نفوس پسند نہیں کرتے تھے تو بعضوں کو جھٹلا دیتے تھے اور بعضوں کو قتل کر دیتے تھے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccxl{اور خیال کرتے تھے کہ (انہیں) کوئی سزا نہیں ملے گی۔ اس لئے وہ اندھے اور بہرے ہوگئے پھر توبہ کی تو اللہ نے ان کی توبہ قبول کر لی (لیکن) اس کے بعد پھر ان میں سے بہت سے لوگ اندھے اور بہرے ہوگئے۔ وہ جو کچھ کر رہے ہیں۔ اللہ اسے خوب دیکھ رہا ہے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccxli{یقینا وہ لوگ کافر ہیں۔ جنہوں نے کہا کہ مسیح بن مریم ہی اللہ ہے حالانکہ خود عیسیٰ نے یہ کہا تھا کہ اے بنی اسرائیل اللہ کی عبادت کرو۔ جو میرا بھی پروردگار ہے اور تمہارا بھی پروردگار ہے۔ بے شک جو شخص کسی کو اللہ کے ساتھ شریک ٹھہرائے گا۔ تو اللہ اس پر جنت حرام کر دے گا اور اس کا ٹھکانا جہنم ہے اور ظالموں کا کوئی یار و مددگار نہیں ہے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccxlii{یقینا وہ لوگ (بھی) کافر ہو گئے جنہوں نے کہا کہ اللہ تین میں سے تیسرا ہے حالانکہ ایک خدا کے سوا کوئی خدا نہیں ہے۔ اور اگر یہ لوگ ان باتوں سے باز نہ آئے تو جو ان میں سے کفر پر برقرار رہیں گے تو انہیں ضرور دردناک عذاب پہنچے گا۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccxliii{یہ لوگ خدا کی بارگاہ میں توبہ کیوں نہیں کرتے اور اس سے (اپنے گناہوں کی) معافی کیوں نہیں مانگتے؟ درآنحالیکہ اللہ بڑا بخشنے والا بڑا رحم کرنے والا ہے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccxliv{مسیح گزر چکے ہیں ان کی ماں صدیقہ (راست باز خاتون) تھیں وہ دونوں کھانا کھاتے تھے۔ دیکھو ہم کس طرح ان کے سامنے واضح دلائل بیان کر رہے ہیں۔ پھر دیکھو یہ کدھر الٹے پھرے جا رہے ہیں۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccxlv{(اے رسول(ص)) ان سے کہیئے! کیا تم اللہ کو کو چھوڑ کر اس کی عبادت کرتے ہو جو تمہیں نہ نفع پہنچا سکتا ہے نہ نقصان (نہ سود نہ زیاں؟) اور اللہ وہ ہے جو ہر بات کا سننے والا ہر چیز کا جاننے والا ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccxlvi{کہیئے! اے اہل کتاب اپنے دین میں ناحق غلو نہ کرو۔ اور ان لوگوں کی خواہشات اور ذاتی خیالات کی پیروی نہ کرو جو پہلے خود گمراہ ہو چکے ہیں۔ اور بہت سوں کو گمراہ کر چکے ہیں اور راہ راست سے بھٹک گئے ہیں۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccxlvii{بنی اسرائیل میں سے جن لوگوں نے کفر اختیار کیا ان پر داؤد اور عیسیٰ بن مریم کی زبان سے لعنت کی گئی یہ اس لیے کہ انہوں نے برابر نافرمانی کی اور حد سے بڑھ جاتے تھے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccxlviii{جو برائی وہ کرتے تھے۔ اس سے ایک دوسرے کو منع نہیں کرتے تھے۔ کیسا برا تھا۔ وہ کام جو وہ کرتے تھے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccxlix{آپ ان میں سے بہتوں کو دیکھیں گے کہ وہ اہلِ اسلام کے بالمقابل کافروں سے دوستی رکھتے ہیں بہت ہی برا ہے وہ (سامان) جو ان کے نفسوں نے ان کے لئے آگے بھیجا ہے۔ (جس سے) اللہ ان پر غضبناک ہوگیا اور وہ ہمیشہ ہمیشہ عذاب میں رہیں گے۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccl{اور اگر وہ خدا پر، رسول(ص) پر اور جو کچھ اس (رسول(ص)) پر نازل کیا گیا ہے۔ اس پر ایمان لاتے، تو ان کافروں کو اپنا دوست نہ بناتے۔ لیکن (بات دراصل یہ ہے کہ) ان میں سے زیادہ تر لوگ فاسق و فاجر (نافرمان) ہیں۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccli{اے پیغمبر(ص)! آپ اہل ایمان سے دشمنی کرنے میں سب لوگوں سے زیادہ سخت ترین دشمن یہودیوں اور مشرکوں کو پائیں گے اور اہل ایمان سے دوستی کرنے میں آپ سب سے زیادہ قریب ان لوگوں کو پائیں گے جو کہتے ہیں کہ ہم نصرانی ہیں یہ اس لئے ہے کہ ان میں پادری اور تارک الدنیا عابد پائے جاتے ہیں اور اس لیے کہ وہ تکبر نہیں کرتے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dcclii{اور جب وہ اس کلام کو سنتے ہیں جو (ہمارے) پیغمبر پر اتارا گیا ہے تو تم دیکھوگے کہ ان کی آنکھیں آنسوؤں سے چھلک رہی ہوتی ہیں اس لئے کہ انہوں نے حق کو پہچان لیا ہے وہ کہتے ہیں پروردگار ہم ایمان لائے سو تو ہم کو (صداقتِ اسلام کی) گواہی دینے والوں میں درج فرما۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccliii{اور ہمیں کیا ہے کہ ہم اللہ پر اور اس حق پر جو ہمیں پہنچا ہے ایمان نہ لائیں حالانکہ ہم خواہش رکھتے ہیں کہ ہمارا پروردگار ہمیں (اپنے) نیک بندوں میں شامل کرے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccliv{اللہ نے ان کو ان کے اس قول کے صلہ میں ایسے بہشت عطا فرمائے جن کے نیچے نہریں جاری ہیں جن میں وہ ہمیشہ رہیں گے اور یہ نیکوکاروں کا معاوضہ ہے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dcclv{اور جن لوگوں نے کفر اختیار کیا اور ہماری آیتوں کو جھٹلایا تو وہی دوزخ والے ہیں۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dcclvi{اے ایمان والو! (اپنے اوپر) حرام نہ کرو ان پاکیزہ چیزوں کو جو اللہ نے تمہارے لئے حلال کی ہیں اور (حد سے) تجاوز نہ کرو بے شک اللہ (حد سے) تجاوز کرنے والوں کو پسند نہیں فرماتا۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dcclvii{اور اللہ نے تمہیں جو حلال اور پاکیزہ چیزیں عطا کی ہیں ان میں سے کھاؤ۔ اور اسی اللہ سے ڈرو (اس کی نافرمانی سے بچو) جس پر تم ایمان رکھتے ہو۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dcclviii{اللہ تم سے تمہاری لایعنی قَسموں پر مواخذہ (بازپرس) نہیں کرے گا۔ مگر جو قسمیں تم نے قصداً کھائی ہیں (اور اس طرح مضبوط کی ہیں) تو ان پر ضرور تم سے مواخذہ کرے گا۔ اور (ایسی قسم توڑنے کا) کفارہ یہ ہے: (۱)دس مسکینوں کو کھانا کھلانا اوسط درجے کا جو تم اپنے گھر والوں کو کھلاتے ہو۔ (۲) یا انہیں کپڑے پہناؤ۔ (۳) یا پھر ایک غلام آزاد کرو۔ اور جس کو اس کا مقدور نہ ہو تو وہ تین روزہ رکھے۔ یہ تمہاری قَسموں کا کفارہ ہے جب تم قَسم کھاؤ اور اپنی قَسموں کی حفاظت کرو (خیال رکھو) اسی طرح اللہ تمہارے لئے اپنے آیات و احکام کھول کر بیان کرتا ہے تاکہ تم شکر گزار بنو۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dcclix{اے ایمان والو! شراب، جوا، بت (یا آستانے، اور پانسے) سب گندے اور شیطانی کام ہیں ان سے اجتناب کرو۔ تاکہ تم فلاح پاؤ۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dcclx{شیطان تو بس یہی چاہتا ہے کہ تمہارے درمیان شراب اور جوئے کے ذریعہ سے بغض و عداوت ڈالے۔ اور تمہیں اللہ کی یاد اور نماز سے باز رکھے (روکے)۔ کیا اب تم (ان چیزوں سے) باز آؤگے؟ ۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dcclxi{اور اطاعت کرو اللہ کی اور اطاعت کرو رسول کی اور (نافرمانی سے) بچتے رہو اور اگر تم نے روگردانی کی تو پھر تمہیں معلوم ہونا چاہیے کہ ہمارے رسول کے ذمہ تو صرف واضح طور پر (ہمارا پیغام) پہنچا دینا ہے اور بس۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dcclxii{جو لوگ ایمان لائے اور نیک عمل کئے ان پر اس میں کوئی گناہ نہیں ہے کہ جو وہ (پہلے) کھا پی چکے ہوں۔ جبکہ (اب) پرہیز کریں اور ایمان لائیں اور نیک عمل کریں۔ اور پھر اس ایمان و پرہیز پر قائم و ثابت قدم بھی رہیں اور پھر تمام برے کاموں سے پرہیز کرتے رہیں اور نیکیاں کرتے رہیں اور اللہ نیک عمل کرنے والوں کو دوست رکھتا ہے۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dcclxiii{اے ایمان والو! خدا تمہیں ضرور اس شکار کے ذریعہ سے آزمائے گا جسے تمہارے یہ ہاتھ اور نیزے پا جائیں (تمہاری زد میں ہو) تاکہ وہ (حسب ظاہر) یہ دیکھے کہ غائبانہ طور پر کون اس سے ڈرتا ہے؟ اور جس نے تنبیہ کے بعد بھی حد سے تجاوز کیا تو اس کے لئے دردناک عذاب ہے۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dcclxiv{اے ایمان والو! شکار کو نہ مارو جبکہ تم احرام باندھے ہوئے ہو اور جو تم میں سے جان بوجھ کر اسے مارے گا تو اس کا جرمانہ مویشیوں سے کوئی جانور ہوگا۔ جو اس جانور کا ہم پلہ ہو جو اس نے مارا ہے جس کا فیصلہ تم میں سے دو عادل شخص کریں گے اور یہ جرمانہ بطور قربانی و نذرانہ خانہ کعبہ پہنچایا جائے گا۔ اس کا کفارہ چند مسکینوں کو کھانا کھلانا ہوگا یا پھر اس کے برابر روزے رکھے جائیں گے۔ تاکہ وہ اپنے کئے کی سزا کا مزہ چکھے۔ تو پہلے جو ہو چکا اسے تو اللہ نے معاف کر دیا۔ اور جو پھر ایسا کرے گا تو اس سے اللہ انتقام (بدلہ) لے گا۔ اور اللہ غالب ہے (زبردست ہے) اور بدلہ لینے والا ہے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dcclxv{تمہارے لئے سمندری شکار (تری والا) اور اس کا کھانا اور قافلہ والوں (مسافروں) کے فائدہ کے لئے حلال قرار دیا گیا ہے اور جب تک تم حالت احرام میں ہو خشکی کا شکار تم پر حرام کیا گیا ہے اور اللہ کی نافرمانی سے ڈرتے رہو۔ جس کے پاس تم جمع کئے جاؤ گے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dcclxvi{خدا نے کعبہ کو جو حرمت والا گھر ہے۔ حرمت والے مہینوں کو اور قربانی کے جانوروں کو اور گلے میں پٹہ بندھے جانوروں کو لوگوں کی بقاء و فلاح کا سبب اور مرکز بنایا ہے تاکہ تمہیں معلوم ہو کہ اللہ وہ سب کچھ جانتا ہے جو آسمانوں میں ہے اور جو زمین میں ہے اور یہ کہ اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dcclxvii{جان لو کہ اللہ (مقامِ عقاب میں) سخت سزا دینے والا بھی ہے اور مقامِ عفو و صفح میں بڑا بخشنے والا اور بڑا رحم کرنے والا بھی ہے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dcclxviii{پیغمبر کی ذمہ داری صرف پیغام پہنچانا ہے اور بس۔ اور اللہ اسے بھی جانتا ہے جو تم ظاہر کرتے ہو اور اسے بھی جسے تم چھپاتے ہو۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dcclxix{کہہ دیجیے کہ خبیث (ناپاک) اور طیب (پاک) برابر نہیں ہو سکتے اگرچہ خبیث (ناپاک) کی کثرت اور بہتات تمہیں تعجب میں بھی ڈال دے (تمہیں بھلی لگے) اے عقل والو! خدا کی نافرمانی سے ڈرو تاکہ تم فلاح پاؤ۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcclxx{اے ایمان والو! ایسی چیزوں کے بارے میں سوال نہ کرو۔ کہ جو اگر ظاہر کر دی جائیں تو تمہیں بری لگیں۔ اور اگر ان کے متعلق ایسے وقت میں سوال کروگے جبکہ قرآن اتر رہا ہے تو وہ تم پر ظاہر کر دی جائیں گی اللہ نے انہیں نظر انداز کر دیا ہے (یا اللہ نے تمہیں معاف کر دیا ہے) اور اللہ بڑا بخشنے والا، بڑا بردبار ہے۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcclxxi{تم سے پہلے بھی کچھ لوگوں نے اس قسم کے سوال (اپنے نبیوں سے) کئے تھے۔ پھر انہیں کی وجہ سے کافر (منکر) ہوگئے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcclxxii{اللہ تعالیٰ نے کوئی بحیرہ، سائبہ، وصیلہ اور حام مقرر نہیں کیا مگر کافر اللہ پر جھوٹا بہتان باندھتے ہیں۔ اور ان میں سے اکثر عقل و شعور نہیں رکھتے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcclxxiii{اور جب ان سے کہا جاتا ہے کہ آؤ اس (قرآن) کی طرف جو اللہ نے اتارا ہے اور آؤ پیغمبر(ص) کی طرف تو وہ کہتے ہیں کہ ہمارے لئے تو وہی (طریقہ) کافی ہے جس پر ہم نے اپنے آباء و اجداد کو پایا ہے اگرچہ ان کے باپ دادا نہ علم رکھتے ہوں اور نہ ہدایت یافتہ ہوں (تو بھی وہ انہی کے طریقہ کو کافی جانیں گے؟)\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcclxxiv{اے ایمان والو! تم پر لازم ہے کہ اپنی جانوں کی فکر کرو۔ جو گمراہ ہے وہ تمہارا کچھ بھی نہیں بگاڑ سکتا جب کہ تم ہدایت یافتہ ہو (راہِ راست پر ہو) تم سب کی بازگشت اللہ ہی کی طرف ہے پھر وہ تمہیں بتائے گا کہ تم دنیا میں کیا کرتے تھے؟ ۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcclxxv{اے ایمان والو! جب تم میں سے کسی کی موت کا وقت آجائے جبکہ وہ وصیت کر رہا ہو تو تمہارے درمیان گواہی کا ضابطہ یہ ہے کہ تم مسلمانوں میں سے دو عادل گواہ ہونے چاہئیں۔ ہاں البتہ اگر تم سفر میں ہو اور تم پر موت کی مصیبت آپڑے (اور مسلمان گواہ نہ مل سکیں) تو پھر دو گواہ غیروں میں سے ہی لے لئے جائیں۔ اور اگر تمہیں شک پڑ جائے تو ان دونوں کو نماز کے بعد روک رکھو اور وہ دونوں ان الفاظ کے ساتھ اللہ کی قَسم کھائیں کہ ہم اس قَسم کے عوض کوئی قیمت (فائدہ) حاصل نہیں کر رہے ہیں۔ اگرچہ ہمارا رشتہ دار ہی کیوں نہ ہو اور ہم اللہ واسطے کی گواہی نہیں چھپائیں گے ورنہ یقینا ہم گنہگاروں میں سے ہوں گے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcclxxvi{اور اگر بعد میں پتہ چلے کہ وہ (جھوٹی گواہی دے کر) گناہ کے مستوجب ہوئے ہیں تو پھر ان کی جگہ دو اور گواہ کھڑے ہوں (جو مرنے والے کے زیادہ) قریبی رشتہ دار ہوں جن کی حق تلفی ہوئی ہے اور اللہ کی قَسم کھائیں کہ ہماری گواہی ان (پہلے) دونوں کی گواہی سے زیادہ برحق ہے اور ہم نے کوئی زیادتی نہیں کی ورنہ ہم ظالموں میں سے ہوں گے۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcclxxvii{یہ طریقہ کار زیادہ قریب ہے اس کے کہ گواہ ٹھیک طریقہ پر گواہی دیں گے یا کم از کم وہ اس بات کا خوف تو کریں گے کہ ان کی قَسموں کے بعد کہیں اور قَسموں سے ان کی تردید نہ ہو جائے (یا انہیں یہ اندیشہ تو ہوگا کہ ان کی قَسموں کے بعد دوسرے گواہوں سے بھی قَسمیں لی جا سکتی ہیں) اللہ (کی نافرمانی) سے ڈرو۔ اور سنو۔ اور اللہ نافرمان لوگوں کو منزل تک نہیں پہنچاتا۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcclxxviii{(اس وقت کو یاد کرو) جب اللہ تمام رسولوں کو جمع کرکے پوچھے گا کہ تمہیں (اپنی امتوں کی طرف سے) کیا جواب ملا تھا تو وہ عرض کریں گے کہ ہمیں تو کچھ علم نہیں ہے۔ تو ہی غیب کی تمام باتوں کا بڑا جاننے والا ہے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcclxxix{(اور وہ وقت یاد کرو) جب خدا فرمائے گا اے مریم کے فرزند عیسیٰ میرا وہ انعام یاد کرو۔ جو میں نے تم پر اور تمہاری والدہ پر کیا تھا۔ جب میں نے روح القدس سے تمہاری تائید کی (جس کی وجہ سے) تم گہوارے میں اور ادھیڑ عمر میں لوگوں سے (یکساں) باتیں کرتے تھے اور جب میں نے تمہیں کتاب (لکھنے) حکمت (دانائی)، توراۃ اور انجیل کی تعلیم دی تم میرے حکم سے مٹی سے پرندہ کی شکل (پتلا) بناتے تھے اور پھر اس میں پھونک مارتے تھے اور وہ میرے حکم سے (سچ مچ) پرندہ بن جاتا تھا۔ اور تم میرے حکم سے پیدائشی اندھے اور کوڑھی کو اچھا کر دیتے تھے اور تم میرے حکم سے مردوں کو (زندہ کرکے قبروں سے) نکالا کرتے تھے۔ اور جب میں نے بنی اسرائیل کو تم سے روکا تھا۔ جب تم ان کے پاس بینات و معجزات لائے تھے تو ان میں سے جو کافر (منکر حق) تھے انہوں نے کہا تھا کہ یہ نہیں ہے، مگر کھلا ہوا جادو۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dcclxxx{اور وہ وقت قابل ذکر ہے جب میں نے حواریون کو الہام کیا کہ مجھ پر اور میرے رسول پر ایمان لاؤ۔ انہوں نے کہا کہ ہم ایمان لائے اور گواہ رہنا کہ ہم مسلمان (تیرے فرمانبردار بندے) ہیں۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcclxxxi{(حواریوں) کے بارے میں یہ قصہ بھی یاد رکھنے کے لائق ہے کہ انہوں نے کہا اے عیسیٰ بن مریم(ع) کیا آپ کا پروردگار اس بات پر قدرت رکھتا ہے کہ ہم پر آسمان سے کھانے کا ایک خوان اتارے عیسیٰ نے کہا اللہ (کی نافرمانی) سے ڈرو۔ اگر تم مؤمن ہو؟ ۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcclxxxii{کہنے لگے ہم چاہتے ہیں کہ اس میں سے کھائیں اور ہمارے دل مطمئن ہو جائیں اور ہمیں یقین ہو جائے کہ آپ نے ہم سے سچ کہا تھا۔ اور ہم اس پر گواہی دینے والوں میں سے ہو جائیں۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiii{عیسیٰ بن مریم(ع) نے (دعا کرتے ہوئے) کہا اے اللہ! اے ہمارے پروردگار! ہم پر آسمان سے ایک خوان نازل کر جو ہمارے لئے اور ہمارے اگلوں پچھلوں کے لئے عید قرار پائے اور تیری طرف سے قدرتی نشانی بن جائے۔ اور ہمیں روزی عطا فرما تو بہترین روزی عطا کرنے والا ہے۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiv{اللہ تعالیٰ نے فرمایا بے شک میں وہ (خوان) تم پر اتارنے والا ہوں اب اس کے بعد جو کفر اختیار کرے گا تو میں اسے ایسی سزا دوں گا جیسی دنیا جہان میں کسی کو بھی نہیں دی ہوگی۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcclxxxv{وہ وقت یاد کرو جب اللہ تعالیٰ فرمائے گا اے عیسیٰ بن مریم کیا تم نے لوگوں سے کہا تھا کہ اللہ کو چھوڑ کر مجھے اور میری ماں کو خدا بنا لو۔ عیسیٰ کہیں گے پاک ہے تیری ذات بھلا میں وہ بات کس طرح کہہ سکتا ہوں جس کا مجھے کوئی حق نہیں ہے اگر میں نے کوئی ایسی بات کہی ہوتی تو تجھے ضرور اس کا علم ہوتا۔ کیونکہ تو وہ سب کچھ جانتا ہے جو میرے دل میں ہے مگر میں تیرے اسرارِ نہانی کو نہیں جانتا۔ بلاشبہ تو غیب کی تمام باتوں کا بڑا جاننے والا ہے۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvi{میں نے ان سے کچھ نہیں کہا تھا سوائے اس بات کے جس کا تو نے مجھے حکم دیا تھا کہ عبادت کرو اللہ کی جو میرا بھی پروردگار ہے اور تمہارا بھی پروردگار ہے اور میں اس وقت تک ان پر گواہ تھا جب تک ان میں تھا پھر جب تو نے مجھے (دنیا سے) اٹھا لیا تو پھر تو ہی ان کا نگران تھا اور تو ہی ہر چیز پر گواہ ہے۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvii{اگر تو انہیں سزا دے تو یہ تیرے بندے ہیں اور اگر انہیں بخش دے تو تُو غالب ہے اور بڑا حکمت والا ہے۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcclxxxviii{ارشادِ قدرت ہوگا یہ وہ دن ہے کہ جس میں سچوں کی سچائی ان کو فائدہ پہنچائے گی۔ ان کے لئے ایسے بہشت ہوں گے جن کے نیچے سے نہریں جاری ہوں گی وہ ان میں ہمیشہ ہمیشہ رہیں گے۔ اللہ ان سے راضی اور وہ اللہ سے راضی (دونوں ایک دوسرے سے خوش) یہی سب سے بڑی کامیابی ہے۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcclxxxix{اللہ ہی کے لئے ہے حکومت آسمانوں کی اور زمین کی اور جو کچھ ان میں ہے اس سب کی اور وہ ہر شی پر قادر ہے۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dccxc{\basmalahur سب تعریف اللہ کے لئے ہے جس نے آسمانوں اور زمین کو پیدا کیا اور تاریکیوں اور روشنی کو بنایا پھر بھی جو کافر ہیں وہ دوسروں کو اپنے پروردگار کے برابر ٹھہراتے ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dccxci{وہ وہی ہے جس نے تم کو مٹی سے پیدا کیا۔ پھر (زندگی کی) ایک مدت مقرر کی اور ایک مقررہ مدت اور بھی ہے جو اسی کے پاس ہے پھر بھی تم شک کرتے ہو۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dccxcii{اور وہی (ایک) اللہ ہے آسمانوں میں بھی اور زمین میں بھی، جو تمہارے باطن و ظاہر اور جو کچھ تم بھلائی و برائی کرتے ہو سب کو جانتا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dccxciii{ان لوگوں کی حالت یہ ہے کہ ان کے پروردگار کی نشانیوں میں سے کوئی نشانی ان کے پاس نہیں آتی مگر یہ کہ وہ اس سے منہ پھیر لیتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dccxciv{چنانچہ انہوں نے اس حق (قرآن) کو بھی جھٹلایا جب وہ ان کے پاس آیا۔ سو عنقریب ان باتوں کی خبریں ان کے پاس آجائیں گی جن کا وہ مذاق اڑاتے رہے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dccxcv{کیا انہوں نے نہیں دیکھا کہ ہم نے ان سے پہلے کتنے دوروں کے لوگوں کو ہلاک و برباد کر دیا جنہیں ہم نے زمین میں وہ اقتدار دیا تھا جو تمہیں بھی نہیں دیا ہے اور ہم نے ان پر آسمان سے موسلادھار بارش برسائی۔ اور ہم نے ان کے نیچے نہریں بہائیں (انجامِ کار) ہم نے ان کے گناہوں (اور کفرانِ نعمت) کی پاداش میں ہلاک کر دیا اور ان کے بعد دوسرے دور کی نسلیں پیدا کیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dccxcvi{(اے رسول(ص)) اگر ہم کاغذ میں لکھی لکھائی کتاب بھی آپ پر اتارتے جسے یہ اپنے ہاتھوں سے چھو بھی لیتے۔ جب بھی کافر یہی کہتے کہ یہ نہیں ہے مگر کھلا ہوا جادو۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dccxcvii{اور وہ کہتے ہیں کہ اس (نبی(ص)) پر کوئی فرشتہ کیوں نہیں اتارا گیا؟ حالانکہ اگر ہم (کھلم کھلا) فرشتہ اتارتے تو پھر فیصلہ ہو چکا ہوتا پھر انہیں مہلت نہ دی جاتی۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dccxcviii{اور اگر ہم کوئی فرشتہ اتارتے تو اسے بھی آدمی کی شکل میں اتارتے اور اس طرح گویا ہم انہیں وہ شبہ کرنے کا موقع دیتے جو اب وہ کر رہے ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dccxcix{آپ سے پہلے بھی بہت سے پیغمبروں کا مذاق اڑایا جاتا رہا ہے تو (آخرکار) ان کا مذاق اڑانے والوں کو اسی عذاب نے آکر گھیر لیا جس کا وہ مذاق اڑایا کرتے تھے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dccc{اے رسول(ص) ان سے کہیے کہ زمین میں چلو پھرو اور پھر دیکھو۔ کہ جھٹلانے والوں کا کیا (بھیانک) انجام ہوا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dccci{(اے رسول(ص)) ان سے کہیے (پوچھئے) کہ جو کچھ آسمانوں اور زمین میں ہے وہ کس کا ہے؟ کہو سب کچھ اللہ ہی کا ہے اس نے مخلوق پر رحمت کرنا اپنے اوپر لازم کر لی ہے (اس لئے جلدی سزا نہیں دیتا) وہ قیامت تک جس میں کوئی شک نہیں ہے تم سب کو اکٹھا کرتا رہے گا (پھر یکجا کرکے لائے گا) جنہوں نے اپنے آپ کو خسارے اور نقصان میں ڈال دیا ہے وہ ایمان نہیں لائیں گے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dcccii{اور اسی (اللہ تعالیٰ) کا ہے جو کچھ رات اور دن میں سکونت پذیر ہے وہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dccciii{(اے رسول(ص)) کہو کیا میں اللہ کو چھوڑ کر کسی اور کو اپنا سرپرست بناؤں؟ جو آسمانوں اور زمین کا بنانے والا ہے جو (ساری مخلوق کو) روزی دیتا ہے (کھلاتا ہے) مگر اس کو کوئی روزی نہیں دیتا (اسے کوئی نہیں کھلاتا)۔ کہو۔ مجھے حکم دیا گیا ہے کہ میں سب سے پہلا مسلمان (خدا کے سامنے سر تسلیم جھکانے والا) بن کر رہوں اور یہ حکم بھی دیا گیا ہے کہ شرک کرنے والوں میں سے نہ ہونا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dccciv{کہیے کہ اگر میں اپنے پروردگار کی نافرمانی کروں۔ تو میں ایک بہت بڑے دن کے عذاب سے ڈرتا ہوں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dcccv{اس دن جس شخص سے عذاب ٹال دیا گیا اس پر اس (خدا) نے بڑا رحم کیا ہے۔ اور یہ بڑی نمایاں کامیابی ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dcccvi{اگر خدا تمہیں کوئی ضرر و زیاں پہنچانا چاہے تو اس کے پاس اس کا کوئی دور کرنے والا نہیں ہے۔ اور اگر کوئی بھلائی پہنچانا چاہے تو وہ ہر چیز پر قادر ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dcccvii{وہ اپنے بندوں پر مکمل اختیار اور قابو رکھنے والا ہے اور وہ بڑا حکمت والا بڑا باخبر ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dcccviii{(اے رسول(ص)) کہو کہ گواہی میں سب سے بڑھ کر کون سی چیز ہے؟ کہہ دیجیے کہ اللہ! جو میرے اور تمہارے درمیان گواہ ہے۔ اور یہ قرآن بذریعہ وحی میری طرف بھیجا گیا ہے تاکہ میں اس کے ذریعہ سے تمہیں اور جس تک یہ پہنچے سب کو ڈراؤں۔ کیا تم اس بات کی گواہی دیتے ہو کہ اللہ کے ساتھ کوئی اور خدا بھی ہیں؟ کہیے کہ میں تو یہ گواہی نہیں دیتا۔ کہو وہ واحد و یکتا ہے۔ اور میں تمہارے شرک سے بری و بیزار ہوں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dcccix{جن لوگوں کو ہم نے کتاب دی ہے وہ ان (پیغمبر(ص)) کو اس طرح پہنچاتے ہیں جس طرح اپنے بیٹوں کو پہنچاتے ہیں۔ مگر جن لوگوں نے اپنے آپ کو خسارے و نقصان میں ڈال رکھا ہے وہ ایمان نہیں لائیں گے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcccx{اور اس شخص سے بڑا ظالم کون ہے جو خدا پر جھوٹا بہتان باندھے یا اس کی آیتوں کو جھٹلائے۔ یقینا ظالم لوگ کبھی فلاح نہیں پائیں گے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcccxi{اور جس دن ہم سب کو (میدانِ حشر میں) اکٹھا کریں گے۔ اور جو لوگ (دنیا میں) شرک کرتے رہے ہیں ان سے کہیں گے کہ کہاں ہیں تمہارے وہ (معبود) جن کو تم خدا کا شریک گمان کرتے تھے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcccxii{اس وقت ان کے پاس اس کے سوا اور کوئی عذر نہ ہوگا کہ وہ کہیں گے ہمیں اپنے پروردگار اللہ کی قسم کہ ہم مشرک نہ تھے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcccxiii{دیکھو وہ کس طرح اپنے ہی برخلاف جھوٹ بولنے لگے؟ اور ان کی وہ تمام افترا پردازیاں گم ہوگئیں جو وہ کیا کرتے تھے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcccxiv{اور ان میں سے کچھ ایسے بھی ہیں جو آپ کی بات غور سے سنتے ہیں اور ہم نے ان کے دلوں پر پردے ڈال دیئے ہیں کہ وہ اسے سمجھتے نہیں ہیں اور کانوں میں گرانی ڈال دی ہے کہ سنتے نہیں ہیں۔ اور اگر وہ سارے کے سارے معجزے دیکھ لیں جب بھی ان پر ایمان نہیں لائیں گے۔ یہاں تک کہ جب آپ کے پاس آتے ہیں تو آپ سے بھی بحث و تکرار کرتے ہیں اور جو کافر ہیں (اور جنہوں نے بہرحال نہ ماننے کا فیصلہ کر لیا ہے) وہ سب کچھ سن کر بھی کہتے ہیں کہ یہ (قرآن) نہیں ہے مگر اگلے لوگوں کی (جھوٹی) داستانیں۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcccxv{یہ ایسے (ناہنجار) ہیں کہ دوسروں کو بھی اس (پیغمبرِ اسلام یا قرآن) سے روکتے ہیں۔ اور خود بھی اس سے دور بھاگتے ہیں اور وہ (اپنی اس روش سے کسی اور کو نہیں) اپنے آپ کو تباہ کر رہے ہیں مگر انہیں اس کا شعور نہیں ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcccxvi{اور کاش تم (ان کی وہ حالت) دیکھو جب وہ آتشِ دوزخ پر کھڑے کئے جائیں گے۔ اور وہ کہیں گے کہ کاش ہم واپس (دنیا میں) بھیج دیئے جائیں اور اپنے پروردگار کی نشانیوں کو نہ جھٹلائیں اور ایمان لانے والوں میں سے ہو جائیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcccxvii{(یہ اسے لئے کہیں گے کہ) ان پر وہ بات واضح و عیاں ہوگئی ہے جسے وہ پہلے چھپایا کرتے تھے (وہ ایسے ناہنجار ہیں کہ) اگر انہیں واپس بھیج دیا جائے تو پھر بھی وہی کریں گے جس سے ان کو منع کیا گیا تھا اور یقینا وہ باکل جھوٹے ہیں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcccxviii{اور وہ یہ بھی کہتے ہیں کہ زندگی تو بس یہی ہماری دنیا کی زندگی ہے اور ہم (قبروں سے) دوبارہ نہیں اٹھائے جائیں گے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcccxix{اور کاش تم وہ منظر دیکھو جب وہ اپنے پروردگار کے سامنے کھڑے کئے جائیں گے اور وہ ان سے پوچھے گا کیا یہ (قیامت) حق نہیں ہے؟ یہ کہیں گے ہاں حق ہے ہمیں اپنے رب کی قسم فرمائے گا تو اب اپنے کفر و انکار کی وجہ سے عذاب کا مزا چکھو۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcccxx{بے شک ان لوگوں نے گھاٹا اٹھایا ہے جنہوں نے اللہ کی بارگاہ میں حاضری کو جھٹلایا۔ یہاں تک کہ جب اچانک قیامت آجائے گی تو وہ لوگ کہیں گے ہائے افسوس ہم سے اس کے بارے میں کیسی کوتاہی ہوئی؟ اور وہ اپنے (گناہوں کے) بوجھ اپنی پشتوں پر اٹھائے ہوں گے۔ کیا برا بوجھ ہے جو وہ اٹھائے ہوئے ہیں؟ ۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcccxxi{اور دنیا کی زندگی نہیں ہے مگر کھیل تماشا اور بے شک آخرت والا گھر پرہیزگاروں کے لئے بہت اچھا ہے کیا تم عقل سے کام نہیں لیتے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dcccxxii{ہمیں معلوم ہے کہ یہ لوگ جو باتیں کرتے ہیں وہ بے شک آپ کو رنج پہنچاتی ہیں۔ (لیکن امر واقع یہ ہے کہ) یہ لوگ آپ کو نہیں جھٹلاتے بلکہ یہ ظالم لوگ (دراصل) اللہ کی آیتوں کا انکار کر رہے ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcccxxiii{بے شک آپ سے پہلے بھی بہت سے پیغمبروں کو جھٹلایا گیا۔ تو انہوں نے جھٹلائے جانے اور اذیت پہنچائے جانے پر صبر کیا یہاں تک کہ ہماری مدد ان کے پاس آئی اور اللہ کی باتوں کو کوئی بدلنے والا نہیں ہے اور پیغمبروں کی کچھ خبریں تو آپ کو پہنچ ہی چکی ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcccxxiv{اور اگر حق سے ان کی روگردانی کرنا آپ پر بہت گراں ہے تو پھر اگر ہو سکتا ہے تو زمین میں کوئی سرنگ لگا کر یا آسمان میں کوئی سیڑھی لگا کر ان کے پاس کوئی معجزہ لاؤ۔ مگر وہ پھر بھی ایمان نہیں لائیں گے اور اگر اللہ (زبردستی) چاہتا تو ان سب کو ہدایت پر جمع کر دیتا۔ لہٰذا آپ ناواقف لوگوں میں سے نہ بنیں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dcccxxv{دعوتِ حق صرف وہی لوگ قبول کرتے ہیں جو سنتے ہیں اور جو مردے ہیں ان کو بس اللہ ہی (قیامت کے دن) اٹھائے گا پھر وہ اس کی طرف لوٹائے جائیں گے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dcccxxvi{اور وہ کفار کہتے ہیں کہ ان پر ان کے پروردگار کی طرف سے کوئی معجزہ کیوں نازل نہیں ہوتا؟ کہہ دیجیے کہ بے شک اللہ تو کوئی بھی معجزہ نازل کرنے پر قادر ہے لیکن ان میں سے اکثر جانتے نہیں ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dcccxxvii{کوئی زمین میں چلنے والا جانور اور اپنے دونوں پروں سے اڑنے والا پرندہ نہیں ہے مگر تمہاری ہی طرح مختلف اقسام اور گروہ ہیں ہم نے کتاب میں کوئی کمی و کوتاہی نہیں کی ہے پھر وہ سب کے سب اپنے رب کے پاس محشور (جمع) کئے جائیں گے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dcccxxviii{بہرے اور گونگے ہیں جوکہ طرح طرح کے اندھیروں میں پڑے ہیں۔ اللہ جسے چاہتا ہے اسے گمراہی میں چھوڑ دیتا ہے اور جسے چاہتا ہے سیدھے راستے پر لگا دیتا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dcccxxix{اے رسول(ص) کہو کہ تم غور کرکے بتاؤ کہ اگر تمہارے پاس اللہ کا عذاب آجائے یا (اچانک) قیامت آجائے تو اللہ کے سوا کسی اور کو پکاروگے؟ بتاؤ اگر سچے ہو۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dcccxxx{بلکہ اسی کو ہی پکاروگے اور اگر وہ چاہے گا تو (مصیبت) کو دور کر دے گا جس کے لئے تم نے اسے پکارا ہے اور تم انہیں بھول جاؤگے جن کو اس کا شریک ٹھہراتے ہو۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dcccxxxi{بلکہ اے رسول(ص) بے شک ہم نے آپ سے پہلے بہت سی امتوں کی طرف پیغمبر بھیجے اور ان کی نافرمانی پر پہلے تو ہم نے ان کو تنگدستی اور تکلیف میں مبتلا کیا۔ تاکہ تضرع و زاری کریں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dcccxxxii{جب ان کے پاس ہماری طرف سے سختی آئی تو آخر انہوں نے تضرع و زاری کیوں نہ کی؟ لیکن ان کے دل تو اور بھی سخت ہوگئے اور شیطان نے (ان کی نظروں میں) ان کاموں کو جو وہ کرتے تھے آراستہ کرکے پیش کیا۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiii{اور جب انہوں نے اس نصیحت کو بھلا دیا جو انہیں کی گئی تھی تو ہم نے (ابتلا و امتحان کے طور پر) ان کے لئے ہر چیز کے دروازے کھول دیئے۔ یہاں تک کہ وہ عطا کردہ چیزوں (نعمتوں) سے خوب خوش ہوگئے اور اترانے لگے تو ہم نے اچانک انہیں پکڑ لیا۔ تو وہ ایک دم مایوس ہوگئے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiv{پس ظالموں کی جڑ کاٹ دی گئی (ان کی نسل قطع ہوگئی) اور سب تعریف اللہ کے لئے ہے جو سارے جہانوں کا پروردگار ہے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dcccxxxv{اے رسول کہیے غور کرکے بتاؤ کہ اگر اللہ تعالیٰ تمہارے کان اور تمہاری آنکھیں لے لے (یعنی قوت شنوائی اور بینائی چھین لے) اور تمہارے دلوں پر مہر لگا دے تو اللہ کے سوا اور کون خدا ہے جو تمہیں یہ چیزیں لا دے؟ دیکھئے ہم کس طرح الٹ پلٹ کر اپنی توحید کی نشانیاں واضح کرتے ہیں پھر بھی وہ روگردانی کرتے ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvi{کہیے ذرا غور کرکے بتاؤ کہ اگر تم پر اللہ کا عذاب اچانک یا علانیہ آجائے تو ظالم لوگوں کے سوا اور کون ہلاک و برباد ہوگا؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvii{اور ہم پیغمبروں کو نہیں بھیجتے مگر نیکوکاروں کو خوشخبری دینے والا اور بدکاروں کو ڈرانے والا بنا کر جو ایمان لے آئیں اور اپنی اصلاح کر لیں نیک عمل کریں۔ تو نہ ان کے لئے کوئی خوف ہے اور نہ ہی وہ غمگین ہوں گے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dcccxxxviii{اور جن لوگوں نے ہماری آیتوں کو جھٹلایا ان کو ان کی نافرمانی کی وجہ سے عذاب پہنچے گا۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dcccxxxix{اے رسول کہہ دیجیے میں تم سے یہ نہیں کہتا کہ میرے پاس اللہ کے خزانے ہیں اور نہ یہ کہ میں غیب جانتا ہوں اور نہ تم سے یہ کہتا ہوں کہ میں فرشتہ ہوں میں تو صرف اس وحی کی پیروی کرتا ہوں جو مجھے کی جاتی ہے آپ کہیے! کیا اندھا اور آنکھوں والا برابر ہے؟ تم غور و فکر کیوں نہیں کرتے؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dcccxl{اور آپ اس (وحی شدہ قرآن) کے ذریعہ سے ان لوگوں کو ڈرائیں۔ جنہیں خوف (اندیشہ) ہے کہ وہ اپنے پروردگار کی طرف محشور ہوں گے کہ اس (اللہ) کے سوا ان کا نہ کوئی سرپرست ہوگا اور نہ کوئی سفارشی شاید کہ وہ متقی و پرہیزگار بن جائیں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dcccxli{(اے رسول(ص)) ان لوگوں کو اپنے پاس سے نہ دھتکارو۔ جو اپنے پروردگار کی رضا جوئی کی خاطر صبح و شام اسے پکارتے ہیں۔ ان کا کچھ بھی حساب کتاب آپ کے ذمہ نہیں ہے اور نہ ہی آپ کا کچھ بھی حساب کتاب ان کے ذمہ ہے اور اگر آپ نے پھر بھی انہیں دھتکار دیا تو آپ بے انصافی کرنے والوں میں سے ہو جائیں گے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dcccxlii{اس طرح ہم نے بعض لوگوں کو بعض کے ذریعہ سے آزمائش میں ڈال رکھا ہے تاکہ وہ کہیں کہ کیا یہی وہ ہیں جن کو ہم میں سے اللہ نے اپنے (خاص) احسان سے نوازا ہے؟ کیا اللہ اپنے شکر گزار بندوں کو (ان سے) زیادہ نہیں جانتا ہے؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dcccxliii{اور جب آپ کے پاس وہ لوگ آئیں جو ہماری آیتوں پر ایمان لائے ہیں تو ان سے کہو سلامٌ علیکم (تم پر سلامتی ہو)۔ تمہارے پروردگار نے اپنے اوپر رحمت لازم قرار دی ہے (لہٰذا) اگر تم میں سے کوئی شخص جہالت و نادانی کی وجہ سے کوئی برائی کرے پھر اس کے بعد توبہ کرلے اور اپنی اصلاح کرلے تو بےشک وہ (اللہ) بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dcccxliv{اور اسی طرح ہم اپنی آیتوں کو تفصیل کے ساتھ بیان کرتے ہیں تاکہ مجرموں کا راستہ بالکل واضح ہو جائے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dcccxlv{اے رسول(ص) کہہ دیجیے! کہ مجھے منع کیا گیا ہے کہ میں ان (معبودانِ باطل) کی عبادت کروں جن کو تم اللہ کے سوا خدا کہہ کر پکارتے ہو میں تمہاری خواہشات کی پیروی نہیں کروں گا۔ اس صورت میں تو میں گمراہ ہو جاؤں گا۔ اور ہدایت یافتہ لوگوں سے نہ رہوں گا۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dcccxlvi{کہہ دیجیے! کہ میں اپنے پروردگار کی طرف سے روشن دلیل پر قائم ہوں۔ اور تم نے اسے جھٹلا دیا ہے جس (عذاب) کی تم جلدی کرتے ہو وہ میرے پاس نہیں ہے فیصلہ کرنے کا اختیار اللہ کے پاس ہے وہ حق بیان کرتا ہے اور وہ بہترین فیصلہ کرنے والا ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dcccxlvii{کہہ دیجیے! کہ جس عذاب کے لئے تم جلدی کرتے ہو اگر وہ میرے پاس ہوتا تو میرے اور تمہارے درمیان کب کا فیصلہ ہو چکا ہوتا۔ اور اللہ ظالموں کو زیادہ بہتر جانتا ہے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dcccxlviii{اور اس (اللہ) کے پاس ہیں غیب کی کنجیاں، جنہیں اس کے سوا اور کوئی نہیں جانتا اور وہ اسے بھی جانتا ہے جو خشکی میں ہے۔ اور اسے بھی جانتا ہے جو تری میں ہے اور کوئی پتا نہیں گرتا مگر وہ اسے جانتا ہے۔ اور زمین کی تاریکیوں میں کوئی دانہ نہیں ہے اور نہ کوئی تر ہے اور نہ کوئی خشک ہے مگر یہ کہ وہ کتابِ مبین میں موجود ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dcccxlix{وہی (اللہ) ہے جو رات کے وقت تمہاری روحیں قبض کر لیتا ہے۔ اور تم دن میں جو کچھ کرتے ہو اسے جانتا ہے پھر تمہیں اس (دن) میں اٹھاتا ہے۔ تاکہ (زندگی کی) مقررہ مدت پوری ہو پھر تمہاری بازگشت اسی کی طرف ہے پھر وہ تمہیں بتائے گا جو کچھ (بھلا یا برا) تم کرتے تھے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dcccl{اور وہ اپنے بندوں پر غالب ہے (اور پوری قدرت رکھتا ہے) اور وہ تم پر حفاظت (نگرانی) کرنے والے (فرشتے) بھیجتا ہے۔ یہاں تک کہ جب تم میں سے کسی کی موت کا وقت آتا ہے تو ہمارے بھیجے ہوئے (فرشتے) اس کی روح قبض کر لیتے ہیں اور وہ کوتاہی نہیں کرتے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dcccli{پھر وہ اللہ کے پاس جو ان کا حقیقی مالک ہے لوٹائے جاتے ہیں۔ خبردار فیصلہ کرنے کا اختیار اسی کو حاصل ہے اور وہ سب سے زیادہ جلدی حساب لینے والا ہے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccclii{(اے رسول(ص)) کہیے کہ تمہیں صحرا و سمندر کے اندھیروں سے (مصیبتوں سے) کون نجات دیتا ہے؟ جب تم اسے گڑگڑا کر اور چپکے چپکے پکارتے ہو۔ (اور دل میں کہتے ہو) کہ اگر وہ ہمیں ان (خطرات) سے نجات دے دے تو ہم شکر گزاروں میں سے ہوں گے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dcccliii{(اے رسول(ص)) کہیئے اللہ تمہیں ان سے اور ہر رنج و غم سے نجات دیتا ہے پھر بھی تم شرک کرتے ہو۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dcccliv{کہہ دو وہ (اللہ) اس پر قادر ہے کہ تم پر کوئی عذاب نازل کرے تمہارے اوپر سے یا تمہارے پاؤں کے نیچے سے (بھیج دے)۔ یا تمہیں مختلف گروہوں میں تقسیم کرکے اور باہم خلط ملط کرکے ٹکرا دے اور تم میں سے بعض کو بعض کی طاقت و سختی کا مزا چکھا دے۔ دیکھیے ہم کس طرح الٹ پھیر کرکے اپنی آیات (دلیلوں) اور نشانیوں کو بیان کرتے ہیں تاکہ وہ سمجھ جائیں۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccclv{اور آپ کی قوم نے اس (قرآن) کو جھٹلایا حالانکہ وہ حق ہے کہہ دیجیے کہ میں تمہارا وکیل (نگہبان) نہیں ہوں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccclvi{اور ہر خبر (کے وقوع) کا ایک وقت مقرر ہے۔ اور عنقریب تمہیں معلوم ہو جائے گا۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccclvii{اور جب دیکھو کہ لوگ ہماری آیتوں کے بارے میں نکتہ چینی اور بے ہودہ بحث کر رہے ہیں تو تم ان سے کنارہ کش ہو جاؤ۔ یہاں تک کہ وہ کسی اور بات میں مشغول ہو جائیں اور (اے مخاطب) اگر کبھی شیطان تجھے بھلا دے تو یاد آنے کے بعد ظالم لوگوں کے پاس مت بیٹھ۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccclviii{ان (غلط کار لوگوں) کے حساب و کتاب کی ذمہ داری پرہیزگار لوگوں پر نہیں ہے (جو ان برے کاموں سے بچتے رہتے ہیں) ہاں البتہ (ان کے ذمہ صرف) نصیحت کرنا ہے تاکہ وہ (برے لوگ) پرہیزگاری اختیار کریں۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccclix{چھوڑو ان لوگوں کو جنہوں نے اپنے دین و مذہب کو کھیل اور تماشا بنا رکھا ہے اور انہیں دنیا کی زندگی نے دھوکہ و فریب میں مبتلا کر رکھا ہے۔ اور ان کو اس (قرآن) کے ذریعہ سے نصیحت کرو۔ ایسا نہ ہو کہ کوئی شخص اپنے کئے کے وبال میں پھنس جائے حالانکہ اللہ کے سوا اس کا نہ کوئی سرپرست ہوگا اور نہ کوئی سفارشی۔ اور اگر وہ اپنے چھٹکارے کے لیے معاوضہ دینا چاہے گا تو وہ قبول نہیں کیا جائے گا یہ وہ لوگ ہیں جو اپنے کرتوتوں کے وبال میں پھنسے ہوئے ہیں ان کے کفر کی وجہ سے ان کے پینے کے لیے کھولتا ہوا گرم پانی ہوگا اور دردناک عذاب۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccclx{کہیے! کیا ہم اللہ کو چھوڑ کر ان کو پکاریں جو نہ ہمیں نفع پہنچا سکتے ہیں اور نہ نقصان اور بعد اس کے کہ خدا ہم کو سیدھا راستہ دکھا چکا ہے ہم الٹے پاؤں پھر جائیں اس شخص کی طرح جسے شیطانوں (بھوتوں پریوں) نے (کہیں) زمین میں بے راہ اور سرگردان کر دیا جبکہ اس کے کچھ ساتھی اسے سیدھے راستے کی طرف بلا رہے ہوں کہ ہماری طرف آؤ مگر اسے کچھ سجھائی نہیں دیتا کہو ہدایت و راہنمائی تو بس اللہ کی ہدایت و راہنمائی ہے۔ اور ہمیں حکم دیا گیا ہے کہ ہم تمام جہانوں کے پروردگار کے سامنے سر تسلیم خم کر دیں۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccclxi{اور (ہم سے کہا گیا ہے کہ) نماز ادا کرو۔ اور اس سے (اس کی نافرمانی سے) ڈرو اور وہی وہ ہے جس کی بارگاہ میں تم محشور ہوگے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccclxii{وہی تو وہ (خدا) ہے جس نے آسمانوں اور زمین کو برحق پیدا کیا۔ جس دن وہ کہے گا کہ ہوجا بس وہ ہو جائے گا۔ اس کا قول حق اور سچ ہے اسی کی حکومت ہوگی جس دن صور پھونکا جائے گا وہ غیب اور حاضر سب کا جاننے والا ہے اور وہ بڑا حکمت والا، بڑا باخبر ہے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccclxiii{(وہ وقت یاد کرو) جب ابراہیم (ع) نے اپنے باپ (یعنی چچا) آزر سے کہا۔ کیا تم بتوں کو خدا بناتے ہو؟ میں تمہیں اور تمہاری قوم کو کھلی ہوئی گمراہی میں دیکھ رہا ہوں۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccclxiv{اور اسی طرح ہم ابراہیم(ع) کو آسمانوں اور زمین کی سلطنت دکھا رہے تھے تاکہ وہ یقین کرنے والوں میں سے ہو جائیں۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccclxv{چنانچہ جب ان (ابراہیم) پر رات کی تاریکی چھا گئی تو انہوں نے ایک ستارہ کو دیکھا تو کہا یہ میرا رب ہے؟ تو جب وہ ڈوب گیا تو کہا۔ میں ڈوب جانے والوں سے محبت نہیں کرتا۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccclxvi{اور جب چاند کو چمکتے ہوئے دیکھا تو کہا یہ میرا پروردگار ہے؟ لیکن جب وہ بھی غروب ہوگیا۔ تو کہا کہ اگر میرا پروردگار میری ہدایت و راہنمائی نہ کرتا رہا تو میں گمراہ لوگوں میں سے ہو جاؤں گا۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccclxvii{پھر جب سورج کو چمکتے دیکھا تو کہا یہ میرا پروردگار ہے؟ یہ سب سے بڑا ہے۔ مگر جب وہ بھی غروب ہوگیا تو کہا اے میری قوم! میں اس شرک سے بری و بیزار ہوں جو تم کرتے ہو۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccclxviii{میں ہر طرف سے ہٹ کر اپنا رخ اس کی طرف کرتا ہوں جس نے آسمانوں اور زمین کو پیدا کیا ہے اور میں مشرکوں میں سے نہیں ہوں۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccclxix{اور ان کی قوم ان سے بحث کرنے لگی۔ فرمایا تم مجھ سے اللہ کے بارے میں بحث کرتے ہو؟ حالانکہ وہ مجھے ہدایت دے چکا ہے اور میں ان سے نہیں ڈرتا جنہیں تم خدا کا شریک ٹھہراتے ہو۔ مگر یہ کہ میرا پروردگار کوئی بات چاہے میرا پروردگار علم کے اعتبار سے ہر چیز پر حاوی اور محیط ہے کیا تم نصیحت قبول نہیں کرتے؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccclxx{اور میں بھلا ان سے کس طرح ڈروں جن کو تم خدا کا شریک ٹھہراتے ہو۔ جب کہ تم اس سے نہیں ڈرتے کہ تم نے ایسی چیزوں کو خدا کا شریک بنا رکھا ہے۔ جن کے متعلق اس نے تمہارے پاس کوئی دلیل نہیں بھیجی ہے۔ سو دونوں گروہوں میں سے کون امن و اطمینان کا زیادہ حقدار ہے (بتاؤ) اگر تم کچھ علم رکھتے ہو؟\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccclxxi{جو لوگ ایمان لائے اور اپنے ایمان کو ظلم سے آلودہ نہیں کیا انہی کے لئے امن و امان ہے اور وہی ہدایت یافتہ ہیں۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dccclxxii{یہ تھی ہماری وہ دلیل جو ہم نے ابراہیم (ع) کو ان کی قوم کے مقابلہ میں عطا کی تھی۔ ہم جس کے چاہتے ہیں درجے بلند کرتے ہیں آپ کا پروردگار بڑا حکمت والا، بڑا جاننے والا ہے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccclxxiii{اور ہم نے انہیں اسحاق جیسا (بیٹا) اور یعقوب (جیسا پوتا) عطا فرمایا۔ ہر ایک کو ہم نے ہدایت دی اور ان سے پہلے نوح کو ہدایت دی۔ اور ان (نوح یا ابراہیم) کی اولاد میں سے داؤد، سلیمان، ایوب، یوسف، موسیٰ، ہارون کو (بھی ہدایت دی) اور اسی طرح ہم نیکوکاروں کو جزا دیا کرتے ہیں۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccclxxiv{اور زکریا، یحییٰ، عیسیٰ اور الیاس کو (بھی ہم نے ہدایت دی) جو سب صالحین میں سے تھے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dccclxxv{اور اسماعیل، یسع، یونس اور لوط کو (بھی ہدایت دی) اور ان سب کو ہم نے تمام جہانوں پر فضیلت دی۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dccclxxvi{اور ان کے آباء و اجداد اور اولاد اور بھائیوں میں سے بھی (کچھ کو ہدایت دی) اور ہم نے انہیں منتخب کیا اور سیدھے راستے کی ہدایت دی۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dccclxxvii{یہ اللہ کی خاص ہدایت ہے جس کے ذریعے سے وہ بندوں میں سے جس کی چاہتا ہے راہنمائی کرتا ہے اور اگر انہوں نے شرک کیا ہوتا تو ان کے وہ سب عمل برباد ہو جاتے جو وہ کیا کرتے تھے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dccclxxviii{یہ وہ لوگ ہیں جن کو ہم نے کتاب کا حکم اور نبوت عطا کی اب اگر یہ (مکہ والے) لوگ ان چیزوں کا انکار کرتے ہیں تو کوئی پروا نہیں ہے ہم نے ان چیزوں کا ذمہ دار ان لوگوں کو بنایا ہے جو انکار کرنے والے نہیں ہیں۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dccclxxix{یہ وہ لوگ ہیں جن کو اللہ نے ہدایت دی ہے سو آپ بھی ان کے راستہ اور طریقہ پر چلیں۔ کہہ دیجئے کہ میں اس پر تم سے کوئی معاوضہ نہیں مانگتا وہ (قرآن) تو تمام عالمین کے لئے نصیحت ہے۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dccclxxx{ان لوگوں نے اللہ کی اس طرح قدر نہیں کی جس طرح قدر کرنے کا حق تھا۔ جب انہوں نے یہ کہا کہ اللہ نے کسی بشر پر کوئی چیز نازل نہیں کی ان سے کہیے کہ وہ کتاب کس نے نازل کی تھی جسے موسیٰ لے کر آئے تھے؟ جو لوگوں کے لئے روشنی اور ہدایت (کا ذریعہ) تھی؟ جسے تم نے ورق ورق کر رکھا ہے۔ اس کا کچھ حصہ تو تم ظاہر کرتے ہو (مگر) بہت سا حصہ چھپاتے ہو۔ حالانکہ تمہیں وہ باتیں سکھائی گئیں ہیں جو نہ تمہیں معلوم تھیں اور نہ تمہارے باپ دادا کو کہیے اللہ نے (وہ کتاب نازل کی تھی)۔ پھر ان کو چھوڑ دیجیے کہ وہ اپنی بے ہودہ نکتہ چینی میں کھیلتے رہیں۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dccclxxxi{اور یہ وہ بابرکت کتاب ہے جسے ہم نے نازل کیا ہے جو اپنے سے پہلے والی کتابوں کی تصدیق کرنے والی ہے (اس لئے نازل کی ہے) کہ تم مکہ اور اس کے اطراف و جوانب والے لوگوں کو ڈراؤ۔ اور جو لوگ قیامت پر ایمان رکھتے ہیں (اسے برحق) مانتے ہیں وہ اس (قرآن) پر بھی ایمان لاتے ہیں اور وہ اپنی نمازوں پر پابندی کرتے ہیں۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dccclxxxii{اور اس شخص سے بڑا ظالم اور کون ہوگا جو خدا پر جھوٹا بہتان باندھے یا یہ کہے کہ مجھ پر وحی آتی ہے حالانکہ اس پر کوئی وحی نہ کی گئی ہو اور (اس سے بڑا ظالم کون ہے) جو کہے کہ جیسا کلام اللہ نے نازل کیا ہے ایسا میں بھی نازل کروں گا۔ (یعنی نازل کر سکتا ہوں) اے کاش! تم وہ منظر دیکھو جب کہ ظالم لوگ موت کے سکرات (سختیوں) میں ہوں گے اور موت والے فرشتے اپنے ہاتھ پھیلائے ہوئے ہوں گے (اور کہیں گے) اپنی روحوں کو ان (سکرات) سے نکالو۔ آج تمہیں ذلت آمیز عذاب کیا جائے گا تمہارے خدا کے بارے میں غلط باتیں کرنے اور اس کی آیتوں کے مقابلہ میں تکبر کرنے کی پاداش میں۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiii{اور تم اسی طرح ہماری بارگاہ میں تن تنہا آئے ہو جس طرح ہم نے پہلی بار تمہیں پیدا کیا تھا۔ اور اپنے پیچھے چھوڑ آئے جو کچھ ساز و سامان ہم نے تمہیں عطا کیا تھا۔ اور (آج) ہم تمہارے ساتھ وہ سفارشی نہیں دیکھتے جن کے متعلق تم گمان کرتے تھے کہ وہ تمہارے معاملہ میں ہمارے شریک ہیں؟ (آج) تمہارے باہمی تعلقات منقطع ہوگئے اور جو تمہارا گمان فاسد تھا وہ غائب ہوگیا۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiv{بے شک اللہ ہی ہے جو دانہ اور گھٹلی کو شگافتہ کرنے والا ہے جو زندہ کو مردہ سے اور مردہ کو زندہ سے نکالتا ہے یہ ہے اللہ تم کدھر بہکے جاتے ہو؟\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dccclxxxv{وہ (رات کے اندھیرے سے) صبح کا برآمد کرنے والا ہے۔ اور اسی نے رات کو سکون و راحت کے لئے بنایا اور سورج و چاند کو (ماہ و سال کے) حساب کے لئے بنایا۔ یہ غالب اور بڑے علم والے (خدا) کا مقرر کردہ نظام ہے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvi{اور وہ وہی ہے جس نے تمہارے لئے ستارے بنائے تاکہ تم ان کے ذریعہ سے خشکی اور تری کے اندھیروں میں راہنمائی حاصل کرو۔ بے شک ہم نے علم رکھنے والوں کے لئے دلائل کھول کر بیان کر دیے ہیں۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvii{اور وہ (اللہ) وہی تو ہے جس نے تم (سب) کو ایک شخص (آدم(ع)) سے پیدا کیا ہے پھر ہر ایک کے لیے ایک قرارگاہ ہے (باپ کی پشت) اور ایک سونپے جانے کا مقام ہے (رحم مادر) اور ہم نے سمجھ بوجھ رکھنے والوں کے لئے (اپنی قدرت کی) نشانیاں تفصیل سے بیان کر دی ہیں۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dccclxxxviii{وہ وہی تو ہے جس نے آسمان کی (بلندی) سے پانی نازل کیا پھر ہم نے اس کے ذریعہ سے ہر قسم کے نباتات اگائے پھر اس سے ہری بھری شاخیں نکالیں کہ ہم اس سے تہہ بہ تہہ (گھتے ہوئے) دانے نکالتے ہیں اور کھجور کے درختوں سے یعنی ان کے شگوفوں سے گچھے نکالتے ہیں جو زمین کی طرف جھکے ہوئے ہیں اور ہم نے انگور، زیتون اور انار کے باغات پیدا کئے جو باہم مشابہ بھی ہیں اور غیر مشابہ بھی اور اس کے پھل کو دیکھو جب وہ پھلتا ہے اور اس کے (پکنے کی کیفیت) کو دیکھو اور بے شک اس میں ایمان لانے والوں کے لئے (اللہ کی توحید و قدرت کی) نشانیاں ہیں۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dccclxxxix{اور ان لوگوں نے جنات کو اللہ کا شریک بنایا ہے حالانکہ اس نے انہیں پیدا کیا ہے اور انہوں نے اس کے لئے جہالت کی وجہ سے بیٹے اور بیٹیاں تراش کر رکھی ہیں۔ وہ پاک ہے اور برتر ہے اس سے جو وہ اس کے بارے میں بیان کرتے ہیں۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcccxc{وہ آسمانوں اور زمین کا موجد ہے اس کے لئے اولاد کیونکر ہو سکتی ہے حالانکہ اس کی کوئی بیوی ہی نہیں ہے۔ اور اسی نے ہر چیز کو پیدا کیا ہے اور وہ ہر چیز کا خوب جاننے والا ہے۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcccxci{یہ ہے اللہ جو تمہارا پروردگار ہے اس کے سوا کوئی خدا نہیں ہے وہی ہر چیز کا خالق ہے لہٰذا اسی کی عبادت کرو۔ اور وہ ہر چیز کا وکیل و کفیل ہے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcccxcii{نگاہیں اسے نہیں پا سکتیں اور وہ نگاہوں کو پا لیتا ہے اور وہ لطیف (جسم و جسمانیات سے مبرا ہے) اور خبیر (بڑا باخبر) ہے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcccxciii{تمہارے پاس تمہارے پروردگار کی طرف سے بصیرتیں (روشن دلیلیں) آچکیں اب جو بصیرت سے کام لے گا وہ اپنا فائدہ کرے گا۔ اور جو اندھا بنا رہے گا وہ اپنا نقصان کرے گا۔ اور میں تمہارے اوپر نگران نہیں ہوں۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcccxciv{اور ہم اپنی آیتیں یونہی الٹ پھیر کر بیان کرتے ہیں اور اس لئے کرتے ہیں کہ یہ لوگ کہیں کہ آپ نے (کسی سے) پڑھا ہے اور تاکہ ہم اسے علم رکھنے والوں کے لئے واضح کر دیں۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcccxcv{آپ اس وحی کی پیروی کریں جو آپ کے پروردگار کی طرف سے آپ کو کی جاتی ہے اس کے سوا کوئی خدا نہیں ہے۔ اور مشرکوں سے بےتوجہی اختیار کریں۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcccxcvi{اور اگر خدا (زبردستی) چاہتا تو وہ شرک نہ کرتے اور ہم نے آپ کو ان پر نگہبان مقرر نہیں کیا اور نہ ہی آپ ان کے ذمہ دار ہیں۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcccxcvii{اور (خبردار) تم ان کو گالیاں نہ دو جن کو یہ اللہ کے سوا پکارتے ہیں ورنہ یہ لوگ اپنی جہالت و ناسمجھی کی بنا پر حد سے گزر کر اللہ کو گالیاں دیں گے۔ اسی طرح ہم نے ہر گروہ کے عمل کو (اس کی نظروں میں) آراستہ کیا ہے۔ پھر ان کی بازگشت ان کے پروردگار کی طرف ہے پھر وہ انہیں بتائے گا جو کچھ وہ کیا کرتے تھے۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcccxcviii{اور انہوں نے اللہ کے نام کی بڑی سخت قسمیں کھائی ہیں کہ اگر ان کی مرضی کے مطابق کوئی معجزہ ان کے پاس آجائے تو وہ ضرور ایمان لائیں گے۔ کہہ دیجیے کہ معجزہ تو بس اللہ ہی کے پاس ہے جب کوئی ایسا معجزہ آبھی جائے گا تو یہ جب بھی ایمان نہیں لائیں گے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcccxcix{(تمہیں کیا خبر کہ) ہم ان کے دلوں اور آنکھوں کو پھیر دیں گے (تہہ و بالا کر دیں گے) لہٰذا جس طرح وہ اس قرآن پر پہلی مرتبہ ایمان نہیں لائے تھے اب بھی نہیں لائیں گے اور ہم انہیں چھوڑ دیں گے تاکہ یہ اپنی سرکشی میں اندھے بنے پھرتے رہیں۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cm{اور اگر ہم ان کی طرف فرشتے بھی نازل کر دیں اور ان سے مردے بھی کلام کریں اور خواہ ہم ہر چیز کو ان کے سامنے لاکھڑا کر دیں تب بھی یہ ایمان لانے والے نہیں ہیں مگر یہ کہ اللہ (اپنی قدرتِ قاہرہ سے) چاہے۔ لیکن اکثر لوگ جاہل ہیں۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cmi{اور اسی طرح ہم نے ہر نبی کے لیے انسانوں اور جنوں میں سے شیطانوں کو دشمن قرار دیا ہے جو ایک دوسرے کو دھوکہ و فریب دینے کے لیے بناوٹی باتوں کی سرگوشی کرتے ہیں اور اگر آپ کا پروردگار (زبردستی) چاہتا، تو یہ ایسا نہ کرتے پس آپ انہیں اور جو کچھ وہ افترا کر رہے ہیں اسے چھوڑ دیں۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cmii{تاکہ ان (بناوٹی باتوں) کی طرف ان لوگوں کے دل مائل ہوں جو آخرت پر ایمان نہیں رکھتے اور تاکہ وہ اسے پسند کریں اور تاکہ وہ ان (برائیوں) کا ارتکاب کریں جن کے یہ مرتکب ہو رہے ہیں۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cmiii{کیا میں اللہ کے سوا کسی اور کو فیصل اور منصف تلاش کروں؟ حالانکہ وہ وہی ہے جس نے تمہاری طرف مفصل اور واضح کتاب نازل کی ہے۔ اور ہم نے جن کو (آسمانی) کتاب دی وہ (اہل کتاب) جانتے ہیں کہ یہ (قرآن) آپ کے پروردگار کی طرف سے حق کے ساتھ نازل ہوا ہے پس آپ ہرگز شک کرنے والوں میں سے نہ ہوں۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cmiv{اور آپ کے پروردگار کی بات صدق و سچائی اور عدل و انصاف کے لحاظ سے مکمل ہے اور اس کی باتوں کا کوئی بدلنے والا نہیں ہے اور وہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cmv{(اے رسول(ص)) اگر آپ زمین کے رہنے والوں کی اکثریت کی اطاعت کریں گے (ان کا کہنا مانیں گے) تو وہ آپ کو اللہ کے راستہ سے بھٹکا دیں گے یہ لوگ پیروی نہیں کرتے مگر گمان کی اور وہ محض تخمینے لگاتے اور اٹکل پچو باتیں کرتے ہیں۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cmvi{بے شک آپ کا پروردگار ہی بہتر جانتا ہے کہ اس کی راہ سے بھٹکا ہوا کون ہے؟ اور وہ خوب جانتا ہے ہدایت یافتہ لوگوں کو۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cmvii{پس جس (ذبیحہ) پر اللہ کا نام لیا گیا ہے اس میں سے کھاؤ۔ اگر تم اس کی آیتوں پر ایمان رکھتے ہو۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cmviii{اور تمہیں کیا ہوگیا ہے کہ تم اس (ذبیحہ) میں سے نہیں کھاتے جس پر اللہ کا نام لیا گیا ہے؟ حالانکہ اس نے جن (جانوروں) کو تم پر حرام قرار دیا ہے ان کو تمہارے لئے تفصیل سے بیان کر دیا ہے۔ سوائے اس کے جس کے کھانے کی طرف تم مضطر و مجبور ہو جاؤ (تو پھر حرام بھی کھا سکتے ہو) اور یقیناً بہت سے لوگ علم کے بغیر محض اپنی خواہشات کی بنا پر گمراہ کرتے ہیں بے شک آپ کا پروردگار حد سے بڑھنے والوں کو خوب جانتا ہے۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cmix{اور (اے لوگو) تمام گناہوں کو چھوڑ دو خواہ علانیہ ہوں اور خواہ خفیہ بے شک جو لوگ گناہ کما (کر) رہے ہیں عنقریب ان کو بدلہ دیا جائے گا اس کا جس کا وہ ارتکاب کرتے ہیں۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cmx{اور اس (جانور) کو نہ کھاؤ جس پر اللہ کا نام نہ لیا گیا ہو۔ کہ یہ (کھانا) فسق (نافرمانی) ہے اور بے شک شیطان اپنے دوستوں کو خفیہ اشارے کرتے ہیں (پٹی پڑھاتے ہیں) تاکہ وہ تم سے جھگڑا کریں اور اگر تم نے ان کی اطاعت کر لی (ان کا کہنا مانا) تو یقینا تم مشرک ہو جاؤ گے۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cmxi{اور کیا وہ شخص جو (پہلے) مردہ تھا پھر ہم نے اسے زندہ کیا اور اس کے لئے ایک نور بنایا جس کے ساتھ وہ لوگوں میں چلتا پھرتا ہے اس شخص کی طرح ہو سکتا ہے جو تاریکیوں میں پڑا ہوا ہے اور ان سے نکل نہیں سکتا۔ جس طرح مؤمن کی نگاہ میں ایمان آراستہ کیا گیا ہے اسی طرح کافروں کی نگاہ میں ان کے اعمال آراستہ کر دیئے گئے ہیں۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cmxii{اور (جس طرح ہم نے مکہ کے فاسقوں کو بڑا بنایا) اسی طرح ہم نے ہر بستی میں اس کے مجرمین کو بڑا سردار بنایا ہے تاکہ وہ وہاں مکر و فریب کیا کریں حالانکہ وہ فریب نہیں دیتے مگر اپنے آپ کو لیکن انہیں اس کا شعور نہیں ہے۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cmxiii{اور جب ان کے پاس کوئی معجزہ آتا ہے تو وہ کہتے ہیں کہ ہم اس وقت تک ہرگز ایمان نہیں لائیں گے جب تک ہم کو بھی وہی نہ دیا جائے جو اللہ کے رسولوں کو دیا گیا ہے۔ اللہ بہتر جانتا ہے کہ اپنی رسالت کو کہاں رکھے؟ (اس کا اہل کون ہے؟) عنقریب مجرموں کو اللہ کے یہاں ذلت نصیب ہوگی اور سخت عذاب بھی ہوگا ان کی ان مکاریوں کی وجہ سے جو وہ کیا کرتے تھے۔\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cmxiv{پس جب اللہ کسی کو ہدایت بخشنے کا ارادہ کرتا ہے تو اس کے سینہ کو اسلام کیلئے کھول دیتا ہے اور جسے گمراہی میں چھوڑنا چاہتا ہے تو اس کے سینہ کو تنگ کر دیتا ہے جیسے کہ وہ زبردستی آسمان پر چڑھ رہا ہے (اس کی طرف اونچا ہو رہا ہے) اسی طرح اللہ ان لوگوں پر کثافت مسلط کر دیتا ہے جو ایمان نہیں لاتے۔\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cmxv{یہ تمہارے پروردگار کا سیدھا راستہ ہے۔ ہم نے نصیحت قبول کرنے والوں کے لیے آیتوں کو تفصیل سے بیان کر دیا ہے۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cmxvi{ان کیلئے سلامتی کا گھر ہے ان کے پروردگار کے ہاں اور ان کے اچھے اعمال کی وجہ سے جو وہ کرتے ہیں اللہ ان کا سرپرست ہے۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cmxvii{اور (وہ دن یاد کرو) جس دن وہ (اللہ) سب (جن و انس) کو محشر میں جمع کرے گا (اور جنات سے خطاب کرکے فرمائے گا) کہ اے گروہِ جن! تم نے بہت انسانوں کو گمراہ کیا (اس وقت) وہ آدمی جو ان (جنات) کے دوست و رفیق ہوں گے کہیں گے اے ہمارے پروردگار! ہم سب نے ایک دوسرے سے خوب فائدہ اٹھایا اور اب ہم اپنی اس میعاد کو پہنچ گئے ہیں جو تو نے ہمارے لئے مقرر کی تھی۔ اللہ فرمائے گا اب تمہارا ٹھکانہ دوزخ ہے جس میں تم ہمیشہ رہوگے۔ سوائے اس کے جسے اللہ (بچانا) چاہے گا۔ بے شک تمہارا پروردگار حکیم و علیم ہے (بڑی حکمت اور بڑے علم والا ہے)۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cmxviii{اور اسی طرح ہم بعض ظالموں کو ان کے اعمال (کرتوتوں) کی وجہ سے بعض کا سرپرست بناتے ہیں (یا ایک دوسرے پر مسلط کرتے ہیں)۔\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cmxix{اے گروہِ جن و انس! کیا تمہارے پاس تم ہی میں سے (میرے) کچھ رسول نہیں آئے تھے جو تمہیں میری آیتیں سناتے تھے۔ اور تمہیں اس دن کی پیشی سے ڈراتے تھے؟ وہ جواب میں کہیں گے کہ ہم اپنے خلاف گواہی دیتے ہیں ان کو دنیوی زندگی نے دھوکہ میں مبتلا کر دیا تھا اور اب وہ اپنے خلاف گواہی دیں گے کہ وہ بے شک کافر تھے۔\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cmxx{یہ (رسولوں کا بھیجنا) اس لئے ہے کہ تمہارا پروردگار بستیوں کو ظلم و جور سے ہلاک نہیں کرتا۔ جبکہ ان کے رہنے والے بے خبر ہوں۔\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cmxxi{اور ہر ایک کے لیے اس کے عمل کے مطابق درجے ہیں۔ اور جو کچھ لوگ کرتے رہتے ہیں آپ کا پروردگار اس سے غافل نہیں ہے۔\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cmxxii{آپ کا پروردگار بے نیاز ہے، رحمت والا ہے، وہ اگر چاہے تو تم لوگوں کو لے جائے اور تمہاری جگہ تمہارے بعد جن کو چاہے لے آئے جس طرح اس نے تمہیں پیدا کیا اور لوگوں کی نسل سے۔\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cmxxiii{بے شک جو کچھ تم سے وعدہ وعید کیا گیا ہے وہ بے شک آکر رہے گا۔ اور تم (خدا کو) عاجز نہیں کر سکتے۔\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cmxxiv{(اے رسول(ص)) کہہ دیجئے! اے میری قوم تم اپنے مرتبہ و مقام کے مطابق عمل کرتے رہو میں بھی اپنے مرتبہ کے مطابق عمل کر رہا ہوں عنقریب تمہیں معلوم ہو جائے گا کہ انجامِ کار کس کے حق میں بہتر ہے جو ظالم ہیں وہ فلاح نہیں پائیں گے۔\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cmxxv{ان لوگوں نے اللہ کے لیے اسی کی پیدا کی ہوئی کھیتی اور مویشیوں میں ایک حصہ مقرر کر رکھا ہے اور اپنے خیال کے مطابق کہتے ہیں کہ یہ حصہ اللہ کا ہے اور یہ ہمارے شریکوں (دیوتاؤں) کا ہے۔ جو حصہ ان کے شریکوں کا ہوتا ہے وہ تو اللہ کو نہیں پہنچتا اور جو حصہ اللہ کا ہے وہ ان کے شریکوں تک پہنچ جاتا ہے یہ لوگ کیا ہی برا فیصلہ کرتے ہیں۔\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cmxxvi{اور اسی طرح بہت سے مشرکوں کے لیے ان کے شریکوں نے ان کی اولاد کے قتل کرنے کو خوشنما بنا رکھا ہے تاکہ (انجامِ کار) انہیں تباہ کریں اور ان کے دین و مذہب کو ان پر مشتبہ کریں اگر اللہ (اپنی قدرتِ قاہرہ سے) چاہتا تو یہ ایسا نہ کرتے لہٰذا انہیں چھوڑیے اور ان کی افترا پردازیوں کو۔ (تاکہ وہ ان میں لگے رہیں)\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cmxxvii{اور وہ اپنی خام خیالی سے کہتے ہیں کہ یہ چوپائے اور کھیت ممنوع ہیں انہیں کوئی نہیں کھا سکتا مگر وہ جسے ہم چاہیں اور جو کچھ چوپائے ہیں جن کی پشت پر سواری اور باربرداری کو حرام قرار دے دیا گیا ہے اور کچھ چوپائے ایسے ہیں جن پر وہ اللہ کا نام نہیں لیتے اور یہ سب کچھ انہوں نے اللہ پر افترا پردازی کرتے ہوئے کیا ہے عنقریب اللہ انہیں ان کی افترا پردازی کا بدلہ دے گا۔\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cmxxviii{اور وہ کہتے ہیں کہ جو ان چوپاؤں کے پیٹ میں ہے وہ ہمارے مردوں کے لیے مخصوص ہے اور ہماری عورتوں پر حرام ہے اور اگر وہ مردار ہوں تو وہ سب اس میں شریک ہیں عنقریب اللہ ان کو اس بات بنانے کا بدلہ دے گا۔\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cmxxix{یقینا وہ لوگ بڑے گھاٹے میں ہیں جنہوں نے علم کے بغیر محض جہالت اور حماقت کی وجہ سے اپنی اولاد کو قتل کیا۔ اور اللہ پر افترا پردازی کرکے اللہ کے دیے ہوئے رزق کو حرام قرار دیا بے شک وہ گمراہ ہوئے اور ہدایت یافتہ اور راہ یاب نہیں ہیں۔\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cmxxx{اور وہ (اللہ) وہی ہے۔ جس نے طرح طرح کے باغات پیدا کیے (ٹیٹوں پر) چڑھائے ہوئے بھی اور بغیر چڑھائے ہوئے بھی اور کھجور کے درخت اور طرح طرح کی کھیتی جس کے مزے مختلف ہیں اور زیتون اور انار جو مشابہ بھی ہیں اور غیر مشابہ بھی اس کے پھلوں میں سے کھاؤ جب وہ پھلیں اور اس کی کٹائی کے دن اس کا حق ادا کرو اور اسراف مت کرو کیونکہ وہ (خدا) اسراف کرنے والوں کو دوست نہیں رکھتا۔\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cmxxxi{اور اللہ وہی ہے جس نے چوپاؤں میں سے کچھ ایسے پیدا کیے ہیں جن سے سواری اور باربرداری کا کام لیا جاتا ہے اور کچھ وہ ہیں جو (کھانے اور) بچھانے کے کام آتے ہیں جو کچھ اللہ نے تمہیں روزی عطا کی ہے اس سے کھاؤ اور شیطان کے نقشِ قدم پر نہ چلو کیونکہ وہ تمہارا کھلا ہوا دشمن ہے۔\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cmxxxii{(خدا نے) آٹھ قسم کے جوڑے پیدا کیے ہیں دو قسمیں بھیڑ سے اور دو قسمیں بکری سے آپ کہیے کہ آیا اس نے ان دونوں قسم کے نروں کو حرام کیا ہے یا دونوں قسم کے ماداؤں کو؟ یا جو دونوں، ماداؤں کے پیٹ میں ہے؟ مجھے علم کی بنیاد پر بتاؤ۔ اگر تم سچے ہو۔\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cmxxxiii{اور اس طرح دو قسمیں اونٹ سے اور دو قسمیں گائے سے۔ کہو اس (اللہ) نے دونوں قسموں کے نروں کو حرام کیا ہے یا دونوں قسم کی ماداؤں کو؟ یا جو دونوں ماداؤں کے پیٹ میں ہے؟ کیا تم اس وقت موجود تھے جب اللہ نے تمہیں اس بات کا حکم دیا تھا؟ تو اس شخص سے بڑھ کر کون ظالم ہوگا جو اللہ پر جھوٹا الزام لگائے تاکہ کسی علم کے بغیر لوگوں کو گمراہ کرے بے شک اللہ ظالم قوم کو ہدایت نہیں کرتا (اسے منزلِ مقصود تک نہیں پہنچاتا)۔\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cmxxxiv{کہہ دیجئے جو وحی میرے پاس آئی ہے میں اس میں کوئی چیز ایسی نہیں پاتا جو کھانے والے پر حرام ہو سوا اس کے کہ مردار ہو یا بہایا ہوا خون ہو یا سور کا گوشت ہو یہ سب رجس اور گندگی ہے یا پھر فسق ہو (نافرمانی کا ذریعہ ہو یعنی) جو اللہ کے سوا کسی اور نام پر ذبح کیا گیا ہو (یا غیر اللہ کے لیے نامزد کیا گیا ہو) ہاں البتہ اگر کوئی مجبور ہو جائے جبکہ وہ نہ باغی و سرکش ہو اور نہ ہی حد سے تجاوز کرنے والا ہو تو یقینا تمہارا پروردگار بڑا بخشنے والا بڑا رحم کرنے والا ہے۔\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cmxxxv{اور جو لوگ یہودی ہوئے ہم نے ان پر تمام کھر والے جانور حرام کر دیئے تھے۔ اور گائے بیل اور بھیڑ بکری کی چربی بھی حرام کر دی۔ سوا اس کے جو ان کی پیٹھ یا ان کی آنتڑیوں سے لگی ہوئی یا ہڈی سے ملی ہوئی ہو ہم نے ان کو بغاوت و سرکشی کی سزا دی تھی اور یقینا ہم بالکل سچے ہیں۔\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cmxxxvi{سو اگر یہ آپ کو جھٹلائیں تو آپ کہہ دیجئے! کہ آپ کا پروردگار بڑی وسیع رحمت والا ہے اور مجرموں سے اس کا عذاب ٹالا نہیں جا سکتا۔\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cmxxxvii{عنقریب مشرک لوگ کہیں گے کہ اگر اللہ نہ چاہتا تو ہم شرک نہ کرتے اور نہ ہمارے باپ دادا اور نہ ہی ہم کسی چیز کو حرام قرار دیتے اسی طرح ان لوگوں نے بھی جھٹلایا تھا جو ان سے پہلے تھے یہاں تک کہ انہوں نے ہمارے عذاب کا مزہ چکھا۔ آپ کہہ دیجئے کہ اگر تمہارے پاس کوئی علمی دلیل ہے تو اسے ہمارے سامنے ظاہر کرو۔ تم تو محض گمان کی پیروی کر رہے ہو اور صرف اٹکل پچو باتیں کرتے ہو۔\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cmxxxviii{کہہ دیجئے! کہ اللہ کی دلیل زبردست ہے۔ اگر اللہ (اپنی مشیت قاہرہ سے) چاہتا تو تم سب کو ہدایت دے دیتا۔\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cmxxxix{کہہ دیجئے! لاؤ اپنے ان گواہوں کو جو اس بات کی گواہی دیں کہ اللہ نے اس کو حرام کیا ہے؟ اور اگر وہ (جھوٹی) گواہی دے بھی دیں تو آپ نہ ان کے ساتھ گواہی دیجئے اور نہ ہی ان لوگوں کی خواہشات کی پیروی کیجئے۔ جنہوں نے ہماری آیتوں کو جھٹلایا ہے۔ اور جو آخرت پر ایمان نہیں رکھتے اور وہ اپنے پروردگار کے برابر دوسروں کو ٹھہراتے ہیں۔\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cmxl{(اے رسول) ان سے کہو۔ آؤ میں تمہیں سناؤں وہ چیزیں جو تمہارے پروردگار نے تم پر حرام کی ہیں: (۱) یہ کہ اس کے ساتھ کسی کو شریک نہ ٹھہراؤ۔ (۲) اور والدین کے ساتھ حسن سلوک کرو۔ (۳) اور اپنی اولاد کو فقر و فاقہ کے ڈر سے قتل نہ کرو۔ ہم تمہیں بھی روزی دیتے ہیں اور انہیں بھی (دیں گے)۔ (۴) اور بے شرمی و بے حیائی کے کاموں (جیسے جنسی غلط کاری) کے قریب بھی نہ جاؤ۔ خواہ وہ علانیہ ہوں اور خواہ پوشیدہ۔ (۵) اور نہ قتل کرو کسی ایسی جان کو جس کے قتل کو خدا نے حرام قرار دیا ہے مگر (شرعی) حق (جیسے قصاص وغیرہ) کے ساتھ۔ یہ وہ ہے جس کی اللہ نے تمہیں وصیت کی ہے۔ تاکہ تم عقل سے کام لو۔\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cmxli{(۶) اور یتیم کے مال کے قریب نہ جاؤ مگر ایسے طریقہ سے جو بہترین ہو یہاں تک کہ وہ اپنے سنِ رشد و کمال تک پہنچ جائے۔ (۷) اور ناپ تول انصاف کے ساتھ پوری کرو۔ ہم کسی شخص کو اس کی وسعت سے زیادہ تکلیف نہیں دیتے۔ (۸) اور جب کوئی بات کہو تو عدل و انصاف کے ساتھ۔ اگرچہ وہ (شخص) تمہارا قرابتدار ہی کیوں نہ ہو۔ (۹) اور اللہ کے عہد و پیمان کو پورا کرو۔ یہ وہ ہے جس کی اس (اللہ) نے تمہیں وصیت کی ہے شاید کہ تم عبرت حاصل کرو۔\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cmxlii{(۱۰) اور (یہ بھی کہو) یہ ہے میرا سیدھا راستہ اسی کی پیروی کرو۔ اور دوسرے راستوں کی پیروی نہ کرو ورنہ وہ تمہیں اس (اللہ) کے راستہ سے جدا کر دیں گے یہ ہے جس کی اللہ نے تمہیں وصیت کی ہے شاید کہ تم پرہیزگار بن جاؤ۔\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cmxliii{پھر ہم نے موسیٰ کو وہ کتاب عطا کی جو نیک عمل کرنے والے پر نعمت کی تکمیل ہے۔ اور اس میں ہر چیز کی تفصیل ہے اور (لوگوں کے لیے) سراسر ہدایت و رحمت ہے تاکہ وہ اپنے پروردگار کی بارگاہ میں حاضری و حضوری پر ایمان لائیں۔\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cmxliv{اور یہ (قرآن) بڑی بابرکت کتاب ہے جسے ہم نے نازل کیا ہے پس تم اس کی پیروی کرو اور تقویٰ اختیار کرو۔ شاید کہ تم پر رحم کیا جائے۔\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cmxlv{(اور اس لیے بھی نازل کی ہے کہ) تم یہ (نہ) کہو کہ ہم سے پہلے دو گروہوں (یہود و نصاریٰ) پر تو کتاب (تورات و انجیل) نازل کی گئی۔ اور ہم تو (عرب ہونے کی وجہ سے) ان کے پڑھنے پڑھانے سے غافل و بے خبر تھے۔\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cmxlvi{یا یہ (نہ) کہو کہ اگر ہم پر کتاب نازل کی گئی ہوتی تو ہم ان لوگوں سے زیادہ راہِ راست پر ہوتے۔ تو اب (تمہارے تمام عذر بہانے قطع کرنے کے لیے) تمہارے پروردگار کی طرف سے کھلی ہوئی دلیل اور ہدایت و رحمت (قرآن کی صورت میں) آگئی ہے سو اب اس سے بڑھ کر ظالم کون ہوگا جو آیاتِ الٰہی کو جھٹلائے اور ان سے روگردانی کرے۔ ہم عنقریب ان لوگوں کو جو ہماری آیات سے روگردانی کرتے ہیں۔ بڑے عذاب کی سزا دیں گے۔\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cmxlvii{کیا یہ لوگ اب صرف اس بات کا انتظار کر رہے ہیں کہ ان کے پاس فرشتے آئیں؟ یا تمہارا پروردگار بذات خود آجائے یا تمہارے پروردگار کی بعض خاص نشانیاں آجائیں۔ یہ تب (ایمان لائیں گے)۔ تو پھر (یاد رکھو) جس دن تمہارے پروردگار کی بعض مخصوص نشانیاں آجائیں گی تو اس دن ایسے شخص کو ایمان لانا کوئی فائدہ نہیں دے گا جو پہلے ایمان نہیں لایا ہوگا اور اپنے ایمان میں کوئی بھلائی نہ کمائی ہوگی۔ ان سے کہو کہ تم بھی انتظار کرو۔ ہم بھی انتظار کرتے ہیں۔\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cmxlviii{بے شک جن لوگوں نے اپنے دین میں تفرقہ ڈالا اور گروہ گروہ بن گئے آپ کا ان سے کوئی تعلق نہیں ہے ان کا معاملہ بس اللہ کے حوالہ ہے۔ پھر وہ انہیں بتلائے گا کہ وہ کیا کیا کرتے تھے؟\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cmxlix{جو شخص ایک نیکی لے کر (اللہ کی بارگاہ میں) آئے گا اس کو دس گنا (اجر) ملے گا۔ اور ان پر ظلم نہیں کیا جائے گا۔\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cml{آپ کہیں! بے شک میرے پروردگار نے مجھے بڑے سیدھے راستہ کی طرف راہنمائی کر دی ہے یعنی اس صحیح اور راست دین کی طرف جو باطل سے ہٹ کر صرف حق کی طرف راغب ابراہیم (ع) کی ملت ہے اور وہ شرک کرنے والوں میں سے نہیں تھے۔\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cmli{(اے رسول(ص)) کہو میری نماز اور میری تمام (مختلف) عبادتیں اور میری زندگی اور میری موت صرف اللہ کے لئے ہے جو تمام جہانوں کا پروردگار ہے۔\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cmlii{اس کا کوئی شریک نہیں ہے اور مجھے اسی کا حکم دیا گیا ہے اور میں سب سے پہلے سرِ تسلیم خم کرنے والا ہوں۔\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cmliii{(اے رسول(ص)) کہہ دیجیے! کیا میں اللہ کے علاوہ کوئی اور رب تلاش کروں؟ حالانکہ وہ ہر چیز کا پروردگار ہے اور ہر نفس جو کچھ کماتا ہے اس کا وبال اسی پر ہے۔ اور کوئی بوجھ اٹھانے والا کسی دوسرے کا بوجھ نہیں اٹھائے گا پھر تم سب کی بازگشت تمہارے پروردگار کی طرف ہے سو وہی تمہیں بتائے گا جس جس چیز میں تم اختلاف کرتے تھے۔\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cmliv{وہ (خدا) وہی ہے جس نے تمہیں زمین میں (پہلوں) کا خلیفہ اور جانشین بنایا اور تم سے بعض کو بعض پر درجات کے اعتبار سے بلندی عطا فرمائی تاکہ جو کچھ تمہیں عطا کیا ہے اس میں تمہاری آزمائش کرے۔ بے شک تمہارا پروردگار بہت جلد سزا دینے والا اور بے شک وہ بڑا بخشنے والا اور بڑا رحم کرنے والا بھی ہے۔\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cmlv{\basmalahur الف، لام، میم، ص۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cmlvi{یہ ایک کتاب ہے جو آپ کی طرف نازل کی گئی ہے۔ لہٰذا تمہارے دل میں اس کی وجہ سے کوئی تنگی نہیں ہونا چاہیے۔ (یہ کتاب اس لئے نازل کی گئی ہے) تاکہ آپ اس کے ذریعہ سے (لوگوں کو خدا کے عذاب سے) ڈرائیں اور اہلِ ایمان کے لئے نصیحت اور یاد دہانی ہو۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cmlvii{(اے لوگو) جو کچھ تمہارے پروردگار کی طرف سے تمہاری طرف نازل کیا گیا ہے اس کی پیروی کرو۔ اور اس (پروردگار) کو چھوڑ کر دوسرے سرپرستوں (حوالی موالی) کی پیروی نہ کرو۔ تم لوگ بہت ہی کم نصیحت قبول کرتے ہو۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cmlviii{اور کتنی ہی بستیاں ہیں کہ ہم نے انہیں تباہ کر دیا پس ہمارا عذاب ان پر راتوں رات آیا یا جب وہ دن میں قیلولہ کر رہے تھے (سو رہے تھے)۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cmlix{جب ہمارا عذاب ان پر آیا تو اس کے سوا ان کی اور کوئی پکار نہ تھی کہ بے شک ہم ظالم تھے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cmlx{بے شک ہم ان لوگوں سے بھی باز پرس کریں گے۔ جن کی طرف رسول بھیجے گئے تھے۔ اور خود رسولوں سے بھی پوچھ گچھ کریں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@cmlxi{پھر ہم پورے علم کے ساتھ ان کے سامنے سب (حالات و واقعات) بیان کریں گے آخر ہم غیر حاضر تو تھے نہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@cmlxii{اور اس دن وزن (اعمال کا تولا جانا) بالکل حق ہے پس جس کے پلے بھاری ہوں گے وہی کامیاب ہوں گے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cmlxiii{اور جس کے پلے ہلکے ہوں گے۔ وہ اپنے آپ کو خسارے میں مبتلا کرنے والے ہوں گے کیونکہ وہ ناانصافی کرتے تھے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@cmlxiv{اور ہم نے تمہیں زمین میں تمکین دی (اقتدار و اختیار دیا) اور اس میں تمہارے لئے زندگی گزارنے کے سامان فراہم کئے۔ مگر تم بہت ہی کم شکر کرتے ہو۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@cmlxv{بے شک ہم نے تمہاری تخلیق کا آغاز کیا اور پھر تمہاری صورت گری کی اس کے بعد فرشتوں سے کہا کہ آدم(ع) کے سامنے سجدہ ریز ہو جاؤ چنانچہ سب نے سجدہ کیا سوا ابلیس کے کہ وہ سجدہ کرنے والوں میں سے نہ تھا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cmlxvi{(خدا نے) فرمایا: جب میں نے تجھے حکم دیا تھا تو تجھے کس چیز نے روکا؟ کہا میں اس (آدم(ع)) سے بہتر ہوں کیونکہ تو نے مجھے آگ سے پیدا کیا ہے اور اسے مٹی سے پیدا کیا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cmlxvii{ارشاد ہوا۔ تو پھر تو یہاں سے نیچے اتر جا۔ کیونکہ تجھے یہ حق نہیں ہے کہ تو یہاں رہ کر تکبر و غرور کرے۔ بس یہاں سے نکل جا۔ یقینا تو ذلیلوں میں سے ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cmlxviii{کہا۔ مجھے اس دن تک مہلت دے جب سب لوگ دوبارہ اٹھائے جائیں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cmlxix{فرمایا: اچھا تو ان میں سے ہے جنہیں مہلت دی گئی ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cmlxx{کہا چونکہ تو نے مجھے گمراہ کیا ہے تو اب میں تیرے سیدھے راستہ پر بیٹھوں گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cmlxxi{پھر میں ان کے آگے کی طرف سے اور ان کے پیچھے کی جانب سے اور ان کی دائیں طرف سے اور ان کی بائیں طرف سے آؤں گا (اور انہیں ورغلاؤں گا) اور تو ان میں سے اکثر کو شکر گزار نہیں پائے گا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cmlxxii{فرمایا: ذلیل اور راندہ ہوکر یہاں سے نکل جا میں تجھے اور اسے جو ان میں سے تیری پیروی کرے گا تم سب سے جہنم بھر دوں گا۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cmlxxiii{اور اے آدم(ع)! تم اور تمہاری بیوی دونوں اس بہشت میں رہو۔ اور جہاں سے چاہو (اور جو چیز دل چاہے) کھاؤ۔ مگر اس درخت کے پاس نہ جانا۔ ورنہ ظالموں میں سے ہو جاؤگے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cmlxxiv{تو شیطان نے جھوٹی قسم کھا کر ان دونوں کو وسوسہ میں ڈالا۔ تاکہ ان کے وہ ستر والے مقام جو ایک دوسرے سے پوشیدہ تھے ظاہر کر دے اور کہا کہ تمہارے پروردگار نے تمہیں صرف اس لئے اس درخت سے روکا ہے کہ کہیں فرشتے نہ بن جاؤ یا ہمیشہ زندہ رہنے والوں میں سے نہ ہو جاؤ۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cmlxxv{اور اس نے دونوں سے قسم کھائی کہ میں تمہارے سچے خیرخواہوں میں سے ہوں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cmlxxvi{اس طرح اس نے ان دونوں کو فریب سے مائل کر دیا (اور اس طرح جنت) کی بلندیوں سے زمین کی پستیوں تک پہنچا دیا۔ پس جب انہوں نے اس درخت کا مزہ چکھا۔ تو ان کے جسم کے چھپے ہوئے حصے نمودار ہوگئے اور وہ جنت کے پتوں کو جوڑ کر اپنے یہ مقام (ستر) چھپانے لگے تب ان کے پروردگار نے ان کو ندا دی۔ کیا میں نے تمہیں اس درخت کے پاس جانے سے منع نہیں کیا تھا؟ اور نہیں کہا تھا کہ شیطان تمہارا کھلا ہوا دشمن ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cmlxxvii{اس وقت ان دونوں نے کہا۔ اے ہمارے پروردگار! ہم نے اپنے اوپر ظلم کیا۔ اور اگر تو درگزر نہیں کرے گا اور ہم پر رحم نہیں کرے گا تو ہم گھاٹا اٹھانے والوں میں سے ہوں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cmlxxviii{ارشاد ہوا! تم دونوں (بہشت سے) نیچے اترو۔ تم ایک دوسرے کے دشمن ہو اور ایک وقت معلوم تک تمہارا زمین میں ہی ٹھکانہ اور سامانِ زیست ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cmlxxix{(یہ بھی فرمایا) اسی زمین میں تم نے جینا ہے اور وہیں مرنا ہے اور پھر اسی سے دوبارہ نکالے جاؤگے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cmlxxx{اے اولادِ آدم(ع)! ہم نے تمہارے لئے لباس نازل کیا ہے جو تمہارے جسم کے قابلِ ستر حصوں کو چھپاتا ہے اور (باعث) زینت بھی ہے۔ اور تقویٰ و پرہیزگاری کا لباس یہ سب سے بہتر ہے یہ (لباس بھی) اللہ کی نشانیوں میں سے ہے تاکہ لوگ نصیحت حاصل کریں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cmlxxxi{اے اولادِ آدم! (ہوشیار رہنا) کہیں ایسا نہ ہو کہ شیطان تمہیں اسی طرح فتنہ میں مبتلا کر دے جس طرح اس نے تمہارے ماں باپ کو جنت سے نکلوایا تھا۔ اور ان کے جسم سے کپڑے تک اتروا دیئے تھے تاکہ ان کے جسم کے قابلِ ستر حصے ان کو دکھا دے یقینا وہ (شیطان) اور اس کا قبیلہ تمہیں جس طرح اور جہاں سے دیکھتا ہے تم انہیں اس طرح نہیں دیکھ سکتے بے شک ہم نے شیطانوں کو ان کا سرپرست بنایا ہے جو ایمان نہیں رکھتے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cmlxxxii{اور جب وہ کوئی بے حیائی کا کام کرتے ہیں تو کہتے ہیں کہ ہم نے اپنے آباء و اجداد کو اسی طریقہ پر پایا ہے اور خدا نے (بھی) ہمیں یہی حکم دیا ہے اے رسول کہیئے کہ یقینا کبھی اللہ بے حیائی کا حکم نہیں دیتا کیا تم اللہ پر ایسی بات کی تہمت لگاتے ہو جو تم نہیں جانتے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiii{اے رسول(ص) کہو! میرے پروردگار نے مجھے عدل و انصاف کا حکم دیا ہے اور یہ کہ اپنے چہرہ کو سیدھ پر رکھو ہر نماز کے وقت اور اسی کو پکارو دین کو اسی کے لئے خالص کرکے جس طرح اس نے پہلی بار تمہیں پیدا کیا تھا اسی طرح تم (اس کے حضور پلٹ) کر جاؤگے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiv{ایک گروہ کو تو اس نے ہدایت دے دی ہے اور ایک گروہ پر گمراہی ثبت ہوگئی ہے۔ انہوں نے اللہ کو چھوڑ کر شیاطین کو اپنا سرپرست بنا لیا ہے اور پھر وہ (اپنے متعلق) خیال کرتے ہیں کہ وہ ہدایت یافتہ ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cmlxxxv{اے اولادِ آدم! ہر نماز کے وقت زینت کرو اور کھاؤ پیو۔ اور اسراف (فضول خرچی) نہ کرو۔ کیونکہ وہ بے شک اسراف کرنے والوں کو دوست نہیں رکھتا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvi{(اے رسول ان لوگوں سے) کہو کہ اللہ کی زیب و زینت کو جو اس نے اپنے بندوں کے لئے پیدا کی ہے کس نے حرام کیا ہے؟ اور کھانے کی اچھی اور پاکیزہ غذاؤں کو (کس نے حرام کیا ہے؟)! وہ تو دراصل ہیں ہی اہلِ ایمان کے لئے دنیوی زندگی میں بھی اور خاص کر قیامت کے دن تو خالص انہی کے لئے ہیں۔ اسی طرح ہم اپنی آیتوں کو تفصیل کے ساتھ بیان کرتے ہیں ان لوگوں کے لئے جو علم رکھتے ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvii{تم کہہ دو! میرے پروردگار نے صرف بے حیائی و بدکاری کے کاموں کو حرام قرار دیا ہے خواہ ظاہری ہوں یا باطنی۔ اور اثم (ہر گناہ یا شراب) کو اور کسی پر ناحق زیادتی کو اور یہ کہ کسی کو اللہ کا شریک بناؤ جس کے لئے اللہ نے کوئی دلیل نہیں اتاری اور یہ کہ اللہ کے بارے میں کوئی ایسی بات کہو جس کا تمہیں علم و یقین نہ ہو۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cmlxxxviii{اور ہر امت (قوم) کے لئے ایک وقت مقرر ہوتا ہے۔ پس جب وہ مقررہ وقت آجاتا ہے تو نہ وہ ایک ساعت کے لیے پیچھے ہٹ سکتے ہیں اور نہ ایک ساعت آگے بڑھ سکتے ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cmlxxxix{اے اولادِ آدم اگر تمہارے پاس تم ہی سے میرے کچھ رسول آئیں جو تمہیں میری آیات پڑھ کر سنائیں (اور میرے احکام تم تک پہنچائیں) تو جو شخص پرہیزگاری اختیار کرے گا۔ اور اپنی اصلاح کرے گا۔ ان کے لئے نہ کوئی خوف ہوگا اور نہ وہ غمگین ہوں گے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cmxc{اور جو لوگ ہماری آیتوں کو جھٹلائیں گے اور ان کے مقابلہ میں تکبر کریں گے وہی لوگ جہنم والے ہوں گے جو اس میں ہمیشہ ہمیشہ رہیں گے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cmxci{اور اس شخص سے بڑھ کر کون ظالم ہوگا جو اللہ پر جھوٹا بہتان باندھے (خود جھوٹی باتیں گھڑ کر اس کی طرف منسوب کرے) یا اس کی آیتوں کو جھٹلائے، ایسے لوگوں کو نوشتۂ کتاب (اپنے مقدر) کا حصہ تو ملے گا۔ لیکن جب ان کے پاس ہمارے فرستادہ (فرشتے) ان کی روحوں کو قبض کرنے کے لیے آئیں گے تو وہ ان سے کہیں گے۔ (آج) وہ کہاں ہیں جن کو تم اللہ کے سوا پکارتے تھے؟ وہ جواب دیں گے کہ وہ تو ہم سے غائب ہوگئے اور وہ خود اپنے خلاف گواہی دیں گے کہ بے شک وہ کافر تھے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cmxcii{ارشاد ہوگا تم بھی اسی جہنم میں داخل ہو جاؤ جس میں تم سے پہلے گزرے ہوئے جن و انس کے گروہ داخل ہو چکے ہیں (اور) جب بھی کوئی (جہنم میں) داخل ہوگا تو اپنے ساتھ (پیش رو) گروہ پر لعنت کرے گا۔ یہاں تک کہ جب سب وہاں جمع ہو جائیں گے (سب واصلِ جہنم ہو جائیں گے) تو بعد والا گروہ پہلے گروہ کے بارے میں کہے گا اے پروردگار! انہوں نے ہمیں گمراہ کیا تھا اس لئے انہیں دوزخ کا دوگنا عذاب دے۔ ارشاد ہوگا ہر ایک کے لئے دونا عذاب ہے لیکن تم جانتے نہیں ہو۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cmxciii{اور ان کا پہلا گروہ دوسرے گروہ سے کہے گا۔ کہ (اگر ہم مستوجبِ الزام تھے) تو پھر تم کو ہم پر کوئی فضیلت تو نہ ہوئی؟ بس (ہماری طرح) تم بھی اپنے کئے کی پاداش میں عذاب کا مزہ چکھو۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cmxciv{یقینا جن لوگوں نے ہماری آیتوں کو جھٹلایا اور ان کے مقابلہ میں تکبر و غرور کیا۔ ان کے لئے آسمان کے دروازے نہیں کھولے جائیں گے۔ اور اس وقت تک وہ جنت میں داخل نہیں ہوں گے جب تک اونٹ سوئی کے ناکے میں سے نہیں گزر جائے گا ہم اسی طرح مجرموں کو بدلہ دیا کرتے تھے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cmxcv{ان کا بچھونا بھی جہنم کا ہوگا اور اوپر سے اوڑھنا بھی جہنم کا ہم اسی طرح ظالموں کو بدلہ دیتے ہیں۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cmxcvi{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے ہم کسی نفس کو اس کی وسعت سے زیادہ تکلیف نہیں دیتے یہی لوگ جنتی ہیں وہ اس میں ہمیشہ ہمیشہ رہیں گے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cmxcvii{اور جو کچھ ان کے دلوں میں کدورت ہوگی ہم اسے باہر نکال دیں گے ان کے نیچے سے نہریں بہتی ہوں گی۔ اور وہ شکر کرتے ہوئے کہیں گے ہر قسم کی تعریف اس اللہ کے لئے ہے جس نے ہمیں اس منزلِ مقصود تک پہنچایا اور ہم کبھی یہاں تک نہیں پہنچ سکتے تھے اگر وہ ہمیں نہ پہنچاتا۔ یقینا ہمارے پروردگار کے رسول حق کے ساتھ آئے اور انہیں ندا دی جائے گی کہ یہ بہشت ہے جس کے تم اپنے ان اعمال کی بدولت وارث بنائے گئے ہو۔ جو تم انجام دیا کرتے تھے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cmxcviii{اور جنتی لوگ دوزخیوں کو ندا دیں گے کہ ہمارے پروردگار نے ہم سے جو وعدہ کیا تھا اس کو ہم نے تو سچا پا لیا ہے کیا تم نے بھی اس وعدہ کو جو تمہارے پروردگار نے تم سے کیا تھا سچا پایا ہے؟ وہ (جواب میں) کہیں گے ہاں تب ایک منادی ان کے درمیان ندا کرے گا کہ خدا کی لعنت ان ظالموں پر۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cmxcix{جو اللہ کے راہ سے (لوگوں کو) روکتے رہے ہیں اور اس میں کجی تلاش کرتے رہے ہیں۔ اور وہ آخرت کا انکار کرتے رہے ہیں۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@m{اور ان دونوں (بہشت و دوزخ) کے درمیان پردہ ہے (حدِ فاصل ہے) اور اعراف پر کچھ لوگ ہوں گے جو ہر ایک کو اس کی علامت سے پہچان لیں گے۔ اور وہ بہشت والوں کو پکار کر کہیں گے کہ تم پر سلام ہو اور یہ لوگ (ابھی) اس میں داخل نہیں ہوئے ہوں گے۔ حالانکہ وہ اس کی خواہش رکھتے ہوں گے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mi{اور جب ان کی نگاہیں دوزخ والوں کی طرف پھریں گی تو کہیں گے اے ہمارے پروردگار! ہمیں ظالم لوگوں کے ساتھ شامل نہ کر۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mii{اور پھر اعراف والے لوگ (دوزخ والے چند آدمیوں کو) آواز دیں گے جنہیں وہ علامتوں سے پہچانتے ہوں گے۔ کہ آج تمہاری جمعیت اور تمہارا غرور و پندار کچھ کام نہ آیا اور تمہیں کوئی فائدہ نہ پہنچایا۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@miii{(پھر کچھ مستحقین جنت کی طرف اشارہ کرتے ہوئے کہیں گے) کیا یہی وہ لوگ ہیں جن کے متعلق تم قسمیں کھا کھا کر کہتے تھے کہ اللہ ان تک اپنی کچھ بھی رحمت نہیں پہنچائے گا۔ (پھر ان مستحقین جنت سے کہیں گے) تم بہشت میں داخل ہو جاؤ۔ نہ تم پر کوئی خوف ہے اور نہ ہی تم مغموم ہوگے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@miv{اور دوزخ والے بہشت والوں کو پکاریں گے کہ تھوڑا سا پانی یا جو کچھ اللہ تعالیٰ نے تمہیں کھانے کو عطا فرمایا ہے اس میں سے کچھ ہماری طرف انڈیل دو وہ (جواب میں) کہیں گے کہ اللہ تعالیٰ نے یہ دونوں چیزیں کافروں پر حرام کر دی ہیں۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mv{جنہوں نے اپنے دین کو کھیل تماشہ بنا لیا تھا اور جنہیں زندگانئ دنیا نے دھوکہ دیا تھا آج ہم بھی انہیں اسی طرح بھلا دیں گے جس طرح انہوں نے آج کے اس دن کی حاضری کو بھلا دیا تھا۔ اور جیسے وہ ہماری آیتوں کو برابر جھٹلاتے رہے تھے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mvi{اور بے شک ہم ان کے پاس ایک ایسی کتاب لائے ہیں جسے ہم نے پورے علم کے ساتھ خوب واضح کر دیا ہے اور جو ایمان لانے والوں کے لئے برابر ہدایت و رحمت ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mvii{کیا یہ لوگ اس (قرآن کی دھمکی) کے انجام کا انتظار کر رہے ہیں؟ (کہ سامنے آئے) حالانکہ جس دن اس کا انجام (سامنے) آئے گا تو وہی لوگ جنہوں نے پہلے اس کو بھلایا ہوگا کہیں گے بے شک ہمارے پروردگار کے رسول ہمارے پاس سچائی کے ساتھ آئے تھے تو کیا آج ہمارے لئے کچھ سفارشی ہیں؟ جو ہماری سفارش کریں یا (یہ ممکن ہے کہ) ہمیں دوبارہ واپس بھیج دیا جائے تاکہ جو کچھ ہم (پہلے) کیا کرتے تھے اس کے خلاف کچھ اور (نیک عمل) کریں؟ یقینا انہوں نے اپنے آپ کو خسارہ میں ڈال دیا اور وہ افترا پردازیاں جو وہ کیا کرتے تھے آج ان سے گم ہوگئیں۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mviii{بے شک تمہارا پروردگار وہی اللہ ہے جس نے آسمانوں اور زمین کو چھ دنوں میں پیدا کیا۔ پھر عرش کی جانب متوجہ ہوا (اور کائنات کے اقتدارِ اعلیٰ پر قابض ہوا) جو رات سے دن کو ڈھانپ لیتا ہے۔ کہ اسے تیزی کے ساتھ جا پکڑتی ہے۔ اور جس نے سورج، چاند اور ستاروں کو پیدا کیا۔ کہ وہ سب طبعی طور پر اس کے حکم کے تابع ہیں خبردار! پیدا کرنا اور حکم دینا اس سے مخصوص ہے۔ بابرکت ہے اللہ جو سارے جہانوں کا پروردگار ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mix{اپنے پروردگار سے گڑگڑا کر اور چپکے چپکے دعا کرو۔ بے شک وہ حد سے تجاوز کرنے والوں کو دوست نہیں رکھتا۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mx{اور زمین میں اس کی اصلاح کے بعد فساد برپا نہ کرو۔ اور خدا سے خوف اور امید کے ساتھ دعا کرو۔ بے شک اللہ کی رحمت نیکوکاروں سے قریب ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mxi{وہ وہی (خدا) ہے جو اپنی رحمت (بارش) سے پہلے ہواؤں کو خوشخبری کے لئے بھیجتا ہے یہاں تک کہ جب وہ بھاری بادلوں کو اٹھا لیتی ہیں تو ہم انہیں کسی مردہ بستی کی طرف ہانک کر لے جاتے ہیں اور پھر وہاں پانی برسا دیتے ہیں۔ اور پھر ہم اس کے ذریعہ سے طرح طرح کے پھل نکالتے ہیں اسی طرح ہم مردوں کو (بھی زندہ کرکے) باہر نکالیں گے شاید کہ تم عبرت اور نصیحت حاصل کرو۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mxii{اور جو زمین عمدہ و پاکیزہ ہوتی ہے خدا کے حکم سے اس کی نبات (پیداوار) خوب نکلتی ہے اور جو خراب اور ناکارہ ہوتی ہے تو اس کی پیداوار بھی خراب اور بہت کم نکلتی ہے ہم اسی طرح شکر گزار قوم کے لیے اپنی نشانیاں الٹ پھیر کر بیان کرتے ہیں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mxiii{ہم نے نوح کو ان کی قوم کی طرف (رسول بنا کر) بھیجا۔ تو انہوں نے کہا اے میری قوم اللہ کی عبادت کرو اس کے علاوہ تمہارا کوئی اللہ نہیں ہے۔ یقینا مجھے تمہاری نسبت ایک بڑے سخت دن (قیامت) کے عذاب کا اندیشہ ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mxiv{ان کی قوم کے سرداروں نے کہا۔ ہم تو تم کو کھلی ہوئی گمراہی میں دیکھتے ہیں۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mxv{نوح نے کہا اے میری قوم! مجھ میں کوئی گمراہی نہیں ہے بلکہ میں تو سارے جہانوں کے پروردگار کا رسول ہوں۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mxvi{تمہیں اپنے پروردگار کے پیغامات پہنچاتا ہوں (اور تمہاری خیر خواہی کے لیے) تمہیں نصیحت کرتا ہوں۔ اور اللہ کی طرف سے وہ کچھ جانتا ہوں جو تم نہیں جانتے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mxvii{کیا تمہیں اس بات پر تعجب ہے کہ تمہارے پروردگار کی طرف سے تمہاری اپنی قوم کے ایک شخص کے پاس وعظ و نصیحت کا پیغام آیا ہے۔ تاکہ وہ تمہیں (خدا کے عذاب سے) ڈرائے! اور تاکہ تم پرہیزگار بنو۔ اور تاکہ تم پر رحم کیا جائے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mxviii{(مگر) ان لوگوں نے انہیں جھٹلایا۔ (جس کا نتیجہ یہ نکلا کہ) ہم نے انہیں اور جو کشتی میں ان کے ساتھ تھے ان کو نجات دی اور جنہوں نے ہماری آیتوں کو جھٹلایا تھا ان کو غرق کر دیا بے شک وہ اندھے (بے بصیرت) لوگ تھے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mxix{اور ہم نے قومِ عاد کی طرف ان کے (قومی) بھائی ہود کو بھیجا۔ انہوں نے کہا! اے میری قوم! اللہ کی عبادت کرو۔ اس کے سوا تمہارا کوئی الٰہ نہیں ہے۔ آخر تم پرہیزگاری کیوں اختیار نہیں کرتے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mxx{ان کی قوم کے کافر سرداروں نے کہا ہم تمہیں حماقت میں مبتلا دیکھتے ہیں اور ہم تمہیں جھوٹا خیال کرتے ہیں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mxxi{ہود نے کہا! اے میری قوم، مجھ میں کوئی حماقت نہیں ہے بلکہ میں تو سارے جہانوں کے پروردگار کا رسول ہوں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mxxii{تمہارے پروردگار کے پیغامات پہنچاتا ہوں۔ اور تمہارا امانتدار ناصح ہوں۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mxxiii{کیا تمہیں اس بات پر تعجب ہے کہ تمہارے پروردگار کی طرف سے تمہاری اپنی قوم کے ایک شخص کے پاس وعظ و نصیحت کا پیغام آیا ہے تاکہ وہ تمہیں (خدا کے عذاب سے) ڈرائے اور یاد کرو (خدا کے اس احسان کو) کہ اس نے تمہیں قومِ نوح کے بعد ان کا جانشین بنایا۔ اور (تمہاری) خلقت میں یعنی قوت و طاقت اور قد و قامت میں زیادتی اور وسعت عطا کی پس اللہ کی نعمتوں کو یاد کرو تاکہ تم (ہر طرح) فلاح پاؤ۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mxxiv{انہوں نے کہا (اے ہود (ع)) کیا تم ہمارے پاس اس لئے آئے ہو کہ ہم ایک اللہ کی عبادت کریں اور ان (معبودوں) کو چھوڑ دیں جن کی ہمارے باپ دادا عبادت کرتے چلے آئے ہیں اگر تم سچے ہو تو۔ ہمارے پاس لاؤ وہ (عذاب) جس کی تم ہمیں دھمکی دیتے ہو۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mxxv{اس (ہود) نے کہا (سمجھ لو کہ) تمہارے پروردگار کی طرف سے تم پر عذاب اور غضب نازل ہوگیا ہے کیا تم مجھ سے ایسے ناموں کے بارے میں جھگڑتے ہو جو تم نے اور تمہارے باپ دادا نے (از خود) رکھ لئے ہیں۔ جن کے متعلق اللہ نے کوئی سند نازل نہیں کی۔ اچھا تو پھر تم (خدا کے عذاب کا) انتظار کرو مَیں بھی تمہارے ساتھ انتظار کرنے والوں میں سے ہوں۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mxxvi{پس (آخرکار) ہم نے اپنی رحمت سے انہیں اور ان کے ساتھیوں کو نجات دی (بچا لیا) اور جن لوگوں نے ہماری آیتوں کو جھٹلایا تھا اور وہ ایمان لانے والے نہیں تھے ان کی جڑ ہی کاٹ دی۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mxxvii{اور قومِ ثمود کی طرف ان کے (قومی) بھائی صالح کو بھیجا۔ انہوں نے کہا اے میری قوم! اللہ ہی کی عبادت کرو اس کے سوا تمہارے پروردگار کی طرف سے (میری صداقت کا) ایک خاص معجزہ آچکا ہے جو یہ اللہ کی خاص اونٹنی ہے جو تمہارے لئے ایک (قدرتی) نشانی (معجزہ) ہے اسے کھلا چھوڑ دو کہ خدا کی زمین میں چَرتی پھرے۔ اور (خبردار) اسے برے ارادے سے ہاتھ نہ لگانا (اسے تکلیف نہ پہنچانا) ورنہ دردناک عذاب تمہیں اپنی گرفت میں لے لے گا۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mxxviii{اور وہ وقت یاد کرو جب اللہ نے تمہیں قومِ عاد کا جانشین بنایا۔ اور تمہیں زمین میں رہنے کے لئے ٹھکانا دیا کہ تم نرم اور ہموار زمین میں محلات بناتے ہو اور پہاڑوں کو تراش کر مکانات بناتے ہو۔ سو اللہ کی نعمتوں کو یاد کرو۔ اور زمین میں فساد مت پھیلاتے پھرو۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mxxix{قوم کے بڑے لوگوں نے جو متکبر تھے۔ ان کمزور لوگوں سے کہا جو ایمان لائے تھے۔ کیا تم جانتے ہو صالح واقعی اپنے پروردگار کی طرف سے بھیجے ہوئے (رسول) ہیں انہوں نے کہا بے شک ہم تو اس (پیغام) پر ایمان لائے جسے دے کر ان کو بھیجا گیا ہے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mxxx{(یہ سن کر) متکبر مزاج بڑے کہنے لگے کہ جس چیز پر تم ایمان لائے ہو ہم اس کے کافر و منکر ہیں۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mxxxi{پھر انہوں نے اس اونٹنی کو پئے کر دیا (اس کی کونچیں کاٹ دیں) اور اپنے پروردگار کے حکم سے سرکشی و سرتابی کی اور کہا اے صالح! اگر تم رسولوں میں سے ہو تو پھر ہمارے پاس لاؤ وہ (عذاب) جس کی ہمیں دھمکی دیتے ہو۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mxxxii{پس انہیں زلزلہ نے آپکڑا اور وہ اپنے گھروں میں اوندھے پڑے رہ گئے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mxxxiii{پس وہ (صالح) یہ کہتے ہوئے وہاں سے منہ موڑ کر نکل گئے اے میری قوم! میں نے تمہیں اپنے پروردگار کا پیغام پہنچا دیا اور تم کو نصیحت کی مگر تم نصیحت کرنے والے خیر خواہوں کو پسند ہی نہیں کرتے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mxxxiv{اور ہم نے لوط کو بھیجا انہوں نے اپنی قوم سے کہا کہ تم ایسا بے حیائی کا کام کرتے ہو کہ ایسا کام تم سے پہلے دنیا والوں میں سے کسی نے نہیں کیا۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mxxxv{یعنی تم عورتوں کو چھوڑ کر مردوں کے ساتھ شہوت رانی کرتے ہو؟ تم بڑے حد سے گزرے ہوئے لوگ ہو۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mxxxvi{ان کی قوم کا اس کے سوا کوئی جواب نہ تھا کہ آپس میں کہنے لگے کہ انہیں اس بستی سے نکال دو۔ یہ لوگ بڑے پاکباز بنتے ہیں۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mxxxvii{تو ہم نے انہیں اور ان کے گھر والوں کو سوا ان کی بیوی کے نجات دی (بچا لیا) ہاں البتہ وہ پیچھے رہ جانے والوں میں سے تھی۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mxxxviii{اور ہم نے ان پر (پتھروں) کی بارش برسائی تو دیکھو مجرموں کا کیسا انجام ہوا؟\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mxxxix{اور ہم نے مدین کی طرف ان کے (قومی) بھائی شعیب کو بھیجا۔ انہوں نے کہا اے میری قوم! اللہ ہی کی عبادت کرو۔ اس کے سوا تمہارا کوئی الٰہ نہیں ہے۔ یقینا تمہارے پاس تمہارے پروردگار کی طرف سے کھلا نشان بھی آچکا ہے۔ پس ناپ تول پوری کیا کرو اور لوگوں کو ان کی (خرید کردہ) چیزیں کم نہ دیا کرو۔ اور زمین میں اس کی اصلاح کے بعد فساد نہ پھیلاؤ۔ یہ بات تمہارے لئے بہتر ہے اگر تم ایمان والے ہو۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mxl{اور ہر راستے پر اس طرح نہ بیٹھو کہ تم (راہ گیروں) کو ڈراؤ دھمکاؤ اور ایمان لانے والوں کو اللہ کی راہ سے روکو۔ اور اس راہ میں کجی تلاش کرو۔ اور وہ وقت یاد کرو۔ جب تم تھوڑے تھے تو اس (خدا) نے تمہیں بڑھا دیا اور دیکھو کہ فساد پھیلانے والوں کا انجام کیسا ہوتا رہا ہے۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mxli{اور اگر تم میں سے ایک گروہ اس پر ایمان نہیں لایا تو صبر کرو۔ یہاں تک کہ اللہ ہمارے درمیان فیصلہ کرے اور وہ بہترین فیصلہ کرنے والا ہے۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mxlii{اور ان کی قوم کے متکبر سرداروں نے کہا۔ اے شعیب ہم تم کو اور جو لوگ تمہارے ساتھ ایمان لائے ہیں ان کو اپنی بستی سے نکال دیں گے یا یہ کہ تم لوگ ہمارے مذہب میں واپس آجاؤ۔ شعیب نے کہا اگرچہ ہم اسے ناپسند ہی کرتے ہوں؟\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mxliii{جب اللہ نے ہمیں تمہارے مذہب سے نجات دے دی ہے۔ اگر اس کے بعد بھی ہم تمہارے مذہب میں واپس آجائیں تو پھر تو ہم نے اللہ پر جھوٹا بہتان باندھا۔ اور ہمارے لئے یہ ممکن نہیں ہے کہ ہم لوٹ آئیں مگر یہ کہ اللہ جو ہمارا پروردگار ہے چاہے ہمارا پروردگار اپنے علم سے ہر چیز کا احاطہ کئے ہوئے ہے۔ ہمارا اللہ ہی پر بھروسہ ہے۔ اے ہمارے پروردگار! تو ہی ہمارے اور ہماری قوم کے درمیان حق کے ساتھ فیصلہ کر دے۔ اور تو بہترین فیصلہ کرنے والا ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mxliv{اور ان کی قوم کے ان سرداروں نے جو کافر تھے آپس میں کہا کہ اگر تم شعیب کی پیروی کروگے تو نقصان اٹھاؤگے۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mxlv{سو زلزلہ نے انہیں آپکڑا جس کے بعد وہ اپنے گھروں میں اوندھے منہ پڑے رہ گئے۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mxlvi{جن لوگوں نے شعیب کو جھٹلایا تھا وہ (اس طرح برباد ہوئے کہ) گویا کبھی ان گھروں میں بستے ہی نہ تھے۔ جنہوں نے شعیب کو جھٹلایا تھا وہی نقصان اٹھانے والے ثابت ہوئے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mxlvii{(اس وقت) وہ ان سے منہ موڑ کر چلے اور کہا اے میری قوم! میں نے تو یقیناً اپنے پروردگار کے پیغامات تمہیں پہنچا دیئے تھے اور تمہیں نصیحت بھی کی تھی تو (اب) کافر قوم (کے عبرتناک انجام) پر کیونکر افسوس کروں؟\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mxlviii{اور ہم نے کبھی کسی بستی میں کوئی نبی نہیں بھیجا مگر یہ کہ اس کے باشندوں کو (ان کی تکذیب پر پہلے) سختی اور تکلیف میں مبتلا کیا تاکہ وہ تضرع و زاری کریں۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mxlix{پھر ہم نے ان کی بدحالی کو خوش حالی سے بدل دیا یہاں تک کہ وہ خوب بڑھے (اور پھلے پھولے) اور کہنے لگے کہ ہمارے باپ دادا کو بھی کبھی تکلیف اور کبھی راحت یونہی پہنچتی رہی ہے۔ تو ایک دم ہم نے ان کو اس طرح پکڑ لیا کہ انہیں اس کا شعور بھی نہ ہو سکا۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ml{اور اگر ان بستیوں کے باشندے ایمان لاتے اور پرہیزگاری اختیار کرتے تو ہم ان پر آسمان و زمین کی برکتوں کے دروازے کھول دیتے۔ لیکن انہوں نے جھٹلایا۔ لہٰذا ہم نے ان کو ان کے کرتوتوں کی پاداش میں پکڑ لیا۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mli{آیا ان بستیوں والے اس سے بے خوف ہوگئے ہیں کہ ان پر ہمارا عذاب راتوں رات آجائے جبکہ وہ سو رہے ہوں؟\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mlii{یا کیا بستیوں والے اس سے بے خوف ہوگئے ہیں کہ ان پر ہمارا عذاب دن چڑھے (چاشت کے وقت) آجائے جبکہ وہ کھیل کود رہے ہوں؟\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mliii{کیا یہ لوگ اللہ کے عذاب یا اس کی خفیہ تدبیر سے بے خوف ہوگئے ہیں۔ حالانکہ اللہ کے عذاب یا اس کی خفیہ تدبیر سے وہی لوگ بے خوف ہوتے ہیں جو گھاٹا اٹھانے والے ہوں۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mliv{کیا ان لوگوں پر جو پہلے اہل زمین کی تباہی کے بعد زمین کے وارث بنے ہیں یہ بات واضح نہیں ہوئی ہے کہ اگر ہم چاہتے تو ان کو گناہوں کی وجہ سے کسی مصیبت میں مبتلا کر دیتے اور ان کے دلوں پر ایسی مہر لگا دیتے کہ وہ سن (سمجھ) نہ سکیں۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mlv{یہ وہ بستیاں ہیں کہ جن کی کچھ خبریں ہم آپ سے بیان کر رہے ہیں بے شک ان کے پاس ان کے رسول کھلے ہوئے نشان (معجزے) لے کر آئے۔ مگر وہ ایسے نہیں تھے کہ اس بات پر ایمان لاتے جسے وہ پہلے جھٹلا چکے تھے۔ اللہ اسی طرح کافروں کے دلوں پر مہر لگاتا ہے۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mlvi{اور ہم نے ان کی اکثریت میں عہد و پیمان کی پاسداری نہیں پائی اور ہم نے اکثر کو فاسق و فاجر پایا ہے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mlvii{پھر ہم نے ان (نبیوں) کے بعد موسیٰ کو اپنی نشانیاں (معجزے) دے کر فرعون اور اس کے سرداروں کی طرف بھیجا۔ مگر انہوں نے ان (نشانیوں) کے ساتھ ظلم کیا (انکار کر دیا) دیکھو مفسدین کا کیا برا انجام ہوا؟\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mlviii{اور موسیٰ نے کہا اے فرعون میں تمام جہانوں کے پروردگار کا رسول ہوں۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mlix{میرے لئے ضروری ہے کہ اللہ کے بارے میں حق کے سوا کوئی بات نہ کہوں میں تمہارے پروردگار کی طرف سے معجزہ لے کر آیا ہوں۔ پس تو بنی اسرائیل کو (آزاد کرکے) میرے ساتھ بھیج دے۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mlx{فرعون نے کہا اگر تم کوئی معجزہ لائے ہو تو اگر تم سچے ہو تو اسے پیش کرو۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mlxi{پس انہوں نے اپنا عصا پھینک دیا اور وہ یکایک کھلا ہوا اژدھا بن گیا۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mlxii{اور اپنا ہاتھ باہر نکالا۔ تو وہ ایک دم دیکھنے والوں کے لیے سفید اور روشن تھا۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mlxiii{قومِ فرعون کے سرداروں نے (یہ منظر دیکھ کر) کہا کہ یہ شخص (موسیٰ) بڑا ماہر جادوگر ہے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mlxiv{(اس پر فرعون نے کہا) یہ تمہیں تمہارے ملک سے نکال دینا چاہتا ہے تو تم کیا مشورہ دیتے ہو؟\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mlxv{ان لوگوں نے کہا کہ انہیں اور ان کے بھائی کو روک رکھیے۔ اور شہروں میں ہرکارے بھیج دیجئے۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mlxvi{جو ہر بڑے ماہر جادوگر کو لے آئیں۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mlxvii{چنانچہ جادوگر فرعون کے پاس آگئے اور کہنے لگے کہ اگر ہم غالب آگئے تو یقینا ہم ایک بڑے معاوضے کے حقدار ہوں گے۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mlxviii{فرعون نے کہا ہاں۔ اور اس کے علاوہ تم ہمارے مقرب بارگاہ لوگوں میں سے ہو جاؤگے۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mlxix{انہوں نے کہا اے موسیٰ یا تم (پہلے) پھینکو یا پھر ہم ہی پھینکتے ہیں۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mlxx{انہوں نے (جواب میں) کہا تم ہی پھینکو! پھر جب انہوں نے (اپنی لاٹھیاں اور رسیاں) پھینکیں تو لوگوں کی نگاہوں کو مسحور کر دیا (ان کی نظر بندی کر دی) اور انہیں خوف زدہ کر دیا اور انہوں نے بڑا زبردست جادو پیش کیا۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mlxxi{ہم نے موسیٰ کو وحی کی کہ اپنا عصا پھینکو۔ تو یکایک وہ (اژدھا بن کر) ان کے طلسموں (جادو کے جھوٹے سانپوں) کو نگلنے لگا۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mlxxii{(نتیجہ یہ نکلا کہ) حق ثابت ہوگیا۔ اور جو جھوٹے کاروائی کر رہے تھے وہ باطل ہوگئی۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mlxxiii{اس طرح وہ (فرعون اور فرعونی) مغلوب ہوئے اور ذلیل و رسوا ہوکر رہ گئے۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mlxxiv{اور تمام جادوگر (کسی غیبی طاقت سے) سجدہ میں گرا دیئے گئے۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mlxxv{اور کہنے لگے ہم سارے جہانوں کے پروردگار پر ایمان لائے۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mlxxvi{جو موسیٰ و ہارون کا پروردگار ہے۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mlxxvii{فرعون نے کہا تم اس پر ایمان لے آئے ہو اس سے پہلے کہ میں تمہیں اجازت دوں؟ یقینا یہ کوئی خفیہ سازش ہے جو تم لوگوں نے کی ہے۔ تاکہ تم شہر کے باشندوں کو اس سے باہر نکالو۔ عنقریب تمہیں (اس کا انجام) معلوم ہو جائے گا۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mlxxviii{میں تمہارے ہاتھ پاؤں کو مختلف سمتوں سے کاٹ دوں گا پھر تم سب کو سولی پر لٹکا دوں گا۔\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mlxxix{انہوں نے کہا (ہمیں کیا پروا ہے) ہم لوگ بہرحال اپنے پروردگار کی طرف پلٹ کر جانے والے ہیں۔\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mlxxx{اور تم ہم سے صرف اس بات کا انتقام لینا چاہتے ہو کہ ہم اپنے پروردگار کی نشانیوں پر ایمان لائے ہیں جب وہ ہمارے پاس آئی ہیں۔ (پھر یوں دعا کی) اے ہمارے پروردگار! ہم پر صبر انڈیل دے اور ہمیں اس حالت میں وفات دے کہ ہم تیرے سچے مسلمان (فرمانبردار) ہوں۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mlxxxi{قومِ فرعون کے سرداروں نے کہا! تو موسیٰ اور اس کی قوم کے آدمیوں کو اس لئے چھوڑے رکھے گا کہ وہ ملک میں فساد پھیلاتے رہیں اور تمہیں اور تمہارے معبودوں کو چھوڑتے رہیں۔ اس (فرعون) نے (چین بجبین ہوکر) کہا ہم عنقریب ان کے لڑکوں کو قتل کریں گے اور ان کی عورتوں کو زندہ رہنے دیں گے اور ہم (پوری طرح) ان پر غالب ہیں۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mlxxxii{موسیٰ نے اپنی قوم سے کہا! تم اللہ سے مدد طلب کرو۔ اور صبر و تحمل سے کام لو بے شک زمین اللہ کی ہے۔ وہ جسے چاہتا ہے اپنے بندوں میں سے اس کا وارث بنا دیتا ہے اور اچھا انجام تو پرہیزگاروں کا ہی ہے۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mlxxxiii{ان لوگوں (بنی اسرائیل) نے کہا ہم آپ کے آنے سے پہلے بھی ستائے جاتے رہے اور آپ کے آنے کے بعد بھی۔ انہوں نے کہا! عنقریب تمہارا پروردگار تمہارے دشمن کو ہلاک کر دے گا اور تمہیں زمین میں (ان کا) جانشین بنائے گا (تمہیں اقتدار عطا فرمائے گا) تاکہ دیکھے کہ تم کیسے عمل کرتے ہو؟\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mlxxxiv{اور ہم نے فرعونیوں کو قحط اور پھلوں کی پیداوار کی کمی میں گرفتار کیا کہ شاید وہ نصیحت حاصل کریں۔\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mlxxxv{(مگر ان کی حالت یہ تھی کہ) جب خوش حالی آتی تو کہتے کہ یہ تو ہمارا حق ہے اور جب بدحالی آتی تو اسے موسیٰ اور ان کے ساتھیوں کی نحوست اور فالِ بد قرار دیتے۔ حالانکہ ان کی نحوست اور بدشگونی خدا کے ہاں ہے لیکن اکثر لوگ (یہ حقیقت) جانتے نہیں ہیں۔\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mlxxxvi{اور انہوں نے (موسیٰ سے) کہا تم جو بھی نشانی (معجزہ) ہمارے سامنے لے آؤ اور اس سے ہمیں مسحور کرنا چاہو ہم پھر بھی ایمان نہیں لائیں گے۔\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mlxxxvii{پھر ہم نے بھیجا ان پر عذاب، طوفان، ٹڈی دل، جوؤں، مینڈکوں اور خون (کی صورت میں) یہ کھلی ہوئی نشانیاں تھیں مگر وہ پھر بھی تکبر اور سرکشی ہی کرتے رہے اور وہ بڑے ہی مجرم لوگ تھے۔\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mlxxxviii{اور جب کبھی ان پر کوئی عذاب نازل ہوتا تو کہتے اے موسیٰ ہمارے لئے اپنے پروردگار سے دعا کرو۔ جس کا اس نے تم سے وعدہ کر رکھا ہے۔ اگر تم نے یہ عذاب ہم سے ٹلوا دیا۔ تو ہم تم پر ایمان لے آئیں گے اور تمہارے ساتھ بنی اسرائیل کو بھیج دیں گے۔\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mlxxxix{تو جب ہم وہ عذاب ایک مقررہ مدت تک ہٹا دیتے جس تک وہ بہرحال پہنچنے والے تھے۔ تو وہ اپنے کئے ہوئے عہد و پیمان کو توڑ دیتے۔\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mxc{تب ہم نے ان سے اس طرح انتقام لیا کہ انہیں سمندر میں غرق کر دیا۔ کیونکہ وہ ہماری نشانیوں کو جھٹلاتے تھے اور ان کی طرف سے غفلت برتتے تھے۔\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mxci{اور ان کی جگہ ہم نے ان لوگوں کو وارث (اور مالک) بنایا جن کو کمزور سمجھا جاتا تھا۔ اور وارث بھی اس مشرق و مغرب کا بنایا جس میں ہم نے برکت دی ہے اور اسی طرح آپ کے پروردگار کا وہ اچھا وعدہ پورا ہوگیا جو اس نے بنی اسرائیل سے کیا تھا کیونکہ انہوں نے صبر و ضبط سے کام لیا تھا اور ہم نے اسے مٹا دیا جو کچھ فرعون اور اس کی قوم والے کرتے تھے اور برباد کر دیئے وہ اونچے مکان جو وہ تعمیر کرتے تھے۔\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mxcii{اور جب ہم نے بنی اسرائیل کو دریا کے اس پار اتار دیا تو ان کا گزر ایک ایسی قوم سے ہوا جو اپنے (خود ساختہ) معبودوں کی پرستش میں مگن بیٹھی تھی۔ انہوں نے کہا اے موسیٰ ہمارے لئے بھی ایک الٰہ بنا دیں جیسے ان کے الٰہ ہیں۔ موسیٰ نے کہا تم بڑے ہی جاہل لوگ ہو۔\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mxciii{جس طریقہ پر یہ لوگ ہیں وہ یقینا تباہ ہو کر رہے گا۔ اور جو کچھ وہ کر رہے ہیں وہ باطل ہوکر رہے گا۔\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mxciv{کہا: کیا میں تمہارے لئے اللہ کے سوا کوئی (اور) خدا تلاش کروں حالانکہ اس نے تمہیں تمام جہانوں کی قوموں پر فضیلت دی۔\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mxcv{اور یاد کرو وہ وقت جب ہم نے تمہیں فرعونیوں سے نجات عطا کی۔ جو تمہیں بدترین عذاب کا مزہ چکھاتے تھے تمہارے لڑکوں کو قتل کرتے تھے اور تمہاری عورتوں کو زندہ چھوڑتے تھے اور اس میں تمہارے پروردگار کی طرف سے بڑی آزمائش تھی۔\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mxcvi{اور ہم نے موسیٰ سے (توراۃ دینے کے لیے) تیس راتوں کا وعدہ کیا تھا اور اسے مزید دس (راتوں) سے مکمل کیا۔ اس طرح ان کے پروردگار کی مدت چالیس راتوں میں پوری ہوگئی اور جناب موسیٰ نے (کوہ طور پر جاتے وقت) اپنے بھائی ہارون سے کہا تم میری قوم میں میرے جانشین بن کر رہو۔ اور اصلاح کرتے رہو اور (خبردار) مفسدین کے راستہ پر نہ چلنا۔\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mxcvii{اور جب جنابِ موسیٰ ہمارے مقرر کردہ وقت پر آگئے اور ان کے پروردگار نے ان سے کلام کیا۔ تو انہوں نے کہا پروردگار! مجھے اپنا جلوہ دکھا تاکہ میں تیری طرف نگاہ کر سکوں۔ ارشاد ہوا تم مجھے کبھی نہیں دیکھ سکوگے۔ مگر ہاں اس پہاڑ کی طرف دیکھو۔ اگر یہ (تجلئِ حق کے وقت) اپنی جگہ پر برقرار رہا تو پھر امید کرنا کہ مجھے دیکھ سکوگے پس جب ان کے پروردگار نے پہاڑ پر اپنی تجلی ڈالی تو اسے ریزہ ریزہ کر دیا اور موسیٰ غش کھا کر گر گئے۔ اور جب ہوش میں آئے تو بولے پاک ہے تیری ذات! میں تیرے حضور توبہ کرتا ہوں اور میں سب سے پہلا ایمان لانے والا ہوں (کہ تو نظر نہیں آتا)۔\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mxcviii{ارشاد ہوا اے موسیٰ میں نے تمہیں اپنی پیغمبری اور ہمکلامی کے لیے تمام لوگوں سے منتخب کیا ہے پس جو چیز (توراۃ) میں نے تمہیں عطا کی ہے اسے لو اور شکر گزار بندوں میں سے ہو جاؤ۔\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mxcix{اور ہم نے موسیٰ کے لیے ان تختیوں میں ہر قسم کی نصیحت اور ہر چیز کی تفصیل لکھ دی ہے۔ پس اسے مضبوطی سے پکڑ لو اور اپنی قوم کو حکم دو کہ وہ اس کی بہترین باتوں کو لے لیں (اس کے احکام پر کاربند ہو جائیں) میں عنقریب تم لوگوں کو نافرمان لوگوں کا گھر دکھا دوں گا۔\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mc{جو لوگ ناحق خدا کی زمین میں سرکشی کرتے ہیں میں اپنی نشانیوں سے ان کی نگاہیں پھرا دوں گا۔ وہ اگر ہر معجزہ بھی دیکھ لیں۔ تو پھر بھی ایمان نہیں لائیں گے۔ اور اگر وہ ہدایت کا راستہ دیکھ بھی لیں تو اسے اپنا راستہ نہیں بنائیں گے۔ اور اگر گمراہی کا راستہ دیکھ لیں تو (فوراً) اسے (اپنا) راستہ بنا لیں گے ان کی یہ حالت اس وجہ سے ہے کہ انہوں نے ہماری آیتوں (نشانیوں) کو جھٹلایا اور ان سے غفلت برتتے رہے۔\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mci{اور جن لوگوں نے ہماری آیتوں کو اور آخرت کی پیشی کو جھٹلایا ان کے سارے اعمال ضائع ہوگئے پس انہیں جزا یا سزا نہیں دی جائے گی مگر انہی اعمال کی جو وہ (دار دنیا میں) کرتے تھے۔\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mcii{اور موسیٰ کی قوم نے ان کے (کوہِ طور پر چلے جانے کے) بعد اپنے زیوروں سے (ان کو گلا کر) ایک بچھڑے کا پتلا بنا لیا جس سے بیل کی سی آواز نکلتی تھی۔ کیا انہوں نے اتنا بھی نہ دیکھا (نہ سوچا) کہ وہ نہ ان سے بات کرتا ہے اور نہ ہی کسی طرح کی راہنمائی کر سکتا ہے پھر بھی انہوں نے اسے (معبود) بنا لیا اور وہ (اپنے اوپر) سخت ظلم کرنے والے تھے۔\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mciii{پھر جب وہ نادم ہوئے اور کفِ افسوس مَلنے لگے اور محسوس کیا کہ وہ گمراہ ہوگئے ہیں۔ تو کہنے لگے کہ ہمارے پروردگار نے ہم پر رحم نہ کیا اور ہمیں نہ بخشا تو ہم نقصان اٹھانے والوں میں سے ہو جائیں گے۔\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mciv{اور جب موسیٰ خشمناک اور افسوس کرتے ہوئے اپنی قوم کے پاس واپس آئے۔ تو فرمایا: اے قوم! تم نے میرے بعد بہت ہی بری جانشینی کی۔ کیا تم نے اپنے پروردگار کا حکم آنے سے پہلے جلد بازی کر لی (وعدہ خداوندی چالیس راتوں کے پورا ہونے کی انتظار بھی نہ کی) اور پھر (للہی جوش میں آخر تورات کی) تختیاں (ہاتھ سے) پھینک دیں اور اپنے بھائی (ہارون) کا سر ہاتھ میں لے کر اپنی طرف کھینچنے لگے۔ انہوں نے کہا اے میرے ماں جائے! قوم نے مجھے کمزور اور بے بس کر دیا تھا اور قریب تھا کہ مجھے قتل کر ڈالیں پس تم مجھ پر دشمنوں کو ہنسنے کا موقع نہ دو۔ اور نہ ہی مجھے ظالم گروہ کے ساتھ شامل کرو۔\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mcv{تب موسیٰ نے کہا۔ پروردگار! مجھے اور میرے بھائی کو بخش دے اور ہمیں اپنی رحمت میں داخل فرما اور تو سب رحم کرنے والوں میں سے بڑا رحم کرنے والا ہے۔\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mcvi{بے شک جن لوگوں نے گو سالہ کو (اپنا معبود) بنایا۔ عنقریب ان پر ان کے پروردگار کا غضب نازل ہوگا۔ اور وہ دنیاوی زندگی میں ذلیل و رسوا ہوں گے اور ہم بہتان باندھنے والوں کو اسی طرح سزا دیا کرتے ہیں۔\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mcvii{اور جو لوگ برے کام کریں اور پھر توبہ کر لیں۔ اور ایمان لے آئیں تو یقینا تمہارا پروردگار اس (توبہ و ایمان) کے بعد بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mcviii{اور جب موسیٰ کا غصہ فرو ہوا۔ تو انہوں نے تختیاں اٹھا لیں تو ان کی کتابت (تحریر) میں اپنے پروردگار سے ڈرنے والوں کے لیے ہدایت اور رحمت تھی۔\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mcix{ہمارے مقرر کردہ وقت پر حاضر ہونے کے لیے موسیٰ نے اپنی قوم کے ستر آدمیوں کو منتخب کیا پھر جب ایک سخت زلزلہ نے انہیں آپکڑا (اور وہ ہلاک ہوگئے) تو موسیٰ نے کہا اے میرے پروردگار اگر تو چاہتا تو ان سب کو پہلے ہی ہلاک کر دیتا اور مجھے بھی۔ کیا تو ایسی بات کی وجہ سے جو ہمارے چند احمقوں نے کی ہے ہم سب کو ہلاک کرتا ہے؟ یہ نہیں ہے مگر تیری طرف سے ایک آزمائش! اس کی وجہ سے تو جسے چاہتا ہے (توفیق سلب کرکے) گمراہی میں چھوڑ دیتا ہے اور جسے چاہتا ہے ہدایت کرتا ہے تو ہی ہمارا ولی و سرپرست ہے۔ ہمیں بخش دے اور ہم پر رحم فرما اور تو بہترین مغفرت کرنے والا ہے۔\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mcx{اور ہمارے لئے اس دنیا میں بھی بھلائی لکھ دے اور آخرت میں بھی ہم تیری ہی طرف رجوع کرتے ہیں (ہم نے تجھ سے لو لگائی ہے) ارشاد ہوا (میرے عذاب کا یہ حال ہے کہ) جس کو چاہتا ہوں دیتا ہوں اور میری رحمت (کا یہ حال ہے کہ وہ) ہر چیز کو گھیرے ہوئے ہے۔ پس میں رحمت ان لوگوں کے لیے لکھ دوں گا جو پرہیزگاری کریں گے (برائیوں سے بچیں گے) اور زکوٰۃ ادا کریں گے اور ہماری آیتوں (نشانیوں) پر ایمان لے آئیں گے۔\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mcxi{جو اس پیغمبر(ص) کی پیروی کریں گے جو نبیِ امی ہے جسے وہ اپنے ہاں توراۃ و انجیل میں لکھا ہوا پاتے ہیں جو انہیں نیک کاموں کا حکم دیتا ہے اور برے کاموں سے روکتا ہے جو ان کے لیے پاک و پسندیدہ چیزوں کو حلال اور گندی و ناپاک چیزوں کو حرام قرار دیتا ہے اور ان پر سے ان کے بوجھ اتارتا ہے اور وہ زنجیریں کھولتا ہے جن میں وہ جکڑے ہوئے تھے۔ پس جو لوگ اس (نبیِ امی) پر ایمان لائے اور اس کی تعظیم کی اور اس کی مدد و نصرت کی اور اس نور (روشنی) کی پیروی کی جو اس کے ساتھ نازل کیا گیا ہے یہی لوگ فوز و فلاح پانے والے ہیں۔\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mcxii{اے پیغمبر! (لوگوں سے) کہو اے انسانو! میں تم سب کی طرف اس اللہ کا بھیجا ہوا رسول ہوں۔ جس کے لیے سارے آسمانوں اور زمین کی بادشاہی ہے اس کے سوا کوئی الٰہ نہیں ہے وہی زندہ کرتا ہے وہی مارتا ہے پس اللہ پر ایمان لاؤ۔ اور اس کے نبیِ امی رسول پر۔ جو خود بھی اللہ اور اس کے کلمات (کتابوں) پر ایمان رکھتا ہے اور اس کی پیروی کرو تاکہ تم ہدایت پاؤ۔\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mcxiii{اور موسیٰ کی قوم میں سے ایک گروہ ایسا بھی ہے جو لوگوں کو حق کے راستہ پر چلاتا ہے اور حق کے ساتھ منصفانہ فیصلہ کرتا ہے۔\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mcxiv{اور ہم نے ان (بنی اسرائیل) کو بارہ خاندانوں کے بارہ گروہوں میں تقسیم کر دیا اور ہم نے موسیٰ کو وحی کی جب ان کی قوم نے ان سے پینے کے لیے پانی مانگا کہ ایک (خاص) چٹان پر اپنی لاٹھی مارو۔ چنانچہ اس سے بارہ چشمے پھوٹ نکلے۔ اور ہر گروہ نے اپنا اپنا گھاٹ معلوم کر لیا اور ہم نے ان پر ابر کا سایہ کیا اور (غذا کے لیے) ان پر من و سلویٰ نازل کیا (اور ان سے کہا) کھاؤ ان پاک اور پسندیدہ چیزوں میں سے جو ہم نے تمہیں عطا کی ہیں۔ انہوں نے (نافرمانی و ناشکری کرکے) ہم پر ظلم نہیں کیا بلکہ اپنے ہی اوپر ظلم و زیادتی کرتے رہے۔\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mcxv{(وہ وقت یاد کرو) جب ان (بنی اسرائیل) سے کہا گیا کہ اس گاؤں میں جاکر آباد ہو جاؤ اور وہاں جہاں سے تمہارا جی چاہے (غذا حاصل کرکے) کھاؤ اور حطۃ حطۃ کہتے ہوئے سجدہ ریز ہوکر (عاجزی سے جھکے ہوئے) شہر کے دروازہ میں داخل ہو جاؤ۔ تو ہم تمہاری خطائیں معاف کر دیں گے۔ اور جو نیک کردار ہیں ان کو مزید اجر سے نوازیں گے۔\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mcxvi{مگر ان میں سے جو ظالم تھے انہوں نے وہ کلمہ بدل دیا ایسے کلمہ سے جو مختلف تھا اس کلمہ سے جو ان سے کہا گیا تھا (اور حطۃ کی جگہ حنطہ حنطہ کہنا شروع کیا، ان کی اس روش کا نتیجہ یہ نکلا کہ) ہم نے آسمان سے ان پر عذاب بھیجا۔ اس ظلم کی وجہ سے جو وہ کیا کرتے تھے۔\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mcxvii{اور (اے پیغمبر) ان سے اس بستی کا حال پوچھو جو سمندر کے کنارے واقع تھی۔ جبکہ وہ (بنی اسرائیل) ہفتہ کے دن خدا کی مقرر کردہ حد سے باہر ہو جاتے تھے۔ جبکہ ہفتہ کے دن مچھلیاں ابھر ابھر کر سطح آب پر تیرتی ہوئی آجاتی تھیں اور جس دن ہفتہ نہیں ہوتا ہے (باقی دنوں میں) تو نہیں آتی تھیں۔ ان کی نافرمانی کی وجہ سے جو وہ کیا کرتے تھے اس طرح ہم ان کی آزمائش کرتے تھے۔\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mcxviii{اور (اس وقت کو یاد کرو) جب ان میں سے ایک گروہ نے کہا (ان لوگوں سے جو ہفتہ کے دن شکار کرنے والوں کو وعظ و نصیحت کرتے تھے) کہ تم ایسے لوگوں کو (بے فائدہ) کیوں نصیحت کرتے ہو۔ جن کو خدا ہلاک کرنے والا ہے یا سخت عذاب میں مبتلا کرنے والا ہے؟ انہوں نے (جواب میں) کہا کہ ہم یہ اس لیے کرتے ہیں کہ تمہارے پروردگار کے سامنے معذرت پیش کر سکیں (کہ ہم نے اپنا فریضۂ امر و نہی ادا کر دیا ہے) اور اس لئے کہ شاید یہ لوگ اس روش سے پرہیز اختیار کریں۔\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mcxix{آخرکار جب ان لوگوں نے وہ تمام نصیحتیں بھلا دیں جو ان کو کی گئی تھیں تو ہم نے ان لوگوں کو تو بچا لیا جو برائی سے روکتے رہتے تھے اور باقی سب ظالموں کو ان کی نافرمانیوں کی وجہ سے سخت عذاب میں گرفتار کیا۔\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mcxx{(جب یہ عذاب بھی ان کو سرکشی سے باز نہ رکھ سکا) اور وہ برابر سرکشی کرتے چلے گئے ان چیزوں کے بارے میں جن سے ان کو روکا گیا تھا تو ہم نے کہا بندر ہو جاؤ ذلیل اور راندے ہوئے۔\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mcxxi{اور (اے پیغمبر(ص)) یاد کرو جب تمہارے پروردگار نے اعلان کر دیا تھا (کہ اگر یہ لوگ اپنی سیاہ کاریوں سے باز نہ آئے) تو خدا ان پر قیامت تک ایسے لوگ مسلط کرے گا جو انہیں بدترین عذاب میں گرفتار کریں گے یقینا تمہارا پروردگار بہت جلد سزا دینے والا ہے اور بڑا بخشنے والا اور بڑا رحم کرنے والا بھی ہے۔\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mcxxii{اور ہم نے ان کو زمین میں مختلف فرقوں کی صورت میں ٹکڑے ٹکڑے کر دیا۔ ان میں سے ناپائیدار ہوگا کچھ لوگ تو نیک ہیں اور کچھ اس کے خلاف اور طرح کے (بدکار) ہیں۔ اور ہم ان کو اچھے اور برے حالات میں مبتلا کرکے آزماتے ہیں تاکہ وہ باز آجائیں۔\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mcxxiii{پھر ان کے بعد ایسے ناخلف لوگ ان کے جانشین ہوئے اور کتابِ الٰہی کے وارث بنے جو (دین فروشی کرکے) دنیائے دوں کے مال و متاع اور ساز و سامان جمع کرتے اور سمیٹتے ہیں اور کہتے ہیں کہ امید ہے کہ ہم بخش دیے جائیں گے اور اگر اتنا ہی اور عارضی ساز و سامان ان کے ہاتھ لگ جائے تو اسے بھی بے دریغ لے لیتے ہیں۔ کیا ان سے کتاب (توراۃ) والا یہ عہد و پیمان نہیں لیا گیا تھا کہ وہ اللہ کی نسبت حق کے سوا اور کوئی بات نہیں کہیں گے؟ اور یہ خود کتاب میں پڑھ چکے ہیں جو اس میں لکھا ہے اور آخرت والا گھر پرہیزگاروں کے لیے بہتر ہے کیا تم عقل سے کام نہیں لیتے؟\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mcxxiv{اور جو لوگ کتابِ الٰہی سے تمسک رکھتے ہیں اور نماز کو قائم کرتے ہیں۔ بے شک ہم اصلاح کرنے والوں کا اجر و ثواب ضائع نہیں کریں گے۔\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mcxxv{اور (وہ وقت یاد کرو) جب ہم نے پہاڑ کو ہلا کر (اور جڑ سے اکھاڑ کر)۔ اس طرح ان کے اوپر بلند کیا۔ کہ گویا سائبان ہے اور انہوں نے گمان کیا کہ یہ ان پر گرا ہی چاہتا ہے ( اور ان سے کہا کہ) جو کچھ (کتاب) ہم نے تمہیں عطا کی ہے اسے مضبوطی کے ساتھ لو۔ اور جو کچھ اس میں لکھا ہے اسے یاد رکھو۔ تاکہ تم پرہیزگار بن جاؤ۔\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mcxxvi{اور (وہ وقت یاد کرو) جب تمہارے پروردگار نے بنی آدم کی پشتوں سے ان کی نسل کو نکالا (جو نسلاً بعد نسل پیدا ہونے والی تھی) اور ان کو خود ان کے اوپر گواہ بناتے ہوئے پوچھا کیا میں تمہارا پروردگار نہیں ہوں؟ سب نے جواب دیا ہاں بے شک ہم گواہی دیتے ہیں کہ تو ہمارا پروردگار ہے (یہ کاروائی اس لئے کی تھی کہ) کہیں تم قیامت کے دن یہ نہ کہہ دو کہ ہم تو اس سے بے خبر تھے۔\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mcxxvii{یا کہو کہ (خدایا) شرک تو ہم سے پہلے ہمارے باپ دادا نے کیا تھا۔ اور ہم تو ان کے بعد ان کی نسل سے تھے (اس لئے لاچار ان کی روش پر چل پڑے) تو کیا تو ہمیں اس (شرک) کی وجہ سے ہلاک کرے گا جو باطل پرستوں نے کیا تھا۔\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mcxxviii{اسی طرح ہم اپنی نشانیاں تفصیل سے بیان کرتے ہیں تاکہ وہ (حق کی طرف) رجوع کریں۔\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mcxxix{(اے رسول(ص)) ان لوگوں کے سامنے اس شخص کا واقعہ بیان کرو جس کو ہم نے اپنی بعض نشانیاں عطا کی تھیں مگر وہ ان سے عاری ہوگیا (وہ جامہ اتار دیا) پس شیطان اس کے پیچھے لگ گیا۔ اور آخرکار وہ گمراہوں میں سے ہوگیا۔\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mcxxx{اور اگر ہم چاہتے تو ان نشانیوں کی وجہ سے اس کا مرتبہ بلند کرتے۔ مگر وہ تو زمین (پستی) کی طرف جھک گیا۔ اور اپنی خواہشِ نفس کا پیرو ہوگیا۔ تو اب اس کی مثال کتے کی سی ہوگئی کہ اگر تم اس پر حملہ کرو تب بھی ہانپتا ہے اور یونہی چھوڑ دو تب بھی ایسا کرتا ہے۔ (زبان لٹکائے ہانپتا ہے) یہ مثال ان لوگوں کی ہے جنہوں نے ہماری نشانیوں کو جھٹلایا (اے رسول) تم یہ قصص و حکایات سناتے رہو شاید وہ غور و فکر کریں۔\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mcxxxi{کیا بری مثال ہے ان لوگوں کی جنہوں نے ہماری نشانیوں کو جھٹلایا۔ اور جو خود اپنے ہی اوپر ظلم کرتے رہے۔\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mcxxxii{جس کو اللہ ہدایت دے وہی ہدایت یافتہ ہے اور جسے وہ گمراہی میں چھوڑ دے وہی لوگ گھاٹا اٹھانے والے ہیں۔\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mcxxxiii{اور کتنے جن و انسان ایسے ہیں جنہیں ہم نے جہنم کے لیے پیدا کیا ہے (یعنی ان کا انجامِ کار جہنم ہے) ان کے دل و دماغ ہیں مگر سوچتے نہیں ہیں۔ ان کی آنکھیں ہیں مگر وہ ان سے دیکھتے نہیں اور ان کے کان ہیں مگر وہ ان سے سنتے نہیں ہیں۔ یہ لوگ چوپایوں کی طرح ہیں۔ بلکہ ان سے بھی زیادہ گمراہ (اور گئے گزرے) ہیں۔ یہی وہ لوگ ہیں جو بالکل غافل و بے خبر ہیں۔\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mcxxxiv{اور اللہ ہی کے لیے اچھے اچھے نام ہیں اسے انہی کے ذریعہ سے پکارو اور ان لوگوں کو چھوڑ دو جو اس کے ناموں میں کجروی کرتے ہیں۔ عنقریب انہیں ان کے کئے کا بدلہ مل جائے گا۔\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mcxxxv{ہماری مخلوق میں سے ایک گروہ ایسا بھی ہے جو حق کے مطابق ہدایت کرتا ہے اور اسی کے مطابق (لوگوں کا) فیصلہ کرتا ہے۔\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mcxxxvi{اور جن لوگوں نے ہماری آیتوں (نشانیوں) کو جھٹلایا ہم انہیں بتدریج (آہستہ آہستہ ان کے انجام بد کی طرف) لے جائیں گے کہ انہیں اس کی خبر تک نہ ہوگی۔\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mcxxxvii{اور میں انہیں ڈھیل دیتا ہوں بے شک میری تدبیر بڑی مضبوط ہے۔\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mcxxxviii{کیا ان لوگوں نے اتنا بھی نہیں سوچا کہ ان کے ساتھی (پیغمبر اسلام(ص)) میں ذرا بھی جنون نہیں ہے۔ وہ تو بس کھلم کھلا (خدا کے عذاب سے) ڈرانے والا ہے۔\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mcxxxix{کیا ان لوگوں نے آسمانوں اور زمین کی بادشاہی میں اور ان چیزوں میں جو اللہ نے پیدا کی ہیں کبھی غور و فکر نہیں کیا؟ اور کبھی نظر اٹھا کر ان کو نہیں دیکھا؟ اور اس بات پر کہ شاید ان کا (مقررہ) وقت آگیا ہو۔ تو اب وہ اس کے بعد کس بات پر ایمان لائیں گے؟\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mcxl{جس کو اللہ گمراہی میں چھوڑ دے اس کو کوئی ہدایت نہیں کر سکتا اور وہ (خدا) انہیں چھوڑ دیتا ہے تاکہ اپنی سرکشی میں بھٹکتے رہیں۔\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mcxli{(اے رسول) لوگ آپ سے قیامت کی گھڑی کے متعلق سوال کرتے ہیں کہ اس کا وقوع کب ہوگا؟ کہہ دو کہ اس کا علم تو میرے پروردگار کے ہی پاس ہے اسے اس کا وقت آنے پر وہی ظاہر کرے گا۔ وہ گھڑی آسمانوں اور زمین میں بڑی بھاری ہے (وہ بڑا بھاری حادثہ ہے جو ان میں رونما ہوگا) وہ نہیں آئے گی تمہارے پاس مگر اچانک۔ لوگ اس طرح آپ سے پوچھتے ہیں جیسے آپ اس کی تحقیق اور کاوش میں لگے ہوئے ہیں؟ کہہ دو۔ کہ اس کا علم تو بس اللہ ہی کے پاس ہے۔ لیکن اکثر لوگ یہ حقیقت جانتے نہیں ہیں۔\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mcxlii{(اے رسول(ص)) کہہ دو۔ کہ میں اپنے نفع و نقصان پر کوئی قدرت و اختیار نہیں رکھتا۔ مگر جو اللہ چاہے (وہی ہوتا ہے) اور اگر مجھے غیب کا علم ہوتا تو بہت سے فائدے حاصل کر لیتا اور (زندگی میں) مجھے کبھی کوئی نقصان نہ پہنچتا۔ میں تو بس (نافرمانوں کو) ڈرانے والا اور ایمانداروں کو خوشخبری دینے والا ہوں۔\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mcxliii{اللہ وہی ہے جس نے تمہیں ایک متنفس (جاندار) سے پیدا کیا۔ اور پھر اس کی جنس سے اس کا جوڑا (شریک حیات) بنایا۔ تاکہ وہ (اس کی رفاقت میں) سکون حاصل کرے۔ پھر جب مرد عورت کو ڈھانک لیتا ہے۔ تو اسے ہلکا سا حمل رہ جاتا ہے جسے لئے وہ چلتی پھرتی رہتی ہے اور جب وہ بوجھل ہو جاتی ہے (وضعِ حمل کا وقت آجاتا ہے) تو دونوں (میاں بیوی) اپنے اللہ سے جو ان کا پروردگار ہے دعا مانگتے ہیں کہ اگر تو نے ہمیں صحیح و سالم اولاد دے دی تو ہم تیرے بڑے شکر گزار ہوں گے۔\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mcxliv{مگر جب وہ ان دونوں کو صحیح و سالم فرزند عطا کر دیتا ہے۔ تو یہ دونوں اس کی عطا کردہ چیز (اولاد) میں دوسروں کو اس کا شریک ٹھہرانے لگتے ہیں۔ اللہ اس سے بہت برتر ہے جو مشرک کرتے ہیں۔\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mcxlv{آیا یہ ان کو شریک ٹھہراتے ہیں جو کسی چیز کو پیدا نہیں کر سکتے اور وہ خود کسی کے پیدا کئے ہوئے ہیں۔\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mcxlvi{اور وہ نہ ان کی مدد کرنے کی طاقت رکھتے ہیں اور نہ ہی اپنی مدد پر قادر ہیں۔\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mcxlvii{اور اگر تم ان کو سیدھے راستہ کی طرف بلاؤ تو وہ تمہارے پیچھے قدم نہیں اٹھا سکتے۔ تمہارے لئے برابر ہے کہ ان کو بلاؤ یا خاموش رہو (دونوں باتوں کا نتیجہ ایک ہی ہے)۔\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mcxlviii{(اے کافرو) یقینا وہ جنہیں تم اللہ کو چھوڑ کر (اور خدا سمجھ کر) پکارتے ہو وہ تمہاری ہی طرح (خدا کے) بندے ہیں۔ اگر تم اس دعویٰ میں سچے ہو (کہ ان میں مافوقِ بشریت طاقتیں ہیں) تو انہیں پکارو۔ پھر تو انہیں چاہیے کہ تمہاری دعا و پکار کا جواب دیں۔\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mcxlix{آیا ان (بتوں) کے پاؤں ہیں کہ جن سے وہ چلتے ہوں آیا ان کے ہاتھ ہیں جن سے وہ پکڑتے ہوں کیا ان کی آنکھیں ہیں جن سے وہ دیکھتے ہوں اور کیا ان کے کان ہیں جن سے وہ سنتے ہوں۔ (اے پیغمبر(ص)) کہو کہ تم اپنے تمام شریکوں کو پکارو۔ پھر میرے خلاف سب تدبیریں کرو اور مجھے بالکل مہلت نہ دو۔\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mcl{میرا ولی و سرپرست وہ اللہ ہے جس نے (یہ) کتاب نازل کی ہے اور وہ نیک بندوں کا سرپرست اور کارساز ہے۔\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mcli{اور جنہیں تم اللہ کے سوا خدا پکارتے ہو۔ وہ نہ تمہاری مدد کر سکتے ہیں اور نہ خود اپنی ہی مدد کر سکتے ہیں۔\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mclii{اور اگر انہیں سیدھے راستہ کی دعوت دو تو وہ تمہاری بات سنتے نہیں ہیں اور تم انہیں دیکھوگے کہ گویا وہ تمہاری طرف دیکھ رہے ہیں حالانکہ وہ دیکھتے نہیں ہیں۔\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mcliii{(اے نبی(ص)) عفو و درگزر سے کام لو۔ اور نیکی کا حکم دیں اور جاہلوں سے روگردانی کریں (ان سے نہ الجھیں)۔\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mcliv{اور اگر شیطان کی طرف سے جوش دلانے کی کوئی کوشش ہو تو خدا سے پناہ مانگیں۔ یقینا وہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mclv{جو لوگ پرہیزگار ہیں جب انہیں کوئی شیطانی خیال چھو بھی جائے تو وہ چوکنے ہو جاتے ہیں اور یادِ الٰہی میں لگ جاتے ہیں اور ان کی بصیرت تازہ ہو جاتی ہے (اور حقیقتِ حال کو دیکھنے لگتے ہیں)۔\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mclvi{اور جو شیطانوں کے بھائی بند ہیں تو وہ (شیاطینِ انسی و جنی) ان کو گمراہی میں کھینچتے لئے جاتے ہیں اور (انہیں گمراہ کرتے ہیں) کوئی کسر اٹھا نہیں رکھتے۔\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mclvii{(اے پیغمبر(ص)) جب تم ان کے سامنے (ان کا کوئی مطلوبہ) معجزہ لے کر نہ جاؤ تو وہ کہتے ہیں کہ تم نے خود کوئی معجزہ کیوں نہ منتخب کر لیا؟ (یعنی اپنی مرضی سے کیوں نہ بنا لیا؟) کہہ دیجیے کہ میں تو صرف اسی وحی کی پیروی کرتا ہوں جو میرا پروردگار مجھے کرتا ہے (اس میں میری پسند کا کیا دخل؟) یہ (قرآن) تمہارے پروردگار کی طرف سے سامانِ ہدایت اور سراسر رحمت ہے۔\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mclviii{اور (اے مسلمانو) جب قرآن پڑھا جائے تو کان لگا کر (توجہ سے) سنو اور خاموش ہو جاؤ تاکہ تم پر رحمت کی جائے۔\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mclix{اور (اے پیغمبر(ص)) صبح و شام اپنے پروردگار کو یاد کرو۔ اپنے دل میں عجز و انکساری اور خوف و ہراس کے ساتھ۔ اور زبان سے بھی چِلائے بغیر (یعنی دھیمی آواز کے ساتھ) اور (یادِ خدا سے) غفلت کرنے والوں میں سے نہ ہو جاؤ۔\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mclx{جو تمہارے پروردگار کے خاص مقرب ہیں وہ کبھی اس کی عبادت سے سرکشی نہیں کرتے اور اس کی تسبیح و تقدیس کرتے ہیں (اس کی پاکی بیان کرتے ہیں)اور اس کی بارگاہ میں سر بسجود ہوتے ہیں۔\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mclxi{\basmalahur (اے رسول) لوگ آپ سے انفال کے بارے میں سوال کرتے ہیں۔ کہہ دیجیے کہ انفال اللہ اور اللہ کے رسول کے لئے ہیں۔ پس اگر تم مؤمن ہو تو اللہ سے ڈرو۔ اور اپنے باہمی تعلقات و معاملات کی اصلاح کرو۔ اور اللہ اور اس کے رسول کی اطاعت کرو۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mclxii{(کامل) ایمان والے تو بس وہ ہیں کہ جب اللہ کا ذکر کیا جائے تو ان کے دل دھل جاتے ہیں اور جب ان کے سامنے اس کی آیتوں کی تلاوت کی جائے تو ان کے ایمان بڑھ جاتے ہیں اور وہ ہر ایک حال میں اپنے پروردگار پر توکل (بھروسہ) رکھتے ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mclxiii{جو نماز قائم کرتے ہیں اور جو کچھ ہم نے ان کو دیا ہے اس میں سے کچھ (ہماری راہ میں) خرچ کرتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mclxiv{بے شک ایسے لوگ حقیقی مؤمن ہیں۔ ان کے لئے ان کے پروردگار کے ہاں مرتبے ہیں۔ اور بخشش ہے اور بہترین روزی ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mclxv{(یہ انفال کا معاملہ ایسا ہی ہے) جیساکہ آپ کے پروردگار نے (جنگِ بدر میں) حق کے ساتھ آپ کو آپ کے گھر سے نکالا اور اہلِ ایمان کا ایک گروہ اس کو ناپسند کر رہا تھا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mclxvi{باوجودیکہ حق واضح ہوگیا تھا مگر وہ گروہ آپ سے اس امرِ حق میں یوں جھگڑ رہا تھا۔ کہ گویا اسے موت کی طرف ہانک کر لے جایا جا رہا ہے اور وہ اپنی آنکھوں سے موت کو دیکھ رہا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mclxvii{اور (یاد کرو وہ وقت) کہ جب خدا نے تم سے دو گروہوں میں سے ایک کا وعدہ کیا تھا کہ وہ تمہارے لئے ہے (تمہارے ہاتھ آئے گا) اور تم یہ چاہتے تھے کہ غیر مسلح گروہ تمہارے ہاتھ آجائے اور اللہ یہ چاہتا تھا کہ اپنے کلام و احکام کے ذریعہ سے حق کو ثابت کر دے اور کافروں کی جڑ کاٹ دے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mclxviii{تاکہ حق کو حق کرکے اور باطل کو باطل کرکے دکھا دے اگرچہ مجرم لوگ اس بات کو کتنا ہی ناپسند کریں (یعنی خدا چاہتا تھا کہ تمہاری مسلح گروہ سے مڈبھیڑ ہو)۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mclxix{(اس وقت کو یاد کرو) جب تم اپنے پروردگار سے فریاد کر رہے تھے اور اس نے تمہاری فریاد سن لی (اور فرمایا) کہ تمہاری مدد کے لیے یکے بعد دیگرے ایک ہزار فرشتے بھیج رہا ہوں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mclxx{اور اللہ نے ایسا اس لئے کیا کہ تمہارے لئے خوشخبری ہو اور تمہارے مضطرب دلوں کو اطمینان ہو ورنہ فتح و فیروزی تو بہرحال اللہ ہی کی طرف سے ہے۔ یقینا اللہ زبردست اور حکمت والا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mclxxi{اور وہ وقت (بھی یاد رکھنے کے قابل ہے کہ) جب اللہ نے تمہیں غنودگی سے ڈھانپ دیا تھا تاکہ اس کی طرف سے تمہیں امن و سکون حاصل ہو۔ اور آسمان سے تم پر پانی برسا رہا تھا۔ تاکہ تمہیں پاک صاف کرے اور تم سے شیطان کی نجاست و ناپاکی دور کرے اور تمہارے دلوں کو مضبوط کرے (تمہاری ڈھارس بندھائے) اور تمہارے قدموں کو جمائے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mclxxii{اور وہ وقت بھی (یاد رکھنے کے قابل ہے) جب تمہارا پروردگار فرشتوں کو وحی کر رہا تھا کہ میں تمہارے ساتھ ہوں۔ تم اہلِ ایمان کو ثابت قدم رکھو۔ میں عنقریب کافروں کے دلوں میں (مؤمنوں کا) رعب ڈال دوں گا سو (اے مسلمانو) تم کافروں کی گردنوں پر ضرب لگاؤ اور جوڑ جوڑ پر چوٹ لگاؤ۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mclxxiii{یہ اس لئے ہے کہ ان لوگوں نے خدا اور رسول(ص) کی مخالفت کی۔ یاد رکھو کہ جو کوئی بھی خدا اور رسول کی مخالفت کرے گا تو اللہ (مکافاتِ عمل میں) سخت سزا دینے والا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mclxxiv{(اے مخالفینِ حق) دنیا میں تمہاری یہ سزا ہے۔ پس اس کا مزہ چکھو۔ اور (آخرت میں) آتشِ دوزخ کا عذاب بھی ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mclxxv{اے ایمان والو! جب کافروں کے لشکر سے تمہاری مڈبھیڑ ہو جائے تو خبردار! ان کے مقابلہ میں ان کو پیٹھ نہ دکھانا (بلکہ سیسہ پلائی ہوئی دیوار کی طرح جم کر لڑنا)۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mclxxvi{اور جو ایسے (جنگ والے) موقع پر ان کو پیٹھ دکھائے گا۔ سوا اس کے جو جنگی چال کے طور پر ہٹ جائے۔ یا کسی (اپنے) فوجی دستہ کے پاس جگہ لینے کے لیے ایسا کرے (کہ اس میں کوئی حرج نہیں ہے) تو وہ خدا کے قہر و غضب میں آجائے گا۔ اور اس کا ٹھکانا دوزخ ہوگا۔ اور وہ بہت بری جائے بازگشت ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mclxxvii{(اے مسلمانو) تم نے ان (کفار) کو قتل نہیں کیا بلکہ اللہ نے قتل کیا اور (اے رسول(ص)) وہ سنگریزے تو نے نہیں پھینکے جبکہ تو نے پھینکے بلکہ خدا نے پھینکے (یہ سب کچھ اس لئے ہوا کہ) خدا اہلِ ایمان پر خوب احسان فرمائے (یا اللہ اس کے ذریعہ سے ایمان والوں کو بہترین آزمائش میں ڈال کر آزمائے) یقینا اللہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mclxxviii{یہ معاملہ تو تمہارے ساتھ ہو چکا ہے اور (کفار کے ساتھ معاملہ یہ ہے کہ) اللہ ان کی مخفی تدبیروں کو کمزور کرنے والا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mclxxix{اور (اے کفارِ مکہ) اگر تم فتحمندی کے طلبگار ہو (کہ جو حق پر ہے اس کی فتح ہو) تو (مسلمانوں کی) فتح تمہارے سامنے آگئی! اور اگر تم اب بھی (جنگ و جدال) سے باز آجاؤ تو یہ تمہارے لئے بہتر ہے اور اگر پلٹ کر پھر وہی (شرارت) کروگے تو ہم بھی وہی کریں گے (مسلمانوں کی نصرت کریں گے اور تمہیں سزا دیں گے) اور تمہاری جمعیت چاہے کتنی ہی زیادہ ہو تمہیں کوئی فائدہ نہ دے گی۔ بے شک اللہ ایمان والوں کے ساتھ ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mclxxx{اے ایمان والو! اللہ اور اس کے رسول کی اطاعت کرو۔ اور اس سے روگردانی نہ کرو حالانکہ تم (آوازِ حق) سن رہے ہو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mclxxxi{اور ان لوگوں کی طرح نہ ہو جانا جو کہتے تو ہیں کہ ہم نے سن لیا حالانکہ (دراصل) وہ کچھ بھی سنتے (سناتے) نہیں ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mclxxxii{بے شک اللہ کے نزدیک سب جانوروں سے بدتر جانور وہ (انسان) ہیں جو بہرے گونگے ہیں جو عقل سے ذرا کام نہیں لیتے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mclxxxiii{اگر اللہ جانتا کہ ان میں کچھ بھی بھلائی ہے تو ضرور انہیں سنوا دیتا اور اگر (اس بھلائی کے بغیر) انہیں سنواتا۔ تو وہ بے رخی کرتے ہوئے پیٹھ پھیر دیتے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mclxxxiv{اے ایمان والو اللہ اور رسول کی آواز پر لبیک کہو۔ جب کہ وہ (رسول) تمہیں بلائیں۔ اس چیز کی طرف جو تمہیں (روحانی) زندگی بخشنے والی ہے۔ اور جان لو۔ کہ اللہ (اپنے مقررہ اسباب کے تحت) انسان اور اس کے دل کے درمیان حائل ہو جاتا ہے اور (یہ بھی جان لو کہ) تم سب اسی کے حضور جمع کئے جاؤگے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mclxxxv{اور اس فتنہ سے بچو جو صرف انہی تک محدود نہیں رہے گا جنہوں نے تم میں سے ظلم و تعدی کی (بلکہ سب اس کی لپیٹ میں آجائیں گے) اور جان لو کہ اللہ سخت سزا دینے والا ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mclxxxvi{اور وہ وقت یاد کرو۔ جب تم تھوڑے تھے اور ملک میں کمزور سمجھے جاتے تھے اور ڈرتے رہتے تھے کہ کہیں لوگ تمہیں اچک نہ لے جائیں تو اللہ نے تمہیں (مدینہ میں) پناہ دی اور اپنی نصرت سے تمہاری تائید کی اور تمہیں پاک و پاکیزہ چیزیں دے کر رزق کا سامان مہیا کر دیا۔ تاکہ تم شکر گزار ہو۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mclxxxvii{اے ایمان والو! سمجھتے بوجھتے ہوئے اللہ اور رسول سے خیانت نہ کرو اور نہ ہی اپنی امانتوں میں خیانت کرو۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mclxxxviii{اور جان لو۔ کہ تمہارے مال اور تمہاری اولاد (تمہارے لئے) ایک آزمائش ہیں اور یہ بھی کہ اللہ ہی کے پاس بڑا اجر ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mclxxxix{اے ایمان والو اگر تم تقوائے الٰہی اختیار کرو۔ تو خدا تمہیں حق و باطل میں تفرقہ کرنے کی قوت و صلاحیت عطا فرمائے گا۔ اور تمہاری برائیوں کو ڈھانپ لے گا (پردہ پوشی کرے گا) اور تمہارے گناہ بخش دے گا۔ اور اللہ بڑا فضل (و کرم) والا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcxc{اور (اے رسول(ص)) وہ وقت یاد کرو جب کافر آپ کے خلاف منصوبے بنا رہے تھے کہ آپ کو قید کر دیں۔ یا قتل کریں۔ یا شہر بدر کر دیں وہ بھی تدبیریں کر رہے تھے اور اللہ بھی تدبیر کر رہا تھا اور اللہ بہترین تدبیر کرنے والا ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcxci{اور جب ان کے سامنے ہماری آیات پڑھی جاتی ہیں تو کہتے ہیں ہاں ہم نے سن لیا۔ اگر ہم چاہیں تو ہم بھی ایسا کلام پیش کر سکتے ہیں۔ یہ نہیں ہیں مگر گزرے ہوئے لوگوں کی داستانیں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcxcii{(اے رسول(ص)) وہ وقت یاد کرو۔ جب انہوں نے کہا۔ اے اللہ! اگر یہ (اسلام) تیری طرف سے برحق ہے۔ تو ہم پر آسمان سے پتھر برسا یا کوئی اور دردناک عذاب لا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcxciii{اور اللہ ایسا نہیں ہے کہ ان پر عذاب نازل کرے جبکہ آپ ان کے درمیان موجود ہیں اور اللہ ایسا بھی نہیں ہے کہ ان پر عذاب نازل کرے جبکہ وہ استغفار کر رہے ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcxciv{لیکن اللہ کیوں نہ ان پر عذاب نازل کرے جبکہ وہ مسجد الحرام سے (مسلمانوں کو) روک رہے ہیں حالانکہ وہ اس کے متولی نہیں ہیں اس کے متولی تو صرف پرہیزگار لوگ ہیں۔ لیکن اکثر لوگ علم نہیں رکھتے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcxcv{اور خانہ کعبہ کے پاس ان کی نماز نہیں تھی۔ مگر سیٹیاں اور تالیاں بجانا۔ سو اب عذاب کا مزہ چکھو۔ یہ تمہارے کفر کی پاداش ہے جو تم کیا کرتے تھے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcxcvi{بے شک جو لوگ کافر ہیں وہ اس لئے اپنے مال خرچ کرتے ہیں کہ (لوگوں کو) خدا کی راہ سے روکیں یہ آئندہ بھی اسی طرح خرچ کریں گے اور پھر انجام کار یہ (مال خرچ کرنا) ان کے لئے حسرت اور پچھتاوے کا باعث بن جائے گا۔ اور بالآخر وہ مغلوب ہو جائیں گے۔ اور جو کافر ہیں وہ گھیر گھار کر جہنم کی طرف جمع کئے جائیں گے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcxcvii{اور یہ سب کچھ اس لئے ہوگا کہ اللہ ناپاک (لوگوں) کو پاک لوگوں سے جدا کر دے اور جو ناپاک ہیں ان کو ایک دوسرے پر تہہ بہ تہہ رکھ کر ڈھیر بنائے اور پھر اس سارے ڈھیر کو جہنم میں جھونک دے۔ یہی وہ لوگ ہیں جو خسارہ (نقصان) اٹھانے والے ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcxcviii{(اے رسول(ص)) کافروں سے کہہ دو کہ اگر وہ اب بھی (شرارت سے) باز آجائیں۔ تو جو کچھ گزر چکا وہ انہیں معاف کر دیا جائے گا۔ اور اگر وہ اپنی سابقہ روش کا اعادہ کریں گے تو پھر گزشتہ (نافرمان) قوموں کے ساتھ (خدا کی روش) بھی گزر چکی ہے (ان کے ساتھ بھی وہی ہوگا)۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcxcix{(اے مسلمانو) ان (کفار) سے جنگ جاری رکھو یہاں تک کہ فتنہ و فساد ختم ہو جائے اور دین پورے کا پورا صرف اللہ کے لئے ہو جائے پھر اگر وہ (کفر و فتنہ پردازی سے) باز آجائیں تو وہ جو کچھ کر رہے ہیں اللہ اس کو خوب دیکھنے والا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcc{تو پھر جان لو کہ اللہ تمہارا سرپرست و کارساز ہے وہ کیا ہی اچھا سرپرست ہے۔ کیا ہی اچھا یار و مددگار ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcci{اور جان لو کہ جو چیز بھی تمہیں بطورِ غنیمت حاصل ہو اس کا پانچواں حصہ اللہ کے لئے، رسول کے لئے، (اور رسول کے) قرابتداروں، یتیموں، مسکینوں اور مسافروں کے لئے ہے (یہ واجب ہے) اگر تم اللہ پر اور اس (غیبی نصرت) پر ایمان رکھتے ہو جو ہم نے اپنے بندۂ خاص پر حق و باطل کا فیصلہ کر دینے والے دن نازل کی تھی جس دن (مسلمانوں اور کافروں کی) دو جمعیتوں میں مڈبھیڑ ہوئی تھی اور اللہ ہر چیز پر قادر ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mccii{جس وقت تم قریب کے ناکہ پر تھے اور وہ دور کے ناکہ پر اور قافلہ تم سے ادھر نیچے (ساحل سمندر پر) تھا اگر تم ایک دوسرے سے وقت مقرر بھی کر لیتے تو بھی تم میں اختلاف ہو جاتا۔ لیکن خدا نے تو اس بات کو پورا کرنا تھا جو (مڈبھیڑ) ہونے والی تھی۔ تاکہ جو ہلاک ہو وہ اتمامِ حجت کے بعد ہلاک ہو اور جو زندہ رہے تو وہ بھی اتمام حجت کے بعد زندہ رہے بے شک اللہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcciii{(اور اے نبی) وہ وقت یاد کرو۔ جب اللہ نے خواب میں آپ کو ان (کفار) کی تعداد تھوڑی کرکے دکھائی تھی اور اگر وہ انہیں زیادہ کرکے دکھاتا تو تم ہمت ہار جاتے۔ اور آپس میں جھگڑنے لگتے۔ لیکن اللہ نے اس سے بچایا۔ بے شک اللہ سینوں کے اندر والی باتوں کا خوب جاننے والا ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcciv{وہ وقت یاد کرو۔ کہ جب اللہ نے انہیں تمہاری نگاہوں میں کم کرکے دکھایا۔ اور تمہاری تعداد کو ان کی نظروں میں کم کرکے دکھایا تاکہ اللہ اس کو پورا کرے جو ہو کر رہنا تھا۔ اور تمام معاملات کی بازگشت اللہ ہی کی طرف ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mccv{اے ایمان والو! جب کسی جماعت سے تمہارا مقابلہ ہو جائے تو ثابت قدم رہا کرو۔ اور اللہ کو یاد کرو۔ تاکہ تم کامیاب ہو جاؤ۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mccvi{اور اللہ اور اس کے رسول کی اطاعت کرو۔ اور آپس میں جھگڑا نہ کرو۔ ورنہ کمزور پڑ جاؤگے اور تمہاری ہوا اکھڑ جائے گی۔ اور (ہر قسم کی مصیبت و تکلیف میں) صبر سے کام لو بے شک اللہ صبر کرنے والوں کے ساتھ ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mccvii{اور ان لوگوں کی مانند نہ ہو جو اپنے گھروں سے اتراتے ہوئے اور لوگوں کو اپنی شان و شوکت دکھاتے ہوئے نکلے اور ان کا حال یہ ہے کہ وہ خدا کی راہ سے روکتے ہیں اور وہ جو کچھ کرتے ہیں اللہ (اپنے علم و قدرت سے) اس کا احاطہ کئے ہوئے ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mccviii{اور وہ وقت یاد کرو جب شیطان نے ان کے اعمال ان کے لئے آراستہ کر دیئے (انہیں خوشنما کرکے دکھایا) اور کہا آج کے دن لوگوں میں سے کوئی بھی تم پر غالب آنے والا نہیں ہے۔ اور میں تمہارا حامی ہوں۔ پھر جب دونوں جماعتیں آمنے سامنے ہوئیں تو وہ الٹے پاؤں واپس ہوا اور کہا میں تم سے بری الذمہ ہوں۔ میں وہ کچھ دیکھ رہا ہوں جو تم نہیں دیکھ رہے میں اللہ سے ڈرتا ہوں۔ اور اللہ بڑی سخت سزا دینے والا ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mccix{اور (وہ وقت بھی قابل یاد ہے) جب منافق اور وہ لوگ جن کے دلوں میں (نفاق کی) بیماری ہے کہہ رہے تھے کہ ان لوگوں (مسلمانوں) کو ان کے دین نے فریب اور خبط میں مبتلا کر دیا ہے اور جو کوئی اللہ پر توکل (بھروسہ) کرتا ہے سو اللہ بڑا زبردست، بڑا حکمت والا ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mccx{اور کاش تم وہ موقع دیکھو کہ جب فرشتے کافروں کی روحیں قبض کرتے ہیں اور ان کے چہروں اور پیٹھوں پر ضربیں لگاتے ہیں اور کہتے ہیں کہ اب عذابِ آتش کا مزہ چکھو۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mccxi{(اے دشمنانِ حق!) یہ سزا ہے اس کی جو تمہارے ہاتھ پہلے بھیج چکے ہیں۔ اور اللہ اپنے بندوں پر ظلم کرنے والا نہیں ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mccxii{ان کا حال قومِ فرعون اور ان لوگوں جیسا ہے۔ جو ان سے پہلے گزر چکے جنہوں نے آیاتِ الٰہی کا انکار کیا اور خدا نے انہیں گناہوں پر پکڑ لیا۔ بے شک اللہ بڑا طاقتور ہے اور بڑی سزا دینے والا ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mccxiii{یہ اس بنا پر ہے کہ اللہ کبھی اس نعمت کو تبدیل نہیں کرتا جو اس نے کسی قوم کو عطا کی ہے جب تک وہ خود اپنی حالت تبدیل نہ کر دیں اللہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mccxiv{(کفارِ مکہ کا) حال قومِ فرعون اور ان سے پہلے گزرے ہوئے (سرکشوں) کا سا ہے جنہوں نے آیاتِ الٰہی کو جھٹلایا اور ہم نے انہیں ان کے گناہوں کی وجہ سے ہلاک کر دیا اور فرعونیوں کو (سمندر میں) غرق کر دیا۔ اور وہ سب کے سب ظالم تھے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxv{بے شک زمین پر چلنے والی سب مخلوق میں سے بدترین وہ لوگ ہیں جو کافر ہیں اور اب وہ کسی طرح بھی ایمان لانے والے نہیں ہیں۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxvi{(اے رسول(ص)) جن لوگوں سے آپ نے (کئی بار صلح کا) معاہدہ کیا اور انہوں نے ہر بار اسے توڑا۔ اور وہ (اللہ سے) نہیں ڈرتے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxvii{پس اگر وہ جنگ میں آپ کے ہاتھ آجائیں تو (انہیں ایسی عبرتناک سزا دیں کہ) جو ان کے بعد والے ہیں (ان کے پشت پناہ ہیں) ان کو منتشر کر دیں۔ تاکہ وہ اس سے عبرت حاصل کریں۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxviii{اور اگر آپ کو کسی جماعت کی طرف سے خیانت (عہد شکنی کا) اندیشہ ہو تو پھر ان کا معاہدہ اس طرح ان کی طرف پھینک دیں کہ معاملہ برابر ہو جائے۔ بے شک اللہ خیانت کرنے والوں کو دوست نہیں رکھتا۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxix{اور کافر لوگ یہ خیال نہ کریں کہ وہ بازی لے گئے (بچ گئے)۔ یقینا وہ اللہ کو عاجز نہیں کر سکتے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxx{(اے مسلمانو!) تم جس قدر استطاعت رکھتے ہو ان (کفار) کے لئے قوت و طاقت اور بندھے ہوئے گھوڑے تیار رکھو۔ تاکہ تم اس (جنگی تیاری) سے خدا کے دشمن اور اپنے دشمن کو اور ان کھلے دشمنوں کے علاوہ دوسرے لوگوں (منافقوں) کو خوفزدہ کر سکو۔ جن کو تم نہیں جانتے البتہ اللہ ان کو جانتا ہے اور تم جو کچھ اللہ کی راہ (جہاد) میں خرچ کروگے تمہیں اس کا پورا پورا اجر و ثواب عطا کیا جائے گا اور تمہارے ساتھ کسی طرح ظلم نہیں کیا جائے گا۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxxi{اور اگر وہ صلح کی طرف مائل ہوں تو آپ بھی اس کی طرف مائل ہو جائیں۔ اور اللہ پر بھروسہ رکھیں بے شک وہ بڑا سننے والا، بڑا علم والا ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxxii{اور اگر ان کا ارادہ یہ ہو کہ آپ کو دھوکہ دیں۔ تو (فکر نہ کریں) اللہ تمہارے لئے کافی ہے وہ وہی ہے جس نے اپنی نصرت اور مؤمنین کی جماعت سے آپ کی تائید کی۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxxiii{اور اسی نے ان (اہلِ ایمان) کے دلوں میں الفت پیدا کی۔ اگر آپ تمام روئے زمین کی دولت بھی خرچ کر دیتے تو ان کے دلوں میں الفت پیدا نہیں کر سکتے تھے۔ مگر اللہ نے (اپنی قدرتِ کاملہ سے) ان کے درمیان الفت پیدا کر دی بے شک وہ غالب اور بڑا حکمت والا ہے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxxiv{اے نبی! آپ کے لئے اللہ اور وہ اہلِ ایمان کافی ہیں جو آپ کے پیروکار ہیں۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccxxv{اے نبی(ص)! اہلِ ایمان کو جنگ پر آمادہ کرو۔ اگر تم میں سے بیس صابر (ثابت قدم) آدمی ہوئے تو وہ دو سو (کافروں) پر غالب آئیں گے اور اگر تم میں سے ایک سو ہوئے تو کافروں کے ایک ہزار پر غالب آجائیں گے کیونکہ یہ وہ لوگ ہیں جو سمجھ بوجھ نہیں رکھتے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccxxvi{اب خدا نے تم پر بوجھ ہلکا کر دیا اور اسے معلوم ہوگیا کہ تم میں کمزوری ہے۔ تو اب اگر تم میں سے ایک سو صابر (ثابت قدم) ہوں گے تو دو سو پر غالب آئیں گے اور اگر تم میں سے ایک ہزار ہوں گے تو وہ اللہ کے حکم سے دو ہزار پر غالب آئیں گے۔ اور اللہ تو صبر کرنے والوں کے ساتھ ہے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mccxxvii{اور یہ بات نبی کے شایانِ شان نہیں ہے کہ اس کے لیے قیدی ہوں۔ جب تک وہ زمین میں خوب خون ریزی نہ کرے (فتنہ کو کچل نہ دے) تم دنیا کا مال و متاع چاہتے ہو اور اللہ آخرت چاہتا ہے اور اللہ زبردست حکمت والا ہے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccxxviii{اگر خدا کی جانب سے پہلے ایک نوشتہ موجود نہ ہوتا۔ تو تم نے جو کچھ کیا ہے اس کی پاداش میں ضرور تمہیں بڑا عذاب پہنچتا۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccxxix{بہرکیف جو کچھ تمہیں بطورِ غنیمت حاصل ہو اسے حلال اور پاکیزہ سمجھ کر کھاؤ اور اللہ (کی نافرمانی سے) ڈرو۔ بے شک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mccxxx{اے نبی! ان قیدیوں سے کہو جو آپ کے قبضہ میں ہیں کہ اگر اللہ نے تمہارے دلوں میں کچھ نیکی اور بھلائی پائی تو جو کچھ تم سے لیا گیا ہے اس سے بہتر تمہیں عطا فرمائے گا۔ اور تمہیں بخش بھی دے گا کیونکہ وہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mccxxxi{اور اگر انہوں نے آپ کو فریب دینا چاہا۔ تو وہ اس سے پہلے خدا کو فریب دے چکے ہیں اور (اس کی پاداش میں) اللہ نے (آپ کو) ان پر قابو دے دیا کیونکہ خدا بڑا علم والا، بڑا حکمت والا ہے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mccxxxii{یقینا جو لوگ ایمان لائے اور ہجرت کی اور اللہ کی راہ میں اپنے مال و جان سے جہاد کیا اور جنہوں نے مہاجرین کو پناہ دی اور امداد کی یہ لوگ آپس میں ایک دوسرے کے حامی و مددگار ہیں۔ اور وہ لوگ جو ایمان تو لائے مگر ہجرت نہیں کی تو ان سے تمہارا ولایت کا کوئی تعلق نہیں ہے۔ یہاں تک کہ ہجرت کریں۔ اور اگر وہ کسی دینی معاملہ میں تم سے مدد چاہیں تو تم پر (ان کی) مدد کرنا فرض ہے۔ سوا اس صورت کے کہ یہ مدد اس قوم کے خلاف مانگیں جس سے تمہارا معاہدۂ امن ہو۔ اور تم جو کچھ کرتے ہو اللہ اسے دیکھنے والا ہے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mccxxxiii{اور جو کافر ہیں وہ آپس میں ایک دوسرے کے حامی و مددگار ہیں اگر تم ایسا نہیں کروگے تو زمین میں بڑا فتنہ اور فساد پھیل جائے گا۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mccxxxiv{جو لوگ ایمان لائے، ہجرت کی اور اللہ کی راہ میں جہاد کیا اور جنہوں نے پناہ دی اور امداد کی یہی لوگ سچے مؤمن ہیں۔ ان کے لئے بخشش ہے اور عزت کی روزی۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mccxxxv{اور جو لوگ بعد میں ایمان لائے اور ہجرت کی اور تمہارے ساتھ مل کر جہاد کیا تو وہ بھی تم ہی میں داخل ہیں اور جو صاحبانِ قرابت ہیں، وہ اللہ کی کتاب میں (میراث کے سلسلہ میں) ایک دوسرے کے زیادہ حقدار ہیں۔ بے شک اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mccxxxvi{\basmalahur (اے مسلمانو) خدا اور اس کے رسول کی طرف سے اعلانِ برأت ہے ان مشرکین سے جن سے تم نے (صلح کا) معاہدہ کیا تھا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccxxxvii{(اے مشرکو) اب تم صرف چار ماہ تک اس سر زمین پر چل پھر لو اور جان لو کہ تم اللہ کو عاجز نہیں کر سکتے اور یہ کہ اللہ کافروں کو ذلیل و رسوا کرنے والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccxxxviii{اللہ اور اس کے رسول کی طرف سے تمام لوگوں کو حجِ اکبر والے دن اعلانِ عام ہے کہ اللہ اور اس کا رسول مشرکین سے بری و بیزار ہیں۔ اب اگر تم (کفر و شرارت سے) توبہ کرلو تو یہ تمہارے لئے بہتر ہے اور اگر تم نے اس سے روگردانی کی تو پھر جان لو کہ تم اللہ کو عاجز نہیں کر سکتے اور (اے نبی) کافروں کو دردناک عذاب کی خوش خبری سنا دو۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccxxxix{سوا ان مشرکوں کے کہ جن سے تم نے معاہدہ کیا تھا اور انہوں نے (اپنا قول و قرار نبھانے میں) کوئی کمی نہیں کی اور نہ تمہارے خلاف کسی کی امداد کی سو تم ان سے کیا ہوا معاہدہ اس کی مقررہ مدت تک پورا کرو۔ بے شک اللہ پرہیزگاروں کو دوست رکھتا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccxl{پس جب محترم مہینے گزر جائیں تو مشرکوں کو جہاں کہیں بھی پاؤ قتل کرو اور انہیں گرفتار کرو۔ اور ان کا گھیراؤ کرو اور ہر گھات میں ان کی تاک میں بیٹھو۔ پھر اگر وہ توبہ کر لیں نماز پڑھنے لگیں اور زکوٰۃ ادا کرنے لگیں تو ان کا راستہ چھوڑ دو۔ بے شک خدا بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccxli{اور اے رسول(ص) اگر مشرکین میں سے کوئی آپ سے پناہ مانگے تو اسے پناہ دے دو تاکہ وہ اللہ کا کلام سنے اور پھر اسے اس کی امن کی جگہ پہنچا دو۔ یہ (حکم) اس لئے ہے کہ یہ لوگ (دعوتِ حق کا) علم نہیں رکھتے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccxlii{بھلا ان مشرکوں کا اللہ اور اس کے رسول کے ہاں کس طرح کوئی عہد و پیمان ہو سکتا ہے بجز ان لوگوں کے جن سے تم نے مسجدِ حرام کے پاس (بمقامِ حدیبیہ) معاہدہ کیا تھا سو جب تک وہ لوگ تم سے سیدھے رہیں (معاہدہ پر قائم رہیں) تو تم بھی ان سے سیدھے رہو (قائم رہو)۔ بے شک اللہ پرہیزگاروں کو دوست رکھتا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccxliii{(ان کے سوا دوسرے) مشرکین سے کس طرح کوئی معاہدہ ہو سکتا ہے؟ حالانکہ اگر وہ تم پر غلبہ پا جائیں تو وہ تمہارے بارے میں نہ کسی قرابت کا پاس کریں اور نہ کسی عہد و پیمان کی ذمہ داری کا۔ وہ صرف تمہیں اپنے منہ (کی باتوں) سے راضی کرنا چاہتے ہیں اور ان کے دل انکار کرتے ہیں۔ اور ان میں سے زیادہ تر لوگ فاسق (نافرمان) ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccxliv{انہوں نے تھوڑی سی قیمت پر آیاتِ الٰہی فروخت کر دی ہیں اور (لوگوں کو) اللہ کی راہ سے روکنے لگے۔ بہت ہی برا ہے وہ کام جو یہ کر رہے ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccxlv{وہ کسی مؤمن کے بارے میں نہ قرابت کا پاس کرتے ہیں اور نہ کسی عہد و پیمان کی ذمہ داری کا اور یہی لوگ ہیں جو ظلم و تعدی کرنے والے ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccxlvi{(بہرحال اب بھی) اگر یہ لوگ توبہ کر لیں۔ اور نماز قائم کریں اور زکوٰۃ دیں تو تمہارے دینی بھائی ہیں ہم اپنی آیات کھول کھول کر بیان کرتے ہیں ان لوگوں کے لئے جو علم رکھتے ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccxlvii{اور اگر یہ لوگ اپنے عہد و پیمان کے بعد اپنی قَسموں کو توڑ دیں اور تمہارے دین پر طعن و تشنیع کریں تو تم کفر کے ان سرغنوں سے جنگ کرو، ان کی قَسموں کا کوئی اعتبار نہیں تاکہ یہ باز آجائیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccxlviii{تم ان لوگوں سے کیوں جنگ نہیں کرتے جنہوں نے اپنی قَسموں کو توڑ ڈالا پیغمبر(ص) کو (وطن سے) نکالنے کا ارادہ کیا اور پھر تمہارے برخلاف لڑائی میں پہل بھی کی۔ تم ان سے ڈرتے ہو؟ اللہ زیادہ حقدار ہے اس بات کا کہ اس سے ڈرو اگر تم مؤمن ہو۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccxlix{ان سے جنگ کرو۔ اللہ انہیں تمہارے ہاتھوں سے سزا دلوائے گا۔ اور انہیں ذلیل و خوار کرے گا اور ان کے مقابلہ میں تمہاری مدد کرے گا اور جماعتِ مؤمنین کے دلوں کو شفا دے گا (ان کے سارے دکھ دور کر دے گا)۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccl{اور ان کے دلوں کے غم و غصہ کو دور کرے گا اور جسے چاہے گا توبہ کی توفیق دے گا (اور اس کی توبہ کو قبول کرے گا) اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccli{(اے مسلمانو) کیا تم یہ سمجھتے ہو کہ تم یونہی چھوڑ دیے جاؤگے حالانکہ ابھی تک اللہ نے (ظاہری طور پر) ان لوگوں کو معلوم ہی نہیں کیا جنہوں نے تم میں سے جہاد کیا اور خدا و رسول اور اہل ایمان کو چھوڑ کر کسی کو اپنا جگری دوست اور (محرمِ راز) نہیں بنایا۔ اور اللہ اس سے باخبر ہے جو کچھ تم کر تے ہو۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcclii{اور مشرکین کے لئے روا نہیں ہے کہ وہ مسجدوں کو آباد کریں جبکہ وہ خود اپنے اوپر اپنے کفر کی گواہی دے رہے ہیں۔ یہ وہ لوگ ہیں جن کے سب اعمال ضائع ہوگئے اور وہ ہمیشہ آتشِ دوزخ میں رہیں گے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccliii{درحقیقت مسجدوں کو آباد وہ کرتا ہے جو اللہ اور آخرت کے دن پر ایمان رکھتا ہے، نماز قائم کرتا ہے اور زکوٰۃ ادا کرتا ہے اور اللہ کے سوا اور کسی سے نہیں ڈرتا۔ انہی کے متعلق یہ امید کی جا سکتی ہے کہ وہ ہدایت یافتہ لوگوں میں سے ہوں گے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccliv{کیا تم نے حاجیوں کو پانی پلانے اور مسجد الحرام کے آباد رکھنے کو اس شخص (کے کام کے) برابر قرار دیا ہے جو اللہ اور قیامت کے دن پر ایمان لایا اور اللہ کی راہ میں جہاد کیا۔ یہ دونوں اللہ کے نزدیک برابر نہیں ہیں۔ اور اللہ ظالموں کو منزلِ مقصود تک نہیں پہنچاتا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcclv{جو لوگ ایمان لائے اور ہجرت کی اور راہ خدا میں اپنے مال و جان سے جہاد کیا، اللہ کے نزدیک وہ درجہ میں بہت بڑے ہیں اور یہی لوگ ہیں جو کامیاب ہونے والے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcclvi{ان کا پروردگار انہیں اپنی رحمتِ خاص اور خوشنودی اور ایسے بہشتوں کی خوشخبری دیتا ہے جن میں دائمی نعمت ہوگی۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcclvii{ان میں وہ ہمیشہ رہیں گے بے شک اللہ ہی کے پاس بہت بڑا اجر ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcclviii{اے ایمان والو! اگر تمہارے باپ اور تمہارے بھائی ایمان کے مقابلہ میں کفر کو ترجیح دیں تو پھر ان کو اپنا رفیق و کارساز نہ بناؤ۔ اور جو کوئی ان کو رفیق و کارساز بنائے گا تو وہی لوگ ظالم ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcclix{(اے رسول) کہہ دو کہ اگر تمہارے باپ، تمہارے بیٹے، تمہارے بھائی، تمہاری بیویاں اور تمہارا کنبہ قبیلہ اور تمہارا وہ مال جو تم نے کمایا ہے۔ اور تمہاری وہ تجارت جس کے مندا پڑ جانے سے ڈرتے ہو اور تمہارے وہ رہائشی مکانات جن کو تم پسند کرتے ہو۔ تم کو اللہ، اس کے رسول اور راہِ خدا میں جہاد کرنے سے زیادہ عزیز ہیں۔ تو پھر انتظار کرو۔ یہاں تک کہ اللہ اپنا فیصلہ (تمہارے سامنے) لے آئے اور اللہ فاسق و فاجر قوم کو منزل مقصود تک نہیں پہنچاتا۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcclx{بے شک اللہ نے بہت سے مقامات پر تمہاری مدد فرمائی ہے۔ اور حنین کے موقع پر بھی جب تمہاری کثرت تعداد نے تمہیں مغرور کر دیا تھا مگر اس (کثرت) نے تمہیں کوئی فائدہ نہ پہنچایا اور زمین اپنی ساری وسعت کے باوجود تم پر تنگ ہوگئی پھر تم پیٹھ دکھا کر بھاگ کھڑے ہوئے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcclxi{پھر اللہ نے اپنی طرف سے اپنے رسول اور اہلِ ایمان پر سکون و اطمینان نازل کیا اور ایسے لشکر نازل کئے جو تمہیں نظر نہیں آئے۔ اور اللہ نے کافروں کو سزا دی اور یہی کافروں کا بدلہ ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcclxii{اس کے بعد اللہ جس کی چاہتا ہے توبہ قبول کرتا ہے (اور اسے توفیقِ توبہ دیتا ہے) اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcclxiii{اے ایمان والو! مشرکین سراسر نجس و ناپاک ہیں سو وہ اس سال (سنہ ۹ ہجری) کے بعد مسجد الحرام کے قریب بھی نہ آنے پائیں۔ اور اگر تمہیں ان کی آمد و رفت کے بند ہونے سے تنگدستی کا اندیشہ ہے تو عنقریب خدا اپنے فضل و کرم سے تمہیں تونگر بنا دے گا۔ بے شک اللہ تعالیٰ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcclxiv{(اے مسلمانو!) اہلِ کتاب میں سے جو لوگ اللہ اور روزِ آخرت پر ایمان نہیں رکھتے اور خدا و رسول کی حرام کردہ چیزوں کو حرام نہیں جانتے اور دینِ حق (اسلام) کو اختیار نہیں کرتے ان سے جنگ کرو یہاں تک کہ وہ چھوٹے بن کر (ذلیل ہوکر) ہاتھ سے جزیہ دیں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcclxv{یہودی کہتے ہیں کہ عزیر اللہ کا بیٹا ہے اور نصرانی کہتے ہیں کہ عیسیٰ اللہ کے بیٹے ہیں۔ یہ ان کی باتیں ہیں (بغیر سوچے سمجھے) ان کے منہ سے نکالی ہوئی۔ یہ لوگ بھی ان جیسی باتیں کرنے لگے ہیں جو ان سے پہلے کفر کر چکے ہیں اللہ ان کو ہلاک کرے یہ کدھر بہکے جا رہے ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcclxvi{انہوں نے اللہ کو چھوڑ کر اپنے عالموں اور راہبوں (علماء و مشائخ) کو پروردگار بنا لیا ہے، اور مریم کے فرزند مسیح کو بھی۔ حالانکہ ان کو صرف یہ حکم دیا گیا تھا کہ وہ ایک ہی معبودِ برحق کی عبادت کریں۔ اللہ کے سوا اور کوئی الٰہ نہیں ہے۔ وہ پاک ہے ان مشرکانہ باتوں سے جو یہ کرتے ہیں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcclxvii{وہ چاہتے ہیں کہ اللہ کے نور کو اپنے منہ سے (پھونک مار کر) بجھا دیں اور اللہ انکاری ہے ہر بات سے سوا اس کے کہ وہ اپنے نور کو کمال تک پہنچائے اگرچہ کافر اس کو ناپسند کریں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcclxviii{وہ (اللہ) وہی ہے جس نے ہدایت اور دینِ حق دے کر اپنے رسول کو بھیجا تاکہ اسے تمام دینوں پر غالب کر دے اگرچہ مشرک اسے ناپسند ہی کریں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcclxix{اے ایمان والو! بہت سے عالم اور راہب لوگوں کا مال ناجائز طریقہ پر کھاتے ہیں اور لوگوں کو خدا کی راہ سے روکتے ہیں۔ اور جو لوگ سونا چاندی جمع کرکے رکھتے رہتے ہیں اور اسے اللہ کی راہ میں خرچ نہیں کرتے، انہیں دردناک عذاب کی بشارت دے دو۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcclxx{یہ (واقعہ) اس دن ہوگا جب کہ اس (سونے چاندی) کو دوزخ کی آگ میں تپایا جائے گا اور پھر اس سے ان کی پیشانیوں، پہلوؤں اور پشتوں کو داغا جائے گا (اور انہیں بتایا جائے گا کہ) یہ ہے وہ جو تم نے اپنے لئے جمع کرکے رکھا تھا تو اب مزا چکھو اس کا جو تم نے جمع کرکے رکھا تھا۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcclxxi{بے شک اللہ کے نزدیک مہینوں کی تعداد نوشتہ خداوندی میں جب سے اللہ نے آسمانوں اور زمین کو پیدا کیا ہے بارہ ہے، جن میں سے چار مہینے حرمت والے ہیں۔ یہی دینِ مستقیم ہے۔ پس ان میں اپنے اوپر ظلم نہ کرو اور تمام مشرکین سے اسی طرح جنگ کرو جس طرح کہ وہ تم سب سے کرتے ہیں اور جان لو کہ بے شک اللہ پرہیزگاروں کے ساتھ ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcclxxii{سوا اس کے نہیں ہے کہ نسیئی (حرمت والے مہینوں کو مؤخر کرنا) کفر میں زیادتی کا موجب ہے۔ اس سے وہ لوگ گمراہ کئے جاتے ہیں جو کافر ہیں۔ وہ اسے ایک سال حلال قرار دیتے ہیں اور اسی کو دوسرے سال حرام قرار دیتے ہیں تاکہ ان مہینوں کی گنتی پوری کریں جنہیں اللہ نے حرام کیا ہے تاکہ اس (حیلے) سے اللہ کی حرام کردہ کو اپنے لئے حلال قرار دیں۔ ان کے برے اعمال ان کے لئے آراستہ کر دیے گئے ہیں اور اللہ کافروں کو منزلِ مقصود تک نہیں پہنچاتا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcclxxiii{اے ایمان والو! تمہیں کیا ہوگیا ہے کہ جب تم سے کہا جاتا ہے کہ اللہ کی راہ میں (جہاد کرنے کے لیے) نکلو تو تم بوجھل ہوکر زمین گیر ہو جاتے ہو۔ کیا تم نے آخرت کے بدلے دنیا کی زندگی کو پسند کر لیا ہے؟ (اگر ایسا ہی ہے تو یاد رکھو کہ) دنیا کا ساز و سامان آخرت کے مقابلہ میں بالکل قلیل ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcclxxiv{اگر تم نہیں نکلوگے تو اللہ تمہیں دردناک عذاب کے ساتھ سزا دے گا اور تمہاری جگہ کسی دوسرے گروہ کو لاکھڑا کرے گا۔ اور تم اسے کچھ بھی نقصان نہیں پہنچا سکوگے۔ اور اللہ ہر چیز پر قادر ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcclxxv{اور اگر تم ان (رسول(ص)) کی نصرت نہیں کروگے (تو نہ کرو) اللہ نے ان کی اس وقت نصرت کی جب کافروں نے ان کو (وطن سے) نکال دیا تھا۔ اور آپ دو میں سے دوسرے تھے۔ جب دونوں غار میں تھے اس وقت وہ اپنے ساتھی سے کہہ رہے تھے کہ غمگین نہ ہو یقینا اللہ ہمارے ساتھ ہے۔ سو اللہ نے ان (رسول(ص)) پر اپنی تسکین نازل کی اور ان کی ایسے لشکروں سے مدد کی جن کو تم نے نہیں دیکھا۔ اور اللہ نے کافروں کے بول کو نیچا کر دیا اور اللہ کا بول ہی بالا ہے۔ اور اللہ زبردست ہے بڑا حکمت والا ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcclxxvi{(اے مسلمانو!) ہلکے پھلکے اور بھاری بوجھل نکل پڑو۔ اور اللہ کی راہ میں اپنے مال و جان کے ساتھ جہاد کرو۔ یہ بات تمہارے لئے بہتر ہے اگر تم علم رکھتے ہو۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcclxxvii{(اے رسول(ص)) اگر فائدہ قریب اور سفر آسان ہوتا تو یہ (منافق) ضرور تمہارے پیچھے چلتے لیکن انہیں راہ دور کی دکھائی دی (اس لئے قطعِ مسافت دشوار ہوگئی) وہ عنقریب اللہ کے نام کی قَسمیں کھا کھا کر کہیں گے کہ اگر ہم مقدور رکھتے تو ضرور آپ کے ساتھ نکلتے۔ یہ لوگ (جھوٹی قَسمیں کھا کر) اپنے کو ہلاکت میں ڈال رہے ہیں اور اللہ جانتا ہے کہ وہ قطعاً جھوٹے ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcclxxviii{(اے رسول(ص)) اللہ آپ کو معاف کرے آپ نے انہیں کیوں (پیچھے رہ جانے کی) اجازت دے دی۔ جب تک آپ پر واضح نہ ہو جاتا کہ سچے کون ہیں اور معلوم نہ ہو جاتا کہ جھوٹے کون؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcclxxix{جو لوگ اللہ اور آخرت کے دن پر ایمان رکھتے ہیں وہ کبھی آپ سے اجازت طلب نہیں کریں گے کہ وہ اپنے مال و جان سے (اللہ کی راہ میں) جہاد کریں۔ اور اللہ پرہیز گاروں کو خوب جانتا ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcclxxx{اس قسم کی اجازت وہی لوگ طلب کرتے ہیں جو اللہ اور آخرت کے دن پر ایمان نہیں رکھتے۔ اور ان کے دل شک میں پڑ گئے ہیں اور وہ اپنے شک میں بھٹک رہے ہیں۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcclxxxi{اگر ان لوگوں نے نکلنے کا ارادہ کیا ہوتا تو اس کے لئے کچھ نہ کچھ سروسامان کی تیاری ضرور کرتے لیکن (حقیقت الامر تو یہ ہے کہ) اللہ کو ان کا اٹھنا اور نکالنا ناپسند تھا۔ اس لئے اس نے ان کو کاہل (اور سست) کر دیا۔ اور (گویا ان سے) کہہ دیا گیا کہ بیٹھے رہو بیٹھنے والوں کے ساتھ۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcclxxxii{اگر وہ تمہارے ساتھ نکلتے تو تمہاری خرابی میں اضافہ ہی کرتے اور فتنہ پردازی کے لئے دوڑ دھوپ کرتے اور تمہارے اندر (ہنوز) ایسے لوگ (جاسوس) موجود ہیں جو ان کی باتوں پر کان دھرنے والے ہیں (جاسوسی کرتے ہیں)۔ اور اللہ ظالموں کو خوب جانتا ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiii{وہ لوگ اس سے پہلے بھی فتنہ پردازی میں کوشاں رہے ہیں اور آپ کے معاملات کو درہم برہم اور الٹ پلٹ کرتے رہے ہیں یہاں تک کہ حق (سامنے) آگیا (نمایاں ہوگیا) اور اللہ کا حکم غالب ہوا۔ جبکہ وہ ناپسند کرتے تھے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiv{اور ان میں کچھ ایسے بھی ہیں جو کہتے ہیں کہ مجھے (گھر میں بیٹھے رہنے کی) اجازت دے دیں۔ اور مجھے فتنہ میں نہ ڈالیں خبردار! وہ فتنہ میں تو خود پڑ ہی چکے ہیں اور بلاشبہ جہنم کافروں کو گھیرے ہوئے ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcclxxxv{اگر آپ کو کوئی بھلائی پہنچے تو ان کو بری لگتی ہے اور اگر آپ پر کوئی مصیبت آجائے تو کہتے ہیں کہ ہم نے تو پہلے ہی اپنا معاملہ ٹھیک کر لیا تھا۔ اور وہ (یہ کہہ کر) خوش خوش واپس لوٹ جاتے ہیں۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvi{(اے پیغمبر(ص)) کہہ دیجیے! کہ ہمیں ہرگز کوئی (بھلائی یا برائی) نہیں پہنچتی مگر وہی جو اللہ نے ہمارے لئے لکھ دی ہے وہی ہمارا مولیٰ و سرپرست ہے۔ اور اللہ ہی پر اہلِ ایمان کو توکل (بھروسہ) کرنا چاہیے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvii{اے پیغمبر(ص) کہہ دیجیے! کہ تم ہمارے بارے میں دو بھلائیوں (فتح یا شہادت) میں سے ایک کے سوا اور کس چیز کا انتظار کر رہے ہو؟ اور ہم تمہارے بارے میں اس بات کا انتظار کر رہے ہیں کہ اللہ تمہیں سزا دے۔ خواہ اپنی طرف سے دے یا ہمارے ہاتھوں سے؟ سو تم انتظار کرو۔ اور ہم بھی تمہارے ساتھ انتظار کر رہے ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcclxxxviii{کہہ دیجیے! کہ تم خوشی سے (اپنا مال) خرچ کرو یا ناخوشی سے۔ بہرحال وہ قبول نہیں کیا جائے گا۔ کیونکہ تم فاسق (نافرمان) لوگ ہو (انما یتقبل اللّٰہ من المتقین یعنی اللہ تو صرف متقیوں کا عمل قبول کرتا ہے)۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcclxxxix{اور ان کی خیرات کے قبول کئے جانے میں اس کے سوا اور کوئی امر مانع نہیں ہے کہ انہوں نے خدا و رسول کے ساتھ کفر کیا ہے (ان کا انکار کیا ہے) اور نماز کی طرف نہیں آتے مگر کاہلی اور سستی سے اور خیرات نہیں کرتے مگر بادلِ ناخواستہ۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxc{سو ان کے مال و اولاد تمہیں حیرت و تعجب میں نہ ڈالیں۔ (اللہ تو یہ چاہتا ہے کہ) ان کو یہ انہی چیزوں کے ذریعہ سے دنیاوی زندگی میں سزا دے۔ اور ان کی جانیں ایسی حالت میں نکلیں کہ وہ کافر ہوں۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxci{اور وہ اللہ کی قسمیں کھاتے ہیں کہ وہ تم ہی میں سے ہیں۔ حالانکہ وہ تم میں سے نہیں ہیں لیکن وہ (تم سے) خوف زدہ ہیں۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxcii{اگر وہ کوئی جائے پناہ پا لیں یا کوئی غار یا گھس بیٹھنے کی کوئی جگہ تو فوراً ادھر کا رخ کریں منہ زوری کرتے ہوئے (اور رسیاں تڑاتے ہوئے)۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxciii{اور (اے نبی) ان میں کچھ ایسے بھی ہیں جو صدقات (کی تقسیم) کے بارے میں آپ(ص) پر عیب لگاتے ہیں۔ پھر اگر اس سے کچھ (معقول مقدار) انہیں دے دی جائے تو راضی ہو جاتے ہیں اور اگر کچھ نہ دیا جائے تو وہ ایک دم ناراض ہو جاتے ہیں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxciv{اور (کیا اچھا ہوتا ہے) اگر وہ اس پر راضی رہتے جو کچھ اللہ اور اس کے رسول نے انہیں دیا تھا اور کہتے کہ اللہ ہمارے لئے کافی ہے۔ وہ عنقریب ہمیں اپنے فضل و کرم سے عطا فرمائے گا اور اس کا رسول بھی۔ ہم تو بس اللہ کی طرف ہی رغبت کرنے والے ہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxcv{صدقات (مالِ زکوٰۃ) تو اور کسی کے لئے نہیں صرف فقیروں کے لئے ہے مسکینوں کے لئے ہے اور ان کارکنوں کے لئے ہے جو اس کی وصولی کے لئے مقرر ہیں۔ اور ان کے لئے ہے جن کی (دلجوئی) مطلوب ہے۔ نیز (غلاموں اور کنیزوں کی) گردنیں (چھڑانے) کے لئے ہے اور مقروضوں (کا قرضہ ادا کرنے) کے لئے ہے اور اللہ کی راہ میں خرچ کرنے کے لئے ہے اور مسافروں (کی مدد) کے لئے ہے یہ اللہ کی طرف سے فرض ہے اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxcvi{اور ان میں کچھ ایسے بھی ہیں جو نبی کو اذیت پہنچاتے ہیں اور کہتے ہیں کہ وہ تو بس کان ہیں (یعنی کان کے کچے ہیں) کہہ دیجیے! وہ تمہارے لئے بہتری کا کان ہیں (ان کے ایسا ہونے میں تمہارا ہی بھلا ہے) جو اللہ پر ایمان رکھتے ہیں اور اہلِ ایمان پر اعتماد کرتے ہیں اور جو تم میں سے ایمان لائے ہیں ان کے لئے سراپا رحمت ہیں اور جو لوگ اللہ کے رسول کو اذیت پہنچاتے ہیں۔ ان کے لئے دردناک عذاب ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxcvii{وہ تمہارے سامنے اللہ کی قَسمیں کھاتے ہیں تاکہ تمہیں راضی کریں۔ حالانکہ اللہ اور اس کا رسول اس کے زیادہ حقدار ہیں کہ ان کو راضی کریں۔ اگر وہ ایمان لائے ہیں۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxcviii{کیا انہیں (یہ بات) معلوم نہیں ہے کہ جو شخص خدا و رسول کی مخالفت کرے گا۔ اس کے لئے آتشِ دوزخ ہے جس میں وہ ہمیشہ رہے گا۔ یہ بہت بڑی رسوائی ہے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxcix{منافق لوگ ڈرتے رہتے ہیں کہ مبادا ان کے بارے میں کوئی ایسی سورہ نہ نازل ہو جائے جو انہیں بتلا دے جو کچھ ان کے دلوں میں (چھپا ہوا) ہے آپ کہہ دیجیے! کہ تم مذاق اڑاؤ۔ یقینا (اب) اللہ اس بات کا ظاہر کرنے والا ہے جس کے شکار ہونے سے تم ڈرتے ہو۔ (تمہارے نفاق کا پردہ چاک ہونے والا ہے)۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccc{(اے رسول(ص)) اگر آپ ان سے پوچھ گچھ کریں تو وہ ضرور کہیں گے کہ ہم تو صرف بحث کر رہے تھے اور تفریح طبعی کر رہے تھے۔ کیا تم اللہ، اس کے رسول اور اس کی آیات سے تمسخر کرتے ہو؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccci{اب عذر نہ تراشو! تم نے (اظہارِ) ایمان کے بعد کفر اختیار کیا ہے۔ اگر ہم تم میں سے ایک گروہ سے درگزر بھی کریں گے تو دوسرے گروہ کو تو ضرور سزا دیں گے کیونکہ وہ (حقیقی) مجرم ہیں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcccii{منافق مرد اور منافق عورتیں ایک دوسرے کے ہم جنس ہیں برائی کا حکم دیتے ہیں اور اچھائی سے روکتے ہیں اور (راہِ حق پر خرچ کرنے سے) اپنے ہاتھ بند رکھتے ہیں (دراصل) انہوں نے خدا کو بھلا دیا ہے اور خدا نے (گویا) ان کو بھلا دیا ہے اور انہیں (نظر انداز کر دیا ہے) بے شک منافق ہی بڑے فاسق (نافرمان) ہیں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccciii{اللہ نے منافق مردوں منافق عورتوں اور کافروں سے آتشِ دوزخ (میں داخل کرنے) کا وعدہ کر رکھا ہے جس میں وہ ہمیشہ رہیں گے وہ ان کے لئے کافی ہے اور اللہ نے ان پر لعنت کی ہے اور ان کے لئے دائمی عذاب ہے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccciv{(اے منافقو! تمہاری حالت) ان لوگوں جیسی ہے جو تم سے پہلے گزر چکے۔ جو تم سے زیادہ طاقتور تھے اور مال و اولاد بھی تم سے زیادہ رکھتے تھے پس انہوں نے اپنے (دنیوی) حصہ سے فائدہ اٹھایا اور تم نے بھی اپنے (دنیوی) حصہ سے اسی طرح فائدہ اٹھایا جس طرح تم سے پہلے گزرے ہوؤں نے فائدہ اٹھایا تھا۔ اور تم بھی ویسے ہی لغو بحثوں میں پڑے جیسے وہ پڑے تھے۔ یہی وہ لوگ ہیں جن کے اعمال دنیا و آخرت میں اکارت ہوئے اور یہی لوگ ہیں جو گھاٹا اٹھانے والے ہیں۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcccv{کیا انہیں ان لوگوں کی خبر نہیں ملی جو ان سے پہلے گزر چکے ہیں (جیسے) نوح کی قوم، اور عاد و ثمود اور ابراہیم کی قوم! اور مدین والے اور وہ جن کی بستیاں الٹ دی گئی تھیں (قومِ لوط) ان کے پاس ان کے پیغمبر کھلی ہوئی نشانیاں (معجزات) لے کر آئے تھے۔ (مگر وہ اپنی گمراہی سے باز نہ آئے)۔ اللہ تو ایسا نہ تھا کہ ان پر ظلم کرتا مگر وہ خود ہی اپنے اوپر ظلم کرتے تھے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcccvi{اور مؤمن مرد اور مؤمن عورتیں یہ سب باہم دگریکرنگ و ہم آہنگ ہیں وہ بھلائی کا حکم دیتے ہیں اور برائی سے روکتے ہیں اور نماز قائم کرتے ہیں۔ اور زکوٰۃ ادا کرتے ہیں۔ اور اللہ اور اس کے رسول کی اطاعت کرتے ہیں۔ یہی وہ لوگ ہیں جن پر اللہ ضرور رحم فرمائے گا۔ یقینا اللہ زبردست ہے، بڑا حکمت والا ہے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcccvii{اللہ نے مؤمن مردوں اور مؤمن عورتوں سے ان بہشتوں کا وعدہ کیا ہے جن کے نیچے نہریں بہہ رہی ہوں گی وہ ان میں ہمیشہ رہیں گے نیز ان کے لئے ان ہمیشگی کے بہشتوں (سدا بہار باغوں) میں پاک و پاکیزہ مکانات ہوں گے۔ اور اللہ کی خوشنودی سب سے بڑی ہے۔ یہی ہے بہت بڑی کامیابی۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcccviii{اے نبی! کافروں اور منافقوں سے جہاد کریں۔ اور ان پر سختی کریں۔ ان کا ٹھکانا جہنم ہے اور وہ بہت بری جائے بازگشت ہے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcccix{وہ تمہارے سامنے اللہ کی قَسمیں کھاتے ہیں کہ انہوں نے (وہ بات) نہیں کہی۔ حالانکہ انہوں نے یقینا کفر کا کلمہ کہا ہے۔ اور اسلام لانے کے بعد کفر اختیار کیا ہے اور انہوں نے وہ کام کرنے کا قصد کیا ہے جسے وہ کر نہ سکے ان کی یہ سب خشمناکی اور عیب جوئی صرف اس وجہ سے ہے کہ خدا و رسول نے (مالِ غنیمت دے کر) ان کو تونگر کر دیا ہے۔ سو اگر وہ اب بھی توبہ کر لیں تو یہ ان کے لئے بہتر ہے اور اگر وہ روگردانی کریں تو اللہ انہیں دنیا و آخرت میں دردناک عذاب دے گا۔ اور تمام روئے زمین پر ان کا کوئی حامی اور یار و مددگار نہ ہوگا۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcccx{اور ان میں سے کچھ ایسے بھی ہیں جنہوں نے اللہ سے عہد کیا تھا کہ اگر اس نے ہمیں اپنے فضل سے (کچھ مال و دولت) سے نوازا تو ہم ضرور خیرات کریں گے اور ضرور نیکوکار بندوں میں سے ہو جائیں گے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcccxi{پھر جب اللہ نے انہیں اپنے فضل و کرم سے نوازا تو وہ اس میں بخل کرنے لگے اور روگردانی کرتے ہوئے (اپنے عہد سے) پھر گئے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcccxii{پس (اس روش کا نتیجہ یہ نکلا کہ) خدا نے ان کی وعدہ خلافی کرنے اور جھوٹ بولنے کی وجہ سے یومِ لقا (قیامت) تک ان کے دلوں میں نفاق قائم کر دیا۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcccxiii{کیا یہ لوگ نہیں جانتے کہ اللہ ان کے دلی راز اور ان کی سرگوشی کو جانتا ہے اور وہ غیب کی تمام باتوں کو بڑا جاننے والا ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcccxiv{یہ ایسے ہیں کہ خوش دلی سے خیرات کرنے والے مؤمنین پر ریاکاری کا عیب لگاتے ہیں۔ اور جو اپنی محنت مزدوری کے سوا اور کچھ نہیں رکھتے (اس لئے راہِ خدا میں تھوڑا مال دیتے ہیں) یہ ان کا مذاق اڑاتے ہیں اللہ ان کا مذاق اڑائے گا۔ (اس کی سزا دے گا) اور ان کے لئے دردناک عذاب ہے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcccxv{(اے رسول(ص)) آپ ان کے لئے مغفرت طلب کریں اور خواہ نہ کریں اگر (بالفرض) آپ ان کے لئے ستر بار بھی مغفرت طلب کریں جب بھی اللہ انہیں ہرگز نہیں بخشے گا۔ یہ اس لئے ہے کہ انہوں نے اللہ اور رسول کے ساتھ کفر کیا۔ اور خدا فاسق (نافرمان) لوگوں کو منزلِ مقصود تک نہیں پہنچاتا۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcccxvi{جو (منافق جنگ تبوک میں) پیچھے چھوڑ دیے گئے وہ رسولِ خدا(ص) کے پیچھے (ان کی خواہش کے خلاف) اپنے گھروں میں بیٹھے رہنے پر خوش ہوئے اور خدا کی راہ میں اپنے مال و جان سے جہاد کرنے کو ناپسند کیا۔ اور (دوسروں سے بھی) کہا کہ گرمی میں سفر نہ کرو۔ کہہ دیجیے! کہ دوزخ کی آگ (اس سے) زیادہ گرم ہے کاش وہ یہ بات سمجھتے۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcccxvii{ان (برے) کاموں کے بدلہ میں جو یہ لوگ کرتے ہیں انہیں چاہیے کہ اب وہ ہنسیں کم اور روئیں زیادہ۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcccxviii{(اے نبی(ص)) اگر اللہ آپ کو واپس لائے ان کے کسی گروہ کی طرف۔ اور وہ آپ سے جہاد کے لیے نکلنے کی اجازت مانگے تو کہہ دیجیے کہ اب تم میرے ساتھ کبھی نہیں نکل سکتے۔ اور میرے ہمراہ ہو کر کبھی دشمن سے جنگ نہیں کر سکتے تم نے پہلی بار (گھر میں) بیٹھ رہنا پسند کیا۔ تو اب بھی بیٹھے رہو پیچھے رہ جانے والوں (بچوں اور عورتوں) کے ساتھ۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcccxix{اور ان میں سے جو کوئی مر جائے تو اس کی نمازِ جنازہ نہ پڑھیں اور نہ ہی اس کی قبر پر کھڑے ہوں۔ بلاشبہ انہوں نے خدا و رسول کے ساتھ کفر کیا اور وہ فسق و نافرمانی کی حالت میں مرے ہیں۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcccxx{اور ان کے مال و اولاد آپ کو حیرت و تعجب میں نہ ڈالیں خدا چاہتا ہے کہ انہی چیزوں کے ذریعہ سے انہیں سزا دے اور ان کی جانیں اس حال میں نکلیں کہ وہ کافر ہوں جب کوئی اس قسم کی سورت نازل ہوتی ہے کہ اللہ پر ایمان لاؤ اور اس کے رسول کے ہمراہ ہو کر جہاد کرو۔ تو ان میں سے جو مقدور والے ہیں وہ آپ سے رخصت مانگتے ہیں۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcccxxi{اور کہتے ہیں کہ ہمیں چھوڑ دیں تاکہ ہم گھر میں بیٹھ رہنے والوں کے ساتھ بیٹھے رہیں۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcccxxii{ان لوگوں نے یہ بات پسند کی کہ گھر میں پیچھے رہ جانے والی عورتوں کے ساتھ رہیں اور (ان کے نفاق و کفر کی وجہ سے) ان کے دلوں پر مہر لگ گئی ہے۔ بس یہ کچھ سمجھتے ہی نہیں ہیں۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcccxxiii{لیکن اللہ کے رسول اور جو ان کے ساتھ ایمان لائے ہیں انہوں نے اپنے مال اور اپنی جان کے ساتھ جہاد کیا اور یہی وہ ہیں جن کے لئے ساری بھلائیاں ہیں۔ اور یہی کامیاب ہونے والے ہیں۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcccxxiv{اللہ نے ان کے لئے ایسے بہشت (باغات) تیار کر رکھے ہیں جن کے نیچے نہریں بہتی ہیں جن میں وہ ہمیشہ رہیں گے اور یہ بہت بڑی کامیابی ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcccxxv{اور صحرائی بَدوؤں میں عذر کرنے والے (آپ کے پاس) آئے کہ انہیں پیچھے رہ جانے کی اجازت دے دی جائے۔ اور جنہوں نے (اسلام کا اظہار کرکے) خدا و رسول سے جھوٹ بولا تھا وہ (بلا اجازت) گھروں میں بیٹھے رہے۔ ان میں سے جنہوں نے کفر اختیار کیا ہے انہیں عنقریب دردناک عذاب پہنچے گا۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcccxxvi{کمزوروں، بیماروں پر اور ان ناداروں پر خرچ کرنے کے لیے کچھ نہیں رکھتے کوئی گناہ نہیں ہے (اگر جہاد میں شریک نہ ہوں) بشرطیکہ وہ خلوصِ دل سے اللہ اور رسول کے وفادار ہوں۔ نیکوکاروں پر کوئی الزام نہیں ہے اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcccxxvii{اور نہ ہی ان لوگوں پر کوئی گناہ ہے جو آپ کے پاس آتے ہیں کہ آپ ان کے لئے سواری کا کوئی انتظام کریں۔ اور آپ نے کہا کہ میرے پاس سواری کے لئے کچھ نہیں ہے۔ تو وہ اس حال میں مجبوراً واپس گئے کہ ان کی آنکھوں سے آنسو جاری تھے اس رنج میں کہ ان کے پاس (راہِ خدا میں) خرچ کرنے کے لیے کچھ میسر نہیں ہے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcccxxviii{ہاں البتہ الزام (اور اعتراض) ان لوگوں پر ہے کہ باوجود دولت مند ہونے کے آپ سے (بیٹھے رہنے کی) اجازت مانگتے ہیں انہوں نے اس بات کو پسند کیا کہ وہ پیچھے رہ جانے والوں کے ساتھ رہیں اور اللہ نے ان کے دلوں پر مہر لگا دی ہے اس لئے وہ کچھ جانتے بوجھتے نہیں ہیں۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcccxxix{جب تم لوگ (جہاد سے) لوٹ کر ان کے پاس جاؤگے۔ تو وہ (منافقین) طرح طرح کے عذر پیش کریں گے۔ (اے رسول(ص)) تم کہہ دو بہانے نہ بناؤ۔ ہم ہرگز تمہاری کسی بات پر اعتبار نہیں کریں گے۔ (کیونکہ) اللہ تعالیٰ نے ہمیں تمہارے حالات بتا دیئے ہیں۔ اب آئندہ اللہ تمہارا طرزِ عمل دیکھے گا اور اس کا رسول بھی پھر تم غائب اور حاضر کے جاننے والے (خدا) کی طرف لوٹائے جاؤگے وہ تمہیں بتلائے گا جو کچھ تم (دنیا میں) کرتے رہے ہو۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcccxxx{جب تم ان کے پاس لوٹ جاؤگے تو وہ ضرور تمہارے سامنے اللہ کی قَسمیں کھائیں گے۔ تاکہ تم ان سے درگزر کرو۔ سو تم ان سے رخ پھیر ہی لو۔ یہ ناپاک ہیں اور ان کا ٹھکانہ جہنم ہے یہ ان کے کئے کی سزا ہے۔ جو وہ کرتے رہے ہیں۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcccxxxi{یہ لوگ تمہارے سامنے قَسمیں کھائیں گے تاکہ تم ان سے راضی ہو جاؤ۔ سو تم اگر ان سے راضی بھی ہو جاؤ تو اللہ تو کبھی فاسق (نافرمان) قوم سے راضی ہونے والا نہیں ہے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcccxxxii{صحرائی عرب کفر و نفاق میں سب سے زیادہ سخت ہیں اور اسی قابل ہیں کہ ان احکام کے حدود و قیود کو نہ سمجھیں جو خدا نے اپنے رسول(ص) پر نازل کئے ہیں اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiii{صحرائی عربوں میں سے کچھ ایسے لوگ ہیں کہ (راہ خدا میں) جو کچھ خرچ کرتے ہیں اسے جرمانہ سمجھتے ہیں اور تمہارے بارے میں زمانہ کی گردشوں کے منتظر ہیں۔ (کہ تم پر کوئی گردش آجائے اور وہ اسلام سے گلو خلاصی کرائیں) حالانکہ بڑی گردش انہی (منافقین) کے لیے ہے۔ خدا سب کچھ جاننے والا ہے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiv{اور انہی بدوؤں میں کچھ ایسے لوگ بھی ہیں جو اللہ اور روزِ آخرت پر ایمان رکھتے ہیں اور جو کچھ (راہِ خدا میں) خرچ کرتے ہیں۔ اسے اللہ کے تقرب اور رسول کی دعاؤں کا وسیلہ سمجھتے ہیں۔ بے شک وہ (خرچ کرنا) ان کے لیے تقرب کا ذریعہ ہے۔ اللہ ضرور ان کو اپنی رحمت میں داخل کرے گا۔ بے شک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcccxxxv{اور مہاجرین اور انصار میں سے جو ایمان لانے میں سبقت کرنے والے ہیں اور جن لوگوں نے حسنِ عمل میں ان کی پیروی کی اللہ ان سے راضی ہے۔ اور وہ اللہ سے راضی ہیں۔ اور اس نے ان کے لیے ایسے بہشت مہیا کر رکھے ہیں جن کے نیچے نہریں بہہ رہی ہیں۔ اور وہ ان میں ہمیشہ رہیں گے۔ یہ بہت بڑی کامیابی ہے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvi{اور جو تمہارے اردگرد صحرائی عرب بستے ہیں ان میں کچھ منافق ہیں۔ اور خود مدینہ کے باشندوں میں بھی (منافق موجود ہیں) جو نفاق پر اڑ گئے ہیں (اس میں مشاق ہوگئے ہیں) (اے رسول(ص)) آپ انہیں نہیں جانتے لیکن ہم جانتے ہیں۔ ہم ان کو (دنیا میں) دوہری سزا دیں گے۔ پھر وہ بہت بڑے عذاب کی طرف لوٹائے جائیں گے۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvii{دوسرے کچھ ایسے لوگ بھی ہیں جنہوں نے اپنے گناہوں کا اعتراف کیا ہے (مگر) انہوں نے نیک اور بدعمل خلط ملط کر دیے ہیں بہت ممکن ہے کہ اللہ ان کی توبہ قبول کرے۔ (اور ان پر رحمت کی نظر ڈالے) بے شک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcccxxxviii{اے رسول! ان لوگوں کے مال سے صدقہ (زکوٰۃ) لیں اور اس کے ذریعہ سے انہیں پاک و پاکیزہ کریں۔ اور (برکت دے کر) انہیں بڑھائیں نیز ان کے لیے دعائے خیر کریں کیونکہ آپ کی دعا ان کے لیے تسکین کا باعث ہے اور خدا بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcccxxxix{کیا انہیں معلوم نہیں ہے کہ اللہ ہی ہے جو اپنے بندوں کی توبہ قبول کرتا ہے اور وہی صدقات کو قبول کرتا ہے یقینا اللہ ہی توبہ کا بڑا قبول کرنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcccxl{(اے رسول(ص)) ان لوگوں سے کہہ دو کہ تم عمل کیے جاؤ اللہ، اس کا رسول اور مؤمنین تمہارے عمل کو دیکھیں گے (کہ تم کیسے عمل کرتے ہو) اور پھر غائب اور حاضر کے جاننے والے (خدا) کی طرف لوٹائے جاؤگے بس وہ تمہیں بتلائے گا تم کیا عمل کرتے ہو۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcccxli{اور کچھ اور لوگ ایسے بھی ہیں جن کا معاملہ خدا کے حکم پر موقوف ہے وہ انہیں سزا دے یا ان کی توبہ کرے اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcccxlii{اور (منافقین میں سے) وہ لوگ بھی ہیں۔ جنہوں نے اس غرض سے ایک مسجد بنائی کہ نقصان پہنچائیں، کفر کریں اور مؤمنین میں تفرقہ ڈالیں۔ اور ان لوگوں کے لیے کمین گاہ بنائیں جو اس سے پہلے خدا و رسول سے جنگ کر چکے ہیں وہ ضرور قَسمیں کھائیں گے کہ بھلائی کے سوا ہمارا کوئی مقصد نہیں ہے اور اللہ گواہی دیتا ہے کہ یہ جھوٹے ہیں۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcccxliii{(اے رسول(ص)) تم ہرگز اس عمارت میں کھڑے نہ ہونا۔ بے شک وہ مسجد جس کی اول دن سے تقویٰ و پرہیزگاری پر بنیاد رکھی گئی ہے۔ اس کی زیادہ مستحق ہے کہ آپ اس میں کھڑے ہوں (مسجد قبا و مسجد نبوی) اس میں ایسے لوگ ہیں جو پاک و صاف رہنا پسند کرتے ہیں اور اللہ پاک و صاف رہنے والوں کو ہی پسند کرتا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcccxliv{آیا وہ شخص بہتر ہے جو اپنی عمارت کی بنیاد خوفِ خدا اور اس کی خوشنودی پر رکھے یا وہ جس نے اپنی عمارت کی بنیاد ایک کھائی کے گرتے ہوئے کنارے پر رکھی اور پھر وہ اسے لے کر دوزخ کی آگ میں جاگری اور اللہ ظالموں کو منزلِ مقصود تک نہیں پہنچاتا۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcccxlv{یہ عمارت جو ان لوگوں نے بنائی ہے (مسجدِ ضرار) یہ ہمیشہ ان کے دلوں کو مضطرب رکھے گی مگر یہ کہ ان کے دل ٹکڑے ٹکڑے ہو جائیں بلاشبہ خدا بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mcccxlvi{بے شک اللہ تعالیٰ نے مؤمنین سے ان کی جانیں خرید لی ہیں اور ان کے مال بھی اس قیمت پر کہ ان کے لیے بہشت ہے وہ اللہ کی راہ میں جنگ کرتے ہیں پس وہ مارتے بھی ہیں اور خود بھی مارے جاتے ہیں (ان سے) یہ وعدہ اس (اللہ تعالیٰ) کے ذمہ ہے تورات، انجیل اور قرآن (سب) میں اور اللہ سے بڑھ کر کون اپنے وعدہ کا پورا کرنے والا ہے؟ پس اے مسلمانو! تم اس سودے پر جو تم نے خدا سے کیا ہے خوشیاں مناؤ۔ یہی تو بڑی کامیابی ہے۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mcccxlvii{(ان لوگوں کے اوصاف یہ ہیں کہ) یہ توبہ کرنے والے (اللہ کی عبادت کرنے والے (اس کی) حمد و ثنا کرنے والے (اس کی راہ میں) سیر و سیاحت کرنے والے (یا روزہ رکھنے والے) رکوع و سجود کرنے والے، نیکی کا حکم دینے والے، برائی سے روکنے والے اور اللہ کی مقررہ حدود کی حفاظت کرنے والے ہیں اور (اے رسول) مؤمنوں کو خوشخبری دے دو (اور یہی وہ مؤمن ہیں)۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mcccxlviii{نبی کو اور ان لوگوں کو جو ایمان لائے ہیں یہ زیبا نہیں ہے کہ مشرکین کے لیے مغفرت طلب کریں اگرچہ وہ ان کے عزیز و اقارب ہی کیوں نہ ہوں۔ جبکہ ان پر واضح ہوگیا کہ وہ دوزخی ہیں۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mcccxlix{اور ابراہیم نے جو اپنے باپ (تایا) کے لیے دعائے مغفرت کی تھی تو وہ ایک وعدہ کی بنا پر تھی جو وہ کر چکے تھے۔ مگر جب ان پر واضح ہوگیا کہ وہ اللہ کا دشمن ہے تو آپ اس سے بیزار ہوگئے بے شک جناب ابراہیم بڑے ہی دردمند اور غمخوار و بردبار انسان تھے۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mcccl{اور اللہ کسی قوم کو ہدایت دینے کے بعد اس وقت تک گمراہ نہیں قرار دیتا جب تک ان پر یہ واضح نہ کر دے کہ انہیں کن چیزوں سے پرہیز کرنا ہے۔ بیشک اللہ ہر شے کا جاننے والا ہے۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mcccli{اللہ ہی کے لئے زمین و آسمان کی حکومت ہے اور وہی حیات و موت کا دینے والا ہے اس کے علاوہ تمہارا نہ کوئی سرپرست ہے نہ مددگار۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mccclii{بیشک خدا نے پیغمبر اور ان مہاجرین و انصار پر رحم کیا ہے جنہوں نے تنگی کے وقت میں پیغمبر کا ساتھ دیا ہے جب کہ ایک جماعت کے دلوں میں کجی پیدا ہو رہی تھی پھر خدا نے ان کی توبہ کو قبول کر لیا کہ وہ ان پر بڑا ترس کھانے والا اور مہربانی کرنے والا ہے۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mcccliii{اور اللہ نے ان تینوں پر بھی رحم کیا جو جہاد سے پیچھے رہ گئے تھے یہاں تک کہ زمین جب اپنی وسعتوں سمیت ان پر تنگ ہوگئی اور ان کے دم پر بن گئی اور انہوں نے یہ سمجھ لیا کہ اب اللہ کے علاوہ کوئی پناہ گاہ نہیں ہے تو اللہ نے ان کی طرف توجہ فرمائی کہ وہ توبہ کر لیں اس لئے کہ وہ بڑا توبہ قبول کرنے والا اور مہربان ہے۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mcccliv{اے ایمان والو! اللہ سے ڈرو اور سچوں کے ساتھ ہو جاؤ۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mccclv{مدینہ کے باشندوں اور صحرائی عربوں کے لیے یہ درست نہیں ہے کہ پیغمبر خدا کا ساتھ چھوڑ کر پیچھے بیٹھیں۔ اور ان کی جان کی پرواہ نہ کرکے اپنی جانوں کی فکر میں لگ جائیں یہ اس لیے ہے کہ ان (مجاہدین) کو راہ خدا میں (جو بھی مصیبت پیش آتی ہے۔ وہ خواہ) پیاس ہو، جسمانی زحمت و مشقت ہو، بھوک ہو۔ یا کسی ایسے راستہ پر چلنا جو کافروں کے غم و غصہ کا باعث ہو یا دشمن کے مقابلہ میں کوئی کامیابی حاصل کرنا مگر یہ کہ ان تمام تکلیفوں کے عوض ان کے لیے ان کے نامۂ اعمال میں نیک عمل لکھا جاتا ہے یقینا اللہ نیکوکاروں کا اجر و ثواب ضائع نہیں کرتا۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mccclvi{اسی طرح وہ راہِ خدا میں کوئی تھوڑا یا بہت مال خرچ نہیں کرتے اور نہ کوئی وادی (میدان) طئے کرتے ہیں مگر یہ کہ ان کے لئے لکھ لیا جاتا ہے تاکہ خدا ان کی کار گزاریوں کا اچھے سے اچھا بدلہ دے۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mccclvii{اور یہ تو نہیں ہو سکتا کہ تمام اہلِ ایمان نکل کھڑے ہوں تو ایسا کیوں نہیں ہو سکتا۔ کہ ہر جماعت میں سے کچھ لوگ نکل آئیں تاکہ وہ دین میں تفقہ (دین کی سمجھ بوجھ) حاصل کریں اور جب (تعلیم و تربیت کے بعد) اپنی قوم کے پاس لوٹ کر آئیں۔ تو اسے (جہالت بے ایمانی اور بد عملی کے نتائج سے) ڈرائیں تاکہ وہ ڈریں۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mccclviii{اے ایمان والو! ان کافروں سے جنگ کرو جو تمہارے آس پاس ہیں اور چاہیے کہ وہ جنگ میں تمہارے اندر سختی محسوس کریں۔ اور جان لو کہ اللہ پرہیزگاروں کے ساتھ ہے۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mccclix{اور جب کوئی سورہ نازل ہوتی ہے تو ان (منافقوں) میں سے کچھ لوگ ایسے ہیں جو (طنزیہ طور پر کہتے ہیں) کہ اس نے تم لوگوں میں سے کس کا ایمان زیادہ کیا ہے؟ (اس کا جواب یہ ہے) کہ جو لوگ ایمان والے ہیں اس نے ان کا ایمان تو زیادہ کر دیا ہے اور وہ خوش ہو رہے ہیں۔\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mccclx{اور جن لوگوں کے دلوں میں (نفاق کی) بیماری ہے تو یہ سورہ ان کی موجودہ نجاست و خباثت میں اور اضافہ کر دیتی ہے اور وہ کفر کی حالت میں مر جاتے ہیں۔\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mccclxi{کیا (یہ لوگ) نہیں دیکھتے کہ وہ ہر سال ایک یا دو مرتبہ آزمائش میں ڈالے جاتے ہیں۔ پھر بھی یہ نہ توبہ کرتے ہیں اور نہ نصیحت حاصل کرتے ہیں۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mccclxii{اور جب کوئی سورہ نازل ہوتی ہے( جس میں منافقوں کا تذکرہ ہوتا ہے) تو وہ ایک دوسرے کی طرف دیکھنے لگتے ہیں اور (آنکھوں کے اشارہ سے) کہتے ہیں تمہیں کوئی دیکھ تو نہیں رہا؟ (پھر چپکے سے) پلٹ جاتے ہیں دراصل اللہ نے ان کے دلوں کو پھیر دیا ہے کیونکہ یہ بالکل ناسمجھ لوگ ہیں۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mccclxiii{(اے لوگو!) تمہارے پاس (اللہ کا) ایک ایسا رسول آگیا ہے جو تم ہی میں سے ہے جس پر تمہارا زحمت میں پڑنا شاق ہے تمہاری بھلائی کا حریص ہے اور ایمان والوں کے ساتھ بڑی شفقت اور مہربانی کرنے والا ہے۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mccclxiv{(اے رسول(ص)) اگر اس پر بھی یہ لوگ روگردانی کرتے ہیں تو کہہ دیجیے کہ میرے لیے اللہ کافی ہے اس کے سوا کوئی الٰہ نہیں ہے۔ اسی پر میرا بھروسہ ہے اور وہی عرشِ عظیم کا مالک ہے۔\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mccclxv{\basmalahur الف، لام، را۔ یہ حکمت والی کتاب کی آیتیں ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccclxvi{کیا یہ بات لوگوں کے لئے تعجب کا باعث ہے کہ ہم نے خود انہی میں سے ایک آدمی پر وحی بھیجی کہ (بے ایمان اور بدکردار لوگوں کو) ڈراؤ۔ اور ایمان لانے والوں کو خوشخبری دے دو۔ کہ ان کے لیے ان کے پروردگار کے ہاں اچھا مقام و مرتبہ ہے (لیکن) کافروں نے کہا کہ یہ شخص تو کھلا جادوگر ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccclxvii{بے شک تمہارا پروردگار اللہ ہے۔ جس نے آسمانوں اور زمینوں کو چھ دنوں میں پیدا کیا ہے۔ پھر عرش پر غالب ہوا وہی (کائنات کے) ہر کام کی تدبیر اور اس کا بندوبست کرتا ہے اس کی بارگاہ میں کوئی سفارشی نہیں ہو سکتا مگر اس کی اجازت کے بعد۔ یہ ہے اللہ تمہارا پروردگار پس اسی کی عبادت کرو کیا تم غور و فکر نہیں کرتے (اور نصیحت قبول نہیں کرتے)۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccclxviii{تم سب نے اسی کی طرف لوٹ کر جانا ہے یہ اللہ کا سچا وعدہ ہے بے شک وہی مخلوق کی پیدائش کی ابتداء کرتا ہے پھر وہی دوبارہ اسے زندہ کرے گا تاکہ جو لوگ ایمان لائیں اور نیک عمل کریں انہیں انصاف کے ساتھ جزا دے اور جنہوں نے کفر کیا انہیں ان کے کفر کی پاداش میں کھولتا ہوا پانی پینے کو ملے گا اور ان کے لئے دردناک عذاب ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccclxix{وہ وہی ہے جس نے سورج کو چمکدار اور چاند کو نور (روشن) بنایا اور پھر چاند کے لئے مختلف منزلیں قرار دیں تاکہ تم برسوں کی گنتی اور دوسرے حساب معلوم کر سکو اللہ نے یہ سب کچھ حق و حکمت کے ساتھ پیدا کیا ہے وہ ان لوگوں کے لیے جو سمجھنا اور جاننا چاہیں اپنی آیتیں کھول کھول کر بیان کرتا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccclxx{بے شک رات اور دن کی ادل بدل اور الٹ پھیر میں اور ان چیزوں میں جو خدا نے آسمانوں اور زمین میں پیدا کی ہیں پرہیزگاروں کے لیے (خدا کی قدرت و حکمت کی) نشانیاں ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccclxxi{بے شک جو لوگ (مرنے کے بعد) ہماری بارگاہ میں حاضری کی امید نہیں رکھتے اور صرف دنیوی زندگی میں مگن ہیں اور اس پر مطمئن ہیں اور جو لوگ ہماری آیتوں سے غافل ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccclxxii{یہ وہ ہیں جن کا ٹھکانا دوزخ ہے ان کرتوتوں کی پاداش میں جو وہ دنیا میں کرتے رہے ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccclxxiii{بے شک جو لوگ ایمان لائے اور نیک عمل کئے۔ ان کا پروردگار ان کے ایمان کی بدولت انہیں اس منزل مقصود تک پہنچائے گا۔ یعنی وہ نعمتِ الٰہی کے ان باغوں میں ہوں گے جن کے نیچے نہریں بہہ رہی ہوں گی۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccclxxiv{وہاں ان کی دعا و صدا یہ ہوگی۔ اے اللہ! پاک ہے تیری ذات اور ان کی صاحب سلامت سلام سے ہوگی اور ان کی آخری دعا و پکار یہ ہوگی کہ ہر قسم کی تعریف اللہ کے لئے ہے جو سب جہانوں کا پروردگار ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccclxxv{اگر خدا لوگوں کو نقصان پہنچانے میں اس طرح جلدی کرتا جس طرح یہ لوگ اپنی بھلائی کے لئے جلدی کرتے ہیں یعنی اگر ہر برائی کا برا نتیجہ فوراً سامنے آجاتا تو ان کی مدت (عمر) کبھی کی پوری ہو چکی ہوتی مگر ہمارے قانون (سزا میں ڈھیل ہے) اس لئے ہم تو ان لوگوں کو بھی اپنی سرکشیوں میں بھٹکنے کے لئے چھوڑ دیتے ہیں جو مرنے کے بعد ہماری بارگاہ میں حضوری کی امید نہیں رکھتے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccclxxvi{جب انسان کو کوئی تکلیف پہنچتی ہے تو وہ کروٹ کے بل لیٹے یا بیٹھے یا کھڑے ہوئے (ہر حال میں) ہمیں پکارتا ہے اور جب ہم اس کی تکلیف دور کر دیتے ہیں تو وہ اس طرح (منہ موڑ کے) چل دیتا ہے جیسے اس نے کسی تکلیف میں جو اسے پہنچی تھی کبھی ہمیں پکارا ہی نہ تھا اسی طرح حد سے گزرنے والوں کے لیے ان کے وہ عمل خوشنما بنا دیئے گئے ہیں جو وہ کرتے رہے ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccclxxvii{اور بالیقین ہم تم سے پہلے (بہت سی) نسلوں کو ہلاک کر چکے ہیں جب انہوں نے ظلم کی راہ و روش اختیار کی۔ اور ان کے رسول ان کے پاس کھلی نشانیاں (معجزے) لے آئے مگر وہ ایسے تھے ہی نہیں کہ ایمان لاتے ہم اسی طرح مجرم لوگوں کو سزا دیتے ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccclxxviii{پھر ہم نے ان (نسلوں) کے بعد تمہیں روئے زمین پر ان کا جانشین بنایا تاکہ ہم دیکھیں کہ تم کیسے کام کرتے ہو؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccclxxix{اور جب انہیں ہماری آیاتِ بینات (واضح آیتیں) پڑھ کر سنائی جاتی ہیں تو جو لوگ مرنے کے بعد ہماری بارگاہ میں حاضری کی توقع نہیں رکھتے وہ کہتے ہیں کہ اس کے علاوہ کوئی اور قرآن لاؤ یا اس میں رد و بدل کر دو۔ آپ کہہ دیجیے! کہ مجھے یہ حق نہیں ہے کہ میں اپنی طرف سے اس میں کچھ رد و بدل کر دوں! میں تو بس اسی کی پیروی کرتا ہوں جو میری طرف وحی کی جاتی ہے اگر میں اپنے پروردگار کی نافرمانی کروں تو میں ایک بڑے دن کے عذاب سے ڈرتا ہوں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccclxxx{(اے رسول(ص)) کہہ دیجیے! اگر خدا چاہتا تو میں تمہیں قرآن پڑھ کر نہ سناتا اور نہ ہی وہ تمہیں اس پر مطلع فرماتا۔ آخر میں تو اس سے پہلے تمہارے درمیان ایک عمر گزار چکا ہوں کیا تم عقل سے کام نہیں لیتے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mccclxxxi{پھر اس سے بڑھ کر کون ظالم ہو سکتا ہے جو خدا پر جھوٹا افترا باندھے؟ یا اس کی آیتوں کو جھٹلائے یقینا مجرم کبھی کامیاب نہیں ہوتے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccclxxxii{یہ لوگ اللہ کو چھوڑ کر ایسی چیزوں کی عبادت کرتے ہیں جو نہ انہیں نقصان پہنچا سکتی ہیں اور نہ فائدہ اور کہتے ہیں کہ یہ اللہ کے ہاں ہمارے سفارشی ہیں (اے رسول(ص)) تم کہو۔ کیا تم اللہ کو اس چیز کی اطلاع دیتے ہو جو خود اسے نہ آسمانوں میں معلوم ہے اور نہ زمین میں۔ پاک ہے اس کی ذات اور بلند و بالا ہے اس شرک سے جو یہ لوگ کر رہے ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiii{اور (ابتداء میں) سب انسان ایک ہی امت تھے (دینِ فطرت پر تھے) پھر آپس میں اختلاف کیا اور اگر تمہارے پروردگار کی طرف سے ایک طئے شدہ بات نہ ہوتی (کہ اعمال کی جزا و سزا آخرت میں ہوگی) تو جن باتوں میں یہ لوگ باہم اختلاف کر رہے ہیں اس کا فیصلہ کر دیا گیا ہوتا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiv{اور یہ لوگ کہتے ہیں کہ ان (پیغمبر(ص)) پر ان کے پروردگار کی طرف سے (ان کی مطلوبہ) کوئی نشانی کیوں نازل نہیں ہوتی؟ کہہ دیجیئے کہ غیب کا علم اللہ سے مخصوص ہے سو تم انتظار کرو۔ میں بھی تمہارے ساتھ انتظار کرنے والوں میں سے ہوں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mccclxxxv{اور جب ہم لوگوں کو تکلیف اور دکھ درد کے بعد (اپنی) رحمت کا مزہ چکھاتے ہیں تو وہ فوراً ہماری آیتوں میں چال بازی و حیلہ سازی کرنے لگتے ہیں۔ کہہ دیجیئے کہ اللہ تدبیر و ترکیب میں (تم سے) زیادہ تیز ہے بے شک ہمارے فرستادہ (فرشتے) تمہاری سب چالبازیاں اور مکاریاں برابر لکھتے جا رہے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvi{وہ (خدا) وہی ہے جو تمہیں خشکی و تری میں سیر و سفر کراتا ہے یہاں تک کہ جب تم کشتیوں میں سوار ہوتے ہو اور وہ موافق ہوا کے مطابق مسافروں کو لے کر چلتی ہیں اور وہ خوش و خرم ہوتے ہیں تو پھر اچانک بادِ مخالف کا تھپیڑ آجاتا ہے اور ہر طرف سے موجیں اٹھتی چلی آتی ہیں اور وہ سمجھنے لگتے ہیں کہ اب ہم بالکل گھر گئے ہیں (اور زندہ بچنے کی کوئی امید باقی نہیں رہتی) تو اس وقت دین کو اللہ کے لئے خالص کرکے یعنی بڑے اخلاص کے ساتھ خدا کو پکارتے ہیں کہ (یا اللہ) اگر تو ہمیں اس (مصیبت) سے نجات دے دے تو ہم ضرور تیرے شکر گزار بندوں میں سے ہوں گے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvii{اور جب اللہ انہیں نجات دے دیتا ہے تو (اپنا سب عہد و پیمان بھول کر) زمین میں ناحق بغاوت اور سرکشی کرنے لگتے ہیں اے لوگو! تمہاری اس بغاوت کا وِزر و وبال تو خود تمہاری ہی جانوں پر پڑ رہا ہے یہ (چند روزہ) زندگی کے مزے ہیں (سو لوٹ لو) پھر تمہاری بازگشت ہماری ہی طرف ہے اس وقت ہم تمہیں بتائیں گے کہ تم کیا کرتے رہے ہو؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mccclxxxviii{دنیاوی زندگی کی مثال تو اس پانی جیسی ہے جسے ہم نے آسمان سے برسایا اور زمین سے وہ نباتات پیدا ہوئیں جن کو انسان اور مویشی سب کھاتے ہیں یہاں تک کہ جب زمین اپنی زیب و زینت کو لے چکی اور فصل کے سبزہ زار سے آراستہ ہوگئی۔ اور اس کے مالک سمجھے کہ انہیں اس (فصل) پر قابو حاصل ہے (جب چاہیں گے کاٹیں گے) تو ایک دم رات یا دن کو ہمارا حکم آگیا۔ تو ہم نے اسے اس طرح بیخ و بن سے کاٹ کے رکھ دیا کہ گویا کل وہاں کچھ تھا ہی نہیں۔ ہم غور و فکر کرنے والوں کیلئے اسی طرح کھول کھول کر اپنی آیتیں پیش کرتے ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mccclxxxix{اور اللہ سلامتی کے گھر کی طرف بلاتا ہے اور جسے چاہتا ہے سیدھے راستہ پر لگا دیتا ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcccxc{جن لوگوں نے (دنیا میں) بھلائی کی ہوگی ان کیلئے (آخرت میں) بھلائی ہوگی اور اس سے بھی کچھ زیادہ ان کے چہروں پر نہ غبار چھائے گا اور نہ ذلت و رسوائی (نمایاں ہوگی) یہی لوگ جنتی ہیں جو اس میں ہمیشہ رہیں گے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcccxci{اور جن لوگوں نے برائیاں کمائیں تو برائی کی سزا بھی ویسی ہی برائی ہے اور ان پر ذلت و خواری چھا جائے گی ان کو اللہ (کے قانون مکافاتِ عمل) سے کوئی بچانے والا نہ ہوگا (ان کے چہرے سیاہ ہوں گے کہ) گویا ان کے چہروں کو اندھیری رات کے ٹکڑوں سے ڈھانپ دیا گیا ہے یہی لوگ دوزخی ہیں جو اس میں ہمیشہ رہیں گے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcccxcii{جس دن ہم سب کو (اپنے حضور) محشور (اکھٹا) کریں گے پھر ان لوگوں سے جنہوں نے شرک کیا تھا کہیں گے کہ تم اور جو تمہارے بنائے ہوئے شریک ہیں اپنی جگہ پر ٹھہر جاؤ۔ پھر ہم ان میں امتیاز پیدا کر دیں گے (الگ الگ کر دیں گے) (اس وقت) ان کے خود ساختہ شریک کہیں گے کہ (اے مشرکو) تم ہماری عبادت تو نہیں کیا کرتے تھے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcccxciii{آج ہمارے اور تمہارے درمیان گواہی کیلئے اللہ کافی ہے کہ ہم تمہاری عبادت سے بالکل غافل و بے خبر تھے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcccxciv{اس موقع پر ہر شخص اسے جانچ لے گا جو کچھ اس نے آگے بھیجا ہے (کہ اس کا نتیجہ کیا ہے؟) اور سب اللہ کی بارگاہ میں لوٹائے جائیں گے جو ان کا حقیقی مالک ہے اور جو (شریک) انہوں نے گھڑ رکھے تھے وہ سب غائب ہو جائیں گے (اور ان کے کچھ کام نہ آئیں گے)\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcccxcv{اے پیغمبر) ان لوگوں سے کہو (پوچھو) وہ کون ہے جو تمہیں آسمان و زمین سے روزی دیتا ہے؟ وہ کون ہے جو سمع و بصر (سننے اور دیکھنے کی طاقت) کا مالک ہے؟ وہ کون ہے جو زندہ کو مردہ سے نکالتا ہے اور مردہ کو زندہ سے؟ اور وہ کون ہے جو کائنات کا انتظام کر رہا ہے؟ اس سوال پر وہ ضرور کہیں گے کہ اللہ پس تم کہو (کہ اگر حقیقت حال یہی ہے) تو تم کیوں نہیں ڈرتے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcccxcvi{یہی اللہ ہے جو تمہارا حقیقی پروردگار ہے پھر حق کے بعد گمراہی کے سوا کیا ہے؟ تمہیں (حق سے) کدھر (غلط سمت) موڑا جا رہا ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcccxcvii{اسی طرح تمہارے پروردگار کی بات فاسقوں (نافرمانوں) پر سچی ثابت ہو کر رہی کہ وہ ایمان نہیں لائیں گے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcccxcviii{(اے پیغمبر(ص)) آپ کہیے۔ تمہارے ساختہ پرداختہ شریکوں میں سے کوئی ہے جو تخلیقِ کائنات کا آغاز بھی کرے اور (فنا کے بعد) اسے دوبارہ زندہ کرے؟ کہیے! اللہ وہ ہے جو کائنات کو پہلے پیدا بھی کرتا ہے اور پھر اسے دوبارہ زندہ بھی کرے گا تم کدھر الٹے جا رہے ہو؟\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcccxcix{(اے پیغمبر(ص)) ان سے کہیے (پوچھئے) کہ تمہارے بنائے ہوئے (خدا کے) شریکوں میں سے کوئی ایسا ہے جو حق کی طرف راہنمائی کرتا ہو؟ کہئے! وہ اللہ ہی ہے جو حق کی طرف راہنمائی کرتا ہے پھر (بتاؤ) جو حق کی طرف راہنمائی کرتا ہے وہ اس کا زیادہ حقدار ہے کہ اس کی پیروی کی جائے یا وہ جو خود اس وقت تک راہ نہیں پا سکتا جب تک اسے راہ نہ دکھائی جائے؟ تمہیں کیا ہوگیا تم کیسے فیصلے کرتے ہو؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcd{لوگوں میں اکثر ایسے ہیں جو صرف گمان کی پیروی کرتے ہیں حالانکہ گمان حق کی پہچان اور اس تک رسائی حاصل کرنے میں کچھ فائدہ نہیں دیتا (اور نہ ہی یہ حق و یقین سے بے نیاز کرتا ہے) بے شک اللہ اسے خوب جانتا ہے جو کچھ لوگ کر رہے ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcdi{اور یہ قرآن ایسا نہیں ہے کہ اللہ کے سوا کسی اور کی طرف سے گھڑ لیا جائے بلکہ یہ تو تمام سابقہ کتابوں اور وحیوں کی تصدیق ہے اور الکتاب کی تفصیل ہے (یعنی اس میں آسمانی کتابوں کی تعلیم کی تفصیل ہے) اس میں کچھ شک و شبہ نہیں ہے کہ یہ تمام جہانوں کے پروردگار کی طرف سے ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcdii{کیا یہ (کافر) لوگ کہتے ہیں کہ اس شخص (پیغمبرِ اسلام(ص)) نے اسے خود گھڑ لیا ہے؟ آپ کہیے! اگر تم اپنے اس الزام میں سچے ہو تو تم اللہ کے سوا اپنی مدد کے لئے جس جس کو بلا سکتے ہو بلا لو اور پھر قرآن کی مانند ایک ہی سورہ لے آؤ۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcdiii{بلکہ یہ لوگ اس چیز کو جھٹلا دیتے ہیں جس کا علمی احاطہ نہیں کر سکتے اور جس کی تاویل ابھی ان کے سامنے نہیں آئی ہے اسی طرح ان لوگوں نے بھی (حقائق کو) جھٹلایا تھا جو ان سے پہلے تھے تو دیکھو کہ ظلم کرنے والوں کا کیا انجام ہوا؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcdiv{ان لوگوں میں کچھ تو ایسے ہیں جو اس (قرآن) پر ایمان لاتے ہیں اور کچھ ایسے بھی ہیں جو ایمان نہیں لاتے اور آپ کا پروردگار مفسدین کو خوب جانتا ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcdv{اور اگر وہ آپ کو جھٹلائیں تو فرما دیجیے! میرا عمل میرے لئے ہے اور تمہارا تمہارے لئے جو کچھ میں کرتا ہوں اس سے تم بری الذمہ ہو اور جو کچھ تم کرتے ہو اس سے میں بری الذمہ ہوں۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcdvi{اور (اے رسول) ان لوگوں میں کچھ ایسے بھی ہیں جو آپ کی باتوں کی طرف کان لگاتے ہیں (حالانکہ سنتے نہیں ہیں) تو کیا آپ بہروں کو سنائیں گے اگرچہ وہ عقل سے کام نہ لیتے ہوں؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcdvii{اور ان میں سے کچھ ایسے ہیں (جو بظاہر) آپ کی طرف دیکھتے ہیں (حالانکہ وہ دیکھتے نہیں ہیں) تو کیا آپ اندھوں کو راہ دکھائیں گے چاہے وہ کچھ نہ دیکھتے ہوں؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcdviii{یقینا اللہ لوگوں پر ذرہ برابر بھی ظلم نہیں کرتا۔ مگر لوگ خود اپنے اوپر ظلم کرتے ہیں۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcdix{جس دن اللہ لوگوں کو اپنی بارگاہ میں جمع کرے گا (اس دن انہیں ایسا معلوم ہوگا کہ) جیسے دن کی ایک گھڑی آپس میں جان پہچان کے لئے ٹھہرے ہوں۔ بے شک وہ لوگ گھاٹے میں ہیں جنہوں نے (مرنے کے بعد) خدا کی بارگاہ میں حضوری کو جھٹلایا اور وہ ہدایت یافتہ نہیں تھے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcdx{اور (اے رسول(ص)) خواہ ہم آپ کو ابھی بعض وہ باتیں (برے اعمال کے نتائج) دکھا دیں جن کا ان (منکرین) سے وعدہ کیا ہے یا اس سے پہلے آپ کو (دنیا سے) اٹھا لیں بہرحال انہیں لوٹ کر آنا تو ہماری ہی طرف ہے پھر اللہ گواہ ہے اس پر جو کچھ وہ کر رہے ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcdxi{اور ہر امت کے لئے ایک رسول ہوتا ہے تو جب ان کا رسول ان کے پاس آجاتا ہے تو پورے انصاف کے ساتھ ان کے درمیان فیصلہ کر دیا جاتا ہے اور ان پر ظلم نہیں کیا جاتا۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcdxii{اور یہ لوگ کہتے ہیں کہ اگر تم سچے ہو تو پھر بتاؤ (عذابِ الٰہی کا) وہ وعدہ کب پورا ہوگا؟\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcdxiii{(اے رسول) کہہ دیجیے! (یہ معاملہ میرے ہاتھ میں نہیں ہے) میں تو خود اپنے نفع و نقصان کا مالک نہیں ہوں۔ مگر جو اللہ چاہے (وہی ہوتا ہے) ہر امت (قوم) کیلئے (مہلت کی) ایک مدت ہوتی ہے جب وہ مدت پوری ہو جاتی ہے (اور مقررہ وقت آجاتا ہے) تو پھر ایک گھڑی کی بھی نہ تاخیر ہو سکتی ہے اور نہ تقدیم۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcdxiv{(اے رسول) ان لوگوں سے کہیے کیا تم نے اس بات پر غور کیا ہے کہ اگر اس کا عذاب (اچانک) رات کے وقت تم پر آجائے یا دن دہاڑے (تو تم کیا کروگے؟) آخر وہ کون سی چیز ہے جس کی مجرم جلدی کر رہے ہیں؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcdxv{کیا جب وہ (عذاب) واقع ہو جائے گا تو تب اس پر تم ایمان لاؤگے؟ (اس پر یقین کروگے؟) (اس وقت تو کہا جائے گا) اب؟ (اس پر یقین کرکے اس سے بچنا چاہتے ہو؟) حالانکہ تم ہی اس کی جلدی کر رہے تھے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcdxvi{پھر ظالموں سے کہا جائے گا کہ اب دائمی عذاب کا مزہ چکھو۔ تم جو کچھ (کرتوت) کیا کرتے تھے اس (دائمی عذاب) کے سوا تمہیں اور کیا بدلہ دیا جا سکتا ہے؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcdxvii{اور وہ آپ سے پوچھتے ہیں کہ کیا یہ سچ ہے؟ (جو آپ کہتے ہیں؟) کہیے ہاں خدا کی قسم یہ بالکل سچ ہے اور تم (خدا کو) عاجز و بے بس نہیں بنا سکتے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcdxviii{جو کچھ روئے زمین پر موجود ہے اگر وہ ہر ظالم شخص کے قبضہ میں آجائے تو (وہ عذاب اس قدر سخت ہے) کہ وہ یہ سب کچھ بطور فدیہ دے دے۔ جب یہ لوگ عذابِ الٰہی کو دیکھیں گے تو ندامت و پشیمانی کو دل میں چھپائیں گے (اور اندر ہی اندر پچھتائیں گے) لیکن پورے انصاف کے ساتھ ان کے درمیان فیصلہ کر دیا جائے گا اور ان پر ظلم نہیں کیا جائے گا۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcdxix{یاد رکھو! جو کچھ آسمانوں اور زمین میں ہے وہ سب اللہ ہی کا ہے اور یہ بھی یاد رکھو کہ اللہ کا وعدہ سچا ہے لیکن اکثر لوگ (یہ حقیقت نہیں جانتے)۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcdxx{وہی زندگی دیتا ہے اور وہی موت دیتا ہے اور اسی کی طرف تم لوٹائے جاؤگے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcdxxi{اے لوگو! تمہارے پاس تمہارے پروردگار کی طرف سے (قرآن کی شکل میں) پند و موعظہ، دلوں کی بیماریوں کی شفا اور اہلِ ایمان کے لئے ہدایت و رحمت کا مجموعہ آگیا ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcdxxii{(اے رسول) کہیے کہ (یہ سب کچھ) خدا کے خاص فضل اور اس کی خصوصی رحمت کا نتیجہ ہے اس لئے چاہیے کہ لوگ خوشی منائیں یہ چیز اس دولتِ دنیا سے بہتر ہے جسے وہ جمع کرتے ہیں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcdxxiii{(اے رسول(ص)) کہیے! لوگو ذرا یہ تو بتاؤ کہ تم نے غور کیا ہے کہ خدا نے تمہارے لئے جو رزق اتارا ہے تو تم نے خود (اپنی خواہشِ نفس سے) کسی کو حرام اور کسی کو حلال قرار دے دیا ہے ان سے پوچھئے! کیا اللہ نے تمہیں اس کی اجازت دی ہے یا تم اللہ پر بہتان باندھ رہے ہو؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcdxxiv{جو لوگ خدا پر افترا پردازی کرتے ہیں ان کا قیامت کے دن کے بارے میں کیا گمان ہے؟ بے شک اللہ لوگوں پر فضل و کرم کرنے والا ہے لیکن اکثر لوگ شکر گزاری نہیں کرتے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcdxxv{(اے رسول(ص)) آپ جس حال میں بھی ہوں اور قرآن میں سے جو کچھ بھی پڑھ کر سنائیں اور (اے لوگو) تم بھی جو کوئی کام کرتے ہو ہم ضرور تم پر ناظر و نگران ہوتے ہیں جب تم اس (کام) میں مشغول و منہمک ہوتے ہو۔ اور آپ کے پروردگار سے کوئی ذرہ بھر چیز بھی پوشیدہ نہیں ہے نہ زمین میں اور نہ آسمان میں۔ اور کوئی چیز خواہ ذرہ سے چھوٹی ہو یا اس سے بڑی مگر یہ کہ وہ ایک واضح کتاب میں موجود ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcdxxvi{آگاہ ہو کہ جو اللہ کے دوست ہیں ان کے لئے نہ کوئی خوف ہے اور نہ وہ غمگین ہوں گے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcdxxvii{یہ (اللہ کے دوست) وہ لوگ ہیں جو ایمان لائے اور تقویٰ اختیار کیا۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcdxxviii{ان کے لئے دنیا کی زندگی میں بھی بشارت ہے اور آخرت میں بھی۔ اللہ کے کلمات میں کوئی تبدیلی نہیں ہو سکتی یہی بڑی کامیابی ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcdxxix{اور (اے رسول) ان (کافروں) کی (معاندانہ) باتیں آپ کو غمزدہ نہ کریں۔ یقینا تمام کی تمام عزت اللہ کے لئے ہے (وہ جسے چاہے عزت و ذلت دے) وہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcdxxx{آگاہ ہو جاؤ وہ تمام ہستیاں جو آسمان میں ہیں اور وہ سب جو زمین میں ہیں اللہ ہی کے مملوک اور اسی کے تابعِ فرمان ہیں۔ اور جو (مشرک) لوگ اللہ کے سوا خود ساختہ شریکوں کو پکارتے ہیں وہ کاہے کی پیروی کر رہے ہیں؟ وہ محض اپنے گمان کی پیروی کر رہے ہیں اور صرف اپنی اٹکلیں دوڑا رہے ہیں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcdxxxi{وہ (خدا) وہی ہے جس نے تمہارے لئے رات بنائی تاکہ اس میں آرام کرو اور دیکھنے کے لئے دن کو روشن بنایا (تاکہ اس میں کام کرو) بے شک اس میں ان لوگوں کیلئے (قدرتِ خدا کی) نشانیاں ہیں جو (کلامِ حق) سنتے ہیں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcdxxxii{یہ لوگ کہتے ہیں کہ اللہ نے اپنا کوئی بیٹا بنایا ہے حالانکہ وہ پاک و بے نیاز ہے اور اس کیلئے زمین و آسمان کی ساری کائنات ہے۔ تمہارے پاس تو تمہاری بات کی کوئی دلیل بھی نہیں ہے۔ کیا تم لوگ خدا پر وہ الزام لگاتے ہو جس کا تمہیں علم بھی نہیں ہے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiii{(اے رسول) کہہ دیجئے جو لوگ خدا پر جھوٹا بہتان باندھتے ہیں وہ کبھی فلاح نہیں پائیں گے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiv{(ان کے لئے صرف) دنیا میں تھوڑا سا فائدہ ہے پھر ان کی بازگشت ہماری طرف ہے پھر ہم ان کو ان کے کفر کی پاداش میں سخت عذاب کا مزہ چکھائیں گے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcdxxxv{اور (اے رسول(ص)) انہیں (کفار کو) نوح کا حال سنائیں جب کہ انہوں نے اپنی قوم سے کہا تھا کہ اے میری قوم! اگر (تمہارے درمیان) میرا قیام کرنا اور آیاتِ الٰہیہ کا یاد دلانا (اور ان کے ساتھ پند و نصیحت کرنا) شاق گزرتا ہے تو میرا بھروسہ صرف اللہ پر ہے تو تم (میرے خلاف) اپنے خود ساختہ شریکوں کو بھی ساتھ ملا کر کوئی متفقہ فیصلہ کرلو اور (پھر خوب سوچ سمجھ لو تاکہ) تمہارا فیصلہ تم پر پوشیدہ نہ رہے اور تمہیں اس میں کوئی تذبذب باقی نہ رہے پھر میرے ساتھ جو کرنا ہے کر گزرو اور مجھے ذرا بھی مہلت نہ دو۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvi{اب اگر (اس کے باوجود) تم روگردانی کرتے ہو (تو تمہارا ہی نقصان ہے میرا کیا نقصان ہے) میں نے تم سے کوئی اجر تو نہیں مانگا۔ میرا اجر تو اللہ کے ذمے ہے مجھے تو حکم دیا گیا ہے کہ میں اس کے فرمانبردار بندوں سے ہو کر رہوں۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvii{(بایں ہمہ) ان لوگوں نے انہیں جھٹلایا پس ہم نے انہیں اور جو کشتی میں ان کے ساتھ سوار تھے نجات دی اور انہیں (غرق ہونے والوں کا) جانشین بنایا اور جنہوں نے ہماری آیتوں کو جھٹلایا تھا ان سب کو غرق کر دیا تو دیکھو جن کو متنبہ کیا گیا تھا اور ڈرایا گیا تھا (مگر وہ نہ مانے) ان کا کیا انجام ہوا؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcdxxxviii{پھر ہم نے ان (نوح(ع)) کے بعد متعدد رسولوں کو ان کی قوموں کی طرف بھیجا اور وہ ان کے پاس کھلی کھلی نشانیاں (معجزے) لے کر آئے اس پر بھی وہ تیار نہ تھے کہ جس چیز کو وہ پہلے جھٹلا چکے ہیں (اب معجزے دیکھ کر) اس پر ایمان لائیں۔ ہم یونہی ظلم و تعدی کرنے والوں کے دلوں پر مہر لگا دیتے ہیں۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcdxxxix{پھر ہم نے ان (رسولوں) کے بعد موسیٰ (ع)و ہارون (ع)کو اپنی نشانیوں (معجزوں) کے ساتھ فرعون اور اس کے سرداروں کی طرف بھیجا تو انہوں نے تکبر کیا اور وہ لوگ (عادی) مجرم تھے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcdxl{اور جب ہماری طرف سے ان کے پاس حق آیا (اور حقیقت واضح ہوگئی) تو انہوں نے کہہ دیا کہ یہ تو کھلا ہوا جادو ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcdxli{موسیٰ (ع) نے کہا کیا تم حق کے بارے میں ایسی بات کہتے ہو جبکہ وہ تمہارے پاس آیا؟ کیا یہ جادو ہے؟ حالانکہ جادوگر کبھی فلاح و کامیابی نہیں پا سکتے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcdxlii{انہوں نے (جواب میں) کہا کہ کیا تم اس لئے ہمارے پاس آئے ہو کہ ہمیں اس راہ سے ہٹا دو جس پر ہم نے اپنے باپ دادوں کو پایا ہے۔ اور اس سر زمین میں تم دونوں (بھائیوں) کی بڑائی (سرداری) قائم ہو جائے اور ہم تم دونوں کی بات تسلیم کرنے والے نہیں ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcdxliii{اور فرعون نے کہا (میرے ملک کے) تمام ماہر جادوگروں کو میرے پاس لاؤ۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcdxliv{اور جب جادوگر آگئے تو موسیٰ نے ان سے کہا (جادو کے سامان سے) تمہیں جو کچھ پھینکنا ہے پھینکو۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcdxlv{جب وہ (رسیاں وغیرہ) پھینک چکے۔ تو موسیٰ نے کہا جو کچھ تم لائے ہو یہ جادو ہے (نہ وہ جو میں لایا ہوں) یقینا اللہ اسے بھی ملیامیٹ کر دے گا کیونکہ قانونِ قدرت ہے کہ اللہ مفسدین کے کام کو بننے نہیں دیتا۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcdxlvi{اور اللہ حق کو اپنے کلمات کے ذریعہ سے ضرور حق ثابت کر دکھاتا ہے اگرچہ مجرموں کو ناپسند ہی ہو۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcdxlvii{پس موسیٰ پر ان کی قوم کے چند نوجوانوں کے ایک گروہ کے سوا اور کوئی ایمان نہیں لایا اور وہ (ایمان لانے والے) بھی فرعون اور اپنی قوم کے سرداروں سے ڈرتے ہوئے ایمان لائے۔ کہ کہیں وہ انہیں آزمائش (اور مصیبت) میں نہ ڈال دے اور بے شک فرعون بڑا سرکش (بادشاہ) تھا اور حد سے بڑھ جانے والوں میں سے تھا۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcdxlviii{اور موسیٰ نے کہا اے میری قوم! اگر تم واقعی اللہ پر ایمان لائے ہو تو پھر اسی پر بھروسہ کرو۔ اگر تم فی الحقیقت مسلمان ہو۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcdxlix{انہوں نے (جواب میں) کہا ہم اللہ ہی پر بھروسہ کرتے ہیں (اور دعا کرتے ہیں) اے ہمارے پروردگار ہمیں ظالم لوگوں کیلئے آزمائش کا موجب نہ بنا (ان کے ظلم کا تختہ مشق نہ بنا)۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcdl{اور ہمیں اپنی رحمت سے ظالموں (کے پنجۂ ظلم) سے نجات عطا فرما۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcdli{اور ہم نے موسیٰ اور ان کے بھائی (ہارون) کی طرف وحی کی کہ مصر میں اپنی قوم کے لئے چند گھر مہیا کرو (بناؤ) اور اپنے گھروں کو قبلہ رخ بنائیں (یا اپنے گھروں کو ہی قبلہ بنائیں) اور نماز قائم کریں اور (اے موسیٰ اہلِ ایمان کو) کامیابی کی بشات دیں۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcdlii{اور موسیٰ نے (دعا مانگتے ہوئے) کہا اے ہمارے پروردگار تو نے فرعون اور اس کے سرداروں کو دنیاوی زندگی میں زیب و زینت (کی چیزوں) اور بہت سے مال و دولت سے نوازا ہے۔ اے پروردگار! اس کا نتیجہ اور انجام یہ ہے کہ وہ (تیرے بندوں کو) تیرے راستہ سے بہکاتے ہیں۔ اے ہمارے مالک، ان کے مالوں کو نابود کر دے اور ان کے دلوں کو سخت کر دے تاکہ جب تک دردناک عذاب نہ دیکھ لیں ایمان نہ لائیں (اور اس وقت ایمان کا لانا سودمند نہ ہوگا)۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcdliii{اللہ تعالیٰ نے فرمایا تم دونوں کی دعا قبول کر لی گئی ہے سو تم ثابت قدم رہو۔ اور ان لوگوں کی پیروی نہ کرو۔ جو (حق و حقیقت کا) علم نہیں رکھتے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcdliv{اور ہم نے بنی اسرائیل کو دریا سے پار اتار دیا پھر فرعون اور اس کے لشکر نے سرکشی اور ظلم و تعدی سے ان کا پیچھا کیا یہاں تک کہ جب وہ (فرعون) (دریا میں) غرق ہونے لگا تو کہنے لگا کہ میں ایمان لاتا ہوں (مانتا ہوں) کہ اس ہستی کے سوا کوئی الٰہ نہیں ہے جس پر بنی اسرائیل ایمان لائے ہیں اور میں مسلمانوں (فرمانبرداروں) میں سے ہوں۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcdlv{(اس سے کہا گیا) اب؟ (ایمان لاتا ہے؟) حالانکہ اس سے پہلے تو مسلسل نافرمانی کرتا رہا ہے اور تو فسادیوں میں سے ایک (بڑا) مفسد تھا۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcdlvi{پس آج ہم صرف تیرے بدن (لاش) کو بچائیں گے تاکہ تو اپنے بعد آنے والوں کے لئے (قدرت و عبرت کی) ایک نشانی بن جائے (اگرچہ) لوگوں کی اکثریت ہماری نشانیوں سے غافل ہی رہتی ہے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcdlvii{اور ہم نے (حسب الوعدہ) بنی اسرائیل کو (رہنے کے لئے) بہت اچھا ٹھکانا دیا اور پاکیزہ چیزوں سے ان کی روزی کا انتظام کیا پس جب تک ان کے پاس توراۃ وغیرہ کی شکل میں علم نہیں آگیا تب تک انہوں نے باہم اختلاف نہیں کیا۔ (پھر جان بوجھ کر اختلاف کیا)۔ یقینا آپ کا پروردگار قیامت کے دن ان کے درمیان فیصلہ کرے گا ان باتوں میں جن میں وہ اختلاف کیا کرتے تھے۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcdlviii{اگر (بالفرض) آپ کو اس (قرآن میں) کچھ شک ہے جو ہم نے آپ کی طرف نازل کیا ہے تو پھر ان لوگوں (اہل کتاب) سے پوچھ لو جو آپ سے پہلے کتابیں (توراۃ و انجیل وغیرہ) پڑھتے رہتے ہیں۔ بے شک آپ کے پروردگار کی طرف سے آپ کے پاس حق آیا ہے لہٰذا ہرگز شک کرنے والوں میں سے نہ ہونا۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcdlix{اور نہ ہی ان لوگوں میں سے ہونا جنہوں نے آیاتِ الٰہیہ کو جھٹلایا ورنہ نقصان اٹھانے والوں میں سے ہو جاؤگے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcdlx{بے شک وہ لوگ جن پر آپ کے پروردگار کی بات ثابت ہو چکی ہے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcdlxi{سو اگرچہ دنیا جہاں کی تمام نشانیاں (معجزات) ان کے سامنے آجائیں مگر وہ جب تک دردناک عذاب اپنی آنکھوں سے نہ دیکھ لیں تب تک وہ کبھی ایمان نہیں لائیں گے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcdlxii{قومِ یونس کے سوا کیوں کوئی ایسی بستی نہیں ہوئی جو (عذاب دیکھ کر) ایمان لائی ہو اور اس کے ایمان نے اسے فائدہ بھی پہنچایا ہو؟ جب وہ (قومِ یونس والے) ایمان لائے تو ہم نے اس دنیاوی زندگی میں ان سے رسوائی والا عذاب ٹال دیا اور ان کو ایک مدت تک زندگی کے سرو سامان سے فائدہ اٹھانے کی مہلت دے دی۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcdlxiii{اگر آپ کا پروردگار (جبراً) چاہتا تو روئے زمین کے سب لوگ ایمان لے آتے۔ تو کیا آپ لوگوں کو مجبور کرتے ہیں کہ وہ مؤمن ہو جائیں۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcdlxiv{کوئی بھی متنفس ایسا نہیں ہے جو اللہ کے اذن کے بغیر ایمان لے آئے اور اللہ ان لوگوں پر (کفر و شرک) کی نجاست ڈال دیتا ہے جو عقل سے کام نہیں لیتے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcdlxv{(اے رسول(ص)) کہیئے۔ (اے لوگو) غور سے دیکھو آسمانوں اور زمین میں کیا کیا (عجائبات قدرت) موجود ہیں (اور کس بات کی گواہی دے رہے ہیں؟) مگر جو لوگ ایمان نہیں لاتے ان کو نہ نشانیاں کوئی فائدہ دیتی ہیں اور نہ ڈرانے والوں کی تنبیہیں۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcdlxvi{کیا یہ لوگ ان جیسے (عذاب کے) دنوں کا انتظار کر رہے ہیں جو ان لوگوں پر آئے جو ان سے پہلے تھے (کہ ایسے ہی ان پر بھی آئیں؟) ان سے کہہ دیجیئے کہ پھر تم انتظار کرو۔ میں بھی تمہارے ساتھ انتظار کرنے والوں میں سے ہوں۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcdlxvii{پھر (جب ایسے دن آتے ہیں) تو ہم اپنے رسولوں کو اور ایمان لانے والوں کو نجات دے دیتے ہیں اسی طرح ہمارے ذمہ حق ہے کہ ہم اہلِ ایمان کو نجات دیا کریں۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcdlxviii{کہیے! اے لوگو اگر تمہیں میرے دین (اسلام) کے بارے میں کچھ شک ہے تو (سن لو) میں ان (بتوں) کی عبادت نہیں کرتا جن کی تم اللہ کو چھوڑ کر عبادت کرتے ہو بلکہ میں اس اللہ کی عبادت کرتا ہوں جو تمہاری روح قبض کرتا ہے اور مجھے حکم دیا گیا ہے کہ میں اہلِ ایمان کے زمرہ میں سے ہوں۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcdlxix{نیز (مجھے حکم دیا گیا ہے کہ) ہر طرف سے اپنا رخ موڑ کر سیدھا دین کی طرف رکھوں اور مشرکوں میں سے نہ ہوں۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcdlxx{نیز (مجھے حکم دیا گیا ہے کہ) اللہ کے سوا کسی ایسی ہستی کو نہ پکاریں جو تمہیں نہ فائدہ پہنچا سکے اور نہ نقصان اور اگر ایسا کیا تو پھر ظالموں میں سے ہو جاؤ گے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcdlxxi{اور اگر اللہ تمہیں کوئی نقصان پہنچانا چاہے تو اس کے سوا کوئی اس کا دور کرنے والا نہیں ہے اور اگر وہ تمہارے ساتھ بھلائی کرنا چاہے تو اس کے فضل کو کوئی روکنے والا نہیں ہے وہ اپنے بندوں میں سے جس پر چاہے اپنا فضل و کرم فرمائے وہ بڑا بخشنے والا، رحم کرنے والا ہے۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcdlxxii{(اے رسول) کہہ دیجئے! اے لوگو تمہارے پروردگار کی طرف سے حق آچکا ہے پس جو ہدایت حاصل کرے گا تو وہ اپنے فائدہ کے لئے کرے گا اور جو گمراہ ہوگا اس کا نقصان بھی اسی کو ہوگا میں تم پر نگہبان و نگران نہیں ہوں۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiii{اور (اے رسول) آپ اس وحی کی پیروی کریں جو آپ کی طرف کی جاتی ہے اور (مخالفین کی ایذا رسانیوں پر) صبر کریں یہاں تک کہ اللہ (آپ کے اور ان کے درمیان) فیصلہ کر دے۔ جو فیصلہ کرنے والوں میں سب سے بہتر فیصلہ کرنے والا ہے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiv{\basmalahur الف، لام، را، یہ وہ کتاب ہے جس کی آیتیں محکم اور مضبوط بنائی گئی ہیں اور پھر تفصیل کے ساتھ کھول کھول کر بیان کی گئی ہیں یہ اس کی طرف سے ہے جو بڑا حکمت والا، بڑا باخبر ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcdlxxv{(اس کا خلاصہ یہ ہے کہ) اللہ کے سوا کسی کی عبادت (بندگی) نہ کرو بلاشبہ میں اس کی طرف سے تمہیں ڈرانے والا اور خوشخبری دینے والا ہوں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvi{اور یہ کہ اپنے پروردگار سے مغفرت طلب کرو پھر اس کی بارگاہ میں توبہ کرو (اس کی طرف رجوع کرو) وہ تمہیں مقررہ مدت (تک زندگی کے) اچھے فوائد سے بہرہ مند کرے گا۔ اور ہر صاحبِ فضل (زیادہ عمل کرنے والے) کو اس کے درجہ کے مطابق عطا فرمائے گا اور اگر تم نے روگردانی کی تو میں تمہارے بارے میں ایک بڑے دن کے عذاب سے ڈرتا ہوں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvii{تم سب کو اللہ ہی کی طرف لوٹ کر جانا ہے اور وہ ہر چیز پر پوری قدرت رکھنے والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcdlxxviii{آگاہ ہو جاؤ یہ (منافق) لوگ اپنے سینوں کو دوہرا کر رہے ہیں تاکہ اس (اللہ یا رسول) سے چھپ جائیں مگر یاد رکھو جب یہ لوگ اپنے (سارے) کپڑے اپنے اوپر اوڑھ لیتے ہیں تو (تب بھی) وہ (اللہ) وہ بھی جانتا ہے جو کچھ وہ چھپاتے ہیں اور وہ بھی جو کچھ وہ ظاہر کرتے ہیں (کیونکہ) بے شک وہ تو ان رازوں سے بھی خوف واقف ہے جو سینوں کے اندر ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcdlxxix{اور زمین میں کوئی چلنے پھرنے والا جانور نہیں ہے مگر یہ کہ اس کا رزق خدا کے ذمے ہے اور وہ جانتا ہے کہ اس کا مستقل ٹھکانہ کہاں ہے اور اس کے سونپے جانے (کم رہنے) کی جگہ کہاں ہے؟ سب کچھ ایک واضح کتاب میں محفوظ ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcdlxxx{اور وہی وہ ہے جس نے آسمانوں اور زمین کو چھ دنوں میں پیدا کیا اور (اس سے پہلے) اس کا عرش پانی پر تھا (یہ سب کچھ کیوں پیدا کیا؟) تاکہ تمہیں آزمائے کہ تم میں سب سے بہتر عمل کرنے والا کون ہے؟ اور (اے رسول(ص)) اگر آپ ان سے کہیں کہ تم مرنے کے بعد (دوبارہ) اٹھائے جاؤگے تو کافر لوگ ضرور کہیں گے۔ یہ تو کھلا ہوا جادو ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxi{اور اگر ہم ان پر عذاب نازل کرنے میں ایک مقررہ مدت تک تاخیر بھی کر دیں تو وہ ضرور یہ کہیں گے کہ کون سی چیز نے اسے روک رکھا ہے؟ یاد رکھو جس دن ان پر وہ (عذاب) آئے گا تو پھر اسے پھیرا نہ جا سکے گا۔ اور انہیں وہ (عذاب) گھیر لے گا جس کا وہ مذاق اڑایا کرتے تھے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxii{اور اگر ہم انسان کو اپنی طرف سے رحمت کا مزہ چکھائیں (کسی نعمت سے نوازیں) اور پھر اسے اس سے چھین لیں تو وہ بڑا مایوس اور بڑا ناشکرا ہو جاتا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiii{اور اگر ہم کسی سختی و تکلیف کے پہنچنے کے بعد کسی نعمت و راحت کا مزہ چکھائیں تو (غافل ہوکر) کہہ اٹھتا ہے کہ میری تمام برائیاں چلی گئیں (دکھ درد دور ہوگئے)۔ بالیقین وہ (انسان) بڑا خوش ہونے والا، بڑا اترانے والا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiv{مگر ہاں جو لوگ صبر کرتے ہیں اور نیک عمل کرتے ہیں (وہ ایسے نہیں ہیں بلکہ) یہی وہ ہیں جن کے لئے بخشش ہے اور بہت بڑا اجر ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxv{(اے پیغمبر(ص)) آپ کی طرف جو وحی کی جاتی ہے تو کیا آپ (کفار کی باتوں سے متاثر ہوکر) اس کا کچھ حصہ چھوڑ دیں گے اور کیا آپ کا سینہ تنگ ہو جائے گا کیونکہ وہ کہتے ہیں کہ ان پر کوئی خزانہ کیوں نہیں اتارا گیا؟ یا ان کے ساتھ کوئی فرشتہ کیوں نہیں آیا؟ (آپ ہرگز ایسا نہیں کر سکتے اور نہ ہی کرنا چاہیئے کیونکہ) آپ تو بس (عذابِ الٰہی سے) ڈرانے والے ہیں اور اللہ ہی ہر چیز پر نگہبان ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvi{یا وہ یہ کہتے ہیں کہ اس شخص (آپ) نے یہ (قرآن) خود گھڑ لیا ہے؟ آپ فرمائیے اگر تم اس دعویٰ میں سچے ہو تو تم بھی اس جیسی گھڑی ہوئی دس سورتیں لے آؤ۔ اور بے شک اللہ کے سوا جس کو (اپنی مدد کیلئے) بلانا چاہتے ہو بلا لو۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvii{(اے مسلمانو) اب اگر وہ (کفار) تمہاری دعوت پر لبیک نہ کہیں تو پھر سمجھ لو کہ جو کچھ (قرآن) نازل کیا گیا ہے وہ اللہ کے علم و قدرت سے اتارا گیا ہے اور یہ بھی (سمجھ لو) کہ اللہ کے سوا کوئی الٰہ نہیں ہے (اے کفار بتاؤ) کیا اب اسلام لاؤگے۔ اور یہ حقیقت تسلیم کروگے؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxviii{اور جو صرف دنیا کی زندگی اور اس کی زیب و زینت چاہتے ہیں تو ہم انہیں ان کی سعی و عمل کی پوری پوری جزا دیتے ہیں۔ اور ان کے ساتھ کوئی کمی نہیں کی جاتی۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxix{یہ وہ (بدنصیب) لوگ ہیں جن کیلئے آخرت (کی زندگی) میں دوزخ کی آگ کے سوا کچھ نہیں ہے۔ اور انہوں نے اس (دنیا) میں جو کچھ کیا تھا وہ سب اکارت ہو جائے گا اور وہ جو کچھ کرتے تھے وہ سب باطل ہو جائے گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcdxc{کیا جو شخص اپنے پروردگار کی طرف سے (اپنی صداقت کی) کھلی ہوئی دلیل رکھتا ہے اور جس کے پیچھے ایک گواہ بھی ہے جو اسی کا جزء ہے اور اس سے پہلے موسیٰ کی کتاب (توراۃ) بھی رحمت و راہنمائی کے طور پر آچکی ہے (اور اس کی تصدیق بھی کر رہی ہے) یہ لوگ اس پر ایمان لائیں گے اور جو مختلف گروہوں میں سے اس کا انکار کرے گا اس کی وعدہ گاہ آتشِ دوزخ ہے خبردار تم! اس کے بارے میں شک میں نہ پڑنا وہ آپ کے پروردگار کی طرف سے برحق ہے مگر اکثر لوگ (حق پر) ایمان نہیں لاتے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcdxci{اور اس شخص سے بڑھ کر کون ظالم ہوگا جو اللہ پر جھوٹا بہتان باندھے ایسے لوگ اپنے پروردگار کی بارگاہ میں پیش کئے جائیں گے۔ اور گواہ گواہی دیں گے کہ یہ ہیں وہ لوگ جنہوں نے اپنے رب پر جھوٹا بہتان باندھا۔ خبردار ان ظالموں پر اللہ کی لعنت ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcdxcii{جو اللہ کی راہ سے (اس کے بندوں کو) روکتے ہیں اور اسے ٹیڑھا کرنا چاہتے ہیں اور آخرت کا انکار کرتے ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcdxciii{یہ لوگ اللہ تعالیٰ کو عاجز کرنے والے نہیں تھے اور نہ خدا کے علاوہ ان کا کوئی مددگار اور کارساز تھا۔ ان کو دوگنا عذاب ہوگا۔ (کیونکہ) یہ نہ (حق بات) سن سکتے ہیں۔ اور نہ (حقیقت) دیکھ سکتے تھے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcdxciv{یہی وہ لوگ ہیں جنہوں نے اپنے آپ کو خسارے میں مبتلا کیا اور وہ (خلافِ حق) جو افترا پردازیاں کیا کرتے تھے وہ سب ان سے گم ہوگئیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcdxcv{بلاشبہ یہی لوگ آخرت میں سب سے زیادہ گھاٹا اٹھانے والے ہوں گے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcdxcvi{بے شک جو لوگ ایمان لائے اور نیک عمل کئے اور عجز و نیاز کے ساتھ اپنے پروردگار کے حضور جھک گئے یہی لوگ جنتی ہیں جو ہمیشہ ہمیشہ اس میں رہیں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcdxcvii{ان دونوں فریقوں کی مثال ایسی ہے جیسے ایک اندھا، بہرا ہو اور دوسرا آنکھ و کان والا۔ (بتاؤ) یہ دونوں برابر ہو سکتے ہیں؟ کیا تم غور و فکر نہیں کرتے (اور نصیحت حاصل نہیں کرتے؟)\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcdxcviii{بے شک ہم نے نوح(ع) کو ان کی قوم کی طرف بھیجا (انہوں نے کہا لوگو!) میں تمہیں کھلا ہوا (عذابِ الٰہی سے) ڈرانے والا ہوں۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcdxcix{اور یہ کہ اللہ کے سوا کسی اور کی عبادت نہ کرو (ورنہ) میں تمہارے بارے میں ایک ہولناک دن کے عذاب سے ڈرتا ہوں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@md{اس پر ان کی قوم کے سردار جو کافر تھے کہنے لگے کہ (اے نوح) ہم تو تمہیں اس کے سوا کچھ نہیں دیکھتے کہ تم ہم جیسے ایک انسان ہو۔ اور ہم تو یہی دیکھ رہے ہیں کہ جن لوگوں نے آپ کی پیروی کی ہے وہ ہم میں سے بالکل رذیل لوگ ہیں اور انہوں نے بھی بے سوچے سمجھے سرسری رائے سے کی ہے اور ہم تم میں اپنے اوپر کوئی برتری نہیں دیکھتے بلکہ تم لوگوں کو جھوٹا خیال کرتے ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdi{نوح(ع) نے کہا اے میری قوم! کیا تم نے (اس بات پر) غور کیا ہے کہ اگر میں اپنے پروردگار کی طرف سے روشن دلیل رکھتا ہوں؟ اور اس نے مجھے اپنی رحمت بھی عطا فرمائی ہے۔ جو تمہیں سجھائی نہیں دیتی۔ تو کہا ہم زبردستی اسے تمہارے اوپر مسلط کر سکتے ہیں۔ جبکہ تم اسے ناپسند کرتے ہو؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdii{اے میری قوم! میں اس (تبلیغِ حق) پر تم سے کوئی مالی معاوضہ طلب نہیں کرتا۔ میرا معاوضہ اللہ کے ذمے ہے اور جو لوگ ایمان لائے ہیں (وہ تمہاری نگاہ میں جس قدر پست ہوں) میں ان کو اپنے پاس سے نکال نہیں سکتا۔ بے شک وہ اپنے پروردگار کی بارگاہ میں حاضری دینے والے ہیں البتہ میں دیکھتا ہوں کہ تم جہالت سے کام لینے والے لوگ ہو۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdiii{اے میری قوم! اگر میں ان کو اپنے پاس سے نکال دوں تو اللہ کے مقابلہ میں کون میری مدد کرے گا۔ کیا تم اتنا بھی غور نہیں کرتے (اور نصیحت قبول نہیں کرتے؟)\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdiv{اور (دیکھو) میں تم سے یہ نہیں کہتا کہ میرے پاس اللہ کے خزانے ہیں اور نہ یہ کہتا ہوں کہ میں غیب کا علم رکھتا ہوں اور نہ یہ کہتا ہوں کہ میں کوئی فرشتہ ہوں اور نہ ہی میں یہ کہتا ہوں کہ جن لوگوں کو تم حقارت کی نگاہ سے دیکھتے ہو کہ اللہ انہیں کوئی بھلائی عطا نہیں کرے گا اللہ ہی بہتر جانتا ہے جو کچھ ان کے دلوں میں ہے اگر میں ایسا کہوں تو ظالموں میں سے ہو جاؤں گا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdv{ان لوگوں نے کہا اے نوح! تم نے ہم سے بحث و تکرار کی ہے اور بہت کر لی (اس کا کوئی فائدہ نہیں ہے) اگر تم سچے ہو تو وہ (عذاب) ہمارے پاس لاؤ جس کی تم ہمیں دھمکی دیتے ہو۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdvi{نوح(ع) نے کہا وہ (عذاب) تو اللہ ہی لائے گا جب چاہے گا اور تم اسے عاجز نہیں کر سکتے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdvii{اگر اللہ تمہیں گمراہی میں چھوڑ دینا چاہے (اور اس طرح تمہیں ہلاک کرنا چاہے تو) میں جس قدر تمہیں نصیحت کرنا چاہوں میری نصیحت تمہیں کوئی فائدہ نہیں پہنچا سکتی۔ وہی تمہارا پروردگار ہے اور اسی کی طرف تمہیں لوٹ کر جانا ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdviii{کیا وہ یہ کہتے ہیں کہ (آپ) نے (یہ قرآن) خود گھڑ لیا ہے۔ تو کہیئے! اگر میں نے یہ گھڑا ہے تو اس جرم کا وبال مجھ پر ہے اور جو جرم تم کر رہے ہو اس سے میں بری الذمہ ہوں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdix{اور نوح(ع) کی طرف وحی کی گئی کہ ان لوگوں کے سوا جو ایمان لا چکے ہیں تمہاری قوم میں سے اور کوئی ایمان نہیں لائے گا۔ پس تم اس پر غمگین نہ ہو جو کچھ یہ لوگ کر رہے ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdx{اور ہماری نگرانی اور ہماری وحی کے مطابق ایک کشتی بناؤ۔ اور ظالموں کے بارے میں مجھ سے کوئی بات (سفارش) نہ کرنا (کیونکہ) یقینا یہ سب لوگ غرق ہو جانے والے ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdxi{چنانچہ نوح(ع) کشتی بنانے لگے اور جب بھی ان کی قوم کے سردار ان کے پاس سے گزرتے تو وہ ان کا مذاق اڑاتے وہ (نوح) کہتے اگر (آج) تم ہمارا مذاق اڑاتے ہو تو (کل کلاں) ہم بھی تمہارا اسی طرح مذاق اڑائیں گے جس طرح تم اڑا رہے ہو۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdxii{عنقریب تمہیں معلوم ہو جائے گا کہ کس پر عذاب آتا ہے جو اسے رسوا کر دے گا اور کس پر دائمی عذاب نازل ہوتا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdxiii{یہاں تک کہ جب ہمارا حکم آگیا۔ اور تنور نے جوش مارا (ابل پڑا) تو ہم نے (نوح(ع) سے) کہا کہ ہر قسم کے جوڑوں میں سے دو دو (نر و مادہ) کو اس (کشتی) میں سوار کر لو۔ اور اپنے گھر والوں کو بھی بجز ان کے جن کی (ہلاکت کی) بات پہلے طئے ہو چکی ہے نیز ان کو بھی (سوار کر لو) جو ایمان لا چکے ہیں اور بہت ہی تھوڑے لوگ ان کے ساتھ ایمان لائے تھے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdxiv{نوح(ع) نے کہا (کشتی میں) سوار ہو جاؤ اللہ کے نام کے سہارے اس کا چلنا بھی ہے اور اس کا ٹھہرنا بھی بے شک میرا پروردگار بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdxv{اور وہ (کشتی) انہیں ایسی موجوں (لہروں) میں سے لئے جا رہی تھی جو پہاڑوں جیسی تھیں اور نوح(ع) نے اپنے بیٹے کو آواز دی جوکہ الگ ایک گوشہ میں (کھڑا) تھا۔ اے میرے بیٹے! ہمارے ساتھ (کشتی میں) سوار ہو جا۔ اور کافروں کے ساتھ نہ ہو۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdxvi{اس نے کہا میں ابھی کسی پہاڑ پر پناہ لے لوں گا جو مجھے پانی سے بچائے گا نوح(ع) نے کہا (بیٹا) آج اللہ کے امر (عذاب) سے کوئی بچانے والا نہیں ہے۔ سوائے اس کے جس پر وہ (اللہ) رحم فرمائے۔ اور پھر (اچانک) ان کے درمیان موج حائل ہوگئی پس وہ ڈوبنے والوں میں سے ہوگیا۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdxvii{اور ارشاد ہوا اے زمین! اپنا پانی نگل لے اور اے آسمان تھم جا۔ اور پانی اتر گیا اور معاملہ طئے کر دیا گیا اور کشی کوہِ جودی پر ٹھہر گئی اور کہا گیا ہلاکت ہو ظلم کرنے والوں کے لئے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdxviii{اور نوح(ع) نے اپنے پروردگار کو پکارا اور کہا اے میرے پروردگار میرا بیٹا میرے اہل میں سے ہے اور یقینا تیرا وعدہ سچا ہے اور تو سب فیصلہ کرنے والوں سے بہتر فیصلہ کرنے والا ہے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdxix{ارشاد ہوا۔ اے نوح وہ تیرے اہل میں سے نہیں ہے وہ تو مجسم عملِ بد ہے پس جس چیز کا تمہیں علم نہیں ہے اس کے بارے میں مجھ سے سوال نہ کر میں تمہیں نصیحت کرتا ہوں کہ جاہلوں میں سے نہ ہو جانا۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdxx{عرض کیا اے میرے پروردگار! میں اس بات سے تیری بارگاہ میں پناہ مانگتا ہوں کہ میں تجھ سے ایسی چیز کا سوال کروں جس کا مجھے علم نہیں ہے۔ اور اگر تو نے مجھے نہ بخشا اور مجھ پر رحم نہ کیا تو میں نقصان اٹھانے والوں میں سے ہو جاؤں گا۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdxxi{ارشاد ہوا۔ اے نوح(ع) اترو۔ ہماری طرف سے سلامتی اور برکتیں ہوں تم پر اور ان گروہوں پر جو تمہارے ساتھ ہیں (یا بالفاظ مناسب تمہارے ساتھ والوں سے پیدا ہونے والی نسلوں پر) اور تمہارے بعد کچھ ایسے گروہ بھی ہوں گے جنہیں ہم کچھ مدت کیلئے (دنیاوی) فائدہ اٹھانے کا موقع دیں گے پھر (انجامِ کار) انہیں ہماری طرف سے دردناک عذاب پہنچے گا۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdxxii{(اے رسول) یہ (قصہ) ان غیب کی خبروں میں سے ہے جسے ہم وحی کے ذریعہ سے آپ تک پہنچا رہے ہیں اس سے پہلے نہ آپ کو ان کا (تفصیلی) علم تھا اور نہ آپ کی قوم کو۔ آپ صبر کریں۔ بے شک (اچھا) انجام پرہیزگاروں کے لئے ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdxxiii{اور ہم نے قومِ عاد کی طرف ان کے بھائی ہود کو بھیجا۔ انہوں نے کہا اے میری قوم! اللہ ہی کی عبادت کرو اس کے سوا تمہارا کوئی الٰہ نہیں ہے تم محض افترا پردازی کر رہے ہو۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdxxiv{اے میری قوم! میں اس (تبلیغ) پر تم سے کوئی مالی معاوضہ نہیں مانگتا۔ میرا معاوضہ تو اس کے ذمے ہے جس نے مجھے پیدا کیا ہے تم کیوں عقل سے کام نہیں لیتے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdxxv{اور اے میری قوم! اپنے پروردگار سے مغفرت طلب کرو۔ اور اس کی بارگاہ میں توبہ کرو (اس کی طرف رجوع کرو) وہ تم پر آسمان سے موسلادھار بارش برسائے گا۔ اور تمہاری (موجودہ) قوت میں مزید اضافہ کر دے گا۔ اور (میری دعوت سے) جرم کرتے ہوئے منہ نہ موڑو۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdxxvi{انہوں نے کہا اے ہود(ع) تم ہمارے پاس کوئی کھلی ہوئی دلیل لے کر نہیں آئے۔ اور ہم تمہارے کہنے سے اپنے خداؤں کو چھوڑنے والے نہیں ہیں۔ اور نہ ہی ہم آپ کی بات تسلیم کرنے والے ہیں۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdxxvii{ہم تو بس یہی کہتے ہیں کہ ہمارے خداؤں میں سے کسی خدا نے آپ کو کچھ (دماغی) نقصان پہنچا دیا ہے۔ انہوں (ہود) نے ان لوگوں کو کہا کہ میں اللہ کو گواہ ٹھہراتا ہوں۔ اور تم بھی گواہ رہو۔ کہ میں ان سے بیزار ہوں جن کو تم نے (حقیقی خدا کو چھوڑ کر) اس کا شریک بنا رکھا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdxxviii{تم سب مل کر میرے خلاف اپنی تدبیریں کرلو۔ اور مجھے (ذرا بھی) مہلت نہ دو۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdxxix{میرا بھروسہ اللہ پر ہے جو میرا بھی پروردگار ہے اور تمہارا بھی۔ کوئی بھی چلنے پھرنے والا ایسا جاندار نہیں جس کی چوٹی اس کے قبضۂ قدرت میں نہ ہو یقینا میرا پروردگار (عدل و انصاف کی) سیدھی راہ پر ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdxxx{اس پر بھی اگر تم روگردانی کرو تو جو (پیغام) دے کر مجھے تمہاری طرف بھیجا گیا تھا وہ میں نے تمہیں پہنچا دیا ہے (اور حجت تمام کر دی ہے) اب اگر تم نے یہ پیغام قبول نہ کیا تو میرا پروردگار تمہاری جگہ کسی اور قوم کو لائے گا۔ اور تم اس کو کچھ بھی نقصان نہیں پہنچا سکو گے بے شک میرا پروردگار ہر چیز پر نگہبان و نگران ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdxxxi{اور جب ہمارا حکم (عذاب) آگیا تو ہم نے اپنی خاص رحمت سے ہود(ع) کو اور ان لوگوں کو جو ان کے ساتھ ایمان لائے تھے نجات دے دی اور انہیں ایک سخت عذاب سے بچا لیا۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdxxxii{اور یہ ہے قومِ عاد جس نے جان بوجھ کر اپنے پروردگار کی آیتوں (نشانیوں) کا انکار کیا اور اس کے رسولوں کی نافرمانی کی اور ہر سرکش اور دشمن (حق) کی اطاعت کی۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdxxxiii{(اس کی پاداش میں) اس دنیا میں ان کے پیچھے لعنت لگا دی گئی اور آخرت میں بھی آگاہ ہو جاؤ کہ قومِ عاد نے اپنے پروردگار کا انکار کیا۔ سو ہلاکت و بربادی ہے ہود کی قومِ عاد کے لئے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdxxxiv{اور ہم نے قومِ ثمود کی طرف ان کے بھائی صالح(ع) کو بھیجا انہوں نے کہا اے میری قوم! اللہ کی عبادت کرو اس کے سوا تمہارا کوئی الٰہ نہیں ہے اسی نے تمہیں زمین سے پیدا کیا اور اسی نے تمہیں اس میں آباد کیا لہٰذا اس سے مغفرت طلب کرو۔ اور اس کی جناب میں توبہ کرو بے شک میرا پروردگار قریب بھی ہے اور مجیب (دعاؤں کا قبول کرنے والا) بھی۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdxxxv{انہوں نے کہا اے صالح! اس سے پہلے تو تو ہمارے اندر ایک ایسا شخص تھا جس سے (بڑی) امیدیں وابستہ تھیں کیا تم ہمیں اس سے روکتے ہو کہ ہم ان (معبودوں) کی پرستش نہ کریں جن کی ہمارے باپ دادا پرستش کیا کرتے تھے؟ اور ہمیں تو اس بات میں بڑا ہی شک ہے جس کی طرف تم ہمیں دعوت دیتے ہو۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdxxxvi{صالح(ع) نے کہا اے میری قوم! کیا تم نے کبھی اس بات پر غور کیا ہے کہ اگر میں اپنے پروردگار کی طرف سے ایک روشن دلیل پر ہوں اور اس نے مجھے اپنی خاص رحمت بھی عطا فرمائی ہے تو اگر میں اس کی نافرمانی کروں تو اس کے مقابلہ میں کون میری مدد کرے گا؟ تم تو میرے خسارے میں اضافہ کے سوا اور کچھ نہیں کر سکتے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdxxxvii{اور اے میری قوم! یہ اللہ کی خاص اونٹنی ہے جو تمہارے لئے ایک خاص نشانی (معجزہ) ہے پس اسے آزاد چھوڑ دو۔ تاکہ اللہ کی زمین سے کھائے اور خبردار اسے کسی قسم کی اذیت نہ پہنچانا۔ ورنہ بہت جلد عذاب تمہیں آپکڑے گا۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdxxxviii{پس ان لوگوں نے اس کی کونچیں کاٹ دیں (اسے مار ڈالا) تب صالح(ع) نے کہا کہ اب تین دن تک اپنے گھروں میں فائدہ اٹھا لو (کھا پی لو) یہ وہ وعدہ ہے جو جھوٹا نہیں ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdxxxix{پس جب ہمارا حکم (عذاب) آگیا تو ہم نے اپنی رحمت سے صالح اور اس کے ساتھ ایمان لانے والوں کو نجات دے دی اور اس دن کی رسوائی سے بچا لیا بے شک پروردگار بڑا طاقتور، بڑا زبردست ہے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdxl{اور وہ لوگ جنہوں نے ظلم کیا تھا ان کو ایک زوردار کڑک نے آپکڑا وہ اس طرح اپنے گھروں میں اوندھے پڑے رہ گئے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdxli{کہ گویا وہ کبھی ان گھروں میں بسے ہی نہ تھے آگاہ ہو جاؤ قومِ ثمود(ع) نے اپنے پروردگار کا انکار کیا آگاہ ہو کہ ہلاکت و بربادی ہے قوم ثمود کے لئے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdxlii{بے شک ہمارے بھیجے ہوئے (فرشتے) ابراہیم(ع) کے پاس خوشخبری لے کر آئے اور کہا تم پر سلام انہوں نے (جواب میں) کہا تم پر بھی سلام پھر دیر نہیں لگائی کہ ایک بھنا ہوا بچھڑا لے آئے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdxliii{مگر جب دیکھا کہ ان کے ہاتھ اس (کھانے) کی طرف نہیں بڑھ رہے تو انہیں اجنبی خیال کیا اور دل ہی دل میں ان سے خوف محسوس کیا۔ انہوں نے کہا آپ ڈریں نہیں۔ ہم تو (اللہ کی طرف سے) قومِ لوط کی طرف بھیجے گئے ہیں۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdxliv{اور ان کی بیوی (سارہ) پاس کھڑی ہوئی تھیں وہ ہنس پڑیں بس ہم نے انہیں اسحاق کی خوشخبری دی اور اسحاق کے بعد یعقوب(ع) کی۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdxlv{(اس پر) وہ کہنے لگیں۔ ہائے میری مصیبت! کیا اب میرے ہاں اولاد ہوگی جبکہ میں بوڑھی ہوگئی ہوں۔ اور یہ میرے شوہر بھی بوڑھے ہو چکے ہیں یہ تو بڑی عجیب بات ہے ۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdxlvi{انہوں (فرشتوں) نے کہا کیا تم اللہ کے کام پر تعجب کرتی ہو؟ اللہ کی رحمت اور اس کی برکتیں ہوں تم پر اے (ابراہیم(ع) کے) گھر والو بے شک وہ بڑا ستائش کیا ہوا ہے، بڑی شان والا ہے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdxlvii{جب ابراہیم (ع) کا خوف دور ہوگیا اور انہیں خوشخبری مل گئی تو قومِ لوط(ع) کے بارے میں ہم سے جھگڑنے لگے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdxlviii{بے شک ابراہیم(ع) بڑے بردبار، بڑے نرم دل اور ہر حال میں ہماری طرف رجوع کرنے والے تھے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdxlix{(ہم نے کہا) اے ابراہیم(ع) اس بات کو چھوڑ دیں تمہارے پروردگار کا حکم (عذاب) آچکا ہے یقینا ان لوگوں پر وہ عذاب آکے رہے گا۔ جو پلٹایا نہیں جا سکتا۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdl{اور جب ہمارے فرستادے لوط(ع) کے پاس آئے تو وہ ان کی وجہ سے مغموم ہوئے اور تنگدل ہوگئے اور کہا بڑا سخت دن ہے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdli{ان کی قوم کے لوگ (نوخیز مہمانوں کی آمد کی خبر سن کر) دوڑتے ہوئے ان کے پاس آئے وہ پہلے سے ہی ایسی بدکاریوں کے عادی ہو رہے تھے لوط(ع) نے کہا اے میری قوم! یہ میری بیٹیاں موجود ہیں یہ تمہارے لئے مناسب اور پاکیزہ ہیں سو اللہ سے ڈرو۔ اور میرے مہمانوں کے معاملہ میں مجھے رسوا نہ کرو۔ کیا تم میں کوئی بھلامانس نہیں ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdlii{ان لوگوں نے کہا تمہیں معلوم ہے کہ ہمیں تمہاری بیٹیوں سے کوئی سروکار نہیں ہے اور تم اچھی طرح جانتے ہو کہ ہم کیا چاہتے ہیں؟\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdliii{لوط نے کہا کاش مجھے تمہارے مقابلہ کی طاقت ہوتی یا یہ کہ میں کسی مضبوط پایہ کا سہارا لے سکتا۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdliv{تب انہوں (مہمانوں) نے کہا اے لوط(ع) ہم آپ کے پروردگار کے بھیجے ہوئے (فرشتے) ہیں یہ لوگ ہرگز آپ تک نہیں پہنچ سکیں گے تم رات کے کسی حصہ میں اپنے اہل و عیال کو لے کر نکل جاؤ۔ سوائے اپنی بیوی کے اور خبردار تم میں سے کوئی پیچھے مڑ کر نہ دیکھے۔ کیونکہ اس (بیوی) پر وہی عذاب نازل ہونے والا ہے جو ان لوگوں پر نازل ہونے والا ہے اور ان (کے عذاب) کا مقرر وقت صبح ہے کیا صبح (بالکل) قریب نہیں ہے؟\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdlv{پھر جب ہمارا حکم (عذاب) آپہنچا۔ تو ہم نے اس سرزمین کو تہہ و بالا کر دیا اور اس پر سنگِ گِل یعنی پکی ہوئی مٹی کے پتھر مسلسل برسائے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdlvi{جن میں سے ہر کنکر تمہارے پروردگار کے ہاں سے نشان زدہ تھا اور یہ (پتھر) ظالموں سے کچھ دور نہیں ہیں۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdlvii{اور ہم نے اہلِ مدین کی طرف ان کے بھائی شعیب کو بھیجا انہوں نے کہا اے میری قوم! اللہ کی عبادت کرو۔ اس کے سوا تمہارا کوئی الٰہ نہیں ہے اور ناپ تول میں کمی نہ کرو۔ میں تمہیں اچھے حال میں دیکھ رہا ہوں۔ مجھے اندیشہ ہے کہ (کفرانِ نعمت اور غلط کاری سے) عذاب کا ایسا دن نہ آجائے جو سب کو گھیر لے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdlviii{اور اے میری قوم! عدل و انصاف کے ساتھ ناپ تول پورا کیا کرو۔ اور لوگوں کو ان کی چیزیں کم نہ دو۔ اور زمین میں شر و فساد نہ پھیلاتے پھرو۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdlix{اللہ کا بقیہ تمہارے لئے بہتر ہے اگر تم ایماندار ہو؟ اور میں تم پر نگران و نگہبان نہیں ہوں۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdlx{ان لوگوں نے کہا اے شعیب(ع)! کیا تمہاری نماز تمہیں حکم دیتی ہے کہ ہم ان (معبودوں) کو چھوڑ دیں جن کی ہمارے باپ دادا پرستش کیا کرتے تھے یا اپنے اپنے اموال میں اپنی مرضی کے مطابق تصرف نہ کریں؟ بس تم ہی عاقل و بردبار اور نیکوکار آدمی ہو؟\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdlxi{آپ(ع) نے کہا میری قوم! مجھے غور کرکے بتاؤ اگر میں اپنے پروردگار کی طرف سے (اپنی صداقت کی) روشن دلیل رکھتا ہوں اور پھر اس نے اپنی بارگاہ سے مجھے اچھی روزی بھی دی ہو (تو پھر کس طرح تبلیغِ حق نہ کروں؟) اور میں یہ بھی نہیں چاہتا کہ جن چیزوں سے تمہیں روکتا ہوں۔ خود ان کے خلاف چلوں۔ میں تو صرف اصلاح (احوال) چاہتا ہوں جہاں تک میرے بس میں ہے۔ اور میری توفیق تو صرف اللہ کی طرف سے ہے اسی پر میرا بھروسہ ہے اور اسی کی طرف (اپنے تمام معاملات میں) رجوع کرتا ہوں۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdlxii{اور اے میری قوم! میری مخالفت تمہیں اس بات پر آمادہ نہ کرے کہ تم ایسے کام کرو کہ جن کی پاداش میں تم پر بھی وہی آفت آپڑے جو نوح(ع) یا ہود(ع) یا صالح(ع) کی قوم پر آئی تھی۔ اور قومِ لوط(ع) تو تم سے کچھ دور نہیں ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdlxiii{اور اپنے پروردگار سے مغفرت طلب کرو اور پھر اس کی جناب میں توبہ کرو (اس کی طرف رجوع کرو) بے شک میرا پروردگار بڑا رحم کرنے والا، بڑا محبت کرنے والا ہے۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdlxiv{ان لوگوں نے کہا اے شعیب! تم جو کچھ کہتے ہو اس میں سے اکثر باتیں تو ہماری سمجھ میں نہیں آتیں اور ہم تمہیں اپنے درمیان ایک کمزور آدمی دیکھتے ہیں اور اگر تمہارا قبیلہ نہ ہوتا تو ہم تمہیں سنگسار کر دیتے۔ اور تم ہم پر غالب نہیں ہو۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdlxv{آپ نے کہا! اے میری قوم! کیا میرا قبیلہ تمہارے نزدیک اللہ سے زیادہ معزز ہے؟ (اللہ سے زیادہ طاقتور ہے) جسے تم نے پسِ پشت ڈال دیا ہے (یاد رکھو) تم جو کچھ کر رہے ہو میرا پروردگار اس کا (علمی) احاطہ کئے ہوئے ہے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdlxvi{اور اے میری قوم! تم اپنی جگہ (اور اپنے طریقہ) پر عمل کئے جاؤ میں اپنی جگہ (اور اپنے طریقہ) پر عمل کر رہا ہوں عنقریب تمہیں معلوم ہو جائے گا کہ کس پر وہ عذاب آتا ہے جو اسے رسوا کر دے گا؟ اور کون جھوٹا ہے؟ اور تم انتظار کرو۔ میں بھی تمہارے ساتھ انتظار کرتا ہوں۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdlxvii{اور جب ہمارا حکم (عذاب) آیا تو ہم نے اپنی خاص رحمت سے شیعب کو اور ان کو جو آپ کے ساتھ ایمان لائے تھے نجات دے دی اور جن لوگوں نے ظلم کیا تھا ان کو ایک خوفناک کڑک نے آپکڑا۔ پس وہ اپنے گھروں میں اوندھے پڑے رہ گئے۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdlxviii{گویا وہ ان میں کبھی آباد ہوئے ہی نہ تھے۔ آگاہ ہو۔ ہلاکت و بربادی ہے مدین کیلئے جس طرح ہلاکت تھی قومِ ثمود کے لیے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdlxix{اور یقیناً ہم نے موسیٰ کو واضح نشانیوں (معجزات) اور واضح سند (عصا) کے ساتھ بھیجا۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdlxx{فرعون اور اس کے سرداروں کی طرف مگر انہوں نے فرعون کے حکم کی پیروی کی حالانکہ فرعون کا حکم درست نہ تھا (بلکہ بالکل غلط تھا)۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdlxxi{قیامت کے دن وہ اپنی قوم کے آگے آگے ہوگا۔ اور اس طرح انہیں آتشِ دوزخ میں پہنچا دے گا کیا ہی اترنے کی بری ہے وہ جگہ جہاں وہ اتارے جائیں گے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdlxxii{اس دنیا میں لعنت ان کے پیچھے لگا دی گئی اور قیامت کے دن (دوزخ) کیا ہی برا عطیہ ہے جو انہیں عطا کیا جائے گا۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdlxxiii{اے رسول(ص) یہ ان بستیوں کی چند خبریں ہیں جو ہم آپ کے سامنے بیان کر رہے ہیں۔ ان (بستیوں) میں سے کچھ تو اب تک قائم ہیں اور بعض کی فصل کٹ چکی ہے (بالکل اجڑ گئی ہیں)۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdlxxiv{اور ہم نے ان پر ظلم نہیں کیا بلکہ خود انہوں نے اپنے اوپر ظلم کیا۔ اور جب آپ کے پروردگار کا حکم (عذاب) آگیا تو انہیں ان کے ان خداؤں نے کچھ بھی فائدہ نہ پہنچایا جنہیں وہ اللہ کو چھوڑ کر پکارا کرتے تھے اور انہوں نے ان کی ہلاکت میں اضافہ کے سوا اور کچھ نہ کیا۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdlxxv{اور آپ کا پروردگار جب ظالم بستیوں کو پکڑتا ہے (یعنی ان کے باشندوں کو ان کے ظلم و تعدی کی وجہ سے پکڑتا ہے) تو اس کی پکڑ ایسی ہوتی ہے بے شک اس کی پکڑ بڑی دردناک (اور) سخت ہوتی ہے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdlxxvi{بے شک اس بات میں (عبرت کی) نشانی ہے اس شخص کے لئے جو آخرت کے عذاب سے ڈرتا ہے وہ ایسا دن ہے جس میں سب لوگ اکھٹے کئے جائیں گے اور وہ (سب کے) پیش ہونے کا دن ہے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdlxxvii{اور ہم اسے صرف ایک مدت (کے پورا ہونے) تک مؤخر کر رہے ہیں۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdlxxviii{تو اس (خدا) کی اجازت کے بغیر کوئی متنفس بات نہیں کر سکے گا (اس دن) کچھ لوگ بدبخت ہوں گے اور کچھ نیک بخت۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdlxxix{جب وہ دن آئے گا تو جو بدبخت ہیں وہ آتشِ دوزخ میں ہوں گے ان کیلئے وہاں چیخنا چلانا ہوگا۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdlxxx{وہ اس میں ہمیشہ رہیں گے جب تک آسمان و زمین قائم ہیں۔ اِلا یہ کہ آپ کا پروردگار (کچھ اور) چاہے بے شک آپ کا پروردگار (قادرِ مختار ہے) جو چاہتا ہے کر گزرتا ہے۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdlxxxi{اور جو نیک بخت ہیں وہ بہشت میں ہوں گے وہ اس میں ہمیشہ ہمیشہ رہیں گے جب تک آسمان و زمین قائم ہیں۔ اِلا یہ کہ آپ کا پروردگار (کچھ اور) چاہے (یہ وہ) عطیہ ہے جو کبھی منقطع نہ ہوگا۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdlxxxii{(اے رسول(ص)) جن کی یہ (مشرک لوگ) عبادت کرتے ہیں آپ ان کے (باطل پرست ہونے) میں کسی شک میں نہ رہیں یہ اسی طرح (کورکورانہ) عبادت کر رہے ہیں جس طرح ان سے پہلے ان کے باپ دادا کرتے تھے اور ہم ان کو ان (کے نتائجِ اعمال) کا پورا پورا حصہ دیں گے جس میں کوئی کمی نہیں کی جائے گی۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiii{اور بے شک ہم نے موسیٰ کو کتاب عطا کی تو اس میں اختلاف کیا گیا اور اگر آپ کے پروردگار کی طرف سے ایک بات پہلے سے طئے نہ کر دی گئی ہوتی (کہ سزا دینے میں جلدی نہیں کرنی) تو کبھی کا ان کے درمیان فیصلہ کر دیا جاتا اور وہ اس (عذاب) کے بارے میں تردد انگیز شک میں مبتلا ہیں۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiv{اور یقیناً آپ کا پروردگار ان سب کو ان کے اعمال کا (بدلہ) پورا پورا دے گا بے شک جو کچھ یہ لوگ کر رہے ہیں خدا اس سے پوری طرح باخبر ہے۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdlxxxv{پس (اے رسول(ص)) جس طرح آپ کو حکم دیا گیا ہے آپ خود اور وہ لوگ بھی جنہوں نے (کفر و عصیان سے) توبہ کر لی ہے اور آپ کے ساتھ ہیں (راہِ راست پر) ثابت قدم رہیں اور حد سے نہ بڑھیں (یقین کرو کہ) تم جو کچھ کرتے ہو وہ (اللہ) اسے دیکھ رہا ہے۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvi{اور خبردار! ظالموں کی طرف مائل نہ ہونا ورنہ (ان کی طرح) تمہیں بھی آتشِ دوزخ چھوئے گی اور اللہ کے سوا تمہارا کوئی سرپرست نہ ہوگا اور نہ ہی تمہاری کوئی مدد کی جائے گی۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvii{(اے نبی) دن کے دونوں کناروں (صبح و شام) اور رات کے کچھ حصوں میں نماز قائم کریں بے شک نیکیاں برائیوں کو دور کر دیتی ہیں یہ نصیحت ہے ان لوگوں کیلئے جو نصیحت حاصل کرتے ہیں۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mdlxxxviii{اور آپ صبر کیجئے! بے شک اللہ نیکوکاروں کا اجر ضائع نہیں کرتا۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mdlxxxix{ان قوموں اور نسلوں میں جو تم سے پہلے گزر چکی ہیں معدودے چند افراد کے سوا جن کو ہم نے نجات دی تھی ایسے سمجھدار اور نیکوکار لوگ کیوں نہ ہوئے جو لوگوں کو زمین میں فساد پھیلانے سے روکتے اور ظالم لوگ تو اسی عیش و عشرت کے پیچھے پڑے رہے جو ان کو دی گئی تھی اور یہ سب لوگ مجرم تھے۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mdxc{اور آپ کا پروردگار ایسا نہیں ہے کہ وہ ظلم کرکے (ناحق) بستیوں کو ہلاک کر دے جبکہ ان کے باشندے نیکوکار اور اصلاح کرنے والے ہوں۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mdxci{اگر آپ کا پروردگار (زبردستی) چاہتا تو سب لوگوں کو ایک ہی امت (گروہ) بنا دیتا مگر اپنی حکمتِ کاملہ سے اس نے ایسا نہیں کیا لہٰذا یہ لوگ ہمیشہ آپس میں اختلاف کرتے رہیں گے۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mdxcii{سوائے اس کے جس پر آپ کا پروردگار رحم فرمائے اور اسی (رحمت) کے لئے تو ان کو پیدا کیا ہے۔ اور آپ کے پروردگار کی بات پوری ہوگئی کہ میں جہنم کو تمام جنوں اور انسانوں سے بھر دوں گا۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mdxciii{اور (اے رسول) پیغمبروں کے قصوں میں سے یہ سب قصے جو ہم آپ کو سناتے ہیں (یہ اس لئے ہے کہ) ہم آپ کے دل کو مضبوط کر دیں اور پھر ان (قصوں) کے اندر تمہارے پاس حق آگیا۔ اور اہلِ ایمان کیلئے پند و موعظہ اور نصیحت و یاددہانی ہے۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mdxciv{اور (اے پیغمبر(ص)) جو لوگ ایمان نہیں لاتے ان سے کہہ دیجیے! تم اپنی جگہ اور اپنے طور پر کام کرو (اور ہم) اپنی جگہ اور اپنے طور پر کام کر رہے ہیں۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mdxcv{تم بھی (نتیجہ کا) انتظار کرو ہم بھی انتظار کرتے ہیں۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mdxcvi{اور آسمانوں اور زمین کا علمِ غیب اللہ ہی سے مخصوص ہے اور اسی کی طرف تمام معاملات کی بازگشت ہے تو آپ(ص) اسی کی عبادت کریں اور اسی پر بھروسہ کریں اور آپ کا پروردگار اس سے غافل نہیں ہے جو کچھ تم کرتے ہو۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mdxcvii{\basmalahur الف، لام، را۔ یہ ایک واضح کتاب کی آیتیں ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdxcviii{بے شک ہم نے اسے عربی زبان کا قرآن بنا کر نازل کیا ہے تاکہ تم اسے سمجھ سکو۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdxcix{(اے رسول(ص)) ہم اس قرآن کے ذریعہ سے جو ہم نے آپ کی طرف وحی کیا ہے ایک بہترین قصہ بیان کرتے ہیں اگرچہ اس سے پہلے آپ غافلوں میں سے تھے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdc{(اس وقت کو یاد کرو) جب یوسف نے اپنے باپ سے کہا کہ میں نے خواب میں گیارہ ستاروں اور سورج و چاند کو دیکھا ہے کہ میرے سامنے سجدہ کر رہے ہیں (جھک رہے ہیں)۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdci{آپ (ع) نے کہا اے میرے بیٹے! اپنا یہ خواب اپنے بھائیوں کے سامنے بیان نہ کرنا کہیں وہ (تمہیں تکلیف پہنچانے کے لئے) کوئی سازش نہ کرنے لگ جائیں بے شک شیطان انسان کا کھلا ہوا دشمن ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcii{اور اسی طرح تمہارا پروردگار تمہیں منتخب کرے گا اور تمہیں تعبیرِ خواب کا علم عطا فرمائے گا اور تم پر نیز یعقوب(ع) کے خانوادہ پر اسی طرح اپنی نعمت پوری کرے گا جس طرح اس سے پہلے تمہارے دادا، پردادا ابراہیم و اسحاق پر اپنی نعمت پوری کر چکا ہے بے شک آپ کا پروردگار بڑا علم والا، بڑا حکمت والا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdciii{بے شک یوسف اور اس کے بھائیوں کے قصہ میں پوچھنے والوں کے لیے (غیب کی) بڑی نشانیاں ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdciv{جب انہوں (یوسف کے سوتیلے بھائیوں) نے آپس میں کہا کہ باوجودیکہ ہم پوری جماعت ہیں مگر یوسف اور اس کا (سگا) بھائی (بن یامین) ہمارے باپ کو زیادہ پیارے ہیں بے شک ہمارے باپ کھلی ہوئی غلطی پر ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcv{یوسف کو قتل کر دو یا کسی اور سرزمین پر پھینک دو۔ تاکہ تمہارے باپ کا رخ (توجہ) صرف تمہاری طرف ہو جائے اس کے بعد تم بھلے آدمی ہو جاؤگے (تمہارے سب کام بن جائیں گے)۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcvi{ان (برادرانِ یوسف) میں سے ایک نے کہا کہ یوسف کو قتل نہ کرو البتہ اگر کچھ کرنا ہے تو اسے کسی اندھے کنویں میں ڈال دو۔ مسافروں کا کوئی قافلہ اسے اٹھا لے جائے گا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcvii{(اس قرارداد کے بعد) انہوں نے کہا اے ہمارے والد! کیا بات ہے کہ آپ یوسف کے بارے میں ہمارا اعتبار نہیں کرتے حالانکہ ہم تو اس کے بڑے خیرخواہ ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcviii{وہ کچھ کھائے پیئے اور کھیلے کودے ہم اس کی حفاظت کے ذمہ دار ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcix{آپ (ع) نے کہا تمہارا اسے اپنے ہمراہ لے جانا مجھے غمگین کرتا ہے اور مجھے یہ اندیشہ بھی ہے کہ تم غفلت کرو اور اسے کوئی بھیڑیا کھا جائے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcx{انہوں نے کہا کہ اگر اسے بھیڑیا کھا جائے جبکہ ہماری پوری جماعت (حفاظت کے لئے) موجود ہے تو پھر تو ہم گھاٹا اٹھانے والے (اور بالکل گئے گزرے) ہوں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcxi{پھر جب وہ (اصرار کرکے) اسے لے گئے اور سب نے اس بات پر اتفاق کیا کہ اسے اندھے کنویں میں ڈال دیں (چنانچہ ایسا ہی کیا)۔ اور ہم نے (اس وقت) اس (یوسف) کی طرف وحی کی کہ (ایک وقت آئے گا کہ) تم ان لوگوں کو ان کی یہ حرکت جتاؤگے جبکہ انہیں اس کا شعور نہیں ہوگا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcxii{اور وہ شام کے وقت اپنے والد کے پاس روتے ہوئے آئے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcxiii{اور کہا اے ہمارے والد! ہم تو آپس میں دوڑ میں لگ گئے اور یوسف کو اپنے سامان کے پاس چھوڑ گئے بس ایک بھیڑیا آیا اور اسے کھا گیا۔ اور اگرچہ ہم سچے ہی ہوں مگر آپ تو ہماری بات کا یقین نہیں کرتے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcxiv{اور وہ اس (یوسف (ع)) کے کُرتے پر جھوٹا خون لگا کر لائے۔ آپ (ع) نے کہا (یہ جھوٹ ہے) بلکہ تمہارے نفسوں نے (اپنے بچاؤ کیلئے) یہ بات گھڑ کر تمہیں خوشنما دکھا دی ہے (بہرحال اس سانحہ پر) صبر کرنا ہی بہتر ہے اور جو کچھ تم بیان کر رہے ہو اس سلسلہ میں اللہ ہی سے مدد مانگی جا سکتی ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcxv{اور ایک قافلہ آیا (اور وہاں اترا) تو انہوں نے (پانی لانے کیلئے) اپنا سقا بھیجا۔ پس اس نے جونہی اپنا ڈول ڈالا۔ (تو یوسف اس میں بیٹھ گئے جب ڈول کھینچا) تو پکار اٹھا۔ مبارک باد یہ تو ایک لڑکا ہے اور ان لوگوں نے اسے سرمایۂ تجارت سمجھ کر چھپا رکھا اور وہ لوگ جو کچھ کر رہے تھے اللہ اس سے خوب واقف تھا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcxvi{اور (ادھر برادرانِ یوسف بھی آپہنچے اور یوسف کو اپنا غلام ظاہر کرکے) بالکل کم قیمت پر یعنی گنتی کے چند درہموں کے عوض بیج ڈالا۔ اور ان (بھائیوں) کو اس میں کوئی دلچسپی نہ تھی (بلکہ اس سے بیزار تھے)۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcxvii{اور پھر (اس قافلہ والوں سے) مصر کے جس شخص (عزیزِ مصر) نے اسے (دوبارہ) خریدا تھا اس نے اپنی بیوی (زلیخا) سے کہا اسے عزت کے ساتھ رکھنا ہو سکتا ہے کہ ہمیں کچھ فائدہ پہنچائے یا ہم اسے اپنا بیٹا بنا لیں! اور اسی طرح (حکمتِ عملی سے) ہم نے اس (یوسف (ع)) کو سر زمینِ مصر میں تمکین دی (زمین ہموار کی تاکہ اسے اقتدار کیلئے منتخب کریں) اور خوابوں کی تعبیر کا علم عطا کریں اور اللہ اپنے ہر کام پر غالب ہے (اور اس کے انجام دینے پر قادر ہے) لیکن اکثر لوگ (یہ حقیقت) نہیں جانتے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcxviii{اور جب وہ (یوسف) پوری جوانی کو پہنچا۔ تو ہم نے اس کو حکمت اور علم عطا کیا اور ہم اسی طرح نیکوکاروں کو بدلہ دیا کرتے ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcxix{اور پھر وہ (یوسف) جس عورت کے گھر میں تھا وہ اپنی مطلب براری کے لئے اس پر ڈورے ڈالنے لگی (چنانچہ) ایک دن سب دروازے بند کر دیے اور کہا بس آجاؤ! یوسف نے کہا معاذ اللہ! (اللہ کی پناہ) وہ (تیرا شوہر) میرا مربی و محسن ہے اس نے مجھے بڑی عزت سے (اپنے گھر میں) ٹھہرایا ہے تو اس کے بدلے میں اس کی امانت میں خیانت کروں؟ (اے معاذ اللہ) بے شک ظالم کبھی فلاح نہیں پاتے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcxx{اس عورت (زلیخا) نے گناہ کرنے کا ارادہ کر لیا تھا۔ اور وہ مرد (یوسف) بھی اس کا ارادہ کرتا اگر اپنے پروردگار کا برہان نہ دیکھ لیتا ایسا ہوا تاکہ ہم اس (یوسف) سے برائی اور بے حیائی کو دور رکھیں بے شک وہ ہمارے برگزیدہ بندوں میں سے تھا۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcxxi{اور وہ دونوں ایک دوسرے سے پہلے دروازہ تک پہنچنے کے لئے دوڑے اور اس عورت نے اس مرد (یوسف) کا کرتہ پیچھے سے (کھینچ کر) پھاڑ دیا اور پھر دونوں نے اس عورت کے خاوند کو دروازے کے پاس (کھڑا ہوا) پایا۔ اسے دیکھتے ہی اپنی بے گناہی ثابت کرنے کے لیے اس عورت نے بات بنائی اور کہا جو شخص تمہاری بیوی کے ساتھ بدکاری کرنے کا ارادہ کرے اس کی سزا اس کے سوا اور کیا ہے کہ اسے قید کر دیا جائے یا کوئی دردناک عذاب دیا جائے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcxxii{یوسف (ع) نے کہا (حقیقت یہ ہے کہ) خود اسی نے اپنی مطلب برآری کے لئے مجھ پر ڈورے ڈالے اور مجھے پھسلانا چاہا اس پر اس عورت کے کنبہ والوں میں سے ایک گواہ نے گواہی دی کہ اگر یوسف کا کرتہ آگے سے پھٹا ہوا ہے تو عورت سچی ہے اور یہ جھوٹا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcxxiii{اور اگر اس کا کرتہ پیچھے سے پھٹا ہوا ہے تو یہ جھوٹی ہے اور وہ سچا۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcxxiv{پس جب اس (خاوند) نے یوسف کا کرتہ دیکھا کہ پیچھے سے پھٹا ہوا ہے تو عورت سے کہا یہ تمہاری مکاریوں سے ایک مکاری ہے بے شک تمہاری مکاریاں بڑی سخت ہوتی ہیں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcxxv{پھر یوسف (ع) سے کہا اے یوسف! اس بات سے درگزر کر (اسے جانے دے) اور بیوی سے کہا اپنے گناہ کی معافی مانگ یقینا تو خطاکاروں میں سے ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcxxvi{پھر (جب اس واقعہ کا چرچا ہوا تو) شہر کی عورتیں کہنے لگیں کہ عزیز کی بیوی اپنے نوجوان پر اپنی مطلب براری کے لئے ڈورے ڈال رہی ہے اس کی محبت اس کے دل کی گہرائیوں میں اتر گئی ہے ہم تو اسے صریح غلطی میں مبتلا دیکھتی ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcxxvii{جب زلیخا نے ان عورتوں کی یہ مکارانہ باتیں سنیں تو اس نے انہیں بلوا بھیجا اور ان کے لئے مسندیں لگا دیں اور ہر ایک کو (پھل کاٹنے کیلئے) ایک چھری دے دی۔ (پھر جب وہ پھل کاٹ کر کھانے لگیں تو) اس نے یوسف (ع) سے کہا ذرا ان کے سامنے نکل آ پس جب انہوں نے دیکھا تو (حسن و جمال میں) انہیں بڑھا ہوا پایا (لہٰذا حیران رہ گئیں اور پھل کی بجائے) اپنے ہاتھ کاٹ بیٹھیں (اور احساس تک نہ ہوا) اور (بے ساختہ) کہہ اٹھیں ماشاء اللہ۔ یہ انسان نہیں ہے بلکہ کوئی معزز فرشتہ ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcxxviii{عزیز کی بیوی نے کہا یہی وہ ہے جس کے بارے میں تم میری ملامت کرتی تھیں بے شک میں نے اس پر ڈورے ڈالے اور پھسلانے کی کوشش کی۔ مگر وہ بچا ہی رہا۔ (ہاں البتہ اب برملا کہتی ہوں کہ) اگر اس نے وہ نہ کیا جس کا میں اسے حکم دیتی ہوں تو پھر اسے ضرور قید کر دیا جائے گا۔ اور ضرور ذلیل بھی ہوگا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcxxix{یوسف (ع) نے (بات سن کر کہا) اے میرے پروردگار! اس کام کی نسبت جس کی یہ مجھے دعوت دے رہی ہیں مجھے قیدخانہ پسند ہے اور اگر تو مجھ سے ان کے مکر و فریب کو دور نہ کرے تو ہو سکتا ہے کہ میں ان کی طرف مائل ہو جاؤں اور اس طرح جاہلوں میں سے ہو جاؤں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcxxx{پس اس کے پروردگار نے اس کی دعا قبول کر لی اور اس سے ان عورتوں کے مکر و فریب کو دور کر دیا بے شک وہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcxxxi{پھر ایسا ہوا کہ باوجودیکہ وہ (یوسف کی پاکدامنی کی) نشانیاں دیکھ چکے تھے۔ تاہم انہیں یہی مناسب معلوم ہوا کہ ایک مدت تک اسے قید کر دیں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcxxxii{اور یوسف (ع) کے ساتھ دو اور جوان آدمی بھی قید خانہ میں داخل ہوئے ان میں سے ایک نے کہا کہ میں نے خواب میں دیکھا ہے کہ میں شراب (بنانے کے لیے انگور کا رس) نچوڑ رہا ہوں اور دوسرے نے کہا کہ میں نے دیکھا ہے کہ سر پر کچھ روٹیاں اٹھائے ہوں۔ جن میں سے پرندے کھا رہے ہیں ہمیں ذرا اس کی تعبیر بتائیے ہم تمہیں نیکوکاروں میں سے دیکھتے ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiii{یوسف (ع) نے کہا جو (مقررہ) کھانا تمہیں دیا جاتا ہے اس کے آنے سے پہلے میں تمہیں تمہارے خوابوں کی تعبیر بتا دوں گا۔ یہ (تعبیرِ خواب) بھی منجملہ ان علوم کے ہے جو میرے پروردگار نے مجھے تعلیم دیے ہیں۔ میں ان لوگوں کا دین و مذہب چھوڑے ہوئے ہوں جو اللہ پر ایمان نہیں رکھتے اور آخرت کے بھی منکر ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiv{اور میں تو اپنے باپ دادا ابراہیم (ع)، اسحاق(ع) اور یعقوب(ع) کے مذہب کا پیرو ہوں۔ ہمیں یہ زیبا نہیں ہے کہ ہم کسی چیز کو بھی خدا کا شریک ٹھہرائیں۔ یہ اللہ کا فضل ہے جو اس نے ہم اور سب لوگوں پر کیا ہے لیکن اکثر لوگ شکر ادا نہیں کرتے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcxxxv{اے قید خانہ کے میرے دونوں ساتھیو (یہ بتاؤ) آیا بہت سے جدا جدا خدا اچھے ہیں یا اللہ جو یگانہ بھی ہے اور سب پر غالب بھی؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvi{اللہ کو چھوڑ کر تم جن کی پرستش کرتے ہو ان کی حقیقت اس کے سوا اور کیا ہے؟ کہ وہ چند نام ہیں جو تم نے اور تمہارے باپ دادا نے رکھ لئے ہیں۔ اللہ نے ان کے لئے کوئی سند نہیں اتاری ہے حکم و حکومت کا حق صرف اللہ کو حاصل ہے اسی نے حکم دیا ہے کہ اس کے سوا اور کسی کی عبادت نہ کرو۔ یہی دینِ مستقیم (سیدھا دین) ہے مگر اکثر لوگ جانتے نہیں ہیں۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvii{اے قید خانہ کے میرے دونوں ساتھیو! (اب اپنے خوابوں کی تعبیر سنو) تم میں سے ایک (پہلا) تو وہ ہے جو اپنے مالک (شاہِ مصر) کو شراب پلائے گا اور جو دوسرا ہے اسے سولی پر لٹکایا جائے گا اور پرندے اس کے سر کو (نوچ نوچ کر) کھائیں گے اس بات کا فیصلہ ہو چکا جس کے بارے میں تم دریافت کرتے ہو۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcxxxviii{اور یوسف (ع) نے اس شخص سے کہا جس کے متعلق وہ سمجھتے تھے کہ وہ ان دنوں میں سے رہا ہو جائے گا۔ کہ اپنے مالک سے میرا تذکرہ بھی کر دینا لیکن شیطان نے اسے اپنے مالک سے یہ تذکرہ کرنا بھلا دیا۔ پس یوسف کئی سال قید خانہ میں پڑا رہا۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcxxxix{(کچھ مدت کے بعد) بادشاہ نے کہا میں نے (خواب میں) سات موٹی تازی گائیں دیکھی ہیں جنہیں سات دبلی پتلی گائیں کھا رہی ہیں اور سات بالیاں ہری ہیں اور سات دوسری سوکھی اے سردارو (درباریو) اگر تم خواب کی تعبیر دے سکتے ہو تو پھر مجھے میرے خواب کی تعبیر بتاؤ۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcxl{انہوں نے کہا یہ تو پریشان خواب و خیالات ہیں (جن کی کوئی خاص تعبیر نہیں ہوتی) اور ہم خوابہائے پریشان کی تعبیر نہیں جانتے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcxli{اس وقت وہ شخص جو ان دو قیدیوں میں رہا ہوا تھا اور مدت کے بعد اسے (یوسف (ع) کا پیغام) یاد آیا تھا بولا میں تمہیں اس خواب کی تعبیر بتاتا ہوں ذرا مجھے (ایک جگہ) بھیج تو دو۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcxlii{(چنانچہ وہ سیدھا قید خانہ گیا اور کہا) اے یوسف! اے بڑے سچے! ذرا ہمیں اس خواب کی تعبیر بتاؤ کہ سات موٹی تازی گائیں ہیں جنہیں سات دبلی پتلی گائیں کھا رہی ہیں اور سات بالیاں ہری ہیں اور سات سوکھی تاکہ میں ان لوگوں کے پاس جاؤں (اور انہیں جا کر بتاؤں) شاید وہ (تمہاری قدر و منزلت یا تعبیر) جان لیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcxliii{یوسف (ع) نے کہا (اس خواب کی تعبیر یہ ہے) کہ تم متواتر سات سال کاشتکاری کروگے پھر جو فصل کاٹو اسے اس کی بالی میں رہنے دو ہاں البتہ تھوڑا سا حصہ نکال لو جسے تم کھاؤ۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcxliv{پھر اس کے بعد سات بڑے سخت سال آئیں گے جو وہ سب کچھ کھا جائیں گے جو تم نے ان کے لئے ذخیرہ کیا تھا مگر تھوڑا سا بچے گا جسے تم محفوظ کر لوگے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcxlv{پھر اس کے بعد ایک سال ایسا آئے گا جس میں لوگوں پر خوب بارش برسائی جائے گی اور اس کے ذریعہ سے ان کی فریاد رسی کی جائے گی۔ اور جس میں وہ (پھلوں کا رس) نچوڑیں گے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdcxlvi{(یہ تعبیر سن کر) بادشاہ نے کہا اس شخص (یوسف) کو میرے پاس لاؤ۔ پس جب قاصد اس کے پاس آیا تو اس نے کہا اپنے بادشاہ کے پاس واپس جا اور اس سے پوچھ کہ ان عورتوں کے معاملہ کی حقیقت کیا ہے جنہوں نے اپنے ہاتھ کاٹ ڈالے تھے؟ بے شک میرا پروردگار ان کے مکر و فریب سے خوب واقف ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcxlvii{(چنانچہ بادشاہ نے ان سب عورتوں کو بلایا اور) پوچھا۔ تمہارا کیا معاملہ تھا جب تم نے اپنی مطلب براری کے لئے یوسف پر ڈورے ڈالے تھے اور اسے پھسلانا چاہا تھا؟ سب نے (بیک زبان) کہا حاشا ﷲ! ہمیں تو اس کی ذرا بھر کوئی برائی معلوم نہیں ہوئی (اس وقت) عزیزِ مصر کی بیوی نے کہا اب جبکہ حق ظاہر ہوگیا (اور حقیقتِ حال بالکل آشکارا ہوگئی) تو وہ میں تھی جس نے اس (یوسف) پر ڈورے ڈالے تھے بے شک وہ سچے لوگوں میں سے ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcxlviii{(یوسف نے کہا) یہ سب کچھ اس لئے کیا تاکہ وہ عزیز مصر کو (مزید) علم ہو جائے کہ میں نے اس کی پس پشت (اس کی امانت میں) خیانت نہیں کی اور یقینا اللہ خیانت کاروں کے مکر و فریب کو کامیاب نہیں ہونے دیتا۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdcxlix{میں اپنے نفس کو (بھی) بری قرار نہیں دیتا بے شک نفس تو برائی کا بڑا حکم دینے والا (اور اس پر اکسانے والا) ہے مگر یہ کہ میرا پروردگار (کسی کے حال پر) رحم کرے یقینا میرا پروردگار بڑا بخشنے والا، بڑا رحم کرنے والا۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdcl{اور بادشاہ نے کہا کہ اسے میرے پاس بلاؤ تاکہ میں اسے اپنے (ذاتی کاموں کی انجام دہی) کے لیے مخصوص کر لوں۔ پس جب (یوسف آئے اور) بادشاہ نے اس سے گفتگو کی تو (متاثر ہوکر) کہا آج سے تم ہمارے ہاں صاحب مرتبہ اور امانت دار ہو۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdcli{آپ (ع) نے کہا مجھے (اس) زمین کے خزانوں پر مقرر کر دیجیے میں یقیناً (مال کی) حفاظت کرنے والا اور اس کام کا جاننے والا بھی ہوں۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdclii{اور اس طرح ہم نے یوسف کو اس سرزمین میں اختیار و اقتدار دیا کہ وہ اس میں جہاں چاہے رہے ہم جسے چاہتے ہیں اپنی رحمت سے نوازتے ہیں اور ہم نیکوکاروں کا اجر ضائع نہیں کرتے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdcliii{اور البتہ جو لوگ ایمان لائے اور تقویٰ اختیار کیا ان کے لئے آخرت کا اجر و ثواب یقیناً (اس سے) بہتر ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdcliv{اور (قحط سالی کے دنوں میں غلہ خریدنے) یوسف کے بھائی (مصر) آئے اور (یوسف) کے پاس گئے تو اس نے انہیں پہچان لیا جبکہ وہ اسے نہ پہچان سکے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdclv{اور جب یوسف نے ان کی (خوراک) کا سامان تیار کروا دیا تو (جاتے وقت) کہا (اب کی بار) اپنے (سوتیلے) پدری بھائی کو بھی میرے پاس لیتے آنا۔ کیا تم نہیں دیکھتے کہ میں پورا پورا ناپ (تول) کر (غلہ) دیتا ہوں اور میں کتنا اچھا مہمان نواز ہوں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdclvi{اور اگر تم اسے میرے پاس نہ لائے تو پھر تمہارے لئے نہ میرے پاس تولنے کے لئے (غلہ) ہوگا اور نہ ہی میرے قریب آنا۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdclvii{ان لوگوں نے کہا کہ ہم اس کے باپ پر ڈورے ڈالیں گے کہ وہ (آمادہ ہو جائیں) اور ہم ضرور ایسا کریں گے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdclviii{اور یوسف نے اپنے جوانوں (غلاموں) سے کہا کہ ان کی پونجی (جس کے عوض غلہ خریدا ہے) ان کے سامان میں رکھ دو۔ تاکہ جب اپنے گھر والوں کے پاس لوٹ کر جائیں تو اسے پہچانیں (اور) شاید دوبارہ آئیں۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdclix{اور جب وہ لوگ لوٹ کر اپنے والد کے پاس گئے تو کہا اے ہمارے باپ! ہمارے لئے (ناپ تول کر) غلہ دیا جانا بند کر دیا گیا ہے (جب تک بھائی کو ہمراہ نہ لے جائیں) اس لئے ہمارے بھائی (بنیامین) کو ہمارے ساتھ بھیجئے تاکہ ہم غلہ لا سکیں اور ہم یقیناً اس کی (پوری) حفاظت کریں گے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdclx{آپ (ع) نے کہا کیا میں اس کے بارے میں تم پر اسی طرح اعتماد کروں جس طرح اس سے پہلے اس کے بھائی کے بارے میں کیا تھا؟ بہرحال اللہ سب سے بہتر حفاظت کرنے والا ہے اور وہی سب سے بڑھ کر رحم کرنے والا ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdclxi{اور جب انہوں نے اپنا سامان کھولا تو دیکھا کہ ان کی پونجی انہیں واپس کر دی گئی ہے تو کہنے لگے ابا جان! ہمیں اور کیا چاہیئے؟ (دیکھے) یہ ہماری پونجی ہے جو ہمیں واپس کر دی گئی ہے (اب کی بار جو بھائی کو اپنے ساتھ لے جائیں گے) تو جہاں اپنے گھر والوں کے لیے رسد لائیں گے اپنے بھائی کی حفاظت کریں گے (وہاں) ایک اونٹ کا بار اور زیادہ بھی لائیں گے اور یہ غلہ (جو اب کی بار ہم لائے ہیں) بہت تھوڑا ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdclxii{آپ (ع) نے کہا میں اسے کبھی تمہارے ساتھ نہیں بھیجوں گا جب تک اللہ کی قسم کھا کر مجھ سے عہد و پیمان نہ کرو کہ تم اسے ضرور اپنے ساتھ لاؤگے سوا اس کے کہ تم سب ہی گھیر لئے جاؤ (اور بے بس ہو جاؤ) پھر جب انہوں نے قسم کھا کر اپنا قول و قرار دے دیا تو آپ نے کہا اللہ ہمارے قول قرار پر نگہبان ہے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdclxiii{اور آپ (ع) نے کہا اے میرے بیٹو (جب مصر پہنچو) تو ایک دروازے سے (شہر میں) داخل نہ ہونا بلکہ مختلف دروازوں سے داخل ہونا اور میں تمہیں اللہ (کی مشیت اور اس کی قضا و قدر) سے بچا تو نہیں سکتا (ہر قسم کا) حکم (اور فیصلہ) اللہ کے قبضہ قدرت میں ہے اسی پر میرا بھروسہ ہے اور اسی پر سب بھروسہ کرنے والوں کو بھروسہ کرنا چاہیئے (میں نے تو صرف احتیاط کے طور پر یہ تدبیر بنائی ہے)۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdclxiv{اور جب وہ لوگ (مصر میں) اسی طرح داخل ہوئے جس طرح ان کے باپ نے انہیں حکم دیا تھا ان کا اس طرح داخل ہونا انہیں خدا (کی مشیت اور اس کی تقدیر) سے بچا تو نہیں سکتا تھا مگر یہ (احتیاطی تدبیر) یعقوب کے دل میں ایک تمنا تھی جسے انہوں نے پورا کر لیا بے شک وہ ہماری دی ہوئی تعلیم سے صاحبِ علم تھا لیکن اکثر لوگ (اس حقیقت کو) نہیں جانتے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdclxv{اور جب یہ لوگ یوسف (ع) کے پاس پہنچے تو اس نے اپنے (حقیقی) بھائی (بنیامین) کو اپنے پاس جگہ دی (اور آہستگی سے) کہا میں تیرا بھائی (یوسف) ہوں بس تو اس پر غمگین نہ ہو جو کچھ یہ لوگ سلوک کرتے رہے ہیں۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdclxvi{پھر جب اس (یوسف) نے ان کا سامان تیار کرایا تو پانی پینے کا کٹورا اپنے (سگے) بھائی کے سامان میں رکھوا دیا پھر ایک منادی نے ندا دی کہ اے قافلہ والو! تم چور ہو۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdclxvii{وہ لوگ ان کی طرف متوجہ ہوئے اور (پریشان ہوکر) کہا تم نے کون سی چیز گم کی ہے؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdclxviii{انہوں نے کہا کہ ہم نے بادشاہ کے پینے کا (قیمتی) کٹورا گم کیا ہے اور جو اسے لائے گا اسے ایک بار شتر (غلہ) انعام دیا جائے گا اور میں (منادی) اس بات کا ضامن ہوں۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdclxix{انہوں نے کہا کہ تم جانتے ہو کہ ہم اس لئے نہیں آئے کہ زمین میں فساد برپا کریں اور نہ ہی ہم چور ہیں۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdclxx{انہوں (ملازمین) نے کہا اگر تم جھوٹے نکلے تو اس (چور) کی سزا کیا ہے؟\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdclxxi{انہوں نے کہا اس کی سزا یہ ہے کہ جس کے سامان سے مل جائے وہ خود ہی اس کی سزا ہے ہم اسی طرح ظلم کرنے والوں کو سزا دیتے ہیں۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdclxxii{تب یوسف (ع) نے اپنے (سگے) بھائی کی خرجین سے پہلے دوسروں کی خرجینوں کی تلاشی لینا شروع کی پھر اپنے بھائی کی خرجین سے وہ گم شدہ کٹورا نکال لیا ہم نے اس طرح (بنیامین کو اپنے پاس رکھنے) کیلئے یوسف کے لیے تدبیر کی کیونکہ وہ (مصر کے) بادشاہ کے قانون میں اپنے بھائی کو نہیں لے سکتے تھے مگر یہ کہ خدا چاہتا ہم جس کے چاہتے ہیں مرتبے بلند کر دیتے ہیں اور ہر صاحبِ علم سے بڑھ کر ایک عالم ہوتا ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdclxxiii{ان لوگوں (برادرانِ یوسف(ع)) نے کہا اگر اس نے چوری کی ہے تو اس پر کیا تعجب اس سے پہلے اس کے ایک حقیقی بھائی نے بھی چوری کی تھی یوسف نے اس بات کو اپنے دل میں پوشیدہ رکھا اور ان پر ظاہر نہیں کیا (البتہ صرف اتنا) کہا تم بہت ہی برے لوگ ہو اور جو کچھ تم بیان کر رہے ہو اسے اللہ ہی بہتر جانتا ہے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdclxxiv{انہوں نے کہا اے عزیز (مصر) اس کا ایک بہت بوڑھا باپ ہے (وہ اس کی جدائی برداشت نہیں کر سکے گا) اس لئے اس کی جگہ ہم میں سے کسی کو رکھ لیجئے ہم آپ کو احسان کرنے والوں میں سے دیکھتے ہیں۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdclxxv{یوسف (ع) نے کہا معاذ اللہ (اللہ کی پناہ) کہ ہم اس آدمی کے سوا جس کے پاس ہم نے اپنا مال پایا ہے کسی اور شخص کو پکڑیں اس صورت میں تو ہم ظالم قرار پائیں گے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdclxxvi{پھر جب وہ لوگ اس (یوسف) سے مایوس ہوگئے تو علیٰحدہ جاکر باہم سرگوشی (مشورہ) کرنے لگے جو ان میں (سب سے) بڑا تھا اس نے کہا کیا تم نہیں جانتے کہ تمہارے باپ (بنیامین کے بارے میں) خدا کے نام پر تم سے عہد و پیمان لے چکے ہیں اور اس سے پہلے یوسف(ع) کے بارے میں جو تقصیر تم کر چکے ہو (وہ بھی تم جانتے ہو) اس لئے میں تو اس سر زمین کو نہیں چھوڑوں گا جب تک میرا باپ مجھے اجازت نہ دے یا پھر اللہ میرے لئے کوئی فیصلہ نہ کرے اور وہ بہترین فیصلہ کرنے والا ہے۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdclxxvii{لہٰذا تم لوگ اپنے باپ کے پاس واپس جاؤ۔ اور جاکر کہو اے ہمارے باپ! آپ کے بیٹے (بنیامین) نے چوری کی ہے اور ہم نے اسی بات کی گواہی دی ہے۔ جس کا ہمیں علم ہے اور ہم غیب کی نگہبانی کرنے والے نہیں ہیں (غیبی باتوں کی ہمیں خبر نہیں ہے)۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdclxxviii{اور آپ اس بستی (مصر) کے لوگوں سے پوچھ لیجئے جس میں ہم تھے اور قافلہ والوں سے دریافت کیجئے جس کے ساتھ ہم آئے ہیں اور بے شک ہم سچے ہیں۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdclxxix{آپ (ع) نے (یہ قصہ سن کر) کہا (ایسا نہیں ہے) بلکہ تمہارے نفسوں نے یہ بات تمہارے لئے گھڑ لی ہے (اور خوشنما کرکے سجھائی ہے) تو اب (میرے لئے) صبرِ جمیل ہی اولیٰ ہے امید ہے کہ اللہ تعالیٰ سب کو میرے پاس لائے گا بے شک وہ بڑا علم والا، بڑا حکمت والا ہے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdclxxx{(یہ کہہ کر) ان لوگوں کی طرف سے منہ پھیر لیا اور کہا ہائے یوسف (ہائے یوسف) اور رنج و غم (کی شدت) سے (رو رو کر) ان کی دونوں آنکھیں سفید ہوگئیں اور وہ (باوجود مصیبت زدہ ہونے) کے بڑے ضبط کرنے والے اور خاموش تھے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdclxxxi{ان لوگوں (بیٹوں) نے کہا خدا کی قسم معلوم ہوتا ہے کہ آپ برابر یوسف (ع) کو یاد کرتے رہیں گے یہاں تک کہ سخت بیمار ہو جائیں گے یا ہلاک ہو جائیں گے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdclxxxii{آپ (ع) نے کہا کہ میں اپنے رنج و غم کی شکایت بس اللہ ہی سے کر رہا ہوں اور میں اللہ کی طرف سے وہ کچھ جانتا ہوں جو تم نہیں جانتے۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiii{اے میرے بیٹو! (ایک بار پھر مصر) جاؤ اور یوسف (ع) اور اس کے بھائی کی تلاش کرو اور اللہ کی رحمت سے مایوس نہ ہو بے شک اللہ کی رحمت سے صرف کافر لوگ ہی مایوس ہوتے ہیں۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiv{(چنانچہ حسب الحکم) جب یہ لوگ (مصر گئے) اور یوسف (ع) کے پاس پہنچے تو کہنے لگے اے عزیزِ مصر! ہمیں اور ہمارے گھر والوں کو بڑی تکلیف پہنچی ہے (اس لئے اب کی بار) ہم بالکل حقیر سی پونجی لائے ہیں (اسے قبول کریں اور) ہمیں پیمانہ پورا ناپ کر دیجیئے (بھرپور غلہ دیجئے) اور (مزید برآں) ہم کو صدقہ و خیرات بھی دیجئے بے شک اللہ صدقہ خیرات کرنے والوں کو جزاءِ خیر دیتا ہے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdclxxxv{آپ (ع) نے کہا تمہیں کچھ معلوم ہے کہ تم نے یوسف اور اس کے (سگے) بھائی کے ساتھ کیا سلوک کیا تھا جبکہ تم جاہل و نادان تھے؟\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvi{اس پر وہ لوگ چونکے اور کہا کیا تم یوسف ہو؟ کہا ہاں میں یوسف (ع) ہوں اور یہ میرا بھائی ہے اللہ نے ہم پر احسان کیا بے شک جو پرہیزگاری اختیار کرتا ہے اور صبر سے کام لیتا ہے (وہ بالآخر ضرور کامیاب ہوتا ہے کیونکہ) اللہ نیکوکاروں کا اجر ضائع نہیں کرتا۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvii{انہوں (بھائیوں) نے (شرمسار ہوکر) کہا بے شک اللہ نے تمہیں ہم پر برتری عطا فرمائی ہے اور بے شک ہم خطاکار ہیں۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdclxxxviii{آپ (ع) نے کہا آج تم پر کوئی الزام (اور لعنت ملامت) نہیں ہے اللہ تمہیں معاف کرے اور وہ بڑا رحم کرنے والا (مہربان) ہے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdclxxxix{(بعد ازاں) کہا میری قمیص لے جاؤ اور اسے میرے والد کے چہرے پر ڈال دو ان کی بینائی پلٹ آئے گی (وہ بینا ہو جائیں گے) اور پھر اپنے سب اہل و عیال کو (یہاں) میرے پاس لے آؤ۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcxc{اور جب (مصر سے) قافلہ روانہ ہوا تو ان کے باپ نے (کنعان میں) کہا اگر تم مجھے مخبوط الحواس نہ سمجھو تو میں یوسف (ع) کی خوشبو محسوس کر رہا ہوں۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcxci{ان (گھر والوں) نے کہا خدا کی قسم آپ اپنی پرانی غلطی میں مبتلا ہیں۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcxcii{پھر جب خوشخبری دینے والا آیا (اور) وہ قمیص ان کے چہرہ پر ڈالی تو وہ فوراً بینا ہوگئے اور کہا کیا میں نے تم سے نہیں کہا تھا کہ میں اللہ کی طرف سے وہ کچھ جانتا ہوں جو تم نہیں جانتے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcxciii{انہوں (بیٹوں) نے کہا اے ہمارے باپ (خدا سے) ہمارے گناہوں کی مغفرت طلب کریں یقینا ہم خطاکار تھے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdcxciv{آپ (ع) نے کہا میں عنقریب تمہارے لئے اپنے پروردگار سے مغفرت طلب کروں گا بے شک وہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdcxcv{جب وہ سب لوگ کنعان سے روانہ ہو کر یوسف (ع)کے پاس (مصر میں) پہنچے تو انہوں نے اپنے ماں باپ کو اپنے پاس جگہ دی اور کہا (اب) مصر میں داخل ہو خدا نے چاہا تو یہاں امن و اطمینان سے رہوگے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdcxcvi{اور (دربار میں پہنچ کر) اپنے ماں باپ کو تختِ شاہی پر (اونچا) بٹھایا اور سب اس کے سامنے سجدہ (شکر) میں جھک گئے (اس وقت) یوسف (ع) نے کہا اے بابا یہ میرے اس خواب کی تعبیر ہے جو (بہت عرصہ) پہلے میں نے دیکھا تھا جسے میرے پروردگار نے سچ کر دکھایا ہے اور اس نے مجھ پر بڑا احسان کیا کہ مجھے قید خانہ سے نکالا اور آپ لوگوں کو صحراء (گاؤں) سے یہاں (شہر میں) لایا۔ بعد اس کے کہ شیطان نے میرے اور میرے بھائیوں کے درمیان اختلاف و فساد ڈال دیا تھا بے شک میرا پروردگار جو کام کرنا چاہتا ہے اس کی بہترین تدبیر کرنے والا ہے بلاشبہ وہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdcxcvii{اے میرے پروردگار! تو نے مجھے سلطنت عطا فرمائی ہے اور خوابوں کی تعبیر کا علم بھی تو نے ہی مجھے بخشا ہے اے آسمانوں اور زمین کے خالق تو دنیا و آخرت میں میرا سرپرست اور کارساز ہے میرا خاتمہ (حقیقی) اسلام اور فرمانبرداری پر کر اور مجھے اپنے نیکوکار بندوں میں داخل فرما۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdcxcviii{(اے پیغمبر(ص)) یہ (داستان) غیب کی خبروں میں سے ہے جس کی ہم آپ کی طرف وحی کر رہے ہیں اور آپ ان (برادرانِ یوسف (ع)) کے پاس اس وقت موجود نہیں تھے جب کہ وہ آپس میں اتفاق کرکے یوسف کے خلاف سازش کر رہے تھے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdcxcix{اور آپ کتنا ہی حرص کریں (اور کتنا ہی چاہیں) مگر اکثر لوگ ایمان نہیں لائیں گے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdcc{حالانکہ آپ اس بات (تبلیغِ رسالت) پر ان سے کوئی اجرت بھی نہیں مانگتے یہ (قرآن) تو تمام جہانوں کے لئے یاددہانی اور پند و موعظہ ہے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdcci{اور آسمانوں اور زمین میں (خدا کے وجود اور اس کی قدرت کی) کتنی ہی نشانیاں موجود ہیں مگر یہ لوگ ان سے روگردانی کرتے ہوئے گزر جاتے ہیں (اور کوئی توجہ نہیں کرتے)۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdccii{اور ان میں سے اکثر اللہ پر ایمان بھی لاتے ہیں تو اس حالت میں کہ (عملی طور پر) برابر شرک بھی کئے جاتے ہیں۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdcciii{کیا وہ اس بات سے مطمئن ہوگئے ہیں کہ ان پر کوئی عذابِ الٰہی آجائے اور چھا جائے یا اچانک ان کے سامنے اس حال میں قیامت آجائے کہ انہیں خبر بھی نہ ہو۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdcciv{(اے پیغمبر) آپ کہہ دیجئے! کہ میرا راستہ تو یہ ہے کہ میں اور جو میرا (حقیقی) پیروکار ہے ہم اللہ کی طرف بلاتے ہیں اس حال میں کہ ہم واضح دلیل پر ہیں اور اللہ ہر نقص و عیب سے پاک ہے اور میں شرک کرنے والوں میں سے نہیں ہوں۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdccv{(اے رسول(ص)) ہم نے آپ سے پہلے جن کو بھی رسول بنا کر بھیجا وہ مرد تھے اور آبادیوں کے باشندے تھے جن کی طرف ہم وحی کیا کرتے تھے کیا یہ لوگ زمین میں چلے پھرے نہیں کہ دیکھتے کہ ان لوگوں کا انجام کیسا ہوا جو ان سے پہلے تھے یقینا آخرت کا گھر پرہیزگاروں کے لئے بہتر ہے کیا تم عقل سے کام نہیں لیتے؟\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdccvi{یہاں تک کہ جب رسول مایوس ہونے لگے اور خیال کرنے لگے کہ (شاید) ان سے جھوٹ بولا گیا ہے۔ تو (اچانک) ان کے پاس ہماری مدد پہنچ گئی پس جسے ہم نے چاہا وہ نجات پا گیا اور مجرموں سے ہمارا عذاب ٹالا نہیں جا سکتا۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdccvii{یقیناً ان لوگوں کے (عروج و زوال کے) قصہ میں صاحبانِ عقل کے لئے بڑی عبرت و نصیحت ہے وہ (قرآن) کوئی گھڑی ہوئی بات نہیں ہے بلکہ یہ تو اس کی تصدیق کرنے والا ہے جو اس سے پہلے موجود ہے اور ہر چیز کی تفصیل ہے اور ایمان لانے والوں کے لئے (سراسر) ہدایت و رحمت ہے۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdccviii{\basmalahur الف، لام، میم، را۔ یہ الکتاب (قرآن) کی آیتیں ہیں اور جو کچھ آپ پر آپ کے پروردگار کی طرف سے نازل کیا گیا ہے وہ سب بالکل حق ہے لیکن اکثر لوگ (اس پر) ایمان نہیں لاتے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccix{اللہ وہی تو ہے جس نے آسمانوں کو بلند کیا ہے بغیر ایسے ستونوں کے جو تم کو نظر آتے ہوں پھر وہ عرش (اقتدار) پر متمکن ہوا۔ اور سورج و چاند کو (اپنے قانون قدرت کا) پابند بنایا (چنانچہ) ہر ایک معینہ مدت تک رواں دواں ہے وہی (اس کارخانۂ قدرت کے) ہر کام کا انتظام کر رہا ہے اور اپنی قدرت کی نشانیاں کھول کھول کر بیان کرتا ہے تاکہ تم اپنے پروردگار کی بارگاہ میں حاضر ہونے کا یقین کرو۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccx{اور وہی ہے جس نے زمین کو پھیلایا اور اس میں مضبوط پہاڑ بنا دیے اور نہریں جاری کر دیں اور اس میں ہر ایک پھل کے جوڑے دو قسم کے پیدا کر دیئے وہ رات (کی تاریکی) سے دن (کی روشنی) کو ڈھانپ دیتا ہے بے شک ان سب چیزوں میں غور و فکر کرنے والوں کے لئے بڑی نشانیاں ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccxi{اور خود زمین میں مختلف ٹکڑے آس پاس واقع ہیں (پھر ان میں) انگوروں کے باغ ہیں (غلہ کی) کھیتیاں ہیں اور کھجور کے درخت ہیں کچھ ایسے جو ایک ہی جڑ سے کئی درخت نکلے ہیں اور کچھ وہ جو ایسے نہیں ہیں سب ایک ہی پانی سے سیراب کئے جاتے ہیں مگر ہم (ذائقہ میں) بعض کو بعض پر برتری دیتے ہیں۔ یقیناً ان امور میں ان لوگوں کیلئے بڑی نشانیاں ہیں جو عقل سے کام لیتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdccxii{(اے مخاطب) اگر تمہیں تعجب کرنا ہے تو تعجب کے قابل ان (کفار) کا یہ قول ہے کہ جب ہم (مر کر) خاک ہو جائیں گے تو کیا ہم از سر نو پیدا ہوں گے؟ یہی وہ لوگ ہیں جنہوں نے اپنے پروردگار کا انکار کیا اور یہ ہیں جن کی گردنوں میں طوق پڑے ہوں گے اور یہی جہنمی ہیں جو ہمیشہ ہمیشہ اس میں رہیں گے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdccxiii{اور (اے رسول(ص)) یہ لوگ آپ سے نیکی (مغفرت) سے پہلے برائی (عذاب) کے لئے جلدی کرتے ہیں حالانکہ ان سے پہلے (ایسے لوگوں پر) خدائی سزاؤں کے نمونے گزر چکے ہیں اور آپ کا پروردگار لوگوں کو ان کے ظلم و زیادتی کے باوجود بڑا بخشنے والا ہے اور یقیناً آپ کا پروردگار سخت سزا دینے والا بھی ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdccxiv{اور کافر لوگ کہتے ہیں ان (پیغمبر اسلام(ص)) پر ان کے پروردگار کی طرف سے کوئی نشانی (ہماری مرضی کے مطابق) کیوں نہیں اتاری جاتی؟ حالانکہ تم تو بس (اللہ کے عذاب سے) ڈرانے والے ہو اور ہر قوم کے لئے ایک راہنما ہوتا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdccxv{اللہ ہی جانتا ہے کہ ہر عورت (اپنے پیٹ میں) کیا اٹھائے پھرتی ہے؟ اور اس کو بھی (جانتا ہے) جو کچھ رحموں میں کمی یا بیشی ہوتی رہتی ہے اور اس کے نزدیک ہر چیز کی ایک مقدار مقرر ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdccxvi{وہ ہر پوشیدہ اور ظاہر سب چیزوں کا جاننے والا ہے وہ بزرگ ہے (اور) عالی شان ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdccxvii{تم میں سے کوئی چپکے سے کوئی بات کرے یا اونچی آواز میں کرے اور جو رات کے وقت چھپا رہتا ہے یا دن کے وقت (صاف ظاہر) چلتا ہے اس کے علم میں سب یکساں (برابر) ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdccxviii{انسان کے آگے اور پیچھے (خدا کے مقرر کردہ) نگہبان ہیں جو اللہ کے حکم سے باری باری اس کی حفاظت کرتے ہیں بے شک اللہ کسی قوم کی اس حالت کو نہیں بدلتا جو اس کی ہے جب تک قوم خود اپنی حالت کو نہ بدلے اور جب خدا کسی قوم کو (اس کے عمل کی پاداش میں) کوئی تکلیف پہنچانا چاہتا ہے تو وہ ٹل نہیں سکتی (پہنچ کر ہی رہتی ہے)۔ اور نہ ہی اللہ کے سوا ان کا کوئی حامی و مددگار ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdccxix{وہ وہی (خدا) ہے جو ڈرانے اور امید دلانے کے لئے بجلی (کی چمک) دکھاتا ہے اور (دوش ہوا پر) بوجھل بادل پیدا کرتا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdccxx{بادل کی گرج اور فرشتے بھی اس کے خوف سے اس کی حمد و ثنا کے ساتھ اس کی تسبیح کرتے ہیں اور وہ آسمانی بجلیاں گراتا ہے اور جسے چاہتا ہے ان کی زد میں لاتا ہے درآنحالیکہ وہ لوگ اللہ کے بارے میں جھگڑ رہے ہوتے ہیں جبکہ وہ بڑا زبردست قوت والا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdccxxi{(تکلیف کے وقت) اسی کو پکارنا برحق ہے اور اسے چھوڑ کر جنہیں یہ لوگ پکارتے ہیں وہ انہیں کچھ بھی جواب نہیں دے سکتے ان کی مثال ایسی ہے جیسے کوئی (پیاسا) اپنے دونوں ہاتھ پانی کی طرف پھیلائے کہ وہ (پانی) اس کے منہ تک پہنچ جائے حالانکہ وہ اس تک پہنچنے والا نہیں ہے اور کافروں کی دعا و پکار گمراہی میں بھٹکتی پھرتی ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdccxxii{اور جو آسمانوں اور زمینوں میں ہیں وہ سب خوشی یا ناخوشی سے اللہ کو ہی سجدہ کر رہے ہیں اور ان کے سائے بھی صبح و شام (اسی کو سجدہ کناں ہیں)۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdccxxiii{(اے رسول) ان سے کہو (پوچھو) آسمانوں اور زمین کا پروردگار کون ہے؟ (خود ہی) بتائیے کہ اللہ (نیز) ان سے کہو۔ کیا تم نے اللہ کو چھوڑ کر کچھ کارساز بنا لئے ہیں؟ جو اپنے نفع و نقصان کا اختیار نہیں رکھتے کہہ دیجئے کہ کیا اندھا اور آنکھوں والا دونوں برابر ہیں اور کیا نور و ظلمت (اندھیرا اور اجالا) یکساں ہیں؟ کیا ان لوگوں نے اللہ کے کچھ ایسے شریک بنائے ہیں جنہوں نے اللہ کی طرح کچھ مخلوق خلق کی ہے؟ جس کی وجہ سے تخلیق کا یہ معاملہ ان پر مشتبہ ہوگیا ہے؟ کہہ دیجیئے کہ ہر چیز کا خالق اللہ ہی ہے وہ یگانہ ہے اور سب پر غالب ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdccxxiv{اسی (اللہ) نے آسمان سے پانی برسایا جس سے ندی نالے اپنی مقدار کے مطابق بہنے لگے اور (میل کچیل سے جھاگ اٹھا تو) سیلاب کی رو نے اس ابھرے ہوئے جھاگ کو اٹھا لیا اور جن چیزوں (دھاتوں) کو لوگ زیور یا کوئی اور چیز (برتن وغیرہ) بنانے کے لیے آگ کے اندر تپاتے ہیں ان سے بھی ایسا ہی جھاگ اٹھتا ہے اسی طرح اللہ تعالیٰ حق و باطل کی مثال بیان کرتا ہے پس جو جھاگ ہے وہ تو رائیگاں چلا جاتا ہے اور جو چیز (پانی اور دھات) لوگوں کو فائدہ پہنچاتی ہے وہ زمین میں باقی رہ جاتی ہے اسی طرح اللہ تعالیٰ سمجھانے کے لیے مثالیں بیان کرتا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdccxxv{جن لوگوں نے اپنے پروردگار کی دعوت پر لبیک کہا (اسے قبول کیا) ان کے لئے بھلائی (ہی بھلائی) ہے اور جنہوں نے اسے قبول نہیں کیا۔ تو اگر ان کو روئے زمین کی سب دولت مل جائے اور اس کے ساتھ اتنی ہی اور ان کے اختیار میں آجائے تو یہ لوگ اسے اپنے بدلے (عذاب سے بچنے کے لیے) بطور فدیہ دے دیں۔ یہی لوگ ہیں جن کا سخت حساب ہوگا۔ اور ان کا ٹھکانا جہنم ہے اور (وہ) کیا ہی برا ٹھکانا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdccxxvi{اے (رسول(ص)) کیا جو شخص یہ جانتا ہے کہ جو کچھ آپ پر آپ کے پروردگار کی طرف سے نازل کیا گیا ہے وہ حق ہے وہ اس شخص کی مانند ہو سکتا ہے جو بالکل اندھا ہے؟ نصیحت تو بس وہی قبول کرتے ہیں جو دانشمند ہوتے ہیں (اور وہی اس بات کو سمجھ سکتے ہیں)۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdccxxvii{وہ جو اللہ سے کئے ہوئے عہد وپیمان کو پورا کرتے ہیں اور عہد شکنی نہیں کرتے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdccxxviii{اور جو ان رشتوں کو جوڑے رکھتے ہیں جن کے جوڑنے کا خدا نے حکم دیا ہے (صلہ رحمی کرتے ہیں) اور اپنے پروردگار سے ڈرتے ہیں اور سخت حساب سے خائف و ترساں رہتے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdccxxix{اور جو اپنے پروردگار کی خوشنودی کی طلب میں صبر کرتے ہیں، نماز قائم کرتے ہیں اور جو کچھ ہم نے انہیں دیا ہے اس میں سے اعلانیہ اور پوشیدہ طور پر( ہماری راہ میں) خرچ کرتے ہیں اور جو برائی کو بھلائی سے دور کرتے ہیں عاقبت کا گھر انہی کیلئے ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdccxxx{یعنی ہمیشگی کے باغ ہیں۔ جن میں وہ خود بھی داخل ہوں گے۔ اور ان کے آباء و اجداد، بیویوں اور اولاد میں سے جو صالح اور نیکوکار ہوں گے۔ وہ بھی (ان کے ہمراہ داخل ہوں گے) اور فرشتے ہر دروازہ سے ان کے پاس آئیں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdccxxxi{(اور کہیں گے) سلام علیکم اس دار آخرت کا انجام کیسا اچھا ہے؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdccxxxii{اور جو لوگ اللہ کے عہد و پیمان کو مضبوط باندھ لینے کے بعد توڑتے ہیں اور جن رشتوں کے جوڑنے کا خدا نے حکم دیا ہے ان کو توڑتے ہیں اور جو زمین میں فساد پھیلاتے ہیں یہ وہ ہیں جن کے لئے لعنت ہے اور ان کے لئے برا گھر (جہنم) ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiii{اللہ جس کے رزق کو چاہتا ہے کشادہ کر دیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے اور یہ (کافر) لوگ دنیوی زندگی سے خوش ہیں حالانکہ دنیا کی زندگی آخرت کی زندگی کے مقابلہ میں صرف ناپائیدار فائدہ ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiv{اور کافر لوگ کہتے ہیں کہ (اگر یہ نبی برحق ہیں) تو ان کے پروردگار کی طرف سے ان پر (ہماری پسند کی) کوئی نشانی کیوں نہیں اتاری گئی؟ کہہ دیجیئے! اللہ جسے چاہتا ہے گمراہی میں چھوڑتا ہے اور جو اس کی طرف رجوع کرتا ہے اسے ہدایت کرتا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdccxxxv{یعنی یہ وہ لوگ ہیں جو ایمان لائے ہیں اور جن کے دل یادِ خدا سے مطمئن ہوتے ہیں یاد رکھو ذکرِ الٰہی سے ہی دلوں کو اطمینان نصیب ہوتا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvi{جو لوگ ایمان لائے اور نیک کام کئے ان کے لئے خوش حالی اور خوش انجامی ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvii{اسی طرح ہم نے آپ کو ایک ایسی قوم میں رسول بنا کر بھیجا جس سے پہلے بہت سی قومیں گزر چکی ہیں تاکہ آپ انہیں وہ (کلام و پیغام) پڑھ کر سنائیں جو ہم نے بطور وحی آپ پر اتارا ہے حالانکہ وہ لوگ اپنے مہربان خدا کا انکار کر رہے ہیں۔ آپ کہہ دیجئے! وہی میرا پروردگار ہے اس کے سوا کوئی الٰہ نہیں ہے۔ اسی پر میرا بھروسہ ہے اور اسی کی طرف بازگشت ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdccxxxviii{اور اگر کوئی ایسا قرآن ہوتا جس کے ذریعہ سے پہاڑ چلنے لگتے، یا زمین (کی مسافتیں) جلدی طے ہو جاتیں یا مردوں سے کلام کیا جا سکتا (تو وہ یہی قرآن ہوتا مگر وہ پھر بھی ایمان نہ لاتے) بلکہ یہ سب کام اللہ کے اختیار میں ہیں۔ کیا ایمان لانے والے اس بات سے مایوس نہیں ہوگئے اگر خدا (زبردستی) چاہتا تو سب لوگوں کو ہدایت کر دیتا! اور کافروں پر ان کے کرتوتوں کی پاداش میں کوئی نہ کوئی آفت آتی ہی رہے گی۔ یا ان کے گھروں کے آس پاس آتی رہے گی۔ یہاں تک کہ اللہ کے وعدہ کے (ظہور) کا وقت آجائے بے شک اللہ کبھی وعدہ خلافی نہیں کرتا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdccxxxix{(اے رسول(ص)) آپ سے پہلے بھی بہت سے پیغمبروں کا مذاق اڑایا گیا ہے مگر میں نے کافروں کو (کچھ مدت تک) ڈھیل دی پھر میں نے انہیں پکڑ لیا۔ تو (دیکھو) میرا عذاب کیسا تھا؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdccxl{کیا وہ ذات جو ہر نفس کے (نیک و بد) اعمال پر نگران ہے کہ اس نے کیا کمایا ہے؟ (وہ ان کے خود ساختہ معبودوں جیسا ہے؟) ان لوگوں نے اللہ کے کچھ شریک بنا لئے ہیں؟ اے رسول ان سے کہو کہ آخر ان کے نام تو بتاؤ یا تم اس (اللہ) کو ایسی چیز کی خبر دیتے ہو جسے وہ (ہمہ دان ہو کر بھی) زمین میں نہیں جانتا کہ کہاں ہے؟ یا یونہی یہ ظاہری الفاظ ہیں (جن کا کوئی مصداق نہیں ہے) بلکہ کافروں کے لئے ان کا مکر و فریب خوشنما بنا دیا گیا ہے اور وہ راہ (راست) سے روک دیئے گئے ہیں اور جسے اللہ گمراہی میں چھوڑ دے (اور اسے ہدایت نہ دے) تو اسے کوئی ہدایت کرنے والا نہیں ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdccxli{ان کے لئے دنیا کی زندگی میں بھی عذاب ہے اور آخرت کا عذاب تو اور بھی زیادہ سخت ہے اور کوئی نہیں ہے جو انہیں اللہ (کی گرفت) سے بچائے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdccxlii{جس جنت کا پرہیزگاروں سے وعدہ کیا گیا ہے اس کی صفت یہ ہے کہ اس کے نیچے سے نہریں جاری ہیں اس کے پھل دائمی ہیں اور اس کا سایہ بھی (لازوال) ہے یہ پرہیزگاروں کا انجام ہے اور کافروں کا انجام آتشِ دوزخ ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdccxliii{اور (اے رسول) جن کو ہم نے (پہلے) کتاب دی ہے وہ اس (کتاب) سے خوش ہوتے ہیں جو ہم نے آپ پر نازل کی ہے اور ان جماعتوں میں کچھ ایسے لوگ بھی ہیں جو اس کتاب کے بعض حصوں کا انکار کرتے ہیں آپ کہہ دیجئے کہ مجھے تو صرف یہی حکم دیا گیا ہے کہ میں اللہ کی عبادت کروں اور کسی کو اس کا شریک نہ ٹھہراؤں میں اسی کی طرف دعوت دیتا ہوں اور اسی کی طرف میری بازگشت ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdccxliv{اسی طرح ہم نے اس قرآن کو عربی فرمان کی شکل میں نازل کیا ہے اور اگر آپ اپنے پاس علم (قرآن) کے آجانے کے بعد بھی انکی خواہشات کی پیروی کریں گے تو اللہ کے مقابلہ میں آپ کا نہ کوئی سرپرست و کارساز ہوگا اور نہ کوئی بچانے والا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdccxlv{اور بے شک ہم نے آپ سے پہلے بہت سے رسول بھیجے ہیں اور ان کے لئے بیوی بچے قرار دیئے اور کسی رسول کے لیے یہ ممکن نہیں ہے کہ وہ اللہ کے حکم کے بغیر کوئی معجزہ پیش کرے ہر وقت کے لیے ایک کتاب (نوشتہ) ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdccxlvi{اللہ جو چاہتا ہے وہ (لکھا ہوا) مٹا دیتا ہے اور (جو چاہتا ہے) برقرار رکھتا ہے اور اس کے پاس ام الکتاب (اصل کتاب یعنی لوح محفوظ) ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxlvii{اور اگر ہم آپ کو کچھ وہ باتیں آنکھوں سے دکھا دیں جن کا ہم ان (کفار) سے وعدہ وعید کر رہے ہیں یا ہم (ان کے ظاہر ہونے سے پہلے) آپ کو اٹھا لیں بہرحال (ہمارا پیغام) پہنچانا آپ کا کام ہے اور حساب لینا ہمارا کام ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxlviii{کیا یہ لوگ نہیں دیکھتے کہ ہم زمین کو اس کے اطراف و جوانب سے برابر گھٹاتے چلے آتے ہیں اللہ ہی حکم دینے والا (اور فیصلہ کرنے والا) ہے اس کے حکم کو کوئی ٹالنے والا نہیں ہے اور وہ بہت جلد حساب لینے والا ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxlix{جو لوگ ان سے پہلے گزر چکے ہیں انہوں نے بڑی مخفی تدبیریں کیں سو ہر قسم کی تدبیریں اور ترکیبیں اللہ ہی کے قبضۂ قدرت میں ہیں وہی جانتا ہے کہ ہر شخص کیا کمائی کر رہا ہے اور بہت جلد کافروں کو معلوم ہو جائے گا کہ اس گھر کا انجام (بخیر) کس کا ہے؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccl{اور کافر لوگ کہتے ہیں کہ آپ رسول نہیں ہیں کہہ دیجیے کہ میرے اور تمہارے درمیان بطور گواہ اللہ کافی ہے اور وہ شخص جس کے پاس کتاب کا علم ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccli{\basmalahur الف، لام، را۔ (اے رسول(ص)) یہ ایک کتاب ہے جو ہم نے آپ پر اس لئے نازل کی ہے کہ آپ لوگوں کو ان کے پروردگار کے حکم سے (کفر کی) تاریکیوں سے نکال کر (ایمان کی) روشنی کی طرف لائیں (یعنی) اس خدا کے راستہ کی طرف جو غالب (اور) قابل تعریف ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdcclii{وہ اللہ کہ جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے سب اسی کا ہے اور تباہی و بربادی ہے سخت عذاب کی وجہ سے ان کافروں کیلئے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccliii{جو دنیا کی زندگی کو آخرت کی زندگی پر ترجیح دیتے ہیں اور جو اللہ کی راہ سے (لوگوں کو) روکتے ہیں اور چاہتے ہیں کہ اسے ٹیڑھا بنا دیں یہ لوگ بڑی دور کی گمراہی میں ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccliv{اور ہم نے (دنیا میں) جب بھی کوئی رسول بھیجا ہے تو اس کی قوم کی زبان میں تاکہ وہ ان کیلئے (پیغامِ خداوندی) کھول کر بیان کرے پس اللہ جسے چاہتا ہے (توفیق سلب کرکے) گمراہی میں چھوڑ دیتا ہے اور جسے چاہتا ہے ہدایت دے دیتا ہے وہ (سب پر) غالب ہے، بڑا حکمت والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcclv{اور بے شک ہم نے موسیٰ کو اپنی نشانیوں کے ساتھ بھیجا تھا (اور حکم دیا) کہ اپنی قوم کو (کفر کے) اندھیروں سے نکال کر (ایمان کی) روشنی میں لائے اور انہیں اللہ کے مخصوص دن یاد دلاؤ یقینا اس (یاددہانی) میں ہر بڑے صبر و شکر کرنے والے کیلئے بڑی نشانیاں ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcclvi{اور یاد کرو جب موسیٰ نے اپنی قوم سے کہا اللہ کے اس احسان کو یاد کرو جو اس نے تم پر کیا یعنی اس نے تمہیں فرعون والوں سے نجات دی جو تمہیں سخت عذاب پہنچاتے تھے اور وہ تمہارے لڑکوں کو ذبح کر ڈالتے تھے اور لڑکیوں کو زندہ چھوڑ دیتے تھے اور اس میں تمہارے پروردگار کی طرف سے تمہاری بڑی آزمائش تھی۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcclvii{اور یاد کرو جب تمہارے پروردگار نے تمہیں مطلع کر دیا تھا کہ اگر (میرا) شکر ادا کروگے تو میں تمہیں اور زیادہ دوں گا اور اگر کفرانِ نعمت (ناشکری) کروگے تو میرا عذاب بھی بڑا سخت ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcclviii{اور موسیٰ نے کہا کہ اگر تم اور روئے زمین کے سب لوگ کفر اختیار کریں تو اللہ کو اس کی کیا پروا ہے وہ یقیناً بے نیاز (اور) قابلِ ستائش ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcclix{کیا تمہیں ان لوگوں کی خبر نہیں پہنچی جو تم سے پہلے گزر چکے (یعنی) قومِ نوح(ع) اور عاد و ثمود(ع) اور وہ لوگ جو ان کے بعد ہوئے ہیں جنہیں اللہ کے سوا کوئی نہیں جانتا کہ جب ان کے رسول ان کے پاس روشن دلیلیں (معجزے) لے کر آئے تو انہوں نے اپنے ہاتھ اپنے منہ میں دبا لئے اور کہا کہ جس پیغام کے ساتھ تم بھیجے گئے ہو ہم اس کا انکار کرتے ہیں اور تم جس (دین) کی طرف ہمیں دعوت دیتے ہو ہم اس کی طرف سے تردد آمیز شک میں ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcclx{ان کے رسولوں نے کہا کیا (تمہیں) اللہ کے بارے میں شک ہے جو آسمانوں اور زمین کا خالق ہے؟ وہ تمہیں اس لئے بلا رہا ہے کہ تمہارے گناہ بخش دے اور تمہیں ایک مقررہ وقت تک مہلت دے اس پر ان لوگوں نے کہا تم نہیں ہو مگر ہمارے جیسے بشر (اور انسان) تم چاہتے ہو کہ جن کی ہمارے باپ دادا عبادت کرتے آئے ہیں ہمیں ان کی عبادت سے روکو! سو ہمارے پاس کوئی کھلا ہوا (ہمارا مطلوبہ) معجزہ لاؤ۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcclxi{ان کے رسولوں نے ان سے کہا کہ بے شک ہم نہیں ہیں مگر تمہارے جیسے بشر (اور انسان) مگر اللہ اپنے بندوں میں سے جس پر چاہتا ہے اپنا احسان فرماتا ہے اور ہمارے لئے یہ ممکن نہیں ہے کہ ہم تمہیں کوئی کھلی ہوئی دلیل (معجزہ) پیش کریں مگر اللہ کے حکم سے اور اللہ پر ہی اہل ایمان کو بھروسہ کرنا چاہیئے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcclxii{آخر ہمیں کیا ہے کہ ہم اللہ پر بھروسہ نہ کریں حالانکہ اسی نے ہمیں ہماری (زندگی کی) راہوں کی راہنمائی کی ہے اور تم ہمیں جو ایذائیں پہنچا رہے ہو ہم ان پر صبر کریں گے اور اللہ ہی پر بھروسہ کرنے والوں کو بھروسہ کرنا چاہیئے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcclxiii{اور کافروں نے اپنے رسولوں سے کہا کہ ہم تمہیں اپنی سر زمین سے نکال دیں گے یا پھر تم ہمارے مذہب میں لوٹ آؤ اور تب ان کے پروردگار نے ان پر وحی بھیجی کہ ہم ان ظالموں کو ضرور ہلاک کر دیں گے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcclxiv{اور ان کے بعد ہم تمہیں اس سر زمین میں آباد کریں گے یہ (وعدہ) ہر اس شخص کے لئے ہے جو میری بارگاہ میں کھڑے ہونے سے ڈرے اور میری تہدید سے خائف ہو۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcclxv{اور انہوں (رسولوں) نے (ہم سے) فتح مندی طلب کی (جو قبول ہوئی) اور ہر سرکش ضدی (حق کی مخالفت کرنے والا) نامراد ہوا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcclxvi{اس (نامرادی) کے پیچھے جہنم ہے اور اسے کچ لہو قسم کا پانی پلایا جائے گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcclxvii{جسے وہ گھونٹ گھونٹ کرکے پئے گا اور گلے سے اتار نہ سکے گا اور ہر طرف سے اس کے پاس موت آئے گی مگر وہ مرے گا نہیں اور (مزید برآں) اس کے پیچھے ایک اور سخت عذاب ہوگا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcclxviii{جن لوگوں نے اپنے پروردگار کا انکار کیا ان کے اعمال کی حالت اس راکھ جیسی ہے جسے سخت آندھی والے دن ہوا اڑا لے جائے جو کچھ انہوں نے کیا (کمایا) اس سے کچھ بھی ان کے ہاتھ نہ آئے گا یہی بہت بڑی گمراہی ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcclxix{کیا تم نے نہیں دیکھا کہ خدا نے آسمانوں اور زمین کو حق (و حکمت) کے ساتھ پیدا کیا ہے وہ چاہے تو تم سب کو لے جائے۔ (فنا کر دے) اور نئی مخلوق کو لے آئے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcclxx{اور یہ بات اللہ کے لئے کچھ بھی مشکل نہیں ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcclxxi{اور (قیامت کے دن) وہ سب ایک ساتھ اللہ کی بارگاہ میں حاضر ہوں گے۔ تو جو کمزور (پیروکار) ہوں گے وہ ان سے کہیں گے جو بڑے (سردار) بنے ہوئے تھے کہ ہم تو (زندگی بھر) تمہارے پیروکار تھے تو تم آج ہمیں اللہ کے عذاب سے کچھ بچا سکتے ہو؟ وہ (بڑے) کہیں گے اگر اللہ ہمیں ہدایت دیتا تو ہم بھی تمہیں ہدایت دیتے اب ہمارے لئے برابر ہے جزع فزع کریں یا صبر کریں۔ آج ہمارے لئے چھٹکارا حاصل کرنے کی کوئی سبیل نہیں ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcclxxii{اور جب (ہر قسم کا) فیصلہ ہو جائے گا تو اس وقت شیطان کہے گا کہ بے شک اللہ نے تم سے جو وعدہ کیا تھا وہ سچا تھا اور میں نے بھی تم سے وعدہ کیا تھا مگر میں نے تم سے وعدہ خلافی کی اور مجھے تم پر کوئی تسلط (زور) تو تھا نہیں سوائے اس کے کہ میں نے تمہیں (کفر اور گناہ کی) دعوت دی اور تم نے میری دعوت قبول کر لی پس تم مجھے ملامت نہ کرو (بلکہ) خود اپنے آپ کو ملامت کرو (آج) نہ میں تمہاری فریاد رسی کر سکتا ہوں۔ اور نہ تم میری فریاد رسی کر سکتے ہو اس سے پہلے (دنیا میں) جو تم نے مجھے (خدا کا) شریک بنایا تھا میں اس سے بیزار ہوں بے شک ظالموں کے لئے دردناک عذاب ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiii{جو لوگ ایمان لائے اور نیک عمل کئے وہ ان بہشتوں میں داخل کئے جائیں گے جن کے نیچے سے نہریں بہہ رہی ہوں گی اور اپنے پروردگار کے حکم سے ان میں ہمیشہ ہمیشہ رہیں گے اس میں ان کی باہمی دعا (بوقت ملاقات) سلام ہوگا۔ (سلامٌ علیکم تم پر سلامتی ہو)۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiv{کیا تم نے نہیں دیکھا کہ اللہ نے کس طرح اچھی مثال بیان کی ہے کہ کلمۂ طیبہ (پاک کلمہ) شجرۂ طیبہ (پاکیزہ) درخت کی مانند ہے۔ جس کی جڑ مضبوط ہے اور اس کی شاخ آسمان تک پہنچی ہوئی ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcclxxv{جو اپنے پروردگار کے حکم سے ہر وقت پھل دے رہا ہے اور اللہ لوگوں کے لئے مثالیں پیش کرتا ہے تاکہ وہ نصیحت حاصل کریں (اور سمجھیں)۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvi{اور کلمۂ خبیثہ (ناپاک کلمہ) کی مثال شجرۂ خبیثہ (ناپاک درخت) کی سی ہے جسے زمین کے اوپر سے اکھاڑ لیا جائے اور اس کے لئے ثبات و قرار نہ ہو۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvii{اللہ ایمان والوں کو قولِ ثابت پر ثابت قدم رکھتا ہے دنیا کی زندگی میں بھی اور آخرت میں بھی اور ظالموں کو گمراہی میں چھوڑ دیتا ہے اور اللہ جو چاہتا ہے وہ کرتا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcclxxviii{کیا تم نے ان لوگوں کی طرف نہیں دیکھا جنہوں نے اللہ کی عطا کردہ نعمت کو کفرانِ نعمت سے بدل دیا اور اپنی قوم کو ہلاکت کے گھر میں یعنی دوزخ میں جا اتارا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcclxxix{جس میں وہ داخل ہوں گے اور وہ (کیسا) برا ٹھکانا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcclxxx{اور انہوں نے اللہ کے لئے کچھ ہمسر (شریک) بنا لئے ہیں تاکہ (لوگوں کو) اس کے راستے سے بھٹکائیں (اے رسول) آپ کہہ دیجیے کہ (چندے) عیش کر لو آخر یقینا تمہاری بازگشت آتش دوزخ کی طرف ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxi{آپ میرے ان بندوں سے کہہ دیجیے جو ایمان لائے ہیں کہ نماز قائم کریں اور جو کچھ ہم نے انہیں دیا ہے اس سے پوشیدہ اور علانیہ خرچ کریں اس سے پہلے کہ وہ دن آئے کہ جس میں نہ خرید و فروخت ہوگی اور نہ مخلصانہ دوستی ہوگی۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxii{اللہ وہی ہے جس نے آسمانوں اور زمین کو پیدا کیا اور پھر کشتی کو تمہارے لئے مسخر کر دیا تاکہ وہ اس کے حکم سے سمندر میں چلے اور دریاؤں کو بھی تمہارے لئے مسخر کر دیا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiii{اور تمہارے لئے سورج و چاند کو (بھی) مسخر کر دیا جو برابر چلے جا رہے ہیں اور رات اور دن کو بھی تمہارے لئے مسخر کر دیا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiv{اور جس نے تمہیں ہر چیز میں سے دیا جو تم نے مانگا اور اگر تم اللہ کی نعمتوں کو شمار کرنا چاہو تو شمار نہیں کر سکتے بے شک انسان بڑا ظالم اور بڑا ناشکرا ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxv{اور وہ وقت یاد کرو جب ابراہیم نے (بارگاہ ایزدی میں) دعا کی تھی اے میرے پروردگار! اس شہر (مکہ) کو امن کی جگہ اور مجھے اور میری اولاد کو اس بات سے بچا کہ ہم بتوں کی پرستش کریں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvi{اے میرے پروردگار ان (بتوں) نے بہت سے لوگوں کو گمراہ کر دیا ہے سو جو میری پیروی کرے گا وہ مجھ سے ہوگا اور جو میری نافرمانی کرے تو یقیناً تو بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvii{اے ہمارے پروردگار میں نے اپنی کچھ اولاد کو تیرے محترم گھر کے پاس بے زراعت میدان میں آباد کیا ہے اے ہمارے مالک تاکہ (وہ یہاں) نماز قائم کریں اب تو کچھ لوگوں کے دلوں کو ایسا کر دے کہ وہ ان کی طرف مائل ہوں اور ان کو پھلوں سے رزق عطا فرما تاکہ وہ (تیرا) شکر ادا کریں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxviii{اے ہمارے پروردگار! بے شک جو کچھ ہم چھپاتے ہیں تو اسے بھی جانتا ہے اور جو ظاہر کرتے ہیں اسے بھی اور زمین و آسمان کی کوئی چیز اللہ سے پوشیدہ نہیں ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxix{ساری ستائش اللہ کے لئے ہے جس نے باوجود بڑھاپے کے مجھے اسماعیل(ع) و اسحاق(ع) (دو بیٹے) عطا فرمائے بے شک میرا پروردگار دعا کا بڑا سننے والا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxc{اے میرے پروردگار! مجھے نماز کا قائم کرنے والا بنا اور میری اولاد کو بھی۔ اے ہمارے پروردگار اور میری دعا کو قبول فرما۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxci{اے ہمارے پروردگار! مجھے اور میرے والدین کو اور سب ایمان لانے والوں کو بخش دے جس دن حساب قائم ہوگا (لیا جائے گا)۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxcii{(اے رسول(ص)) جو کچھ (یہ) ظالم لوگ کر رہے ہیں تم اللہ کو اس سے غافل نہ سمجھو۔ وہ تو انہیں اس دن کے لئے مہلت دے رہا ہے جس میں (شدتِ خوف و حیرت سے) آنکھیں کھلی کی کھلی رہ جائیں گی۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccxciii{وہ تیزی سے دوڑ رہے ہوں گے اپنے سر اوپر اٹھاتے ہوئے اس عالم میں کہ ان کی نگاہ خود ان کی طرف نہیں پلٹے گی اور ان کے دل (خوف و دہشت کے سوا ہر خیال سے) خالی ہو رہے ہوں گے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccxciv{(اے رسول) لوگوں کو اس دن سے ڈراؤ جب ان پر عذاب آئے گا تو ظالم لوگ کہیں گے اے ہمارے رب تھوڑی سی مدت کے لئے ہمیں مہلت دے دے ہم تیری دعوت پر لبیک کہیں گے اور (تیرے) رسولوں کی پیروی کریں گے (انہیں جواب دیا جائے گا) کیا تم نے اس سے پہلے قسمیں نہیں کھائی تھیں کہ تمہیں کبھی زوال نہ ہوگا۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdccxcv{حالانکہ تم انہی لوگوں کے مسکنوں میں آباد تھے جنہوں نے اپنے اوپر ظلم کیا تھا اور تم پر واضح ہوگیا تھا کہ ہم نے ان کے ساتھ کیا سلوک کیا تھا؟ اور ہم نے (تمہیں سمجھانے کے لئے) مثالیں بھی بیان کر دیں تھیں۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdccxcvi{اور انہوں نے اپنی ساری تدبیریں کیں (اور چالیں چلیں) اور اللہ کے پاس ان کی ہر تدبیر اور چال (کا جواب) ہے اگرچہ ان کی تدبیریں و ترکیبیں ایسی تھیں کہ ان سے پہاڑ بھی اپنی جگہ سے ہٹ جائیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdccxcvii{خبردار! یہ خیال نہ کرنا کہ اللہ نے اپنے رسولوں سے جو وعدہ کیا ہے وہ اس کے خلاف کرے گا بے شک اللہ (سب پر) غالب ہے (اور) انتقام لینے والا ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdccxcviii{(اور یہ اس دن ہوگا) جس دن یہ زمین دوسری قسم کی زمین سے بدل دی جائے گی اور آسمان بھی (بدل جائیں گے) اور سب لوگ اللہ کی بارگاہ میں حاضر ہو جائیں گے جو ایک ہے اور سب پر غالب ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdccxcix{اور تم اس دن مجرموں کو دیکھوگے کہ زنجیروں میں جکڑے ہوئے ہوں گے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccc{ان کے کرتے تارکول کے ہوں گے اور ان کے چہروں کو آگ ڈھانپ رہی ہوگی۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdccci{یہ اس لئے ہوگا کہ اللہ ہر شخص کو اس کے کئے کا بدلہ دے گا بے شک اللہ بہت جلد حساب لینے والا ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccii{یہ سب انسانوں کے لئے ایک پیغام ہے تاکہ انہیں اس کے ذریعہ سے ڈرایا جائے اور یہ کہ انہیں معلوم ہو جائے کہ الٰہ بس ایک ہی ہے نیز یہ کہ عقل والے لوگ اس سے نصیحت حاصل کریں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccciii{\basmalahur الف، لام، را۔ یہ کتاب (الٰہی) یعنی روشن قرآن کی آیتیں ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccciv{جن لوگوں نے کفر اختیار کیا ہے وہ بہت تمنا کریں گے کہ کاش وہ مسلمان ہوتے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdcccv{(اے رسول(ص)) انہیں چھوڑ دو کہ وہ کھائیں (پئیں) اور عیش و آرام کریں اور (بے شک جھوٹی) امید انہیں غفلت میں رکھے عنقریب انہیں (سب کچھ) معلوم ہو جائے گا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdcccvi{اور ہم نے کبھی کوئی بستی ہلاک نہیں کی مگر یہ کہ اس کے لئے وقتِ معلوم لکھا ہوا تھا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcccvii{کوئی قوم اپنے مقررہ وقت سے نہ آگے بڑھ سکتی ہے اور نہ پیچھے ہٹ سکتی ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcccviii{اور وہ (کفار) کہتے ہیں: اے وہ جس پر ذکر (قرآن) اتارا گیا ہے یقینا تم دیوانہ ہو۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcccix{اگر تم سچے ہو تو پھر ہمارے پاس فرشتوں کو کیوں نہیں لے آتے؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcccx{ہم فرشتوں کو نہیں اتارتے مگر (صحیح موقع پر فیصلہ) حق کے ساتھ اور پھر لوگوں کو مہلت نہیں دی جاتی۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcccxi{بے شک ہم نے ہی ذکر (قرآن) اتارا ہے اور ہم ہی اس کے محافظ ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcccxii{اور ہم نے آپ سے پہلے مختلف جماعتوں میں رسول بھیجے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcccxiii{اور ان کے پاس کوئی ایسا رسول نہیں آیا جس کے ساتھ انہوں نے مذاق نہ کیا ہو۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcccxiv{اسی طرح ہم اس (ذکر) کو مجرموں کے دلوں میں ڈال دیتے ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcccxv{(مگر) وہ اس (ذکر) پر ایمان نہیں لاتے اور جو پہلے گزر چکے ہیں ان کا طریقہ بھی یہی رہ چکا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcccxvi{اور اگر ہم ان پر آسمان کا ایک دروازہ کھول دیں جس سے وہ دن دہاڑے چڑھنے لگیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcccxvii{تو پھر بھی وہ یہی کہیں گے کہ ہماری آنکھوں کو مدہوش کر دیا گیا ہے بلکہ ہم پر جادو کر دیا گیا ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcccxviii{اور بے شک ہم نے آسمان میں بہت سے برج بنا دیئے اور اس (آسمان) کو دیکھنے والوں کے لئے آراستہ کر دیا ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcccxix{اور ہم نے اسے ہر مردود شیطان سے محفوظ کر دیا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcccxx{مگر یہ کہ کوئی (شیطان) چوری چھپے کچھ سن لے تو (اس صورت میں) ایک چمکتا ہوا شعلہ اس کا پیچھا کرتا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcccxxi{اور ہم نے زمین کو پھیلا دیا اور اس میں پہاڑ گاڑ دیے اور اس میں ہر قسم کی چیزیں نپی تلی اگائیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcccxxii{اور ہم نے اس میں تمہارے لئے بھی معاش کے وسائل بنائے اور ان کیلئے بھی جن کے روزی رساں تم نہیں ہو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiii{اور کوئی چیز ایسی نہیں ہے جس کے خزانے ہمارے پاس نہ ہوں اور ہم اسے نہیں اتارتے مگر ایک معیّن مقدار میں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiv{اور ہم ہواؤں کو باردار بنا کر بھیجتے ہیں پھر آسمان سے پانی برساتے ہیں پھر وہ پانی ہم تمہیں پلاتے ہیں حالانکہ تم اسکے خزانہ دار نہیں ہو۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcccxxv{اور بلاشبہ ہم ہی زندہ کرتے ہیں اور ہم ہی مارتے ہیں اور ہم ہی (سب کے) وارث ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvi{اور یقیناً ہم ان کو بھی جانتے ہیں جو تم سے پہلے ہو گزرے اور ان کو بھی جانتے ہیں جو بعد میں آنے والے ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvii{بے شک تمہارا پروردگار (بروزِ قیامت) سب کو جمع کرے گا وہ بڑا حکمت والا، بڑا علم والا ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcccxxviii{اور بلاشبہ ہم نے انسان کو سڑے ہوئے گارے کی کھنکھناتی مٹی سے پیدا کیا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcccxxix{اور اس سے پہلے ہم نے جان کو بے دھواں تیز گرم آگ سے پیدا کیا۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcccxxx{(وہ وقت یاد کرو) جب آپ کے پروردگار نے فرشتوں سے کہا کہ میں سڑے ہوئے گارے کی کھنکھناتی ہوئی مٹی سے ایک بشر پیدا کرنے والا ہوں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxi{پس جب میں اسے مکمل کر لوں اور اس میں اپنی (خاص) روح پھونک دوں تو تم اس کے سامنے سجدہ میں گر جاؤ۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxii{چنانچہ سب فرشتوں نے سجدہ کیا۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiii{سوائے ابلیس کے کہ اس نے سجدہ کرنے والوں کے ساتھ ہونے سے انکار کیا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiv{ارشاد ہوا: اے ابلیس! تجھے کیا ہوا کہ تو نے سجدہ کرنے والوں کا ساتھ نہ دیا؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxv{اس نے کہا میں ایسا نہیں ہوں کہ ایسے بشر کو سجدہ کروں جسے تو نے سڑے ہوئے گارے کی کھنکھناتی ہوئی مٹی سے پیدا کیا ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvi{ارشاد ہوا (یہاں سے) نکل جا کہ تو مردود (راندہ ہوا) ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvii{اور روزِ جزا (قیامت) تک تجھ پر لعنت ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxviii{اس نے کہا کہ اے میرے رب! مجھے اس دن تک مہلت دے جب لوگ دوبارہ اٹھائے جائیں گے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxix{فرمایا بے شک تو مہلت پانے والوں میں سے ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcccxl{(جنہیں) وقتِ معلوم تک مہلت دی گئی ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcccxli{اس نے کہا اے میرے رب! چونکہ تو نے مجھے گمراہ کیا ہے تو میں بھی زمین میں ان (بندوں) کے لئے گناہوں کو خوشنما بناؤں گا اور سب کو گمراہ کروں گا۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcccxlii{سوائے تیرے مخلص بندوں کے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcccxliii{فرمایا یہ سیدھا راستہ ہے مجھ تک پہنچنے والا۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcccxliv{جو میرے خاص بندے ہیں ان پر تیرا کوئی قابو نہ ہوگا سوائے ان گمراہوں کے جو تیری پیروی کریں گے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcccxlv{اور بے شک جہنم ان سب کی وعدہ گاہ ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvi{اس کے سات دروازے ہیں (اور) ہر دروازے کے لئے ان (لوگوں) میں سے ایک حصہ ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvii{بے شک پرہیزگار لوگ بہشتوں اور چشموں میں ہوں گے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcccxlviii{(ان سے کہا جائے گا) کہ تم سلامتی اور امن و امان کے ساتھ ان میں داخل ہو جاؤ۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcccxlix{اور ہم ان کے سینوں سے ہر قسم کی کدورت نکال دیں گے اور وہ بھائیوں کی طرح تختوں پر آمنے سامنے بیٹھے ہوں گے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcccl{ان کے اندر انہیں کوئی تکلیف و زحمت چھوئے گی بھی نہیں اور نہ ہی وہ وہاں سے نکالے جائیں گے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcccli{(اے رسول) میرے بندوں کو آگاہ کر دو کہ میں بڑا بخشنے والا، بڑا رحم کرنے والا ہوں۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccclii{اور یہ بھی (بتا دو) کہ میرا عذاب بھی بڑا دردناک عذاب ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcccliii{اور انہیں ابراہیم(ع) کے مہمانوں کا واقعہ بھی سنا دو۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccliv{جبکہ وہ ان کے پاس آئے اور سلام کیا اور انہوں نے (جوابِ سلام کے بعد) کہا ہم کو تم سے ڈر لگ رہا ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccclv{(مہمانوں) نے کہا کہ ڈرئیے نہیں ہم آپ کو ایک صاحبِ علم بچہ کی (ولادت کی) بشارت دیتے ہیں۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdccclvi{ابراہیم(ع) نے کہا تم مجھے اس حال میں بشارت دیتے ہو کہ مجھ پر بڑھاپا آچکا ہے یہ کس چیز کی بشارت ہے جو تم مجھے دیتے ہو؟\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdccclvii{انہوں نے کہا ہم آپ کو بالکل سچی بشارت دے رہے ہیں تو آپ ناامید ہونے والوں میں سے نہ ہوں۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdccclviii{ابراہیم(ع) نے کہا اپنے پروردگار کی رحمت سے تو گمراہوں کے سوا کون مایوس ہوتا ہے؟\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdccclix{(پھر) کہا اے اللہ کے فرستادو آخر تمہیں کیا مہم درپیش ہے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdccclx{انہوں نے کہا کہ ہم ایک مجرم قوم کی طرف بھیجے گئے ہیں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdccclxi{سوا لوط(ع) کے گھر والوں کے کہ ہم ان سب کو بچا لیں گے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdccclxii{بجز اس کی بیوی کے اس کی نسبت ہم نے یہ طے کیا ہے کہ وہ پیچھے رہ جانے والوں میں سے ہوگی۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdccclxiii{پس جب اللہ کے فرستادہ خاندانِ لوط (ع) کے پاس آئے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdccclxiv{تو لوط نے کہا کہ تم تو اجنبی لوگ معلوم ہوتے ہو۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdccclxv{انہوں نے کہا (نہیں) بلکہ ہم تمہارے پاس وہ چیز (عذاب) لے کر آئے ہیں جس میں (یہ) لوگ شک کیا کرتے تھے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdccclxvi{اور ہم آپ کے پاس حق (عذاب) لے کر آئے ہیں اور بلاشبہ ہم بالکل سچے ہیں۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdccclxvii{تو آپ رات کے کسی حصہ میں اپنے اہل و عیال کو لے کر نکل جائیں اور خود آپ ان کے پیچھے پیچھے چلیں اور آپ میں سے کوئی پیچھے مڑ کر نہ دیکھے اور جدھر جانے کا آپ کو حکم دیا گیا ہے ادھر ہی چلے جائیں۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdccclxviii{اور ہم نے ان (لوط(ع)) کو بذریعۂ وحی اس فیصلہ سے آگاہ کر دیا کہ صبح ہوتے ہوتے ان کی جڑ بالکل کاٹ دی جائے گی۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdccclxix{اور شہر والے (نوجوان اور خوبصورت مہمانوں کو دیکھ کر) خوشیاں مناتے ہوئے آگئے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdccclxx{(لوط(ع) نے) کہا یہ لوگ میرے مہمان ہیں تم میری فضیحت نہ کرو۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdccclxxi{اور اللہ سے ڈرو اور مجھے رسوا نہ کرو۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdccclxxii{انہوں نے کہا کہ کیا ہم نے آپ کو دنیا بھر کے لوگوں (کو مہمان کرنے) سے منع نہیں کر دیا تھا۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiii{آپ نے کہا اگر تم نے کچھ کرنا ہے تو پھر یہ میری (قوم کی) بیٹیاں موجود ہیں۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiv{آپ کی جان کی قسم! یہ لوگ اپنے نشہ میں بالکل اندھے ہو رہے تھے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdccclxxv{آخرکار سورج نکلتے نکلتے انہیں ایک ہولناک آواز (چیخ) نے آلیا۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvi{پس ہم نے اس (بستی) کو تہہ و بالا کر دیا (اوپر کا طبقہ نیچے کر دیا)۔ اور ان پر پکی ہوئی مٹی کے پتھروں کی بارش کر دی۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvii{بے شک اس (واقعہ) میں حقیقت کی پہچان رکھنے والوں کے لئے بڑی نشانیاں ہیں۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdccclxxviii{اور وہ (بستی) ایک عام گزرگاہ پر واقع ہے جو اب تک قائم ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdccclxxix{بے شک اس (واقعہ) میں اہلِ ایمان کے لئے بڑی نشانی ہے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdccclxxx{اور بے شک ایک (گھنے جنگل) والے بڑے ظالم تھے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxi{ہم نے ان سے انتقام لیا اور یہ دونوں (بستیاں) شارعِ عام پر واقع ہیں۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxii{اور بے شک حجر کے لوگوں نے رسولوں کو جھٹلایا۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiii{اور ہم نے انہیں نشانیاں عطا کیں مگر وہ ان سے روگردانی ہی کرتے رہے۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiv{اور وہ پہاڑوں کو تراش کر گھر بناتے تھے تاکہ امن و اطمینان سے رہیں۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxv{پس صبح کے وقت انہیں ایک ہولناک آواز نے آپکڑا۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvi{سو جو کچھ انہوں نے کمایا تھا وہ ان کے کام نہ آیا۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvii{اور ہم نے آسمانوں اور زمین کو نیز جو کچھ ان کے درمیان ہے اس کو پیدا نہیں کیا مگر حق و حکمت کے ساتھ اور قیامت یقینا آنے والی ہے پس (اے رسول) آپ شائستہ طریقہ سے درگزر کریں۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxviii{بے شک آپ کا پروردگار ہی بڑا پیدا کرنے والا (اور) بڑا جاننے والا ہے۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxix{اور بلاشبہ ہم نے آپ کو دہرائی جانے والی سات آیتیں عطا کی ہیں اور قرآنِ عظیم بھی۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdcccxc{آپ اپنی آنکھ اٹھا کر بھی ان چیزوں کی طرف نہ دیکھیں جن سے ہم نے مختلف قسم کے لوگوں (کافروں) کو بہرہ مند کیا ہے اور نہ ہی ان کے بارے میں غمگین ہوں اور اہلِ ایمان کے لئے اپنے بازو پھیلا دیں (ان کے ساتھ شفقت سے پیش آئیں)۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdcccxci{اور کہہ دیجیے کہ میں تو عذاب سے کھلا ہوا ڈرانے والا ہوں۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdcccxcii{(اے رسول) جس طرح ہم نے تقسیم کرنے والوں پر اپنا کلام نازل کیا تھا۔ (اسی طرح) آپ پر بھی نازل کیا ہے۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdcccxciii{(لیکن یہ وہ لوگ تھے) جنہوں نے قرآن کے ٹکڑے ٹکڑے کر دئیے۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdcccxciv{آپ کے پروردگار کی قسم ہم ان سے اس کی بابت ضرور سوال کریں گے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdcccxcv{جو کچھ وہ کیا کرتے تھے۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvi{پس جس چیز کا آپ کو حکم دیا گیا ہے اس کا واضح اعلان کر دیں اور مشرکوں سے اعراض کریں (ان کی کچھ پروا نہ کریں)۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvii{جو آپ کا مذاق اڑاتے ہیں ہم ان کے لئے کافی ہیں۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcccxcviii{جو خدا کے ساتھ دوسرا الٰہ قرار دیتے ہیں انہیں عنقریب (اپنا انجام) معلوم ہو جائے گا۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcccxcix{اور بے شک ہم جانتے ہیں کہ جو کچھ (یہ لوگ) کہتے رہتے ہیں اس سے آپ کا دل تنگ ہوتا ہے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcm{تو اپنے پروردگار کی حمد کے ساتھ اس کی تسبیح کریں اور سجدہ کرنے والوں میں سے ہو جائیں۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcmi{اور اس وقت تک برابر اپنے پروردگار کی عبادت کرتے رہیں جب تک کہ تمہارے پاس موت نہ آجائے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcmii{\basmalahur اللہ کا حکم (عذاب) آگیا ہے پس تم اس کے لئے جلدی نہ کرو وہ پاک اور برتر ہے ان چیزوں سے جن کو وہ اس کا شریک ٹھہراتے ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcmiii{وہ اپنے بندوں میں سے جس پر چاہتا ہے اپنے حکم سے فرشتوں کو روح کے ساتھ نازل کر دیتا ہے کہ لوگوں کو خبردار کر دو (ڈراؤ) کہ میرے سوا کوئی الٰہ نہیں ہے پس مجھ ہی سے ڈرو۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcmiv{اس نے آسمانوں اور زمین کو حق کے ساتھ پیدا کیا ہے وہ جن چیزوں کو اس کا شریک قرار دیتے ہیں وہ ان سے بلند و بالا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcmv{اس نے انسان کو نطفہ (پانی کی ایک بوند) سے پیدا کیا پھر وہ ایک دم کھلم کھلا جھگڑالو بن گیا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcmvi{اور اسی نے تمہارے لئے چوپائے پیدا کئے جن میں تمہارے لئے گرم لباس بھی ہے اور دوسرے فائدے بھی اور انہی سے بعض کا تم گوشت کھاتے ہو۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcmvii{اور ان (چوپاؤں) میں تمہارے لئے زیب و زینت بھی ہے جب شام کو واپس لاتے ہو اور صبح جب (چراگاہ کی طرف) لے جاتے ہو (اس وقت ان کا منظر کیسا خوش آئند ہوتا ہے)۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcmviii{اور یہ (جانور) تمہارے بوجھوں کو اٹھاتے ہیں۔ اور ان (دور دراز) شہروں تک پہنچاتے ہیں جن تک تم بڑی جانکاہی کے بغیر نہیں پہنچ سکتے تھے بے شک تمہارا پروردگار تمہارا شفیق و بڑا مہربان ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcmix{اور اس نے گھوڑے، خچر اور گدھے پیدا کئے تاکہ تم ان پر سوار ہو اور اپنے لئے انہیں زینت بناؤ اور خدا وہ کچھ پیدا کرتا ہے (اور کرے گا) جو تم نہیں جانتے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcmx{اور سیدھے راستہ کی طرف راہنمائی کرنا اللہ کی ذمہ داری ہے اور ان میں کچھ راستے کج بھی ہوتے ہیں اور اگر اللہ تعالیٰ (زبردستی) چاہتا تو تم سب کو ہدایت دے دیتا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcmxi{وہ وہی ہے جس نے تمہارے (فائدے کے لئے) آسمان سے پانی برسایا جس سے تم پیتے بھی ہو اور جس سے وہ درخت (اور سبزے اگتے ہیں) جن میں تم (اپنے جانور) چراتے ہو۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcmxii{اسی (پانی) سے وہ (خدا) تمہارے لئے کھیتی، زیتون، کھجور، انگور اور ہر قسم کے پھل پیدا کرتا ہے بے شک اس میں غور و فکر کرنے والوں کے لئے ایک بڑی نشانی ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcmxiii{اور اسی نے تمہارے لئے رات، دن، سورج اور چاند کو مسخر کر دیا ہے (تمہارے کام میں لگا دیا ہے) اور ستارے بھی مسخّر ہیں (یہ سب تسخیر) اسی کے حکم سے ہے بے شک اس میں عقل سے کام لینے والوں کے لئے بہت سی نشانیاں موجود ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcmxiv{اور اس نے تمہارے لئے زمین میں جو رنگ برنگ کی چیزیں پیدا کی ہیں اور مسخر کی ہیں اس میں سوچنے سمجھنے اور نصیحت حاصل کرنے والوں کے لئے ایک بڑی نشانی ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcmxv{اور وہ وہی ہے جس نے سمندر (کو تمہارا) مسخر کر دیا تاکہ تم اس سے تروتازہ گوشت کھاؤ اور اس سے زیور کی چیزیں (موتی وغیرہ) نکالو جنہیں تم (آرائش کیلئے) پہنتے ہو اور تم دیکھتے ہو کہ اس میں کشتیاں پانی کو چیرتی پھاڑتی ہوئی چلی جاتی ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcmxvi{اور اس (خدا) نے زمین میں بھاری بھر کم پہاڑوں کے لنگر ڈال دیئے ہیں تاکہ وہ تمہیں لے کر کہیں ڈھلک نہ جائے اور اس نے نہریں رواں دواں کر دیں اور راستے بنائے تاکہ تم (خشکی و تری میں) راہ پاؤ (اور منزل مقصود تک پہنچ جاؤ)۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcmxvii{اور اس نے (قطعِ مسافت اور راستہ بتانے کے لئے) مختلف علامتیں مقرر کیں اور ستاروں سے بھی لوگ راستہ پاتے ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcmxviii{کیا وہ (خدا) جو پیدا کرتا ہے، اس کی مانند ہے جو کچھ پیدا نہیں کرتا؟ کیا تم اتنا بھی غور نہیں کرتے اور نصیحت حاصل نہیں کرتے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcmxix{اور اگر تم اللہ کی نعمتوں کو شمار کرنا چاہو تو شمار نہیں کر سکتے بےشک اللہ بڑا ہی بخشنے والا اور بڑا مہربان ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcmxx{اللہ وہ (سب کچھ) جانتا ہے جو کچھ تم چھپاتے ہو اور جو کچھ ظاہر کرتے ہو۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcmxxi{اور اللہ کو چھوڑ کر جن کو یہ (مشرک) لوگ پکارتے ہیں وہ کوئی چیز پیدا نہیں کر سکتے (بلکہ) وہ خود پیدا کئے ہوئے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcmxxii{وہ مردہ ہیں زندہ نہیں ہیں۔ انہیں تو یہ بھی خبر نہیں ہے کہ انہیں یا ان کے پجاریوں کو (دوبارہ) کب اٹھایا جائے گا؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcmxxiii{تمہارا الٰہ بس ایک ہی الٰہ ہے سو جو لوگ آخرت پر ایمان نہیں رکھتے ان کے دل منکر ہیں اور وہ بڑے مغرور ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcmxxiv{یقینا اللہ وہ سب کچھ جانتا ہے جو وہ (دلوں میں) چھپاتے ہیں اور اسے بھی جو وہ ظاہر کرتے ہیں بے شک وہ تکبر کرنے والوں کو پسند نہیں کرتا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcmxxv{اور جب ان سے کہا (پوچھا) جاتا ہے کہ تمہارے پروردگار نے کیا نازل کیا ہے؟ تو وہ کہتے ہیں (کچھ بھی نہیں) بس اگلے لوگوں کی (فرسودہ) داستانیں ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcmxxvi{اس کا انجام یہ ہے کہ قیامت کے دن یہ اپنے گناہوں کا بھی پورا پورا بوجھ اٹھائیں گے اور کچھ بوجھ ان کا بھی اٹھائیں گے جنہیں یہ بے سمجھے گمراہ کر رہے ہیں (دیکھو) کیا ہی برا بوجھ ہے وہ جو یہ اٹھا رہے ہیں؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcmxxvii{جو لوگ ان سے پہلے گزر چکے ہیں انہوں نے بھی (دعوتِ حق کے خلاف) مکاریاں کی تھیں تو اللہ تعالیٰ نے ان کی (مکاریوں والی) عمارت بنیاد سے اکھیڑ دی اور اس کی چھت اوپر سے ان پر آپڑی اور ان پر اس طرف سے عذاب آیا جدھر سے ان کو وہم و گمان بھی نہ تھا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcmxxviii{پھر قیامت کے دن وہ (اللہ) انہیں ذلیل و خوار کرے گا اور کہے گا کہ (بتاؤ) کہاں ہیں وہ میرے شریک جن کے بارے میں تم (اہلِ حق سے) لڑا جھگڑا کرتے تھے (اس وقت) وہ لوگ کہیں گے جن کو (حقیقت کا) علم دیا گیا تھا کہ آج کے دن رسوائی اور برائی ان کافروں کے لئے ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcmxxix{کہ جن کی روحیں فرشتوں نے اس حال میں قبض کی تھیں کہ وہ اپنے اوپر ظلم کر رہے تھے اس وقت انہوں نے (سپر ڈال دی تھی اور) صلح کی پیشکش کرتے ہوئے کہا تھا کہ ہم تو کوئی برائی نہیں کرتے تھے (ان سے کہا گیا) ہاں (تم نے ضرور برائی کی تھی) تم لوگ جو کچھ کرتے رہے ہو اللہ اس سے بخوبی واقف ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcmxxx{پس اب جہنم کے دروازوں میں سے (جہنم میں) داخل ہو جاؤ اب تمہیں ہمیشہ کے لئے اسی میں رہنا ہے پس کیا ہی برا ٹھکانہ ہے تکبر کرنے والوں کا۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcmxxxi{اور جب صاحبانِ تقویٰ سے کہا جاتا ہے کہ تمہارے پروردگار نے کیا نازل کیا ہے؟ تو وہ کہتے ہیں کہ سراسر خیر و خوبی نازل کی ہے جن لوگوں نے اس دنیا میں نیکی اور بھلائی کی ان کے لئے یہاں بھی بھلائی ہے اور آخرت کا گھر تو یقیناً اور بھی بہتر ہے اور متقیوں کا گھر کیا ہی خوب ہے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcmxxxii{(یعنی) وہاں ہمیشہ رہنے والے باغات ہیں جن میں وہ داخل ہوں گے جن کے نیچے نہریں جاری ہوں گی وہاں وہ جو کچھ چاہیں گے ان کو مل جائے گا خدا اسی طرح پرہیزگاروں کو جزا دیتا ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiii{وہ متقی جن کی روحیں اس حال میں فرشتے قبض کرتے ہیں کہ وہ (کفر و شرک) سے پاک و صاف ہوتے ہیں (اس وقت) فرشتے کہتے ہیں تم پر سلام ہو بہشت میں داخل ہو جاؤ ان اعمال کی بدولت جو تم کیا کرتے تھے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiv{(اے رسول) یہ (منکرین) صرف اس بات کا انتظار کر رہے ہیں کہ ان کے پاس (عذاب والے) فرشتے آجائیں یا آپ کے پروردگار کا حکم (عذاب) آجائے؟ ایسا ہی ان لوگوں نے کیا تھا جو ان سے پہلے خود ہی اپنے اوپر ظلم کرتے رہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcmxxxv{آخرکار ان کے کرتوتوں کی برائیاں ان تک پہنچ گئیں اور انہیں اس (عذاب) نے گھیر لیا جس کا وہ مذاق اڑایا کرتے تھے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvi{اور مشرک لوگ کہتے ہیں کہ اگر اللہ چاہتا تو ہم اور ہمارے آباء و اجداد اس کے سوا نہ کسی اور کی عبادت کرتے اور نہ ہی ہم اس کے حکم کے بغیر کسی چیز کو حرام کرتے ایسا ہی ان لوگوں نے کیا جو ان سے پہلے تھے (بتاؤ) پیغمبروں کے ذمے کھلا پیغام دینے کے سوا اور کیا ہے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvii{اور یقیناً ہم نے ہر ایک امت میں کوئی نہ کوئی رسول (یہ پیغام دے کر) ضرور بھیجا ہے کہ اللہ کی عبادت کرو اور طاغوت (کی بندگی) سے بچو پس ان (امتوں) میں سے بعض کو اللہ نے ہدایت دی اور بعض پر گمراہی مستقر اور ثابت ہوگئی پس تم زمین پر چلو پھرو اور دیکھو کہ جھٹلانے والوں کا کیا انجام ہوا؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcmxxxviii{(اے رسول) آپ ان کے ہدایت پانے کے کتنے ہی حریص ہوں مگر (یہ ہدایت پانے والے نہیں) کیونکہ اللہ جس کو (اس کے کفر و سرکشی کی وجہ سے) گمراہی میں چھوڑ دیتا ہے اس کو ہدایت نہیں کرتا اور ان کے لئے کوئی مددگار نہیں ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcmxxxix{وہ اللہ کی سخت قسمیں کھا کر کہتے ہیں کہ جو مر گیا خدا اسے ہرگز (دوبارہ) نہیں اٹھائے گا۔ ہاں (ضرور اٹھائے گا) یہ اس کا وعدہ ہے جس کا پورا کرنا اس پر لازم ہے لیکن اکثر لوگ اس کا علم نہیں رکھتے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcmxl{(یہ دوبارہ اٹھانا اس لئے ضروری ہے) تاکہ جن باتوں میں یہ لوگ اختلاف کرتے ہیں ان کے سامنے ان کی حقیقت کھول دے اور تاکہ کافروں کو معلوم ہو جائے کہ وہ جھوٹے تھے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcmxli{ہم جب کسی چیز (کے پیدا کرنے) کا ارادہ کرتے ہیں تو ہمارا کہنا بس اتنا ہی ہوتا ہے کہ اس سے کہتے ہیں کہ ہو جا بس وہ ہو جاتی ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcmxlii{اور جن لوگوں نے خدا کے واسطے ہجرت کی اس کے بعد کہ (ایمان لانے کی وجہ سے) ان پر ظلم کئے گئے ہم ان کو دنیا میں بھی اچھا ٹھکانہ دیں گے اور آخرت کا اجر تو بہت بڑا ہے کاش یہ لوگ جان لیتے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcmxliii{یہی وہ لوگ ہیں جنہوں نے صبر کیا اور اپنے پروردگار پر بھروسہ کرتے ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcmxliv{(اے رسول) ہم نے آپ سے پہلے مردوں کو ہی رسول بنا کر بھیجا، کھلی ہوئی دلیلوں اور کتابوں کے ساتھ جن کی طرف ہم وحی کرتے تھے اگر تم لوگ نہیں جانتے تو اہلِ ذکر سے پوچھ لو۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcmxlv{اور ہم نے آپ پر الذکر (قرآن مجید) اس لئے نازل کیا ہے کہ آپ لوگوں کے لئے (وہ معارف و احکام) کھول کر بیان کریں جو ان کی طرف نازل کئے گئے ہیں تاکہ وہ غور و فکر کریں۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcmxlvi{کیا وہ لوگ جو (پیغمبر(ص) کے خلاف) بری تدبیریں اور ترکیبیں کر رہے ہیں وہ اس بات سے مطمئن ہوگئے ہیں کہ اللہ انہیں زمین میں دھنسا دے یا ان پر ایسے موقع سے عذاب آجائے جہاں سے انہیں وہم و گمان بھی نہ ہو؟\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcmxlvii{یا انہیں اپنے کاروبار میں ان کے چلتے پھرتے وقت آپکڑے پس وہ اپنی چالبازیوں سے اللہ کو عاجز نہیں کر سکتے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcmxlviii{یا انہیں اس وقت پکڑے جب وہ اس سے خوف زدہ ہوں بلاشبہ تمہارا پروردگار بڑا شفیق اور بڑا مہربان ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcmxlix{کیا ان لوگوں نے کبھی اللہ کی پیدا کی ہوئی مختلف چیزوں میں غور نہیں کیا کہ ان کے سائے کس طرح اللہ کو سجدہ کرتے ہوئے دائیں بائیں جھکتے ہیں اس طرح وہ سب اپنے عجز کا اظہار کر رہے ہیں۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcml{اور جو (جاندار) چیزیں آسمانوں میں ہیں اور زمین میں جتنے جانور ہیں اور فرشتے سب اللہ کے لئے سربسجود ہیں اور وہ سرکشی نہیں کرتے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcmli{وہ اپنے پروردگار سے ڈرتے رہتے ہیں جو ان پر بالادست ہے اور انہیں جو کچھ حکم دیا جاتا ہے وہ وہی کرتے ہیں۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcmlii{اور اللہ تعالیٰ نے فرمایا ہے کہ دو اِلٰہ (خدا) نہ بناؤ۔ الٰہ (خدا) تو صرف ایک ہی ہے سو تم صرف مجھ ہی سے ڈرو۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcmliii{اور اسی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اور اسی کا دین دائمی اور واجب الاطاعت ہے تو کیا تم اللہ کے سوا غیروں سے ڈرتے ہو؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcmliv{اور تمہارے پاس جو بھی نعمت ہے وہ سب اللہ ہی کی طرف سے ہے پھر جب تمہیں کوئی تکلیف پہنچتی ہے تو اسی کی جناب میں داد و فریاد کرتے ہو۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcmlv{پھر جب وہ تکلیف کو دور کر دیتا ہے تو ایک دم تم میں سے ایک گروہ اپنے پروردگار کے ساتھ شرک کرنے لگتا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcmlvi{تاکہ جو کچھ ہم نے انہیں عطا کیا ہے اس کا کفران کریں سو (اے ناشکرو) چند روزہ فائدہ اٹھا لو۔ عنقریب تمہیں (اپنا انجام) معلوم ہو جائے گا۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcmlvii{یہ لوگ ہمارے دیے ہوئے رزق میں سے ان (بتوں وغیرہ) کے لئے حصہ مقرر کرتے ہیں جن کو یہ جانتے بھی نہیں ہیں خدا کی قسم تم سے ضرور پوچھا جائے گا کہ تم کیسی افترا پردازیاں کرتے تھے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcmlviii{اور یہ اللہ کے لئے لڑکیاں قرار دیتے ہیں پاک ہے اس کی ذات اور خود ان کے لئے وہ ہے جس کے یہ خواہشمند ہیں۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcmlix{اور جب ان میں سے کسی کو بیٹی کے پیدا ہونے کی اطلاع دی جاتی ہے تو اس کا چہرہ سیاہ پڑ جاتا ہے اور وہ رنج و غم سے بھر جاتا ہے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcmlx{وہ اس بری خبر سے جو اسے دی گئی ہے لوگوں سے چھپتا پھرتا ہے (اور سوچتا ہے) کہ ذلت کے ساتھ اسے لئے رہے یا اسے مٹی کے تلے گاڑ دے؟ کیا ہی بُرا فیصلہ ہے جو یہ کرتے ہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcmlxi{جو لوگ آخرت پر ایمان نہیں رکھتے ان کی حالت بری ہے اور اللہ کے لئے اعلیٰ صفت ہے وہ زبردست ہے بڑا حکمت والا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcmlxii{اگر اللہ لوگوں کو ان کی زیادتی پر (فوراً) پکڑ لیا کرتا تو پھر روئے زمین پر کسی جاندار کو نہ چھوڑتا مگر وہ انہیں ایک مقررہ مدت تک مہلت دیتا ہے پھر جب وہ مقررہ وقت آجاتا ہے تو اس سے وہ ایک گھڑی پیچھے آگے نہیں ہو سکتے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcmlxiii{اور وہ اللہ کے لئے وہ چیزیں (بیٹیاں) قرار دیتے ہیں جن کو اپنے لئے ناپسند کرتے ہیں اور ان کی زبانیں غلط بیانی کرتی ہیں کہ ان کے لئے (بہرحال) بھلائی ہی بھلائی ہے (نہیں) ہاں البتہ ان کے لئے دوزخ کی آگ ہے اور بے شک یہ سب سے پہلے اس میں پہنچائے (جھونکے) جائیں گے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcmlxiv{خدا کی قسم! ہم نے آپ سے پہلے کئی امتوں کی طرف رسول بھیجے ہیں پس شیطان نے ان کے (برے) اعمال خوشنما کرکے انہیں دکھائے سو وہی آج ان کا سرپرست ہے اور ان کے لئے دردناک عذاب ہے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcmlxv{اور ہم نے آپ پر یہ کتاب نہیں اتاری مگر اس لئے کہ آپ ان باتوں کو کھول کر بیان کر دیں جن میں وہ اختلاف کر رہے ہیں اور یہ (کتاب) ایمان لانے والوں کے لئے سراسر ہدایت اور رحمت ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcmlxvi{اور اللہ نے آسمان سے پانی اتارا ہے اور اس کے ذریعہ سے زمین کو اس کے مردہ (بنجر) ہو جانے کے بعد زندہ کر دیتا ہے۔ بے شک اس میں آوازِ حق سننے والوں کے لئے بڑی نشانی ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcmlxvii{اور بے شک تمہارے لئے چوپایوں میں عبرت کا سامان موجود ہے ہم ان کے پیٹ سے گوبر اور خون کے درمیان سے نکال کر تمہیں خالص دودھ پلاتے ہیں جو پینے والوں کے لئے خوشگوار ہے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcmlxviii{اور ہم کھجور اور انگور کے پھلوں سے بھی (تمہیں اس حالت میں) جن سے تم نشہ آور عرق بھی بنا لیتے ہو اور بہترین رزق بھی یقیناً اس میں ایک نشانی ہے ان لوگوں کے لئے جو عقل سے کام لیتے ہیں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcmlxix{اور آپ کے پروردگار نے شہد کی مکھی کو یہ وحی کی کہ پہاڑوں میں، درختوں میں اور ان چھپروں میں جن پر لوگ بیلیں چڑھاتے ہیں گھر (چھتے) بنایا کر۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcmlxx{پھر ہر قسم کے پھلوں (اور پھولوں) کا رس چوسا کر پس اپنے پروردگار کی ہموار کردہ راہوں پر چلتی رہ۔ شہد کی ان مکھیوں کے پیٹ سے مختلف رنگوں کا وہ مشروب نکلتا ہے جس میں لوگوں کے لئے شفا ہے اس میں ان لوگوں کے لئے نشانی ہے جو غور و فکر کرتے ہیں۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcmlxxi{اور اللہ نے تمہیں پیدا کیا ہے پھر وہی تمہیں وفات دے گا اور تم میں سے بعض ایسے بھی ہیں کہ جن کو (بڑھاپے کی) بدترین عمر تک لوٹا دیا جاتا ہے تاکہ (بہت کچھ) جاننے کے بعد کچھ بھی نہ جانیں بے شک اللہ بڑا جاننے والا، بڑا قدرت والا ہے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcmlxxii{اور اللہ نے تم میں سے بعض کو بعض پر رزق کے معاملہ میں فضیلت (برتری) دی ہے پھر جن لوگوں کو یہ فضیلت دی گئی ہے وہ اپنا رزق اپنے غلاموں (اور زیر دستوں) کو لوٹا دینے والے نہیں ہیں تاکہ وہ سب اس میں برابر ہو جائیں تو کیا وہ اللہ کی نعمت کا انکار کرتے ہیں؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiii{اور اللہ نے ہی تمہاری جنس سے تمہارے لئے بیویاں بنائیں اور پھر ان بیویوں سے بیٹے اور پوتے عنایت فرمائے اور تمہاری روزی کیلئے تمہیں پاکیزہ چیزیں عطا فرمائیں تو کیا (پھر بھی) یہ لوگ باطل کو مانتے رہیں گے اور اللہ کی نعمتوں کا انکار کرتے رہیں گے؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiv{اور یہ اللہ کو چھوڑ کر ایسوں کی عبادت (پرستش) کرتے ہیں جو ان کو آسمان و زمین سے روزی پہنچانے کا کوئی اختیار نہیں رکھتے اور نہ ہی وہ یہ کام کر سکتے ہیں۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcmlxxv{پس تم اللہ کے لئے مثالیں نہ دیا کرو بے شک اللہ بہتر جانتا ہے تم نہیں جانتے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvi{اللہ ایک مثال پیش کرتا ہے کہ ایک غلام ہے جو دوسرے کا مملوک ہے اور کسی چیز پر اختیار نہیں رکھتا اور ایک دوسرا ہے جسے ہم نے بہترین رزق عطا کر رکھا ہے اور وہ اس میں سے پوشیدہ اور علانیہ طور پر خرچ بھی کرتا ہے کیا وہ سب برابر ہو سکتے ہیں؟ الحمد ﷲ (سب تعریفیں اللہ کے لئے ہیں) مگر اکثر لوگ (اتنی سیدھی بات بھی) نہیں جانتے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvii{اور اللہ دو آدمیوں کی مثال پیش کرتا ہے جن میں سے ایک گونگا ہے کسی بات پر قدرت نہیں رکھتا اور وہ اپنے آقا پر بوجھ ہے وہ اسے جدھر بھی بھیجے وہ کسی بھلائی کے ساتھ واپس نہیں آتا اور دوسرا وہ ہے جو عدل و انصاف کا حکم دیتا ہے اور خود راہِ راست پر قائم ہے کیا وہ (پہلا) اور یہ (دوسرا) برابر ہو سکتے ہیں؟\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcmlxxviii{آسمان و زمین کا سارا غیب اللہ ہی کے لئے ہے اور قیامت کا حکم تو صرف ایک پل جھپکنے کے برابر یا اس سے بھی قریب تر ہے اور یقینا اللہ ہر شے پر قدرت رکھنے والا ہے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcmlxxix{اور اللہ ہی نے تمہیں شکمِ مادر سے اس طرح نکالا ہے کہ تم کچھ نہیں جانتے تھے اور اسی نے تمہارے لئے کان، آنکھ اور دل قرار دیئے ہیں کہ شاید تم شکر گزار بن جاؤ۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcmlxxx{کیا ان لوگوں نے پرندوں کی طرف نہیں دیکھا کہ وہ کس طرح فضائے آسمان میں مسخر ہیں کہ اللہ کے علاوہ انہیں کوئی روکنے والا اور سنبھالنے والا نہیں ہے بے شک اس میں بھی اس قوم کے لئے بہت سی نشانیاں ہیں جو ایمان رکھنے والی قوم ہے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxi{اور اللہ ہی نے تمہارے لئے تمہارے گھروں کو وجہِ سکون بنایا ہے اور تمہارے لئے جانوروں کی کھالوں سے ایسے گھر بنا دیئے ہیں جن کو تم روزِ سفر بھی ہلکا سمجھتے ہو اور روزِ قیامت بھی ہلکا محسوس کرتے ہو اور پھر ان کے اون، روئیں اور بالوں سے مختلف سامانِ زندگی اور ایک مدت کے لئے کارآمد چیزیں بنا دیں۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxii{اور اللہ ہی نے تمہارے لئے مخلوقات کا سایہ قرار دیا ہے اور پہاڑوں میں چھپنے کی جگہیں بنائی ہیں اور ایسے پیراہن بنائے ہیں جو گرمی سے بچا سکیں اور پھر ایسے پیراہن بنائے جو ہتھیاروں کی زد سے بچا سکیں۔ وہ اسی طرح اپنی نعمتوں کو تمہارے اوپر تمام کر دیتا ہے کہ شاید تم اطاعت گزار بن جاؤ۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiii{پھر اس کے بعد بھی اگر یہ ظالم منہ پھیر لیں تو آپ کا کام صرف واضح پیغام کا پہنچا دینا ہے اور بس۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiv{یہ لوگ اللہ کی نعمت کو پہچانتے ہیں اور پھر انکار کرتے ہیں اور ان کی اکثریت کافر ہے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxv{اور جس دن ہم ہر امت سے ایک گواہ اٹھا کر کھڑا کریں گے پھر کافروں کو اجازت نہیں دی جائے گی اور نہ ہی ان سے اللہ کو راضی کرنے کی فرمائش کی جائے گی۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvi{اور جب ظالم لوگ (ایک بار) عذاب کو دیکھ لیں گے تو پھر نہ ان کے عذاب میں کوئی تخفیف کی جائے گی اور نہ ہی انہیں مہلت دی جائے گی۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvii{اور جن لوگوں نے (دنیا میں) شرک کیا تھا جب وہ (قیامت کے دن) اپنے بنائے ہوئے شریکوں کو دیکھیں گے تو کہیں گے اے ہمارے پروردگار یہ ہیں ہمارے وہ شرکاء جنہیں ہم تجھے چھوڑ کر پکارا کرتے تھے تو وہ (شرکاء) یہ بات ان کی طرف پھینک دیں گے کہ تم جھوٹے ہو۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxviii{اور اس دن سب اللہ کے سامنے جھک جائیں گے اور وہ ساری افتراء پردازیاں غائب ہو جائیں گی جو وہ کیا کرتے تھے۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxix{جن لوگوں نے کفر کیا اور لوگوں کو اللہ کی راہ سے روکا۔ تو ہم ان کے فساد پھیلانے کی پاداش میں ان کے عذاب پر ایک اور عذاب کا اضافہ کر دیں گے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcmxc{اور جس دن ہم ہر امت میں سے ایک گواہ اٹھا کھڑا کریں گے جو ان کے بالمقابل گواہی دے گا اور آپ کو ان سب کے بالمقابل گواہ بنا کر لائیں گے اور ہم نے آپ پر وہ کتاب نازل کی ہے جو ہر بات کو کھول کر بیان کرتی ہے اور سرِ تسلیم خم کرنے والوں کے لئے سراسر ہدایت، رحمت اور بشارت ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcmxci{بے شک اللہ عدل، احسان اور قرابتداروں کو (ان کا حق) دینے کا حکم دیتا ہے اور بے حیائی، برائی اور ظلم و زیادتی کرنے سے منع کرتا ہے اور تمہیں نصیحت کرتا ہے تاکہ تم نصیحت قبول کرو۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcmxcii{اور اللہ کے عہد کو پورا کرو جب بھی تم کوئی عہد کرو اور اپنی قسموں کو پختہ کرنے کے بعد نہ توڑو جبکہ تم اللہ کو ضامن بنا چکے ہو بے شک اللہ جانتا ہے جو کچھ تم کرتے ہو۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcmxciii{خبردار تم اس عورت کی مانند نہ ہو جانا جس نے بڑی مضبوطی سے سوت کاتنے کے بعد اسے ٹکڑے ٹکڑے کر دیا تم اپنی قسموں کو اپنے درمیان مکر و فریب کا ذریعہ بناتے ہو۔ تاکہ ایک گروہ دوسرے سے زیادہ فائدہ حاصل کرے اور اللہ اس بات سے تمہاری آزمائش کرتا ہے اور یقیناً قیامت کے دن وہ تمہارے لئے وہ حکمت ظاہر کر دے گا جس میں تم اختلاف کرتے ہو۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcmxciv{اور اگر اللہ چاہتا تو تم سب کو ایک امت بنا دیتا لیکن وہ جسے چاہتا ہے گمراہی میں چھوڑ دیتا ہے اور جسے چاہتا ہے ہدایت دیتا ہے اور تم جو کچھ کر رہے ہو اس کے بارے میں تم سے ضرور سوال کیا جائے گا۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcmxcv{اور تم اپنے درمیان اپنی قسموں کو مکر و فریب کا ذریعہ نہ بناؤ۔ کہیں کوئی قدم جم جانے کے بعد پھسل نہ جائے اور اس طرح تمہیں اللہ کی راہ سے روکنے کی پاداش میں برائی کا مزہ چکھنا پڑے اور تمہارے لئے عذابِ عظیم ہے۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcmxcvi{اور اللہ کے عہد و پیمان کو تھوڑی سی قیمت کے عوض فروخت نہ کرو۔ بے شک جو کچھ اللہ کے پاس ہے وہ تمہارے لئے بہتر ہے اگر تم جانتے ہو۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcmxcvii{جو کچھ تمہارے پاس ہے وہ ختم ہو جائے گا اور جو کچھ اللہ کے پاس ہے وہ باقی رہنے والا ہے اور ہم یقیناً صبر کرنے والوں کو ان کا اجر ان کے بہترین اعمال کے مطابق عطا کریں گے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcmxcviii{جو کوئی بھی نیک عمل کرے خواہ مرد ہو یا عورت بشرطیکہ وہ مؤمن ہو تو ہم اسے (دنیا) میں پاک و پاکیزہ زندگی بسر کرائیں گے اور (آخرت میں) ان کا اجر ان کے بہترین اعمال کے مطابق عطا کریں گے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcmxcix{پس جب آپ قرآن پڑھنے لگیں تو مردود شیطان سے خدا کی پناہ مانگ لیا کریں۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mm{جو لوگ ایماندار ہیں اور اپنے پروردگار پر بھروسہ کرتے ہیں ان پر اس (شیطان) کا کوئی تسلط نہیں ہے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmi{اس کا قابو تو صرف ان لوگوں پر چلتا ہے جو اسے اپنا دوست بناتے ہیں اور اس کی وجہ سے شرک کرتے ہیں۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmii{اور جب ہم ایک آیت کو کسی اور آیت سے بدلتے ہیں تو اللہ بہتر جانتا ہے کہ وہ کیا نازل کر رہا ہے تو یہ لوگ کہتے ہیں کہ تم (یہ کلام) اپنے دل سے گھڑ لیا کرتے ہو حالانکہ ان میں سے اکثر لوگ (حقیقتِ حال کو) نہیں جانتے۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmiii{آپ کہہ دیجیے کہ اس (قرآن) کو تمہارے پروردگار کی طرف سے روح القدس نے حق کے ساتھ اتارا ہے تاکہ ایمان لانے والوں کو ثابت قدم رکھے اور اطاعت گزاروں کے لئے ہدایت اور نجات کی خوشخبری ثابت ہو۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmiv{اور بے شک ہم جانتے ہیں کہ وہ (قرآن کے بارے میں) کہتے ہیں کہ اس شخص (پیغمبر) کو ایک آدمی سکھاتا ہے حالانکہ جس شخص کی طرف یہ نسبت دیتے ہیں اس کی زبان عجمی ہے اور یہ (قرآن) تو فصیح عربی زبان میں ہے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmv{جو لوگ آیاتِ الٰہی پر ایمان نہیں لاتے اللہ کبھی انہیں ہدایت نہیں دیتا اور ان کے لئے دردناک عذاب ہے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmvi{جھوٹ تو صرف وہی لوگ گھڑتے ہیں جو اللہ کی آیتوں پر ایمان نہیں رکھتے اور یہی لوگ جھوٹے ہیں۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmvii{جو کوئی اللہ پر ایمان لانے کے بعد کفر کرے سوائے اس صورت کے کہ اسے مجبور کیا جائے جبکہ اس کا دل ایمان پر مطمئن ہو (کہ اس پر کوئی مؤاخذہ نہیں ہے) لیکن جو کشادہ دلی سے کفر اختیار کرے (زبان سے کفر کرے اور اس کا دل اس کفر پر رضامند ہو) تو ایسے لوگوں پر اللہ کا غضب ہے اور ان کے لئے بڑا عذاب ہے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmviii{یہ اس لئے ہے کہ انہوں نے دنیوی زندگی کو آخرت پر ترجیح دی ہے اور اللہ کافروں کو ہدایت نہیں کیا کرتا۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmix{یہی وہ لوگ ہیں کہ جن کے دلوں، کانوں اور آنکھوں پر اللہ نے مہر لگا دی اور یہی لوگ بالکل غافل ہیں۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmx{اور یقیناً یہی لوگ آخرت میں نقصان و زیاں اٹھانے والے ہیں۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmxi{پھر آپ کا پروردگار ان لوگوں کے لئے جنہوں نے (سخت) آزمائش میں مبتلا ہونے کے بعد ہجرت کی پھر جہاد کیا اور صبر سے کام لیا یقیناً (آپ کا) پروردگار ان اعمال کے بعد بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmxii{(اس دن کو یاد کرو) جس دن ہر شخص اپنی ذات کی خاطر جھگڑا کرتا ہوا آئے گا اور ہر شخص کو اس کے عمل کا پورا پورا بدلہ دیا جائے گا اور ان پر (کسی طرح بھی) کوئی ظلم نہیں کیا جائے گا۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmxiii{اور اللہ نے ایک بستی کی مثال بیان کی ہے جو امن و اطمینان سے (آباد) تھی اس کی روزی فراغت سے آرہی تھی پس اس نے کفرانِ نعمت شروع کیا تو اللہ نے اس کے باشندوں کے کرتوتوں کی پاداش میں اسے یہ مزہ چکھایا کہ بھوک اور خوف کو اس کا اوڑھنا بنا دیا۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmxiv{اور پھر خود انہی میں سے ایک رسول ان کے پاس آیا مگر انہوں نے اسے جھٹلا دیا پس عذاب نے انہیں اس حال میں آپکڑا کہ وہ ظالم تھے۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmxv{(اے لوگو) خدا نے تمہیں جو حلال (اور) پاک و پاکیزہ رزق دیا ہے اس میں سے کھاؤ (پیو) اور اس کے ساتھ ساتھ اللہ کی نعمت کا شکر بھی ادا کرو اگر تم صرف اسی کی عبادت کرتے ہو۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmxvi{اس نے تم پر صرف مردار، خون، خنزیر کا گوشت اور وہ جس پر ذبح کے وقت غیر اللہ کا نام بلند کیا گیا ہو حرام کیا ہے۔ پس جو (ان کے کھانے پر) مجبور ہو جائے نہ باغی ہو اور نہ حد سے تجاوز کرنے والا (تو کوئی مضائقہ نہیں) بے شک خدا بڑا بخشنے والا، بڑا مہربان ہے۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmxvii{(خبردار) تمہاری زبانوں پر جو جھوٹی بات آجائے (اور وہ جھوٹے احکام لگائیں) ان کے متعلق نہ کہو کہ یہ حلال ہے اور یہ حرام! اس طرح تم اللہ پر جھوٹا افترا باندھوگے بے شک جو لوگ خدا پر جھوٹا بہتان باندھتے ہیں وہ کبھی فلاح نہیں پاتے۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmxviii{اس افترا پردازی کا چند روزہ فائدہ ہے (آخرکار) ان کے لئے دردناک عذاب ہے۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmxix{اور ہم نے یہودیوں پر وہ چیزیں حرام کر دیں جن کا ذکر ہم اس سے پہلے (سورہ انعام میں) آپ سے کر چکے ہیں اور ہم نے ان پر کوئی ظلم نہیں کیا تھا بلکہ وہ خود ہی اپنے اوپر ظلم کرتے تھے۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmxx{بے شک آپ کا پروردگار ان لوگوں کے لئے جو جہالت و نادانی سے برائی کر گزرتے ہیں اور پھرا س کے بعد توبہ کر لیتے ہیں اور اپنی اصلاح کر لیتے ہیں یقیناً آپ کا پروردگار اس کے بعد بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmxxi{بے شک ابراہیم(ع) (اپنی ذات میں) ایک پوری امت تھے اللہ کے مطیع فرمان تھے (سب سے کٹ کر) یکسوئی سے (خدا کی طرف) مائل تھے اور ہرگز مشرکوں میں سے نہیں تھے۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmxxii{وہ اللہ کی نعمتوں کے شکر گزار تھے اللہ نے انہیں منتخب کر لیا تھا اور انہیں سیدھے راستہ پر لگا دیا تھا۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmxxiii{ہم نے انہیں دنیا میں بھی بھلائی دی اور آخرت میں تو وہ صالحین میں سے ہی ہیں۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmxxiv{اے رسول(ص) پھر ہم نے آپ کی طرف وحی کی کہ یکسو ہوکر ابراہیم کی ملت (طریقہ) کی پیروی کریں جو یقیناً مشرکوں میں سے نہیں تھے۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmxxv{(باقی رہا) سبت (کے احترام کا معاملہ) تو یہ صرف ان لوگوں پر عائد کیا گیا تھا جنہوں نے اس کے بارے میں اختلاف کیا تھا اور اللہ قیامت کے دن ان کے درمیان فیصلہ کرے گا ان باتوں کے بارے میں جن میں وہ باہم اختلاف کرتے تھے۔\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmxxvi{(اے پیغمبر(ص)) آپ اپنے پروردگار کے راستے کی طرف (لوگوں کو) بلائیں حکمت اور عمدہ نصیحت کے ساتھ اور لوگوں سے بہترین انداز میں بحث و مباحثہ کریں۔ آپ کا پروردگار ہی بہتر جانتا ہے کہ اس کے راستہ سے بھٹکا ہوا کون ہے اور وہی بہتر جانتا ہے کہ ہدایت یافتہ کون ہے؟\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmxxvii{اور اگر تم بدلہ لینا چاہو تو اس قدر لو جس قدر تم پر زیادتی کی گئی ہے اور اگر تم صبر کرو تو وہ صبر کرنے والوں کے حق میں بہتر ہے۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmxxviii{اور (اے پیغمبر) آپ صبر کیجئے اور آپ کا صبر کرنا تو محض اللہ کی توفیق سے ہے اور آپ ان لوگوں کے حال پر غم نہ کیجئے اور نہ ہی ان کی مکاریوں سے دل تنگ ہو جایئے۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmxxix{بے شک اللہ ان لوگوں کے ساتھ ہے جو تقویٰ اختیار کرتے ہیں اور جو (خلقِ خدا سے) حسنِ سلوک کرتے ہیں۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmxxx{\basmalahur پاک ہے وہ (خدا) جو اپنے بندہ (خاص) کو رات کے ایک حصہ میں مسجد الحرام سے اس مسجدِ اقصیٰ تک لے گیا جس کے گرد و پیش ہم نے برکت دی ہے تاکہ ہم انہیں اپنی (قدرت کی) کچھ نشانیاں دکھائیں بے شک وہ بڑا سننے والا، بڑا دیکھنے والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmxxxi{اور ہم نے موسیٰ کو کتاب دی اور اسے بنی اسرائیل کے لئے ذریعۂ ہدایت بنایا کہ (دیکھو) میرے سوا کسی کو اپنا کارساز نہ بنانا۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmxxxii{اے ان لوگوں کی اولاد جن کو ہم نے نوح کے ساتھ (کشتی میں) سوار کر لیا تھا بے شک وہ (نوح) ایک شکر گزار بندہ تھا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmxxxiii{اور ہم نے اس کتاب (توراۃ) میں بنی اسرائیل کو آگاہ کر دیا تھا کہ تم ضرور زمین میں دو مرتبہ فساد برپا کروگے اور بڑی سرکشی کروگے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmxxxiv{چنانچہ جب ان دونوں میں سے پہلے وعدہ کا وقت آگیا تو ہم نے (تمہاری سرکوبی کیلئے) اپنے کچھ ایسے سخت جنگجو بندے بھیج دیئے جو تمہاری آبادیوں کے اندر گھس گئے اور (خدا) کا وعدہ پورا ہو کر رہا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmxxxv{اور پھر ہم نے گردشِ زمانہ کو تمہارے حق میں دشمن کے خلاف کر دیا (تمہیں ان پر غلبہ دے دیا) اور مال اور اولاد سے تمہاری مدد کی اور تمہیں کثیر التعداد بنا دیا۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmxxxvi{(دیکھو) اگر تم اچھے کام کروگے تو اپنے لئے ہی کروگے اور اگر برے کام کروگے تو وہ بھی اپنے لئے کروگے پس جب دوسرا وعدہ آگیا (تو ہم نے اور بندوں کو مسلط کر دیا) تاکہ تمہارے چہروں کو بگاڑ دیں اور مسجد (بیت المقدس) میں اسی طرح (جبراً) داخل ہو جائیں جس طرح پہلی بار (حملہ آور) داخل ہوئے تھے اور تاکہ جس جس چیز پر وہ قابو پائیں اسے تباہ و برباد کر دیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmxxxvii{ہو سکتا ہے کہ تمہارا پروردگار تم پر رحم فرمائے اور اگر تم پھر (فساد و سرکشی کی طرف) لوٹے تو پھر ہم بھی اسی طرح لوٹیں گے اور ہم نے جہنم کو کافروں کے لئے قید خانہ بنا دیا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmxxxviii{یقیناً یہ قرآن اس راستہ کی طرف راہنمائی کرتا ہے جو سب سے زیادہ سیدھا ہے اور خوشخبری دیتا ہے ان اہلِ ایمان کو جو نیک عمل کرتے ہیں کہ ان کے لئے بہت بڑا اجر ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmxxxix{اور جو لوگ آخرت پر ایمان نہیں رکھتے ان کے لئے ہم نے دردناک عذاب تیار کر رکھا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmxl{اور انسان برائی کی دعا اسی طرح کرتا ہے جس طرح اچھائی کی دعا کرتا ہے (دراصل) انسان بڑا ہی جلد باز ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmxli{اور ہم نے رات اور دن کو (اپنی قدرت کی) دو نشانیاں بنایا ہے سو ہم نے رات کی نشانی کو دھندلا بنایا اور دن کی نشانی کو روشن بنایا تاکہ تم اپنے پروردگار کا فضل و کرم (رزق) تلاش کرو اور تاکہ برسوں کی گنتی اور (ہر طرح کا) حساب معلوم کر سکو اور ہم نے ہر (ضروری) چیز کو تفصیل سے بیان کر دیا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmxlii{اور ہم نے ہر انسان کا (نامہ) عمل اس کی گردن میں ڈال دیا ہے اور قیامت کے دن ہم ایک کتاب (نوشتہ) نکالیں گے جسے وہ اپنے سامنے کھلا ہوا پائے گا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmxliii{(ہم حکم دیں گے کہ) اپنا نامۂ عمل پڑھ آج تو خود ہی اپنے حساب کے لئے کافی ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmxliv{جو راہِ راست اختیار کرتا ہے وہ اپنے فائدہ کے لئے ہی کرتا ہے اور جو گمراہی اختیار کرتا ہے تو اس کا وبال اسی پر ہے اور کوئی بوجھ اٹھانے والا کسی دوسرے کا بوجھ نہیں اٹھائے گا اور ہم اس وقت تک عذاب نازل نہیں کرتے جب تک (اتمامِ حجت کی خاطر) کوئی رسول بھیج نہیں دیتے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmxlv{اور جب ہم کسی بستی کو ہلاک کرنا چاہتے ہیں تو ہم وہاں کے خوشحال لوگوں کو (انبیاء کے ذریعہ سے اپنی اطاعت کا) حکم دیتے ہیں اور وہ (اطاعت کی بجائے) نافرمانی کرنے لگتے ہیں تب اس پر (عذاب کی) بات ثابت ہو جاتی ہے اور ہم اسے تباہ و برباد کر دیتے ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmxlvi{اور ہم نے نوح کے بعد کتنی ہی قوموں کو (ان کے گناہوں کی پاداش میں) ہلاک کیا اور آپ کا پروردگار اپنے بندوں کے گناہوں سے باخبر ہونے اور دیکھنے کی حیثیت سے کافی ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmxlvii{جو کوئی دنیا کا خواہشمند ہو تو ہم جسے جتنا دینا چاہتے ہیں اسی (دنیا) میں جلدی دے دیتے ہیں پھر اس کے لئے دوزخ قرار دیتے ہیں جس میں وہ ملامت زدہ اور راندہ ہوا داخل ہوگا (اور اسے تاپے گا)۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmxlviii{اور جو کوئی آخرت کا طلبگار ہوتا ہے اور اس کے لئے ایسی کوشش بھی کرے جیسی کہ کرنی چاہیئے درآنحالیکہ وہ مؤمن بھی ہو تو یہ وہ ہیں جن کی کوشش مشکور ہوگی۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmxlix{ہم ہر ایک کی امداد کرتے ہیں اِن کی بھی اور اُن کی بھی آپ کے پروردگار کی عطا و بخشش سے اور آپ کے پروردگار کی عطا کسی پر بند نہیں ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mml{(دیکھو) ہم نے (یہاں) کس طرح بعض لوگوں کو بعض پر فضیلت دی ہے اور آخرت تو درجات کے اعتبار سے بہت بڑی ہے اور فضیلت کے لحاظ سے بھی بہت بڑی ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmli{اللہ کے ساتھ کوئی الٰہ (معبود) نہ ٹھہراؤ۔ ورنہ ملامت زدہ ہوکر اور بے یار و مددگار ہو کر بیٹھے رہوگے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmlii{اور آپ کے پروردگار نے فیصلہ کر دیا ہے کہ تم اس کے سوا اور کسی کی عبادت نہ کرو اور ماں باپ کے ساتھ بھلائی کرو اگر تمہارے پاس ان میں سے ایک یا دونوں بڑھاپے تک پہنچ جائیں تو انہیں اف تک نہ کہو اور نہ انہیں جھڑکو۔ اور ان سے احترام کے ساتھ بات کرو۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmliii{اور ان کے سامنے مہر و مہربانی کے ساتھ انکساری کا پہلو جھکائے رکھو اور کہو اے پروردگار تو ان دونوں پر اسی طرح رحم و کرم فرما جس طرح انہوں نے میرے بچپنے میں مجھے پالا( اور میری پرورش کی)۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmliv{تمہارا پروردگار بہتر جانتا ہے جو کچھ تمہارے دلوں میں ہے اگر تم صالح اور نیک کردار ہوئے تو وہ توبہ و انابہ کرنے والوں کے لئے بڑا ہی بخشنے والا ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmlv{اور (دیکھو) قریبی رشتہ دار کو اس کا حق دے دو اور مسکین و مسافر کو بھی اور (خبردار) فضول خرچی نہ کرو۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmlvi{بے شک فضول خرچی کرنے والے شیطانوں کے بھائی بند ہیں اور شیطان اپنے پروردگار کا بڑا ناشکرا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmlvii{اور اگر تمہیں ان لوگوں سے پہلوتہی کرنی پڑے اس انتظار میں کہ تمہارے پروردگار کی طرف سے رحمت (کشائش) آئے جس کے تم امیدوار ہو تو ان سے نرم انداز میں بات کرو۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmlviii{اور (دیکھو) نہ تو اپنا ہاتھ اپنی گردن سے باندھ لو اور نہ ہی اسے بالکل کھول دو کہ (ایسا کرنے سے) ملامت زدہ (اور) تہی دست ہو کر بیٹھ جاؤگے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmlix{تمہارا پروردگار جس کسی کی چاہتا ہے روزی فراخ کر دیتا ہے اور جس کی چاہتا ہے تنگ کر دیتا ہے بے شک وہ اپنے بندوں کے حال سے بڑا باخبر ہے اور بڑا نگاہ رکھنے والا ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmlx{اور فقر و فاقہ کے خوف سے اپنی اولاد کو قتل نہ کرو۔ ہم ہی انہیں اور تمہیں روزی دیتے ہیں بے شک انہیں قتل کرنا بڑا جرم ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmlxi{اور زناکاری کے قریب بھی نہ جاؤ یقینا وہ بہت بڑی بے حیائی ہے اور بہت برا راستہ ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmlxii{اور جس جان کا مارنا اللہ نے حرام قرار دیا ہے اس کو قتل نہ کرو۔ مگر حق کے ساتھ اور جو شخص ناحق قتل کیا جائے تو ہم نے اس کے وارث کو (قصاص کا) اختیار دے دیا ہے پس چاہیئے کہ وہ قتل میں حد سے آگے نہ بڑھے ضرور اس کی مدد کی جائے گی۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmlxiii{اور یتیم کے مال کے قریب بھی نہ جاؤ سوائے احسن طریقہ کے یہاں تک کہ وہ اپنی پختگی کے سن و سال (جوانی) تک پہنچ جائے اور (اپنے عہد) کو پورا کرو بے شک عہد کے بارے میں تم سے بازپرس کی جائے گی۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmlxiv{اور جب ناپو تولو تو ناپ پوری پوری رکھا کرو اور جب تولو تو صحیح ترازو سے تولو یہی بہتر ہے اور انجام کے اعتبار سے بھی بہت اچھا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmlxv{اور جس چیز کا تمہیں علم نہیں ہے اس کے پیچھے نہ پڑو یقیناً کان، آنکھ اور دل ان سب کے بارے میں (تم سے) بازپرس کی جائے گی۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmlxvi{اور زمین میں اکڑتے ہوئے نہ چلو کیونکہ تم (اس طرح چلنے سے) نہ زمین کو پھاڑ سکتے ہو اور نہ لمبائی میں پہاڑوں تک پہنچ سکتے ہو۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmlxvii{ان سب باتوں میں سے ہر بری بات اللہ کو سخت ناپسند ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmlxviii{یہ سب باتیں حکمت و دانائی کی ان باتوں میں سے ہیں جو آپ کے پروردگار کی طرف سے آپ پر وحی کی گئی ہیں اللہ کے ساتھ کوئی دوسرا الٰہ (خدا) قرار نہ دو ورنہ اس حال میں جہنم میں ڈالے جاؤگے کہ تم ملامت زدہ اور راندۂ بارگاہ ہوگے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmlxix{کیا تمہارے پروردگار نے تمہیں تو بیٹوں کے لئے منتخب کر لیا اور خود اپنے لئے فرشتوں کو بیٹیاں بنا لیا؟ اس میں شک نہیں ہے کہ تم بڑی سخت بات کہتے ہو۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmlxx{اور بے شک ہم نے (مطالبِ حقہ کو) اس قرآن میں مختلف انداز میں بار بار بیان کیا ہے تاکہ وہ نصیحت حاصل کریں مگر (اس تکرار) نے ان کی نفرت میں اضافہ کیا ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmlxxi{(اے پیغمبر(ص)!) آپ کہہ دیجیے کہ اگر اس (خدا) کے ساتھ اور خدا بھی ہوتے جیساکہ یہ (کافر) کہتے ہیں تو وہ ضرور مالکِ عرش تک پہنچنے کا کوئی راستہ تلاش کرتے (اور مقابلہ تک نوبت پہنچ جاتی)۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmlxxii{وہ پاک ہے اور کہیں برتر و بالا ہے ان باتوں سے جو یہ لوگ کہتے ہیں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmlxxiii{ساتوں آسمان اور زمین اور جو کوئی بھی ان میں موجود ہیں اس کی تسبیح کرتے ہیں اور کوئی بھی چیز ایسی نہیں ہے جو حمد کے ساتھ اس کی تسبیح نہ کرتی ہو۔ لیکن تم ان کی تسبیح کو سمجھتے نہیں ہو بے شک وہ بڑا بردبار، بڑا بخشنے والا ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmlxxiv{(اے پیغمبر(ص)!) جب آپ قرآن پڑھتے ہیں تو ہم آپ کے اور ان لوگوں کے درمیان جو آخرت پر ایمان نہیں رکھتے ایک پوشیدہ پردہ ڈال دیتے ہیں۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmlxxv{اور (ان کے پیہم انکار کی وجہ سے گویا) ہم نے ان کے دلوں پر پردے ڈال دیے ہیں تاکہ وہ اسے نہ سمجھیں اور کانوں میں گرانی (پیدا کر دیتے ہیں) اور جب آپ قرآن میں اپنے واحد و یکتا پروردگار کا ذکر کرتے ہیں تو وہ لوگ نفرت کرتے ہوئے پچھلے پاؤں پلٹ جاتے ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmlxxvi{ہم خوب جانتے ہیں کہ وہ غور سے کیا سنتے ہیں؟ جب یہ آپ کی طرف کان لگاتے ہیں اور (ہم خوب جانتے ہیں) جب یہ ظالم سرگوشیاں کرتے ہوئے کہتے ہیں کہ تم تو ایک سحر زدہ آدمی کی پیروی کر رہے ہو۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmlxxvii{دیکھیے یہ کیسی کیسی مثالیں آپ کے لئے بناتے ہیں جس کی وجہ سے وہ ایسے گمراہ ہوگئے ہیں کہ راستہ پا ہی نہیں سکتے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmlxxviii{اور وہ کہتے ہیں کہ جب ہم (مر کر) ہڈیاں اور چُورا ہو جائیں گے تو کیا از سرِ نو پیدا کرکے اٹھائے جائیں گے؟\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmlxxix{کہہ دیجیے! کہ تم پتھر ہو جاؤ یا لوہا۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmlxxx{یا کوئی اور ایسی چیز (جس کا دوبارہ پیدا ہونا) تمہارے خیال میں بڑا (مشکل) ہو (بہرحال تمہیں دوبارہ زندہ کیا جائے گا) وہ (یہ سن کر) ضرور کہیں گے کہ کون ہمیں دوبارہ (زندہ کرکے) لائے گا؟ کہہ دیجیے! وہی جس نے تمہیں پہلی بار پیدا کیا پس وہ اپنے سر جھکا کر کہیں گے کہ کب ایسا ہوگا؟ کہہ دیجئے! کہ شاید بالکل قریب ہو۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmlxxxi{وہی دن کہ جب (خدا) تمہیں بلائے گا تو تم اس کی حمد کے ساتھ لبیک کہوگے اور خیال کروگے تم بہت تھوڑی مدت (عالمِ برزخ میں) رہے ہو۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmlxxxii{(اے رسول) میرے بندوں سے کہہ دو کہ وہ (لوگوں سے) ایسی بات کریں جو بہترین ہو۔ بے شک شیطان ان کے درمیان فساد ڈالتا ہے۔ یقیناً شیطان انسان کا کھلا ہوا دشمن ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiii{تمہارا پروردگار تمہیں خوب جانتا ہے وہ اگر چاہے تو تم پر رحم کرے اور اگر چاہے تو تمہیں سزا دے۔ (اے رسول(ص)) ہم نے آپ کو ان پر داروغہ بنا کر نہیں بھیجا۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiv{آپ کا پروردگار خوب جانتا ہے ان کو جو آسمانوں اور زمین میں ہیں اور ہم نے بعض بندوں کو بعض پر فضیلت دی ہے اور ہم نے داؤد کو زبور عطا کی۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmlxxxv{(اے رسول(ص)) ان لوگوں سے کہہ دو کہ جنہیں تم اللہ کے سوا (کارساز) سمجھتے ہو۔ ذرا انہیں پکار کر دیکھو۔ وہ نہ تو تم سے تکلیف دور کر سکتے ہیں اور نہ ہی (اسے) بدل سکتے ہیں۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvi{جن کو یہ لوگ پکارتے ہیں وہ تو خود اپنے پروردگار کی بارگاہ میں وسیلہ تلاش کر رہے ہیں کہ کون زیادہ قرب رکھنے والا ہے؟ اور وہ اللہ کی رحمت کی امید رکھتے ہیں اور اس کے عذاب سے ڈرتے ہیں۔ بے شک تمہارے پروردگار کا عذاب ڈرنے کے قابل ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvii{کوئی بستی ایسی نہیں ہے جسے ہم قیامت سے پہلے ہلاک نہ کر دیں یا سخت عذاب میں مبتلا کر دیں یہ بات کتاب (نوشتۂ تقدیر) میں لکھی ہوئی ہے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmlxxxviii{اور (منکرین کی مطلوبہ) نشانیاں بھیجنے سے ہمیں کسی چیز نے نہیں روکا۔ مگر اس بات نے کہ پہلے لوگ انہیں جھٹلا چکے ہیں۔ اور ہم نے قومِ ثمود کو ایک (خاص) اونٹنی دی جوکہ روشن نشانی تھی۔ تو انہوں نے اس پر ظلم کیا اور ہم نشانیاں صرف ڈرانے کیلئے بھیجتے ہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmlxxxix{(اے رسول وہ وقت یاد کرو) جب ہم نے آپ سے کہا تھا کہ آپ کے پروردگار نے لوگوں کو گھیرے میں لے لیا ہے اور جو منظر ہم نے آپ کو دکھایا تھا۔ اس کو اور اس درخت کو جس پر قرآن میں لعنت کی گئی ہے، ہم نے لوگوں کیلئے آزمائش کا ذریعہ بنایا ہے اور ہم انہیں ڈراتے ہیں مگر یہ ڈرانا ان کی سرکشی میں اضافہ ہی کر رہا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmxc{(وہ وقت یاد کرو) جب ہم نے فرشتوں سے کہا تھا آدم(ع) کے سامنے سجدہ ریز ہو جاؤ تو سب نے سجدہ کیا سوائے ابلیس کے۔ اس نے کہا کیا میں اس کو سجدہ کروں جسے تو نے مٹی سے پیدا کیا ہے؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmxci{نیز اس نے کہا بھلا مجھے بتا تو سہی یہ شخص جس کو تو نے مجھ پر فضیلت دی ہے (آخر کیوں افضل ہے) اگر تو مجھے قیامت کے دن تک مہلت دے دے تو میں چند افراد کے سوا اس کی پوری اولاد کی بیخ کنی کر ڈالوں گا۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmxcii{ارشاد ہوا چل نکل جا! ان میں سے جو کوئی بھی تیری پیروی کرے گا تو بے شک جہنم تم سب کی پوری پوری سزا ہے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmxciii{اور ان میں سے جس پر تیرا قابو چلتا ہے اپنی پکار سے اسے ورغلا اور ان پر اپنے سواروں اور پیادوں سے چڑھائی کر اور ان کے مالوں اور اولاد میں شریک ہو جا۔ اور ان سے وعدے کر۔ اور شیطان تو دھوکے اور فریب کے سوا ان سے کوئی وعدہ کرتا ہی نہیں ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmxciv{بے شک جو میرے خاص بندے ہیں ان پر تیرا کوئی قابو نہیں ہے اور کارسازی کیلئے آپ کا پروردگار کافی ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmxcv{تمہارا پروردگار وہ ہے جو سمندر میں تمہارے لئے کشتی چلاتا ہے تاکہ تم اس کا فضل (مال) تلاش کرو یقینا وہ تم پر بڑا مہربان ہے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmxcvi{اور جب تمہیں سمندر میں کوئی تکلیف پہنچتی ہے۔ تو اس کے سوا جس جس کو تم پکارتے ہو وہ سب غائب ہو جاتے ہیں اور جب وہ تمہیں (خیریت سے) خشکی پر پہنچا دیتا ہے تو تم روگردانی کرنے لگتے ہو اور انسان بڑا ہی ناشکرا ہے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmxcvii{کیا تم اس بات سے بے فکر ہوگئے ہو کہ وہ تمہیں خشکی کے کسی گوشے میں زمین کے اندر دھنسا دے یا تم پر کوئی پتھر برسانے والی آندھی بھیج دے۔ پھر تم کسی کو بھی اپنا کارساز نہیں پاؤگے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmxcviii{کیا تم اس بات سے بے فکر ہوگئے ہو کہ وہ تمہیں دوبارہ اسی (سمندر) میں پہنچائے اور پھر تم پر طوفانی ہوا چلا کر تمہیں ناشکرے پن کی پاداش میں غرق کر دے۔ پھر تم اس کی ہم سے بازپرس کرنے والا کوئی نہیں پاؤگے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmxcix{بے شک ہم نے اولادِ آدم کو بڑی عزت و بزرگی دی ہے اور ہم نے انہیں خشکی اور تری میں سوار کیا (سواریاں دیں) پاک و پاکیزہ چیزوں سے روزی دی اور انہیں اپنی مخلوقات پر (جو بہت ہیں) فضیلت دی۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmc{اس دن (کو یاد کرو) جب ہم (ہر دور کے) تمام انسانوں کو انکے امام (پیشوا) کے ساتھ بلائیں گے پس جس کسی کو اس کا نامۂ اعمال دائیں ہاتھ میں دیا جائے گا تو یہ لوگ اپنا صحیفۂ اعمال (خوش خوش) پڑھیں گے اور ان پر ذرہ برابر بھی ظلم نہیں کیا جائے گا۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmci{اور جو کوئی اس دنیا میں اندھا بنا رہا وہ آخرت میں بھی اندھا ہی ہوگا اور بڑا راہ گم کردہ ہوگا۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcii{(اے رسول(ص)) یہ (کافر) اس بات میں کوشاں تھے (اور اس کا ارادہ کر لیا تھا کہ) آپ کو اس (کتاب) سے پھیر دیں جو ہم نے آپ کی طرف بذریعۂ وحی بھیجی ہے تاکہ آپ اس کے خلاف کوئی بات گڑھ گھڑ کر ہماری طرف منسوب کریں اور اس صورت میں وہ ضرور آپ کو اپنا گہرا دوست بنا لیتے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmciii{اور اگر ہم آپ کو ثابت قدم نہ رکھتے تو آپ کچھ نہ کچھ ضرور ان کی طرف جھک جاتے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmciv{اور اگر آپ ایسا کرتے تو ہم آپ کو دنیا میں عذاب کا مزہ چکھاتے اور مرنے پر بھی دوہرے عذاب کا مزہ چکھاتے۔ پھر آپ ہمارے مقابلہ میں کوئی یار و مددگار نہ پاتے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcv{اور یہ لوگ اس بات میں بھی کوشاں تھے کہ اس سر زمین سے آپ کے قدم اکھیڑ دیں اور اس طرح آپ کو یہاں سے نکال دیں اور اگر وہ ایسا کریں گے تو وہ خود بھی آپ کے بعد زیادہ دیر نہیں ٹھہریں گے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcvi{یہی ہمارا دستور رہا ہے ان رسولوں کے بارے میں جنہیں ہم نے پہلے بھیجا ہے اور آپ ہمارے اس دستور میں کوئی تبدیلی نہیں پائیں گے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcvii{(اے پیغمبر(ص)) زوالِ آفتاب سے لے کر رات کے اندھیرے تک نماز قائم کرو۔ اور نمازِ صبح بھی۔ کیونکہ صبح کی نماز حضوری کا وقت ہے (اس وقت شب و روز کے فرشتے حاضر ہوتے ہیں)۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcviii{اور رات کے کچھ حصہ (پچھلے پہر) میں قرآن کے ساتھ بیدار رہیں (نمازِ تہجد پڑھیں) یہ آپ کے لئے اضافہ ہے۔ عنقریب آپ کا پروردگار آپ کو مقامِ محمود پر فائز کرے گا۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcix{اور کہیے اے میرے پروردگار! مجھے (ہر جگہ) سچائی کے ساتھ داخل کر اور نکال بھی سچائی کے ساتھ اور میرے لئے اپنی جانب سے ایسی قوت قرار دے جو مددگار ہو۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcx{اور کہیئے! کہ حق آگیا اور باطل مٹ گیا۔ یقیناً باطل تو تھا ہی مٹنے والا۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcxi{اور ہم تنزیلِ قرآن کے سلسلہ میں وہ کچھ نازل کر رہے ہیں جو اہلِ ایمان کے لئے شفاء اور رحمت ہے اور ظالموں کے لئے خسارہ کے سوا اور کسی چیز میں اضافہ نہیں کرتا۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcxii{اور جب ہم انسان کو کوئی نعمت عطا کرتے ہیں تو وہ منہ پھیر لیتا ہے اور پہلو تہی کرتا ہے اور جب اسے کوئی تکلیف پہنچتی ہے تو مایوس ہو جاتا ہے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcxiii{کہہ دیجیے! ہر شخص اپنے طریقہ پر عمل پیرا ہے۔ اب یہ تو تمہارا پروردگار ہی بہتر جانتا ہے کہ ٹھیک راہ پر کون ہے؟\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcxiv{(اے رسول(ص)!) لوگ آپ سے روح کے بارے میں سوال کرتے ہیں۔ کہہ دیجئے کہ روح میرے پروردگار کے امر سے ہے اور تمہیں بہت ہی تھوڑا سا علم دیا گیا ہے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcxv{اور اگر ہم چاہیں تو وہ سب کچھ سلب کر لیں جو ہم نے آپ کی طرف وحی کی ہے۔ اور پھر آپ ہمارے مقابلہ میں کوئی وکیل (حمایتی) بھی نہ پائیں (جو اسے واپس دلا سکے)۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcxvi{مگر یہ آپ کے پروردگار کی خاص رحمت ہے (کہ وہ ایسا نہیں کرتا) بے شک آپ پر اس کا بہت بڑا فضل ہے۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcxvii{کہہ دیجئے کہ اگر سارے انسان اور جن اکٹھے ہو جائیں (اور چاہیں) اس جیسا قرآن لے آئیں تو جب بھی اس جیسا نہیں لا سکیں گے۔ اگرچہ ایک دوسرے کے مددگار بھی بن جائیں۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcxviii{اور یقیناً ہم نے اس قرآن میں ہر طرح کی مثالیں (بار بار) ادل بدل کر بیان کی ہیں لوگوں کے لئے (تاکہ وہ سمجھیں) مگر اکثر لوگ انکار کئے بغیر نہ رہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcxix{اور انہوں نے کہا ہم اس وقت تک آپ کی بات نہیں مانیں گے جب تک آپ یہ کام کرکے نہ دکھا دیں (مثلاً) ہمارے لئے زمین سے چشمہ جاری کریں۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcxx{یا آپ کے لئے کھجوروں اور انگوروں کا ایک باغ ہو اور آپ اس کے درمیان بہت سی نہریں جاری کریں۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcxxi{یا جیساکہ آپ کا خیال ہے آسمان کے ٹکڑے ٹکڑے کرکے ہم پر گرا دیں یا پھر خدا اور فرشتوں کو کھلم کھلا ہمارے سامنے لے آئیں۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcxxii{یا آپ کا خالص سونے کا ایک گھر ہو۔ یا پھر آپ آسمان پر چڑھ جائیں اور ہم آپ کے (آسمان پر) چڑھنے کو بھی اس وقت تک نہیں مانیں گے جب تک ایک (لکھی لکھائی) کتاب اتار کے نہ لے آئیں جسے ہم خود پڑھیں۔ کہہ دیجئے پاک ہے میرا پروردگار میں پیغام پہنچانے والا انسان کے سوا کیا ہوں؟\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcxxiii{جب کبھی لوگوں کے پاس ہدایت پہنچی تو ان کو ایمان لانے سے نہیں روکا مگر اس بات نے کہ کہنے لگے کیا اللہ نے کسی بشر کو رسول بنا کر بھیجا ہے؟\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcxxiv{کہہ دیجئے! کہ اگر زمین میں (انسان کی بجائے) فرشتے ہوتے جو اطمینان و آرام سے چلتے پھرتے تو ہم ضرور ان پر آسمان سے کسی فرشتہ کو رسول(ص) بنا کر بھیجتے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcxxv{(اے رسول(ص)!) کہہ دیئے! کہ میرے اور تمہارے درمیان گواہی کیلئے اللہ ہی کافی ہے۔ بے شک وہ اپنے بندوں کو خوب جانتا ہے۔ (اور) خوب دیکھتا ہے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcxxvi{اور جس کو اللہ ہدایت دے دے وہی ہدایت یافتہ ہے اور جسے (وہ اپنی توفیق سلب کرکے) گمراہی میں چھوڑ دے تو تم اللہ کے سوا اس کا کوئی حامی و مددگار نہیں پاؤگے اور قیامت کے دن ہم ایسے لوگوں کو منہ کے بل اس حال میں اٹھائیں گے کہ وہ اندھے، گونگے اور بہرے ہوں گے۔ ان کا ٹھکانہ جہنم ہے جب بھی وہ بجھنے لگے گی تو ہم اسے اور بھڑکا دیں گے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcxxvii{یہ ان کی سزا ہے کیونکہ انہوں نے ہماری آیتوں کا انکار کیا۔ اور کہا کہ جب ہم (گل سڑ کر) ہڈیاں اور چورہ ہو جائیں گے تو کیا ہم ازسرِنو پیدا کرکے اٹھائے جائیں گے؟\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcxxviii{کیا انہوں نے (اس بات پر) غور نہیں کیا کہ وہ اللہ جس نے آسمانوں اور زمین کو پیدا کیا ہے وہ اس پر بھی ضرور قادر ہے کہ ان جیسوں کو (دوبارہ) پیدا کر دے اور اس نے ان کے (حشر کے) لئے ایک میعاد مقرر کر رکھی ہے جس میں کوئی شک نہیں ہے مگر اس امر میں ظالم انکار کئے بغیر نہ رہے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcxxix{کہہ دیجئے! کہ اگر تم میرے پروردگار کی رحمت کے خزانوں کے مالک بھی ہوتے تو تم ان کے خرچ ہو جانے کے خوف سے (ہاتھ) روک لیتے اور انسان بڑا بخیل ہے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcxxx{اور ہم نے موسیٰ کو نو کھلی نشانیاں عطا فرمائیں۔ آپ بنی اسرائیل سے پوچھ لیں جب کہ وہ (موسیٰ) ان کے پاس آئے تھے! تو فرعون نے اس سے کہا۔ اے موسیٰ! میں تو تمہیں سحر زدہ (یا ساحر) خیال کرتا ہوں۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcxxxi{موسیٰ نے کہا (اے فرعون) تو (دل میں تو) یقیناً جانتا ہے کہ یہ نشانیاں آسمانوں اور زمین کے پروردگار نے بصیرت کا سامان بنا کر نازل کی ہیں۔ اور اے فرعون! میں سمجھتا ہوں کہ تو ایک ہلاکت زدہ آدمی ہے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcxxxii{اس (فرعون) نے ارادہ کیا کہ وہ (موسیٰ اور بنی اسرائیل) کو اس سر زمین سے نکال باہر کرے لیکن ہم نے اسے اور اس کے سب ساتھیوں کو غرق کر دیا۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiii{اور اس (واقعہ) کے بعد ہم نے بنی اسرائیل سے کہا کہ تم اس سر زمین میں سکونت اختیار کرو۔ پس جب آخرت کا وعدہ آجائے گا تو ہم تم (سب) کو (اپنے حضور) سمیٹ لائیں گے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiv{اور ہم نے اس (قرآن) کو حق کے ساتھ نازل کیا ہے اور وہ حق کے ساتھ نازل ہوا ہے۔ اور ہم نے آپ کو بشارت دینے والا اور ڈرانے والا بنا کر بھیجا ہے۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcxxxv{اور ہم نے قرآن کو متفرق طور پر (جدا جدا کرکے) نازل کیا ہے تاکہ آپ اسے لوگوں کے سامنے ٹھہر ٹھہر کر پڑھیں اور ہم نے اسے (موقع بموقع) بتدریج نازل کیا ہے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvi{کہہ دیجیے! کہ تم (لوگ) اس پر ایمان لاؤ یا نہ لاؤ۔ لیکن جن کو اس سے پہلے علم دیا گیا ہے جب اسے ان کے سامنے پڑھا جاتا ہے تو وہ منہ کے بل سجدہ میں گر پڑتے ہیں۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvii{اور کہتے ہیں کہ پاک ہے ہمارا پروردگار! بے شک ہمارے پروردگار کا وعدہ تو پورا ہو کر ہی رہتا ہے۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcxxxviii{اور وہ روتے ہوئے منہ کے بل گر پڑتے ہیں۔ اور یہ (قرآن) ان کے خشوع و خضوع میں اضافہ کر دیتا ہے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcxxxix{کہہ دیجیے! کہ اسے اللہ کہہ کر پکارو یا رحمٰن کہہ کر پکارو جس نام سے بھی اسے پکارو۔ اس کے سارے نام اچھے ہیں اور نہ ہی اپنی نماز زیادہ بلند آواز سے پڑھو اور نہ ہی بالکل آہستہ سے بلکہ ان دونوں کے درمیان کا راستہ اختیار کرو۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcxl{اور کہہ دیجئے! سب تعریفیں اللہ کے لئے ہیں جس نے نہ کسی کو بیٹا بنایا ہے اور نہ ہی کسی کو شریک بنایا ہے اور نہ ہی درماندگی اور عاجزی کی وجہ سے اس کا کوئی مددگار ہے اور اس کی کبریائی اور بڑائی کا بیان کرو جس طرح بڑائی بیان کرنی چاہیئے۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcxli{\basmalahur ہر قسم کی تعریف اس اللہ کے لئے ہے جس نے اپنے بندہ (خاص) پر کتاب نازل کی اور اس میں کسی طرح کی کوئی کمی نہیں رکھی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcxlii{بالکل سیدھی اور ہموار تاکہ وہ (مکذبین کو) اللہ کی طرف سے آنے والے سخت عذاب سے ڈرائے اور ان اہل ایمان کو خوشخبری دے جو نیک عمل کرتے ہیں کہ ان کے لئے بہترین اجر ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcxliii{جس میں وہ ہمیشہ ہمیشہ رہیں گے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcxliv{اور تاکہ وہ ان لوگوں کو ڈرائے جو کہتے ہیں کہ اللہ نے کسی کو اپنا بیٹا بنا لیا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcxlv{اس بارے میں نہ انہیں کوئی علم ہے اور نہ ان کے باپ دادوں کو کوئی علم تھا۔ یہ بہت بڑی بات ہے جو ان کے منہ سے نکلتی ہے۔ یہ لوگ بالکل جھوٹ بولتے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcxlvi{(اے پیغمبر(ص)!) شاید آپ ان کے پیچھے اس رنج و افسوس میں اپنی جان دے دیں گے کہ وہ اس کلام پر ایمان نہیں لائے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcxlvii{بے شک جو کچھ زمین پر ہے ہم نے اسے زمین کی زینت بنایا ہے۔ تاکہ ہم ان لوگوں کو آزمائیں کہ عمل کے لحاظ سے کون بہتر ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcxlviii{اور جو کچھ زمین پر ہے ہم اسے (ایک دن) چٹیل میدان بنانے والے ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcxlix{کیا آپ خیال کرتے ہیں کہ کہف و رقیم (غار اور کتبے) والے ہماری نشانیوں میں سے کوئی عجیب نشانی تھے؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcl{جب ان جوانوں نے غار میں پناہ لی اور کہا اے ہمارے پروردگار! اپنی بارگاہ سے رحمت عطا فرما اور ہمارے لئے اس کام میں ہدایت کا سامان مہیا فرما۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcli{تو ہم نے غار میں کئی برسوں تک ان کے کانوں پر (نیند کا) پردہ ڈال دیا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmclii{پھر ہم نے انہیں اٹھایا۔ تاکہ ہم دیکھیں کہ ان دو گروہوں میں سے کون اپنے ٹھہرنے کی مدت کا زیادہ ٹھیک شمار کر سکتا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcliii{(اے رسول(ص)) ہم آپ کو ان کا اصل قصہ سناتے ہیں وہ چند نوجوان تھے جو اپنے پروردگار پر ایمان لائے اور ہم نے ان کی ہدایت میں اضافہ کر دیا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcliv{اور ہم نے ان کے دل اس وقت اور مضبوط کر دیئے جب وہ کھڑے ہوکر کہنے لگے کہ ہمارا پروردگار وہ ہے جو آسمانوں اور زمین کا پروردگار ہے۔ ہم اس کے سوا اور کسی کو معبود ہرگز نہیں پکاریں گے۔ ورنہ ہم بالکل ناحق بات کے مرتکب ہوں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmclv{یہ ہماری قوم ہے جنہوں نے خدا کو چھوڑ کر اور خدا اپنا لئے ہیں، یہ لوگ ان کی خدائی پر کوئی واضح دلیل کیوں نہیں لاتے؟ پس اس شخص سے بڑا ظالم کون ہوگا جو اللہ پر جھوٹ باندھے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmclvi{اور (پھر آپس میں کہنے لگے) اب جب کہ تم نے ان لوگوں سے اور ان کے ان معبودوں سے جن کی وہ اللہ کے سوا عبادت کرتے ہیں علیٰحدگی اختیار کر لی ہے تو غار میں چل کر پناہ لو۔ تمہارا پروردگار تم پر اپنی رحمت (کا سایہ) تم پر پھیلائے گا۔ اور تمہارے اس کام کے لئے سروسامان مہیا کر دے گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmclvii{اور (وہ غار اس طرح واقع ہوئی ہے کہ) تم دیکھوگے کہ جب سورج طلوع ہوتا ہے تو ان کے غار سے دائیں طرف مڑ جاتا ہے اور جب ڈوبتا ہے تو ان سے بائیں طرف کترا کر نکل جاتا ہے۔ اور وہ ایک کشادہ جگہ پر (سوئے ہوئے) ہیں۔ یہ اللہ کی نشانیوں میں سے ایک (نشانی) ہے جسے اللہ ہدایت دے وہی ہدایت یافتہ ہے اور جسے وہ گمراہی میں چھوڑ دے تو تم اس کے لئے کوئی یار و مددگار اور راہنما نہیں پاؤگے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmclviii{اور تم انہیں دیکھو تو خیال کرو کہ وہ جاگ رہے ہیں حالانکہ وہ سوئے ہوئے ہیں اور ہم انہیں دائیں اور بائیں کروٹ بدلواتے رہتے ہیں اور ان کا کتا غار کے دہانے پر اپنے دونوں بازو پھیلائے بیٹھا ہے اگر تم انہیں جھانک کر دیکھو تو تم الٹے پاؤں بھاگ کھڑے ہو۔ اور تمہارے دل میں دہشت سما جائے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmclix{اور (جس طرح انہیں اپنی قدرت سے سلایا تھا) اسی طرح ہم نے انہیں اٹھایا تاکہ آپس میں سوال و جواب کریں۔ چنانچہ ان میں سے ایک کہنے والے نے کہا کہ تم کتنی دیر ٹھہرے ہوگے؟ دوسروں نے کہا ہم ایک دن ٹھہرے ہوں گے یا دن کا کچھ حصہ (پھر) بولے تمہارا پروردگار ہی بہتر جانتا ہے کہ تم کتنا ٹھہرے؟ اچھا اب اپنے میں سے کسی کو چاندی کا یہ سکہ دے کر شہر میں بھیجو۔ وہ (جا کر) دیکھے کہ کون سا کھانا زیادہ پاک و پاکیزہ ہے۔ تو وہ اس میں سے کچھ کھانا تمہارے لئے لائے۔ اور اسے چاہیے کہ ہوش و تدبر سے کام لے اور کسی کو تمہاری خبر نہ ہونے دے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmclx{یقیناً اگر ان لوگوں کو تمہاری اطلاع ہوگئی تو وہ تمہیں سنگسار کر دیں گے یا پھر (زبردستی) تمہیں اپنے دین کی طرف واپس لے جائیں گے اور اس طرح تم کبھی بھی فلاح نہیں پا سکوگے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmclxi{اور اسی طرح ہم نے لوگوں کو ان پر مطلع کیا تاکہ وہ لوگ جان لیں کہ اللہ کا وعدہ سچھا ہے اور یہ کہ قیامت میں کوئی شک نہیں ہے۔ یہ اس وقت کی بات ہے جب وہ (بستی والے) لوگ ان (اصحافِ کہف) کے معاملہ میں آپس میں جھگڑ رہے تھے (کہ کیا کیا جائے؟) تو (کچھ) لوگوں نے کہا کہ ان پر (یعنی غار پر) ایک (یادگاری) عمارت بنا دو۔ ان کا پروردگار ہی ان کو بہتر جانتا ہے۔ (آخرکار) جو لوگ ان کے معاملات پر غالب آئے تھے وہ بولے کہ ہم ان پر ایک مسجد (عبادت گاہ) بنائیں گے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmclxii{عنقریب کچھ لوگ کہہ دیں گے کہ وہ تین تھے اور چوتھا ان کا کتا تھا۔ اور کچھ کہہ دیں گے کہ وہ پانچ تھے اور چھٹا ان کا کتا تھا۔ (اے رسول(ص)) کہہ دیجیئے کہ میرا پروردگار ہی ان کی تعداد کو بہتر جانتا ہے۔ اور بہت کم لوگوں کو ان کا علم ہے۔ سو ان کے بارے میں سوائے سرسری گفتگو کے لوگوں سے زیادہ بحث نہ کریں اور نہ ہی ان کے بارے میں ان میں سے کسی سے کچھ پوچھیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmclxiii{اور آپ کسی چیز کے بارے میں یہ نہ کہیں کہ میں کل اسے ضرور کروں گا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmclxiv{مگر یہ کہ خدا چاہے (یعنی اس کے ساتھ انشاء اللہ کہا کرو) اور جب بھی بھول جائیں تو اپنے پروردگار کو یاد کریں۔ اور آپ کہہ دیجئے! کہ امید ہے کہ میرا پروردگار ایسی بات کی مجھے راہنمائی کرے جو رشد و ہدایت میں اس سے بھی زیادہ قریب ہو۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmclxv{اور وہ لوگ غار میں رہے نو برس اوپر تین سو سال۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmclxvi{کہہ دیجئے! کہ اللہ ہی بہتر جانتا ہے کہ وہ کتنا رہے؟ تمام آسمانوں اور زمین کا (علمِ) غیب اسی کے لئے ہے وہ کتنا بڑا دیکھنے والا اور کتنا بڑا سننے والا ہے۔ اللہ کے سوا ان لوگوں کا کوئی سرپرست نہیں ہے اور نہ وہ کسی کو اپنے حکم میں شریک کرتا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmclxvii{(اے رسول) آپ کے پروردگار کی طرف کتاب (قرآن) کے ذریعہ سے جو وحی کی گئی ہے۔ اسے پڑھ سنائیں۔ اس کی باتوں کو کوئی بدلنے والا نہیں ہے۔ اور آپ اس کے سوا کوئی جائے پناہ نہیں پائیں گے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmclxviii{(اے رسول(ص)!) جو لوگ صبح و شام اپنے پروردگار کو پکارتے ہیں اور اس کی رضا کے طلبگار ہیں آپ ان کی معیت پر صبر کریں۔ اور دنیا کی زینت کے طلبگار ہوتے ہوئے ان کی طرف سے آپ کی آنکھیں نہ پھر جائیں۔ اور جس کے دل کو ہم نے اپنی یاد سے غافل چھوڑ رکھا ہے اور وہ اپنی خواہش کی پیروی کرتا ہے اور اس کا معاملہ حد سے گزر گیا ہے اس کی اطاعت نہ کریں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmclxix{اور آپ کہہ دیجئے کہ حق تمہارے پروردگار کی طرف سے ہے تو جو چاہے ایمان لائے اور جو چاہے کفر اختیار کرے۔ بے شک ہم نے ظالموں کیلئے ایسی آگ تیار کر رکھی ہے جس کی قناطیں انہیں گھیر لیں گی اور اگر وہ فریاد کریں گے تو ان کی فریاد رسی ایسے پانی سے کی جائے گی جو پگھلے ہوئے تانبے کی طرح ہوگا۔ جو چہروں کو بھون ڈالے گا کیا بری چیز ہے پینے کی۔ اور کیا بری آرام گاہ ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmclxx{بے شک جو لوگ ایمان لائے اور نیک عمل کئے۔ یقینا ہم نیکوکار لوگوں کا اجر ضائع نہیں کرتے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmclxxi{یہ وہ لوگ ہیں جن کے لئے ہمیشگی کے باغات ہیں جن کے نیچے نہریں جاری ہوں گی انہیں ان میں سونے کے کنگن پہنائے جائیں گے۔ سبز ریشم کے باریک اور دبیز کپڑے پہنیں گے اور وہ ان میں مسندوں پر گاؤ تکیہ لگائے بیٹھے ہوں گے۔ کیا ہی اچھا ہے ان کا ثواب اور کیا ہی اچھی ہے ان کی آرام گاہ۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmclxxii{(اے رسول(ص)!) ان لوگوں کے سامنے ان دو شخصوں کی مثال پیش کریں کہ ہم نے ان میں سے ایک کو انگور کے دو باغ دے رکھے تھے اور انہیں کھجور کے درختوں سے گھیر رکھا تھا۔ اور ان کے درمیان کھیتی اگا دی تھی۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmclxxiii{یہ دونوں باغ خوب پھل دیتے تھے اور اس میں کچھ بھی کمی نہیں کی اور ہم نے ان کے درمیان (آبپاشی کیلئے) ایک نہر بھی جاری کر دی تھی۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmclxxiv{اور اس کے پاس اور بھی تمول کا سامان تھا۔ (ایک دن گھمنڈ میں آکر) اس نے اپنے (غریب) ساتھی سے باتیں کرتے ہوئے کہا کہ میں مال کے اعتبار سے تجھ سے زیادہ (مالدار) ہوں اور نفری کے لحاظ سے بھی تجھ سے زیادہ طاقتور ہوں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmclxxv{اور وہ (ایک دن) اپنے باغ میں داخل ہوا جبکہ وہ اپنے اوپر ظلم کرنے والا تھا (اور) کہنے لگا کہ میں خیال نہیں کرتا کہ یہ (باغ) کبھی تباہ ہو جائے گا۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmclxxvi{اور میں خیال نہیں کرتا کہ کبھی قیامت برپا ہوگی اور اگر (بالفرض) میں کبھی اپنے پروردگار کی طرف لوٹایا گیا تو اس (باغ) سے بہتر ٹھکانہ پاؤں گا۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmclxxvii{اس کے ساتھی نے اس سے باتیں کرتے ہوئے کہا کہ کیا تو اس ہستی کا انکار کرتا ہے جس نے تجھے پہلے مٹی سے اور پھر نطفہ سے پیدا کیا پھر تجھے اچھا خاصا مرد بنایا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmclxxviii{لیکن میں! تو میرا پروردگار تو وہی اللہ ہے اور میں اپنے پروردگار کے ساتھ کسی کو شریک نہیں کرتا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmclxxix{اور تو جب اپنے باغ میں داخل ہوا تو کیوں نہ کہا؟ ماشاء اللہ لا قوۃ الا باللہ (جو اللہ چاہتا ہے وہی ہوتا ہے اور خدا کی قوت کے بغیر کوئی قوت نہیں ہے)۔ اور اگر تو مجھے مال و اولاد میں (اپنے سے) کمتر دیکھتا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmclxxx{تو قریب ہے کہ میرا پروردگار مجھے تیرے باغ سے بہتر (باغ) عطا فرمائے اور تیرے باغ پر آسمان سے بجلیاں بھیج دے جس سے وہ چٹیل چکنا میدان بن کر رہ جائے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmclxxxi{یا اس کا پانی اس طرح نیچے اتر جائے کہ تو کسی طرح بھی اسے حاصل نہ کر سکے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmclxxxii{(چنانچہ) اس کے پھلوں کو گھیرے میں لے لیا گیا (ان پر آفت آگئی) تو اس نے باغ پر جو کچھ خرچ کیا تھا اس پر کفِ افسوس ملتا تھا اور وہ (باغ) اپنے چھپروں پر گرا پڑا تھا۔ اور وہ کہتا تھا کہ اے کاش کہ میں نے کسی کو اپنے پروردگار کا شریک نہ بنایا ہوتا۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiii{اب اس کے پاس کوئی ایسا گروہ بھی نہیں تھا جو اللہ کے مقابلہ میں اس کی مدد کرتا اور نہ ہی وہ غالب اور بدلہ لینے کے قابل تھا۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiv{(ثابت ہوا) کہ ہر قسم کا اختیار خدائے برحق کیلئے ہے۔ وہی بہتر ثواب دینے والا اور وہی بہترین انجام والا ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmclxxxv{اور آپ ان لوگوں کے سامنے زندگانئ دنیا کی (ایک اور) مثال پیش کریں کہ وہ ایسی ہے جیسے ہم نے آسمان سے پانی برسایا تو اس سے زمین کی نباتات مل گئی (اور خوب پھلی پھولی) پھر وہ ریزہ ریزہ ہوگئی جسے ہوائیں اڑائے پھرتی ہیں اور اللہ ہر چیز پر قدرت رکھتا ہے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvi{مال اور اولادِ زندگانی دنیا کی (ہنگامی) زیب و زینت ہیں اور (دراصل) باقی رہنے والی نیکیاں تمہارے پروردگار کے نزدیک ثواب کے لحاظ سے بھی اور امید کے اعتبار سے بھی کہیں بہتر ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvii{اور وہ دن (یاد کرو) جب ہم پہاڑوں کو چلائیں گے اور تم زمین کو دیکھوگے کہ وہ کھلا ہوا میدان ہے اور ہم اس طرح سب لوگوں کو جمع کریں گے کہ کسی ایک کو بھی نہیں چھوڑیں گے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmclxxxviii{اور وہ تمہارے پروردگار کے حضور صفیں باندھے پیش کئے جائیں گے (تب ان سے کہا جائے گا) آخر تم اسی طرح ہمارے پاس آگئے ہو جس طرح ہم نے تمہیں پہلی مرتبہ پیدا کیا تھا۔ ہاں البتہ تم نے یہ خیال کیا تھا کہ ہم نے تمہارے لئے (دوبارہ پیدا کرنے کا) کوئی وعدہ گاہ مقرر نہیں کیا ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmclxxxix{اور نامۂ اعمال (سامنے) رکھ دیا جائے گا اور تم دیکھو گے کہ مجرم لوگ اس کے مندرجات سے ڈر رہے ہوں گے اور کہتے ہوں گے۔ ہائے ہماری کم بختی! یہ کیسا نامۂ عمل ہے؟ جس نے (ہمارا) کوئی چھوٹا بڑا (گناہ) نہیں چھوڑا مگر سب کو درج کر لیا ہے۔ اور جو کچھ ان لوگوں نے کیا تھا وہ سب اپنے اپنے سامنے پائیں گے اور تمہارا پروردگار کسی پر ظلم نہیں کرتا۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcxc{اور (وہ وقت یاد کرو) جب ہم نے فرشتوں سے کہا کہ آدم کے سامنے سجدہ ریز ہو جاؤ۔ تو سب نے سجدہ کیا سوائے ابلیس کے وہ جنات میں سے تھا۔ اس نے اپنے پروردگار کے حکم کی سرتابی کی۔ کیا تم (اے منکرینِ حق) مجھے چھوڑ کر اس کو اور اس کی اولاد کو اپنا سرپرست و کارساز بناتے ہو؟ حالانکہ وہ تمہارا دشمن ہے۔ ظالموں کیلئے کیا ہی برا بدل ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcxci{اور میں نے انہیں آسمان و زمین کی پیدائش کے وقت حاضر نہیں کیا اور نہ ہی ان کی اپنی خلقت کے وقت اور میں ایسا نہیں ہوں کہ گمراہ کرنے والوں کو اپنا دست و بازو بناؤں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcxcii{اور وہ دن (یاد رکھو) جب وہ (اللہ مشرکین سے) فرمائے گا کہ بلاؤ میرے ان شریکوں کو جن کو تم میرا شریک خیال کرتے تھے۔ چنانچہ وہ انہیں پکاریں گے لیکن وہ انہیں کوئی جواب نہیں دیں گے اور ہم ان کے درمیان ایک آڑ مقرر کر دیں گے کہ وہ ایک دوسرے کی بات نہیں سن سکتے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcxciii{اور جب مجرم لوگ (دوزخ کی) آگ دیکھیں گے تو وہ خیال کریں گے کہ وہ اس میں گرنے والے ہیں اور وہ اس سے بچنے کی کوئی راہ نہیں پائیں گے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcxciv{اور ہم نے اس قرآن میں لوگوں (کی ہدایت) کے لئے ہر قسم کی مثالیں الٹ پلٹ کر بیان کر دی ہیں۔ (مگر) انسان ہر چیز سے بڑھ کر جھگڑالو ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcxcv{اور جب لوگوں کے پاس ہدایت آگئی ہے تو ان کو ایمان لانے اور مغفرت طلب کرنے سے منع نہیں کیا۔ مگر اس چیز نے کہ اگلی قوموں کا معاملہ انہیں بھی پیش آئے یا عذاب ان کے سامنے آئے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcxcvi{اور ہم رسولوں کو نہیں بھیجتے۔ مگر خوشخبری دینے والا اور ڈرانے والا بنا کر۔ اور جو کافر ہیں وہ باطل کے (ہتھیار سے) جھگڑتے ہیں تاکہ اس کے ذریعہ سے حق کو باطل کر دیں اور انہوں نے میری آیتوں کو اور جس چیز (عذاب) سے انہیں ڈرایا گیا تھا اس کو مذاق بنا رکھا ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcxcvii{اور اس شخص سے بڑھ کر ظالم کون ہے جسے اس کے پروردگار کی نشانیوں کے ذریعہ سے نصیحت کی جائے مگر وہ ان سے روگردانی کرے اور اپنے ان (گناہوں) کو بھول جائے۔ جو وہ اپنے ہاتھوں پہلے بھیج چکا ہے ہم نے ان کے دلوں پر پردے ڈال دیئے ہیں کہ اس کو سمجھیں اور ان کے کانوں میں گرانی ڈال دی ہے۔ کہ اس کو سنیں (یہ حق سے اعراض کرنے کی سزا ہے) اور اگر انہیں ہدایت کی طرف بلائیں تو وہ اس حالت میں کبھی راہِ راست پر نہیں آئیں گے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcxcviii{اور آپ کا پروردگار بڑا بخشنے والا، رحمت والا ہے اگر وہ لوگوں سے ان کے کئے (گناہوں) کا مواخذہ کرتا تو جلدی ہی میں ان پر عذاب نازل کر دیتا مگر ان کے لئے ایک میعاد ٹھہرا دی گئی ہے اس سے ادھر (پہلے) کوئی جائے پناہ نہیں پائیں گے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcxcix{اور یہ بستیاں ہیں جب (ان کے باشندوں نے) ظلم و زیادتی کی تو ہم نے انہیں ہلاک کر ڈالا اور ہم نے ان کی ہلاکت کے لئے ایک میعاد مقرر کر دی تھی۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcc{اور (وہ وقت یاد کرو) جب موسیٰ (ع) نے اپنے جوان سے کہا کہ میں برابر سفر جاری رکھوں گا یہاں تک کہ اس جگہ پہنچوں جہاں دو دریا اکٹھے ہوتے ہیں یا پھر (یونہی چلتے چلتے) سالہا سال گزار دوں گا۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcci{تو جب وہ دونوں ان دونوں دریاؤں کے اکٹھا ہونے کی جگہ پر پہنچے تو وہ دونوں اپنی مچھلی کو بھول گئے اور اس نے دریا میں داخل ہونے کے لئے سرنگ کی طرح اپنا راستہ بنا لیا۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmccii{جب وہ دونوں وہاں سے آگے بڑھ گئے۔ تو موسیٰ نے اپنے جوان سے کہا ہمارا صبح کا کھانا (ناشتہ) لاؤ۔ یقینا ہمیں اس سفر میں بڑی مشقت اٹھانا پڑی ہے۔ (ہم بہت تھک گئے ہیں)۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcciii{اس (جوان) نے کہا کیا آپ نے دیکھا تھا؟ کہ جب ہم اس چٹان کے پاس (سستانے کیلئے) ٹھہرے ہوئے تھے تو میں مچھلی کو بھول گیا۔ اور شیطان نے مجھے ایسا غافل کیا کہ میں (آپ سے) اس کا ذکر کرنا بھی بھول گیا اور اس نے عجیب طریقہ سے دریا میں اپنا راستہ بنا لیا۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcciv{موسیٰ نے کہا یہی تو وہ (مقام) تھا جس کی ہمیں تلاش تھی (اور جسے ہم چاہتے تھے) چنانچہ وہ دونوں اپنے پاؤں کا نشان دیکھتے ہوئے واپس ہوئے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmccv{سو انہوں نے وہاں ہمارے بندوں میں سے ایک (خاص) بندہ کو پایا۔ جسے ہم نے اپنی خاص رحمت سے نوازا تھا۔ اور اسے اپنی طرف سے (خاص) علم عطا کیا تھا۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmccvi{موسیٰ نے اس سے کہا! کیا میں آپ کے ساتھ رہ سکتا ہوں بشرطیکہ رشد و ہدایت کا وہ خصوصی علم جو آپ کو سکھایا گیا ہے اس میں سے کچھ مجھے بھی سکھا دیں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmccvii{اس نے (جواب میں) کہا کہ آپ میرے ساتھ (رہ کر) صبر نہیں کر سکتے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmccviii{اور بھلا اس بات پر آپ صبر کر بھی کیسے سکتے ہیں جو تمہارے علمی دائرہ سے باہر ہے؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmccix{موسیٰ نے کہا انشاء اللہ آپ مجھے صابر پائیں گے اور میں آپ کے کسی حکم کی خلاف ورزی نہیں کروں گا۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmccx{اس نے کہا کہ اگر آپ میرے ساتھ رہنا چاہتے ہیں تو آپ کسی چیز کے بارے میں مجھ سے سوال نہ کریں۔ جب تک میں خود آپ سے اس کا ذکر نہ کروں۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmccxi{اس کے بعد دونوں چل پڑے یہاں تک کہ جب کشتی میں سوار ہوگئے تو خضر (ع) نے اس میں سوراخ کر دیا۔ موسیٰ نے کہا۔ آپ نے اس لئے کشتی میں سوراخ کیا ہے کہ سب کشتی والوں کو غرق کر دیں؟ آپ نے بڑی عجیب حرکت کی ہے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmccxii{خضر نے کہا۔ کیا میں نے نہیں کہا تھا کہ آپ صبر نہیں کر سکیں گے؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmccxiii{موسیٰ نے کہا جو بھول ہوگئی اس پر مجھ سے مؤاخذہ نہ کریں اور اس معاملہ میں مجھ سے زیادہ سختی نہ کریں۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmccxiv{چنانچہ پھر دونوں چل پڑے یہاں تک کہ ایک لڑکے سے ملے تو اس بندہ نے اسے قتل کر دیا۔ موسیٰ نے کہا آپ نے ایک پاکیزہ نفس (بے گناہ) کو قصاص کے بغیر قتل کر دیا۔ یہ تو آپ نے سخت برا کام کیا۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmccxv{خضر (ع) نے کہا کیا میں نے تم سے کہا نہ تھا کہ آپ میرے ساتھ صبر نہیں کر سکیں گے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmccxvi{موسیٰ (ع) نے کہا (اچھا) اگر اس کے بعد آپ سے کسی چیز کے متعلق پوچھوں تو آپ مجھے اپنے ساتھ نہ رکھیں۔ بےشک آپ میری طرف سے عذر کی حد تک پہنچ گئے ہیں (اب آپ معذور ہیں)۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmccxvii{اس کے بعد وہ دونوں آگے چلے یہاں تک کہ ایک گاؤں والوں کے پاس پہنچے اور ان سے کھانا طلب کیا۔ مگر انہوں نے ان کی مہمانداری کرنے سے انکار کر دیا۔ پھر ان دونوں نے وہاں ایک دیوار پائی جو گرا چاہتی تھی۔ تو خضر (ع) نے اسے (بنا کر) سیدھا کھڑا کر دیا۔ (اس پر) موسیٰ (ع) نے کہا اگر آپ چاہتے تو اس کام کی (ان لوگوں سے) کچھ اجرت ہی لے لیتے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmccxviii{خضر (ع) نے کہا بس (ساتھ ختم ہوا) اب میری اور تمہاری جدائی ہے اب میں تمہیں ان باتوں کی حقیقت بتاتا ہوں جن پر تم صبر نہ کر سکے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmccxix{جہاں تک کشتی کا معاملہ ہے تو وہ چند مسکینوں کی تھی جو دریا پر کام کرتے تھے۔ میں نے چاہا کہ اسے عیب دار بنا دوں کیونکہ ادھر ایک (ظالم) بادشاہ تھا جو ہر (بے عیب) کشتی پر زبردستی قبضہ کر لیتا تھا۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmccxx{اور جہاں تک اس بچے کا معاملہ ہے تو اس کے ماں باپ مؤمن تھے ہمیں اندیشہ ہوا کہ یہ (بڑا ہوکر) ان کو بھی سرکشی اور کفر میں مبتلا کر دے گا۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmccxxi{تو ہم نے چاہا کہ ان کا پروردگار اس کے عوض انہیں ایسی اولاد دے جو پاکیزگی میں اس سے بہتر ہو اور مہر و محبت میں اس سے بڑھ کر ہو۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmccxxii{باقی رہا دیوار کا معاملہ تو وہ اس شہر کے دو یتیم بچوں کی تھی اور اس کے نیچے ان بچوں کا خزانہ (دفن) تھا۔ اور ان کا باپ نیک آدمی تھا۔ تو تمہارے پروردگار نے چاہا کہ وہ بچے اپنی جوانی کو پہنچیں اور اپنا خزانہ نکالیں اور یہ سب کچھ پروردگار کی رحمت کی بناء پر ہوا ہے۔ اور میں نے جو کچھ کیا ہے اپنی مرضی سے نہیں کیا (بلکہ خدا کے حکم سے کیا) یہ ہے حقیقت ان باتوں کی جن پر تم صبر نہ کر سکے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmccxxiii{(اے رسول(ص)) لوگ آپ سے ذوالقرنین کے بارے میں سوال کرتے ہیں۔ آپ کہہ دیجئے کہ میں عنقریب ان کا کچھ حال تمہیں سناتا ہوں۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmccxxiv{ہم نے اسے زمین میں اقتدار عطا کیا تھا اور اسے ہر طرح کا ساز و سامان مہیا کر دیا تھا۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmccxxv{پھر اس نے (ایک مہم کیلئے) ساز و سامان کیا۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmccxxvi{یہاں تک کہ وہ (چلتے چلتے) غروبِ آفتاب کے مقام پر پہنچ گیا تو اسے ایک سیاہ چشمے میں غروب ہوتا ہوا پایا۔ (محسوس کیا) اور اس کے پاس ایک قوم کو (آباد) پایا۔ ہم نے کہا اے ذوالقرنین! (تمہیں اختیار ہے) خواہ انہیں سزا دو یا ان کے ساتھ حسن سلوک کا رویہ اختیار کرو۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmccxxvii{ذوالقرنین نے کہا کہ (ہم بے انصافی نہیں کریں گے) جو ظلم و سرکشی کرے گا ہم اسے ضرور سزا دیں گے اور پھر وہ اپنے پروردگار کی طرف پلٹایا جائے گا تو وہ اسے سخت سزا دے گا۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmccxxviii{اور جو کوئی ایمان لائے گا اور نیک عمل کرے گا اس کیلئے اچھی جزا ہے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmccxxix{اور ہم بھی اس کے ساتھ معاملہ میں نرم بات کریں گے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmccxxx{پھر اس نے (دوسری مہم کیلئے) ساز و سامان کیا۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmccxxxi{یہاں تک کہ (چلتے چلتے) وہ طلوعِ آفتاب کی جگہ پہنچا۔ تو اسے ایک ایسی قوم پر طلوع ہوتا ہوا پایا کہ جس کیلئے ہم نے سورج کے سامنے کوئی پردہ نہیں رکھا ہے۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmccxxxii{ایسا ہی تھا اور جو کچھ ذوالقرنین کے پاس تھا اس کی ہم کو پوری خبر ہے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiii{پھر (ایک اور مہم کی) تیاری کی۔ یہاں تک کہ (جب چلتے چلتے) وہ (دو پہاڑوں کی) دیواروں کے درمیان میں پہنچا تو ان کے ادھر ایک ایسی قوم کو پایا۔ جو (ان کی) کوئی بات نہیں سمجھتی تھی۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiv{انہوں نے (اشاروں سے) کہا اے ذوالقرنین! یاجوج اور ماجوج اس سر زمین میں فساد کرنے والے ہیں تو کیا (یہ ممکن ہے کہ) ہم آپ کیلئے خرچ کا کچھ انتظام کر دیں اکہ آپ ہمارے اور ان کے درمیان کوئی دیوار تعمیر کر دیں۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmccxxxv{ذوالقرنین نے کہا جو طاقت میرے پروردگار نے مجھے دے رکھی ہے وہ (تمہارے سامان سے) بہتر ہے۔ تم بس اپنی (بدنی) قوت سے میری مدد کرو۔ تو میں تمہارے اور ان کے درمیان بند باندھ دوں گا۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvi{میرے پاس لوہے کے بڑے بڑے ٹکڑے لاؤ (چنانچہ وہ لائے) یہاں تک کہ جب دو پہاڑوں کے (درمیانی خلا کو پُر کرکے) دونوں کے سروں کے درمیان کو برابر کر دیا۔ تو کہا آگ پھونکو۔ یہاں تک کہ جب اس (آہنی دیوار) کو بالکل آگ بنا دیا تو کہا اب پگھلا ہوا تانبا لاؤ تاکہ اس پر انڈیل دوں۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvii{(چنانچہ یہ دیوار اتنی مضبوط بن گئی کہ) یاجوج و ماجوج نہ اس پر چڑھ سکتے تھے اور نہ ہی اس میں سرنگ لگا سکتے تھے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmccxxxviii{ذوالقرنین نے کہا یہ میرے پرورگار کی رحمت ہے تو جب میرے پروردگار کے وعدے کے وقت آجائے گا تو وہ اسے ڈھا کر زمین کے برابر کر دے گا۔ اور میرے پروردگار کا وعدہ برحق ہے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmccxxxix{اور ہم اس (قیامت کے) دن ہم اس طرح ان کو چھوڑ دیں گے کہ دریا کی لہروں کی طرح گڈمڈ ہو جائیں گے۔ اور صور پھونکا جائے گا۔ اور پھر ہم سب کو پوری طرح جمع کر دیں گے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmccxl{اور اس دن ہم دوزخ کو کافروں کے سامنے پیش کر دیں گے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmccxli{جن کی آنکھوں پر میری یاد سے پردہ پڑا ہوا تھا (کہ میری آیات نہیں دیکھتے تھے) اور وہ سن نہیں سکتے تھے۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmccxlii{کیا کافروں کا یہ خیال ہے کہ وہ مجھے چھوڑ کر میرے بندوں کو اپنا کارساز اور سرپرست بنا لیں گے۱ (اور ہم باز پرس نہیں کریں گے) بےشک ہم نے دوزخ کو کافروں کی مہمانی کیلئے تیار کر رکھا ہے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmccxliii{(اے پیغمبر(ص)) آپ کہہ دیجئے (اے لوگو) کیا ہم تمہیں بتا دیں کہ اعمال کے اعتبار سے سب سے زیادہ گھاٹے میں کون ہیں۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmccxliv{جن کی دنیا کی زندگی کی تمام سعی و کوشش اکارت ہوگئی حالانکہ وہ یہ خیال کرتے ہیں کہ وہ بڑے اچھے کام کر رہے ہیں۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmccxlv{یہ وہ لوگ ہیں جنہوں نے اپنے پروردگار کی آیتوں کا اور اس کی بارگاہ میں حاضری کا انکار کیا پس ان کے سارے اعمال ضائع ہوگئے۔ اس لئے ہم قیامت کے دن ان کے لئے کوئی وزن قائم نہیں کریں گے۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmccxlvi{یہ ان کی سزا ہے جہنم۔ ان کے کفر کرنے اور میری آیات اور میرے رسولوں کا مذاق اڑانے کی پاداش میں۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmccxlvii{بےشک جو لوگ ایمان لائے اور نیک عمل بھی کئے تو ان کی مہمانی کیلئے فردوس کے باغ ہیں۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmccxlviii{جن میں وہ ہمیشہ رہیں گے وہاں سے منتقل ہونا پسند نہیں کریں گے۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmccxlix{کہہ دیجئے! کہ اگر میرے پروردگار کے کلمات لکھنے کیلئے سمندر سیاہی بن جائے تو وہ ختم ہو جائے گا قبل اس کے کہ میرے پروردگار کے کلمات ختم ہوں اگرچہ ہم اس کی مدد کیلئے ویسا ہی ایک سمندر لے آئیں۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmccl{(اے رسول(ص)) کہہ دیجئے! کہ میں (بھی) تمہاری طرح ایک بشر (انسان) ہوں البتہ میری طرف وحی کی جاتی ہے کہ تمہارا خدا ایک ہی خدا ہے پس جو کوئی اپنے پروردگار کی بارگاہ میں حاضر ہونے کا امیدوار ہے۔ اسے چاہیے کہ نیک عمل کرتا رہے اور اپنے پروردگار کی عبادت میں کسی کو بھی شریک نہ کرے۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmccli{\basmalahur کاف۔ ہا۔ یا۔ عین۔ صاد۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcclii{(اے رسول (ص)) آپ کے پروردگار نے اپنے (خاص) بندے زکریا(ع) پر جو (خاص) رحمت کی تھی یہ اس کا تذکرہ ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmccliii{جب انہوں نے اپنے پروردگار کو چپکے چپکے پکارا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccliv{کہا اے میرے پروردگار! میری ہڈیاں کمزور ہوگئی ہیں اور سر میں بڑھاپے کے شعلے بھڑک اٹھے ہیں۔ (بال سفید ہوگئے ہیں) اور میرے پروردگار میں کبھی تجھ سے دعا مانگ کر نامراد نہیں رہا ہوں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcclv{اور میں اپنے بعد بھائی بندوں سے ڈرتا ہوں۔ اور میری بیوی بانجھ ہے سو تو ہی مجھے (خاص) اپنے پاس سے ایک وارث عطا کر۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcclvi{جو میرا بھی وارث بنے اور آل یعقوب کا بھی اور اے میرے پروردگار! تو اسے پسندیدہ بنا۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcclvii{(ارشاد ہوا) اے زکریا! ہم تمہیں ایک لڑکے کی خوشخبری دیتے ہیں۔ جس کا نام یحییٰ ہوگا جس کا اس سے پہلے ہم نے کوئی ہمنام نہیں بنایا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcclviii{زکریا نے (از راہ تعجب) کہا اے میرے پروردگار! میرے ہاں لڑکا کیسے ہوگا؟ جبکہ میری بیوی بانجھ ہے اور میں بڑھاپے کی انتہا کو پہنچا ہوا ہوں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcclix{ارشاد ہوا: ایسا ہی ہوگا۔ تمہارا پروردگار فرماتا ہے کہ وہ مجھ پر آسان ہے اور میں نے ہی اس سے پہلے تمہیں پیدا کیا جبکہ تم کچھ بھی نہ تھے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcclx{زکریا (ع) نے عرض کیا: اے میرے پروردگار! میرے لئے کوئی علامت قرار دے۔ ارشاد ہوا تمہارے لئے علامت یہ ہے کہ تم تندرست ہوتے ہوئے بھی برابر تین رات (دن) تک لوگوں سے بات نہیں کر سکوگے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcclxi{پس وہ عبادت گاہ سے نکل کر اپنی قوم کے پاس آئے اور انہیں اشارہ سے کہا کہ صبح و شام (خدا کی) تسبیح و تقدیس کرو۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcclxii{(جب حکم خدا کے مطابق وہ لڑکا پیدا ہوا اور بڑھا تو ہم نے کہا) اے یحییٰ! کتاب کو مضبوطی سے پکڑو اور ہم نے اسے بچپن ہی میں علم و حکمت سے نوازا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcclxiii{اور وہ اپنے والدین سے نیکی کرنے والا تھا وہ سرکش اور نافرمان نہ تھا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcclxiv{اور ہم نے خاص اپنے پاس سے (اسے) رحمدلی اور پاکیزگی عطا کی اور وہ پرہیزگار تھا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcclxv{سلام ہو اس پر جس دن وہ پیدا ہوا اور جس دن وفات پائے گا اور جس دن وہ زندہ کرکے اٹھایا جائے گا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcclxvi{(اے رسول(ص)) اس کتاب میں مریم کا ذکر کیجئے۔ جب کہ وہ اپنے گھر والوں سے الگ ہوکر ایک مشرقی مکان میں گئیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcclxvii{پھر اس نے ان لوگوں کی طرف سے پردہ کر لیا پس ہم نے اس کی طرف اپنی جانب سے روح (یعنی فرشتہ) کو بھیجا تو وہ اس کے سامنے ایک تندرست انسان کی صورت میں نمودار ہوا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcclxviii{مریم نے (گھبرا کر) کہا کہ اگر تو پرہیزگار آدمی ہے تو میں تجھ سے خدائے رحمن کی پناہ مانگتی ہوں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcclxix{اس (فرشتہ) نے کہا میں تو تمہارے پروردگار کا فرستادہ ہوں تاکہ تمہیں ایک پاکیزہ لڑکا دوں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcclxx{مریم نے کہا میرے ہاں لڑکا کیسے ہو سکتا ہے جبکہ کسی بشر نے مجھے چھوا تک نہیں ہے اور نہ ہی میں بدکردار ہوں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcclxxi{فرشتہ نے کہا یونہی ہے (مگر) تمہارے پروردگار نے فرمایا ہے وہ کام میرے لئے آسان ہے۔ اور یہ اس لئے بھی ہے کہ ہم اسے لوگوں کے لئے (اپنی قدرت کی) ایک نشانی قرار دیں اور اپنی طرف سے رحمت اور یہ ایک طے شدہ بات ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcclxxii{پس وہ اس (لڑکے) کے ساتھ حاملہ ہوگئی پھر وہ اس حمل کو لئے ہوئے دور جگہ چلی گئی۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiii{اس کے بعد دردِ زہ اسے کھجور کے درخت کے تنا کے پاس لے گیا (اور) کہا کاش میں اس سے پہلے مر گئی ہوتی اور بالکل نسیاً منسیاً (بھول بسری) ہوگئی ہوتی۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiv{اور ایک منادی نے اس کے نیچے سے آواز دی کہ (اے مریم) رنجیدہ نہ ہو۔ تیرے پروردگار نے تیرے نیچے ایک چھوٹی سی نہر جاری کر دی ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcclxxv{اور کھجور کے تنا کو پکڑ کر اپنی طرف ہلا۔ وہ تم پر تر و تازہ اور پکی ہوئی کھجوریں گرائے گی۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvi{پس تو (خرمے) کھا اور (نہر کا پانی) پی اور (بیٹے کو دیکھ کر) اپنی آنکھیں ٹھنڈی کر۔ پھر اگر کسی آدمی کو دیکھے اور (وہ تم سے کچھ پوچھے) تو (اشارہ سے) کہہ دینا کہ میں نے خدائے رحمن کے لئے (چپ کے) روزہ کی منت مانی ہے تو میں آج کسی آدمی سے بات نہیں کروں گی۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvii{اس کے بعد وہ بچہ کو (گود میں) اٹھائے اپنی قوم کے پاس لائی۔ انہوں نے کہا اے مریم تو نے بڑا برا کام کیا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcclxxviii{اے ہارون کی بہن! نہ تیرا باپ برا آدمی تھا اور نہ ہی تیری ماں بدکار تھی۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcclxxix{مریم نے (نومولود) بچہ کی طرف اشارہ کیا (کہ اس سے پوچھو کہ کہاں سے آیا؟) وہ لوگ کہنے لگے کہ ہم اس سے کس طرح بات کریں گے جو ابھی گہوارہ میں (کمسن) بچہ ہے؟\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcclxxx{(مگر) وہ بچہ بولا: میں اللہ کا بندہ ہوں اس نے مجھے کتاب عطا کی ہے اور مجھے نبی بنایا ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxi{اور اس نے مجھے نماز (پڑھنے) اور زکوٰۃ (دینے) کا حکم دیا ہے جب تک کہ میں زندہ ہوں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxii{اور اس نے مجھے اپنی ماں کے ساتھ نیک سلوک کرنے والا بنایا ہے اور مجھے سرکش اور بدبخت نہیں بنایا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiii{سلامتی ہے مجھ پر جس دن میں پیدا ہوا، جس دن میں مروں گا اور جس دن زندہ کرکے اٹھایا جاؤں گا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiv{یہ ہے عیسیٰ بن مریم (اور یہ ہے) اس کے بارے میں وہ سچی بات جس میں لوگ شک کرتے ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxv{یہ بات اللہ کے شایانِ شان نہیں ہے کہ وہ کسی کو اپنا بیٹا بنائے۔ پاک ہے اس کی ذات جب وہ کسی کام کا فیصلہ کر لیتا ہے تو اسے کہتا ہے ہو جا تو وہ (کام) ہو جاتا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvi{(عیسیٰ نے کہا) بےشک میرا اور تمہارا پروردگار اللہ ہے پس تم اس کی عبادت کرو۔ یہی سیدھا راستہ ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvii{پھر مختلف گروہ آپ کے بارے میں اختلاف کرنے لگے تو جن لوگوں نے کفر اختیار کیا ان کے لئے ہلاکت ہے جب وہ ایک بہت بڑے سخت دن کا سامنا کریں گے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxviii{جس دن وہ ہمارے پاس آئیں گے تو اس دن ان کے کان کیسے سننے والے اور آنکھیں کیسی دیکھنے والی ہوں گی۔ مگر آج یہ ظالم کھلی ہوئی گمراہی میں مبتلا ہیں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxix{اور (اے رسول(ص)) انہیں حسرت و ندامت کے دن سے ڈرائیں جبکہ ہر بات کا (آخری) فیصلہ کر دیا جائے گا۔ اور یہ لوگ غفلت میں پڑے ہیں اور ایمان نہیں لاتے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccxc{(آخرکار) ہم ہی زمین کے اور جو کچھ اس کے اوپر ہے اس کے وارث ہوں گے اور سب ہماری طرف لوٹائے جائیں گے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccxci{اور قرآن میں ابراہیم (ع) کا ذکر کیجئے۔ بےشک وہ بڑے راست باز تھے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmccxcii{جب انہوں نے اپنے (منہ بولے) باپ (حقیقی چچا) آذر سے کہا کہ اے باپ! آپ ان چیزوں کی عبادت کیوں کرتے ہیں جو نہ سنتی ہیں اور نہ دیکھتی ہیں اور نہ آپ کو کوئی فائدہ پہنچا سکتی ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmccxciii{اے باپ! میرے پاس وہ علم آیا ہے جو آپ کے پاس نہیں آیا۔ آپ میری پیروی کیجئے میں آپ کو سیدھا راستہ دکھا دوں گا۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmccxciv{اے باپ! شیطان کی پرستش نہ کیجئے (کیونکہ) بےشک خدائے رحمن کا وہ نافرمان ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmccxcv{اے باپ! مجھے اندیشہ ہے کہ آپ پر خدائے رحمن کا عذاب نازل نہ ہو جائے اور آپ شیطان کے ساتھی بن جائیں۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmccxcvi{آزر نے کہا: اے ابراہیم کیا تم میرے خداؤں سے روگردانی کرتے ہو؟ اگر تم باز نہ آئے تو میں تمہیں سنگسار کر دوں گا۔ اور تم ایک مدت تک مجھ سے دور ہو جاؤ۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmccxcvii{ابراہیم نے کہا: (اچھا خدا حافظ) آپ پر میرا سلام! میں عنقریب اپنے پروردگار سے آپ کے لئے مغفرت طلب کروں گا۔ بےشک وہ مجھ پر بڑا مہربان ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmccxcviii{اور میں آپ لوگوں سے اور ان سے جنہیں آپ اللہ کو چھوڑ کر پکارتے ہیں کنارہ کرتا ہوں۔ میں تو اپنے پروردگار کو ہی پکاروں گا۔ مجھے امید ہے کہ میں اپنے پروردگار کی دعا و پکار کی برکت سے نامراد نہیں رہوں گا۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmccxcix{پس جب وہ ان لوگوں کے اور ان کے خداؤں سے کنارہ کش ہوگئے تو ہم نے ان کو اسحاق و یعقوب جیسی اولاد عنایت فرمائی اور ہم نے سب کو نبی بنایا۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmccc{اور ہم نے ان ہستیوں کو اپنی (خاص) رحمت سے حصہ عطا کیا اور ان کے لئے سچائی کی زبان کو بلند قرار دیا۔ (یعنی آئندہ نسلوں میں ان کے ذکر جمیل کی آواز بلند کی)۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmccci{اور (اے رسول) کتاب (قرآن) میں موسیٰ کا ذکر کیجئے! بےشک وہ اللہ کے برگزیدہ بندے اور نبی مرسل تھے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcccii{اور ہم نے کوہِ طور کی دائیں جانب سے آواز دی اور راز و نیاز کی باتیں کرنے کیلئے انہیں اپنا مقرب بنایا۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmccciii{اور ہم نے انہیں اپنی خاص رحمت سے آواز دی اور راز و نیاز کی باتیں کرنے کے لئے اپنا مقرب بنایا اور (بطور وزیر) ان کو ان کا بھائی ہارون عطا کیا جو نبی تھا۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmccciv{اور (اے پیغمبر(ص)) آپ کتاب (قرآن) میں اسماعیل (ع) کا ذکر کیجئے جو وعدہ کے سچے اور نبی مرسل تھے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcccv{اور اپنے گھر والوں کو نماز اور زکوٰۃ کا حکم دیتے تھے اور وہ اپنے پروردگار کے نزدیک پسندیدہ تھے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcccvi{اور (اے رسول(ص)) کتاب (قرآن) میں ادریس کا ذکر کیجئے بےشک وہ بڑے سچے نبی تھے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcccvii{اور ہم نے انہیں بڑے ہی اونچے مقام تک بلند کیا تھا۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcccviii{یہ وہ نبی ہیں جن پر اللہ نے انعام فرمایا۔ آدم (ع) کی نسل سے اور ان کی نسل سے جنہیں ہم نے نوح کے ساتھ کشتی میں سوار کیا تھا اور ابراہیم و اسرائیل (یعقوب) کی نسل سے اور (یہ سب) ان لوگوں میں سے تھے جنہیں ہم نے راہ رست دکھائی اور منتخب کیا جب ان کے سامنے خدائے رحمن کی آیتین پڑھی جاتی تھیں تو وہ روتے ہوئے سجدے میں گر پڑتے تھے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcccix{پھر ان کے بعد کچھ وہ ناخلف ان کے جانشین ہوئے جنہوں نے نمازوں کو ضائع کیا اور خواہشات کی پیروی کی پس وہ عنقریب گمراہی (کے انجام) سے دوچار ہوں گے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcccx{ہاں البتہ جو توبہ کر لیں، ایمان لائیں اور نیک عمل بجا لائیں تو یہ لوگ بہشت میں داخل ہوں گے اور ان پر کچھ بھی ظلم نہیں کیا جائے گا۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcccxi{وہ ہمیشہ رہنے والی جنتیں جن کا خدائے رحمن نے غائبانہ وعدہ کر رکھا ہے۔ بےشک اس کا وعدہ (سامنے) آنے والا ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcccxii{وہ وہاں سلامتی کی صداؤں کے سوا کوئی بے ہودہ بات نہیں سنیں گے اور ان کا مقررہ رزق انہیں صبح و شام ملتا رہے گا۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcccxiii{یہ ہے وہ بہشت جس کا وارث ہم اپنے بندوں میں سے اس کو بنائیں گے جو پرہیزگار ہوگا۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcccxiv{(اے رسول(ص)) ہم (فرشتے) آپ کے پروردگار کے حکم کے بغیر (زمین پر) نازل نہیں ہوتے جو کچھ ہمارے آگے ہے یا جو کچھ ہمارے پیچھے ہے اور جو کچھ ان کے درمیان ہے سب کچھ اسی کا ہے اور آپ کا پروردگار بھولنے والا نہیں ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcccxv{وہ آسمانوں اور زمین اور جو کچھ ان کے درمیان ہے کا پروردگار ہے پس اسی کی عبادت کرو اور اس کی عبادت پر ثابت قدم رہو کیا تم اس کا کوئی ہمنام و ہمسر جانتے ہو؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcccxvi{اور (غافل) انسان کہتا ہے کہ جب میں مر جاؤں گا تو کیا پھر زندہ کرکے نکالا جاؤں گا؟\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcccxvii{کیا انسان کو یاد نہیں رہا کہ ہم ہی نے اس کو اس سے پہلے پیدا کیا جبکہ وہ کچھ بھی نہیں تھا۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcccxviii{تو قسم ہے تمہارے پروردگار کی کہ ہم ان کو اور شیطانوں کو اکٹھا کریں گے پھر ان سب کو جہنم کے اردگرد گھٹنوں کے بل حاضر کریں گے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcccxix{پھر ہم ہر گروہ میں سے اس شخص کو جدا کریں گے جو خدائے رحمن کے مقابلہ میں زیادہ سرکش تھا۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcccxx{پھر ہم ہی زیادہ بہتر جانتے ہیں کہ کون اس (جہنم) میں داخل ہونے کا زیادہ سزاوار ہے؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcccxxi{اور تم میں سے کوئی بھی ایسا نہیں ہے جو جہنم پر وارد نہ ہو (جو وہاں سے نہ گزرے) یہ حتمی طے شدہ فیصلہ ہے جس کا پورا کرنا تمہارے پروردگار کے ذمہ ہے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcccxxii{پھر جو پرہیزگار ہوں گے ہم انہیں نجات دے دیں گے اور ظالموں کو اس میں گھٹنوں کے بل گرا چھوڑ دیں گے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiii{جب ان کے سامنے ہماری واضح آیتیں پڑھی جاتی ہیں تو کافر لوگ ایمان لانے والوں سے کہتے ہیں کہ (دیکھو ہم) دونوں گروہوں میں سے رہائش گاہ کس کی اچھی ہے اور محفل کس کی زیادہ شاندار ہے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiv{حالانکہ ہم ان سے پہلے کتنی ایسی قوموں کو ہلاک کر چکے ہیں جو ساز و سامان اور ظاہری شان و شوکت میں ان سے بڑھی ہوئی تھیں۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcccxxv{آپ کہہ دیجئے! کہ جو کوئی گمراہی میں مبتلا ہو تو خدائے رحمن اسے برابر ڈھیل دیتا رہتا ہے یہاں تک کہ جب یہ لوگ اسے دیکھیں گے جس کا ان سے وعدہ وعید ہوا ہے خواہ وہ (یہاں کا) عذاب ہو یا قیامت کی گھڑی! تب انہیں معلوم ہوگا کہ مکان کے لحاظ سے زیادہ برا کون ہے اور لاؤ لشکر کے اعتبار سے زیادہ کمزور کون ہے؟\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvi{اور اللہ ہدایت یافتہ لوگوں کی ہدایت میں اور اضافہ کرتا ہے اور جو باقی رہنے والی نیکیاں ہیں وہ تمہارے پروردگار کے نزدیک ثواب اور انجام کے اعتبار سے بہتر ہیں۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvii{کیا آپ نے اس شخص کو دیکھا ہے جس نے ہماری آیتوں کا انکار کیا ہے اور کہتا ہے کہ مجھے مال ضرور دیا جائے گا اور اولاد بھی۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcccxxviii{کیا وہ غیب پر مطلع ہوگیا ہے؟ یا اس نے خدائے رحمن سے کوئی عہد و پیمان حاصل کر لیا ہے؟\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcccxxix{ہرگز ایسا نہیں ہے جو کچھ یہ کہتا ہے ہم اسے لکھ لیں گے۔ اور اس کے عذاب میں برابر اضافہ کرتے جائیں گے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcccxxx{وہ جو کہتا ہے (کہ اس کے پاس مال و اولاد ہے) اس کے وارث ہم ہی ہوں گے۔ اور یہ تو اکیلا ہماری بارگاہ میں حاضر ہوگا۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxi{اور ان لوگوں نے خدا کو چھوڑ کر بہت سے خدا بنا رکھے ہیں تاکہ وہ ان کیلئے عزت و قوت کا باعث ہوں۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxii{ہرگز ایسا نہیں ہے وہ عنقریب ان کی عبادت کا انکار کریں گے اور ان کے مخالف ہوں گے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiii{اے (رسول(ص)) کیا آپ نے نہیں دیکھا کہ ہم نے شیطانوں کو کافروں پر چھوڑ رکھا ہے جو انہیں برابر اکساتے رہتے ہیں۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiv{آپ ان کے بارے میں جلدی نہ کیجئے ہم تو اچھی طرح ان کے دن گن رہے ہیں۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxv{جس دن ہم پرہیزگاروں کو اپنے حضور مہمانوں کی طرح لائیں گے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvi{اور مجرموں کو پیاسے جانوروں کی طرح جہنم کی طرف ہانک کر لے جائیں گے۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvii{انہیں شفاعت کا کوئی اختیار نہ ہوگا سوائے اس کے جس نے اللہ سے عہد لے لیا ہوگا۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxviii{اور وہ (نصاریٰ) کہتے ہیں کہ خدا نے اپنا ایک بیٹا بنا رکھا ہے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxix{تم نے یہ ایسی سخت بُری بات کہی ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcccxl{کہ قریب ہے کہ آسمان پھٹ پڑیں اور زمین شق ہو جائے اور پہاڑ ٹکڑے ٹکڑے ہو کر گر پڑیں۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcccxli{کیونکہ وہ کہہ رہے ہیں کہ خدائے رحمن کا بیٹا ہے۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcccxlii{اور یہ بات رحمن کے شایانِ شان نہیں ہے کہ وہ کسی کو اپنا بیٹا بنائے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcccxliii{آسمانوں اور زمین میں جو کوئی بھی ہے وہ خدائے رحمن کی بارگاہ میں بندہ بن کر حاضر ہونے والے ہیں۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcccxliv{اس (اللہ) نے ان سب کا احاطہ کر رکھا ہے اور انہیں اچھی طرح شمار کر رکھا ہے۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcccxlv{اور قیامت کے دن ان میں سے ہر ایک تنہا تنہا اس کی بارگاہ میں حاضر ہوگا۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvi{بےشک جو لوگ ایمان لائے اور نیک عمل بجا لائے۔ ان کیلئے عنقریب خدائے رحمن (لوگوں کے دلوں میں) محبت قرار دے گا۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvii{اے (رسول(ص)) ہم نے اس (قرآن) کو آپ کی زبان میں آسان کر دیا ہے تاکہ آپ پرہیزگاروں کو خوشخبری سنائیں اور جھگڑالو قوم کو ڈرائیں۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcccxlviii{اور ہم نے ان سے پہلے کتنی ہی قومیں ہلاک کی ہیں کیا آپ ان میں سے کسی کو بھی محسوس کرتے ہیں یا ان کی کوئی بھنک بھی سنتے ہیں۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcccxlix{\basmalahur طا۔ ھا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcccl{ہم نے اس لئے آپ پر قرآن نازل نہیں کیا کہ آپ مشقت میں پڑ جائیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcccli{بلکہ (اس لئے نازل کیا ہے کہ) جو (خدا سے) ڈرنے والا ہے اس کی یاددہانی ہو۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccclii{(یہ) اس ہستی کی طرف سے نازل ہوا ہے جس نے زمین اور بلند آسمانوں کو پیدا کیا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcccliii{وہ خدائے رحمن ہے جس کا عرش پر اقتدار قائم ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcccliv{جو کچھ آسمانوں اور زمین میں ہے اور جو کچھ ان دونوں کے درمیان ہے اور جو کچھ زمین کے نیچے ہے سب اسی کا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmccclv{اگر تم پکار کر بات کرو (تو تمہاری مرضی) وہ تو راز کو بلکہ اس سے بھی زیادہ مخفی بات کو جانتا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmccclvi{وہ الٰہ ہے اس کے سوا کوئی الہ نہیں ہے۔ سب اچھے اچھے نام اسی کے لئے ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmccclvii{کیا آپ(ص) تک موسیٰ کا واقعہ پہنچا ہے؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmccclviii{جب انہوں نے آگ دیکھی تو انہوں نے اپنے گھر والوں سے کہا کہ تم (یہیں) ٹھہرو۔ میں نے آگ دیکھی ہے شاید تمہارے لئے ایک آدھ انگارا لے آؤں یا آگ کے پاس راستہ کا کوئی پتّہ پاؤں؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmccclix{تو جب اس کے پاس گئے تو انہیں آواز دی گئی کہ اے موسیٰ!\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmccclx{میں ہی تمہارا پروردگار ہوں! پس اپنی جوتیاں اتار دو (کیونکہ) تم طویٰ نامی ایک مقدس وادی میں ہو۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmccclxi{اور میں نے تمہیں (پیغمبری کیلئے) منتخب کیا ہے۔ پس (تمہیں) جو کچھ وحی کی جاتی ہے اسے غور سے سنو۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmccclxii{بےشک میں ہی اللہ ہوں۔ میرے سوا کوئی الٰہ نہیں ہے پس میری عبادت کرو اور میری یاد کیلئے نماز قائم کرو۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmccclxiii{یقیناً قیامت آنے والی ہے میں اسے پوشیدہ رکھنا چاہتا ہوں تاکہ ہر شخص کو اس کی سعی و کوشش کا معاوضہ مل جائے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmccclxiv{پس (خیال رکھنا) کہیں وہ شخص جو اس پر ایمان نہیں رکھتا اور اپنی خواہش نفس کا پیرو ہے تمہیں اس کی فکر سے روک نہ دے ورنہ تم تباہ ہو جاؤگے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmccclxv{اور اے موسیٰ! تمہارے دائیں ہاتھ میں کیا ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmccclxvi{کہا وہ میرا عصا ہے میں اس پر ٹیک لگاتا ہوں اور اس سے اپنی بکریوں کیلئے (درختوں سے) پتے جھاڑتا ہوں اور میرے لئے اس میں اور بھی کئی فائدے ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmccclxvii{ارشاد ہوا اے موسیٰ! اسے پھینک دو۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmccclxviii{چنانچہ موسیٰ نے اسے پھینک دیا تو وہ ایک دم دوڑتا ہوا سانپ بن گیا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmccclxix{ارشاد ہوا اسے پکڑ لو۔ اور ڈرو نہیں ہم ابھی اسے اس کی پہلی حالت کی طرف پلٹا دیں گے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmccclxx{اور اپنے ہاتھ کو سمیٹ کر اپنے بازو کے نیچے (بغل میں) کر لو وہ کسی برائی و بیماری کے بغیر چمکتا ہوا نکلے گا یہ دوسری نشانی ہوگی۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmccclxxi{تاکہ ہم آپ کو اپنی بڑی نشانیوں سے کچھ دکھائیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmccclxxii{جاؤ فرعون کے پاس کہ وہ بڑا سرکش ہو گیا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiii{موسیٰ نے کہا اے میرے پروردگار! میرا سینہ کشادہ فرما۔ (حوصلہ فراخ کر)۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiv{اور میرے کام کو میرے لئے آسان کر۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmccclxxv{اور میری زبان کی گرہ کھول دے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvi{تاکہ لوگ میری بات سمجھ سکیں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvii{اور میرے خاندان میں سے میرے بھائی۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmccclxxviii{ہارون کو میرا وزیر بنا۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmccclxxix{اس کے ذریعے سے میری کمر کو مضبوط بنا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmccclxxx{اسے میرے کام (رسالت) میں میرا شریک بنا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxi{تاکہ ہم کثرت سے تیری تسبیح کریں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxii{اور کثرت سے تیرا ذکر کریں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiii{بےشک تو ہمارے حال کو خوب دیکھ رہا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiv{خدا نے فرمایا اے موسیٰ! تمہاری درخواست منظور کر لی گئی ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxv{اور ہم ایک مرتبہ اور بھی تم پر احسان کر چکے ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvi{جب ہم نے تمہاری ماں کی طرف وحی بھیجی جو بھیجنا تھی (جو اب بذریعہ وحی تمہیں بتائی جا رہی ہے)۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvii{کہ اس (موسیٰ) کو صندوق میں رکھ اور پھر صندوق کو دریا میں ڈال دے پھر دریا اسے کنارہ پر پھینک دے گا (اور) اسے وہ شخص (فرعون) اٹھائے گا جو میرا بھی دشمن ہے اور اس (موسیٰ) کا بھی دشمن ہے میں نے تم پر اپنی محبت کا اثر ڈال دیا۔ (جو دیکھتا وہ پیار کرتا) اور اس لئے کہ تم میری خاص نگرانی میں پرورش پائے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxviii{اور وہ وقت یاد کرو جب تمہاری بہن چل رہی تھی اور (فرعون کے اہل خانہ سے) کہہ رہی تھی کہ کیا میں تم لوگوں کو ایسی (دایہ) بتاؤں جو اس کی پرورش کرے؟ اور اس طرح ہم نے تمہیں تمہاری ماں کی طرف لوٹا دیا تاکہ اس کی آنکھ ٹھنڈی ہو اور رنجیدہ نہ ہو اور تم نے ایک شخص کو قتل کر دیا تھا تو ہم نے تمہیں اس غم سے نجات دی اور ہم نے تمہاری ہر طرح آزمائش کی۔ پھر تم کئی برس تک مدین کے لوگوں میں رہے اور پھر اے موسیٰ! تم اپنے معین وقت پر (یہاں) آگئے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxix{اور میں نے تمہیں اپنی ذات کیلئے منتخب کر لیا۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcccxc{(سو اب) تم اور تمہارا بھائی میری نشانیوں کے ساتھ (فرعون کے پاس) جاؤ اور میری یاد میں سستی نہ کرنا۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcccxci{تم دونوں فرعون کے پاس جاؤ کہ وہ سرکش ہوگیا ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcccxcii{اس سے نرمی کے ساتھ بات کرنا کہ شاید وہ نصیحت قبول کرے یا ڈر جائے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcccxciii{ان دونوں نے کہا اے ہمارے پروردگار! ہمیں اندیشہ ہے کہ وہ ہم پر زیادتی کرے یا سرکشی کرے؟\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcccxciv{ارشاد ہوا تم ڈرو نہیں میں تمہارے ساتھ ہوں۔ سب کچھ سن رہا ہوں اور دیکھ رہا ہوں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcccxcv{تم (بے دھڑک) اس کے پاس جاؤ۔ اور کہو کہ ہم تیرے پروردگار کے پیغمبر ہیں۔ سو تو بنی اسرائیل کو ہمارے ساتھ روانہ کر اور ان کو تکلیف نہ پہنچا۔ ہم تیرے پاس تیرے پروردگار کی طرف سے معجزہ لے کر آئے ہیں اور سلامتی ہے اس کے لئے جو ہدایت کی پیروی کرے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvi{بےشک ہماری طرف یہ وحی کی گئی ہے کہ عذاب اس کیلئے ہے جو (آیات اللہ کو) جھٹلائے اور (اس کے احکام سے) روگردانی کرے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvii{(چنانچہ وہ گئے) اور فرعون نے کہا اے موسیٰ! تمہارا پروردگار کون ہے؟\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcccxcviii{موسیٰ نے کہا ہمارا پروردگار وہ ہے جس نے ہر چیز کو خلقت بخشی پھر راہنمائی فرمائی۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcccxcix{فرعون نے کہا پھر ان نسلوں کا کیا ہوگا جو پہلے گزر چکی ہیں؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcd{موسیٰ نے کہا ان کا علم میرے پروردگار کے پاس ایک کتاب میں ہے میرا پروردگار نہ بھٹکتا ہے اور نہ بھولتا ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcdi{وہ وہی ہے جس نے تمہارے لئے زمین کو گہوارہ بنایا ہے اور اس میں تمہارے لئے راستے بنائے اور آسمان سے پانی برسایا۔ تو ہم نے اس سے مختلف اقسام کے نباتات کے جوڑے پیدا کئے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcdii{خود بھی کھاؤ اور اپنے مویشیوں کو بھی چراؤ۔ بےشک اس (نظام قدرت) میں صاحبانِ عقل کیلئے بہت سی نشانیاں ہیں۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcdiii{اسی زمین سے ہم نے تمہیں پیدا کیا ہے اور اسی میں ہم تمہیں لوٹائیں گے اور اسی سے دوبارہ تمہیں نکالیں گے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcdiv{اور ہم نے اس (فرعون) کو اپنی سب نشانیاں دکھائیں مگر اس پر بھی اس نے جھٹلایا اور انکار کیا۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcdv{اور کہا اے موسیٰ! کیا تم اس لئے ہمارے پاس آئے ہو کہ اپنے جادو کے زور سے ہمیں ہماری سرزمین سے نکال دو؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcdvi{سو ہم بھی تمہارے مقابلہ میں ویسا ہی جادو لائیں گے لہٰذا تم (مقابلہ کیلئے) ہمارے اور اپنے درمیان ایک وعدہ گاہ مقرر کرو۔ جس کی نہ ہم خلاف ورزی کریں گے اور نہ تم۔ اور وہ وعدہ گاہ ہو بھی ہموار اور کھلے میدان میں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcdvii{موسیٰ نے کہا تمہارے لئے وعدہ کا دن جشن والا دن ہے اور یہ کہ دن چڑھے لوگ جمع کر لئے جائیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcdviii{اس کے بعد فرعون واپس چلا گیا اور اپنے سب مکر و فریب (داؤ) جمع کئے اور پھر (مقابلہ کیلئے) آگیا۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcdix{موسیٰ نے (فرعونیوں سے) کہا افسوس ہے تم پر۔ اللہ پر جھوٹا بہتان نہ باندھو۔ ورنہ وہ کسی عذاب سے تمہارا قلع قمع کر دے گا۔ اور جو کوئی بہتان باندھتا ہے وہ ناکام و نامراد ہوتا ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcdx{پھر وہ اپنے معاملہ میں باہم جھگڑنے لگے اور پوشیدہ سرگوشیاں کرنے لگے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcdxi{(آخرکار) انہوں نے کہا کہ یہ دونوں جادوگر ہیں جو چاہتے ہیں کہ اپنے جادو کے زور سے تمہیں تمہاری سرزمین سے نکال دیں اور تمہارے اعلیٰ و مثالی طریقہ کار کو مٹا دیں۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcdxii{لہٰذا تم اپنی سب تدبیریں (داؤ پیچ) جمع کرو۔ اور پرا باندھ کر (مقابلہ میں) آجاؤ۔ یقیناً فلاح وہی پائے گا جو غالب آئے گا۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcdxiii{ان لوگوں (جادوگروں) نے کہا اے موسیٰ تم پہلے پھینکوگے یا پہلے ہم پھینکیں؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcdxiv{موسیٰ علیہ السلام نے کہا: نہیں۔ بلکہ تم ہی (پہلے) پھینکو! پس اچانک ان کی رسیاں اور لاٹھیاں ان کے جادو کی وجہ سے موسیٰ کو دوڑتی ہوئی محسوس ہوئیں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcdxv{(یہ منظر دیکھ کر) موسیٰ نے اپنے دل میں کچھ خوف محسوس کیا۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcdxvi{ہم نے کہا (اے موسیٰ) ڈرو نہیں بےشک تم ہی غالب رہوگے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcdxvii{اور جو تمہارے دائیں ہاتھ میں (عصا) ہے اسے پھینک دو۔ یہ ان کی سب بناوٹی چیزوں کو نگل جائے گا۔ جو کچھ انہوں نے بنایا ہے وہ جادوگر کا فریب ہے اور جادوگر کہیں بھی آئے (جائے) کبھی کامیاب نہیں ہو سکتا۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcdxviii{چنانچہ (ایسا ہی ہوا کہ) سب جادوگر (بے ساختہ) سجدے میں گرا دیئے گئے (اور)کہنے لگے کہ ہم ہارون اور موسیٰ کے پروردگار پر ایمان لائے ہیں۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcdxix{فرعون نے کہا تم اس پر ایمان لے آئے قبل اس کے کہ میں تمہیں اجازت دوں یہی تمہارا وہ بڑا (جادوگر) ہے جس نے تمہیں جادو سکھایا ہے اب میں ضرور تمہارے ہاتھ پاؤن مخالف سمت سے کٹواتا ہوں اور تمہیں کھجور کے تنوں پر سولی دیتا ہوں پھر تمہیں معلوم ہو جائے گا کہ ہم (دونوں) میں اور موسیٰ میں سے کس کا عذاب سخت اور دیرپا ہے؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcdxx{جادوگروں نے کہا ہمارے پاس جو کھلی نشانیاں آچکی ہیں ہم ان پر اور اس ذات پر جس نے ہمیں پیدا کیا ہے۔ کبھی تجھے ترجیح نہیں دیں گے بےشک تو جو فیصلہ کرنا چاہتا ہے وہ تو (زیادہ سے زیادہ) اسی دنیاوی زندگی (کے ختم کرنے) کا فیصلہ کر سکتا ہے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcdxxi{ہم تو اپنے پروردگار پر ایمان لا چکے ہیں تاکہ وہ ہماری خطاؤں کو اور اس جادوگری کو جس پر تو نے ہمیں مجبور کیا تھا معاف کر دے۔ ہمارے لئے اللہ ہی بہتر ہے اور وہی زیادہ دیرپا ہے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcdxxii{بےشک جو کوئی مجرم بن کر اپنے پروردگار کی بارگاہ میں حاضر ہوگا اس کیلئے وہ جہنم ہے جس میں وہ نہ مرے گا اور نہ جیئے گا۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiii{اور جو کوئی مؤمن بن کر اس کی بارگاہ میں حاضر ہوگا۔ جب کہ اس نے نیک عمل بھی کئے ہوں گے ان کے لئے بڑے بلند درجے ہیں۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiv{(اور) ہمیشہ رہنے والے باغات جن کے نیچے نہریں جاری ہوں گی۔ وہ ان میں ہمیشہ رہیں گے۔ یہ اس کی جزاء ہے جو پاکباز رہا۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcdxxv{اور ہم نے موسیٰ کی طرف وحی کی کہ میرے بندوں (بنی اسرائیل) کو لے کر نکل جاؤ پھر (عصا مار کر) ان کیلئے سمندر سے خشک راستہ بناؤ۔ نہ تمہیں پیچھے سے ان کے پکڑے جانے کا خطرہ ہو اور نہ ہی (غرق وغیرہ کا) کوئی اندیشہ۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvi{پھر فرعون نے اپنی فوجوں کے ساتھ ان کا پیچھا کیا تو انہیں سمندر نے ڈھانپ لیا جیساکہ ڈھانپنے کا حق تھا۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvii{اور فرعون نے اپنی قوم کو گمراہ ہی کیا کوئی راہنمائی نہیں کی۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcdxxviii{اے بنی اسرائیل! ہم نے تمہیں تمہارے دشمن سے نجات دی اور تم سے کوہ طور کی دائیں جانب توریت دینے کا قول و قرار کیا۔ اور تم پر من و سلویٰ نازل کیا۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcdxxix{تم سے کہا گیا کہ جو پاکیزہ روزی تمہیں دی گئی ہے اس سے کھاؤ اور اس کے بارے میں سرکشی نہ کرو (حد سے نہ گزرو) ورنہ تم پر میرا غضب نازل ہوگا اور جس پر میرا غضب نازل ہو جائے وہ ہلاک ہی ہوگیا۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcdxxx{اور جو کوئی توبہ کرے اور ایمان لائے اور نیک عمل بجا لائے اور پھر راہِ راست پر قائم رہے تو میں اس کو بہت ہی بخشنے والا ہوں۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxi{اے موسیٰ! اپنی قوم سے پہلے کیا چیز تمہیں جلدی لے آئی؟\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxii{موسیٰ نے کہا: وہ لوگ میرے نقش قدم پر آرہے ہیں۔ اور اے میرے پروردگار! میں اس لئے جلدی تیری بارگاہ میں حاضر ہوگیا ہوں کہ تو خوش ہو جائے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiii{ارشاد ہوا۔ ہم نے تمہارے بعد تمہاری قوم کو آزمائش میں ڈال دیا ہے۔ اور سامری نے انہیں گمراہ کر دیا ہے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiv{پس موسیٰ غصہ میں افسوس کرتے ہوئے اپنی قوم کی طرف لوٹے (اور) کہا اے میری قوم! کیا تمہارے پروردگار نے تم سے بڑا اچھا وعدہ نہیں کیا تھا؟ تو کیا تم پر (وعدہ سے) زیادہ مدت گزر گئی؟ یا تم نے چاہا کہ تمہارے رب کا غضب تم پر نازل ہو؟ اس لئے تم نے مجھ سے وعدہ خلافی کی؟\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxv{قوم نے کہا کہ ہم نے اپنے اختیار سے تو آپ سے وعدہ خلافی نہیں کی (البتہ بات یوں ہوئی) کہ ہمیں اس جماعت کے زیورات جمع کرکے لانے پر آمادہ کیا گیا اور یہ سامری ایک (سنہرا) بچھڑا نکال کر لایا۔ جس سے گائے کی سی آواز نکلتی تھی۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvi{تو لوگوں سے کہا یہی تمہارا خدا ہے اور موسیٰ کا بھی جسے وہ بھول گئے ہیں۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvii{کیا وہ اتنا بھی نہیں دیکھتے کہ وہ (گؤ سالہ) ان کی کسی بات کا جواب نہیں دیتا اور نہ ہی وہ ان کو نقصان یا نفع پہنچانے کا کوئی اختیار رکھتا ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxviii{اور ہارون نے اس سے پہلے ہی ان سے کہہ دیا تھا کہ اے میری قوم! تم اس (گو سالہ) کی وجہ سے آزمائش میں پڑ گئے ہو۔ اور یقیناً تمہارا پروردگار خدائے رحمن ہے سو تم میری پیروی کرو۔ اور میرے حکم کی تعمیل کرو۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxix{مگر قوم نے کہا کہ ہم تو برابر اس کی عبادت پر جمے رہیں گے یہاں تک کہ موسیٰ ہماری طرف آجائیں۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcdxl{موسیٰ نے کہا اے ہارون! جب تم نے دیکھا کہ یہ لوگ گمراہ ہوگئے ہیں۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcdxli{تو تمہیں کس چیز نے میری پیروی کرنے سے روکا؟ کیا تم نے میرے حکم کی خلاف ورزی کی ہے؟\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcdxlii{ہارون نے کہا: اے میرے ماں جائے! میری ڈاڑھی اور میرا سر نہ پکڑئیے! مجھے تو یہ ڈر تھا کہ کہیں آپ یہ نہ کہیں کہ تم نے بنی اسرائیل میں تفرقہ ڈال دیا۔ اور میری بات کا خیال نہیں کیا (یا میرے حکم کا انتظار نہ کیا؟)۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcdxliii{(بعد ازاں) کہا اے سامری! تیرا کیا معاملہ ہے؟\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcdxliv{اس نے کہا کہ میں نے ایک ایسی چیز دیکھی جو اور لوگوں نے نہیں دیکھی تو میں نے (خدا کے) فرستادہ کے نقش قدم سے ایک مٹھی (خاک) اٹھا لی۔ اور اسے (اس گو سالہ میں) ڈال دیا۔ میرے نفس نے مجھے یہ بات سجھائی (اور میرے لئے آراستہ کر دی)۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcdxlv{موسیٰ نے کہا جا چلا جا! تیرے لئے اس زندگی میں یہ (سزا) ہے کہ تو کہتا رہے گا کہ مجھے کوئی نہ چھوئے (کہ میں اچھوت ہوں) اور تیرے لئے (آخرت میں عذاب) کا ایک وعدہ ہے جو تجھ سے ٹلنے والا نہیں ہے۔ اور اب دیکھ اپنے اس معبود کو جس کی پرستش پر تو جما بیٹھا رہا۔ ہم (پہلے) اسے جلائیں گے اور پھر اس کی راکھ کو اڑا کر سمندر میں بہائیں گے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvi{اے لوگو! تمہارا الٰہ تو بس اللہ ہی ہے جس کے سوا کوئی الہ نہیں ہے۔ اور وہ ہر چیز کا علمی احاطہ کئے ہوئے ہے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvii{(اے رسول) ہم اسی طرح گزرے ہوئے واقعات کی کچھ خبریں آپ سے بیان کرتے ہیں اور ہم نے اپنی طرف سے آپ کو ایک نصیحت نامہ (قرآن) عطا کیا ہے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcdxlviii{جو کوئی اس سے روگردانی کرے گا تو وہ قیامت کے دن (اپنے اس جرم کا) بوجھ خود اٹھائے گا۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcdxlix{ایسے لوگ ہمیشہ اسی حالت میں گرفتار رہیں گے اور قیامت کے دن یہ بوجھ بڑا برا بوجھ ہوگا۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcdl{جس دن صور پھونکا جائے گا تو ہم مجرموں کو اس طرح محشور کریں گے کہ ان کی آنکھیں نیلی ہوں گی۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcdli{وہ آپس میں چپکے چپکے کہیں گے کہ تم (دنیا و برزخ میں) کوئی دس دن ہی رہے ہوگے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcdlii{ہم خوب جانتے ہیں جو وہ کہہ رہے ہوں گے جبکہ ان کا سب سے زیادہ صائب الرائے یہ کہتا ہوگا کہ تم تو بس ایک دن رہے ہو۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcdliii{(اے رسول(ص)) لوگ آپ سے پہاڑوں کے بارے میں پوچھتے ہیں کہ (قیامت کے دن کہاں جائیں گے)؟ تو آپ کہہ دیجئے! کہ میرا پروردگار ان کو (ریزہ ریزہ کرکے) اڑا دے گا۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcdliv{پھر ان کی جگہ زمین کو اس طرح چٹیل میدان بنا دے گا۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcdlv{کہ تم اس میں نہ کوئی ناہمواری دیکھوگے اور نہ بلندی۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcdlvi{اس روز لوگ ایک پکارنے والے (اسرافیل) کے پیچھے اس طرح سیدھے آئیں گے جس میں کوئی کجی نہ ہوگی اور خدا کے سامنے اور سب آوازیں دب جائیں گی پس تم قدموں کی آہٹ کے سوا کچھ نہیں سنوگے۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcdlvii{اس دن کوئی شفاعت فائدہ نہیں دے گی سوائے اس کے جس کو خدا اجازت دے گا اور اس کے بولنے کو پسند کرے گا۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcdlviii{جو کچھ لوگوں کے آگے ہے (آنے والے حالات) اور جو کچھ ان کے پیچھے ہے (گزرے ہوئے واقعات) وہ سب کچھ جانتا ہے مگر لوگ اپنے علم سے اس کا احاطہ نہیں کر سکتے۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcdlix{سب کے چہرے حی و قیوم کے سامنے جھکے ہوئے ہوں گے اور جو شخص ظلم کا بوجھ اٹھائے گا وہ ناکام و نامراد ہو جائے گا۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcdlx{اور جو کوئی نیک کام کرے درآنحالیکہ وہ مؤمن بھی ہو تو اسے نہ ظلم و زیادتی کا اندیشہ ہوگا اور نہ کمی و حق تلفی کا۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmcdlxi{اور اس طرح ہم نے اس (کتاب) کو عربی زبان میں قرآن بنا کر نازل کیا ہے اس میں وعید و تہدید بیان کی ہے تاکہ وہ پرہیزگار بن جائیں یا وہ ان میں نصیحت پذیری پیدا کر دے۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmcdlxii{بلند و برتر ہے اللہ جو حقیقی بادشاہ ہے اور (اے پیغمبر(ص)) جب تک قرآن کی وحی آپ پر پوری نہ ہو جائے اس (کے پڑھنے) میں جلدی نہ کیا کیجئے۔ اور دعا کیجئے کہ (اے پروردگار) میرے علم میں اور اضافہ فرما۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiii{اور ہم نے اس سے پہلے آدم سے عہد لیا تھا مگر وہ بھول گئے اور ہم نے ان میں عزم و ثبات نہ پایا۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiv{اور (وہ وقت یاد کرو) جب ہم نے فرشتوں سے کہا کہ آدم (ع) کے سامنے سجدہ میں گر جاؤ۔ (چنانچہ) ابلیس کے سوا سب سجدے میں گر گئے۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmcdlxv{سو ہم نے کہا اے آدم (ع)! یہ آپ کا اور آپ کی زوجہ کا دشمن ہے یہ کہیں آپ دونوں کو جنت سے نکلوا نہ دے؟ ورنہ مشقت میں پڑ جائیں گے۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvi{بیشک تم اس میں نہ کبھی بھوکے رہوگے اور نہ ننگے۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvii{اور نہ یہاں پیاسے رہوگے اور نہ دھوپ کھاؤگے۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmcdlxviii{پھر شیطان نے ان کے دل میں وسوسہ ڈالا (اور) کہا اے آدم! کیا میں تمہیں بتاؤں ہمیشگی والا درخت اور نہ زائل ہونے والی سلطنت؟\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmcdlxix{پس ان دونوں نے اس (درخت) میں سے کچھ کھایا۔ تو ان پر ان کے قابل ستر مقامات ظاہر ہوگئے اور وہ اپنے اوپر جنت کے پتے چپکانے لگے اور آدم نے اپنے پروردگار (کے امر ارشادی) کی خلاف ورزی کی اور (اپنے مقصد میں) ناکام ہوئے۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmcdlxx{اس کے بعد ان کے پروردگار نے انہیں برگزیدہ کیا (چنانچہ) ان کی توبہ قبول کی اور ہدایت بخشی۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxi{فرمایا (اب) تم زمین پر اتر جاؤ ایک دوسرے کے دشمن ہوکر پھر اگر تمہارے پاس میری طرف سے کوئی ہدایت پہنچے تو جو کوئی میری ہدایت کی پیروی کرے گا وہ نہ گمراہ ہوگا اور نہ بدبخت ہوگا۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxii{اور جو کوئی میری یاد سے روگردانی کرے گا تو اس کے لئے تنگ زندگی ہوگی۔ اور ہم اسے قیامت کے دن اندھا محشور کریں گے۔\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiii{وہ کہے گا اے میرے پروردگار! تو نے مجھے اندھا کیوں محشور کیا ہے حالانکہ میں آنکھوں والا تھا؟\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiv{ارشاد ہوگا اسی طرح ہماری آیات تیرے پاس آئی تھیں اور تو نے انہیں بھلا دیا تھا اسی طرح آج تجھے بھی بھلا دیا جائے گا اور نظر انداز کر دیا جائے گا۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxv{اور جو کوئی حد سے تجاوز کرے اور اپنے پروردگار کی بات پر ایمان نہ لائے تو ہم اسے اسی طرح (دنیا میں) سزا دیتے ہیں اور آخرت کا عذاب تو اور بھی بڑا سخت اور پائیدار ہے۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvi{کیا (اس بات سے بھی) انہیں ہدایت نہ ملی کہ ہم نے ان سے پہلے کتنی نسلیں (ان گناہوں کی پاداش میں) ہلاک کر دیں جن کے مکانوں میں (آج) یہ چلتے پھرتے ہیں بےشک اس میں صاحبان عقل کیلئے خدا کی قدرت کی بڑی نشانیاں ہیں۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvii{اور (اے رسول(ص)) اگر آپ کے پروردگار کی طرف سے ایک بات طے نہ کر دی گئی ہوتی اور ایک (مہلت کی) مدت معین نہ ہو چکی ہوتی تو (عذاب) لازمی طور پر آچکا ہوتا۔\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxviii{سو آپ ان کی باتوں پر صبر کیجئے اور طلوع آفتاب سے پہلے اور غروب آفتاب سے پہلے اور رات کے اوقات میں بھی اور دن کے اول و آخر میں بھی اپنے پروردگار کی حمد و ثناء کے ساتھ تسبیح کیجئے تاکہ آپ راضی ہو جائیں۔\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxix{اور جو کچھ ہم نے مختلف لوگوں کو آزمائش کیلئے دنیا کی زیب و زینت اور آرائش دے رکھی ہے اس کی طرف نگاہیں اٹھا کر بھی نہ دیکھیں اور آپ کے پروردگار کا دیا ہوا رزق بہتر ہے اور زیادہ پائیدار ہے۔\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxx{اور اپنے گھر والوں کو نماز کا حکم دیں اور خود بھی اس پر قائم و برقرار رہیں ہم آپ سے روزی طلب نہیں کرتے۔ ہم تو خود آپ کو روزی دیتے ہیں اور انجام بخیر تو پرہیزگاری کا ہی ہے۔\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxi{اور یہ لوگ (اہل مکہ) کہتے ہیں کہ یہ (رسول) ہمارے پاس اپنے پروردگار کی طرف سے کوئی نشانی (معجزہ) کیوں نہیں لاتے۔ کیا ان کے پاس اگلی کتابوں کا کھلا ہوا ثبوت نہیں آیا؟\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxii{اور اگر ہم اس (رسول) سے پہلے انہیں عذاب سے ہلاک کر دیتے تو یہ کہتے اے ہمارے پروردگار! تو نے ہماری طرف کوئی رسول کیوں نہ بھیجا؟ کہ ہم ذلیل و رسوا ہونے سے پہلے تیری آیتوں کی پیروی کرتے۔\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiii{آپ کہہ دیجئے! کہ ہر ایک اپنے (انجام کا) انتظار کر رہا ہے سو تم بھی انتظار کرو۔ عنقریب تمہیں معلوم ہو جائے گا کہ سیدھی راہ والے کون ہیں؟ اور ہدایت یافتہ کون ہیں۔\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiv{\basmalahur لوگوں کے حساب کتاب (کا وقت) قریب آگیا ہے اور وہ غفلت میں پڑے منہ پھیرے ہوئے ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxv{ان کے پروردگار کی طرف سے کوئی نئی یاددہانی ان کے پاس آتی ہے۔ تو وہ اسے کھیل کود میں لگے ہوئے سنتے ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvi{ان کے دل بالکل غافل ہیں اور یہ ظالم چپکے چپکے سرگوشیاں کرتے ہیں کہ یہ شخص (رسول) اس کے سوا کیا ہے؟ تمہاری ہی طرح کا ایک بشر ہے کیا تم آنکھیں دیکھتے ہوئے (اور سوجھ بوجھ رکھتے ہوئے) جادو (کی بات) سنتے جاؤگے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvii{(پیغمبر اسلام(ص)) نے کہا کہ میرا پروردگار آسمان اور زمین کی ہر بات کو جانتا ہے (کیونکہ) وہ بڑا سننے والا (اور) بڑا جاننے والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxviii{بلکہ یہ لوگ کہتے ہیں کہ یہ (قرآن) خواب ہائے پریشان ہیں (نہیں) بلکہ یہ اس نے خود گھڑ لیا ہے۔ بلکہ وہ تو ایک شاعر ہے (اور اگر ایسا نہیں ہے) تو پھر ہمارے پاس کوئی معجزہ لائے جس طرح پہلے رسول (معجزات کے ساتھ) بھیجے گئے تھے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxix{ان سے پہلے کوئی بستی بھی جسے ہم نے ہلاک کیا وہ تو ایمان لائی نہیں تو کیا یہ ایمان لائیں گے؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcdxc{(اے رسول) اور ہم نے آپ سے پہلے بھی مردوں کو ہی رسول بنا کر بھیجا تھا جن کی طرف وحی کیا کرتے تھے۔ اگر تم نہیں جانتے تو اہل ذکر سے پوچھ لو۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcdxci{اور ہم نے ان رسولوں کو کبھی ایسے جسم کا نہیں بنایا کہ وہ کھانا نہ کھاتے ہوں۔ اور نہ وہ ہمیشہ زندہ رہنے والے تھے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcdxcii{پھر ہم نے ان سے جو وعدہ کیا تھا اسے سچا کر دکھایا اور انہیں اور ان کے ساتھ جن کو چاہا بچالیا اور زیادتی کرنے والوں کو تباہ و برباد کردیا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcdxciii{بےشک ہم نے تمہاری طرف ایک ایسی کتاب نازل کی ہے جس میں تمہارا ہی ذکر ہے کیا تم عقل سے کام نہیں لیتے؟ (نہیں سمجھتے؟)۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcdxciv{اور کتنی ہی بستیاں ہیں جو ہم نے بریاد کر دیں۔ کیونکہ وہ ظالم تھیں (ان کے باشندے ظالم تھے) اور ان کی جگہ اور قوم کو پیدا کر دیا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcdxcv{جب انہوں نے ہمارا عذاب محسوس کیا تو ایک دم وہاں سے بھاگنے لگے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvi{(ان سے کہا گیا) بھاگو نہیں (بلکہ) اپنی آسائش کی طرف لوٹو جو تمہیں دی گئی تھی۔ اور اپنے گھروں کی طرف لوٹو۔ تاکہ تم سے پوچھ گچھ کی جائے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvii{ان لوگوں نے کہا ہائے ہماری بدبختی بےشک ہم ظالم تھے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcdxcviii{وہ برابر یہی پکارتے رہے یہاں تک کہ ہم نے انہیں کٹی ہوئی کھیتی کی طرح (اور) بجھی ہوئی آگ کی طرح کر دیا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcdxcix{اور ہم نے آسمان اور زمین کو اور جو کچھ ان کے درمیان ہے ان کو کھیل تماشے کے طور پر پیدا نہیں کیا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmd{اگر ہم کوئی دل بستگی کا سامان چاہتے تو اپنے پاس سے ہی کر لیتے مگر ہم ایسا کرنے والے نہیں ہیں۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdi{بلکہ ہم باطل پر حق کی چوٹ لگاتے ہیں جو اس کا بھیجا نکال دیتی ہے (سر کچل دیتی ہے) پھر یکایک باطل مٹ جاتا ہے۔ افسوس ہے تم پر ان باتوں کی وجہ سے جو تم بناتے ہو۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdii{جو کوئی آسمانوں میں ہے اور جو کوئی زمین ہے سب اسی کیلئے ہے اور جو اس کی بارگاہ میں ہیں وہ اس کی عبادت سے تکبر و سرکشی نہیں کرتے اور نہ ہی تھکتے ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdiii{وہ رات دن اس کی تسبیح کرتے ہیں کبھی ملول ہوکر وقفہ نہیں کرتے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdiv{کیا انہوں نے زمینی (مخلوق) سے ایسے معبود بنائے ہیں جو مردوں کو زندہ کر دیتے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdv{اگر زمین و آسمان میں اللہ کے سوا کوئی اور خدا ہوتا تو دونوں کا نظام برباد ہو جاتا پس پاک ہے اللہ جو عرش کا مالک ہے ان باتوں سے جو لوگ بناتے ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdvi{وہ جو کچھ کرتا ہے اس کے بارے میں اس سے بازپرس نہیں کی جا سکتی اور وہ ہر ایک کا حساب لینے والا ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdvii{کیا ان لوگوں نے اللہ کے علاوہ اور خدا بنائے ہیں؟ کہئے کہ اپنی دلیل پیش کرو۔ یہ (قرآن) میرے ساتھ والوں کی (کتاب) ہے اور مجھ سے پہلے والوں کی (کتابیں بھی) ہیں (ان سے کوئی بات میرے دعویٰ کے خلاف نکال کر لاؤ) بلکہ اکثر لوگ حق کو نہیں جانتے (اس لئے) اس سے روگردانی کرتے ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdviii{اور ہم نے آپ سے پہلے کوئی ایسا رسول نہیں بھیجا جس کی طرف یہ وحی نہ کی ہو کہ میرے سوا کوئی خدا نہیں ہے۔ پس تم میری ہی عبادت کرو۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdix{اور وہ کہتے ہیں کہ خدائے رحمن نے اولاد بنا رکھی ہے وہ (اس سے) پاک ہے بلکہ وہ فرشتے تو اس کے بندے ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdx{جو بات کرنے میں بھی اس سے سبقت نہیں کرتے اور اسی کے حکم پر عمل کرتے ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdxi{اللہ جانتا ہے جو کچھ ان کے آگے ہے اور جو کچھ ان کے پیچھے ہے اور وہ کسی کی شفاعت نہیں کرتے سوائے اس کے جس سے خدا راضی ہو۔ اور وہ اس کے خوف و خشیہ سے لرزتے رہتے ہیں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdxii{اور جو (بالفرض) ان میں سے یہ کہہ دے کہ اللہ کے علاوہ میں خدا ہوں۔ تو ہم اسے جہنم کی سزا دیں گے ہم ظالموں کو ایسی ہی سزا دیا کرتے ہیں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdxiii{کیا کافر اس بات پر غور نہیں کرتے کہ آسمان اور زمین پہلے آپس میں ملے ہوئے تھے پھر ہم نے دونوں کو جدا کیا۔ اور ہم نے (پہلے) ہر زندہ چیز کو پانی سے پیدا کیا ہے۔ کیا یہ لوگ پھر بھی ایمان نہیں لاتے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdxiv{اور ہم نے زمین میں پہاڑ قرار دیئے تاکہ وہ لوگوں کو لے کر ڈھلک نہ جائے اور ہم نے ان (پہاڑوں) میں کشادہ راستے بنائے تاکہ وہ راہ پائیں (اور منزل مقصود تک پہنچ جائیں)۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdxv{اور ہم نے آسمان کو محفوظ چھت بنایا مگر یہ لوگ پھر بھی اس کی نشانیوں سے منہ پھیرے ہوئے ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdxvi{اور وہ وہی ہے جس نے رات اور دن اور سورج اور چاند کو پیدا کیا۔ سب (اپنے اپنے) دائرہ (مدار) میں تیر رہے ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdxvii{اور ہم نے آپ سے پہلے کسی آدمی کو ہمیشگی نہیں دی۔ تو اگر آپ انتقال کر جائیں تو کیا یہ لوگ ہمیشہ (یہاں) رہیں گے؟\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdxviii{ہر جاندار موت کا مزہ چکھنے والا ہے اور ہم تمہیں برائی اور اچھائی کے ساتھ آزماتے ہیں (آخرکار) تم ہماری ہی طرف لوٹائے جاؤگے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdxix{اور (اے رسول(ص)) جب کافر آپ کو دیکھتے ہیں تو بس وہ آپ کا مذاق اڑاتے ہیں (اور کہتے ہیں) کیا یہی وہ شخص ہے جو (برائی سے) تمہارے خداؤں کا ذکر کرتا ہے؟ حالانکہ وہ خود خدائے رحمن کے ذکر کے منکر ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdxx{انسان جلد بازی سے پیدا ہوا ہے میں عنقریب تمہیں اپنی (قدرت کی) نشانیاں دکھلاؤں گا۔ پس تم مجھ سے جلدی کا مطالبہ نہ کرو۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdxxi{اور وہ کہتے ہیں کہ اگر آپ سچے ہیں تو یہ (قیامت کا) وعدہ کب پورا ہوگا؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdxxii{کاش ان کافروں کو اس کا کچھ علم ہوتا۔ جب یہ لوگ آگ کو نہیں روک سکیں گے نہ اپنے چہروں سے اور نہ اپنی پشتوں سے اور نہ ہی ان کی کوئی مدد کی جائے گی۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdxxiii{بلکہ وہ (گھڑی) اچانک ان پر آجائے گی۔ اور انہیں مبہوت کر دے گی پھر نہ تو وہ اسے ہٹا سکیں گے اور نہ ہی انہیں مہلت دی جائے گی۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdxxiv{بےشک ان پیغمبروں کا مذاق اڑایا گیا جو آپ سے پہلے تھے تو اسی (عذاب) نے ان مذاق اڑانے والوں کو گھیر لیا جس کا وہ مذاق اڑایا کرتے تھے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdxxv{(اے رسول(ص)) کہہ دیجئے! کون ہے جو رات میں یا دن میں خدائے رحمن (کے عذاب) سے تمہاری حفاظت کر سکتا ہے؟ بلکہ یہ لوگ اپنے پروردگار کے ذکر سے منہ موڑے ہوئے ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdxxvi{کیا ہمارے علاوہ ان کے ایسے خدا ہیں جو ان کی حفاظت کر سکیں؟ وہ (خود ساختہ) خدا تو خود اپنی مدد نہیں کر سکتے اور نہ ہی ہماری طرف سے ان کو پناہ دی جائے گی (اور نہ تائید کی جائے گی)۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdxxvii{بلکہ ہم نے انہیں اور ان کے آباء و اجداد کو (زندگی کا) سر و سامان دیا یہاں تک کہ ان کی لمبی لمبی عمریں گزر گئیں (عرصہ دراز گزر گیا) کیا وہ نہیں دیکھتے کہ ہم زمین کو اس کے اطراف سے برابر گھٹاتے چلے آرہے ہیں تو کیا وہ غالب آسکتے ہیں؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdxxviii{آپ کہہ دیجئے کہ میں تو تمہیں صرف وحی کی بناء پر (عذاب سے) ڈراتا ہوں مگر جو بہرے ہوتے ہیں وہ دعا و پکار نہیں سنتے جب انہیں ڈرایا جائے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdxxix{اور جب انہیں تمہارے پروردگار کے عذاب کا ایک جھونکا بھی چھو جائے تو وہ کہہ اٹھیں گے کہ ہائے افسوس بےشک ہم ظالم تھے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdxxx{ہم قیامت کے دن صحیح تولنے والے میزان (ترازو) قائم کر دیں گے۔ پس کسی شخص پر ذرا بھی ظلم نہیں کیا جائے گا اور اگر کوئی (عمل) رائی کے دانہ کے برابر بھی ہوگا تو ہم اسے (وزن میں) لے آئیں گے اور حساب لینے والے ہم ہی کافی ہیں۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdxxxi{بےشک ہم نے موسیٰ و ہارون کو فرقان، روشنی اور پرہیزگاروں کیلئے نصیحت نامہ عطا کیا۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdxxxii{جو بے دیکھے اپنے پروردگار سے ڈرتے ہیں نیز جو قیامت سے بھی خوف زدہ رہتے ہیں۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiii{اور یہ (قرآن) بابرکت نصیحت نامہ ہے جسے ہم نے نازل کیا ہے۔ کیا تم اس کا انکار کرتے ہو؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiv{اور یقیناً ہم نے اس (عہد موسوی) سے پہلے ابراہیم (ع) کو (ان کے مقام کے مطابق) سوجھ بوجھ عطا فرمائی تھی اور ہم ان کو خوب جانتے تھے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdxxxv{جب آپ نے (منہ بولے) باپ اور اپنی قوم سے کہا کہ یہ مورتیں کیسی ہیں جن (کی عبادت) پر تم جمے بیٹھے ہو۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvi{انہوں نے کہا کہ ہم نے اپنے باپ دادا کو ان کی عبادت کرتے ہوئے پایا ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvii{آپ نے کہا تم بھی اور تمہارے باپ دادا بھی کھلی ہوئی گمراہی میں تھے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdxxxviii{انہوں نے کہا کیا تم ہمارے پاس کوئی حق بات (سچا پیغام) لے کر آئے ہو یا صرف دل لگی کر رہے ہو؟\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdxxxix{آپ نے کہا (دل لگی نہیں) بلکہ تمہارا پروردگار وہ ہے جو آسمانوں اور زمین کا پروردگار ہے جس نے انہیں پیدا کیا ہے اور میں اس بات کے گواہوں میں سے ایک گواہ ہوں۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdxl{اور بخدا میں تمہارے بتوں کے ساتھ (کوئی نہ کوئی) چال ضرور چلوں گا جب تم پیٹھ پھیر کر چلے جاؤ گے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdxli{چنانچہ آپ نے ان کے ایک بڑے بت کے سوا باقی سب کے ٹکڑے ٹکڑے کر دیئے تاکہ وہ اس کی طرف رجوع کریں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdxlii{انہوں نے کہا ہمارے خداؤں کے ساتھ کس نے یہ سلوک کیا ہے؟ بےشک وہ ظالموں میں سے ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdxliii{(بعض) لوگ کہنے لگے کہ ہم نے ایک نوجوان کو سنا ہے جو ان کا ذکر (برائی سے) کیا کرتا ہے جسے ابراہیم کہا جاتا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdxliv{انہوں نے کہا تو پھر اسے (پکڑ کر) سب لوگوں کے سامنے لاؤ تاکہ وہ گواہی دیں۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdxlv{(چنانچہ آپ لائے گئے) ان لوگوں نے کہا اے ابراہیم (ع)! کیا تم نے ہمارے خداؤں کے ساتھ یہ سلوک کیا ہے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdxlvi{ابراہیم (ع)نے کہا: بلکہ ان کے بڑے بت نے یہ سب کاروائی کی ہے ان بتوں سے ہی پوچھ لو اگر وہ بول سکتے ہیں؟\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdxlvii{وہ لوگ (ابراہیم کا یہ جواب سن کر) اپنے دلوں میں سوچنے لگے اور آپس میں کہنے لگے واقعی تم خود ہی ظالم ہو۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdxlviii{پھر انہوں نے (خجالت سے) سر جھکا کر کہا کہ تم جانتے ہو کہ یہ (بت) بات نہیں کرتے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdxlix{آپ نے کہا تو پھر تم اللہ کو چھوڑ کر ایسی چیزوں کی عبادت کرتے ہو جو نہ تمہیں فائدہ پہنچا سکتی ہیں اور نہ نقصان پہنچا سکتی ہیں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdl{تف ہے تم پر اور ان (بتوں) پر جن کی تم اللہ کو چھوڑ کر پرستش کرتے ہو۔ کیا تم عقل سے کام نہیں لیتے؟\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdli{ان لوگوں نے کہا اگر کچھ کرنا چاہتے ہو تو اسے آگ میں جلا دو۔ اور اپنے خداؤں کی مدد کرو۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdlii{(چنانچہ انہوں نے آپ کو آگ میں ڈال دیا تو) ہم نے کہا اے آگ! ٹھنڈی ہوکر اور ابراہیم کے لئے سلامتی کا باعث بن جا۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdliii{ان لوگوں نے ابراہیم کے ساتھ چالبازی کرنا چاہی تھی مگر ہم نے انہیں ناکام کر دیا۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdliv{اور ہم نے انہیں اور لوط کو نجات دی اور اس سر زمین (شام) کی طرف لے گئے جسے ہم نے دنیا جہان والوں کیلئے بابرکت بنایا ہے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdlv{اور ہم نے اسحاق (جیسا بیٹا) اور مزید یعقوب (جیسا پوتا) عطا فرمایا اور سب کو صالح بنایا۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdlvi{اور ہم نے انہیں ایسا امام (پیشوا) بنایا جو ہمارے حکم سے (لوگوں کو) ہدایت کرتے تھے اور ہم نے انہیں نیک کاموں کے کرنے، نماز پڑھنے اور زکوٰۃ دینے کی وحی کی اور وہ ہمارے عبادت گزار تھے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdlvii{اور ہم نے لوط (ع) کو حکمت اور علم عطا کیا۔ اور انہیں اس بستی سے نجات دی جس کے باشندے گندے کام کیا کرتے تھے واقعی وہ قوم بڑی بری اور نافرمان تھی۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdlviii{اور ہم نے اس (لوط(ع)) کو اپنی رحمت میں داخل کیا۔ بےشک وہ بڑے نیکوکاروں میں سے تھے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdlix{اور نوح(ع) (کا ذکر کیجئے) جب انہوں نے (ان سب سے) پہلے پکارا اور ہم نے ان کی دعا و پکار قبول کی اور انہیں اور ان کے اہل کو سخت غم و کرب سے نجات دی۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdlx{اور ان لوگوں کے مقابلہ میں جو ہماری آیتوں کو جھٹلاتے تھے ان کی مدد کی بےشک وہ بڑے برے لوگ تھے۔ پس ہم نے ان سب کو غرق کر دیا۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdlxi{اور داؤد (ع) اور سلیمان (ع) (کا تذکرہ کیجئے) جب وہ کھیت کے بارے میں فیصلہ کر رہے تھے جب ایک گروہ کی بکریاں رات کے وقت اس میں گھس گئی تھیں اور ہم ان کے فیصلہ کا مشاہدہ کر رہے تھے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdlxii{اور ہم نے اس کا فیصلہ سلیمان کو سمجھا دیا تھا اور ہم نے ہر ایک کو حکمت اور علم عطا کیا تھا اور ہم نے داؤد کے ساتھ پہاڑوں اور پرندوں کو مسخر کر دیا تھا جو ان کے ساتھ تسبیح کیا کرتے تھے اور (یہ کام) کرنے والے ہم ہی تھے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdlxiii{اور ہم نے انہیں تمہارے فائدہ کیلئے زرہ بنانے کی صنعت سکھائی تھی تاکہ وہ تمہیں تمہاری لڑائی میں ایک دوسرے کی زد سے بچائے۔ کیا تم اس (احسان) کے شکرگزار ہو؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdlxiv{اور ہم نے تیز و تند ہوا کو سلیمان کیلئے مسخر کر دیا تھا جو ان کے حکم سے اس سرزمین کی طرف چلتی تھی جس میں ہم نے برکت قرار دی ہے اور ہم ہر چیز کا علم رکھنے والے تھے۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdlxv{اور ہم نے کچھ شیطانوں (جنات) کو ان کا تابع بنا دیا تھا جو ان کے لئے غوطہ زنی کرتے تھے۔ اور اس کے علاوہ اور کام بھی کرتے تھے اور ہم ہی ان کے نگہبان تھے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdlxvi{اور ایوب (کا ذکر کیجئے) جب انہوں نے اپنے پروردگار کو پکارا مجھے (بیماری کی) تکلیف پہنچ رہی ہے اور تو ارحم الراحمین ہے (میرے حال پر رحم فرما)۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdlxvii{ہم نے ان کی دعا قبول کی اور ان کو جو تکلیف تھی وہ دور کر دی اور اپنی خاص رحمت سے ہم نے ان کو ان کے اہل و عیال عطا کئے اور ان کے برابر اور بھی اور اس لئے کہ یہ عبادت گزاروں کیلئے یادگار ہے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdlxviii{اور اسماعیل (ع)، ادریس (ع) اور ذوالکفل (کا تذکرہ کیجئے) یہ سب (راہ حق میں) صبر کرنے والوں میں سے تھے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdlxix{اور ہم نے ان سب کو اپنی (خاص) رحمت میں داخل کر لیا تھا۔ یقیناً وہ نیکوکار بندوں میں سے تھے۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdlxx{اور ذوالنون (مچھلی والے) کا (ذکر کیجئے) جب وہ خشمناک ہوکر چلے گئے اور وہ سمجھے کہ ہم ان پر تنگی نہیں کریں گے۔ پھر انہوں نے اندھیروں میں سے پکارا۔ تیرے سوا کوئی الہ نہیں ہے۔ پاک ہے تیری ذات بےشک میں زیاں کاروں میں سے ہوں۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdlxxi{ہم نے ان کی دعا قبول کی اور انہیں غم سے نجات دی اور ہم اسی طرح ایمان والوں کو نجات دیا کرتے ہیں۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdlxxii{اور زکریا (ع) کا (ذکر کیجئے) جب انہوں نے پکارا اے میرے پروردگار! مجھے (وارث کے بغیر) اکیلا نہ چھوڑ۔ جبکہ تو خود بہترین وارث ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiii{ہم نے ان کی دعا قبول کی اور انہیں یحییٰ (جیسا بیٹا) عطا کیا اور ان کی بیوی کو ان کیلئے تندرست کر دیا۔ یہ لوگ نیک کاموں میں جلدی کرتے تھے اور ہم کو شوق و خوف (اور امید و بیم) کے ساتھ پکارتے تھے اور وہ ہمارے لئے (عجز و نیاز سے) جھکے ہوئے تھے۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiv{اور اس خاتون (کا ذکر کیجئے) جس نے اپنے ناموس کی حفاظت کی تو ہم نے اس میں اپنی (خاص) روح پھونک دی۔ اور انہیں اور ان کے بیٹے (عیسیٰ) کو دنیا جہان والوں کیلئے (اپنی قدرت کی) نشانی بنا دیا۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdlxxv{(اے ایمان والو) یہ تمہاری (ملت) ہے جو درحقیقت ملت واحدہ ہے اور میں تمہارا پروردگار ہوں۔ بس تم میری ہی عبادت کرو۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvi{لیکن لوگوں نے اپنے (دینی) معاملہ کو ٹکڑے ٹکڑے کر ڈالا (انجام کار) سب ہماری ہی طرف لوٹ کر آنے والے ہیں۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvii{پس جو کوئی نیک کام کرے درآنحالیکہ وہ مؤمن ہو تو اس کی کوشش کی ناقدری نہ ہوگی اور ہم اسے لکھ رہے ہیں۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdlxxviii{اور جس بستی کو ہم نے ہلاک کر دیا اس کیلئے حرام ہے۔ یعنی وہ (دنیا میں) دوبارہ لوٹ کر نہیں آئیں گے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdlxxix{یہاں تک کہ جب یاجوج و ماجوج کھول دیئے جائیں گے تو وہ ہر بلندی سے دوڑتے ہوئے نکل پڑیں گے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdlxxx{اور (جب) اللہ کا سچا وعدہ (قیامت کا) قریب آجائے گا تو ایک دم کافروں کی آنکھیں پھٹی رہ جائیں گی (اور کہیں گے) ہائے افسوس! ہم اس سے غفلت میں رہے بلکہ ہم ظالم تھے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxi{بےشک تم اور وہ چیزیں جن کی تم اللہ کو چھوڑ کر عبادت کرتے تھے جہنم کا ایندھن ہیں اس میں تم سب کو داخل ہونا ہے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxii{اگر یہ چیزیں برحق خدا ہوتیں تو جہنم میں نہ جاتیں اب تم سب کو اس میں ہمیشہ رہنا ہے۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiii{ان کی اس میں چیخ و پکار ہوگی اور وہ اس میں کچھ نہیں سنیں گے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiv{ہاں البتہ وہ لوگ جن کیلئے ہماری طرف سے پہلے بھلائی مقدر ہو چکی ہوگی وہ اس سے دور رہیں گے۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxv{وہ اس کی آہٹ بھی نہیں سنیں گے اور وہ اپنی من پسند نعمتوں میں ہمیشہ رہیں گے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvi{ان کو بڑی گھبراہٹ بھی غمزدہ نہیں کر سکے گی اور فرشتے ان کا استقبال کریں گے (اور بتائیں گے کہ) یہ ہے آپ کا وہ دن جس کا تم سے وعدہ کیا جاتا تھا۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvii{جس دن ہم آسمان کو اس طرح لپیٹ دیں گے جس طرح طومار میں خطوط لپیٹے جاتے ہیں جس طرح ہم نے پہلے تخلیق کی ابتداء کی تھی اسی طرح ہم اس کا اعادہ کریں گے۔ یہ ہمارے ذمہ وعدہ ہے یقیناً ہم اسے (پورا) کرکے رہیں گے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxviii{اور ہم نے ذکر (توراۃ یا پند و نصیحت) کے بعد زبور میں لکھ دیا تھا کہ زمین کے وارث میرے نیک بندے ہوں گے۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxix{بےشک اس میں عبادت گزار لوگوں کیلئے بڑا انعام ہے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdxc{(اے رسول) ہم نے آپ کو تمام عالمین کیلئے رحمت بنا کر بھیجا ہے۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdxci{آپ کہہ دیجئے! کہ میری طرف جو کچھ وحی کی گئی ہے وہ یہ ہے کہ تمہارا الٰہ بس ایک الہ ہے۔ تو کیا تم اس کے آگے سر جھکاتے ہو؟\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdxcii{پس اگر وہ اس سے روگردانی کریں تو آپ کہہ دیجئے! کہ میں نے برابر آپ کو خبردار کر دیا ہے اب مجھے معلوم نہیں ہے کہ وہ دن جس کا تم سے وعدہ کیا گیا ہے وہ قریب ہے یا دور؟\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdxciii{بےشک وہ (اللہ) بلند آواز سے کہی گئی بات کو بھی جانتا ہے اور اسے بھی جسے تم چھپاتے ہو۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdxciv{اور میں کیا جانوں؟ کہ یہ تاخیر) تمہارے لئے آزمائش ہے یا ایک خاص وقت تک زندگی کا لطف اٹھانے کی مہلت ہے۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdxcv{(آخرکار رسول(ص) نے) کہا اے میرے پروردگار! تو حق کے ساتھ فیصلہ کر دے۔ (اے لوگو) ہمارا پروردگار وہی خدائے رحمن ہے جس سے ان باتوں کے خلاف مدد مانگی جاتی ہے جو تم بنا رہے ہو۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdxcvi{\basmalahur اے لوگو! اپنے پروردگار (کی ناراضی) سے ڈرو۔ بیشک قیامت کا زلزلہ بہت بڑی شے ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdxcvii{جس دن تم اسے دیکھوگے کہ ہر دودھ پلانے والی (ماں) اس (بچہ) سے غافل ہو جائے گی جسے وہ دودھ پلاتی ہے اور ہر حاملہ عورت اپنا حمل گرا دے گی۔ اور تم لوگوں کو نشہ میں مدہوش دیکھوگے۔ حالانکہ وہ نشہ میں مدہوش نہیں ہوں گے۔ مگر اللہ کا عذاب بڑا سخت ہوگا۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdxcviii{اور لوگوں میں سے کچھ ایسے بھی ہیں کہ جو اللہ کے بارے میں علم کے بغیر کج بحثی کرتے ہیں اور سرکش شیطان کی پیروی کرتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdxcix{جس (مردود) کے بارے میں لکھا جا چکا ہے کہ جو کوئی اس کو دوست بنائے گا وہ ضرور اسے گمراہ کرے گا۔ اور اسے بھڑکتی ہوئی آگ کے عذاب کا راستہ دکھائے گا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdc{اے لوگو! اگر تمہیں (دوبارہ) اٹھائے جانے میں شک ہے تو (اس میں تو کوئی شک نہیں کہ) ہم نے تمہیں مٹي سے پیدا کیا ہے پھر نطفہ سے، پھر جمے ہوئے خون سے، پھر گوشت کے لوتھڑے سے جو متشکل (مکمل تخلیق والا) بھی ہوتا ہے اور غیر متشکل (نامکمل تخلیق والا) بھی۔ اور یہ اس لئے ہے کہ ہم تم پر (اپنی قدرت کی کار فرمائی) واضح کریں اور ہم جس (نطفے) کو چاہتے ہیں ایک مقررہ مدت تک رحموں میں ٹھہرائے رکھتے ہیں پھر تمہیں بچے کی صورت میں باہر نکالتے ہیں پھر (تمہاری پرورش کرتے ہیں) تاکہ اپنی پوری قوت کی منزل (جوانی) تک پہنچو۔ پھر تم میں سے بعض کو تو (بڑھاپے سے پہلے) اٹھا لیا جاتا ہے اور بعض کو پست ترین عمر کی طرف لوٹا دیا جاتا ہے تاکہ جاننے کے بعد کچھ نہ جانے اور تم دیکھتے ہو کہ زمین خشک پڑی ہے تو جب ہم اس پر پانی برساتے ہیں تو وہ لہلہانے اور ابھرنے لگتی ہے اور ہر قسم کی خوشنما نباتات اگاتی ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdci{یہ (سب کچھ) اس لئے ہے کہ اللہ ہی کی ذات حق ہے۔ اور بےشک وہی مردوں کو زندہ کرتا ہے اور وہ ہر چیز پر قادر ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdcii{اور قیامت ضرور آنے والی ہے۔ جس میں کوئی شک نہیں ہے اور یقیناً اللہ انہیں زندہ کرے گا جو قبروں میں ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdciii{اور لوگوں میں سے کچھ ایسے بھی ہیں جو اللہ کے بارے میں بغیر کسی علم کے، بغیر کسی راہنمائی کے اور بغیر کسی روشن کتاب کے کج بحثی کرتے ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdciv{(غرور سے) اپنے شانے کو موڑے ہوئے (اور گردن اکڑائے ہوئے) تاکہ (لوگوں کو) اللہ کی راہ سے گمراہ کریں ان کیلئے دنیا میں رسوائی ہے اور قیامت کے دن ہم انہیں جلانے والی آگ کے عذاب کا مزہ چکھائیں گے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdcv{تب اسے بتایا جائے گا کہ یہ سب کچھ سزا ہے اس کی جو تیرے دونوں ہاتھوں نے آگے بھیجا ہے اور خدا ہرگز اپنے بندوں پر ظلم کرنے والا نہیں ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcvi{اور لوگوں میں کوئی ایسا بھی ہوتا ہے جو کنارہ پر رہ کر خدا کی عبادت کرتا ہے۔ سو اگر اسے کوئی فائدہ پہنچ جائے تو وہ اس سے مطمئن ہو جاتا ہے اور اگر اسے کوئی آزمائش پیش آجائے (یا کوئی مصیبت پہنچ جائے) تو فوراً (اسلام سے) منہ موڑ لیتا ہے۔ اس نے دنیا و آخرت کا گھاٹا اٹھایا اور یہ کھلا ہوا خسارہ ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdcvii{وہ اللہ کو چھوڑ کر اس کو پکارتا ہے جو نہ اسے نقصان پہنچاتا ہے اور نہ نفع۔ یہی تو انتہائی گمراہی ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdcviii{وہ ایسے کو پکارتا ہے جس کا ضرر اس کے فائدہ سے زیادہ قریب ہے۔ کیا ہی برا ہے آقا اور کیا ہی برا ہے ساتھی۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcix{بےشک اللہ ان لوگوں کو جو ایمان لائے اور نیک عمل بھی کئے ان بہشتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہوں گی۔ بیشک اللہ وہ کرتا ہے جو کچھ وہ چاہتا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcx{جو شخص یہ خیال کرتا ہے کہ خدا دنیا اور آخرت میں اس کی مدد نہیں کرے گا تو اسے چاہیے کہ ایک رسی کے ذریعہ آسمان تک پہنچ کر شگاف لگائے۔ پھر دیکھے کہ آیا اس کی یہ تدبیر اس چیز کو دور کر سکتی ہے جو اسے غصہ میں لا رہی تھی۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcxi{اور اسی طرح ہم نے اس (قرآن) کو نازل کیا ہے روشن دلیلوں کی صورت میں اور بےشک اللہ جسے چاہتا ہے ہدایت دیتا ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxii{بےشک جو اہلِ ایمان ہیں، جو یہودی ہیں، جو صابی ہیں، جو عیسائی ہیں، جو مجوسی ہیں اور جو مشرک ہیں یقیناً قیامت کے دن اللہ ان کے درمیان فیصلہ کرے گا۔ بیشک اللہ ہر چیز پر گواہ ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxiii{کیا تم نے نہیں دیکھا کہ ہر چیز اللہ کو سجدہ کر رہی ہے خواہ وہ آسمانوں میں ہے یا زمین میں۔ سورج، چاند، ستارے، پہاڑ، درخت، چوپائے اور بہت سارے انسان بھی اور بہت سے انسان وہ ہیں جن پر عذاب مقرر ہو چکا ہے اور جس کو اللہ ذلیل کر دے اسے کوئی عزت دینے والا نہیں ہے بیشک اللہ کرتا ہے جو وہ چاہتا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxiv{یہ دو فریق ہیں جو اپنے پروردگار کے بارے میں باہم جھگڑ رہے ہیں تو ان میں سے جو لوگ کافر ہیں ان کیلئے آگ کے کپڑے کاٹے جا چکے ہیں ان کے سروں پر کھولتا ہوا پانی انڈیلا جائے گا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxv{(اور) جس سے ان کے پیٹ کے اندر کی چیزیں اور کھالیں گل جائیں گی۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxvi{اور ان کے لئے لوہے کے گرز ہوں گے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxvii{جب بھی چاہیں گے کہ اس (جہنم) سے نکل کر رنج و غم سے چھٹکارا پائیں تو پھر اسی میں لوٹا دئیے جائیں گے اور (ان سے کہا جائے گا کہ) جلانے والی آگ کا مزہ چکھو۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxviii{جو لوگ ایمان لائے اور اس کے ساتھ نیک عمل بھی کئے بےشک اللہ ان کو ان بہشتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہوں گی وہاں ان کو سونے کے کنگن اور موتی (کے ہار) پہنائے جائیں گے اور وہاں ان کے لباس ریشم کے ہوں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxix{(یہ اس لئے ہے کہ) انہیں پاکیزہ گفتگو کی طرف ہدایت دی گئی اور انہیں لائق ستائش (خدا) کی راہ کی طرف راہنمائی کی گئی۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxx{جن لوگوں نے کفر اختیار کیا اور (لوگوں) کو خدا کے راستے سے روکتے ہیں اور اس مسجد سے جسے ہم نے (بلا امتیاز) سب لوگوں کیلئے (عبادت گاہ) بنایا ہے جس میں وہاں کے رہنے والے اور باہر سے آنے والے برابر ہیں اور جو بھی اس میں ظلم و زیادتی کے ساتھ غلط روی کا ارادہ کرے تو ہم اسے دردناک عذاب کا مزہ چکھائیں گے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxxi{اور (وہ وقت یاد کرو) جب ہم نے ابراہیم (ع) کیلئے خانہ کعبہ کی جگہ معین کر دی۔ (اور حکم دیا کہ) میرے ساتھ کسی کو شریک نہ کرنا۔ اور میرے گھر کو طواف کرنے والوں، قیام کرنے والوں اور رکوع و سجود کرنے والوں کیلئے پاک رکھنا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcxxii{اور لوگوں میں حج کا اعلان کر دو۔ کہ لوگ (آپ کی آواز پر لبیک کہتے ہوئے) آپ کے پاس آئیں گے۔ پیادہ پا اور ہر لاغر سواری پر کہ وہ سواریاں دور دراز سے آئی ہوں گی۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiii{تاکہ وہ اپنے فائدوں کیلئے حاضر ہوں اور مقررہ (دنوں میں خدا کا نام لیں) ان چوپایوں پر (ذبح کے وقت) جو اللہ نے انہیں عنایت فرمائے۔ پس خود بھی ان سے کھاؤ اور حاجت مند فقیر کو بھی کھلاؤ۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiv{پھر لوگوں کو چاہیئے کہ اپنی میل کچیل دور کریں اور اپنی نذریں پوری کریں اور قدیم گھر (خانہ کعبہ) کا طواف کریں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcxxv{یہ ہے حج اور اس کے مناسک کی بات! جو اللہ کی محترم چیزوں کی تعظیم کرتا ہے۔ تو یہ اس کے پروردگار کے ہاں بہتر ہے اور تمہارے لئے چوپائے حلال ہیں۔ بجز ان کے جو تم سے بیان کئے جاتے رہتے ہیں۔ پس تم بتوں کی گندگی سے پرہیز کرو۔ اور راگ گانے کی مجلس سے اجتناب کرو۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvi{صرف اللہ ہی کیلئے ہو کر رہو اس کے ساتھ کسی کو شریک نہ ٹھہراتے ہوئے۔ اور جو کوئی اللہ کے ساتھ کسی کو شریک ٹھہراتا ہے تو گویا وہ آسمان سے گرا تو اسے کسی پرندہ نے اچک لیا یا ہوا نے اسے کسی دور دراز جگہ پر پھینک دیا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvii{یہ ہے حقیقت حال! اور جو کوئی شعائر اللہ کی تعظیم کرے تو یہ دلوں کے تقویٰ سے ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcxxviii{تمہارے ان جانوروں میں ایک مقررہ مدت تک فائدے ہیں۔ پھر ان کے ذبح کرنے کا مقام اسی قدیم گھر کی طرف ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcxxix{اور ہم نے ہر قوم کیلئے قربانی کا ایک طور طریقہ مقرر کیا ہے۔ تاکہ وہ ان چوپایوں پر (ذبح کے وقت) اللہ کا نام لیں، جو اس نے انہیں عطا کئے ہیں (الغرض) تمہارا اللہ ایک ہی ہے لہٰذا تم اس کی بارگاہ میں سر جھکاؤ اور ان عاجزی کرنے والوں کو خوشخبری دے دو۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcxxx{کہ جب (ان کے سامنے) اللہ کا ذکر کیا جاتا ہے تو ان کے دل دھل جاتے ہیں۔ اور جو ان مصائب و آلام پر صبر کرنے والے ہیں جو انہیں پہنچتے ہیں اور جو پابندی سے نماز ادا کرتے ہیں۔ اور ہم نے انہیں جو کچھ عطا کیا ہے اس میں سے (راہ خدا میں) خرچ کرتے رہتے ہیں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxi{اور ہم نے قربانی کے اونٹوں کو تمہارے لئے شعائر اللہ سے قرار دیا ہے۔ ان میں تمہارے لئے بھلائی ہے پس تم ان کو صف بستہ کھڑا کرکے خدا کا نام لو۔ اور جب وہ کروٹ کے بل گر پڑیں تو ان میں سے خود بھی کھاؤ اور بے سوال اور سوالی کو بھی کھلاؤ اسی طرح ہم نے ان جانوروں کو تمہارے لئے مسخر کیا ہے تاکہ تم شکرگزار (بندے) بن جاؤ۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxii{نہ ان کا گوشت اللہ تک پہنچتا ہے اور نہ ان کا خون ہاں البتہ اس تک تمہارا تقویٰ پہنچتا ہے۔ اسی طرح ہم نے انہیں تمہارے لئے مسخر کیا ہے تاکہ تم اس کی دی ہوئی ہدایت پر اس کی کبریائی و بڑائی بیان کرو۔ اور (اے رسول) احسان کرنے والوں کو خوشخبری دے دو۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiii{بےشک اللہ اہلِ ایمان کی طرف سے دفاع کرتا ہے۔ یقیناً اللہ کسی خیانت کار کفرانِ نعمت کرنے والے کو دوست نہیں رکھتا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiv{ان مظلوموں کو (دفاعی جہاد کی) اجازت دی جاتی ہے جن سے جنگ کی جا رہی ہے اس بناء پر کہ ان پر ظلم کیا گیا ہے۔ اور بیشک اللہ ان کی مدد کرنے پر قادر ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxv{یہ وہ (مظلوم) ہیں جو ناحق اپنے گھروں سے نکال دیئے گئے صرف اتنی بات پر کہ وہ کہتے تھے کہ ہمارا پروردگار اللہ ہے اور اگر خدا بعض لوگوں کو بعض کے ذریعہ سے دفع نہ کرتا رہتا تو نصرانیوں کی خانقاہیں اور گرجے اور (یہود کے) عبادت خانے اور (مسلمانوں کی) مسجدیں جن میں بکثرت ذکر خدا ہوتا ہے۔ سب گرا دی جاتیں جو کوئی اللہ (کے دین) کی مدد کرے گا اللہ ضرور اس کی مدد کرے گا۔ بیشک وہ طاقت والا (اور) غالب آنے والا ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvi{یہ وہ لوگ ہیں کہ اگر ہم انہیں زمین میں اقتدار عطا کریں تو وہ نماز قائم کریں گے، زکوٰۃ دیں گے، نیکی کا حکم دیں گے اور برائی سے روکیں گے اور تمام کاموں کا انجام اللہ ہی کے ہاتھ (اختیار) میں ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvii{(اے رسول(ص)) اگر لوگ آپ کو جھٹلاتے ہیں تو (یہ کوئی نئی بات نہیں ہے) ان سے پہلے (کئی قومیں اپنے نبیوں کو جھٹلا چکی ہیں جیسے) قوم نوح نے، عاد و ثمود نے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxviii{اور قوم ابراہیم (ع) نے اور قوم لوط نے (جھٹلایا)۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxix{اور اہل مدین نے بھی۔ اور موسیٰ کو بھی جھٹلایا گیا۔ سو پہلے میں نے کافروں کو (کچھ) مہلت دی اور پھر انہیں پکڑ لیا۔ تو (دیکھو) میرا عذاب کیسا تھا؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcxl{غرض کتنی ہی بستیاں ہیں جنہیں ہم نے تباہ و برباد کر دیا کیونکہ وہ ظالم تھیں (چنانچہ) وہ اپنی چھتوں پر گری پڑی ہیں اور کتنے کنویں ہیں جو بیکار پڑے ہیں اور کتنے مضبوط محل ہیں (جو کھنڈر بن گئے ہیں)۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcxli{کیا یہ لوگ زمین میں چلے پھرے نہیں ہیں تاکہ( یہ منظر دیکھ کر) ان کے دل ایسے ہو جاتے کہ جن سے وہ (حق کو) سمجھ سکتے اور کان ایسے ہو جاتے جن سے (آواز حق) سن سکتے۔ مگر (حقیقت یہ ہے کہ) آنکھیں اندھی نہیں ہوتیں وہ دل اندھے ہو جاتے ہیں جو سینوں میں ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcxlii{(اے رسول(ص)) یہ لوگ آپ سے عذاب کے مطالبہ میں جلدی کر رہے ہیں اور اللہ کبھی اپنے وعدہ کی خلاف ورزی نہیں کرے گا اور آپ کے پروردگار کے نزدیک ایک دن تم لوگوں کے شمار کئے ہوئے ایک ہزار سال کے برابر ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcxliii{اور کتنی ہی ایسی بستیاں ہیں جن کو میں نے مہلت دی۔ حالانکہ وہ ظالم تھیں۔ پھر میں نے انہیں پکڑ لیا اور (آخرکار) میری طرف لوٹ کر آنا ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcxliv{(اے رسول(ص)) آپ کہہ دیجئے! اے لوگو! میں تو صرف تمہیں ایک کھلا ہوا (عذاب خدا سے) ڈرانے والا ہوں۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcxlv{سنو جو لوگ ایمان لائے اور نیک عمل کئے ان کیلئے (گناہوں کی) بخشش بھی ہے اور عزت کی روزی بھی۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvi{اور جو لوگ ہماری آیتوں کے بارے میں (ہمیں) عاجز کرنے کی کوشش کرتے ہیں۔ وہی لوگ (دوزخی) ہیں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvii{اور ہم نے آپ سے پہلے کوئی رسول اور کوئی نبی نہیںبھیجا مگر یہ کہ جب اس نے (اصلاح احوال کی) آرزو کی تو شیطان نے اس کی آرزو میں خلل اندازی کی۔ پس شیطان جو خلل اندازی کرتا ہے خدا اسے مٹا دیتا ہے اور اپنی نشانیوں کو زیادہ مضبوط کر دیتا ہے اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcxlviii{(یہ سب اس لئے ہے) تاکہ اللہ شیطانوں کی خلل اندازی کو ان لوگوں کیلئے آزمائش کا ذریعہ بنائے جن کے دلوں میں بیماری ہے اور جن کے دل سخت ہیں بےشک ظالم لوگ بڑی گہری مخالفت میں پڑے ہوئے ہیں۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcxlix{اور اس میں (یہ مصلحت بھی ہے) کہ وہ لوگ جنہیں علم عطا کیا گیا ہے۔ جان لیں کہ یہ (وحی) آپ کے پروردگار کی طرف سے حق ہے تاکہ وہ اس پر ایمان لائیں اور ان کے دلوں میں اس کیلئے عجز و نیاز پیدا ہو جائے۔ بےشک اللہ ایمان لانے والوں کو سیدھے راستہ تک پہنچانے والا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcl{اور جو کافر ہیں وہ تو ہمیشہ اس کی طرف سے شک میں پڑے رہیں گے یہاں تک کہ اچانک قیامت ان پر آجائے۔ یا پھر منحوس دن کا عذاب ان پر آجائے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcli{اس دن بادشاہی صرف اللہ ہی کی ہوگی (لہٰذا) وہی لوگوں کے درمیان فیصلہ کرے گا۔ پس جو ایمان لائے اور نیک عمل کرے وہ نعمتوں والے بہشتوں میں ہوں گے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdclii{اور جنہوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا ان کیلئے رسوا کن عذاب ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcliii{اور جن لوگوں نے اللہ کی راہ میں ہجرت کی پھر قتل کر دیئے گئے۔ یا اپنی موت مر گئے (دونوں صورتوں میں) اللہ ضرور انہیں اچھی روزی عطا فرمائے گا (کیونکہ) وہ بہترین روزی عطا کرنے والا ہے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcliv{(اور) وہ ضرور انہیں ایسی جگہ داخل کرے گا جسے وہ پسند کریں گے۔ بےشک وہ بڑا جاننے والا، بڑا بردبار ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdclv{یہ بات تو ہو چکی۔ اور جو شخص ویسی ہی سزا دے جیسی اسے سزا ملی ہے پھر اس پر زیادتی کی جائے تو اللہ ضرور اس کی مدد کرے گا۔ بےشک اللہ بڑا معاف کرنے والا، بڑا بخشنے والا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdclvi{یہ اس لئے ہے کہ اللہ رات کو دن میں اور دن کو رات میں داخل کرتا ہے اور بےشک اللہ بڑا سننے والا، بڑا دیکھنے والا ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdclvii{اس کی وجہ یہ ہے کہ اللہ ہی حق ہے۔ اور اس کے علاوہ جسے وہ پکارتے ہیں وہ باطل ہے۔ اور بےشک اللہ ہی بلند (مرتبہ والا) بزرگ ہے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdclviii{کیا تم نے نہیں دیکھا کہ خدا آسمان سے پانی برساتا ہے تو (خشک) زمین سرسبز و شاداب ہو جاتی ہے۔ بےشک اللہ بڑا لطف و کرم کرنے والا (اور) بڑا خبر رکھنے والا ہے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdclix{جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے سب اسی کا ہے اور بےشک اللہ سب سے بے نیاز (اور) ہر تعریف کا حقدار ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdclx{کیا تم نہیں دیکھتے کہ جو کچھ زمین میں ہے۔ اللہ نے وہ سب کچھ تمہارے لئے مسخر کر دیا ہے اور کشتی کو بھی جو سمندر میں اس کے حکم سے چلتی ہے۔ اور وہی آسمان کو روکے ہوئے ہے کہ اس کے حکم کے بغیر زمین پر نہ گر پڑے۔ بےشک اللہ لوگوں پر بڑا شفقت والا، بڑا رحمت والا ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdclxi{وہ وہی ہے جس نے تمہیں زندگی عطا کی ہے پھر وہی تمہیں موت دے گا۔ اور پھر (دوبارہ) زندہ کرے گا۔ بےشک انسان بڑا ناشکرا ہے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdclxii{(اے رسول(ص)) ہم نے ہر قوم کیلئے عبادت کا ایک طریقہ مقرر کر دیا ہے جس کے مطابق وہ عبادت کر رہی ہے۔ اس لئے انہیں آپ سے جھگڑا نہیں کرنا چاہیے اور آپ اپنے پروردگار کی طرف بلاتے رہیے! یقیناً آپ ہدایت کے سیدھے راستہ پر ہیں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdclxiii{اور اگر وہ لوگ (خواہ مخواہ) آپ سے بحث کریں تو آپ کہہ دیجئے! کہ اللہ بہتر جانتا ہے جو کچھ تم کر رہے ہو۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdclxiv{قیامت کے دن اللہ تمہارے درمیان ان باتوں کے بارے میں فیصلہ کر دے گا جن میں تم باہم اختلاف کرتے ہو۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdclxv{کیا تم نہیں جانتے کہ اللہ وہ سب کچھ جانتا ہے جو آسمان اور زمین میں ہے۔ بےشک یہ سب کچھ ایک کتاب میں درج ہے۔ اور یہ بات اللہ پر آسان ہے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdclxvi{اور یہ لوگ اللہ کو چھوڑ کر ایسوں کی عبادت کرتے ہیں جن کیلئے نہ تو اللہ نے کوئی دلیل (سند) نازل کی ہے اور نہ ہی انہیں ان کے بارے میں کوئی علم ہے اور (ان) ظالموں کیلئے کوئی مددگار نہیں ہے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdclxvii{اور جب ان کے سامنے ہماری آیتیں پڑھی جاتی ہیں تو تم کافروں کے چہروں پر ناگواری کے آثار واضح محسوس کرتے ہو۔ قریب ہے وہ ان پر حملہ کر دیں جو ان کے سامنے ہماری آیتیں پڑھ کر سناتے ہیں۔ کیا میں تمہیں بتاؤں کہ اس سے بڑھ کر ناگوار چیز کیا ہے؟ وہ دوزخ کی آگ ہے۔ جس کا اللہ نے کافروں سے وعدہ کر رکھا ہے۔ اور وہ بڑا برا ٹھکانہ ہے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdclxviii{اے لوگو! ایک مثال دی جاتی ہے اسے غور سے سنو۔ اللہ کو چھوڑ کر تم جن معبودوں کو پکارتے ہو وہ ایک مکھی بھی پیدا نہیں کر سکتے۔ اگرچہ وہ سب کے سب اس کام کے لئے اکٹھے ہو جائیں۔ اور اگر ایک مکھی ان سے کوئی چیز چھین کر لے جائے تو وہ اسے اس (مکھی) سے چھڑا نہیں سکتے۔ طالب و مطلوب دونوں ہی کمزور و ناتواں ہیں۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdclxix{(آہ) ان لوگوں نے اللہ کی اس طرح قدر نہیں کی جس طرح قدر کرنی چاہیے۔ بےشک اللہ بڑا طاقتور ہے (اور) سب پر غالب ہے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdclxx{اللہ پیغام پہنچانے والے فرشتوں میں سے منتخب کر لیتا ہے اور انسانوں میں سے بھی۔ بیشک اللہ بڑا سننے والا، بڑا دیکھنے والا ہے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdclxxi{وہ جانتا ہے جو کچھ ان کے سامنے ہے اور جو کچھ ان کے پیچھے ہے اور سب معاملات کی بازگشت اللہ ہی کی طرف ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdclxxii{اے ایمان والو! رکوع و سجود کرو۔ اور اپنے پروردگار کی عبادت کرو۔ اور نیک کام کرو۔ تاکہ تم فلاح پاؤ۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiii{اور اللہ کی راہ میں جہاد کرو۔ جیساکہ جہاد کرنے کا حق ہے اس نے تمہیں منتخب کیا ہے۔ اور دین کے معاملہ میں اس نے تمہارے لئے کوئی تنگی روا نہیں رکھی۔ اپنے باپ (مورث اعلیٰ) ابراہیم (ع) کی ملت کی پیروی کرو۔ اسی (اللہ) نے اس سے پہلے بھی تمہارا نام مسلمان رکھا اور اس (قرآن) میں بھی تاکہ پیغمبر تم پر گواہ ہوں۔ اور تم لوگوں پر گواہ ہو۔ پس تم نماز قائم کرو۔ اور زکوٰۃ دو اور اللہ سے وابستہ ہو جاؤ۔ وہی تمہارا مولا ہے سو کیسا اچھا مولا ہے اور کیسا اچھا مددگار ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiv{\basmalahur یقیناً وہ اہلِ ایمان فلاح پاگئے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdclxxv{جو اپنی نمازوں میں خشوع و خضوع کرتے ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvi{اور جو بیہودہ باتوں سے منہ موڑتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvii{اور جو زکوٰۃ ادا کرتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdclxxviii{اور جو اپنی شرمگاہوں کی حفاظت کرتے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdclxxix{سوائے اپنی بیویوں کے اور ان کنیزوں کے جو ان کی ملکیت ہیں کہ اس صورت میں وہ قابل ملامت نہیں ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdclxxx{اور جو اس (دو طرح) کے علاوہ کوئی خواہش کرے تو ایسے ہی لوگ (حد سے) تجاوز کرنے والے ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxi{اور جو اپنی امانتوں اور اپنے عہد و پیمان کا لحاظ رکھتے ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxii{اور جو اپنی نمازوں کی پوری حفاظت کرتے ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiii{یہی لوگ وارث ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiv{جو فردوس (بریں) کے وارث ہوں گے (اور) وہ اس میں ہمیشہ رہیں گے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxv{یقیناً ہم نے انسان کو مٹی کے جوہر سے پیدا کیا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvi{پھر ہم نے اسے نطفہ کی صورت میں ایک محفوظ مقام (رحم) میں رکھا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvii{پھر ہم نے نطفہ کو منجمد خون بنایا اور پھر ہم نے اس منجمد خون کو گوشت کا لوتھڑا بنایا پھر اس لوتھڑے سے ہڈیاں پیدا کیں پھر ان ہڈیوں پر گوشت چڑھایا پھر ہم نے (اس میں روح ڈال کر) ایک دوسری مخلوق بنا دیا۔ پس بڑا بابرکت ہے وہ اللہ جو بہترین خالق ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxviii{پھر تم اس کے بعد ضرور مرنے والے ہو۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxix{پھر اس کے بعد تم قیامت کے دن اٹھائے جاؤگے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxc{اور یقیناً ہم نے تمہارے اوپر سات راستے (آسمان) پیدا کئے ہیں اور ہم (اپنی) مخلوق سے غافل نہیں تھے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxci{اور ہم نے ایک خاص اندازہ کے ساتھ آسمان سے پانی برسایا اور اسے زمین میں ٹھہرایا اور یقیناً ہم اسے لے جانے پر بھی قادر ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxcii{پھر ہم نے اس کے ذریعہ سے تمہارے لئے کھجوروں اور انگوروں کے باغات اگائے ان باغوں میں تمہارے لئے بہت سے پھل ہیں اور ان میں سے تم کھاتے بھی ہو۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxciii{اور (ہم نے) ایک درخت ایسا بھی (پیدا کیا) جو طور سینا سے نکلتا ہے (زیتون کا درخت) جو کھانے والوں کیلئے تیل اور سالن لے کر اگتا ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxciv{اور تمہارے لئے چوپایوں میں بڑا سامانِ عبرت ہے ہم تمہیں اس سے (دودھ) پلاتے ہیں جو ان کے پیٹوں میں ہے اور تمہارے لئے ان میں اور بہت سے فائدے ہیں اور انہی کے (گوشت) سے تم کھاتے بھی ہو۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxcv{اور ان پر اور کشتیوں پر تمہیں سوار کیا جاتا ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvi{اور بےشک ہم نے نوح(ع) کو ان کی قوم کی طرف ہدایت کیلئے بھیجا۔ تو آپ نے کہا اے میری قوم! اللہ کی عبادت کرو۔ اس کے سوا کوئی اللہ نہیں ہے۔ کیا تم (اس کی حکم عدولی سے) نہیں ڈرتے؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvii{تو ان کی قوم کے کافر سرداروں نے کہا کہ یہ (نوح(ع)) نہیں ہے مگر تم ہی جیسا ایک بشر (آدمی) ہے جو تم پر بڑائی حاصل کرنا چاہتا ہے اور اگر خدا (یہی) چاہتا تو وہ فرشتوں کو بھیجتا۔ ہم نے تو یہ بات اپنے پہلے باپ داداؤں سے نہین سنی۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxcviii{بس یہ ایک آدمی ہے۔ جسے کچھ جنون ہوگیا ہے۔ پس تم اس کے بارے میں کچھ مدت تک انتظار کرو۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxcix{آپ نے کہا اے میرے پروردگار! تو میری مدد کر کیونکہ انہوں نے مجھے جھٹلایا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcc{سو ہم نے ان کی طرف وحی بھیجی کہ تم ہماری نگرانی اور ہماری وحی کے مطابق کشتی بناؤ۔ پس جب ہمارا عذاب آجائے۔ اور تنور سے پانی ابلنے لگے تو ہر قسم کے نر اور مادہ (جانوروں) میں سے جوڑا جوڑا (اس میں) داخل کرلو۔ اور اپنے گھر والوں کو بھی سوا ان کے جن کے خلاف پہلے سے فیصلہ ہو چکا ہے۔ اور ظالموں کے بارے میں مجھ سے کوئی بات نہ کرنا کیونکہ یہ اب یقیناً غرق ہونے والے ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcci{اور جب تم اور تمہارے ساتھی کشتی پر سوار ہو جائیں تو کہنا۔ الحمدﷲ۔ سب تعریف اس اللہ کیلئے ہے۔ جس نے ہمیں ظالم قوم سے نجات دی ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccii{اور کہنا اے میرے پروردگار! مجھے بابرکت، اتار تو سب سے بہتر اتارنے والا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcciii{بےشک اس (واقعہ) میں بڑی نشانیاں ہیں اور ہم (لوگوں کی) آزمائش کیا کرتے ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcciv{پھر ہم نے ان کے بعد ایک اور نسل پیدا کی۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccv{پھر ہم نے انہی میں سے ایک پیغمبر بھیجا (جس نے ان سے کہا) اللہ کی عبادت کرو۔ اس کے سوا کوئی الٰہ نہیں ہے۔ کیا تم (اس کی حکم عدولی) سے ڈرتے نہیں ہو؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccvi{اور اس کی قوم کے وہ سردار جو کافر تھے اور آخرت کی حاضری کو جھٹلاتے تھے اور جنہیں ہم نے دنیوی زندگی میں آسودگی دے رکھی تھی۔ وہ کہنے لگے کہ یہ نہیں ہے مگر تمہارے ہی جیسا ایک بشر (آدمی) ہے یہ وہی (خوراک) کھاتا ہے جو تم کھاتے ہو اور وہی (مشروب) پیتا ہے۔ جو تم پیتے ہو۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccvii{اور اگر تم نے اپنے ہی جیسے ایک بشر کی اطاعت کر لی تو تم گھاٹے میں رہوگے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdccviii{کیا وہ تم سے وعدہ کرتا ہے کہ جب تم مر جاؤگے اور مٹی اور ہڈیاں ہو جاؤگے تو پھر تم (قبروں سے) نکالے جاؤگے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdccix{(حاشا و کلا) بہت بعید ہے بہت بعید ہے وہ بات جس کا تم سے وعدہ کیا جا رہا ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdccx{کوئی اور زندگی نہیں سوائے اس دنیوی زندگی کے جس میں ہمیں مرنا بھی ہے اور جینا بھی۔ اور ہمیں (دوبارہ) نہیں اٹھایا جائے گا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdccxi{وہ نہیں ہے مگر ایک ایسا شخص جس نے خدا پر جھوٹا بہتان باندھا ہے اور ہم تو (اس کو) ماننے والے نہیں ہیں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdccxii{اس (رسول) نے کہا اے میرے پروردگار! تو میری مدد کر! کیونکہ ان لوگوں نے مجھے جھٹلایا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdccxiii{ارشاد ہوا کہ عنقریب یہ لوگ (اپنے کئے پر) پشیمان ہوں گے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdccxiv{چنانچہ بجاطور پر انہیں ایک سخت آواز نے آپکڑا اور ہم نے انہیں خس و خاشاک بنا دیا سو ہلاکت ہے ظالم قوم کیلئے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdccxv{پھر ہم نے ان کے بعد دوسری قومیں پیدا کیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdccxvi{کوئی قوم اپنے مقررہ وقت سے نہ آگے بڑھ سکتی ہے۔ اور نہ پیچھے ہٹ سکتی ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdccxvii{پھر ہم نے لگاتار اپنے رسول بھیجے جب بھی کسی امت کے پاس اس کا رسول آیا تو انہوں نے اسے جھٹلایا تو ہم بھی ایک کے بعد دوسرے کو ہلاک کرتے رہے۔ اور ہم نے انہیں قصہ پارینہ (اور افسانہ) بنا دیا۔ پس تباہی ہو اس قوم کیلئے جو ایمان نہیں لاتے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdccxviii{پھر ہم نے موسیٰ اور ان کے بھائی ہارون کو اپنی نشانیوں اور کھلی ہوئی دلیل کے ساتھ۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdccxix{فرعون اور اس کے سرداروں کی طرف بھیجا تو انہوں نے تکبر کیا اور وہ لوگ بڑے سرکش لوگ تھے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdccxx{چنانچہ وہ کہنے لگے کہ ہم اپنے ہی جیسے دو آدمیوں پر ایمان لائیں حالانکہ ان کی قوم ہماری خدمت گزار ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdccxxi{پس ان لوگوں نے ان دونوں کو جھٹلایا (نتیجہ یہ نکلا کہ) وہ بھی ہلاک ہونے والوں میں شامل ہوگئے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdccxxii{اور ہم نے موسیٰ کو کتاب (توراۃ) عطا کی تاکہ وہ لوگ ہدایت پائیں۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiii{اور ہم نے ابن مریم اور اس کی ماں کو (اپنی قدرت کی) نشانی بنایا اور ان دونوں کو ایک بلند مقام پر پناہ دی جو ٹھہرنے کے قابل بھی تھا اور جہاں چشمے جاری تھے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiv{اے (میرے) پیغمبرو! پاکیزہ چیزیں کھاؤ اور نیک عمل کرو۔ بیشک تم جو کچھ کرتے ہو میں اسے خوب جانتا ہوں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdccxxv{اور یہ تمہاری امت (جماعت) ایک امت ہے اور میں تمہارا پروردگار ہوں سو تم مجھ ہی سے ڈرو۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvi{مگر ان لوگوں نے اپنے (دینی) معاملہ کو آپس میں ٹکڑے ٹکڑے کر ڈالا پس ہر گروہ کے پاس جو (دین) ہے وہ اس پر خوش ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvii{پس (اے رسول(ص)) آپ ان کو ایک خاص وقت تک اپنی غفلت و مدہوشی میں پڑا رہنے دیجئے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdccxxviii{کیا یہ لوگ خیال کرتے ہیں کہ ہم جو مال و اولاد (کی فراوانی) سے ان کی امداد کر رہے ہیں۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdccxxix{تو ہم ان کے ساتھ بھلائیاں کرنے میں جلدی کر رہے ہیں؟ (ایسا نہیں) بلکہ انہیں (اصل حقیقت کا) شعور نہیں ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdccxxx{بےشک جو لوگ اپنے پروردگار کی ہیبت سے ڈرتے ہیں۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxi{اور جو اپنے پروردگار کی آیتوں پر ایمان لاتے ہیں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxii{اور جو اپنے پروردگار کے ساتھ کسی کو شریک نہیں ٹھہراتے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiii{اور وہ جو دیتے ہیں جو کچھ بھی دیتے ہیں (پھر بھی) ان کے دل اس خیال سے ترساں رہتے یں کہ انہوں نے اپنے پروردگار کی طرف پلٹ کر جانا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiv{یہی لوگ بھلائیاں کرنے میں جلدی کیا کرتے ہیں اور بھلائیوں میں سبقت لے جانے والے ہیں۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxv{ہم کسی شخص کو اس کی وسعت سے زیادہ تکلیف نہیں دیتے اور ہمارے پاس وہ کتاب (نامۂ اعمال) ہے جو حق کے ساتھ بولتی ہے اور ان پر ظلم نہیں کیا جائے گا۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvi{بلکہ ان کے دل اس (دینی) معاملہ میں غفلت و سرشاری میںپڑے ہیں اور اس کے علاوہ بھی ان کے کچھ (برے) عمل ہیں جو یہ کرتے رہتے ہیں۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvii{یہاں تک کہ جب ہم ان کے خوشحال لوگوں کو عذاب کی گرفت میں لیتے ہیں تو وہ چیخنے چلانے لگتے ہیں۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxviii{آج کے دن چیخو چلاؤ نہیں (آج) ہماری طرف سے تمہاری کوئی مدد نہیں کی جائے گی۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxix{(وہ وقت یاد کرو جب) میری آیتیں تمہارے سامنے پڑھی جاتی تھیں تو تم (سنتے ہی) الٹے پاؤں پلٹ جایا کرتے تھے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdccxl{تکبر کرتے ہوئے داستان سرائی کرتے ہوئے (اور) بے ہودہ بکتے ہوئے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdccxli{کیا ان لوگوں نے اس کلام میں کبھی غور نہیں کیا یا ان کے پاس ایسی چیز آئی ہے جو ان کے پہلے والے باپ داداؤں کے پاس نہیں آئی تھی؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdccxlii{یا کیا انہوں نے اپنے رسول کو پہچانا نہیں ہے؟ اس لئے منکر ہوگئے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdccxliii{یا وہ کہتے ہیں کہ یہ مجنون ہے؟ بلکہ وہ تو ان کے پاس حق لے کر آیا ہے اور اکثر لوگ حق کو ناپسند کرتے ہیں۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdccxliv{اور اگر حق لوگوں کی خواہشات کی پیروی کرتا تو آسمان و زمین اور جو ان کے اندر ہے سب درہم برہم ہو جاتے۔ بلکہ ہم تو ان کے پاس نصیحت لے کر آئے مگر وہ اپنی نصیحت سے ہی روگردانی کرتے ہیں۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdccxlv{کیا آپ ان سے کوئی معاوضہ طلب کرتے ہیں؟ تمہارے لئے تو تمہارے پروردگار کا معاوضہ بہت بہتر ہے اور وہ بہترین رازق ہے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvi{اور بےشک آپ ان لوگوں کو سیدھے راستے کی طرف بلاتے ہیں۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvii{اور جو آخرت پر ایمان نہیں رکھتے وہ راہ سے ہٹے ہوئے ہیں۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdccxlviii{اور اگر ہم ان پر رحم کریں اور جس تکلیف میں مبتلا ہیں وہ بھی دور کر دیں تو بھی یہ لوگ اپنی سرکشی میں اندھا دھند بڑھتے جائیں گے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdccxlix{اور ہم نے انہیں سزا میں گرفتار بھی کیا مگر وہ پھر بھی اپنے پروردگار کے سامنے نہ جھکے اور نہ تضرع و زاری کی۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdccl{یہاں تک کہ جب ہم ان پر سخت عذاب کا دروازہ کھول دیں گے تو وہ ایک دم ناامید ہو جائیں گے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdccli{اور اللہ وہی ہے جس نے تمہارے لئے جان، آنکھیں اور دل بنائے (لیکن) تم لوگ بہت کم شکر ادا کرتے ہو۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdcclii{وہ وہی ہے جس نے تمہیں روئے زمین پر (پیدا کرکے) پھیلا دیا ہے اور اسی کی طرف تم اکٹھے کئے جاؤگے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdccliii{وہ وہی ہے جو زندہ کرتا ہے اور مارتا ہے اور رات اور دن کی آمد و رفت اسی کے قبضۂ قدرت میں ہے۔ کیا تم عقل سے کام نہیں لیتے؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdccliv{ان لوگوں نے وہی بات کہی ہے جو ان کے پہلے (کافر) کہتے رہے ہیں۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdcclv{کہتے ہیں کہ جب ہم مر جائیں گے اور خاک اور ہڈیاں ہو جائیں گے تو کیا ہم دوبارہ اٹھائے جائیں گے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdcclvi{ہم سے بھی اور اس سے پہلے ہمارے باپ داداؤں سے بھی یہ وعدہ ہوتا آیا ہے۔ یہ کچھ بھی نہیں صرف پہلے عہدوں کے افسانے ہیں۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdcclvii{آپ کہہ دیجیے اگر تم جانتے ہو تو (بتاؤ) کہ زمین اور جو اس میں رہتے ہیں کس کیلئے ہیں؟\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdcclviii{وہ ضرور کہیں گے کہ اللہ کیلئے ہیں۔ تو کہئے کہ تم غور کیوں نہیں کرتے؟\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdcclix{آپ کہئے کہ سات آسمانوں اور اس بڑے تخت سلطنت کا پروردگار کون ہے؟\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdcclx{وہ ضرور کہیں گے کہ اللہ ہے! کہئے کیا تم پھر بھی پرہیزگار نہیں بنتے (اس سے نہیں ڈرتے؟)۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdcclxi{آپ کہئے کہ اگر جانتے ہو تو بتاؤ کہ ہر چیز کی بادشاہی کس کے قبضہ میں ہے۔ جو سب کو پناہ دیتا ہے۔ مگر اس کے مقابلہ میں پناہ نہیں دی جا سکتی۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdcclxii{وہ ضرور کہیں گے کہ اللہ کے! تو کہئے! کہ پھر تم پر کہاں سے جادو کیا جا رہا ہے؟\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiii{بلکہ ہم ان کے سامنے حق لے آئے ہیں۔ اور یقیناً وہ جھوٹے ہیں۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiv{اللہ نے کسی کو اپنی اولاد نہیں بنایا اور نہ ہی اس کے ساتھ کوئی الہ ہے۔ اگر ایسا ہوتا تو ہر خدا اپنی مخلوق کو لے کر الگ ہو جاتا اور پھر ایک خدا دوسرے خدا پر چڑھ دوڑتا۔ پاک ہے خدا اس سے جو لوگ بیان کرتے ہیں۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdcclxv{وہ غیب و شہادت یعنی پوشیدہ اور ظاہر سب کا جاننے والا ہے۔ اور وہ اس شرک سے بلند و بالا ہے جو یہ لوگ بیان کرتے ہیں۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvi{(اے رسول(ص)) آپ کہئے کہ اے میرے پروردگار اگر تو مجھے وہ عذاب دکھا دے جس کی ان لوگوں کو دھمکی دی جا رہی ہے۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvii{تو اے میرے پروردگار! مجھے ظالم لوگوں میں شامل نہ کرنا۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdcclxviii{اور ہم اس عذاب کے آپ کو دکھانے پر قادر ہیں جس کی ان کو دھمکی دی جا رہی ہے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdcclxix{(اے رسول(ص)) آپ برائی کو احسن طریقہ سے دفع کریں۔ ہم خوب جانتے ہیں جو وہ (آپ کی نسبت) بیان کرتے ہیں۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdcclxx{اور آپ کہئے! اے میرے پروردگار! میں شیطانوں کے وسوسوں سے تجھ سے پناہ مانگتا ہوں۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxi{اور اے میرے پروردگار! میں تجھ سے پناہ مانگتا ہوں اس سے کہ وہ (شیطان) میرے پاس آئیں۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxii{(کافروں کی یہی حالت رہتی ہے) یہاں تک کہ جب ان میں سے کسی کے پاس موت آکھڑی ہوتی ہے تو (تب) کہتا ہے کہ اے میرے پروردگار! مجھے (ایک بار) اسی دنیا میں واپس بھیج دے جسے میں چھوڑ آیا ہوں۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiii{تاکہ میں نیک عمل کر سکوں (ارشاد ہوگا) ہرگز نہیں! یہ محض ایک (فضول) بات ہے جو وہ کہہ رہا ہے اور ان کے (مرنے کے) بعد برزخ کا زمانہ ہے ان کے (دوبارہ) اٹھائے جانے تک۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiv{پھر جب صور پھونکا جائے گا تو اس دن نہ تو ان کے درمیان رشتے ناطے رہیں گے اور نہ ہی ایک دوسرے کو پوچھیں گے۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxv{(ہاں البتہ) جن کے پلڑے بھاری ہوں گے تو وہی کامیاب ہوں گے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvi{اور جن کے پلڑے ہلکے ہوں گے تو یہ وہی لوگ ہوں گے جنہوں نے اپنے آپ کو نقصان پہنچایا (اور) وہ ہمیشہ جہنم میں رہیں گے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvii{آگ ان کے چہروں کو جھلسا رہی ہوگی اور ان کی شکلیں اس میں بگڑ گئی ہوں گی۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxviii{(ان سے کہا جائے گا) کیا تمہارے سامنے ہماری آیتیں نہیں پڑھی جاتی تھیں اور تم انہیں جھٹلاتے تھے؟\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxix{(وہ اس وقت) کہیں گے اے ہمارے پروردگار! ہم پر ہماری بدبختی غالب آگئی تھی۔ اور واقعی ہم گمراہ لوگ تھے۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxx{اے ہمارے پروردگار! (ایک بار) ہمیں اس سے نکال دے۔ پھر اگر ہم ایسا کریں گے تو بےشک ہم سراسر ظالم ہوں گے۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxi{ارشاد ہوگا اور مجھ سے کوئی بات نہ کرو۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxii{(تمہیں یاد ہے) کہ بےشک میرے بندوں میں ایک گروہ ایسا بھی تھا جو کہتا تھا: اے ہمارے پروردگار! ہم ایمان لائے ہیں! پس تو ہمیں بخش دے اور ہم پر رحم کر اور تو بہترین رحم کرنے والا ہے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiii{تو تم ان کا مذاق اڑاتے تھے یہاں تک کہ (گویا) انہوں نے تمہیں میری یاد بھی بھلا دی اور تم ان پر ہنستے تھے۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiv{(دیکھو) آج میں نے انہیں ان کے صبر کی جزا دی ہے۔ وہی کامران ہیں۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxv{ارشاد ہوگا تم کتنے برس تک زمین میں رہے ہو؟\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvi{وہ کہیں گے: ایک دن یا ایک دن کا بھی کچھ عرصہ۔ سو تو گننے والوں سے پوچھ لے۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvii{ارشاد ہوگا: تم نہیں رہے۔ مگر تھوڑا عرصہ کاش تم نے یہ بات سمجھی ہوتی۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxviii{کیا تمہارا یہ خیال تھا کہ ہم نے تمہیں بلا مقصد پیدا کیا ہے اور تم نے کبھی ہماری طرف پلٹ کر نہیں آنا ہے؟\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxix{اللہ جو حقیقی بادشاہ ہے (ایسی بات سے) بلند و برتر ہے اس کے سوا کوئی الہ نہیں ہے۔ وہ عزت و عظمت والے عرش کا مالک ہے۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmdccxc{اور جو کوئی اللہ کے سوا کسی دوسرے (خود ساختہ) الہ (خدا) کو پکارتا ہے تو اس کے پاس اس کے لئے کوئی دلیل نہیں ہے تو اس کا حساب و کتاب پروردگار کے پاس ہے۔ اور جو کافر ہیں وہ کبھی فلاح نہیں پائیں گے۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmdccxci{اور (اے رسول(ص)) آپ کہئے! اے میرے پروردگار! تو بخش دے اور رحم فرما۔ اور تو بہترین رحم کرنے والا ہے۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmdccxcii{\basmalahur (شروع کرتا ہوں) اللہ کے نام سے جو بڑا مہربان نہایت رحم والا ہے۔یہ ایک سورہ ہے جسے ہم نے نازل کیا ہے اور ہم نے (ہی) اس (کے احکام) کو فرض کیا ہے۔ اور ہم نے ہی اس میں کھلی ہوئی آیتیں نازل کی ہیں۔ تاکہ تم نصیحت حاصل کرو۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccxciii{زناکار عورت اور زناکار مرد ان دونوں میں سے ہر ایک کو سو سو کوڑے لگاؤ۔ اور اللہ کے دین کے معاملہ میں تمہیں ان پر ترس نہ آئے۔ اگر تم اللہ اور آخرت کے دن پر ایمان رکھتے ہو اور ان دونوں کو سزا دیتے وقت اہلِ ایمان کی ایک جماعت کو موجود رہنا چاہیے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccxciv{زناکار مرد نکاح نہیں کرتا مگر زناکار عورت یا مشرک عورت کے ساتھ اور زناکار عورت نکاح نہیں کرتی مگر زناکار مرد یا مشرک مرد کے ساتھ اور یہ (زنا) اہلِ ایمان پر حرام قرار دے دیا گیا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccxcv{اور جو لوگ پاکدامن عورتوں پر زنا کی تہمت لگائیں اور پھر چار گواہ پیش نہ کریں تو انہیں اسّی (۰۸) کوڑے لگاؤ اور کبھی ان کی کوئی گواہی قبول نہ کرو اور یہ لوگ فاسق ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvi{سوائے ان کے جو اس کے بعد توبہ کر لیں اور (اپنی) اصلاح کر لیں۔ تو بےشک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvii{اور جو (خاوند) اپنی بیویوں پر تہمت (زنا) لگائیں اور (ثبوت کیلئے) ان کے پاس خود ان کے سوا کوئی گواہ نہ ہو تو ان میں سے کسی کی گواہی اس طرح معتبر ہوگی کہ وہ چار مرتبہ خدا کی قسم کھائے کہ وہ (اپنے دعویٰ میں) سچا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccxcviii{اور پانچویں مرتبہ یوں کہے کہ اس پر اللہ کی لعنت ہو اگر وہ (اپنے دعویٰ میں) جھوٹا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccxcix{اور اس عورت سے یہ صورت شرعی حد کو ٹال سکتی ہے کہ وہ چار بار اللہ کی قسم کھا کر کہے کہ وہ (خاوند) جھوٹا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccc{اور پانچویں بار یوں قسم کھائے کہ اس پر اللہ کا غضب ہو اگر وہ (مرد) سچا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccci{اگر اللہ کا فضل و کرم اور اس کا رحم نہ ہوتا اور یہ (بات نہ ہوتی) کہ اللہ بڑا توبہ قبول کرنے والا، بڑا حکمت والا ہے (تو اس الزام تراشی کا انجام بڑا دردناک ہوتا)۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcccii{بےشک جو لوگ جھوٹا بہتان گھڑ کر لائے ہیں وہ تم ہی میں سے ایک گروہ ہے۔ تم اسے اپنے حق میں برا نہ سمجھو۔ بلکہ وہ تمہارے لئے بہتر ہے۔ اس (گروہ) میں سے ہر آدمی کیلئے اتنا حصہ ہے جتنا اس نے گناہ کمایا ہے۔ اور جو ان میں سے اس (گناہ) کے بڑے حصہ کا ذمہ دار ہے اس کیلئے عذاب بھی بہت بڑا ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccciii{ایسا کیوں نہ ہوا کہ جب تم لوگوں نے یہ (بہتان) سنا تھا تو مؤمن مرد اور مؤمن عورتیں اپنوں کے حق میں نیک گمان کرتے اور کہتے کہ یہ تو ایک کھلا ہوا بہتان ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccciv{وہ اس پر چار گواہ کیوں نہیں لائے؟ سو جب یہ لوگ گواہ نہیں لائے تو یہ اللہ کے نزدیک جھوٹے ہی ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcccv{اور اگر تم پر دنیا و آخرت میں خدا کا فضل و کرم اور اس کی رحمت نہ ہوتی تو جس بات میں تم پڑ گئے تھے (اور اس کا چرچا کیا تھا) تمہیں سخت عذاب پہنچتا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcccvi{جب تم لوگ اس (بہتان) کو ایک دوسرے کی زبان سے نقل کر رہے تھے اور اپنے مونہوں سے وہ بات کہہ رہے تھے جس کا خود تمہیں علم نہیں تھا۔ اور تم اسے ایک معمولی بات سمجھ رہے تھے۔ حالانکہ اللہ کے نزدیک وہ بہت بڑی بات تھی۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcccvii{اور ایسا کیوں نہ ہوا کہ جب تم نے یہ (افواہ) سنی تھی تو کہہ دیتے کہ ہمارے لئے زیبا نہیں ہے کہ یہ بات منہ سے نکالیں۔ سبحان اللہ! یہ تو بڑا بہتان ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcccviii{اللہ تمہیں نصیحت کرتا ہے کہ تم مؤمن ہو تو آئندہ کبھی اس قسم کی بات نہ کرنا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcccix{اور اللہ تمہارے لئے (اپنی) آیتیں کھول کر بیان کرتا ہے۔ اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcccx{اور جو لوگ چاہتے ہیں کہ اہلِ ایمان میں بے حیائی و برائی کی اشاعت ہو (اور اس کا چرچا ہو) ان کیلئے دنیا و آخرت میں دردناک عذاب ہے۔ اور اللہ جانتا ہے اور تم نہیں جانتے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcccxi{اور اگر تم پر اللہ کا فضل و کرم اور اس کی رحمت نہ ہوتی اور یہ کہ اللہ بڑا شفقت والا، بڑا رحم کرنے والا ہے (تو تم دیکھ لیتے کہ اس بہتان تراشی کا کیا انجام ہوتا)۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcccxii{اے ایمان والو! شیطان کے نقش قدم پر نہ چلو۔ اور جو کوئی شیطان کے نقش قدم پر چلتا ہے تو وہ اسے بے حیائی اور ہر طرح کی برائی کا حکم دیتا ہے اور اگر تم پر خدا کا فضل و کرم اور اس کی رحمت نہ ہوتی تو تم میں سے کوئی بھی کبھی پاک و صاف نہ ہوتا۔ لیکن اللہ جسے چاہتا ہے اسے پاک و صاف کر دیتا ہے اور اللہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiii{اور جو لوگ تم میں سے مال و دولت اور وسعت والے ہیں وہ قسم نہ کھائیں کہ وہ قرابتداروں، مسکینوں اور راہِ خدا میں ہجرت کرنے والوں کو کچھ نہیں دیں گے۔ چاہئے کہ یہ لوگ معاف کر دیں اور درگزر کریں۔ کیا تم یہ نہیں چاہتے کہ اللہ تمہیں بخش دے؟ اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiv{جو لوگ پاکدامن، بے خبر اور ایماندار عورتوں پر تہمت لگاتے ہیں ان پر دنیا و آخرت میں لعنت ہے اور ان کیلئے بہت بڑا عذاب ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcccxv{جس دن ان کی زبانیں اور ان کے ہاتھ پاؤں ان کے خلاف گواہی دیں گے۔ ان کے اعمال کے متعلق جو وہ کیا کرتے تھے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvi{اس دن اللہ انہیں پورا پورا بدلہ دے گا جس کے وہ حقدار ہیں اور انہیں معلوم ہو جائے گا کہ اللہ ہی حق ہے جو نمایاں ہے (اور حق کا ظاہر کرنے والا ہے)۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvii{ناپاک باتیں، ناپاک لوگوں کے لئے (زیبا) ہیں اور ناپاک آدمی ناپاک باتوں کیلئے موزوں (مناسب) ہیں اور اچھی اور ستھری باتیں اچھے آدمیوں کیلئے (مناسب) ہیں۔ اور اچھے اور ستھرے آدمی اچھی اور ستھتری باتوں کے (لائق) ہیں اور یہ ان باتوں سے بری الذمہ ہیں جو لوگ (ان کے بارے میں) کہتے ہیں ان کیلئے مغفرت ہے اور باعزت روزی۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcccxviii{اے ایمان والو! اپنے گھروں کے سوا دوسرے گھروں میں داخل نہ ہوا کرو۔ جب تک کہ اجازت نہ لے لو۔ اور گھر والوں پر سلام نہ کرو۔ یہی تمہارے لئے بہتر ہے۔ تاکہ نصیحت حاصل کرو۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcccxix{پھر اگر ان (گھروں) میں کسی (آدمی) کو نہ پاؤ تو ان میں داخل نہ ہو جب تک کہ تمہیں اجازت نہ مل جائے اور اگر تم سے کہا جائے کہ واپس چلے جاؤ تو واپس چلے جاؤ یہ (طریقہ کار) تمہارے لئے زیادہ پاکیزہ ہے۔ اور تم جو کچھ کرتے ہو اللہ اسے خوب جانتا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcccxx{(ہاں البتہ) ایسے گھروں میں داخل ہونے میں تمہارے لئے کوئی مضائقہ نہیں ہے جن میں کوئی رہائش نہیں رکھتا۔ جبکہ ان میں تمہارا کچھ سامان ہو اور اللہ اسے بھی خوب جانتا ہے جو کچھ تم ظاہر کرتے ہو اور اسے بھی جانتا ہے جو کچھ تم چھپاتے ہو۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxi{(اے رسول(ص)) آپ مؤمن مردوں سے کہہ دیجئے! کہ وہ اپنی نگاہیں نیچی رکھیں اور اپنی شرمگاہوں کی حفاظت کریں یہ (طریقہ) ان کیلئے زیادہ پاکیزگی کا باعث ہے۔ بےشک لوگ جو کچھ کیا کرتے ہیں اللہ اس سے خوب واقف ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxii{اور (اے رسول(ص)) آپ مؤمن عورتوں سے کہہ دیجئے! کہ وہ اپنی نگاہیں نیچی رکھیں اور اپنی شرمگاہوں کی حفاطت کریں اور اپنی زینت و آرائش کو ظاہر نہ کریں سوائے اس کے جو خود ظاہر ہو اور چاہیے کہ وہ اپنی اوڑھنیاں اپنے گریبانوں پر ڈالے رہیں اور اپنی زیبائش و آرائش ظاہر نہ کریں سوائے اپنے شوہروں کے، یا اپنے باپ داداؤں کے، یا اپنے شوہروں کے باپ داداؤں کے، یا اپنے بیٹوں کے یا اپنے شوہروں کے بیٹوں کے، یا اپنے بھائیوں کے یا اپنے بھتیجوں کے یا اپنے بھانجوں کے یا اپنے (ہم مذہب) عورتوں کے یا اپنے غلاموں یا لونڈیوں کے یا اپنے نوکروں چاکروں کے جو جنسی خواہش نہ رکھتے ہوں۔ یا ان بچوں کے جو ابھی عورتوں کی پردہ والی باتوں سے واقف نہیں ہیں اور وہ اپنے پاؤں (زمین پر) اس طرح نہ ماریں کہ جس سے ان کی وہ زیبائش و آرائش معلوم ہو جائے جسے وہ چھپائے ہوئے ہیں۔ اے اہل ایمان! تم سب مل کر اللہ کی بارگاہ میں توبہ کرو۔ تاکہ تم فلاح پاؤ۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiii{اور تم میں جو (مرد و زن) بے نکاح ہیں ان کا نکاح کرو۔ نیز اپنے غلاموں اور کنیزوں میں سے بھی جو (نکاح کے) قابل ہوں۔ ان کا بھی نکاح کرو۔ اگر وہ غریب و نادار ہوں گے تو اللہ انہیں اپنے فضل و کرم سے مالدار بنا دے گا۔ اور اللہ بڑی وسعت والا، بڑا علم والا ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiv{اور جو لوگ نکاح کرنے کی قدرت نہیں رکھتے انہیں چاہیے کہ عفت اور ضبط نفس سے کام لیں۔ یہاں تک کہ اللہ انہیں اپنے فضل سے غنی کر دے اور تمہارے مملوکہ غلاموں اور کنیزوں میں سے جو مکاتب بننے کے خواہشمند ہوں۔ تو اگر تمہیں ان میں کوئی بھلائی معلوم ہو تو ان سے مکاتبہ کرلو۔ اور تم اللہ کے مال میں سے انہیں عطا کرو اور اپنی جوان کنیزوں کو محض دنیوی رنگ کا کچھ سامان حاصل کرنے کیلئے بدکاری پر مجبور نہ کرو جبکہ وہ پاکدامن رہنا چاہتی ہوں اگر کوئی انہیں مجبور کرے تو بیشک ان کو مجبور کرنے کے بعد بھی اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxv{بےشک ہم نے تم لوگوں کی طرف واضح آیتیں نازل کی ہیں اور تم سے پہلے گزرے ہوئے لوگوں کی مثالیں بھی اور پرہیزگاروں کیلئے پند و نصیحت بھی۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvi{اللہ آسمانوں اور زمین کا نور ہے۔ اس کے نور کی مثال یہ ہے جیسے ایک طاق میں چراغ رکھا ہوا ہو (اور) چراغ شیشہ کی قندیل میں ہو۔ اور (وہ) قندیل گویا موتی کی طرح چمکتا ہوا ایک ستارہ ہے (اور وہ چراغ) زیتون کے بابرکت درخت (کے تیل) سے روشن کیا جاتا ہے۔ جو نہ شرقی ہے نہ غربی قریب ہے کہ اس کا تیل خود بخود بھڑک اٹھے اگرچہ آگ نے اسے چھوا بھی نہ ہو۔ یہ نور بالائے نور ہے۔ اللہ جس کو چاہتا ہے اپنے نور کی طرف ہدایت فرماتا ہے۔ اور اللہ لوگوں کیلئے مثالیں بیان کرتا ہے۔ اور اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvii{(یہ ہدایت پانے والے) ایسے گھروں میں ہیں جن کے بارے میں اللہ نے حکم دیا ہے کہ انہیں بلند کیا جائے اور ان میں خدا کا نام لیا جائے ان میں ایسے لوگ صبح و شام اس کی تسبیح کرتے ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxviii{جنہیں کوئی تجارت اور (خرید) فروخت اللہ کی یاد سے نماز پڑھنے سے اور زکوٰۃ دینے سے غافل نہیں کرتی (کیونکہ) وہ اس دن سے ڈرتے ہیں جس میں دل اور نگاہیں الٹ پلٹ ہو جائیں گی۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxix{تاکہ اللہ ان کو ان کے بہترین اعمال کی جزا دے اور اپنے فضل سے مزید نوازے اور اللہ جسے چاہتا ہے اسے بے حساب رزق عطا کرتا ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxx{اور جن لوگوں نے کفر اختیار کیا ان کے اعمال سراب کی مانند ہیں جو ایک چٹیل میدان میں ہو۔ جسے آدمی پانی خیال کرتا ہے یہاں تک کہ جب اس کے پاس جاتا ہے تو اسے کچھ نہیں پاتا بلکہ وہاں اللہ کو موجود پاتا ہے۔ جس نے اس کا پورا پورا حساب چکا دیا۔ اور اللہ بہت جلدی حساب لینے والا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxi{یا پھر ان کی مثال ایسی ہے جیسے گہرے سمندر میں اندھیرا۔ کہ اسے ایک موج ڈھانپ لے پھر اس (موج) کے اوپر ایک اور موج ہو۔ اور پھر اس کے اوپر بادل ہو۔ الغرض اندھیروں پر اندھیرا کہ اگر کوئی اپنا ہاتھ نکالے تو اسے دیکھ نہ پائے اور جسے اللہ نور (ہدایت) نہ دے تو اس کے لئے کوئی نور نہیں ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxii{کیا تم نے نہیں دیکھا کہ جو کوئی آسمانوں اور زمین میں ہیں اللہ کی تسبیح کرتے ہیں اور پر پھیلائے ہوئے پرندے بھی ہر ایک اپنی اپنی (مخصوص) نماز و تسبیح کو جانتا ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiii{اور آسمانوں اور زمین کی بادشاہی اللہ ہی کیلئے ہے اور اللہ ہی کی طرف (سب کی) بازگشت ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiv{کیا تم نے نہیں دیکھا کہ اللہ بادل کو آہستہ آہستہ چلاتا ہے۔ پھر اس کے ٹکڑوں کو باہم ملاتا ہے۔ پھر اسے تہہ بہ تہہ کر دیتا ہے پھر تم دیکھتے ہو کہ اس کے درمیان سے بارش نکلواتا ہے اور وہ (اللہ) آسمان سے پہاڑوں کی شکل کے بادلوں سے برف یعنی اولے برساتا ہے پھر ان کو جس پر چاہتا ہے گرا دیتا ہے اور جس سے چاہتا ہے ہٹا دیتا ہے قریب ہے کہ اس کی بجلی کی چمک آنکھوں (کی بینائی) کو لے جائے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxv{اللہ رات دن کو ادلتا بدلتا رہتا ہے۔ بےشک اس میں آنکھوں والوں کیلئے (سامان) عبرت ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvi{اور اللہ ہی نے زمین پر چلنے والے ہر جاندار کو (ایک خاص) پانی سے پیدا کیا ہے تو ان میں سے کوئی پیٹ کے بل چلتا ہے۔ اور کوئی دو ٹانگوں پر چلتا ہے اور کوئی چار ٹانگوں پر۔ اللہ جو چاہتا ہے پیدا کرتا ہے۔ بےشک اللہ ہر شئے پر پوری قدرت رکھتا ہے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvii{یقیناً ہم نے حقیقت واضح کرنے والی آیتیں نازل کر دی ہیں اور اللہ جسے چاہتا ہے سیدھے راستے کی طرف راہنمائی کر دیتا ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxviii{اور وہ کہتے ہیں کہ ہم اللہ اور رسول پر ایمان لائے ہیں۔ اور ہم نے اطاعت بھی کی۔ مگر اس کے بعد ان میں سے ایک گروہ منہ پھر لیتا ہے اور ایسے لوگ (ہرگز) مؤمن نہیں ہیں۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxix{اور جب انہیں خدا اور رسول کی طرف بلایا جاتا ہے تاکہ رسول ان کے درمیان فیصلہ کر دیں تو ایک دم ان میں سے ایک گروہ روگردان ہو جاتا ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcccxl{اور اگر حق ان کے موافق ہو (اس میں ان کا فائدہ) تو پھر سر تسلیم خم کئے اس (رسول) کی طرف آجاتے ہیں۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcccxli{ان کے دلوں میں (نفاق وغیرہ) کی کوئی بیماری ہے یا (اسلام کے متعلق) شک میں مبتلا ہیں یا پھر ڈرتے ہیں کہ اللہ اور اس کا رسول ان کے ساتھ زیادتی کریں گے؟ (نہیں) بلکہ یہ لوگ خود ظلم و زیادتی کرنے والے ہیں۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlii{اہلِ ایمان کو جب خدا اور رسول کی طرف بلایا جائے کہ وہ (رسول) ان کے درمیان فیصلہ کریں تو ان کا قول یہ ہوتا ہے کہ وہ کہتے ہیں ہم نے سنا اور اطاعت کی اور یہی لوگ فلاح پانے والے ہیں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliii{اور جو کوئی اللہ اور اس کے رسول کی اطاعت کرے اور اللہ سے ڈرے اور پرہیزگاری اختیار کرے (اس کی نافرمانی سے بچے) تو ایسے ہی لوگ کامیاب ہونے والے ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliv{اور یہ (منافق) اپنے مقدور بھر اللہ کی قسمیں کھا کر کہتے ہیں کہ اگر آپ انہیں حکم دیں گے تو وہ (اپنے گھروں سے بھی) نکل کھڑے ہوں گے آپ کہیئے کہ تم قسمیں نہ کھاؤ۔ پس معروف و معلوم فرمانبرداری مطلوب ہے۔ بےشک جو کچھ تم کرتے ہو اللہ اس سے خوب واقف ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlv{آپ کہہ دیجئے! کہ تم اللہ کی اطاعت کرو۔ اور رسول کی اطاعت کرو اور اگر تم روگردانی کروگے تو اس (رسول) کے ذمہ وہی ہے جو بار اس پر ڈالا گیا ہے اور تمہارے ذمہ وہ ہے جو بار تم پر ڈالا گیا ہے۔ اور تم اگر اس کی اطاعت کروگے تو خود ہی ہدایت پاؤگے۔ ورنہ رسول کے ذمہ واضح طور پر پیغام پہنچانے کے سوا کچھ نہیں ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvi{جو لوگ تم میں سے ایمان لائے اور نیک عمل کئے اللہ نے ان سے وعدہ کیا ہے کہ وہ انہیں زمین میں اسی طرح جانشین بنائے گا جس طرح ان سے پہلے گزرے ہوئے لوگوں کو بنایا تھا۔ اور جس دین کو اللہ نے پسند کیا ہے وہ انہیں ضرور اس پر قدرت دے گا۔ اور ان کے خوف کو امن سے بدل دے گا۔ پس وہ میری عبادت کریں اور کسی کو میرا شریک نہ بنائیں۔ اور جو اس کے بعد کفر اختیار کرے وہی لوگ فاسق ہیں۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvii{اور نماز قائم کرو اور زکوٰۃ دو۔ اور رسول(ص) کی اطاعت کرو۔ تاکہ تم پر رحم کیا جائے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlviii{جو لوگ کافر ہیں ان کے بارے میں خیال نہ کرو کہ وہ زمین میں (خدا کو) عاجز کر دیں گے ان کا ٹھکانہ جہنم ہے اور وہ بہت ہی برا ٹھکانہ ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlix{اے ایمان والو! چاہیے کہ تمہارے غلام اور وہ بچے جو ابھی حدِ بلوغ کو نہیں پہنچے (گھروں میں داخل ہوتے وقت) تین بار تم سے اجازت طلب کریں۔ نمازِ صبح سے پہلے، اور جس وقت تم دوپہر کو اپنے کپڑے اتار دیتے ہو اور نماز عشاء کے بعد۔ یہ تین وقت (آرام کرنے کیلئے) تمہارے لئے پردے کے وقت ہیں ان اوقات کے علاوہ تم پر اور ان پر کوئی حرج نہیں ہے تم لوگ ایک دوسرے کے پاس بار بار چکر لگاتے رہتے ہو۔ اسی طرح اللہ آیتوں کو کھول کر بیان کرتا ہے اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcccl{اور جب تمہارے لڑکے حدِ بلوغ کو پہنچ جائیں تو انہیں بھی اسی طرح اجازت لینی چاہیے جس طرح ان سے پہلے لوگ (اپنے بڑوں سے) اجازت لیتے رہے ہیں اسی طرح اللہ تعالیٰ تمہارے لئے اپنی آیتیں کھول کر بیان کرتا ہے۔ اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdcccli{اور وہ عورتیں جو (بڑھاپے کی وجہ سے) خانہ نشین ہوگئی ہوں جنہیں نکاح کی کوئی آرزو نہ ہو ان کیلئے کوئی حرج نہیں ہے کہ وہ اپنے (پردہ کے) کپڑے اتار کر رکھ دیں بشرطیکہ زینت کی نمائش کرنے والیاں نہ ہوں۔ اور اگر اس سے بھی باز رہیں (اور پاکدامنی سے کام لیں) تو یہ اور بہتر ہے۔ اور اللہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccclii{اور اندھے کیلئے کوئی مضائقہ نہیں ہے اور نہ ہی لنگڑے کیلئے کوئی مضائقہ ہے اور نہ بیمار کیلئے اور نہ خود تمہارے لئے کوئی حرج ہے کہ تم اپنے گھروں سے کھاؤ۔ یا اپنے باپ دادا کے گھروں سے یا اپنی ماؤں کے گھروں سے یا اپنے بھائیوں یا اپنی بہنوں کے گھروں سے یا اپنے چچاؤں کے گھروں سے یا اپنی پھوپھیوں کے گھروں سے یا اپنے ماموؤں کے گھروں سے یا اپنی خالاؤں کے گھروں سے یا ان کے گھروں سے جن کی کنجیاں تمہارے اختیار میں ہیں یا اپنے دوستوں کے گھروں سے تمہارے لئے کوئی مضائقہ نہیں ہے کہ اکٹھے ہوکر کھاؤ۔ یا الگ الگ (ہاں البتہ) جب گھروں میں داخل ہونے لگو تو اپنے لوگوں کو سلام کر لیا کرو۔ یہ اللہ کی طرف سے پاکیزہ اور بابرکت ہدیہ ہے اللہ اسی طرح آیتیں کھول کر بیان کرتا ہے تاکہ تم عقل سے کام لو۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdcccliii{مؤمن تو صرف وہ لوگ ہیں جو اللہ اور اس کے رسول(ص) پر ایمان رکھتے ہیں اور جب کسی اجتماعی معاملہ میں رسول کے ساتھ ہوتے ہیں تو جب تک آپ سے اجازت نہیں لیتے کہیں نہیں جاتے۔ بےشک جو لوگ آپ سے اجازت مانگتے ہیں وہی اللہ اور اس کے رسول پر ایمان رکھتے ہیں۔ پس جب وہ آپ سے اپنے کسی کام کیلئے اجازت مانگیں تو آپ ان میں سے جسے چاہیں اجازت دے دیں اور ان کیلئے اللہ سے مغفرت طلب کریں۔ بیشک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdcccliv{اے ایمان والو! اپنے درمیان رسول کے بلانے کو آپس میں ایک دوسرے کو بلانے کی طرح نہ بناؤ۔ اللہ ان لوگوں کو خوب جانتا ہے جو تم میں سے ایک دوسرے کی آڑ لے کر کھسک جاتے ہیں۔ جو لوگ حکمِ خدا سے انحراف کرتے ہیں ان کو اس بات سے ڈرنا چاہیے کہ وہ کسی فتنہ میں مبتلا نہ ہو جائیں یا انہیں کوئی دردناک عذاب نہ پہنچ جائے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccclv{خبردار! جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے وہ اللہ ہی کا ہے تم جس حال میں ہو اللہ اسے خوب جانتا ہے اور اس دن کو بھی جب لوگ اس کی بارگاہ میں لوٹائے جائیں گے تو وہ انہیں بتائے گا جو کچھ وہ کرتے رہے تھے۔ اور اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccclvi{\basmalahur بابرکت ہے وہ خدا جس نے اپنے (خاص) بندہ پر فرقان نازل کیا ہے تاکہ وہ تمام جہانوں کیلئے ڈرانے والا بن جائے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccclvii{جس کیلئے آسمانوں اور زمین کی بادشاہی ہے اور اس نے کسی کو اولاد نہیں بنایا۔ اور نہ بادشاہی میں اس کا کوئی شریک ہے اور اس نے ہر چیز کو پیدا کیا ہے اور ہر چیز کا ایک اندازہ (پیمانہ) مقرر کیا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccclviii{اور ان (مشرکوں) نے اللہ کو چھوڑ کر ایسے خدا بنائے ہیں جو کوئی چیز پیدا نہیں کر سکتے اور وہ خود پیدا کئے ہوئے ہیں اور وہ خود اپنے لئے نقصان یا نفع کے مالک و مختار نہیں ہیں۔ جو نہ مار سکتے ہیں نہ جلا سکتے ہیں اور نہ ہی کسی مرے ہوئے کو دوبارہ اٹھا سکتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccclix{اور جو لوگ کافر ہیں وہ کہتے ہیں کہ یہ (قرآن) محض ایک جھوٹ ہے جسے اس شخص نے گھڑ لیا ہے اور کچھ دوسرے لوگوں نے اس کام میں اس کی مدد کی ہے (یہ بات کہہ کر) خود یہ لوگ بڑے ظلم اور جھوٹ کے مرتکب ہوئے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccclx{اور کہتے ہیں کہ یہ تو پہلے لوگوں کی لکھی ہوئی داستانیں ہیں جو اس شخص نے لکھوائی ہیں اور وہ صبح و شام اس کے سامنے پڑھی جاتی ہیں (یا اس سے لکھوائی جاتی ہیں)۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccclxi{آپ(ص) کہہ دیجئے! کہ اس (قرآن) کو اس (خدا) نے نازل کیا ہے جو آسمانوں اور زمین کے رازوں کو جانتا ہے۔ بےشک وہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccclxii{اور وہ کہتے ہیں کہ یہ کیسا رسول ہے جو کھانا کھاتا ہے اور بازاروں میں چلتا پھرتا ہے؟ اس پر کوئی فرشتہ کیوں نہ اتارا گیا جو اس کے ساتھ ڈرانے والا ہوتا؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiii{یا اس پر کوئی خزانہ اتارا جاتا یا اس کے لئے کوئی باغ ہی ہوتا جس سے یہ کھاتا؟ اور ظالموں نے تو (یہاں تک) کہہ دیا کہ تم ایک ایسے شخص کی پیروی کر رہے ہو جس پر جادو کیا گیا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiv{دیکھئے! یہ لوگ آپ کے متعلق کیسی کیسی (کٹ حجتیاں) باتیں بیان کرتے ہیں سو وہ گمراہ ہوگئے ہیں سو اب وہ راہ نہیں پا سکتے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccclxv{بڑا بابرکت ہے وہ خدا جو اگر چاہے تو آپ کو اس (کفار کی بیان کردہ چیزوں) سے بہتر دے دے۔ یعنی ایسے باغات کہ جن کے نیچے نہریں جاری ہوں۔ اور آپ کیلئے (عالیشان) محل بنوا دے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvi{بلکہ یہ لوگ قیامت کو جھٹلاتے ہیں اور جو لوگ قیامت کو جھٹلاتے ہیں ہم نے ان کیلئے بھڑکتی ہوئی آگ تیار کر رکھی ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvii{اور وہ (آگ) جب انہیں دور سے دیکھے گی تو وہ اس کا جوش مارنا اور چنگھاڑنا سنیں گے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccclxviii{اور جب انہیں زنجیروں میں جکڑ کر آتش (دوزخ) کی کسی تنگ جگہ میں ڈال دیا جائے گا تو وہاں (اپنی) ہلاکت کو پکاریں گے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdccclxix{(ان سے کہا جائے گا کہ) آج ایک ہلاکت کو نہ پکارو بلکہ بہت سی ہلاکتوں کو پکارو۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdccclxx{آپ ان سے کہیے کہ آیا یہ (آتش دوزخ) اچھی ہے یا وہ دائمی جنت جس کا پرہیزگاروں سے وعدہ کیا گیا ہے۔ یہ ان (کے اعمال) کا صلہ ہے اور (آخری) ٹھکانا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxi{اس میں ان کیلئے وہ سب کچھ ہوگا جو وہ چاہیں گے وہ اس میں ہمیشہ رہیں گے اور ایک وعدہ جو آپ کے رب کے ذمہ ہے جس کے متعلق سوال کیا جائے گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxii{اور جس دن اللہ ان لوگوں کو اور ان کے ان معبودوں کو جنہیں وہ اللہ کو چھوڑ کر پوجتے رہے ہیں۔ اکٹھا کرے گا تو اللہ ان (معبودوں) سے پوچھے گا کہ آیا تم نے میرے ان بندوں کو گمراہ کیا تھا؟ یا وہ خود ہی (سیدھے) راستہ سے بھٹک گئے تھے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiii{وہ کہیں گے کہ پاک ہے تیری ذات ہمیں یہ حق نہیں تھا کہ ہم تجھے چھوڑ کر کسی اور کو اپنا مولا بنائیں لیکن تو نے انہیں اور ان کے باپ دادا کو خوب آسودگی اور آسائش عطا کی۔ یہاں تک کہ انہوں نے (تیری) یاد بھلا دی۔ اور اس طرح تباہ و برباد ہوگئے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiv{(اے کافرو) اس طرح وہ (تمہارے معبود) تمہاری ان باتوں کو جھٹلا دیں گے جو تم کرتے ہو۔ پھر نہ تو تم (عذاب کو) ٹال سکوگے اور نہ ہی اپنی کوئی مدد کر سکوگے۔ اور تم میں سے جو ظلم کرے گا ہم اسے بڑے عذاب کا مزہ چکھائیں گے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxv{(اے رسول) ہم نے آپ سے پہلے جتنے رسول بھیجے ہیں وہ جو سب کھانا بھی کھاتے تھے اور بازاروں میں چلتے پھرتے بھی تھے اور ہم نے تم کو ایک دوسرے کیلئے ذریعہ آزمائش بنایا ہے کیا تم صبر کروگے؟ اور آپ کا پروردگار بڑا دیکھنے والا ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvi{اور جو لوگ ہمارے پاس آنے کی امید نہیں رکھتے وہ کہتے ہیں کہ ہمارے اوپر فرشتے کیوں نہیں اتارے گئے؟ یا ہم اپنے پروردگار کو ہی دیکھ لیتے! انہوں نے اپنے دلوں میں اپنے کو بہت بڑا سمجھا اور سرکشی میں حد سے گزر گئے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvii{یہ لوگ جس دن فرشتوں کو دیکھیں گے تو اس دن مجرموں کیلئے کوئی بشارت نہیں ہوگی اور وہ کہیں گے پناہ ہے پناہ (یا حرام ہے حرام)۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxviii{اور ہم ان کے ان کاموں کی طرف متوجہ ہوں گے جو انہوں نے کئے ہوں گے۔ اور انہیں پراگندہ غبار بنا دیں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxix{اس دن بہشت والوں کا ٹھکانہ بہترین ہوگا اور دوپہر کی آرام گاہ بھی عمدہ ہوگی۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxx{اور جس دن بادل کے ساتھ آسمان شق ہو جائے گا اور فرشتے جوق در جوق اتارے جائیں گے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxi{اس دن حقیقی بادشاہی (خدائے) رحمن کی ہوگی اور وہ دن کافروں کیلئے بڑا سخت ہوگا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxii{اور اس دن ظالم (حسرت سے) اپنے ہاتھوں کو کاٹے گا (اور) کہے گا: کاش! میں نے رسول(ص) کے ساتھ (سیدھا) راستہ اختیار کیا ہوتا۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiii{ہائے میری بدبختی! کاش میں نے فلاں شخص کو اپنا دوست نہ بنایا ہوتا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiv{اس نے نصیحت (یا قرآن) کے میرے پاس آجانے کے بعد مجھے اس کے قبول کرنے سے بہکا دیا اور شیطان تو ہے ہی (مشکل وقت میں) بے یار و مددگار چھوڑ دینے والا (دغا باز)۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxv{اور رسول(ص) کہیں گے اے میرے پروردگار! میری قوم (امت) نے اس قرآن کو بالکل چھوڑ دیا تھا۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvi{اور اسی طرح ہم نے ہر نبی کیلئے مجرموں میں سے بعض کو دشمن بنایا اور آپ کا پروردگار راہنمائی اور مدد کیلئے کافی ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvii{اور کافر لوگ کہتے ہیں کہ اس شخص پر پورا قرآن یکبارگی کیوں نہیں نازل کیا گیا؟ ہاں اس طرح اس لئے کیا کہ ہم تمہارے دل کو ثبات و تقویت دیں اور (اسی لئے) اسے عمدہ ترتیب کے ساتھ ٹھہر ٹھہر کر نازل کیا ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxviii{اور یہ لوگ جب بھی کوئی (نیا) اعتراض اٹھاتے ہیں تو ہم اس کا صحیح جواب اور عمدہ تشریح آپ کے سامنے لاتے ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxix{وہ لوگ جو اپنے مونہوں کے بل جہنم کی طرف لے جائے جائیں گے وہ ٹھکانے کے لحاظ سے بدتر اور راستہ کے اعتبار سے گمراہ تر ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxc{بےشک ہم نے موسیٰ کو کتاب عطا کی اور ان کے ساتھ ان کے بھائی ہارون کو ان کا وزیر مقرر کیا۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxci{پھر ہم نے ان سے کہا کہ تم دونوں جاؤ اس قوم کی طرف جنہوں نے ہماری آیتوں کو جھٹلایا ہے (جب انہوں نے نہ مانا) تو ہم نے ان کو بالکل ہلاک و برباد کر دیا۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcii{اور نوح(ع) کی قوم کو بھی ہم نے غرق کر دیا جب انہوں نے رسولوں کو جھٹلایا۔ اور انہیں لوگوں کیلئے نشانِ عبرت بنا دیا اور ہم نے ظالموں کیلئے دردناک عذاب تیار کر رکھا ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciii{اور (اسی طرح) ہم نے قومِ عاد و ثمود اور اصحاب الرس کو اور ان کے درمیان، بہت سی نسلوں (اور) قوموں کو بھی ہلاک کیا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciv{اور ہم نے ہر ایک کیلئے (پہلے برباد ہونے والوں) کی مثالیں بیان کیں اور (آخرکار) ہم نے سب کو نیست و نابود کر دیا۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcv{اور (یہ لوگ) اس بستی سے گزرے ہیں! جس پر (پتھروں کی) بڑی بارش برسائی گئی تھی کیا (وہاں سے گزرتے ہوئے) اسے دیکھتے نہیں رہتے بلکہ (دراصل بات یہ ہے کہ) یہ حشر و نشر کی امید ہی نہیں رکھتے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvi{اور وہ جب بھی آپ کو دیکھتے ہیں تو آپ کا مذاق اڑانے لگتے ہیں (اور کہتے ہیں) کیا یہ وہ ہے جسے خدا نے رسول بنا کر بھیجا ہے؟\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvii{وہ تو قریب تھا کہ یہ شخص ہمارے معبودوں سے ہمیں بہکا دے۔ اگر ہم ان (کی پرستش) پر ثابت قدم نہ رہتے تو عنقریب جب وہ عذاب (الٰہی) کو دیکھیں گے تو انہیں معلوم ہو جائے گا کہ راہِ راست سے کون زیادہ بھٹکا ہوا ہے؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcviii{(اے رسول(ص)) کیا آپ نے وہ شخص دیکھا ہے جس نے اپنی خواہش (نفس) کو اپنا خدا بنا رکھا ہے؟ کیا آپ اس کے ذمہ دار ہو سکتے ہیں؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcix{کیا آپ خیال کرتے ہیں کہ ان میں سے اکثر سنتے یا سمجھتے ہیں؟ یہ تو محض چوپایوں کی طرح ہیں بلکہ ان سے بھی زیادہ گم کردہ راہ ہیں۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcm{کیا تم نے اپنے پروردگار کی (قدرت کی) طرف نہیں دیکھا کہ اس نے سایہ کو کیونکر پھیلایا ہے؟ اور اگر وہ چاہتا تو اسے (ایک جگہ) ٹھہرا ہوا بنا دیتا۔ پھر ہم نے سورج کو اس پر دلیل راہ بنایا۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmi{پھر ہم اس (سایہ) کو تھوڑا تھوڑا کرکے اپنی طرف سمیٹتے جاتے ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmii{اور وہ وہی ہے جس نے تمہارے لئے رات کو پردہ پوش اور نیند کو (باعث) راحت اور دن کو اٹھ کھڑے ہونے کا وقت بنایا۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmiii{اور وہ وہی ہے جو ہواؤں کو اپنی رحمت (بارش) سے پہلے خوشخبری بنا کر بھیجتا ہے۔ اور ہم آسمان سے پاک اور پاک کرنے والا پانی برساتے ہیں تاکہ اس کے ذریعہ کسی مردہ شہر (غیر آباد) کو زندہ کریں اور اپنی مخلوق میں سے بہت سے جانوروں اور انسانوں کو پلائیں۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmiv{اور ہم اس (پانی) کو طرح طرح سے لوگوں کے درمیان تقسیم کرتے ہیں تاکہ وہ نصیحت حاصل کریں مگر اکثر لوگوں نے ناشکری کے سوا ہر بات سے انکار کر دیا ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmv{اور اگر ہم چاہتے تو ایک ایک بستی میں ایک ایک ڈرانے والا بھیجتے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmvi{(اے نبی(ص)) آپ کافروں کی پیروی نہ کریں اور اس (قرآن) کے ذریعہ سے ان سے بڑا جہاد کریں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmvii{اور وہ وہی ہے جس نے دو دریاؤں کو آپس میں ملا دیا ہے یہ شیریں و خوشگوار ہے اور یہ سخت کھاری و تلخ ہے اور ان دونوں کے درمیان ایک حد فاصل اور مضبوط رکاوٹ بنا دی ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmviii{اور وہ وہی ہے جس نے پانی سے انسان کو پیدا کیا اور پھر اس کو خاندان والا اور سسرال والا بنایا اور تمہارا پروردگار بڑی قدرت والا ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmix{اور وہ (مشرک) اللہ کو چھوڑ کر ان کی پرستش کرتے ہیں جو ان کو نہ نفع پہنچا سکتے ہیں نہ نقصان اور کافر تو (ہمیشہ) اپنے پروردگار کے مقابلے میں (مخالفوں کی) پشت پناہی کرتا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmx{اور ہم نے آپ کو نہیں بھیجا مگر خوشخبری دینے والا اور ڈرانے والا بنا کر۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmxi{اور آپ کہہ دیجئے! کہ میں اس (کار رسالت) پر تم سے کوئی معاوضہ نہیں مانگتا سوائے اس کے کہ جو چاہے اپنے پروردگار کا راستہ اختیار کرے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmxii{(اے رسول(ص)) آپ اس زندہ (خدا) پر بھروسہ کیجئے جس کے لئے موت نہیں ہے۔ اور اس کی حمد کے ساتھ تسبیح کیجئے اور وہ اپنے بندوں کے گناہوں کی خبر رکھنے کیلئے خود کافی ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxiii{وہ خدا جس نے آسمانوں اور زمین اور جو کچھ ان کے درمیان ہے سب کو چھ (۶) دن میں پیدا کیا۔ پھر عرش پر اقتدار قائم کیا۔ وہی (خدائے) رحمن ہے اس کے بارے میں کسی باخبر سے پوچھو۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxiv{اور جب ان سے کہا جاتا ہے کہ رحمن کو سجدہ کرو۔ تو وہ کہتے ہیں کہ یہ رحمن کیا چیز ہے؟ کیا ہم اسے سجدہ کریں جس کے بارے میں تم ہمیں حکم دو؟ اور یہ چیز ان کی نفرت میں اور اضافہ کر دیتی ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxv{بڑا بابرکت ہے وہ (خدا) جس نے آسمان میں (بارہ) برج بنائے اور ان میں ایک چراغ (سورج) اور ایک چمکتا ہوا چاند بنایا۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxvi{اور وہ وہی ہے جس نے رات اور دن کو ایک دوسرے کا جانشین بنایا ہے اس شخص کیلئے جو نصیحت حاصل کرنا چاہے یا شکر ادا کرنا چاہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxvii{اور (خدائے) رحمن کے (خاص) بندے وہ ہیں جو زمین پر آہستہ آہستہ (فروتنی کے ساتھ) چلتے ہیں اور جب جاہل لوگ ان سے خطاب کرتے ہیں تو وہ کہتے ہیں تم پر سلام۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxviii{اور جو اپنے پروردگار کی بارگاہ میں سجدہ اور قیام کرتے ہوئے رات گزارتے ہیں۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxix{اور جو کہتے ہیں کہ اے ہمارے پروردگار! ہم سے جہنم کا عذاب دور رکھ۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxx{بےشک اس کا عذاب پوری ہلاکت ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxxi{وہ (جہنم) بہت برا ٹھکانا ہے اور بہت بری جگہ ہے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxxii{اور وہ جب خرچ کرتے ہیں تو نہ فضول خرچی کرتے ہیں اور نہ کنجوسی (بلکہ) ان کا خرچ کرنا ان (دونوں) کے درمیان (حد اعتدال پر) ہوتا ہے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiii{اور وہ اللہ کے ساتھ کسی اور خدا کو نہیں پکارتے اور جس جان (کے مارنے) کو اللہ نے حرام قرار دیا ہے اسے ناحق قتل نہیں کرتے اور نہ زنا کرتے ہیں اور جو کوئی ایسا کرے گا تو وہ گناہ کی سزا پائے گا۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiv{قیامت کے دن اس کا عذاب دوگنا کر دیا جائے گا۔ اور وہ اس میں ذلیل و خوار ہوکر ہمیشہ رہے گا۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcmxxv{سوائے اس کے جو توبہ کرے اور ایمان لائے اور نیک عمل کرے کہ اللہ ایسے لوگوں کی برائیوں کو بھلائیوں سے بدل دے گا اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvi{اور جو کوئی توبہ کرے اور نیک عمل کرے تو وہ اللہ کی طرف اس طرح رجوع کرتا ہے جو رجوع کرنے کا حق ہے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvii{اور جو جھوٹی گواہی نہیں دیتے (یا جو زُور یعنی غنا کی جگہ پر حاضر نہیں ہوتے) اور جو جب کسی بیہودہ کام کے پاس سے گزرتے ہیں تو شریفانہ انداز میں گزر جاتے ہیں۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcmxxviii{اور جب انہیں ان کے پروردگار کی آیتوں کے ذریعہ سے نصیحت کی جاتی ہے تو وہ بہرے اور اندھے ہوکر ان پر گر نہیں پڑتے (بلکہ ان میں غور و فکر کرتے ہیں)۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcmxxix{اور وہ کہتے ہیں اے ہمارے پروردگار! ہمیں ہماری بیویوں اور ہماری اولاد کی طرف سے آنکھوں کی ٹھنڈک عطا فرما اور ہمیں پرہیزگاروں کا پیش رو بنا۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcmxxx{یہ وہ ہیں جنہیں ان کے صبر و ثبات کے صلہ میں بہشت میں بالاخانہ عطا کیا جائے گا۔ اور وہاں ان کا تحیہ و سلام سے استقبال کیا جائے گا۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxi{وہ ہمیشہ اس میں رہیں گے کیا اچھا ہے وہ ٹھکانہ اور وہ مقام۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxii{آپ کہہ دیجئے! اگر تمہاری دعا و پکار نہ ہو تو میرا پروردگار تمہاری کوئی پروا نہ کرے سو اب جبکہ تم نے (رسول کو) جھٹلا دیا ہے تو یہ (تکذیب) عنقریب (تمہارے لئے) وبال جان بن کر رہے گی۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiii{\basmalahur طا، سین، میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiv{یہ ایک واضح کتاب کی آیتیں ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxv{شاید آپ (اس غم میں) جان دے دیں گے کہ یہ لوگ ایمان نہیں لاتے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvi{اگر ہم چاہیں تو ان پر آسمان سے کوئی ایسی نشانی اتاریں جس کے آگے ان کی گردنیں جھک جائیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvii{اور جب بھی ان کے پاس خدائے رحمن کی طرف سے کوئی نئی نصیحت آتی ہے تو یہ اس سے منہ پھیر لیتے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxviii{بےشک یہ جھٹلا چکے ہیں تو عنقریب ان کے سامنے اس چیز کی خبریں آئیں گی جس کا یہ مذاق اڑاتے رہے ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxix{کیا انہوں نے زمین کی طرف (غور سے) نہیں دیکھا کہ ہم نے اس میں کتنی کثرت سے عمدہ نباتات اگائی ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcmxl{بےشک اس کے اندر ایک بڑی نشانی ہے لیکن ان میں سے اکثر ایمان لانے والے نہیں ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcmxli{اور بےشک آپ کا پروردگار بڑا غالب، بڑا رحم کرنے والا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcmxlii{(اے رسول(ص)) وہ وقت یاد کرو جب آپ کے پروردگار نے موسیٰ کو پکارا کہ ظالم قوم کے پاس جاؤ۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcmxliii{یعنی فرعون کی قوم کے پاس۔ کیا وہ نہیں ڈرتے؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcmxliv{موسیٰ نے کہا اے میرے پروردگار! میں ڈرتا ہوں کہ وہ مجھے جھٹلائیں گے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcmxlv{اور میرا سینہ تنگ ہوتا ہے اور میری زبان نہیں چلتی سو ہارون کے پاس (وحی) بھیج (کہ وہ میرا ساتھ دے)۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvi{اور ان لوگوں کا میرے ذمہ ایک جرم بھی ہے اس لئے مجھے اندیشہ ہے کہ وہ مجھے قتل کر دیں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvii{ارشاد ہوا ہرگز نہیں! تم دونوں ہماری نشانیاں لے کر جاؤ ہم تمہارے ساتھ (سب کچھ) سن رہے ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcmxlviii{پس تم دونوں فرعون کے پاس جاؤ۔ اور اس سے کہو کہ ہم تمام جہانوں کے پروردگار کے رسول ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcmxlix{کہ تو بنی اسرائیل کو ہمارے ساتھ بھیج دے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcml{فرعون نے کہا (اے موسیٰ) کیا تمہارے بچپن میں ہم نے تمہاری پرورش نہیں کی ہے؟ اور تو نے اپنی عمر کے کئی سال ہم میں گزارے ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcmli{اور تو نے اپنی وہ حرکت بھی کی تھی جو کی تھی اور تو ناشکروں میں سے ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcmlii{موسیٰ نے کہا: ہاں میں نے وہ کام اس وقت کیا تھا جب میں راستہ سے بھٹکا ہوا تھا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcmliii{تو جب میں تم سے ڈرا تو بھاگ کھڑا ہوا۔ اس کے بعد میرے پروردگار نے مجھے علم و حکمت عطا کیا اور مجھے رسولوں میں سے قرار دے دیا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcmliv{اور یہی (پرورش وغیرہ کا) وہ احسان ہے جو تو مجھے جتا رہا ہے جب کہ تو نے بنی اسرائیل کو غلام بنا رکھا ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcmlv{فرعون نے کہا اور یہ رب العالمین کیا چیز ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcmlvi{موسیٰ نے کہا وہ آسمانوں اور زمین اور جو کچھ ان کے درمیان ہے سب کا پروردگار ہے۔ اگر تم یقین کرنے والے ہو۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcmlvii{فرعون نے اپنے اردگرد والوں سے کہا کیا تم سنتے نہیں ہو؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcmlviii{موسیٰ نے کہا وہ تمہارا بھی پروردگار ہے اور تمہارے اگلے آباء و اجداد کا بھی پروردگار۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcmlix{فرعون نے کہا تمہارا یہ رسول جو تمہاری طرف بھیجا گیا ہے یہ تو بالکل دیوانہ ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcmlx{موسیٰ نے کہا کہ وہ مشرق و مغرب اور جو کچھ ان کے درمیان ہے سب کا پروردگار ہے اگر تم عقل سے کام لو۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcmlxi{فرعون نے کہا کہ اگر تو نے میرے سوا کوئی معبود بنایا تو میں تمہیں قیدیوں میں شامل کر دوں گا۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcmlxii{موسیٰ نے کہا: اگرچہ میں تیرے پاس کوئی واضح نشانی بھی لے کر آؤں؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiii{فرعون نے کہا: اچھا تو لے آ۔ اگر تو سچا ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiv{اس پر موسیٰ نے اپنا عصا پھینک دیا تو ایک دم وہ کھلا ہوا اژدھا بن گیا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcmlxv{اس نے اپنا ہاتھ نکالا تو وہ ایک دم دیکھنے والوں کیلئے چمک رہا تھا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvi{فرعون نے اپنے اردگرد کے عمائدین سے کہا کہ یہ تو بڑا ماہر جادوگر ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvii{یہ اپنے جادو (کے زور) سے تمہیں اپنے ملک سے باہر نکالنا چاہتا ہے۔ اب تم کیا رائے دیتے ہو؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcmlxviii{انہوں نے کہا اسے اور اس کے بھائی کو روک لیجئے اور تمام شہروں میں جمع کرنے والے آدمی (ہرکارے) بھیجئے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcmlxix{جو ہر بڑے جادوگر کو تمہارے پاس لے آئیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcmlxx{چنانچہ تمام جادوگر ایک خاص مقررہ وقت پر جمع کر لئے گئے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxi{اور عام لوگوں سے کہا گیا۔ کیا تم لوگ بھی (مقابلہ دیکھنے کیلئے) جمع ہوگے؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxii{تاکہ اگر جادوگر غالب آجائیں تو ہم سب ان کی پیروی کریں۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiii{تو جب جادوگر (میدان میں) آگئے تو انہوں نے فرعون سے کہا کہ اگر ہم غالب آگئے تو ہمیں کچھ صلہ تو ملے گا۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiv{فرعون نے کہا: ہاں ضرور! اور تم اس وقت مقرب بارگاہ ہو جاؤگے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxv{موسیٰ نے ان سے کہا کہ تم پھینکو جو کچھ تمہیں پھینکنا ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvi{چنانچہ انہوں نے اپنی رسیاں اور اپنی لاٹھیاں پھینک دیں اور کہا کہ فرعون کے جلال و اقبال کی قَسم ہم ہی غالب آئیں گے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvii{پھر موسیٰ نے اپنا عصا پھینکا تو وہ ایک دم ان کے بنائے ہوئے جھوٹ کو نگلنے لگا۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxviii{(یہ معجزہ دیکھ کر) سب جادوگر سجدہ میں گر پڑے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxix{اور کہنے لگے کہ ہم رب العالمین پر ایمان لائے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxx{جو موسیٰ و ہارون کا رب ہے فرعون نے کہا تم اس پر ایمان لائے قبل اس کے کہ میں تمہیں اجازت دوں یقیناً یہ تمہارا بڑا (جادوگر) ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxi{جس نے تمہیں جادو سکھایا ہے ابھی تمہیں (اس کا انجام) معلوم ہو جائے گا کہ میں تمہارے ہاتھ پاؤں کو مخالف سمتوں سے کٹوا دوں گا۔ اور تم سب کو سولی چڑھا دوں گا۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxii{انہوں نے کہا کوئی جرم نہیں ہم اپنے پروردگار کی بارگاہ میں لوٹ جائیں گے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiii{ہمیں امید ہے کہ وہ ہماری خطاؤں کو معاف کرے گا کیونکہ ہم سب سے پہلے ایمان لا رہے ہیں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiv{اور ہم نے موسیٰ کو وحی کی کہ راتوں رات میرے بندوں کو لے کر نکل جاؤ کیونکہ تمہارا پیچھا کیا جائے گا۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxv{پس فرعون نے تمام شہروں میں (لشکر) جمع کرنے والے (ہرکارے) بھیجے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvi{(اور کہلا بھیجا کہ) یہ لوگ ایک چھوٹی سی جماعت ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvii{اور انہوں نے ہمیں بہت غصہ دلایا ہے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxviii{اور بےشک ہم پورے محتاط اور چوکنا ہیں۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxix{پھر ہم نے انہیں (مصر کے) باغوں اور چشموں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxc{اور خزانوں اور شاندر عمدہ مکانوں سے نکال باہر کیا۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxci{ایسا ہی ہوا اور ہم نے ان چیزوں کا وارث بنی اسرائیل کو بنایا۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxcii{چنانچہ صبح تڑکے وہ لوگ (فرعونی) ان کے تعاقب میں نکلے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxciii{پس جب دونوں جماعتیں ایک دوسرے کو دیکھنے لگیں (آمنے سامنے ہوئیں) تو موسیٰ کے ساتھیوں نے (گھبرا کر) کہا کہ بس ہم تو پکڑے گئے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxciv{موسیٰ نے کہا ہرگز نہیں! یقیناً میرا پروردگار میرے ساتھ ہے جو ضرور میری راہنمائی کرے گا۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxcv{سو ہم نے موسیٰ کو وحی کی کہ اپنا عصا دریا پر مارو۔ چنانچہ وہ دریا پھٹ گیا اور (پانی کا) ہر حصہ ایک بڑے پہاڑ کی طرح ہوگیا۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvi{اور ہم وہاں دوسرے فریق کو بھی نزدیک لائے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvii{اور ہم نے موسیٰ اور ان کے ساتھیوں کو نجات دی۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxcviii{اور پھر ہم نے دوسرے فریق کو غرق کر دیا۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxcix{بےشک اس واقعہ میں ایک بڑی نشانی ہے مگر ان سے اکثر لوگ ایمان لانے والے نہیں ہیں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmm{اور بےشک آپ کا پروردگار بڑا غالب آنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmi{اور آپ ان لوگوں کے سامنے ابراہیم (ع) کا قصہ بیان کیجئے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmii{جب انہوں نے اپنے باپ (یعنی چچا) اور اپنی قوم سے کہا کہ تم کس چیز کی پرستش کرتے ہو؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmiii{انہوں نے کہا کہ ہم تو بتوں کی پرستش کرتے ہیں اور اس پر قائم ہیں۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmiv{ابراہیم نے کہا کہ جب تم انہیں پکارتے ہو تو کیا یہ تمہاری آواز سنتے ہیں۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmv{یا تمہیں کچھ نفع یا نقصان پہنچاتے ہیں؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmvi{انہوں نے کہا بلکہ ہم نے اپنے باپ داداؤں کو ایسے ہی کرتے پایا ہے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmvii{ابراہیم نے کہا کیا تم نے ان چیزوں کی (اصل حقیقت) دیکھی ہے کہ جن کی تم\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmviii{اور تمہارے باپ دادا پرستش کرتے رہے ہیں؟ (کہ وہ کیا ہے؟)\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmix{بہرکیف یہ سب میرے دشمن ہیں سوائے رب العالمین کے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmx{جس نے مجھے پیدا کیا ہے۔ پھر وہی میری راہنمائی کرتا ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmxi{اور وہ جو مجھے کھلاتا ہے اور پلاتا بھی۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmxii{اور جب میں بیمار ہوتا ہوں تو وہ مجھے شفا دیتا ہے۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmxiii{اور جو مجھے موت دے گا اور پھر مجھے (دوبارہ) زندہ کرے گا۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmxiv{اور جس سے میں امید رکھتا ہوں کہ وہ جزا و سزا کے دن میری خطا معاف کر دے گا۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmxv{اے میرے پروردگار! مجھے (علم و حکمت) عطا فرما۔ اور مجھے نیکوکاروں میں شامل فرما۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmxvi{اور آئندہ آنے والوں میں میرا ذکرِ خیر جاری رکھ۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmxvii{اور مجھے جنتِ نعیم کے وارثوں میں شامل فرما۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmxviii{اور میرے باپ (یعنی چچا) کی مغفرت فرما۔ بےشک وہ گمراہوں میں سے تھا۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmxix{اور جس دن لوگ (قبروں سے) اٹھائے جائیں گے اس دن مجھے رسوا نہ کر۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmxx{جس دن نہ مال فائدہ دے گا اور نہ اولاد۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmxxi{اور سوائے اس کے جو اللہ کی بارگاہ میں قلبِ سلیم کے ساتھ حاضر ہوگا۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmxxii{اور جنت پرہیزگاروں کے قریب کر دی جائے گی۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmxxiii{اور دوزخ گمراہوں کے سامنے ظاہر کر دی جائے گی۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmxxiv{اور ان سے کہا جائے گا کہ تمہارے وہ معبود کہاں ہیں جن کی تم اللہ کو چھوڑ کر عبادت کرتے تھے؟\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmxxv{کیا وہ (آج) تمہاری کچھ مدد کرتے ہیں یا وہ اپنا ہی بچاؤ کر سکتے ہیں؟\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmxxvi{پھر وہ معبود اور (یہ) گمراہ لوگ۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmxxvii{اور ابلیس اور اس کے سارے لشکر اس (دوزخ) میں اندھے منہ ڈال دیئے جائیں گے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmxxviii{اور وہ دوزخ میں باہم جھگڑتے ہوئے کہیں گے۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmxxix{خدا کی قَسم ہم کھلی ہوئی گمراہی میں تھے۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmxxx{جب تمہیں رب العالمین کے برابر قرار دیتے تھے۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmxxxi{اور ہم کو تو بس (بڑے) مجرموں نے گمراہ کیا تھا۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmxxxii{نہ اب ہمارا کوئی سفارشی ہے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiii{اور نہ کوئی مخلص دوست۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiv{کاش! ہم دوبارہ (دنیا میں) بھیجے جاتے تو ضرور ہم اہلِ ایمان سے ہو جاتے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmxxxv{بےشک اس میں بڑی نشانی ہے مگر ان میں سے اکثر ایمان لانے والے نہیں ہیں۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvi{اور یقیناً آپ کا پروردگار بڑا غالب اور بڑا رحم کرنے والا ہے۔\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvii{نوح(ع) کی قوم نے پیغمبروں کو جھٹلایا۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmxxxviii{جب کہ ان کے بھائی نوح نے ان سے کہا کیا تم ڈرتے نہیں ہو؟ ۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmxxxix{بےشک میں تمہارے لئے امانت دار رسول ہوں۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmxl{سو تم اللہ سے ڈرو اور میری اطاعت کرو۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmxli{اور میں تم سے اس (تبلیغ) پر کوئی اجرت نہیں مانگتا۔ میری اجرت تو رب العالمین کے ذمہ ہے۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmxlii{پس تم اللہ سے ڈرو اور میری اطاعت کرو۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmxliii{انہوں نے کہا ہم کس طرح تجھے مان لیں (اور اطاعت کریں) جبکہ رذیل لوگ تمہاری پیروی کر رہے ہیں۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmxliv{آپ نے کہا مجھے اس کی کیا خبر (اور کیا غرض؟) جو وہ کرتے رہے ہیں؟\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmxlv{ان کا حساب کتاب کرنا تو میرے پروردگار ہی کا کام ہے کاش تم شعور سے کام لیتے۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmxlvi{اور میں اہلِ ایمان کو دھتکارنے والا نہیں ہوں۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmxlvii{میں تو صرف ایک کھلا ہوا ڈرانے والا ہوں۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmxlviii{ان لوگوں نے کہا اے نوح! اگر تم باز نہ آئے تو تم ضرور سنگسار کر دیئے جاؤگے۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmxlix{آپ نے کہا اے میرے پروردگار! میری قوم نے تو مجھے جھٹلایا دیا ہے۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmml{پس اب تو ہی میرے اور ان کے درمیان فیصلہ فرما اور مجھے اور میرے ساتھ ایمان لانے والوں کو نجات دے۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmli{پس ہم نے انہیں اور جو اس بھری ہوئی کشتی میں ان کے ساتھ تھے سب کو نجات دی۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmlii{پھر اس کے بعد باقی لوگوں کو غرق کر دیا۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmliii{بےشک اس میں ایک بڑی نشانی ہے (مگر) ان میں سے اکثر لوگ ایمان نہیں لانے والے ہیں۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmliv{اور آپ کا پروردگار بڑا غالب ہے، بڑا رحم کرنے والا ہے۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmlv{(اسی طرح قوم) عاد نے بھی رسولوں کو جھٹلایا۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmlvi{جبکہ ان کے بھائی ہود نے ان سے کہا کیا تم ڈرتے نہیں ہو؟\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmlvii{بےشک میں تمہارے لئے امانت دار رسول ہوں۔\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmlviii{سو تم اللہ سے ڈرو اور میری اطاعت کرو۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmlix{اور میں تم سے اس (تبلیغ) پر کوئی اجرت نہیں مانگتا۔ میری اجرت تو رب العالمین کے ذمہ ہے۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmlx{کیا تم ہر بلندی پر بے فائدہ ایک یادگار تعمیر کرتے ہو؟\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmlxi{اور تم بڑے بڑے محل تعمیر کرتے ہو شاید کہ تم ہمیشہ زندہ رہوگے۔\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmlxii{اور جب تم کسی پر حملہ کرتے ہو تو جبار و سرکش بن کر حملہ کرتے ہو؟\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmlxiii{پس تم اللہ سے ڈرو اور میری اطاعت کرو۔\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmlxiv{اور اس ذات سے ڈرو جس نے ان چیزوں سے تمہاری مدد کی ہے جنہیں تم جانتے ہو۔\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmlxv{(یعنی) اس نے مویشیوں اور اولاد سے تمہاری مدد فرمائی۔\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmlxvi{اور باغات اور چشموں سے۔\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmlxvii{میں تمہارے متعلق ایک بہت بڑے (سخت) دن کے عذاب سے ڈرتا ہوں۔\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmlxviii{ان لوگوں نے کہا کہ تم نصیحت کرو یا نہ کرو۔ ہمارے لئے برابر ہے۔\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmlxix{یہ (ڈراوا) تو بس اگلے لوگوں کی عادت ہے۔\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmlxx{اور ہم کبھی عذاب میں مبتلا ہونے والے نہیں ہیں۔\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmlxxi{پس انہوں نے اس (ہود) کو جھٹلایا اور ہم نے انہیں ہلاک کر دیا بےشک اس میں ایک بڑی نشانی ہے مگر ان میں سے اکثر لوگ ایمان لائے نہیں تھے۔\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmlxxii{اور یقیناً آپ کا پروردگار بڑا غالب، بڑا رحم کرنے والا ہے۔\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiii{قومِ ثمود نے رسولوں کو جھٹلایا۔\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiv{جبکہ ان کے بھائی صالح نے ان سے کہا کیا تم ڈرتے نہیں ہو؟\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmlxxv{میں تمہارے لئے امانت دار رسول ہوں۔\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvi{سو تم اللہ سے ڈرو اور میری اطاعت کرو۔\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvii{اور میں تم سے اس (تبلیغ رسالت) پر کوئی اجرت نہیں مانگتا۔ میری اجرت تو رب العالمین کے ذمہ ہے۔\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmlxxviii{کیا تمہیں ان چیزوں میں جو یہاں ہیں امن و اطمینان سے چھوڑ دیا جائے گا۔\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmlxxix{(یعنی) باغوں اور چشموں میں۔\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmlxxx{اور ان کھجوروں میں جن کے خوشے نرم اور خوب بھرے ہوئے ہیں۔\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxi{اور تم پہاڑوں کو تراش تراش کر اتراتے ہوئے (یا مہارت سے) مکانات بناتے ہو۔\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxii{پس اللہ سے ڈرو اور میری اطاعت کرو۔\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiii{اور ان حد سے تجاوز کرنے والوں کے حکم کی اطاعت نہ کرو۔\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiv{جو زمین میں فساد پھیلاتے ہیں اور اصلاح نہیں کرتے۔\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxv{ان لوگوں نے کہا: (اے صالح) تم ان لوگوں میں سے ہو جن پر سخت (یا بار بار) جادو کر دیا گیا ہے۔\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvi{(اور) تم تو بس ہمارے جیسے ایک بندہ ہو۔ اگر تم سچے ہو تو کوئی معجزہ لاؤ۔\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvii{صالح نے کہا یہ ایک اونٹنی ہے ایک دن اس کے پانی پینے کا ہوگا اور ایک مقررہ دن کا پانی تمہارے پینے کیلئے ہوگا۔\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxviii{اور خبردار اسے کوئی تکلیف نہ پہنچانا ورنہ تمہیں ایک بڑے دن کا عذاب آپکڑے گا۔\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxix{پس انہوں نے اس کی کونچیں کاٹ دیں پھر پشیمان ہوئے۔\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmxc{پھر ان کو عذاب نے آپکڑا بےشک اس (واقعہ) میں ایک بڑی نشانی ہے مگر ان میں سے اکثر لوگ ایمان لانے والے نہیں تھے۔\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmxci{اور یقیناً آپ کا پروردگار بڑا غالب ہے، بڑا رحم کرنے والا ہے۔\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmxcii{قومِ لوط نے رسولوں کو جھٹلایا۔\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmxciii{جبکہ ان کے بھائی لوط نے ان سے کہا کیا تم ڈرتے نہیں ہو۔\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmxciv{میں تمہارے لئے امانت دار رسول ہوں۔\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmxcv{پس تم اللہ سے ڈرو اور میری اطاعت کرو۔\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmxcvi{اور میں تم سے اس (تبلیغ رسالت) پر کوئی اجرت نہیں مانگتا میری اجرت تو بس رب العالمین کے ذمہ ہے۔\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmxcvii{کیا تم دنیا جہان والوں میں سے (بدفعلی کیلئے) مَردوں کے پاس ہی جاتے ہو۔\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmxcviii{اور تمہارے پروردگار نے تمہارے لئے جو بیویاں پیدا کی ہیں انہیں چھوڑ دیتے ہو۔ بلکہ تم حد سے گزر جانے والے لوگ ہو۔\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmxcix{ان لوگوں نے کہا: اے لوط (ع)! (اگر تم ان باتوں سے) باز نہ آئے تو تمہیں ضرور باہر نکال دیا جائے گا۔\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmc{آپ نے کہا میں تمہارے (اس) کردار سے سخت نفرت کرنے والوں میں سے ہوں۔\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmci{اے میرے پروردگار! مجھے اور میرے گھر والوں کو اس عمل (کے وبال) سے جو یہ کرتے ہیں نجات عطا فرما۔\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcii{چنانچہ ہم نے انہیں اور ان کے گھر والوں کو نجات عطا کی ہے۔\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmciii{سوائے ایک بڑھیا کے جو پیچھے رہ جانے والوں میں سے تھی۔\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmciv{پھر ہم نے دوسرے سب لوگوں کو تباہ و برباد کر دیا۔\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcv{اور ہم نے ان پر (پتھروں کی) بارش برسائی۔ سو کیا بڑی بارش تھی جو ڈرائے ہوؤوں پر برسی۔\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcvi{بےشک اس میں ایک بڑی نشانی ہے۔ مگر ان میں سے اکثر لوگ ایمان لانے والے نہیں تھے۔\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcvii{اور یقیناً آپ کا پروردگار بڑا غالب ہے، بڑا رحم کرنے والا ہے۔\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcviii{ایکہ والوں نے رسولوں کو جھٹلایا۔\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcix{جبکہ ان کے بھائی شعیب (ع) نے کہا کیا تم ڈرتے نہیں ہو؟\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcx{بےشک میں تمہارے لئے امانت دار رسول ہوں۔\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcxi{سو تم اللہ سے ڈرو اور میری اطاعت کرو۔\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcxii{میں تم سے اس (تبلیغ رسالت) پر کوئی اجرت نہیں مانگتا۔ میری اجرت تو بس رب العالمین کے ذمہ ہے۔\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcxiii{(دیکھو) پورا ناپا کرو (پیمانہ بھرا کرو) اور نقصان پہنچانے والوں میں سے نہ ہو۔\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcxiv{اور صحیح ترازو سے تولا کرو (ڈنڈی سیدھی رکھا کرو)۔\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcxv{اور لوگوں کو ان کی چیزیں کم نہ دیا کرو۔ اور زمین میں فساد پھیلاتے نہ پھرو۔\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mmmcxvi{اور اس (اللہ) سے ڈرو جس نے تمہیں اور پہلی مخلوق کو پیدا کیا ہے۔\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mmmcxvii{ان لوگوں نے کہا کہ تم تو بس سخت سحر زدہ آدمی ہو۔\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mmmcxviii{اور تم ہمارے ہی جیسے ایک انسان ہو اور ہمیں تو جھوٹے بھی معلوم ہوتے ہو۔\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mmmcxix{اگر تم سچے ہو تو ہم پر آسمان کا کوئی ٹکڑا گرا دو۔\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mmmcxx{آپ نے کہا میرا پروردگار بہتر جانتا ہے جو کچھ تم کرتے ہو۔\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mmmcxxi{پس ان لوگوں نے ان (شعیب (ع)) کو جھٹلایا تو سائبان والے دن کے عذاب نے انہیں اپنی گرفت میں لے لیا۔ بےشک وہ ایک بڑے سخت دن کا عذاب تھا۔\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mmmcxxii{بےشک اس میں ایک بڑی نشانی ہے۔ مگر ان میں سے اکثر لوگ ایمان لانے والے نہیں تھے۔\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiii{اور بےشک آپ کا پروردگار بڑا غالب ہے، بڑا رحم کرنے والا ہے۔\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiv{اور بےشک یہ (قرآن) رب العالمین کا نازل کردہ ہے۔\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mmmcxxv{جسے روح الامین (جبرائیل) نے آپ کے دل پر اتارا ہے۔\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvi{تاکہ آپ (عذابِ الٰہی سے) ڈرانے والوں میں سے ہو جائیں۔\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvii{یہ کھلی ہوئی عربی زبان میں ہے۔\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mmmcxxviii{اور یہ پہلے لوگوں کی کتابوں میں (بھی) ہے۔\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mmmcxxix{کیا یہ نشانی اس (اہل مکہ) کیلئے کافی نہیں ہے کہ اس (قرآن) کو بنی اسرائیل کے علماء جانتے ہیں۔\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mmmcxxx{اور اگر ہم اسے کسی عجمی (غیر عرب) پر نازل کرتے۔\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxi{پھر وہ اسے پڑھ کر ان کو سناتا تب بھی وہ اس پر ایمان نہ لاتے۔\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxii{اسی طرح ہم نے اس (انکار) کو مجرموں کے دلوں میں داخل کر دیا ہے۔\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiii{یہ اس پر ایمان نہیں لائیں گے جب تک دردناک عذاب کو نہیں دیکھ لیں گے۔\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiv{چنانچہ وہ (عذاب) اس طرح اچانک ان پر آجائے گا کہ انہیں احساس بھی نہ ہوگا۔\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxv{تب وہ کہیں گے کیا ہمیں مہلت مل سکتی ہے؟\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvi{کیا یہ لوگ ہمارے عذاب کیلئے جلدی کر رہے ہیں۔\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvii{کیا تم دیکھتے ہو کہ اگر ہم انہیں کئی سال تک فائدہ اٹھانے کا موقع دیں۔\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxviii{پھر ان پر وہ عذاب آجائے جس سے انہیں ڈرایا جاتا تھا۔\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxix{تو وہ سب ساز و سامان جس سے وہ فائدہ اٹھاتے رہے تھے انہیں کوئی فائدہ نہ دے گا۔\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@mmmcxl{اور ہم نے کبھی کسی بستی کو اس وقت تک ہلاک نہیں کیا جب تک اس کے پاس عذاب الٰہی سے ڈرانے والے نہ آچکے ہوں۔\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@mmmcxli{نصیحت اور یاد دہانی کیلئے! اور ہم کبھی ظالم نہیں تھے۔\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@mmmcxlii{اور اس (قرآن) کو شیطانوں نے نہیں اتارا۔\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@mmmcxliii{اور نہ ہی یہ ان کیلئے مناسب ہے اور نہ ہی وہ اس کی طاقت رکھتے ہیں۔\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@mmmcxliv{وہ تو اس (وحی) کے سننے سے بھی معزول کئے جا چکے ہیں۔\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@mmmcxlv{پس آپ اللہ کے ساتھ کسی اور الہ کو نہ پکاریں ورنہ آپ بھی سزا پانے والوں میں شامل ہو جائیں گے۔\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvi{اور (اے رسول) اپنے قریب ترین رشتہ داروں کو (عذاب سے) ڈراؤ۔\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvii{اور جو اہلِ ایمان آپ کی پیروی کریں ان کیلئے اپنا بازو جھکاؤ (ان کے ساتھ تواضع و فروتنی سے پیش آؤ)۔\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@mmmcxlviii{اور اگر وہ تمہاری نافرمانی کریں تو کہہ دو کہ میں اس سے بیزار ہوں جو کچھ تم کرتے ہو۔\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@mmmcxlix{اور اس (پروردگار) پر بھروسہ کیجئے جو غالب ہے اور بڑا رحم کرنے والا ہے۔\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@mmmcl{جو آپ کو اس وقت دیکھتا ہے جب آپ کھڑے ہوتے ہیں۔\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@mmmcli{اور جب آپ سجدہ کرنے والوں میں نشست و برخاست کرتے ہیں تب بھی دیکھتا ہے۔\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@mmmclii{بےشک وہ بڑا سننے والا، بڑا علم والا ہے۔\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@mmmcliii{کیا میں تمہیں بتاؤں کہ شیاطین کس پر اترتے ہیں۔\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@mmmcliv{وہ ہر جھوٹ گھڑنے والے گنہگار پر اترتے ہیں۔\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@mmmclv{جو ان (شیاطین) کی طرف کان لگائے رہتے ہیں اور ان میں اکثر جھوٹے ہوتے ہیں۔\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@mmmclvi{اور جو شعراء ہیں ان کی پیروی گمراہ لوگ کرتے ہیں۔\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@mmmclvii{کیا تم نہیں دیکھتے کہ وہ ہر وادی میں حیران و سرگرداں پھرا کرتے ہیں۔\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@mmmclviii{اور وہ کہتے ہیں ایسی باتیں جو کرتے نہیں ہیں۔\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@mmmclix{سوائے ان کے جو ایمان لائے اور نیک عمل کئے اور بکثرت اللہ کا ذکر کیا اور بعد اس کے کہ ان پر ظلم ہوا انہوں نے بدلہ لیا اور جن لوگوں نے ظلم کیا انہیں عنقریب معلوم ہو جائے گا کہ وہ کس جگہ لوٹ کر جا رہے ہیں؟\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@mmmclx{\basmalahur طا۔ سین۔ یہ قرآن واضح کتاب کی آیتیں ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmclxi{جو ان ایمان والوں کیلئے (سراسر) ہدایت و بشارت ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmclxii{جو نماز پڑھتے اور زکوٰۃ دیتے ہیں اور آخرت پر یقین رکھتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmclxiii{جو لوگ ایمان نہیں رکھتے۔ ہم نے ان کے اعمال (ان کی نظر میں) خوشنما بنا دیئے ہیں پس وہ سرگردان پھر رہے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmclxiv{یہ وہ لوگ ہیں جن کیلئے (دنیا میں) بڑا عذاب ہے اور وہ آخرت میں سب سے زیادہ نقصان اٹھانے والے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmclxv{(اے رسول(ص)) بےشک آپ کو یہ قرآن ایک بڑے حکمت والے، بڑے علم والے کی طرف سے عطا کیا جا رہا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmclxvi{(وہ وقت یاد کرو) جب موسیٰ نے اپنے گھر والوں سے کہا کہ میں نے آگ دیکھی ہے تو میں ابھی وہاں سے کوئی خبر لاتا ہوں یا آگ کا کوئی انگارہ لاتا ہوں تاکہ تم تاپو۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmclxvii{پھر جب وہ اس کے پاس آئے تو (انہیں) ندا دی گئی کہ مبارک ہے وہ جس کا جلوہ آگ میں ہے۔ اور جس کا جلوہ اس کے اردگرد ہے اور پاک ہے اللہ جو پروردگارِ عالمیان ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmclxviii{اے موسیٰ! بلاشبہ یہ میں اللہ ہوں، بڑا غلبہ والا، بڑا حکمت والا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmclxix{اور تم اپنا عصا پھینکو۔ پھر جب انہوں نے اسے دیکھا کہ وہ حرکت کر رہا ہے جیسے کہ وہ ایک سانپ ہے تو وہ پیٹھ پھیر کر مڑے اور پیچھے پلٹ کر بھی نہ دیکھا (ہم نے آواز دی) اے موسیٰ خوف نہ کرو۔ میں وہ ہوں کہ میرے حضور پیغمبر خوف نہیں کرتے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmclxx{سوائے اس کے جو کوئی زیادتی کرے پھر وہ برائی کو اچھائی سے بدل دے تو بےشک میں بڑا بخشنے والا، بڑا رحم کرنے والا ہوں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmclxxi{اور اپنا ہاتھ اپنے گریبان میں ڈالو تو وہ کسی بیماری کے بغیر چمکتا ہوا نکلے گا (یہ دو معجزے ہیں) ان نو معجزات میں سے جنہیں لے کر آپ نے فرعون اور اس کی قوم کے پاس جانا ہے۔ وہ بڑے ہی نافرمان لوگ ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmclxxii{سو جب ان کے پاس ہمارے واضح معجزات پہنچے تو انہوں نے کہا کہ یہ تو کھلا ہوا جادو ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiii{اور ان لوگوں نے ظلم و تکبر کی راہ سے ان (معجزات) کا انکار کر دیا۔ حالانکہ ان کے نفوس (دلوں) کو ان کا یقین تھا۔ اب دیکھو کہ فساد کرنے والوں کا انجام کیا ہوا؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiv{اور ہم نے داؤد اور سلیمان کو (خاص) علم عطا فرمایا۔ اور ان دونوں نے کہا کہ ہر قِسم کی تعریف اس اللہ کے لئے ہے جس نے ہمیں اپنے بہت سے مؤمن بندوں پر فضیلت عطا کی ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmclxxv{اور سلیمان داؤد کے وارث ہوئے اور کہا اے لوگو! ہمیں پرندوں کی بولی کی تعلیم دی گئی ہے اور ہمیں ہر قسم کی چیزیں عطا کی گئی ہیں۔ بےشک یہ (اللہ کا) کھلا ہوا فضل و کرم ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvi{اور سلیمان کے لئے جنوں، انسانوں اور پرندوں میں سے لشکر جمع کئے گئے۔ پس ان کی ترتیب وار صف بندی کی جاتی تھی۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvii{یہاں تک کہ جب وہ چیونٹیوں کی وادی میں پہنچے تو ایک چیونٹی نے کہا اے چیونٹیو! اپنے اپنے بلوں میں گھس جاؤ۔ ایسا نہ ہو کہ سلیمان اور ان کا لشکر تمہیں کچل ڈالے اور انہیں خبر بھی نہ ہو۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmclxxviii{وہ (سلیمان) اس کی بات پر مسکرا کر ہنس پڑے۔ اور کہا اے میرے پروردگار! مجھے ہمیشہ توفیق دے کہ میں تیری ان نعمتوں کا شکریہ ادا کر سکوں جن سے تو نے مجھے اور میرے والدین کو نوازا ہے اور ایسا نیک عمل کروں جسے تو پسند کرے اور مجھے اپنی رحمت سے اپنے نیک بندوں میں داخل کر۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmclxxix{اور سلیمان (ع) نے (ایک دن) پرندوں کا جائزہ لیا تو کہا کیا بات ہے کہ میں ہُدہُد کو نہیں دیکھ رہا ہوں کیا وہ کہیں غائب ہے؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmclxxx{(اگر ایسا ہی ہے) تو میں اسے سخت سزا دوں گا۔ یا اسے ذبح کر دوں گا۔ یا پھر وہ کوئی واضح دلیل (عذر) میرے سامنے پیش کرے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxi{پس کچھ زیادہ دیر نہیں گزری تھی کہ ہد ہد نے آکر کہا کہ میں نے وہ بات معلوم کی ہے جو آپ کو معلوم نہیں ہے۔ اور میں (ملک) سبا سے آپ کے پاس ایک یقینی خبر لایا ہوں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxii{میں نے ایک عورت کو پایا ہے جو ان لوگوں پر حکومت کرتی ہے اور اسے ہر چیز دی گئی ہے اور اس کا ایک بڑا تخت (سلطنت) ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiii{میں نے اسے اور اس کی قوم کو پایا ہے کہ وہ اللہ کو چھوڑ کر سورج کو سجدہ کرتے ہیں اور شیطان نے ان کے عملوں کو ان کی نظر میں خوشنما بنا دیا ہے۔ پس اس نے انہیں اصل (سیدھے) راستہ سے ہٹا دیا ہے۔ سو وہ ہدایت نہیں پاتے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiv{وہ کیوں اس خدا کو سجدہ نہ کریں جو آسمانوں اور زمین میں پوشیدہ چیزوں کو باہر لاتا ہے اور وہ جانتا ہے جو کچھ تم چھپاتے ہو اور جو کچھ تم ظاہر کرتے ہو۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxv{اللہ کے سوا کوئی الہ نہیں ہے جو عرش عظیم کا مالک ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvi{سلیمان نے کہا ہم ابھی دیکھتے ہیں کہ تو نے سچ کہا ہے یا تو جھوٹوں میں سے ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvii{میرا یہ خط لے جا اور اسے ان کے پاس ڈال دے پھر ان سے ہٹ جا۔ پھر دیکھ کہ وہ کیا جواب دیتے ہیں؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxviii{اس (ملکہ) نے کہا اے (دربار کے) سردارو! مجھے ایک معزز خط پہنچایا گیا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxix{وہ سلیمان کی طرف سے ہے اور وہ یہ ہے بسم اللہ الرحمن الرحیم۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcxc{تم میرے مقابلہ میں سرکشی نہ کرو اور فرمانبردار ہوکر میرے پاس آجاؤ۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcxci{چنانچہ ملکہ نے کہا: اے سردارانِ قوم! تم مجھے میرے اس معاملہ میں رائے دو (کیونکہ) میں کبھی کسی معاملہ کا کوئی قطعی فیصلہ نہیں کرتی جب تک تم لوگ میرے پاس موجود نہ ہو۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcxcii{انہوں نے کہا ہم طاقتور اور سخت لڑنے والے ہیں لیکن اختیار آپ کو ہی ہے۔ آپ دیکھ لیں (غور کریں) کہ کیا حکم دیتی ہیں؟\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcxciii{ملکہ نے کہا بادشاہ جب کسی بستی میں داخل ہوتے ہیں تو اسے تباہ کر دیتے ہیں اور اس کے معزز باشندوں کو ذلیل کر دیتے ہیں اور ایسا ہی (یہ لوگ) کریں گے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcxciv{(لہٰذا جنگ مناسب نہیں البتہ) میں ان کے پاس ایک ہدیہ بھیجتی ہوں۔ اور پھر دیکھتی ہوں کہ میرے فرستادے (قاصد) کیا جواب لاتے ہیں؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcxcv{سو جب وہ فرستادہ (یا ملکہ کا سفیر) سلیمان کے پاس پہنچا تو آپ نے کہا کیا تم لوگ مال سے میری مدد کرنا چاہتے ہو؟ تو اللہ نے مجھے جو کچھ دے رکھا ہے وہ اس سے بہتر ہے جو تمہیں دیا ہے البتہ تم ہی اپنے ہدیہ پر خوش ہو سکتے ہو۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvi{(اے سفیر) تو ان لوگوں کے پاس واپس لوٹ جا (اور ان کو بتا کہ) ہم ان کے پاس ایسے لشکر لے کر آرہے ہیں جن کے مقابلہ کی ان میں تاب نہ ہوگی اور ہم ان کو وہاں سے اس طرح ذلیل کرکے نکالیں گے کہ وہ خوار ہو چکے ہوں گے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvii{آپ نے کہا اے عمائدین سلطنت! تم میں سے کون ہے؟ جو اس (ملکہ سبا) کا تخت میرے پاس لائے قبل اس کے کہ وہ مسلمان ہوکر میرے پاس آئیں؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcxcviii{جنات میں سے ایک شریر و چالاک جن نے کہا کہ میں اسے آپ کے پاس لے آؤں گا اس سے پہلے کہ آپ اپنی جگہ سے اٹھیں۔ بےشک میں اس کی طاقت رکھتا ہوں (اور میں) امانت دار بھی ہوں۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcxcix{اور اس شخص نے کہا جس کے پاس کتاب کا کچھ علم تھا میں اسے آپ کے پاس لے آؤں گا اس سے پہلے کہ آپ کی آنکھ جھپکے پھر جب سلیمان نے اسے اپنے پاس رکھا ہوا دیکھا تو کہا کہ یہ میرے پروردگار کا فضل و کرم ہے تاکہ وہ مجھے آزمائے کہ میں اس کا شکر ادا کرتا ہوں یا ناشکری کرتا ہوں اور جو کوئی شکر کرتا ہے تو وہ اپنے فائدہ کیلئے شکر کرتا ہے اور جو ناشکری کرتا ہے تو وہ (اپنا نقصان کرتا ہے) میرا پروردگار بے نیاز اور کریم ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcc{آپ نے کہا اس (ملکہ) کے تخت کی صورت بدل دو تاکہ ہم دیکھیں کہ آیا وہ صحیح بات تک راہ پاتی ہے یا وہ ان لوگوں میں سے ہے جو صحیح بات تک راہ نہیں پاتے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcci{الغرض جب ملکہ آئی تو اس سے کہا گیا کیا تمہارا تخت ایسا ہی ہے؟ اس نے کہا یہ تو گویا وہی ہے اور ہمیں تو پہلے ہی سے حقیقت معلوم ہوگئی تھی۔ اور ہم تو مسلمان (مطیع و فرمانبردار) ہو چکے ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccii{اور سلیمان نے اس (ملکہ) کو غیر اللہ کی عبادت سے روک دیا جو وہ کیا کرتی تھی کیونکہ وہ کافر قوم میں سے تھی۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcciii{اس سے کہا گیا کہ محل میں داخل ہو۔ تو جب اس نے اس کو دیکھا تو (بلوریں فرش کو گہرا) پانی خیال کیا اور (گزرنے کیلئے اس طرح پائیچے اٹھائے کہ) اپنی دونوں پنڈلیاں کھول دیں۔ آپ نے کہا یہ (پانی نہیں ہے بلکہ) شیشوں سے مرصع محل ہے (اور بلوریں فرش ہے) ملکہ نے کہا اے میرے پروردگار! میں نے اپنے اوپر ظلم کیا تھا اور میں سلیمان کے ساتھ رب العالمین پر ایمان لاتی ہوں۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcciv{اور بےشک ہم نے قوم ثمود کی طرف ان کے بھائی صالح کو رسول بنا کر (اس پیغام کے ساتھ) بھیجا کہ اللہ کی عبادت کرو۔ تو وہ دو فریق (مؤمن و کافر) ہوگئے جو آپس میں جھگڑنے لگے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccv{آپ نے کہا اے میری قوم! تم بھلائی سے پہلے برائی کیلئے کیوں جلدی کرتے ہو؟ تم اللہ سے کیوں بخشش طلب نہیں کرتے؟ تاکہ تم پر رحم کیا جائے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccvi{انہوں نے کہا کہ ہم تو تمہیں اور تمہارے ساتھیوں کو برا شگون سمجھتے ہیں آپ (ع) نے کہا تمہاری بدشگونی تو اللہ کے پاس ہے بلکہ تم وہ لوگ ہو جو آزمائے جا رہے ہو۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccvii{اور (اس) شہر میں نو گروہ تھے جو زمین میں فساد برپا کرتے تھے اور اصلاح نہیں کرتے تھے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccviii{انہوں نے کہا کہ آپس میں خدا کی قسم کھا کر عہد کرو کہ ہم رات کے وقت صالح اور اس کے گھر والوں کو ہلاک کر دیں گے اور پھر ان کے وارث سے کہیں گے کہ ہم ان کے گھر والوں کی ہلاکت کے موقع پر موجود ہی نہیں تھے اور ہم بالکل سچے ہیں۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmccix{اور (اس طرح) انہوں نے ایک چال چلی اور ہم نے بھی ایک چال چلی جس کی انہیں خبر نہ تھی۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccx{تو دیکھو ان کی چال کا انجام کیا ہوا؟ ہم نے ان کو اور ان کی قوم کو تباہ و برباد کر دیا۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccxi{سو یہ ان کے گھر ہیں جو ان کے ظلم کی وجہ سے ویران پڑے ہیں۔ بےشک اس (واقعہ) میں ایک بڑی نشانی ہے ان لوگوں کیلئے جو علم رکھتے ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmccxii{اور ہم نے ان لوگوں کو نجات دی جو ایمان لائے اور تقویٰ اختیار کئے ہوئے تھے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmccxiii{اور ہم نے لوط کو بھی (رسول بنا کر بھیجا) جب انہوں نے اپنی قوم سے کہا کہ تم بے حیائی کا کام کرتے ہو حالانکہ تم دیکھ رہے ہو (جانتے بوجھتے ہو)۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmccxiv{کیا تم عورتوں کو چھوڑ کر مردوں سے شہوت رانی کرتے ہو؟ بلکہ تم بڑے ہی جاہل لوگ ہو۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmccxv{ان کی قوم کا جواب اس کے سوا کوئی نہ تھا کہ لوط کے گھرانے کو اپنی بستی سے نکال دو یہ لوگ بڑے پاکباز بنتے ہیں۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmccxvi{پس ہم نے آپ کو اور آپ کے گھر والوں کو نجات دی سوائے آپ کی بیوی کے کہ جس کے بارے میں ہم نے فیصلہ کر دیا تھا کہ وہ پیچھے رہ جانے والوں میں سے ہوگی۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmccxvii{اور ہم نے ان پر ایک خاص (پتھروں کی) بارش برسائی سو کیسی بری بارش تھی ان لوگوں کیلئے جن کو ڈرایا جا چکا تھا۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmccxviii{آپ کہئے! ہر قِسم کی تعریف اللہ کیلئے ہے اور اس کے ان بندوں پر سلام ہو جنہیں اس نے منتخب کیا ہے (ان سے پوچھو) کیا اللہ بہتر ہے یا وہ (معبود) جنہیں وہ (اللہ کا) شریک ٹھہراتے ہیں؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmccxix{(ان مشرکین سے پوچھو) بھلا وہ کون ہے جس نے آسمانوں اور زمین کو پیدا کیا؟ اور تمہارے لئے آسمان سے پانی اتارا؟ پھر ہم نے اس (پانی) سے خوش منظر (بارونق) باغات اگائے۔ ان درختوں کا اگانا تمہارے بس میں نہیں تھا۔ کیا اللہ کے ساتھ کوئی اور الٰہ ہے؟ بلکہ یہ (راہِ حق سے) انحراف کرنے والے لوگ ہیں۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmccxx{بھلا وہ کون ہے جس نے زمین کو قرارگاہ بنایا؟ اور اس کے درمیان نہریں (ندیاں) جاری کیں اور اس کیلئے بھاری پہاڑ بنائے اور دو دریاؤں کے درمیان پردہ حائل کر دیا۔ کیا اللہ کے ساتھ کوئی اور الہ ہے؟ بلکہ ان میں سے اکثر لوگ جانتے نہیں ہیں۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmccxxi{کون ہے جو مضطر و بے قرار کی دعا و پکار کو قبول کرتا ہے۔ جب وہ اسے پکارتا ہے؟ اور اس کی تکلیف و مصیبت کو دور کر دیتا ہے؟ اور تمہیں زمین میں (اگلوں کا) جانشین بناتا ہے؟ کیا اللہ کے ساتھ کوئی اور الہ ہے؟ نہیں - بلکہ یہ لوگ بہت کم نصیحت حاصل کرتے ہیں۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmccxxii{جو خشکی اور تری کی تاریکیوں میں تمہاری راہنمائی کرتا ہے۔ اور اپنی (باران) رحمت سے پہلے ہواؤں کو خوشخبری دینے والا بنا کر بھیجتا ہے کیا اللہ کے ساتھ کوئی اور الہ ہے؟ اللہ برتر و بالا ہے ان چیزوں سے جنہیں وہ اس کا شریک ٹھہراتے ہیں۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiii{وہ کون ہے جو خلقت کی ابتداء کرتا ہے اور پھر اسے دوبارہ پیدا کرے گا اور کون ہے جو تمہیں آسمان و زمین سے روزی دیتا ہے؟ کیا اللہ کے ساتھ کوئی اور الہ ہے؟ کہہ دیجئے کہ اگر تم سچے ہو تو اپنی دلیل لاؤ۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiv{آپ کہہ دیجئے! کہ آسمانوں اور زمین میں جو بھی ہیں اللہ کے سوا کوئی بھی غیب کا علم نہیں رکھتا۔ اور نہ وہ یہ جانتے ہیں کہ وہ کب (دوبارہ) اٹھائے جائیں گے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmccxxv{بلکہ آخرت کی منزل میں رفتہ رفتہ انہیں پورا علم ہوگا۔ بلکہ وہ اس کے بارے میں شک میں مبتلا ہیں بلکہ یہ اس کی طرف سے بالکل اندھے ہیں۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvi{اور کافر لوگ کہتے ہیں کہ جب ہم اور ہمارے باپ دادا مٹی ہو جائیں گے تب ہم (دوبارہ قبروں سے) نکالے جائیں گے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvii{اس کا وعدہ ہم سے بھی کیا گیا اور اس سے پہلے ہمارے باپ دادا سے بھی کیا گیا یہ تو محض اگلے لوگوں کی کہانیاں ہیں۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmccxxviii{آپ کہئے کہ زمین میں چلو پھرو اور دیکھو کہ مجرموں کا کیا انجام ہوا؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmccxxix{اور (اے رسول(ص)) آپ ان (کے حال) پر غمزدہ نہ ہوں۔ اور جو چالیں یہ چل رہے ہیں اس سے دل تنگ نہ ہوں۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmccxxx{اور وہ کہتے ہیں کہ یہ وعدہ وعید کب پورا ہوگا؟ اگر تم سچے ہو؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxi{آپ کہئے! بہت ممکن ہے کہ جس (عذاب) کیلئے تم جلدی کر رہے ہو اس کا کچھ حصہ تمہارے پیچھے آ لگا ہو(قریب آگیا ہو)۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxii{اور بےشک آپ کا پروردگار لوگوں پر بڑا فضل و کرم کرنے والا ہے لیکن اکثر لوگ شکر نہیں کرتے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiii{اور یقیناً آپ کا پروردگار خوب جانتا ہے اسے جو ان کے سینے چھپائے ہوئے ہیں اور جو کچھ وہ ظاہر کرتے ہیں۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiv{اور آسمانوں و زمین میں کوئی ایسی پوشیدہ چیز نہیں ہے۔ جو ایک واضح کتاب میں موجود نہ ہو۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxv{بےشک یہ قرآن بنی اسرائیل کے سامنے اکثر وہ باتیں بیان کرتا ہے جن میں وہ اختلاف کیا کرتے ہیں۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvi{اور بلاشبہ وہ (قرآن) مؤمنین کیلئے سراپا ہدایت اور رحمت ہے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvii{اور بےشک آپ کا پروردگار اپنے حکم سے ان کے درمیان فیصلہ کرے گا۔ وہ بڑا غالب اور بڑا جاننے والا ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxviii{سو آپ اللہ پر بھروسہ کریں۔ بےشک آپ واضح حق پر ہیں۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxix{آپ مُردوں کو (آواز) نہیں سنا سکتے۔ اور نہ بہروں کو (اپنی) پکار سنا سکتے ہیں جو پیٹھ پھیر کر چل دیں۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmccxl{اور نہ ہی آپ (دل کے) اندھوں کو ان کی گمراہی سے (ہٹا کر) راستہ دکھا سکتے ہیں۔ آپ تو صرف انہی لوگوں کو سنا سکتے ہیں جو ہماری آیتوں پر ایمان لاتے ہیں۔ بس یہی لوگ ماننے والے ہیں۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmccxli{اور جب ان لوگوں پر وعدہ پورا ہونے کو ہوگا تو ہم زمین سے چلنے پھرنے والا نکالیں گے جو ان سے کلام کرے گا۔ (اس بناء پر) کہ لوگ ہماری آیتوں پر یقین نہیں کرتے تھے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmccxlii{اور (اس دن کو یاد کرو) جس دن ہم ہر امت میں سے ایک ایسا گروہ محشور (جمع) کریں گے جو ہماری آیتوں کو جھٹلایا کرتا تھا۔ پھر اس کو روک کر جماعت بندی کی جائے گی۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmccxliii{یہاں تک کہ جب وہ (سب) آجائیں گے تو اللہ ان سے فرمائے گا کیا تم نے میری آیتوں کو اس حالت میں جھٹلایا تھا کہ تم نے ان کا علمی احاطہ بھی نہ کیا تھا؟ یا وہ کیا تھا جو تم کیا کرتے تھے؟\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmccxliv{اور ان لوگوں کے ظلم کی وجہ سے ان پر (وعدۂ عذاب کی) بات پوری ہو جائے گی تو اب وہ نہیں بولیں گے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmccxlv{کیا انہوں نے نہیں دیکھا کہ ہم نے رات (تاریک) اس لئے بنائی کہ وہ اس میں آرام کریں اور دن کو روشن اس لئے بنایا (تاکہ اس میں کام کریں) بےشک اس میں ایمان لانے والوں کیلئے (قدرت خدا کی) نشانیاں ہیں۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvi{اور جس دن صور پھونکا جائے گا۔ تو جو بھی آسمانوں اور زمین میں ہیں سب گھبرا جائیں گے سوائے ان کے جن کو خدا (بچانا) چاہے گا اور سب ذلت وعاجزی کے ساتھ اس کی بارگاہ میں حاضر ہوں گے۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvii{(اس وقت) تم پہاڑوں کو دیکھوگے تو خیال کروگے کہ وہ ساکن و برقرار ہیں حالانکہ وہ بادلوں کی مانند رواں دواں ہوں گے۔ یہ خدا کی کاریگری ہے جس نے ہر شئے کو محکم و پائیدار بنایا ہے۔ بیشک وہ خوب جانتا ہے جو کچھ تم کرتے ہو۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmccxlviii{جو شخص نیکی لے کر آئے گا اسے اس سے بہتر ملے گا اور اس دن کی گھبراہٹ سے محفوظ ہوں گے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmccxlix{اور جو شخص برائی لے کر آئے گا تو ان کو اوندھے منہ آتش (دوزخ) میں پھینک دیا جائے گا۔ کیا تمہیں تمہارے عمل کے علاوہ کوئی بدلہ مل سکتا ہے؟ (جیسا کروگے ویسا بھروگے)۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmccl{(اے رسول(ص)۔ کہو) مجھے تو بس یہی حکم ملا ہے کہ میں فرمانبرداروں میں سے رہوں۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmccli{اور یہ کہ قرآن پڑھ کر سناؤں سو اب جو ہدایت اختیار کرے گا وہ اپنے لئے ہدایت اختیار کرے گا۔ اور جو کوئی گمراہی اختیار کرے گا تو آپ کہہ دیجئے! کہ میں تو صرف ڈرانے والوں میں سے ہوں۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmcclii{اور آپ کہہ دیجئے! کہ سب تعریف اللہ کیلئے ہے وہ عنقریب تمہیں اپنی نشانیاں دکھائے گا اور تم انہیں پہچان لوگے اور تمہارا پروردگار اس سے غافل نہیں ہے جو کچھ تم کرتے ہو۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmccliii{\basmalahur طا۔ سین۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmccliv{یہ کتابِ مبین کی آیتیں ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcclv{ہم اہلِ ایمان کے فائدہ کیلئے موسیٰ و فرعون کی کچھ خبریں سچائی کے ساتھ آپ کے سامنے پڑھ کر سناتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcclvi{بےشک فرعون زمین (مصر) میں سرکش ہوگیا تھا اور اس کے باشندوں کو مختلف گروہوں میں تقسیم کر دیا تھا اور اس نے ان میں سے ایک گروہ کو کمزور بنا رکھا تھا (چنانچہ) ان کے بیٹوں کو ذبح کر دیتا تھا اور ان کی عورتوں (لڑکیوں) کو زندہ چھوڑ دیتا تھا۔ بےشک وہ (زمین میں) فساد برپا کرنے والوں میں سے تھا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcclvii{اور ہم چاہتے ہیں کہ ان لوگوں پر احسان کریں جنہیں زمین میں کمزور کر دیا گیا تھا اور انہیں پیشوا بنائیں اور انہیں (زمین کا) وارث قرار دیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcclviii{اور انہیں زمین میں اقتدار عطا کریں اور فرعون، ہامان اور ان کی فوجوں کو ان (کمزوروں) کی جانب سے وہ کچھ دکھلائیں جس سے وہ ڈرتے تھے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcclix{اور ہم نے مادر موسیٰ کو وحی کی کہ اس (بچہ) کو دودھ پلا۔ اور جب اس کے متعلق خطرہ محسوس ہو تو اسے دریا میں ڈال دے اور (کسی قسم کا) خوف اور غم نہ کر، بلاشبہ ہم اسے تیری طرف واپس لوٹا دیں گے اور اسے رسولوں میں سے بنائیں گے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcclx{چنانچہ فرعون کے گھر والوں نے اسے (دریا سے) اٹھا لیا تاکہ وہ ان کیلئے دشمن اور رنج و غم (کا باعث) بنے۔ بیشک فرعون، ہامان اور دونوں کے لشکر والے خطاکار (اور غلط کار) تھے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcclxi{اور فرعون کی بیوی نے (اس سے) کہا کہ یہ (بچہ) تو میری اور تیری آنکھوں کی ٹھنڈک ہے۔ اسے قتل نہ کرو۔ ممکن ہے کہ ہمیں نفع پہنچائے یا ہم اسے اپنا بیٹا ہی بنا لین اور انہیں (انجام کی) کچھ خبر نہ تھی۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcclxii{اور مادرِ موسیٰ کا دل بے چین ہوگیا اور قریب تھا کہ وہ اس (بچہ) کا حال ظاہر کر دے۔ اگر ہم اس کے دل کو مضبوط نہ کرتے تاکہ وہ (ہمارے وعدہ پر) ایمان لانے والوں میں سے ہو۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiii{اور ہم نے اس (بچہ) کی بہن سے کہا کہ تو اس کے پیچھے پیچھے جا۔ چنانچہ وہ دور سے اسے دیکھتی رہی جبکہ ان لوگوں کو خبر بھی نہ ہوئی۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiv{اور ہم نے اس (بچہ) پر دائیوں کو پہلے سے حرام کر دیا تھا تو اس (بچہ کی بہن) نے کہا کیا میں تم لوگوں کو ایک ایسے گھرانے کا پتہ بتاؤں جو تمہارے لئے اس کی پرورش کرے؟ اور وہ اس کے خیرخواہ بھی ہوں؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcclxv{اس طرح ہم نے وہ (بچہ) اس کی ماں کی طرف لوٹا دیا۔ تاکہ اس کی آنکھ ٹھنڈی اور غمناک نہ ہو اور یہ بھی جان لے کہ اللہ کا وعدہ سچا ہوتا ہے لیکن اکثر لوگ (یہ بات) نہیں جانتے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvi{اور جب وہ (بچہ) اپنے پورے شباب کو پہنچ گیا اور (قد و قامت) پورا درست ہوگیا تو ہم نے اس کو (خاص) حکمت و علم عطا کیا اور ہم اسی طرح نیکوکاروں کو صلہ دیتے ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvii{وہ (جوان) ایسے وقت شہر میں داخل ہوا جب کہ اس شہر کے باشندے بے خبر تھے۔ تو اس نے وہاں دو آدمیوں کو آپس میں لڑتے ہوئے پایا۔ یہ ایک ان کے گروہ میں سے تھا۔ اور یہ دوسرا ان کے دشمنوں میں سے تھا پس جو اس کے گروہ میں سے تھا اس نے (موسیٰ) کو اس کے خلاف جو اس کے دشمنوں میں سے تھا مدد کیلئے پکارا تو موسیٰ نے اسے ایک مکا مارا۔ بس اس کا کام تمام کر دیا اور کہا یہ (ان کی لڑائی) شیطان کی کاروائی تھی۔ بےشک وہ کھلا ہوا گمراہ کرنے والا دشمن ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcclxviii{کہا اے میرے پروردگار میں نے اپنے اوپر ظلم کیا تو مجھے بخش دے تو خدا نے اسے بخش دیا۔ بےشک وہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcclxix{(پھر) کہا اے میرے پروردگار تو نے مجھے اپنی نعمت سے نوازا ہے۔ میں کبھی مجرموں کا پشت پناہ نہیں بنوں گا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcclxx{پھر موسیٰ نے شہر میں اس حال میں صبح کی کہ وہ خوف زدہ اور منتظر تھا (کہ کیا ہوتا ہے؟) کہ اچانک دیکھا کہ وہی شخص جس نے کل اس سے مدد طلب کی تھی (آج پھر چیخ کر( اس کو مدد کیلئے پکار رہا ہے موسیٰ نے اس سے کہا کہ تو کھلا ہوا بد راہ ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxi{پھر جب موسیٰ نے اس شخص پر سخت ہاتھ ڈالنا چاہا جو ان دونوں کا دشمن تھا تو اس نے کہا اے موسیٰ تو (آج) مجھے اسی طرح قتل کرنا چاہتا ہے جس طرح کل ایک شخص کو قتل کیا؟ تو بس یہی چاہتا ہے کہ زمین میں سرکش بن جائے اور یہ نہیں چاہتا کہ اصلاح کرنے والوں میں سے ہو۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxii{اور شہر کے آخری حصہ سے ایک آدمی دوڑتا ہوا آیا (اور) کہا اے موسیٰ! قوم کے بڑے لوگ تمہارے بارے میں مشورہ کر رہے ہیں کہ تجھے قتل کر دیں۔ (لہٰذا) یہاں سے نکل جا یقیناً میں تیرے خیر خواہوں میں سے ہوں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiii{چنانچہ موسیٰ وہاں سے خوفزدہ ہوکر نتیجہ کا انتظار کرتا ہوا نکلا (اور) کہا اے میرے پروردگار! مجھے ظالم لوگوں سے نجات عطا فرما۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiv{اور جب موسیٰ نے (مصر سے نکل کر) مدین کا رخ کیا تو کہا امید ہے کہ میرا پروردگار سیدھے راستہ کی طرف میری راہنمائی کرے گا۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxv{اور جب وہ مدین کے پانی (کنویں) پر پہنچا تو وہاں لوگوں کا ایک مجمع پایا جو (اپنے مویشیوں کو) پانی پلا رہا ہے اور ان لوگوں سے الگ دو عورتوں کو پایا کہ وہ (اپنے ریوڑ کو) روکے ہوئے کھڑی ہیں۔ موسیٰ نے کہا تمہارا کیا معاملہ ہے؟ ان دونوں نے کہا ہم اس وقت تک (اپنے جانوروں کو) پانی نہیں پلاتیں جب تک (یہ) چرواہے اپنے مویشیوں کو (پانی پلا کر) نہ لے جائیں اور ہمارے والد بہت بوڑھے ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvi{(یہ سن کر) موسیٰ نے (ان کے ریوڑ کو) پانی پلا دیا اور پھر وہاں سے ہٹ کر سایہ میں آگیا اور کہا اے میرے پروردگار! تو جو خیر (نعمت) بھی مجھ پر اتارے میں اس کا محتاج ہوں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvii{پس ان دو عورتوں مین سے ایک شرم و حیا کے ساتھ چلتی ہوئی اس کے پاس آئی (اور) کہا میرے والد تمہیں بلاتے ہیں تاکہ تمہیں اس کا معاوضہ دیں جو تم نے ہماری خاطر پانی پلایا تو جب موسیٰ اس کے پاس پہنچا اور اسے سارا اپنا قصہ سنایا تو اس (بزرگ) نے (تسلی دیتے ہوئے) کہا خوف نہ کر اب تم ظالم لوگوں سے نجات پا گئے ہو۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxviii{تو ان دو میں سے ایک لڑکی نے کہا اے ابا! اس کو اجرت پر رکھ لیجئے کیونکہ اچھا مزدور جسے آپ اجرت پر رکھیں وہی ہے جو طاقت ور بھی ہو اور امانت دار بھی۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxix{اس (شعیب) نے (موسیٰ سے) کہا کہ میں چاہتا ہوں کہ اپنی دو بیٹیوں میں سے ایک کا عقد نکاح تمہارے ساتھ اس شرط پر کر دوں کہ تم آٹھ سال تک میری خدمت کرو اور اگر دس سال پورے کرو تو یہ تمہاری طرف سے (احسان) ہے اور میں تم پر کوئی سختی نہیں کرنا چاہتا۔ ان شاء اللہ تم مجھے نیکوکار لوگوں میں سے پاؤگے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxx{موسیٰ نے کہا (اچھا) یہ بات میرے اور آپ کے درمیان طے ہوگئی۔ ان دونوں میں سے میں جو مدت بھی پوری کر دوں (اس کے بعد) مجھ پر کوئی زیادتی نہ ہوگی اور ہم جو کچھ کہہ رہے ہیں اللہ اس پر نگہبان ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxi{پھر جب موسیٰ نے (مقررہ) مدت پوری کر دی اور اپنے اہل و (عیال) کو ساتھ لے کر مصر روانہ ہوئے تو طور کی جانب سے آگ محسوس کی تو گھر والوں سے کہا کہ تم ٹھہرو میں نے آگ محسوس کی ہے شاید میں تمہارے پاس (وہاں سے) کوئی خبر لاؤں یا آگ کا کوئی انگارہ لاؤں تاکہ تم تاپو۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxii{تو جب آپ وہاں گئے تو اس وادی کے داہنے کنارے سے اس مبارک مقام پر درخت سے انہیں ندا دی گئی اے موسیٰ! میں ہی اللہ ہوں سارے جہانوں کا پروردگار۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiii{اور یہ کہ تم اپنا عصا پھینک دو تو جب اسے دیکھا کہ اس طرح حرکت کر رہا ہے جیسے وہ سانپ ہے تو وہ منہ موڑ کر الٹے مڑے اور پیچھے مڑ کر بھی نہ دیکھا (آواز آئی) اے موسیٰ! آگے آؤ۔ اور ڈرو نہیں تم (ہر طرح) امن میں ہو۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiv{(اور) اپنا ہاتھ اپنے گریبان میں ڈالو وہ بغیر کسی تکلیف (اور بیماری) کے سفید چمکتا ہوا نکلے گا اور رفع خوف کیلئے اپنا بازو اپنی طرف سمیٹ لو یہ تمہارے پروردگار کی طرف سے دو نشانیاں ہیں فرعون اور اس کے سرداروں کے سامنے پیش کرنے کیلئے۔ بیشک وہ (بڑے) نافرمان لوگ ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxv{موسیٰ نے کہا اے میرے پروردگار! میں نے ان کا ایک آدمی قتل کیا تھا ڈرتا ہوں کہ وہ مجھے قتل کر دیں گے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvi{اور میرا بھائی ہارون جو مجھ سے زیادہ فصیح اللسان ہے تو اسے میرا مددگار بنا کر میرے ساتھ بھیج تاکہ وہ میری تصدیق کرے کیونکہ مجھے اندیشہ ہے کہ وہ مجھے جھٹلائیں گے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvii{ارشاد ہوا: ہم تمہارے بازو کو تمہارے بھائی کے ذریعہ سے مضبوط کریں گے اور ہم تم دونوں کو غلبہ عطا کریں گے کہ وہ تم تک پہنچ بھی نہیں سکیں گے۔ ہماری نشانیوں کی برکت سے تم اور تمہارے پیروکار ہی غالب آئیں گے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxviii{تو جب موسیٰ ان لوگوں کے پاس کھلی ہوئی نشانیوں کے ساتھ آئے تو انہوں نے کہا یہ نہیں ہے مگر گھڑا ہوا جادو اور یہ باتیں تو ہم نے اپنے باپ داداؤں کے زمانہ میں بھی نہیں سنیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxix{اور موسیٰ نے کہا میرا پروردگار بہتر جانتا ہے کہ اس کی طرف سے کون ہدایت لے کر آیا ہے اور کس کیلئے دار آخرت کا انجام بخیر ہے؟ بیشک ظالم لوگ کبھی فلاح نہیں پاتے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccxc{اور فرعون نے کہا اے سردارو! میں تو اپنے سوا تمہارے لئے کوئی خدا نہیں جانتا تو اے ہامان! تو میرے لئے مٹی کو آگ میں پکا (مٹی کو کچی اینٹوں کو پکوا) پھر میرے لئے ایک بلند عمارت بنوا۔ تاکہ میں (اس پر چڑھ کر) موسیٰ کے خدا کا کوئی سراغ لگا سکوں اور میں تو اسے (اس دعویٰ میں) جھوٹا ہی خیال کرتا ہوں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccxci{اور فرعون اور اس کی فوجوں نے زمین میں ناحق تکبر کیا اور انہوں نے خیال کیا کہ وہ ہماری طرف نہیں لوٹائے جائیں گے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccxcii{سو ہم نے اسے اور اس کی فوجوں کو پکڑا اور سمندر میں پھینک دیا تو دیکھو ظالموں کا کیسا انجام ہوا؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccxciii{اور ہم نے انہیں ایسا پیشوا قرار دیا ہے جو (لوگوں کو) آتش (دوزخ) کی طرف بلاتے ہیں اور قیامت کے دن ان کی کوئی مدد نہ کی جائے گی۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccxciv{اور ہم نے اس دنیا میں ان کے پیچھے لعنت لگا دی ہے اور قیامت کے دن قبیح المنظر لوگوں میں سے ہوں گے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccxcv{اور پہلی امتوں کو ہلاک کرنے کے بعد بالیقین ہم نے موسیٰ کو کتاب عطا کی جو لوگوں کیلئے بصیرتوں کا مجموعہ اور سراپا ہدایت و رحمت تھی تاکہ وہ نصیحت حاصل کریں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvi{اور (اے رسول(ص)) آپ (کوہِ طور کی) مغربی جانب موجود نہ تھے جب ہم نے موسیٰ سے (نبوت و رسالت) کا معاملہ طے کیا تھا اور نہ ہی آپ وہاں حاضرین میں سے تھے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvii{لیکن ہم نے (اس اثناء میں) کئی نسلیں پیدا کیں اور ان پر زمانہ دراز گزر گیا ہے (اور ہمارے عہد و پیمان کو بھلا دیا) اور نہ ہی آپ مدین والوں میں مقیم تھے کہ ان کو ہماری آیتیں پڑھ کر سناتے لیکن ہم (آپ کو) رسول بنا کر بھیجنے والے تھے (اس لئے ان کے حالات سے آپ کو آگاہ کیا)۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccxcviii{اور نہ آپ کوہ طور کے دامن میں موجود تھے جب ہم نے (موسیٰ کو) ندا دی تھی لیکن یہ (آپ کا مبعوث برسالت ہونا) آپ کے پروردگار کی رحمت ہے تاکہ آپ اس قوم کو ڈرائیں جس کے پاس آپ سے پہلے کوئی ڈرانے والا نہیں آیا تاکہ وہ نصیحت حاصل کریں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccxcix{(اور شاید ہم رسول نہ بھیجتے) اگر یہ بات نہ ہوتی کہ اگر ان کے کرتوتوں کی پاداش میں انہیں کوئی مصیبت پہنچے تو وہ یہ نہ کہنے لگ جائیں کہ اے ہمارے پروردگار تو نے ہماری طرف کوئی رسول کیوں نہ بھیجا تاکہ ہم تیری آیتوں کی پیروی کرتے اور ہم ایمان لانے والوں میں سے ہوتے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccc{جب ہماری طرف سے ان کے پاس حق آگیا (آخری برحق رسول آگیا) تو کہنے لگے اس (رسول) کو وہ کچھ کیوں نہ دیا گیا جو موسیٰ کو دیا گیا تھا کیا انہوں نے اس کا انکار نہیں کیا تھا؟ وہ کہتے ہیں کہ یہ دونوں جادوگر ہیں جو ایک دوسرے کی مدد کرتے ہیں اور کہتے تھے کہ ہم ہر ایک کے منکر ہیں۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccci{آپ کہیے! کہ تم سچے ہو تو اللہ کی طرف سے کوئی ایسی کتاب لاؤ جو ان دونوں (توراۃ، قرآن) سے زیادہ ہدایت کرنے والی ہو تو میں اسی کی پیروی کروں گا۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccii{اور اگر وہ آپ کی یہ بات قبول نہ کریں تو پھر سمجھ لیں کہ وہ صرف اپنی نفسانی خواہشوں کی پیروی کرتے ہیں اور اس شخص سے بڑھ کر گمراہ کون ہوگا جو خدائی ہدایت کے بغیر اپنی خواہش نفس کی پیروی کرے؟ بےشک خدا ظالم لوگوں کو ہدایت نہیں کرتا۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccciii{اور ہم نے ان کیلئے کلام (ہدایت نظام) کا تسلسل جاری رکھا تاکہ وہ نصیحت حاصل کریں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccciv{جن کو ہم نے اس (نزولِ قرآن) سے پہلے کتاب عطا کی وہ اس پر ایمان لاتے ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccv{اور جب یہ (قرآن) ان کے سامنے پڑھا جاتا ہے تو وہ کہتے ہیں کہ ہم اس پر ایمان لائے بےشک یہ ہمارے پروردگار کی طرف سے حق ہے اور ہم تو اس سے پہلے ہی مسلم (اسے ماننے والے) ہیں۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccvi{یہ وہ لوگ ہیں جنہیں ان کے صبر و ثبات کی وجہ سے دوہرا اجر عطا کیا جائے گا اور وہ برائی کا دفعیہ بھلائی سے کرتے ہیں اور ہم نے انہیں جو رزق دے رکھا ہے وہ اس میں سے (راہِ خدا میں) خرچ کرتے ہیں۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccvii{اور وہ جب کوئی فضول بات سنتے ہیں تو اس سے روگردانی کرتے ہیں اور کہتے ہیں کہ ہمارے اعمال ہمارے لئے ہیں اور تمہارے اعمال تمہارے لئے! تم کو سلام! ہم جاہلوں کو پسند نہیں کرتے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccviii{(اے رسول(ص)) آپ جسے چاہیں اسے ہدایت نہیں کر سکتے لیکن اللہ جسے چاہتا ہے اسے ہدایت دے دیتا ہے اور وہ ہدایت پانے والوں کو بہتر جانتا ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccix{اور وہ (کفارِ مکہ) کہتے ہیں کہ اگر ہم آپ کے ساتھ ہدایت کی پیروی کریں تو ہمیں اپنی سر زمین سے اچک لیا جائے گا (یہاں سے نکال دیا جائے گا) کیا ہم نے ان کو ایسے امن والے محترم مقام میں جگہ نہیں دی؟ جہاں ہماری طرف سے رزق کے طور پر ہر قسم کے پھل لائے جاتے ہیں مگر ان میں سے اکثر لوگ جانتے نہیں ہیں۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccx{اور ہم نے کتنی ہی ایسی بستیاں ہلاک کر دیں جو اپنی معیشت (خوشحالی) پر اترا گئی تھیں (دیکھو) یہ ان کے مکانات ہیں جو (اجڑے) پڑے ہیں جو ان کے بعد کم ہی آباد ہوئے ہیں آخرکار ہم ہی وارث ہیں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxi{اور آپ کا پروردگار بستیوں کو ہلاک کرنے والا نہیں ہے جب تک ان کے مرکزی مقام میں کوئی رسول نہ بھیج دے جو ہماری آیتوں کی تلاوت کرے اور ہم بستیوں کو ہلاک کرنے والے نہیں ہیں جب تک ان کے باشندے ظالم نہ ہوں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcccxii{اور تمہیں جو کچھ بھی دیا گیا ہے یہ محض زندگانی دنیا کا سرمایہ ہے اور اسی کی زیب و زینت اور جو کچھ اللہ کے پاس ہے وہ بہتر ہے اور زیادہ پائیدار بھی تم عقل سے کیوں کام نہیں لیتے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiii{کیا وہ شخص جس سے ہم نے اچھا وعدہ کیا ہے اور وہ اسے پانے والا بھی ہے۔ اس شخص کی مانند ہو سکتا ہے جسے ہم نے صرف دنیوی زندگانی کا (چند روزہ) سامان دیا ہے۔ اور پھر قیامت کے دن (سزا کیلئے پکڑ کر) حاضر کیا جائے گا۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiv{اور (وہ دن یاد رکھو) جس دن اللہ انہیں پکارے گا اور فرمائے گا (آج) کہاں ہیں میرے وہ شریک جن کو تم (میرا شریک) گمان کرتے تھے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcccxv{جن پر خدا کا حکم (عذاب) نافذ ہو چکا ہوگا۔ کہیں گے اے ہمارے پروردگار! یہ ہیں وہ لوگ جنہیں ہم نے گمراہ کیا تھا ہم نے انہیں اسی طرح گمراہ کیا تھا جیسے ہم خود گمراہ تھے (اب) ہم تیری بارگاہ میں (ان سے) برأت کا اظہار کرتے ہیں کہ یہ ہماری پرستش نہیں کیا کرتے تھے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvi{پھر (ان سے) کہا جائے گا کہ اپنے (مزعومہ) شریکوں کو بلاؤ چنانچہ وہ انہیں پکاریں گے مگر وہ انہیں کوئی جواب نہیں دیں گے۔ اور عذاب کو دیکھیں گے (اس پر وہ تمنا کریں گے کہ) کاش وہ ہدایت یافتہ ہوتے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvii{اور (وہ دن یاد کرو) جس دن اللہ انہیں پکارے گا اور کہے گا کہ تم نے پیغمبروں کو کیا جواب دیا تھا؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcccxviii{اس دن ان پر خبریں تاریک ہو جائیں گی (کوئی جواب نہ بن پڑے گا) اور نہ ہی یہ آپس میں ایک دوسرے سے پوچھ گچھ کر سکیں گے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcccxix{البتہ جو توبہ کرے اور ایمان لائے اور نیک عمل کرے تو امید ہے کہ وہ فلاح پانے والوں میں سے ہوگا۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcccxx{اور (اے رسول) آپ کا پروردگار جو چاہتا ہے پیدا کرتا ہے اور (جسے چاہتا ہے) منتخب کرتا ہے لوگوں کو کوئی اختیار نہیں ہے اللہ پاک ہے اور جو وہ شرک کرتے ہیں وہ اس سے بلند و برتر ہے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxi{اور آپ کا پروردگار جانتا ہے وہ جو کچھ ان کے سینے چھپائے ہوئے ہیں اور وہ بھی جو وہ ظاہر کرتے ہیں۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxii{وہی (ایک) اللہ ہے اس کے سوا کوئی اللہ نہیں ہے اسی کیلئے ہر قسم کی تعریف ہے دنیا میں بھی اور آخرت میں بھی اور اسی کی حکومت (فرمانروائی) ہے اور تم اسی کی طرف لوٹائے جاؤگے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiii{آپ کہئے آیا تم نے کبھی غور کیا ہے کہ اگر اللہ قیامت تک تم پر رات مقرر (مسلط) کر دے تو اللہ کے سوا کون الہ ہے جو تمہارے پاس روشنی لائے؟ کیا تم سنتے نہیں ہو؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiv{اور کہئے! آیا تم نے کبھی غور کیا ہے کہ اگر قیامت تک تم پر دن مقرر (مسلط) کر دے تو اللہ کے سوا کون الٰہ ہے جو تمہارے پاس رات لائے جس میں تم آرام کرو کیا تم دیکھتے نہیں ہو؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxv{اور اس نے اپنی (خاص) رحمت سے تمہارے لئے رات اور دن بنائے تاکہ (رات میں) آرام کرو۔ اور (دن میں) اس کا فضل (روزی) تلاش کرو اور تاکہ تم شکر گزار بنو۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvi{اور (یاد کرو) وہ دن جس میں اللہ ان (مشرکین) کو پکارے گا اور کہے گا کہاں ہیں میرے شریک جن کے متعلق تم گمان فاسد کیا کرتے تھے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvii{اور ہم ہر امت میں سے ایک گواہ نکال کر لائیں گے پھر ان سے کہیں گے کہ اپنی دلیل و برہان لاؤ تب انہیں معلوم ہوگا کہ حق اللہ ہی کیلئے ہے اور وہ جو افتراء پردازیاں کیا کرتے تھے وہ سب ان سے غائب ہو جائیں گی۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxviii{بےشک قارون موسیٰ کی قوم میں سے تھا پھر وہ ان کے خلاف سرکش ہوگیا۔ اور ہم نے اسے اتنے خزانے عطا کئے تھے کہ اس کی چابیاں ایک طاقتور جماعت کو بھی گرانبار کر دیتی تھیں (اس سے مشکل سے اٹھتی تھیں) جبکہ اس کی قوم نے اس سے کہا کہ (اپنی منزلت پر) مت اترا بےشک اللہ اترانے والوں کو دوست نہیں رکھتا۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxix{اور اللہ نے تجھے جو کچھ (مال و زر) دیا ہے۔ اس سے آخرت کے گھر کی جستجو کر اور دنیا سے بھی اپنا حصہ فراموش نہ کر۔ اور جس طرح اللہ نے تیرے ساتھ احسان کیا ہے تو بھی اسی طرح (اس کے بندوں کے ساتھ) احسان کر۔ اور زمین میں فساد برپا کرنے کی خواہش نہ کر یقیناً اللہ فساد برپا کرنے والوں کو دوست نہیں رکھتا۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxx{قارون نے کہا کہ مجھے جو کچھ (مال و منال) ملا ہے وہ اس (خاص) علم کی بدولت ملا ہے جو میرے پاس ہے کیا وہ یہ نہیں جانتا کہ اللہ نے اس سے پہلے بہت سی ایسی نسلوں کو ہلاک کر دیا ہے جو قوت میں اس سے سخت تر اور جمعیت میں زیادہ تھیں اور مجرموں سے ان کے گناہوں کے بارے میں سوال نہیں کرنا پڑتا۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxi{وہ (ایک دن) اپنی قوم کے سامنے اپنی زیب و زینت کے ساتھ نکلا تو جو لوگ دنیاوی زندگی کے طلبگار تھے وہ کہنے لگے کہ کاش ہمیں بھی وہ (ساز و سامان) ملتا جو قارون کو دیا گیا ہے۔ بیشک وہ بڑا نصیب والا ہے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxii{اور جن لوگوں کو علم دیا گیا تھا انہوں نے کہا وائے ہو تم پر! جو شخص ایمان لائے اور نیک عمل کرے اس کیلئے اللہ کا صلہ و ثواب اس سے بہتر ہے اور یہ (حکمت و منزلت) صرف صبر و ثبات کرنے والوں کو مرحمت کی جاتی ہے۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiii{پھر ہم نے قارون کو اور اس کے گھر کو زمین میں دھنسا دیا سو نہ اس کے حامیوں کی کوئی جماعت تھی جو اللہ کے مقابلہ میں اس کی مدد کرتی اور نہ ہی وہ اپنی مدد آپ کر سکا۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiv{اور وہ لوگ جو کل اس کے جاہ و مرتبہ کی تمنا کر رہے تھے اب کہنے لگے افسوس (اب پتہ چلا) کہ اللہ اپنے بندوں میں سے جس کا رزق چاہتا ہے کشادہ کر دیتا ہے اور جس کا چاہتا ہے تنگ کر دیتا ہے۔ اگر اللہ ہم پر (تنگدست بنا کر) احسان نہ کرتا تو ہمیں بھی زمین میں دھنسا دیتا اور کافر کبھی فلاح نہیں پاتے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxv{یہ آخرت کا گھر ہم ان لوگوں کیلئے قرار دیتے ہیں جو زمین میں تکبر و سرکشی اور فساد برپا کرنے کا ارادہ بھی نہیں کرتے اور (نیک) انجام تو پرہیزگاروں کے ہی لئے ہے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvi{جو کوئی بھلائی لے کر آئے گا اسے اس سے بہتر صلہ ملے گا اور جو کوئی برائی لے کر آئے گا تو ایسے لوگوں کو جو برائیاں کرتے ہیں تو انہیں بدلہ بھی اتنا ہی ملے گا جتنا وہ (برائی) کرتے تھے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvii{(اے رسول(ص)) جس (خدا) نے آپ پرقرآن (کا پہنچانا) فرض کیا ہے وہ آپ کو واپسی کی منزل (مکہ) تک پھر پہنچا کر رہے گا۔ آپ کہئے! میرا پروردگار بہتر جانتا ہے کہ ہدایت لے کر کون آیا ہے اور کھلی ہوئی گمراہی میں کون ہے؟\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxviii{اور آپ کو اس بات کی امید نہیں تھی کہ آپ پر (یہ) کتاب نازل کی جائے گی۔ یہ تو بس آپ کے پروردگار کی رحمت ہے۔ لہٰذا آپ بھی کافروں کے پشت پناہ نہ بنئے گا۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxix{اور (خیال رکھنا) کہ یہ لوگ آپ کو اللہ کی آیتوں (کی تبلیغ) سے کہیں روک نہ دیں بعد اس کے کہ وہ آپ پر نازل ہو چکی ہیں اور آپ اپنے پروردگار کی طرف (لوگوں کو) بلائیں اور ہرگز مشرکوں میں سے نہ ہونا۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmcccxl{اور اللہ کے ساتھ کسی اور الٰہ کو نہ پکاریں اس کے سوا کوئی الٰہ نہیں ہے ہر شئ ہلاک ہونے والی ہے سوائے اس کے وجہ (ذات) کے اسی کی حکومت (اور فرمانروائی) ہے اور اسی کی طرف تم (سب) لوٹائے جاؤگے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmcccxli{\basmalahur الف۔ لام۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlii{کیا لوگوں نے یہ گمان کر رکھا ہے کہ ان کے (زبانی) کہنے سے کہ ہم ایمان لے آئے ہیں چھوڑ دیئے جائیں گے اور ان کی آزمائش نہیں کی جائیگی؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliii{حالانکہ ہم نے ان (سب) کی آزمائش کی تھی جو ان سے پہلے گزر چکے ہیں سو اللہ ضرور معلوم کرے گا ان کو جو (دعوائے ایمان میں) سچے ہیں اور ان کو بھی معلوم کرے گا جو جھوٹے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliv{جو لوگ برے کام کرتے ہیں کیا انہوں نے یہ گمان کر رکھا ہے کہ وہ ہم سے آگے نکل جائیں گے؟ وہ کتنا برا حکم لگاتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlv{جو کوئی اللہ کے حضور حاضری کی امید رکھتا ہے تو بیشک اللہ کا مقررہ وقت ضرور آنے والا ہے اور وہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvi{اور جو کوئی جہاد کرتا ہے تو وہ اپنے ہی لئے جہاد کرتا ہے۔ بےشک اللہ تمام جہانوں سے بے نیاز ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvii{اور جو لوگ ایمان لائے اور نیک عمل بھی کئے تو ہم ان کی برائیاں دور کر دیں گے (ان کی غلطیوں کو نظر انداز کر دیں گے) اور ہم انہیں ان کے اعمال کی بہترین جزا دیں گے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlviii{اور ہم نے انسان کو وصیت کی ہے یعنی حکم دیا ہے کہ وہ اپنے والدین کے ساتھ اچھا سلوک کرے اور (یہ بھی کہ) اگر وہ تجھ پر زور ڈالیں کہ تو کسی ایسی چیز کو میرا شریک بنا جس کا تجھے کوئی علم نہیں ہے تو پھر ان کی اطاعت نہ کر تم سب کی بازگشت میری ہی طرف ہے تو میں تمہیں بتاؤں گا جو کچھ تم کیا کرتے تھے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlix{اور جو لوگ ایمان لائے اور نیک عمل بھی بجا لائے ہم ضرور انہیں صالحین میں داخل کریں گے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcccl{اور لوگوں میں سے کچھ ایسے بھی ہیں جو (زبان سے) کہتے ہیں کہ ہم اللہ پر ایمان لائے پھر اللہ کی راہ میں جب اسے اذیت پہنچائی جاتی ہے تو وہ ان لوگوں کی آزمائش کو اللہ کے عذاب کے مانند قرار دے دیتا ہے اور اگر آپ کے پروردگار کی طرف سے کوئی مدد پہنچ جائے تو وہ کہتے ہیں کہ ہم (بھی) تو تمہارے ساتھ تھے کیا جو کچھ دنیا جہاں والوں کے دلوں میں ہے کیا اللہ اس کا سب سے بہتر جاننے والا نہیں ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcccli{اور اللہ ضرور معلوم کرے گا کہ مؤمن کون ہیں اور منافق کون؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmccclii{اور کافر لوگ اہلِ ایمان سے کہتے ہیں کہ تم ہمارے راستہ پر چلو تمہارے گناہوں (کا بوجھ) ہم اٹھائیں گے۔ حالانکہ یہ ان کے گناہوں کو کچھ بھی اٹھانے والے نہیں وہ بالکل جھوٹے ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcccliii{(ہاں البتہ) یہ لوگ اپنے بوجھ اٹھائیں گے اور اپنے بوجھوں کے ساتھ کچھ اور بوجھ بھی۔ اور قیامت کے دن ضرور ان سے بازپرس کی جائے گی ان افترا پردازیوں کے بارے میں جو وہ کرتے تھے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcccliv{اور یقیناً ہم نے نوح کو ان کی قوم کی طرف بھیجا اور وہ اس میں پچاس سال کم ایک ہزار سال رہے پھر (آخرکار) اس قوم کو طوفان نے آپکڑا اس حال میں کہ وہ ظالم تھے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmccclv{پس ہم نے نوح کو اور کشتی والوں کو نجات دی اور اس (کشتی) کو تمام جہانوں کیلئے (اپنی ایک) نشانی بنا دیا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmccclvi{اور (ہم نے) ابراہیم کو (بھیجا) جبکہ انہوں نے اپنی قوم سے کہا کہ اللہ کی عبادت کرو اور اس (کی نافرمانی) سے ڈرو اگر تم کچھ سمجھ رکھتے ہو تو یہ تمہارے لئے بہتر ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmccclvii{تم اللہ کو چھوڑ کر محض بتوں کی پرستش کرتے ہو اور تم ایک جھوٹ گھڑتے ہو۔ بےشک یہ جن کی تم اللہ کو چھوڑ کر عبادت کرتے ہو وہ تمہاری روزی کے مالک و مختار نہیں ہیں۔ پس تم اللہ سے روزی طلب کرو اور اسی کی عبادت کرو اور اسی کا شکر ادا کرو۔ اور اسی کی طرف تم لوٹائے جاؤگے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmccclviii{اور اگر تم (مجھے) جھٹلاتے ہو (تو یہ کوئی نئی بات نہیں ہے) تم سے پہلے بھی کئی امتیں (اپنے پیغمبروں کو) جھٹلا چکی ہیں اور رسول کی ذمہ داری صرف واضح تبلیغ کرنا ہے۔ و بس۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmccclix{کیا ان لوگوں نے نہیں دیکھا کہ اللہ کس طرح پہلی بار مخلوق کو پیدا کرتا ہے پھر کس طرح اسے دوبارہ پلٹاتا ہے؟ بےشک یہ بات اللہ کیلئے آسان ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmccclx{آپ کہئے! کہ زمین میں چلو پھرو پھر (غور سے) دیکھو کہ اللہ نے کس طرح مخلوق کو پہلی بار پیدا کیا؟ پھر (اسی طرح) اللہ پچھلی بار بھی پیدا کرے گا۔ بےشک اللہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmccclxi{وہ جسے چاہتا ہے سزا دیتا ہے اور جس پر چاہتا ہے رحم کرتا ہے اور اسی کی طرف تم سب لوٹائے جاؤگے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmccclxii{اور تم (اللہ کو) نہ زمین میں عاجز کر سکتے ہو اور نہ آسمان میں اور نہ ہی اللہ کے سوا تمہارا کوئی سرپرست و کارساز ہے اور نہ ہی کوئی مددگار۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiii{اور جن لوگوں نے اللہ کی آیتوں اور اس کی بارگاہ میں حاضری کا انکار کیا ہے وہ میری رحمت سے مایوس ہوگئے ہیں اور ان کیلئے دردناک عذاب ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiv{اور ان (ابراہیم) کی قوم کا جواب اس کے سوا اور کوئی نہیں تھا کہ انہیں قتل کر دو یا آگ میں جلا دو تو اللہ نے انہیں آگ سے بچا لیا۔ بےشک اس میں ایمان لانے والوں کیلئے (بڑی) نشانیاں ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmccclxv{اور ابراہیم نے (اپنی قوم سے) کہا کہ تم نے اللہ کو چھوڑ کر زندگانی دنیا میں باہمی محبت کا ذریعہ سمجھ کر ان بتوں کو اختیار کر رکھا ہے پھر قیامت کے دن تم ایک دوسرے کا انکار کروگے اور ایک دوسرے پر لعنت کروگے اور تمہارا ٹھکانہ دوزخ ہوگا۔ اور تمہارا کوئی مددگار نہ ہوگا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvi{اور لوط نے ان (ابراہیم) کی بات مانی اور اطاعت کی اور انہوں نے کہا میں اپنے پروردگار کی طرف ہجرت کرنے والا ہوں۔ بیشک وہ غالب (اور) بڑا حکمت والا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvii{اور ہم نے انہیں اسحاق اور یعقوب عطا کئے۔ اور نبوت اور کتاب ان کی نسل میں قرار دے دی۔ اور ہم نے ان کو دنیا میں بھی ان کا صلہ دیا اور آخرت میں یقیناً وہ صالحین میں سے ہوں گے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmccclxviii{اور (ہم نے) لوط کو (بھیجا) جبکہ انہوں نے اپنی قوم سے کہا کہ تم بے حیائی کا وہ کام کرتے ہو جو تم سے پہلے دنیا جہان والوں میں سے کسی نے نہیں کیا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmccclxix{کیا تم (عورتوں کو چھوڑ کر) مردوں کے پاس جاتے ہو؟ اور راہزنی کرتے ہو اور اپنے مجمع میں برے کام کرتے ہو۔ تو ان کی قوم کے پاس اس کے سوا کوئی جواب نہ تھا کہ انہوں نے کہا (اے لوط) اگر تم سچے ہو تو ہم پر اللہ کا عذاب لاؤ۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmccclxx{لوط نے کہا اے میرے پروردگار! ان مفسد لوگوں کے مقابلہ میں میری مدد فرما۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxi{اور جب ہمارے بھیجے ہوئے (فرشتے) ابراہیم کے پاس خوشخبری لے کر آئے۔ تو انہوں نے (اثنائے گفتگو میں یہ بھی) کہا کہ ہم اس (لوط کی) بستی والوں کو ہلاک کرنے والے ہیں (کیونکہ) اس بستی کے لوگ (بڑے) ظالم ہیں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxii{ابراہیم نے کہا اس بستی میں تو لوط بھی ہیں؟ فرشتوں نے کہا ہم بہتر جانتے ہیں کہ اس میں کون کون ہیں؟ ہم انہیں اور ان کے گھر والوں کو بچا لیں گے۔ سوائے ان کی بیوی کے کہ وہ پیچھے رہ جانے والوں میں سے ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiii{اور جب (وہ) ہمارے بھیجے ہوئے (فرشتے) لوط کے پاس آئے تو وہ ان کی آمد سے رنجیدہ اور دل تنگ ہوئے اور فرشتوں نے (ان کی حالت دیکھ کر) کہا کہ نہ ڈرو اور نہ رنج کرو ہم آپ کو اور آپ کے گھر والوں کو بچا لیں گے سوائے آپ کی بیوی کے جو پیچھے رہ جانے والوں میں سے ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiv{ہم اس بستی والوں پر ان کی نافرمانیوں کی وجہ سے آسمان سے عذاب نازل کرنے والے ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxv{اور ہم نے اس بستی کے کچھ نشان باقی چھوڑ دیئے (ان لوگوں کی عبرت کیلئے) جو عقل سے کام لیتے ہیں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvi{اور ہم نے مدین (والوں) کی طرف ان کے بھائی شعیب کو بھیجا۔ تو انہوں نے کہا: اے میری قوم! اللہ کی عبادت کرو اور روز آخرت کی امید رکھو۔ اور زمین میں فساد پھیلاتے نہ پھرو۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvii{پس ان لوگوں نے آپ کو جھٹلایا تو (انجام کار) ایک (سخت) زلزلے نے انہیں آپکڑا اور وہ اپنے گھروں میں گھٹنوں کے بل (مردہ ہوکر) گر گئے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxviii{اور ہم نے عاد و ثمود کو بھی ہلاک کر دیا۔ اور (یہ بات) ان کے (تباہ شدہ) مکانات سے واضح ہو چکی ہے اور شیطان نے ان کے (برے) کاموں کو خوشنما کرکے پیش کیا اور انہیں (سیدھے) راستہ سے روک دیا۔ حالانکہ وہ سمجھ دار تھے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxix{اور ہم نے قارون، فرعون اور ہامان کو (بھی ہلاک کیا) اور البتہ موسیٰ ان کے پاس کھلی نشانیاں لے کر آئے۔ مگر انہوں نے زمین میں تکبر و غرور کیا حالانکہ وہ (ہم سے) آگے نکل جانے والے نہیں تھے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxx{پس ہم نے ہر ایک کو اس کے گناہ کی پاداش میں پکڑا۔ سو ان میں سے بعض پر (پتھراؤ کرنے والی) تیز آندھی بھیجی اور بعض کو ہولناک چنگھاڑ نے آدبایا اور بعض کو ہم نے زمین میں دھنسایا اور بعض کو (دریا میں) غرق کر دیا اور اللہ ایسا نہ تھا کہ ان پر ظلم کرتا بلکہ وہ خود اپنے اوپر ظلم کرتے تھے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxi{جن لوگوں نے اللہ کو چھوڑ کر اور سرپرست اور کارساز بنا لئے ہیں ان کی مثال مکڑی جیسی ہے جس نے (جالے کا) ایک گھر بنایا اور یقیناً تمام گھروں سے زیادہ کمزور مکڑی کا گھر ہے۔ کاش لوگ (یہ حقیقت) جانتے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxii{اللہ کو چھوڑ کر یہ لوگ جس شئے کو پکارتے ہیں۔ بےشک اللہ اسے جانتا ہے۔ وہ غالب ہے، بڑا حکمت والا ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiii{اور یہ مثالیں ہم پیش تو سب لوگوں کے سامنے کرتے ہیں مگر انہیں سمجھتے صرف اہل علم ہیں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiv{اللہ نے آسمانوں اور زمین کو حق کے ساتھ پیدا کیا ہے۔ بےشک اس میں اہلِ ایمان کیلئے (اس کی قدرت کی) ایک نشانی موجود ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxv{(اے رسول(ص)) آپ اس (کتاب) کی تلاوت کریں جو آپ کی طرف وحی کی گئی ہے اور نماز قائم کریں۔ بے شک نماز بے حیائی اور برائی سے روکتی ہے اور اللہ کا ذکر سب سے بڑی چیز ہے اور جو کچھ تم کرتے ہو اللہ اسے جانتا ہے.\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvi{اور (اے مسلمانو!) تم اہلِ کتاب سے بحث و مباحثہ نہ کرو مگر بہترین انداز سے سوائے ان کے جو ان میں سے ظالم ہیں اور (ان سے) کہو کہ ہم تو اس (کتاب) پر بھی ایمان لائے ہیں جو ہماری طرف نازل کی گئی ہے اور اس (کتاب پر بھی) جو تمہاری طرف نازل کی گئی ہے اور ہمارا اور تمہارا الٰہ (اللہ) ایک ہے اور ہم سب اسی کے فرمانبردار ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvii{اور (اے رسول(ص)) ہم نے اسی طرح آپ پر کتاب نازل کی ہے (جس طرح پہلے رسولوں پر کتابیں نازل کی تھیں) تو جن کو ہم نے (پہلے) کتاب دی تھی وہ اس (قرآن) پر ایمان لاتے ہیں اور ان (اہلِ مکہ و عرب) میں سے بھی بعض اس پر ایمان لا رہے ہیں اور ہماری آیتوں کا کافروں کے سوا اور کوئی انکار نہیں کرتا۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxviii{اور (اے رسول(ص)) آپ اس (نزولِ قرآن) سے پہلے نہ کوئی کتاب پڑھتے تھے اور نہ ہی اپنے دائیں ہاتھ سے کچھ لکھتے تھے اگر ایسا ہوتا تو یہ اہلِ باطل ضرور (آپ کی نبوت میں) شک کرتے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxix{بلکہ وہ (قرآن) کھلی ہوئی آیتیں ہیں جو ان لوگوں کے سینہ میں ہیں جنہیں علم دیا گیا ہے اور ہماری آیتوں کا ظالموں کے سوا اور کوئی انکار نہیں کرتا۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccxc{اور وہ کہتے ہیں کہ اس شخص (پیغمبرِ اسلام(ص)) پر ان کے پروردگار کی طرف سے معجزات کیوں نہیں اتارے گئے؟ آپ کہہ دیجئے! کہ معجزات تو بس اللہ کے پاس ہیں میں تو صرف (عذابِ الٰہی) سے واضح طور پر ڈرانے والا ہوں۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcccxci{کیا ان کیلئے یہ (معجزہ) کافی نہیں ہے کہ ہم نے آپ پر (یہ) کتاب نازل کی ہے۔ جو انہیں پڑھ کر سنائی جاتی ہے؟ بے شک اس میں ایمان والوں کیلئے رحمت اور نصیحت موجود ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcii{(اے رسول(ص)) آپ کہہ دیجئے! کہ میرے اور تمہارے درمیان گواہی کیلئے اللہ کافی ہے جو کچھ آسمانوں اور زمین میں ہے وہ سب کچھ جانتا ہے اور جو لوگ باطل پر ایمان لاتے ہیں اور اللہ کا ذکر کرتے ہیں وہی نقصان اٹھانے والے ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciii{اور یہ لوگ آپ سے جلدی عذاب لانے کا مطالبہ کرتے ہیں حالانکہ اگر (اس کیلئے) ایک وقتِ مقرر نہ ہوتا تو ان پر (کبھی کا) عذاب آچکا ہوتا۔ اور وہ اس طرح ان پر اچانک آپڑے گا کہ انہیں خبر بھی نہ ہوگی۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciv{وہ آپ سے جلدی عذاب لانے کا مطالبہ کرتے ہیں حالانکہ جہنم کافروں کو گھیرے ہوئے ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcv{جس دن عذاب ان کو اوپر سے اور پاؤں کے نیچے سے ڈھانک لے گا اور خدا کہے گا کہ (اب) مزہ چکھو اس کا جو کچھ تم (دنیا میں) کرتے رہے ہو (تب ان کو پتہ چلے گا)۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvi{اے میرے وہ بندو جو ایمان لائے ہو! میری زمین (بہت) وسیع ہے۔ پس تم میری ہی عبادت کرو۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvii{ہر نفس موت کا مزہ چکھنے والا ہے پھر تم سب ہماری طرف لوٹائے جاؤگے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcviii{اور جو لوگ ایمان لائے اور نیک عمل کئے ہم ان کو جنت کے بالا خانوں میں جگہ دیں گے جن کے نیچے نہریں جاری ہوں گی (اور) وہ ان میں ہمیشہ رہیں گے کیا اچھا اجر ہے (نیک) عمل کرنے والوں کا۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcix{جنہوں نے صبر کیا اور اپنے پروردگار پر بھروسہ کرتے ہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcd{اور کتنے زمین پر چلنے والے (جانور) ایسے ہیں جو اپنا رزق اٹھائے نہیں پھرتے اللہ ہی انہیں رزق دیتا ہے اور تمہیں بھی۔ اور وہ بڑا سننے والا (اور) بڑا جاننے والا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdi{اور اگر آپ ان (مشرکوں) سے پوچھیں کہ آسمانوں اور زمین کو کس نے پیدا کیا ہے؟ اور سورج اور چاند کو کس نے مسخر کیا ہے؟ تو وہ ضرور کہیں گے کہ اللہ نے۔ تو پھر وہ کدھر جا رہے ہیں؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcdii{اللہ ہی اپنے بندوں میں سے جس کو چاہتا ہے روزی کشادہ کر دیتا ہے اور جس کی چاہتا ہے تنگ کر دیتا ہے۔ بے شک اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcdiii{اور اگر آپ ان سے پوچھیں کہ آسمان سے پانی کس نے نازل کیا؟ اور زمین کو مردہ ہونے (بنجر ہونے) کے بعد کس نے زندہ (آباد) کیا؟ تو وہ ضرور کہیں گے اللہ نے! آپ کہیے! الحمد ﷲ۔ لیکن اکثر لوگ عقل سے کام نہیں لیتے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcdiv{اور یہ دنیاوی زندگی تو محض کھیل تماشہ ہے اور حقیقی زندگی تو آخرت والی ہے۔ کاش لوگوں کو اس (حقیقت) کا علم ہوتا۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcdv{پس جب یہ لوگ کشتی میں سوار ہوتے ہیں تو اپنے دین (و اعتقاد) کو اللہ کیلئے خالص کرکے اس سے دعا مانگتے ہیں پھر جب انہیں نجات دے کر خشکی کی طرف لے آتا ہے تو ایک دم وہ شرک کرنے لگتے ہیں۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcdvi{تاکہ جو نعمت ہم نے انہیں عطا کی ہے وہ اس کا کفران کریں اور تاکہ وہ لطف اٹھا لیں سو انہیں (اس کا انجام) عنقریب معلوم ہو جائے گا۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcdvii{کیا یہ لوگ نہیں دیکھتے کہ ہم نے (ان کے شہر کو) امن والا حرم بنا دیا ہے۔ حالانکہ ان کے گرد و پیش کے لوگوں کو اچک لیا جاتا ہے (پھر بھی) یہ لوگ باطل پر ایمان لاتے ہیں اور اللہ کی نعمت کا کفران (ناشکری) کرتے ہیں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcdviii{اس شخص سے بڑا ظالم کون ہے جو اللہ پر جھوٹا بہتان باندھے یا حق کو جھٹلائے جبکہ وہ اس کے پاس آچکا ہے! کیا کافروں کا ٹھکانا جہنم نہیں ہے؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcdix{اور جو لوگ ہماری خاطر جدوجہد کرتے ہیں ہم ان کو ضرور اپنے راستے دکھا دیتے ہیں اور بے شک اللہ محسنین کے ساتھ ہے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcdx{\basmalahur الف، لام، میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdxi{رومی مغلوب ہوگئے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdxii{قریب ترین زمین میں (اہلِ فارس سے) اور یہ مغلوب ہونے کے بعد عنقریب غالب آجائیں گے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiii{چند سالوں میں اختیار اللہ کو ہی حاصل ہے پہلے بھی اور بعد بھی۔ اور اس دن اہلِ ایمان خوش ہوں گے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiv{اللہ کی نصرت سے، اللہ جسے چاہتا ہے نصرت عطا فرماتا ہے اور وہ غالب ہے (اور) بڑا رحم کرنے والا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdxv{یہ اللہ کا وعدہ ہے اللہ اپنے وعدہ کی خلاف ورزی نہیں کرتا لیکن اکثر لوگ جانتے نہیں ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvi{یہ لوگ صرف دنیاوی زندگی کے ظاہر کو جانتے ہیں اور آخرت سے بالکل غافل ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvii{کیا انہوں نے اپنے آپ میں کبھی غور و فکر نہیں کیا؟ اللہ نے آسمانوں اور زمین کو اور جو کچھ ان کے درمیان ہے سب کو (حق اور حکمت کے) ساتھ ایک مقررہ مدت تک کیلئے پیدا کیا ہے اور یقیناً بہت سے لوگ اپنے پروردگار کی بارگاہ میں حضوری کے منکر ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdxviii{آیا یہ لوگ زمین میں چلتے پھرتے نہیں ہیں کہ دیکھتے کہ جو لوگ ان سے پہلے تھے ان کا انجام کیا ہوا؟ وہ قوت میں ان سے زیادہ مضبوط تھے اور انہوں نے ان سے زیادہ زمین کو جَوتا بویا اور آباد کیا تھا۔ اور ان کے پاس ان کے رسول واضح نشانیاں لے کر آئے تو اللہ ایسا نہ تھا کہ ان پر ظلم کرتا لیکن وہ خود اپنے آپ پر ظلم کیا کرتے تھے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdxix{پھر ان لوگوں کا انجام جنہوں نے (مسلسل) برائیاں کیں برا ہی ہوا کیونکہ انہوں نے اللہ کی آیتوں کو جھٹلایا تھا اور ان کا مذاق اڑایا کرتے تھے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdxx{اللہ ہی تخلیق کی ابتداء کرتا ہے وہی پھر اس کا اعادہ کرے گا۔ پھر اسی کی طرف تم لوٹائے جاؤگے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxi{اور جس دن قیامت قائم ہوگی (اس دن) مجرم مایوس اور بےآس ہو جائیں گے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxii{اور ان کے بنائے شریکوں میں سے کوئی ان کا سفارشی نہ ہوگا اور وہ بھی اپنے شریکوں سے انکار کر جائیں گے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiii{اور جس دن قیامت قائم ہوگی اس دن (مؤمن و کافر) الگ الگ ہو جائیں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiv{پس وہ لوگ جو ایمان لائے تھے اور نیک عمل کئے تھے وہ باغ (بہشت) میں خوش و خرم اور محترم ہوں گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxv{اور جنہوں نے کفر کیا اور ہماری آیتوں اور آخرت کی حضوری کو جھٹلایا وہ (ہر وقت) عذاب میں حاضر رکھے جائیں گے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvi{پس تم جب شام کرو اور جب صبح کرو تو اللہ کی تسبیح کرو (اس کی پاکیزگی بیان کرو)۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvii{اور آسمانوں میں اور زمین میں اور سہ پہر کو اور جب تم ظہر کرتے ہو ساری حمد و ثنا اسی خدا کے لئے ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxviii{وہ زندہ کو مردے سے نکالتا ہے اور مردے کو زندہ سے نکالتا ہے۔ اور زمین کو اس کی موت کے بعد زندہ (سرسبز) کر دیتا ہے۔ اسی طرح تم (مرنے کے بعد) نکالے جاؤگے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxix{اور اس کی (قدرت) کی نشانیوں سے (ایک) یہ بھی ہے کہ اس نے تمہیں مٹی سے پیدا کیا اور پھر تم ایک دم آدمی بن کر پھیلتے جا رہے ہو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxx{اور اس کی (قدرت کی) نشانیوں میں سے یہ بھی ہے کہ اس نے تمہارے لئے تمہاری ہی جنس سے بیویاں پیدا کیں تاکہ تم ان سے سکون حاصل کرو۔ اور تمہارے درمیان محبت اور رحمت (نرم دلی و ہمدردی) پیدا کر دی۔ بے شک اس میں غور و فکر کرنے والوں کیلئے بہت نشانیاں ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxi{اور اس کی نشانیوں میں سے آسمانوں اور زمین کا پیدا کرنا اور تمہاری زبانوں اور تمہارے رنگوں کا مختلف ہونا بھی ہے۔ بے شک اس میں اہلِ علم کے لئے بہت سی نشانیاں موجود ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxii{اور اس کی نشانیوں میں سے تمہارا رات اور دن میں سونا ہے اور (دن میں) اس کے فضل (روزی) کا تلاش کرنا بھی بے شک اس میں (غور سے) سننے والوں کیلئے بہت سی نشانیاں ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiii{اور اس کی نشانیوں میں سے یہ بھی ہے کہ وہ تمہیں ڈرانے اور امید دلانے کے لئے بجلی دکھاتا ہے اور آسمان سے پانی برساتا ہے پھر اس کے ذریعہ سے زمین کو اس کی موت (خشکی) کے بعد زندہ (شاداب) کر دیتا ہے۔ بے شک اس میں عقل سے کام لینے والے لوگوں کیلئے بہت سی نشانیاں ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiv{اور اس کی نشانیوں میں سے یہ بھی ہے کہ آسمان اور زمین اس کے حکم سے قائم ہیں پھر جب وہ تمہیں زمین سے ایک ہی بار پکارے گا تو تم یکبارگی نکل پڑوگے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxv{جو کوئی آسمانوں اور زمین میں ہے اسی کا ہے (اور) سب اسی کے تابعِ فرمان ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvi{اور وہ وہی ہے جو تخلیق کی ابتداء کرتا ہے پھر وہی اس کو دوبارہ پیدا کرے گا۔ اور یہ اس کیلئے زیادہ آسان ہے اور آسمانوں اور زمین میں اس کی صفت سب سے اعلیٰ ہے۔ وہ غالب ہے اور بڑا حکمت والا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvii{وہ (اللہ) تمہارے لئے تمہاری اپنی ذات (اور تمہارے حالات) سے ایک مثل بیان کرتا ہے کہ تمہارے غلاموں میں سے کوئی تمہارا اس طرح شریک ہے ان چیزوں میں جو ہم نے تمہیں عطا کر رکھی ہیں کہ تم اور وہ برابر کے حصہ دار بن جاؤ کہ تم ان سے اس طرح ڈرنے لگو۔ جس طرح تم آپس میں ایک دوسرے (برابر والے) سے ڈرتے ہو؟ ہم عقل سے کام لینے والوں کیلئے اسی طرح آیتیں کھول کر بیان کرتے ہیں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxviii{بلکہ ظالم لوگ سمجھے بوجھے بھی اپنی خواہشات کی پیروی کر رہے ہیں۔ جسے اللہ (اس کی نافرمانی کی وجہ سے) گمراہی میں چھوڑ دے اسے کون ہدایت دے سکتا ہے؟ اور ان کا کوئی ناصر و مددگار نہیں ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxix{پس (اے رسول(ص)) آپ باطل سے کنارہ کش ہوکر اپنا رخ دین (حق) کی طرف رکھیں یعنی اس (دینِ) فطرت کی پیروی کریں جس پر اس نے انسانوں کو پیدا کیا ہے۔ اللہ کی تخلیق میں کوئی تبدیلی نہیں ہے یہی سیدھا دین ہے مگر اکثر لوگ جانتے نہیں ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcdxl{(تم اپنا رخ اسلام کی طرف رکھو) اللہ کی طرف رجوع کرتے ہوئے اور اس سے ڈرو اور نماز قائم کرو اور (ان) مشرکین میں سے نہ ہو جاؤ۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcdxli{جنہوں نے اپنے دین کو ٹکڑے ٹکڑے کر دیا اور خود گروہ گروہ ہو گئے۔ (پھر) ہر گروہ اس پر خوش ہے جو کچھ اس کے پاس ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlii{اور جب لوگوں کو کوئی تکلیف پہنچتی ہے تو وہ اپنے پروردگار کی طرف رجوع کرتے ہوئے اسے پکارتے ہیں پھر جب وہ انہیں اپنی طرف سے رحمت کا مزہ چکھاتا ہے تو یکایک ان میں سے ایک گروہ پروردگار کے ساتھ شرک کرنے لگتا ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliii{تاکہ اس (نعمت) کی ناشکری کریں جو ہم نے انہیں عطا کی ہے۔ اچھا کچھ دن مزہ حاصل کر لو۔ عنقریب تمہیں اس کا انجام معلوم ہو جائے گا۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliv{کیا ہم نے ان پر کوئی سند (دلیل) نازل کی ہے جو انہیں شرک کرنے کو کہہ رہی ہے جو وہ کر رہے ہیں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlv{اور جب ہم لوگوں کو (اپنی) زحمت کا مزہ چکھاتے ہیں تو وہ اس سے خوش ہو جاتے ہیں اور جب ان پر ان کے اعمال کی پاداش میں جو وہ پہلے اپنے ہاتھوں کر چکے ہیں کوئی مصیبت آتی ہے تو ایک دم مایوس ہو جاتے ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvi{کیا یہ لوگ نہیں دیکھتے کہ اللہ جس کا چاہتا ہے رزق کشادہ کر دیتا ہے اور جس کا چاہتا ہے تنگ کر دیتا ہے۔ بے شک اس میں ایمان والوں کیلئے (قدرتِ خدا کی) بہت سی نشانیاں ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvii{پس (اے رسول(ص)) آپ (اپنے) قرابتدار مسکین اور مسافر کو ان کا حق دے دیں۔ یہ ان لوگوں کیلئے بہتر ہے جو رضائے خدا کے طلبگار ہیں اور یہی لوگ فلاح پانے والے ہیں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlviii{اور جو چیز (روپیہ) تم اس لئے سود پر دیتے ہو کہ لوگوں کے مال میں شامل ہوکر بڑھ جائے تو وہ اللہ کے نزدیک نہیں بڑھتا اور جو زکوٰۃ تم خوشنودئ خدا کیلئے دیتے ہو ایسے ہی لوگ اپنا مال (کئی گنا) بڑھانے والے ہیں۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlix{وہ اللہ ہی ہے جس نے (پہلے) تمہیں پیدا کیا۔ پھر تمہیں رزق دیا۔ پھر وہ تمہیں موت دے گا اور پھر تمہیں زندہ کرے گا۔ کیا تمہارے بنائے ہوئے شریکوں میں سے کوئی ایسا ہے جو ان کاموں میں سے کوئی کام کر سکے؟ اللہ پاک ہے اور بلند و بالا ہے ان کے شرک سے جو وہ کرتے ہیں۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcdl{لوگوں کے ہاتھوں کی کارستانیوں کی وجہ سے خشکی و تری (ساری دنیا) میں فساد پھیل گیا ہے تاکہ اللہ انہیں ان کے بعض (برے) اعمال کا مزہ چکھائے تاکہ وہ لوگ باز آجائیں۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcdli{(اے رسول(ص)) آپ کہہ دیجئے! کہ زمین میں چلو پھرو۔ پھر دیکھو کہ پہلے گزرے ہوئے لوگوں کا انجام کیسا ہوا؟ ان میں سے اکثر مشرک تھے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmcdlii{پس (اے رسول(ص)) آپ اپنا رخ دینِ مستقیم کی طرف رکھیں قبل اس کے کہ وہ دن آجائے کہ جس کیلئے اللہ کی طرف سے ٹلنا نہ ہوگا۔ اس دن لوگ الگ الگ ہو جائیں گے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcdliii{جس نے کفر کیا۔ پس اس کے کفر کا وبال اسی پر ہوگا اور جنہوں نے نیک عمل کئے وہ اپنے ہی لئے راہ ہموار کر رہے ہیں۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcdliv{تاکہ اللہ اپنے فضل و کرم سے ایمان لانے والوں اور نیک عمل کرنے والوں کو جزاء (خیر) دے۔ بے شک وہ کافروں کو پسند نہیں کرتا۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmcdlv{اور اس کی (قدرت کی) نشانیوں میں سے ایک یہ ہے کہ وہ ہواؤں کو (بارش کی) بشارت دینے کیلئے بھیجتا ہے اور تاکہ وہ تمہیں اپنی رحمت کا مزہ چکھائے اور تاکہ اس کے حکم سے (تمہاری) کشتیاں چلیں اور تاکہ تم اس کا فضل (رزق) تلاش کرو اور تاکہ تم شکر ادا کرو۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvi{بے شک ہم نے آپ سے پہلے (بہت سے) پیغمبر ان کی قوموں کی طرف بھیجے جو ان کے پاس کھلی ہوئی نشانیاں (معجزات) لے کر آئے۔ پھر ہم نے مجرموں سے بدلہ لیا اور ہم پر اہلِ ایمان کی مدد کرنا لازم ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvii{اللہ ہی وہ ہے جو ہواؤں کو بھیجتا ہے۔ تو وہ بادل کو اٹھاتی ہیں۔ پھر اللہ جس طرح چاہتا ہے اسے آسمان پر پھیلا دیتا ہے اور پھر اسے ٹکڑے ٹکڑے کر دیتا ہے۔ پھر تم دیکھتے ہو کہ اس کے درمیان سے بارش نکلنے لگتی ہے۔ پھر وہ اپنے بندوں سے جسے چاہتا ہے پہنچاتا ہے۔ تو بس وہ خوش ہو جاتے ہیں۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmcdlviii{اگرچہ وہ اس کے برسنے سے پہلے بالکل مایوس ہو رہے تھے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcdlix{پس اللہ کی رحمت کے آثار کو دیکھو کہ وہ زمین کو اس کے مردہ (بنجر) ہو جانے کے بعد کس طرح زندہ (سرسبز و شاداب) کرتا ہے۔ بے شک وہی مُردوں کو زندہ کرنے والا ہے اور وہ ہر چیز پر پوری قدرت رکھنے والا ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcdlx{اور اگر ہم ایسی ہوا بھیج دیں جس سے وہ اپنی (سرسبز) کھیتی کو زرد ہوتے دیکھ لیں تو وہ اس کے بعد ناشکری کرنے لگیں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxi{(اے رسول(ص)) آپ مُردوں کو نہیں سنا سکتے اور نہ ہی بہروں کو (اپنی) پکار سنا سکتے ہیں جب وہ پیٹھ پھیرے چلے جا رہے ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxii{اور نہ آپ اندھوں کو ان کی گمراہی سے نکال کر ہدایت دے سکتے ہیں آپ تو بس انہی لوگوں کو سنا سکتے ہیں جو ہماری آیتوں پر ایمان لاتے ہیں پھر وہی لوگ تو ماننے والے ہیں۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiii{اللہ ہی وہ ہے جس نے کمزوری کی حالت سے تمہاری پیدائش کا آغاز کیا۔ پھر کمزوری کے بعد (تمہیں جوانی کی) قوت بخشی اور پھر اس نے قوت کے بعد کمزوری اور بڑھاپا پیدا کر دیا وہ جو چاہتا ہے پیدا کرتا ہے اور وہ بڑا جاننے والا، بڑی قدرت والا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiv{اور جس دن قیامت قائم ہوگی تو مجرم لوگ قَسمیں کھائیں گے کہ وہ (دنیا) میں گھڑی بھر سے زیادہ نہیں ٹھہرے۔ یہ لوگ (دنیا میں بھی) اسی طرح الٹے چلا کرتے تھے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxv{اور جن لوگوں کو علم و ایمان دیا گیا تھا وہ کہیں گے کہ تم اللہ کے نوشتہ کے مطابق حشر کے دن تک ٹھہرے رہے ہو۔ چنانچہ یہ وہی حشر کا دن ہے لیکن تمہیں (اس کا) علم و یقین نہیں تھا۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvi{سو اس دن ظالموں کو ان کی معذرت کوئی فائدہ نہیں دے گی اور نہ ہی ان سے (توبہ کرکے) خدا کو راضی کرنے کیلئے کہا جائے گا۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvii{بے شک ہم نے اس قرآن میں لوگوں کے (سمجھانے) کیلئے ہر قسم کی مثال پیش کی ہے اور اگر آپ ان کے پاس کوئی نشانی (معجزہ) لے بھی آئیں تو بھی کافر لوگ یہی کہیں گے کہ تم باطل پر ہو۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxviii{اسی طرح اللہ ان لوگوں کے دلوں پر مہر لگا دیتا ہے جو جانتے نہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxix{(اے رسول(ص)) آپ صبر و ثبات سے کام لیں۔ بے شک اللہ کا وعدہ سچا ہے اور جو لوگ یقین نہیں رکھتے وہ آپ کو (جوش دلا کر) بے برداشت نہ کر دیں۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxx{\basmalahur الف، لام، میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxi{یہ کتابِ حکیم کی آیتیں ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxii{جو (سراپا) ہدایت اور رحمت ان نیکوکار لوگوں کیلئے ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiii{جو پورے اہتمام سے نماز ادا کرتے ہیں اور جو کچھ ہم نے ان کو دیا ہے اس میں سے کچھ (میری راہ میں) خرچ کرتے ہیں اور وہ آخرت پر یقین رکھتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiv{یہی لوگ اپنے پروردگار کی ہدایت پر (قائم) ہیں اور یہی وہ ہیں جو (آخرت میں) فلاح پانے والے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxv{اور انسانوں میں سے کوئی ایسا بھی ہوتا ہے جو اللہ سے غافل کر دینے والا بے ہودہ کلام خریدتا ہے تاکہ بغیر سوچے سمجھے لوگوں کو خدا کی راہ سے بھٹکائے اور اس (راہ یا آیتوں) کا مذاق اڑائے۔ ایسے لوگوں کیلئے رسوا کرنے والا عذاب ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvi{اور جب اس کے سامنے ہماری آیتیں پڑھی جاتی ہیں تو وہ تکبر سے اس طرح منہ موڑ لیتا ہے کہ گویا اس نے انہیں سنا ہی نہیں گویا کہ اس کے کانوں میں گرانی (بہرہ پن) ہے تو اسے دردناک عذاب کی خبر سنا دیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvii{بے شک جو لوگ ایمان لائے اور انہوں نے نیک عمل کئے ان کیلئے نعمت (اور آرام) والی جنتیں ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxviii{جن میں وہ ہمیشہ رہیں گے۔ یہ اللہ کا سچا (اور پکا) وعدہ ہے۔ وہ بڑا غالب ہے (اور) بڑا حکمت والا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxix{اس نے آسمانوں کو ایسے ستونوں کے بغیر پیدا کیا ہے جو تمہیں نظر آئیں اور اس نے زمین میں بھاری پہاڑ گاڑ دیئے تاکہ وہ تمہیں لے کر (ایک طرف) ڈھلک نہ جائے اور اس میں ہر قسم کے چلنے پھرنے والے (جانور) پھیلا دیئے اور ہم نے آسمانوں (بلندی) سے پانی برسایا اور اس سے زمین میں ہر قسم کی عمدہ چیزیں اگائیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxx{یہ تو ہے اللہ کی تخلیق! (اور اس کی پیدا کی ہوئی چیزیں)۔ اب تم مجھے دکھاؤ کہ جو اس کے علاوہ (تمہارے شرکاء) ہیں انہوں نے کیا پیدا کیا ہے؟ بلکہ ظالم لوگ کھلی ہوئی گمراہی میں ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxi{اور ہم نے لقمان کو حکمت (و دانائی) عطا کی (اور کہا) کہ خدا کا شکر ادا کرو اور جو شکر ادا کرتا ہے وہ اپنے ہی فائدہ کیلئے شکر ادا کرتا ہے اور جو کفرانِ نعمت (ناشکری) کرتا ہے (وہ اپنا نقصان کرتا ہے کیونکہ) بے شک اللہ بے نیاز ہے (اور) لائقِ حمد و ثنا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxii{اور (وہ وقت یاد کرو) جب لقمان نے اپنے بیٹے کو نصیحت کرتے ہوئے کہا کہ اے بیٹے! (خبردار کسی کو) اللہ کا شریک نہ بنانا۔ بے شک شرک بہت بڑا ظلم ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiii{اور ہم نے انسان کو اس کے ماں باپ کے بارے میں (حسنِ سلوک کرنے کا) تاکیدی حکم دیا (کیونکہ) اس کی ماں نے کمزوری پر کمزوری سہہ کر اسے (پیٹ میں) اٹھائے رکھا اور دو برس میں اس کا دودھ چھوٹا (وہ تاکیدی حکم یہ تھا کہ) میرا اور اپنے ماں باپ کا شکریہ ادا کر (آخرکار) میری ہی طرف (تمہاری) بازگشت ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiv{اور اگر وہ تجھ پر دباؤ ڈالیں کہ تو کسی ایسی چیز کو میرا شریک ٹھہرائے جس کا تجھے کوئی علم نہیں ہے تو پھر ان کی اطاعت نہ کر اور دنیا میں ان کے ساتھ نیک سلوک کر اور اس شخص کے راستہ کی پیروی کر جو (ہر معاملہ میں) میری طرف رجوع کرے پھر تم سب کی بازگشت میری ہی طرف ہے۔ تو (اس وقت) میں تمہیں بتاؤں گا کہ جو کچھ تم کیا کرتے تھے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxv{اے بیٹا! اگر کوئی (نیک یا بد) عمل رائی کے دانہ کے برابر بھی ہو اور کسی پتھر کے نیچے ہو یا آسمانوں میں یا زمین میں تو اللہ اسے لے ہی آئے گا بے شک اللہ بڑا باریک بین اور بڑا باخبر ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvi{اے بیٹا! نماز قائم کر اور نیکی کا حکم دے اور برائی سے منع کر اور جو مصیبت پیش آئے اس پر صبر کر۔ بے شک یہ (صبر) عزم و ہمت کے کاموں میں سے ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvii{اور (تکبر سے) اپنا رخسار لوگوں سے نہ پھیر اور زمین پر ناز و انداز سے نہ چل۔ بے شک خدا تکبر کرنے والے (اور) بہت فخر کرنے والے کو دوست نہیں رکھتا۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxviii{اور اپنی رفتار (چال) میں میانہ روی اختیار کر اور اپنی آواز دھیمی رکھ۔ بے شک سب آوازوں میں سے زیادہ ناگوار آواز گدھوں کی ہوتی ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxix{کیا تم نہیں دیکھتے کہ جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اللہ تعالیٰ نے سب کو تمہارے لئے مسخر کر دیا ہے اور اپنی سب ظاہری اور باطنی نعمتیں تم پر تمام کر دی ہیں اور لوگوں میں سے کچھ ایسے بھی ہیں جو علم، ہدایت اور روشن کتاب کے بغیر خدا کے بارے میں بحث و تکرار کرتے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxc{اور جب ان سے کہا جاتا ہے کہ اس چیز کی پیروی کرو جو اللہ نے نازل کی ہے تو وہ کہتے ہیں کہ (نہیں) بلکہ ہم تو اس کی پیروی کریں گے جس پر ہم نے اپنے باپ دادا کو پایا ہے۔ کیا (یہ جب بھی انہی کی پیروی کریں گے) اگرچہ شیطان ان (بڑوں) کو بھڑکتی آگ کے عذاب کی طرف بلا رہا ہو؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxci{اور جو کوئی اپنا رخ اللہ کی طرف جھکا دے (اپنے آپ کو اللہ کے حوالے کر دے) درآنحالیکہ وہ نیکوکار بھی ہو تو اس نے مضبوط راستہ (سہارا) پکڑ لیا ان (سب) نے ہماری ہی طرف لوٹ کر آنا ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcii{اور جو کوئی کفر اختیار کرے تو (اے رسول(ص)) اس کا کفر آپ کو غمگین نہ کرے۔ پس (اس وقت) ہم انہیں بتائیں گے کہ جو کچھ وہ کیا کرتے تھے۔ بے شک اللہ سینوں کے اندر کی باتوں کو خوب جاننے والا ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciii{ہم انہیں چند روزہ عیش کا موقع دیں گے اور پھر انہیں سخت عذاب کی طرف کشاں کشاں لے جائیں گے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciv{(اے رسول(ص)) اگر آپ ان (مشرکین) سے پوچھیں کہ آسمانوں اور زمین کو کس نے پیدا کیا ہے؟ تو وہ (جواب میں) ضرور کہیں گے کہ اللہ نے! آپ کہئے! الحمدﷲ مگر ان میں سے اکثر لوگ جانتے نہیں ہیں۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcv{جو کچھ آسمانوں اور زمین میں ہے وہ سب اللہ ہی کا ہے۔ بے شک اللہ بے نیاز ہے اور لائقِ حمد و ثنا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvi{اور جتنے درخت زمین میں ہیں اگر وہ سب قَلمیں بن جائیں اور سمندر (سیاہی بن جائیں) اور اس کے علاوہ سات سمندر اسے سہارا دیں (سیاہی مہیا کریں) تب بھی اللہ کے کلمات ختم نہیں ہوں گے بے شک اللہ بڑا غالب (اور) بڑا حکمت والا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvii{تم سب کا پیدا کرنا اور دوبارہ زندہ کرکے اٹھانا (اللہ کیلئے) ایک شخص کے پیدا کرنے اور دوبارہ اٹھانے کی مانند ہے بے شک اللہ بڑا سننے والا، بڑا دیکھنے والا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcviii{کیا تم نہیں دیکھتے کہ اللہ رات کو دن میں اور دن کو رات میں داخل کر دیتا ہے اور اس نے سورج اور چاند کو مسخر کر رکھا ہے۔ ہر ایک اپنے مقررہ وقت تک (اپنے مدار میں) چل رہا ہے۔ اور تم جو کچھ کرتے ہو اللہ اسے خوب جانتا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcix{یہ سب اس لئے ہے کہ اللہ ہی حق ہے اور اس کے سوا جن چیزوں کو (مشرک) پکارتے ہیں وہ سب باطل ہیں اور بے شک اللہ بلند (شان والا) ہے اور بزرگ ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmd{کیا تم نے نہیں دیکھا کہ محض اللہ کے فضل سے سمندر میں کشتی چلتی ہے۔ تاکہ وہ تمہیں اپنی قدرت کی کچھ نشانیاں دکھائے۔ بے شک اس میں بہت سی نشانیاں ہیں ہر بہت صبر و شکر کرنے والے کیلئے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdi{اور جب انہیں ایک موج سائبانوں کی طرح ڈھانپ لیتی ہے تو یہ اپنے دین کو اللہ کیلئے خالص کرکے اسے پکارتے ہیں پھر جب وہ ان کو نجات دے کر خشکی تک پہنچا دیتا ہے تو پھر ان میں سے کچھ تو اعتدال پر رہتے ہیں (اور اکثر انکار کر دیتے ہیں) اور ہماری نشانیوں کا انکار نہیں کرتا مگر وہی شخص جو بڑا غدار (بے وفا) اور بڑا ناشکرا ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdii{اے لوگو! اپنے پروردگار (کی نافرمانی) سے ڈرو۔ اور اس دن کا خوف کرو۔ جب نہ کوئی باپ اپنے بیٹے کو فائدہ پہنچا سکے گا اور نہ کوئی بیٹا اپنے باپ کو کوئی فائدہ پہنچا سکے گا۔ بے شک اللہ کا وعدہ سچا ہے تو تمہیں دنیا کی (عارضی) زندگی دھوکہ نہ دے اور نہ ہی کوئی دھوکہ باز (شیطان وغیرہ) تمہیں اللہ کے بارے میں دھوکہ دے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdiii{بے شک اللہ ہی کے پاس قیامت کا علم ہے اور وہی بارش برساتا ہے اور وہی جانتا ہے کہ ماؤں کے رحموں میں کیا ہے؟ اور کوئی نہیں جانتا کہ وہ کل کیا کرے گا اور کوئی نہیں جانتا کہ وہ کس سرزمین میں مرے گا۔ بے شک اللہ بڑا جاننے والا (اور) بڑا باخبر ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdiv{\basmalahur الف، لام، میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdv{بلا شک و شبہ یہ کتاب (قرآن) کی تنزیل تمام جہانوں کے پروردگار کی طرف سے ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdvi{کیا وہ لوگ کہتے ہیں کہ اس (رسول(ص)) نے اسے خود گھڑ لیا ہے؟ (نہیں) بلکہ یہ آپ کے پروردگار کی طرف سے حق ہے تاکہ آپ اس قوم کو ڈرائیں جس کے پاس آپ سے پہلے کوئی ڈرانے والا نہیں آیا۔ شاید کہ وہ ہدایت پا جائیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdvii{اللہ ہی وہ ہے جس نے آسمانوں اور زمین اور ان کے درمیان کی سب چیزوں کو چھ دنوں میں پیدا کیا پھر عرش پر متمکن ہوا اس کے سوا نہ تمہارا کوئی سرپرست ہے اور نہ کوئی سفارشی کیا تم نصیحت حاصل نہیں کرتے؟\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdviii{وہ آسمان سے لے کر زمین تک ہر معاملہ کی تدبیر کرتا ہے اور پھر ہر معاملہ اس کی بارگاہ میں اس دن پیش ہوگا جس کی مقدار تمہارے شمار کے مطابق ایک ہزار سال ہوگی۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdix{یہ ہے ہر پوشیدہ اور ظاہر کا جاننے والا جو بڑا غالب ہے (اور) بڑا رحم کرنے والا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdx{جس نے جو چیز بنائی بہترین بنائی اور انسان (آدم (ع)) کی خلقت کی ابتدائ گیلی مٹی سے کی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxi{پھر اس کی نسل کو ایک حقیر پانی (نطفہ) کے نچوڑ سے قرار دیا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxii{پھر اس کو درست کیا (اس کی نوک پلک سنواری) اور پھر اس میں اپنی (خاص) روح پھونک دی اور تمہارے لئے کان، آنکھیں اور دل (دماغ) بنائے مگر تم لوگ بہت کم شکر ادا کرتے رہو۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxiii{اور وہ (کفار) کہتے ہیں کہ جب ہم زمین میں گم (ناپید) ہو جائیں گے تو کیا ہم از سرِ نو پیدا کئے جائیں گے بلکہ (اصل بات یہ ہے کہ) یہ لوگ اپنے پروردگار کی بارگاہ میں حاضری کے منکر ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxiv{آپ کہہ دیجئے! کہ موت کا وہ فرشتہ جو تم پر مقرر کیا گیا ہے وہ تمہیں پورا پورا اپنے قبضے میں لیتا ہے پھر تم اپنے پروردگار کی طرف لوٹائے جاؤگے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxv{اور کاش! تم دیکھتے جب مجرم اپنے سر جھکائے اپنے پروردگار کی بارگاہ میں (کھڑے) ہوں گے اور (عرض کریں گے) اے ہمارے پروردگار! ہم نے دیکھ لیا اور سن لیا تو (ایک بار دنیا میں) ہمیں واپس بھیج دے۔ (اب) ہم نیک کام کریں گے اب ہمیں یقین آگیا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxvi{اور اگر ہم (مشیتِ قاہرہ سے) چاہتے تو ہر متنفس کو اس کی ہدایت دے دیتے لیکن میری طرف سے یہ بات طے ہو چکی ہے کہ میں جہنم کو سب (نافرمان) جنوں اور انسانوں سے بھر دوں گا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxvii{سو اس دن کی حاضری کو بھلا دینے کا (آج) مزا چکھو۔ (اب) ہم نے بھی تمہیں نظر انداز کر دیا ہے اور اپنے برے اعمال کی پاداش میں دائمی عذاب کا مزہ چکھو۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxviii{ہماری آیتوں پر بس وہی لوگ ایمان لاتے ہیں جن کو جب بھی ان (آیتوں) کے ساتھ نصیحت کی جائے تو وہ سجدے میں گر جاتے ہیں اور اپنے پروردگار کی حمد کے ساتھ تسبیح کرتے ہیں اور وہ تکبر نہیں کرتے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxix{(رات کے وقت) ان کے پہلو بستروں سے الگ رہتے ہیں (اور) وہ بیم و امید سے اپنے پروردگار کو پکارتے ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdxx{پس کوئی شخص نہیں جانتا کہ ان کے (اچھے) اعمال کے صلہ میں ان کی آنکھوں کی ٹھنڈک کی کیا کیا نعمتیں چھپا کر رکھی گئی ہیں۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdxxi{تو کیا جو مؤمن ہے وہ فاسق کی مانند ہو سکتا ہے؟ یہ برابر نہیں ہو سکتے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdxxii{پس جو لوگ ایمان لائے اور نیک عمل (بھی) کئے تو ان کے (اچھے) اعمال کے صلہ میں مہمانی کے طور پر ان کے (آرام) کے لئے جنتوں کی قیام گاہیں ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiii{اور جنہوں نے نافرمانی کی ان کا ٹھکانا آتش دوزخ ہے وہ جب بھی اس میں سے نکلنا چاہیں گے تو اسی میں لوٹا دیئے جائیں گے اور ان سے کہا جائے گا کہ اسی آگ کے عذاب کا مزہ چکھو جسے تم جھٹلاتے تھے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiv{اور ہم انہیں (قیامت والے) بڑے عذاب سے پہلے چھوٹے عذاب کا مزہ چکھائیں گے تاکہ یہ باز آجائیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdxxv{اور اس شخص سے بڑا ظالم کون ہوگا جسے اس کے پروردگار کی آیتوں کے ذریعہ سے نصیحت کی جائے (اور) پھر وہ ان سے روگردانی کرے۔ بے شک ہم مجرموں سے انتقام لینے والے ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvi{اور بیشک ہم نے موسیٰ (ع)کو کتاب (توراۃ) عطا کی تھی۔ تو آپ کو ایسی کتاب کے ملنے پر شک میں نہیں پڑنا چاہیے اور ہم نے اسے بنی اسرائیل کے لئے ذریعۂ ہدایت بنایا تھا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvii{اور ہم نے ان میں سے بعض کو ایسا امام و پیشوا قرار دیا تھا جو ہمارے حکم سے ہدایت کیا کرتے تھے جب کہ انہوں نے صبر کیا تھا اور وہ ہماری آیتوں پر یقین رکھتے تھے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdxxviii{بے شک آپ کا پروردگار قیامت کے دن ان کے درمیان فیصلہ کرے گا۔ ان باتوں میں جن میں وہ باہم اختلاف کیا کرتے تھے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdxxix{کیا اس بات سے بھی اللہ نے انہیں ہدایت نہیں کی کہ ہم نے ان سے پہلے کتنی قوموں کو ہلاک کر دیا ہے جن کے مکانات میں یہ (آج) چل پھر رہے ہیں۔ بے شک اس میں (عبرت کیلئے) بڑی نشانیاں ہیں کیا یہ لوگ سنتے نہیں ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdxxx{کیا انہوں نے نہیں دیکھا کہ ہم بنجر زمین کی طرف پانی کو بہا لے جاتے ہیں پھر اس سے ایسی کھیتی اگاتے ہیں جس میں ان کے چوپائے بھی کھاتے ہیں اور خود بھی تو کیا یہ لوگ دیکھتے نہیں ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxi{اور وہ لوگ یہ کہتے ہیں کہ اگر تم سچے ہو تو (بتاؤ) یہ فتح (فیصلہ) کب ہوگا؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxii{آپ کہئے کہ فتح (فیصلہ) والے دن کافروں کو ان کا ایمان لانا کوئی فائدہ نہ دے گا اور نہ ہی انہیں مہلت دی جائے گی۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiii{سو آپ ان سے بے اعتنائی کریں اور انتظار کریں۔ وہ بھی انتظار کر رہے ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiv{\basmalahur اے نبی! اللہ سے ڈرتے رہیں اور کافروں اور منافقوں کی اطاعت نہ کریں۔ بے شک اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxv{اور جو کچھ آپ کے پروردگار کی طرف سے آپ کو وحی کی جاتی ہے اس کی پیروی کریں بے شک تم لوگ جو کچھ کرتے ہو اللہ اس سے خوب باخبر ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvi{اور آپ اپنے پروردگار پر توکل کریں بے شک اللہ تعالیٰ کارسازی کیلئے کافی ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvii{اور اللہ نے کسی مرد کے سینہ میں دو دل نہیں بنائے اور نہ ہی تمہاری ان بیویوں کو تمہاری مائیں بنایا ہے جن سے تم ظہار کرتے ہو اور نہ ہی اس نے تمہارے منہ بولے بیٹوں کو تمہارا (حقیقی) بیٹا بنایا ہے اور وہی (سیدھے) راستے کی ہدایت کرتا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxviii{ان (منہ بولے بیٹوں) کو ان کے (حقیقی) باپوں کے نام سے پکارا کرو۔ یہ بات اللہ کے نزدیک زیادہ قرینِ انصاف ہے اور اگر تمہیں ان کے (حقیقی) باپوں کا علم نہ ہو تو پھر وہ تمہارے دینی بھائی اور تمہارے دوست ہیں اور تم سے جو بھول چوک ہو جائے اس کا تم پر کوئی گناہ نہیں ہے۔ ہاں البتہ (گناہ اس پر ہے) جو تم دل سے ارادہ کرکے کرو۔ اور اللہ بڑا بخشنے والا (اور) رحم کرنے والا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxix{نبی مؤمنین پر ان کی جانوں سے بھی زیادہ حق (تصرف) رکھتے ہیں۔ اور آپ کی بیویاں ان (مؤمنین) کی مائیں ہیں اور کتاب اللہ کی رو سے رشتہ دار بہ نسبت عام مؤمنین و مہاجرین کے (وراثت میں) ایک دوسرے کے زیادہ حقدار ہیں مگر یہ کہ تم اپنے دوستوں کے ساتھ حسن سلوک کرنا چاہو۔ یہ حکم کتاب (الٰہی) میں لکھا ہوا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdxl{اور وہ وقت یاد کرو۔ جب ہم نے نبیوں سے عہد و پیمان لیا تھا اور آپ سے بھی اور نوح، ابراہیم، موسیٰ اور عیسیٰ بن مریم سے بھی اور ہم نے ان سب سے سخت عہد لیا تھا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxli{تاکہ وہ (پروردگار) ان سچے لوگوں سے ان کی سچائی کے متعلق سوال کرے اور اس نے کافروں کیلئے دردناک عذاب تیار کر رکھا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxlii{اے ایمان والو! اللہ کے اس احسان کو یاد کرو جو اس نے تم پر کیا ہے جب (کفار کے) لشکر تم پر چڑھ آئے اور ہم نے (تمہاری مدد کیلئے) ان پر ہوا (آندھی) بھیجی اور (فرشتوں کے) ایسے لشکر بھیجے جن کو تم نے نہیں دیکھا اور جو کچھ تم کر رہے تھے۔ اللہ اسے خوب دیکھ رہا تھا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxliii{جب وہ تم پر اوپر اور نیچے سے چڑھ آئے اور (شدتِ خوف سے) آنکھیں پتھرا گئیں اور دل (کلیجے) منہ کو آگئے اور تم اللہ کی نسبت طرح طرح کے گمان کرنے لگے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxliv{اس وقت ایمان والوں کو خوب آزمایا گیا اور انہیں سخت زلزلہ میں ڈال دیا (سخت جھنجھوڑا گیا)۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxlv{اور جب منافق اور وہ لوگ جن کے دلوں میں بیماری تھی کہنے لگے کہ خدا اور رسول نے ہم سے (فتح کا) جو وعدہ کیا تھا وہ دھوکہ کے سوا کچھ نہ تھا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvi{اور وہ وقت یاد کرو جب ان میں سے ایک گروہ کہنے لگا کہ اے یثرب والو! اب (یہاں) تمہارے ٹھہرنے کا موقع نہیں ہے سو واپس چلو اور ان میں سے ایک گروہ یہ کہہ کر پیغمبرِ خدا (صلی اللہ علیہ و آلہ وسلم) سے اجازت مانگ رہا تھا کہ ہمارے گھر خالی (غیر محفوظ) ہیں حالانکہ وہ خالی (غیر محفوظ) نہیں تھے وہ تو صرف (محاذ سے) بھاگنا چاہتے تھے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvii{اور اگر ان پر اسی (مدینہ) کے اطراف سے (دشمن) گھس آتے اور پھر انہیں اس فتنہ (میں شرکت) کی دعوت دی جاتی تو یہ اس میں پڑ جاتے اور اس میں زیادہ توقف نہ کرتے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxlviii{حالانکہ انہوں نے اللہ سے عہد کیا تھا کہ وہ (مقابلہ میں) پیٹھ نہیں پھیریں گے اور اللہ سے جو وعدہ کیا تھا اس کے متعلق بازپرس کی جائے گی۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxlix{آپ کہہ دیجئے! کہ اگر تم موت یا قتل سے بھاگو تو یہ بھاگنا تمہیں کوئی فائدہ نہ دے گا اگر ایسا کیا بھی تو پھر بھی (زندگانی دنیا سے) تمہیں لطف اندوز ہونے کا بہت تھوڑا موقع دیا جائے گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdl{آپ کہئے! کون ہے جو تمہیں اللہ سے بچا سکے اگر وہ تمہیں نقصان پہنچانا چاہے یا اگر وہ تم پر مہربانی کرنا چاہے (تو اسے کون روک سکتا ہے؟) اور وہ لوگ اللہ کے سوا اپنا نہ کوئی سرپرست پائیں گے اور نہ کوئی مددگار۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdli{اللہ تم میں سے ان لوگوں کو خوب جانتا ہے جو (جہاد سے) روکتے ہیں اور انہیں بھی جو اپنے بھائی بندوں سے کہتے ہیں کہ (محاذِ جنگ چھوڑ کر) ہماری طرف آجاؤ اور یہ لوگ میدانِ جنگ میں بہت کم آتے ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdlii{وہ تمہارے معاملہ میں سخت بخیل ہیں اور جب خوف (کا وقت) آجائے تو آپ انہیں دیکھیں گے کہ وہ آپ کی طرف اس طرح دیکھتے ہیں کہ ان کی آنکھیں اس شخص کی طرح گھوم رہی ہیں جس پر موت کی غشی طاری ہو پھر جب خوف جاتا رہے تو یہ لوگ (اپنی) تیز زبانوں سے طعنہ دیتے ہیں یہ مال (غنیمت) کے بڑے حریص ہیں (دراصل) یہ لوگ ایمان لائے ہی نہیں چنانچہ اللہ نے ان کے اعمال اکارت کر دیئے ہیں اور ایسا کرنا اللہ کیلئے بالکل آسان ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdliii{(دشمن چلا گیا مگر) یہ لوگ خیال کرتے ہیں کہ ابھی لشکر گئے نہیں ہیں اور اگر وہ لشکر (دوبارہ) آجائیں تو یہ پسند کریں گے کہ کاش ہم صحرا میں بدوؤں کے ساتھ جا کر رہیں اور وہاں سے تمہاری خبریں پوچھتے رہیں اور اگر تم میں ہوتے تو جب بھی (دشمن سے) جنگ نہ کرتے مگر بہت کم۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdliv{بے شک تمہارے لئے پیغمبرِ اسلام (صلی اللہ علیہ و آلہ وسلم) کی ذات میں (پیروی کیلئے) بہترین نمونہ موجود ہے۔ ہر اس شخص کیلئے جو اللہ (کی بارگاہ میں حاضری) اور قیامت (کے آنے) کی امید رکھتا ہے اور اللہ کو بکثرت یاد کرتا ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdlv{اور (سچے) اہلِ ایمان کا حال یہ تھا کہ جب انہوں نے لشکروں کو دیکھا تو کہنے لگے کہ یہ ہے وہ (لشکر) جس کا خدا اور رسول نے وعدہ کیا تھا اور خدا اور رسول نے سچ فرمایا تھا اور اس (بات) نے ان کے ایمان اور (جذبۂ) تسلیم میں مزید اضافہ کر دیا۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdlvi{اور اہلِ ایمان میں سے کچھ ایسے بھی ہیں جنہوں نے وہ عہد و پیمان سچا کر دکھایا جو اللہ سے کیا تھا۔ سو ان میں سے کچھ وہ ہیں جو اپنا وقت پورا کر چکے ہیں اور کچھ اس (وقت) کا انتظار کر رہے ہیں اور انہوں نے (اپنی روش میں) ذرا بھی تبدیلی نہیں کی۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdlvii{تاکہ خدا سچوں کو ان کی سچائی کی جزا دے اور منافقوں کو چاہے تو سزا دے اور چاہے تو ان کی توبہ قبول کرے۔ بے شک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdlviii{اور اللہ نے کافروں کو غم و غصہ کی حالت میں (بے نیل مُرام) لوٹایا کہ وہ کوئی فائدہ حاصل نہ کر سکے اور اللہ نے مؤمنوں کو جنگ (کی زحمت) سے بچا لیا اور اللہ بڑا طاقتور (اور) غالب ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdlix{خدا نے ان اہلِ کتاب کو جنہوں نے ان (کفار) کی مدد کی تھی ان کے قلعوں سے اتار دیا اور ان کے دلوں میں رعب ڈال دیا۔ چنانچہ تم ان میں سے بعض کو قتل کرنے لگے اور بعض کو قید کر لیا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdlx{اور (خدا نے) تمہیں ان (کافروں) کی زمین کا اور ان کے گھروں کا اور ان کے اموال کا اور ان کی اس زمین کا جس پر تم نے قدم بھی نہیں رکھا تھا وارث بنا دیا اور اللہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdlxi{اے نبی! اپنی بیویوں سے کہہ دیجئے کہا گر تم دنیاوی زندگی اور اس کی زیب و زینت چاہتی ہو تو آؤ کہ تمہیں کچھ مال و متاع دے کر اچھے طریقے سے رخصت کروں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdlxii{اور اگر تم خدا اور اس کے رسول اور دارِ آخرت کی طلبگار ہو تو بے شک اللہ نے تم میں سے جو نیکوکار ہیں ان کیلئے اجرِ عظیم تیار کر رکھا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiii{اے نبی کی بیویو! تم میں سے جو کوئی بے حیائی اور برائی کرے گی تو اسے دوہری سزا دی جائے گی اور یہ بات اللہ کیلئے بالکل آسان ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiv{اور تم میں سے جو خدا اور اس کے رسول کی اطاعت کرے گی اور نیک عمل کرتی رہے گی تو ہم اس کو اس کا اجر و دہرا دیں گے اور ہم نے اس کیلئے (جنت میں) عمدہ روزی تیار کر رکھی ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdlxv{اے نبی کی بیویو! تم اور (عام) عورتوں کی طرح نہیں ہوا اگر تم پرہیزگاری اختیار کرو۔ پس تم ایسے نرم لہجہ میں بات نہ کرو کہ جس کے دل میں کوئی بیماری ہے وہ طمع کرنے لگے اور قاعدے کے مطابق (باوقار طریقہ سے) بات کیا کرو۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvi{اور اپنے گھروں میں قرار سے رہو اور سابقہ زمانۂ جاہلیت کی طرح اپنی آرائش کی نمائش نہ کرتی پھرو (باہر نہ نکلا کرو) اور نماز قائم کرو اور زکوٰۃ ادا کرو اور اللہ اور اس کے رسول کی اطاعت کیا کرو۔ اے اہل بیت! اللہ تو بس یہی چاہتا ہے کہ تم سے ہر قسم کے رجس (آلودگی) کو دور رکھے اور تمہیں اس طرح پاک و پاکیزہ رکھے جس طرح پاک رکھنے کا حق ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvii{اور اللہ کی جو آیتیں اور حکمت کی جو باتیں تمہارے گھروں میں پڑھ کر سنائی جاتی ہیں ان کو یاد رکھو بے شک اللہ بڑا باریک بین (اور) بڑا باخبر ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdlxviii{بے شک مسلمان مرد اور مسلمان عورتیں، مؤمن مرد اور مؤمن عورتیں، اطاعت گزار مرد اور اطاعت گزار عورتیں، سچے مرد اور سچی عورتیں، صابر مرد اور صابر عورتیں، عاجزی کرنے والے مرد اور عاجزی کرنے والی عورتیں، صدقہ دینے والے مرد اور صدقہ دینے والی عورتیں، روزہ دار مرد اور روزہ دار عورتیں، اپنی شرمگاہوں کی حفاظت کرنے والے مرد اور حفاظت کرنے والی عورتیں اور اللہ کو بکثرت یاد کرنے والے مرد اور یاد کرنے والی عورتیں اللہ نے ان کیلئے مغفرت اور بڑا اجر و ثواب مہیا کر رکھا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdlxix{کسی مؤمن مرد اور کسی مؤمن عورت کو یہ حق نہیں ہے کہ جب خدا اور اس کا رسول کسی معاملے کا فیصلہ کر دیں تو انہیں اپنے (اس) معاملے میں کوئی اختیار ہو اور جو کوئی اللہ اور اس کے رسول کی نافرمانی کرے گا وہ کھلی ہوئی گمراہی میں پڑے گا۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdlxx{(اے رسول! وہ وقت یاد کرو) جب آپ اس شخص سے کہہ رہے تھے جس پر اللہ نے اور آپ نے احسان کیا تھا کہ اپنی بیوی کو اپنے پاس رہنے دے (اسے نہ چھوڑ) اور اللہ سے ڈر۔ اور آپ (اس وقت) وہ بات اپنے دل میں چھپا رہے تھے جسے اللہ ظاہر کرنے والا تھا اور آپ لوگوں (کی طعن و تشنیع) سے ڈر رہے تھے حالانکہ اللہ اس بات کا زیادہ حقدار ہے کہ آپ اس سے ڈریں (بہرحال) جب زید نے اس عورت (زینب) سے اپنی حاجت پوری کر لی (اسے طلاق دے دی) تو ہم نے اس خاتون کی شادی آپ سے کر دی تاکہ اہلِ ایمان پر اپنے منہ بولے بیٹوں کی بیویوں سے (نکاح کرنے) کے معاملے میں کوئی تنگی نہ رہ جائے جب وہ ان سے (اپنی) حاجت پوری کر چکے ہوں (اور انہیں طلاق دے کر فارغ کر چکے ہوں) اور اللہ کا حکم تو بہرحال ہوکر رہتا ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxi{اس کام کے کرنے میں نبی(ص) پر کوئی مضائقہ نہیں ہے جو خدا نے ان کیلئے مقرر کیا ہے جو لوگ (انبیاء(ع)) اس سے پہلے گزر چکے ہیں ان کے بارے میں بھی خدا کا یہی معمول رہا ہے اور اللہ کا حکم حقیقی اندازے کے مطابق مقرر کیا ہوا ہوتا ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxii{وہ (پیغمبر(ص)) ایسے لوگ ہیں جو اللہ کے پیغامات (اس کے بندوں تک) پہنچاتے ہیں اور اسی سے ڈرتے ہیں اور وہ اللہ کے سوا اور کسی سے نہیں ڈرتے اور محاسبہ کیلئے اللہ ہی کافی ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiii{محمد (صلی اللہ علیہ و آلہٰ وسلم) تمہارے مردوں میں سے کسی مرد کے باپ نہیں ہیں۔ ہاں البتہ وہ اللہ کے رسول(ص) اور خاتم النبیین(ص) (سلسلۂ انبیاء کے ختم کرنے والے اور مہرِ اختتام) ہیں اور خدا ہر چیز کا خوب جاننے والا ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiv{اے ایمان والو! اللہ کو بکثرت یاد کیا کرو۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxv{اور صبح و شام اس کی تسبیح کیا کرو۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvi{وہ (اللہ) وہی ہے جو تم پر رحمت بھیجتا ہے اور اس کے فرشتے بھی (دعائے مغفرت) کرتے ہیں تاکہ تمہیں (دوزخ اور جحیم کی) تاریکیوں سے نور (جنت و نعیم) کی طرف نکال لائے اور وہ اہلِ ایمان پر بڑا رحم کرنے والا ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvii{جس دن وہ اس کی بارگاہ میں حاضر ہوں گے تو ان کو سلام سے دعا دی جائے گی (کہ تم سلامت رہو) اور اس نے ان کیلئے باعزت اجر (بہشت) تیار کر رکھا ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxviii{اے نبی(ص)! ہم نے آپ کو (لوگوں کا) گواہ بنا کر اور (نیکوکاروں کو) خوشخبری دینے والا اور (بدکاروں کو) ڈرانے والا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxix{اور اللہ کی طرف اس کے حکم سے بلانے والا اور (رشد و ہدایت کا) روشن چراغ بنا کر بھیجا ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxx{اور ایمان والوں کو خوشخبری دیجئے کہ اللہ کی طرف سے ان کیلئے بڑا فضل و کرم ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxi{اور (خبردار) کافروں اور منافقوں کی اطاعت نہ کیجئے گا اور ان کی اذیت رسانی کو چھوڑ دیجئے (اس کی پرواہ نہ کریں) اور اللہ پر بھروسہ کیجئے اور کارسازی کیلئے اللہ کافی ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxii{اے ایمان والو! جب تم مؤمن عورتوں سے نکاح کرو اور پھر انہیں ہاتھ لگانے (مباشرت کرنے) سے پہلے طلاق دے دو تو تمہاری طرف سے ان پر کوئی عدت نہیں ہے جسے تم شمار کرو (اور جس کے دنوں کو گنو) لہٰذا انہیں کچھ مال دے کر اور خوبصورتی سے رخصت کر دو۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiii{اے نبی(ص)! ہم نے آپ کیلئے آپ کی وہ بیویاں حلال کر دی ہیں جن کے مہر آپ نے ادا کر دیئے ہیں اور وہ مملوکہ کنیزیں جو اللہ نے بطورِ غنیمت آپ کو عطا کی ہیں اور آپ کے چچا کی بیٹیاں اور آپ کی پھوپھیوں کی بیٹیاں اور آپ کے ماموں کی بیٹیاں اور آپ کی خالاؤں کی بیٹیاں جنہوں نے آپ کے ساتھ ہجرت کی ہے (یہ سب بھی حلال ہیں) اور اس مؤمن عورت کو بھی (حلال کیا ہے) اگر وہ اپنا نفس نبی(ص) کو ھبہ کر دے بشرطیکہ نبی(ص) بھی اس سے نکاح کرنا چاہیں یہ (اجازت) صرف آپ کیلئے ہے دوسرے مؤمنوں کیلئے نہیں ہے ہم جانتے ہیں جو (احکام) ہم نے ان پر ان کی بیویوں اور مملوکہ کنیزوں کے بارے میں مقرر کئے ہیں تاکہ آپ پر کسی قسم کی تنگی نہ ہو اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiv{(آپ کو اختیار ہے کہ) اپنی ازواج میں سے جس کو چاہیں دور کر دیں اور جس کو چاہیں اپنے پاس رکھیں اور جن کو آپ نے علیٰحدہ کر دیا تھا اگر ان میں سے کسی کو (دوبارہ) طلب کرنا چاہیں تو اس میں بھی آپ کیلئے کوئی مضائقہ نہیں ہے یہ (اختیار جو آپ کو دیا گیا ہے) اس سے قریب تر ہے کہ ان (ازواج) کی آنکھیں ٹھنڈی ہوں اور وہ رنجیدہ نہ ہوں اور آپ انہیں جو کچھ عطا فرمائیں وہ سب کی سب اس پر خوش ہو جائیں اور جو کچھ تمہارے دلوں میں ہے اللہ اسے جانتا ہے اور (بے شک) اللہ بڑا جاننے والا (اور) بڑا بردبار ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxv{اب اس کے بعد اور عورتیں آپ کیلئے حلال نہیں ہیں اور نہ ہی اس کی اجازت ہے کہ ان کے بدلے اور بیویاں لے آئیں اگرچہ ان کا حسن و جمال آپ کو کتنا ہی پسند ہو۔ سوائے ان (کنیزوں) کے جو آپ کی ملکیت میں ہیں اور اللہ ہر چیز کا نگران ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvi{اے ایمان والو! نبی(ص) کے گھروں میں داخل نہ ہوا کرو۔ مگر جب تمہیں کھانے کیلئے (اندر آنے کی) اجازت دی جائے (اور) نہ ہی اس کے پکنے کا انتظار (نبی(ص) کے گھر میں بیٹھ کر کیا) کرو۔ لیکن جب تمہیں بلایا جائے تو (عین وقت پر) اندر داخل ہو جاؤ پھر جب کھانا کھا چکو تو منتشر ہو جاؤ اور دل بہلانے کیلئے باتوں میں نہ لگے رہو کیونکہ تمہاری باتیں نبی(ص) کو اذیت پہنچاتی ہیں مگر وہ تم سے شرم کرتے ہیں (اور کچھ نہیں کہتے) اور اللہ حق بات (کہنے سے) نہیں شرماتا اور جب تم ان (ازواجِ نبی(ص)) سے کوئی چیز مانگو تو پردے کے پیچھے سے مانگا کرو۔ یہ (طریقۂ کار) تمہارے دلوں کیلئے اور ان کے دلوں کیلئے پاکیزگی کا زیادہ باعث ہے اور تمہارے لئے جائز نہیں ہے کہ تم رسولِ(ص) خدا کو اذیت پہنچاؤ اور نہ یہ جائز ہے کہ ان کے بعد کبھی بھی ان کی بیویوں سے نکاح کرو بیشک یہ بات اللہ کے نزدیک بہت بڑی (برائی گناہ کی) بات ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvii{تم اگر کسی چیز کو ظاہر کرو یا اسے چھپاؤ۔ بہرحال اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxviii{ان (ازواج النبی(ص)) کیلئے اس بات میں کوئی مضائقہ نہیں کہ ان کے باپ، ان کے بیٹے، ان کے بھائی، ان کے بھتیجے، بھانجے اور ان کی اپنی (مسلمان) عورتیں اور ان کی مملوکہ کنیزیں (ان کے) سامنے آئیں اور اللہ سے ڈرتی رہو۔ بے شک اللہ ہر چیز پر گواہ ہے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxix{بے شک اللہ اور اس کے فرشتے نبی(ص) پر درود بھیجتے ہیں اے ایمان والو! تم بھی ان پر درود و سلام بھیجو جس طرح بھیجنے کا حق ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdxc{بے شک جو لوگ اللہ اور اس کے رسول(ص) کو اذیت پہنچاتے ہیں اللہ ان پر دنیا و آخرت میں لعنت کرتا ہے اور ان کیلئے رسوا کرنے والا عذاب مہیا کر رکھا ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdxci{اور جو لوگ مؤمن مردوں اور مؤمن عورتوں کو اذیت پہنچاتے ہیں بغیر اس کے کہ انہوں نے کوئی (جرم) کیا ہو۔ بے شک وہ ایک بڑے بہتان اور کھلے ہوئے گناہ کا بوجھ اٹھاتے ہیں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdxcii{اے نبی(ص)! آپ اپنی بیویوں، بیٹیوں اور (عام) اہلِ ایمان کی عورتوں سے کہہ دیجئے کہ وہ (باہر نکلتے وقت) اپنے اوپر چادر (بطور گھونگھٹ) لٹکا لیا کریں یہ طریقہ قریب تر ہے کہ وہ پہچان لی جائیں اور ستائی نہ جائیں اور اللہ بڑا بخشنے والا، رحم کرنے والا ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdxciii{اگر منافقین اور وہ لوگ جن کے دلوں میں بیماری ہے اور مدینہ میں افواہیں پھیلانے والے (اپنی حرکتوں سے) باز نہ آئے تو ہم آپ کو ان کے خلاف حرکت میں لے آئیں گے پھر وہ (مدینہ) میں آپ کے پڑوس میں نہیں رہ سکیں گے مگر بہت کم۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdxciv{وہ بھی لعنت کے مارے ہوئے وہ جہاں کہیں پائے جائیں گے پکڑے جائیں گے اور بری طرح قتل کئے جائیں گے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdxcv{جو (ایسے لوگ) ان سے پہلے گزر چکے ہیں ان میں بھی اللہ کا یہی دستور رہا ہے اور آپ اللہ کے دستور میں کوئی تبدیلی نہیں پائیں گے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvi{لوگ آپ سے قیامت کے بارے میں دریافت کرتے ہیں (کب آئے گی؟) آپ کہہ دیجئے! کہ اس کا علم تو بس اللہ ہی کے پاس ہے (اے سائل!) تمہیں کیا خبر شاید قیامت قریب ہی ہو؟\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvii{بے شک اللہ نے کافروں پر لعنت کی ہے اور ان کیلئے بھڑکتی ہوئی آگ تیار کر رکھی ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdxcviii{جس میں وہ ہمیشہ ہمیشہ رہیں گے وہ (وہاں) کوئی حامی و مددگار نہیں پائیں گے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdxcix{جس دن ان کے چہرے (دوزخ کی) آگ میں الٹ پلٹ کئے جائیں گے تو وہ کہیں کہ کاش ہم نے اللہ کی اطاعت کی ہوتی اور (کاش) ہم نے رسول(ص) کی اطاعت کی ہوتی۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdc{اور وہی کہیں گے اے ہمارے پروردگار! ہم نے اپنی سرداروں کی اطاعت کی۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdci{سو انہوں نے (سیدھے) راستہ سے ہمیں بھٹکا دیا اے ہمارے پرورگار! انہیں دوہرا عذاب دے اور ان پر بہت بڑی لعنت کر۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcii{اے ایمان والو! ان لوگوں کی طرح نہ ہو جاؤ جنہوں نے موسیٰ(ع) کو اذیت پہنچائی تھی تو اللہ نے انہیں ان کی ان باتوں (تہمتوں) سے بَری کر دیا اور وہ اللہ کے نزدیک بڑے معزز تھے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdciii{اے ایمان والو! اللہ (کی نافرمانی) سے ڈرو اور درستی و راستی کی بات کہا کرو۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdciv{اللہ تمہارے اعمال کی اصلاح کرے گا۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcv{بے شک ہم نے امانت کو آسمانوں اور زمین اور پہاڑوں پر پیش کیا مگر ان سب نے اس کے اٹھانے سے انکار کیا اور وہ اس سے ڈر گئے اور انسان نے اسے (بلا تامل) اٹھا لیا بے شک وہ بڑا ظالم اور جاہل ہے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcvi{تاکہ خدا منافق مردوں اور منافق عورتوں اور مشرک مردوں اور منافق عورتوں کو سزا دے اور (تاکہ) مؤمن مردوں اور مؤمن عورتوں کی توبہ قبول کرے (ان پر نظرِ توجہ فرمائے) اور بے شک اللہ بڑا بخشنے والا، رحم کرنے والا ہے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcvii{\basmalahur ہر قِسم کی تعریف اس خدا کیلئے ہے جو آسمانوں اور زمین کی ہر چیز کا مالک ہے اور آخرت میں بھی ہر قسم کی تعریف اسی کیلئے ہے اور وہ بڑا حکمت والا، بڑا باخبر ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdcviii{وہ جانتا ہے جو کچھ زمین کے اندر داخل ہوتا ہے اور جو کچھ اس سے نکلتا ہے اور جو کچھ آسمان سے اترتا ہے اور جو کچھ اس میں چڑھتا ہے وہ بڑا رحم کرنے والا، بڑا بخشنے والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdcix{اور کافر کہتے ہیں کہ ہم پر قیامت نہیں آئے گی آپ کہہ دیجئے! کہ وہ ضرور آئے گی مجھے قَسم ہے اپنے پروردگار کی جو عالم الغیب ہے جس سے آسمانوں اور زمین کی ذرہ برابر کوئی چیز پوشیدہ نہیں ہے اور نہ اس (ذرہ) سے کوئی چھوٹی چیز ہے اور نہ بڑی مگر وہ کتابِ مبین میں (درج) ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdcx{(اور قیامت اس لئے آئے گی) تاکہ خدا ان لوگوں کو جزا دے جو ایمان لائے اور نیک عمل کئے یہی وہ (خوش قسمت) لوگ ہیں جن کیلئے بخشش اور باعزت رزق ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdcxi{اور جو لوگ ہماری آیتوں کے بارے میں (انہیں جھٹلا کر ہمیں) ہرانے کی کوشش کرتے ہیں یہی وہ (بدبخت) لوگ ہیں جن کیلئے سخت قسم کا دردناک عذاب ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdcxii{اور جنہیں علم دیا گیا ہے وہ جانتے ہیں وہ کچھ (قرآن) آپ کے پروردگار کی طرف سے آپ پر نازل کیا گیا ہے وہ حق ہے اور وہ غالب اور لائقِ ستائش (خدا) کے راستہ کی طرف راہنمائی کرتا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiii{اور کافر (ایک دوسرے سے) کہتے ہیں کہ کیا ہم تمہیں ایسا آدمی بتائیں جو تمہیں خبر دیتا ہے کہ جب تم (مرنے کے بعد) بالکل ریزہ ریزہ کر دیئے جاؤگے تو تم ازسرِنو پیدا کئے جاؤگے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiv{کیا یہ اللہ پر جھوٹا بہتان باندھتا ہے یا اسے جنون ہے (پیغمبرِ اسلام(ص) تو نہیں) بلکہ وہ لوگ جو آخرت پر ایمان نہیں رکھتے وہ عذاب اور دور دراز کی گمراہی (سخت گمراہی) میں مبتلا ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdcxv{کیا انہوں نے اسے نہیں دیکھا جو ان کے آگے پیچھے ہے (ان کو محیط ہے) یعنی آسمان و زمین! اگر ہم چاہیں تو انہیں زمین میں دھنسا دیں یا ان پر آسمان کے کچھ ٹکڑے گرا دیں۔ بے شک اس میں اللہ کی طرف رجوع کرنے والے بندہ کیلئے ایک نشانی ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvi{اور بلاشبہ ہم نے داؤد(ع) کو اپنے ہاں سے (بڑی) فضیلت عطا کی تھی (اور پہاڑوں سے کہا) اے پہاڑو ان کے ساتھ تسبیح کرو اور پرندوں کو بھی (یہی حکم دیا) اور ہم نے ان کیلئے لوہا نرم کر دیا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvii{اور ان سے کہا کہ کشادہ زرہیں بناؤ اور کڑیوں کے جوڑنے میں مناسب اندازہ رکھو اور (اے آلِ داؤد(ع)) تم سب نیک عمل کرو (کیونکہ) تم لوگ جو کچھ کرتے ہو میں خوب دیکھ رہا ہوں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdcxviii{اور ہم نے سلیمان(ع) کیلئے ہوا کو مسخر کر دیا جس کا صبح کا سفر ایک مہینہ کی راہ تک تھا اور شام کا ایک مہینہ کی راہ تک اور ہم نے ان کیلئے پگھلے ہوئے تانبے کا چشمہ جاری کیا اور جنات میں سے کچھ ایسے تھے جو ان (سلیمان(ع)) کے پروردگار کے حکم سے ان کے سامنے کام کرتے تھے اور ان (جنوں) میں سے جو ہمارے حکم سے سرتابی کرتا تھا ہم اسے بھڑکتی ہوئی آگ کا مزہ چکھاتے تھے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdcxix{وہ ان کیلئے وہ کچھ کرتے تھے جو وہ چاہتے تھے (جیسے) محرابیں (مقدس اونچی عمارتیں) اور مجسمے اور بڑے بڑے پیالے جیسے حوض اور گڑی ہوئی دیگیں۔ اے داؤد(ع) کے خاندان والو! (میرا) شکر ادا کرو اور میرے بندوں میں شکر گزار بہت ہی کم ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcxx{اور جب ہم نے سلیمان(ع) پر موت کا فیصلہ نافذ کیا (اور وہ فوت ہوگئے) تو ان کی موت کا پتہ ان (جنات) کو نہیں دیا مگر اس دیمک نے جو ان کے عصا کو کھا رہی تھی تو جب (عصا کھوکھلا ہوگیا اور) آپ زمین پر گرے تو جنات پر اصلی حالت کھل گئی کہ اگر وہ غیب جانتے ہوتے تو (اتنے عرصے تک) اس رسوا کن عذاب میں مبتلا نہ رہتے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxi{قبیلہ سباء والوں کیلئے ان کی آبادی میں (قدرتِ خدا کی) ایک نشانی موجود تھی (یعنی) دو باغ تھے دائیں اور بائیں (اور ان سے کہہ دیا گیا) کہ اپنے پروردگار کے رزق سے کھاؤ اور اس کا شکر ادا کرو شہر ہے پاک و پاکیزہ اور پروردگار ہے بخشنے والا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxii{پس انہوں نے روگردانی کی تو ہم نے ان پر بند توڑ سیلاب چھوڑ دیا اور ان کے ان دو باغوں کو ایسے دو باغوں سے بدل دیا جن کے پھل بدمزہ تھے اور جھاؤ کے کچھ درخت اور کچھ تھوڑی سی بیریاں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiii{یہ ہم نے انہیں ان کے ناشکراپن کی پاداش میں سزا دی اور کیا ہم ایسی سزا ناشکرے انسان کے سوا کسی اور کو دیتے ہیں؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiv{اور ہم نے ان کے اور ان کی بستیوں کے درمیان جن کو ہم نے برکت دی تھی (سرِ راہ) کئی اور نمایاں بستیاں بسا دیں اور ہم نے ان میں سفر کی منزلیں ایک اندازے پر مقرر کر دیں کہ (جب چاہو) راتوں میں، دنوں میں امن و عافیت سے چلو پھرو۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxv{(مگر) انہوں نے کہا اے ہمارے پروردگار ہمارے سفروں (ان کی مسافتوں) کو دور دراز کر دے اور (یہ کہہ کر) انہوں نے اپنے اوپر ظلم کیا سو ہم نے انہیں (برباد) کرکے افسانہ بنا دیا اور بالکل ٹکڑے ٹکڑے کر دیا بے شک اس میں نشانیاں ہیں ہر بہت صبر کرنے (اور) بہت شکر کرنے والے کیلئے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvi{بیشک شیطان نے ان لوگوں کے بارے میں اپنا خیال سچا کر دکھایا چنانچہ انہوں نے اس کی پیروی کی۔ سوائے اہلِ ایمان کے ایک گروہ کے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvii{اور شیطان کو ان پر ایسا اقتدار نہیں تھا کہ جس سے وہ بے اختیار ہو جائیں لیکن یہ سب کچھ اس لئے کہ ہم معلوم کریں کہ کون آخرت پر ایمان رکھتا ہے اور کون اس سے متعلق شک میں ہے اور آپ کا پروردگار ہر چیز پر نگران و نگہبان ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxviii{اے رسول(ص)! (ان مشرکین سے) کہیے! تم ان کو پکارو جنہیں تم اللہ کے سوا (معبود) سمجھتے ہو( پھر دیکھو) وہ ذرہ بھر چیز کے بھی مالک نہیں ہیں، نہ آسمانوں اور زمین میں اور نہ ہی ان کی ان دونوں (کی ملکیت) میں کوئی شرکت ہے اور نہ ہی ان میں سے کوئی اس (اللہ) کا مددگار ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxix{اور نہ اس (اللہ) کے ہاں کوئی سفارش (کسی کو کوئی) فائدہ دے گی مگر اس کے حق میں جس کیلئے وہ اجازت دے گا (اور جس کو دے گا) یہاں تک کہ جب ان کے دلوں سے گھبراہٹ دور کر دی جائے گی تو وہ پوچھیں گے کہ تمہارے پروردگار نے کیا کہا ہے؟ تو وہ کہیں گے کہ اس نے حق کہا ہے اور وہ بلند و بالا اور بزرگ و برتر ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxx{آپ کہیے! کہ آسمانوں اور زمین سے تمہیں کون روزی دیتا ہے؟ (پھر) فرمائیے! کہ اللہ! اور بے شک ہم یا تم ہدایت پر ہیں یا کھلی ہوئی گمراہی میں ہیں؟ ۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxi{آپ کہہ دیجئے! کہ تم سے ہمارے جرائم کی بابت بازپرس نہیں ہوگی اور نہ ہم سے تمہارے اعمال کے بارے میں سوال ہوگا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxii{آپ کہیے (ایک دن) ہمارا پروردگار ہم سب کو جمع کرے گا پھر ہمارے درمیان حق کے ساتھ فیصلہ کرے گا اور وہ بڑا فیصلہ کرنے والا (حاکم اور) بڑا جاننے والا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiii{آپ کہیے! (ذرا) مجھے تو دکھاؤ وہ جنہیں تم نے شریک بنا کر اس (اللہ) کے ساتھ ملا رکھا ہے؟ ہرگز نہیں! بلکہ وہ اللہ ہی ہے جو بڑا غالب (اور) بڑا حکمت والا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiv{اور ہم نے آپ کو نہیں بھیجا مگر تمام انسانوں کیلئے بشیر و نذیر بنا کر مگر اکثر لوگ جانتے نہیں ہیں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxv{اور وہ کہتے ہیں کہ اگر تم سچے ہو تو (بتاؤ) یہ وعدہ وعید کب پورا ہوگا؟\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvi{آپ کہیے! تمہارے لئے وعدہ کا ایک دن مقرر ہے جس سے نہ تم ایک گھڑی پیچھے ہٹ سکتے ہو اور نہ آگے بڑھ سکتے ہو۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvii{اور کافر کہتے ہیں کہ ہم نہ اس قرآن پر ایمان لائیں گے اور نہ اس سے پہلے نازل شدہ کتابوں پر (یا نہ اس پر جو اس کے آگے ہے یعنی قیامت اور اس کے عذاب پر)۔ (اے پیغمبر(ص)) کاش تم دیکھتے جب ظالم لوگ اپنے پروردگار کے حضور (سوال و جواب کیلئے) کھڑے کئے جائیں گے (اور) ایک دوسرے کی بات رد کر رہا ہوگا چنانچہ وہ لوگ جو دنیا میں کمزور سمجھے جاتے تھے وہ ان سے کہیں گے جو بڑے بنے ہوئے تھے کہ اگر تم نہ ہوتے تو ہم ضرور ایمان لے آئے ہوتے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxviii{بڑے لوگ کمزور لوگوں سے (جواب میں) کہیں گے کیا ہم نے تمہیں ہدایت سے روکا تھا جبکہ وہ تمہارے پاس آئی تھی۔ بلکہ تم خود ہی مجرم ہو۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxix{اور کمزور لوگ (جواب میں) بڑا بننے والوں سے کہیں گے کہ (اس طرح نہیں) بلکہ یہ (تمہارے) شب و روز کے مکر و فریب نے ہمیں قبولِ حق سے باز رکھا جبکہ تم ہمیں حکم دیتے تھے کہ ہم اللہ کے ساتھ کفر کریں اور اس کے ہمسر (شریک) ٹھہرائیں اور یہ لوگ جب عذابِ الٰہی کو دیکھیں گے تو ندامت و پشیمانی کو دل میں چھپائیں گے (دلوں میں پچھتائیں گے) اور ہم کافروں کی گردنوں میں طوق ڈالیں گے یہ لوگ (دنیا میں) جیسے عمل کرتے تھے (آج) ان کا ہی ان کو بدلہ دیا جائے گا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxl{اور ہم نے جب بھی کسی بستی میں کوئی ڈرانے والا (نبی(ع)) بھیجا تو وہاں کے آسودہ حال لوگوں نے یہی کہا کہ جس (دین) کے ساتھ تم بھیجے گئے ہو ہم اسے نہیں مانتے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxli{اور ہمیشہ یہ بھی کہا ہم مال و اولاد میں تم سے بڑھے ہوئے ہیں اور ہم کو کبھی عذاب نہیں دیا جائے گا۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlii{کہہ دیجئے! کہ میرا پروردگار (اپنے بندوں میں سے) جس کیلئے چاہتا ہے رزق کشادہ کر دیتا ہے اور جس کیلئے چاہتا ہے تنگ کر دیتا ہے لیکن اکثر لوگ (اس حقیقت کو) جانتے نہیں ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliii{اور تمہارے مال اور تمہاری اولاد (کوئی ایسی چیز نہیں ہیں) جو تمہیں ہمارا مقرب بارگاہ بنائیں مگر وہ جو ایمان لائے اور نیک عمل کرے (اسے ہمارا قرب حاصل ہوگا) ایسے لوگوں کیلئے ان کے عمل کی دوگنی جزا ہے اور وہ بہشت کے اونچے اونچے درجوں میں امن و اطمینان سے رہیں گے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliv{اور جو لوگ ہماری آیتوں کے بارے میں (ہمیں نیچا دکھانے کیلئے) کوشش کرتے ہیں وہ عذاب میں حاضر کئے جائیں گے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlv{آپ(ص) کہہ دیجئے! میرا پروردگار اپنے بندوں میں سے جس کا چاہتا ہے رزق کشادہ کر دیتا ہے اور جس کا چاہتا ہے تنگ کر دیتا ہے اور جو کچھ تم (راہِ خدا میں) خرچ کرتے ہو تو وہ اس کی جگہ عطا کرتا ہے اور وہ بہترین روزی دینے والا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvi{اور جس دن وہ لوگوں کو جمع کرے گا پھر فرشتوں سے کہے گا (پوچھے گا) کیا یہ لوگ تمہاری ہی عبادت کرتے تھے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvii{وہ کہیں گے پاک ہے تیری ذات! تو ہمارا آقا ہے نہ کہ وہ (ہمارا تعلق تجھ سے ہے نہ کہ ان سے) بلکہ یہ تو جنات کی عبادت کیا کرتے تھے ان کی اکثریت انہی پر ایمان و اعتقاد رکھتی تھی۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlviii{(ارشادِ قدرت ہوگا) آج تم میں سے کوئی نہ کسی دوسرے کو نفع پہنچا سکے گا اور نہ نقصان اور ہم ظالموں سے کہیں گے کہ اب عذاب جہنم کا مزہ چکھو جسے تم جھٹلایا کرتے تھے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlix{اور جب ان کے سامنے ہماری واضح آیتیں پڑھ کر سنائی جاتی ہیں تو وہ کہتے ہیں کہ یہ شخص تو بس یہ چاہتا ہے کہ تمہیں تمہارے باپ دادا کے معبودوں سے روکے اور کہتے ہیں کہ یہ (قرآن) نہیں ہے مگر گھڑا ہوا جھوٹ اور جب بھی کافروں کے پاس حق آیا تو انہوں نے یہی کہا کہ یہ تو کھلا ہوا جادو ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcl{حالانکہ ہم نے نہ انہیں کوئی کتابیں دیں جنہیں وہ پڑھتے ہیں اور نہ ہی آپ سے پہلے ان کی طرف کوئی ڈرانے والا (نبی) بھیجا ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcli{اور وہ ان سے پہلے گزرے ہوئے (نبیوں کو) جھٹلا چکے ہیں اور جو کچھ (ساز و سامان اور قوت و طاقت) ان کو عطا کیا تھا یہ (کفارِ مکہ) تو اس کے عشرِ عشیر کو بھی نہیں پہنچے۔ لیکن جب انہوں نے میرے رسولوں کو جھٹلایا تو میری سزا کیسی (سخت) تھی؟\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdclii{(اے نبی(ص)) آپ کہہ دیجئے! میں تمہیں صرف ایک بات کی نصیحت کرتا ہوں کہ تم دو، دو اور ایک ایک ہو کر خدا کیلئے کھڑے ہو جاؤ اور پھر غور و فکر کرو (ضرور تمہیں معلوم ہو جائے گا کہ) تمہارے ساتھی (رسولِ(ص) خدا) میں کسی قسم کا کوئی جنون (اور دیوانگی) نہیں ہے وہ تو صرف ایک سخت عذاب کے آنے سے پہلے تمہیں ڈرانے والا ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcliii{کہہ دیجئے! میں نے (تبلیغِ رسالت(ص) کے سلسلہ میں) تم سے جو اجر مانگا ہے وہ تمہارے ہی (فائدہ کے) لئے ہے میری اجرت تو بس اللہ کے ذمہ ہے اور وہ ہر چیز پر گواہ ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcliv{کہہ دیجئے! کہ میرا پروردگار جوکہ بڑا غیب دان ہے حق کو (باطل پر) ڈالتا (مارتا) ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdclv{آپ(ص) کہہ دیجئے! حق آگیا ہے اور باطل نہ کچھ ایجاد کر سکتا ہے اور نہ دوبارہ پلٹا سکتا ہے (بالکل مٹ گیا ہے)۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdclvi{کہہ دیجئے! اگر (تمہارے خیال کے مطابق) میں گمراہ ہوگیا ہوں تو اس کا وِزر و وبال میری جان پر ہے اور اگر میں ہدایت یافتہ ہوں تو یہ اس وحی کا ثمرہ ہے جو میرا پروردگار میری طرف بھیجتا ہے بے شک وہ بڑا سننے والا بالکل قریب ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdclvii{اور کاش تم دیکھو کہ جب یہ لوگ گھبرائے ہوئے (پریشان حال) ہوں گے لیکن بچ نکلنے کا کوئی موقع نہ ہوگا اور وہ قریبی جگہ سے پکڑ لئے جائیں گے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdclviii{اور (اب) وہ کہیں گے کہ ہم اس پر ایمان لے آئے۔ مگر اتنی دور دراز جگہ سے اب اس (ایمان) پر دسترس کہاں؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdclix{حالانکہ اس سے پہلے تو وہ اس (ایمان) کا انکار کرتے رہے اور (بلاتحقیق) بہت دور سے اَٹکَل کے تُکے چلاتے رہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdclx{سو اب ان کے اور ان چیزوں کے درمیان جن کے یہ خواہش مند ہیں رکاوٹ کھڑی کر دی جائے گی۔ جیساکہ اس سے پہلے ان کے ہم مشربوں کے ساتھ کیا جا چکا ہے یقیناً وہ بڑے شبہ اور شک میں مبتلا تھے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdclxi{\basmalahur سب تعریفیں اللہ ہی کیلئے ہیں جو آسمانوں اور زمین کا پیدا کرنے والا ہے (اور) فرشتوں کو پیغام رساں بنانے والا ہے جن کے دو دو، تین تین اور چار چار پر اور بازو ہیں۔ وہ (اپنی مخلوق کی) خلقت میں جب چاہتا ہے اضافہ کرتا ہے۔ بیشک اللہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdclxii{اور اللہ لوگوں کیلئے (اپنی) رحمت (کا جو دروازہ) کھول دے اسے کوئی روکنے والا نہیں ہے اور جسے وہ بند کر دے اسے اس (اللہ) کے بعد کوئی کھولنے والا نہیں ہے وہ زبردست (اور) بڑا حکمت والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiii{اے لوگو! اللہ کے وہ احسانات یاد کرو جو اس نے تم پر کئے ہیں کیا اللہ کے سوا کوئی اور ہے جو تمہیں آسمان اور زمین سے روزی دیتا ہو؟ اس کے سوا کوئی الٰہ نہیں ہے تم کہاں الٹے چلے جا رہے ہو؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiv{(اے رسول(ص)!) اور اگر یہ لوگ آپ(ص) کو جھٹلاتے ہیں تو آپ(ص) سے پہلے بھی بہت سے پیغمبر جھٹلائے گئے اور تمام معاملات کی بازگشت خدا ہی کی طرف ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdclxv{اے لوگو! اللہ کا وعدہ یقیناً سچا ہے (خیال رکھنا) زندگانیٔ دنیا کہیں تمہیں دھوکے میں نہ ڈال دے اور نہ ہی بڑا دھوکہ باز (شیطان) تمہیں اللہ کے بارے میں دھوکہ دے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvi{بے شک شیطان تمہارا دشمن ہے۔ لہٰذا تم بھی اسے (اپنا) دشمن ہی سمجھو، وہ اپنے گروہ کو اس لئے بلاتا ہے کہ وہ دوزخیوں میں سے ہو جائیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvii{جن لوگوں نے کفر اختیار کیا ان کیلئے سخت عذاب ہے اور جو لوگ ایمان لائے اور نیک عمل کئے ان کیلئے مغفرت اور بڑا اجر ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdclxviii{بھلا وہ شخص جس کا برا عمل (اس کی نگاہ میں) خوشنما بنا دیا گیا ہو اور وہ اسے اچھا سمجھنے لگے (کیا وہ ایک مؤمنِ صالح کی مانند ہو سکتا ہے؟ یا کیا اس کی اصلاح کی کوئی امید ہو سکتی ہے؟) بے شک اللہ جسے چاہتا ہے گمراہی میں چھوڑ دیتا ہے اور جسے چاہتا ہے ہدایت دیتا ہے۔ پس ان (بدبختوں) کے بارے میں افسوس کرتے کرتے آپ کی جان نہ چلی جائے۔ جو کچھ یہ لوگ کر رہے ہیں یقیناً اللہ اسے خوب جانتا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdclxix{اور اللہ ہی وہ (قادر) ہے جو ہواؤں کو بھیجتا ہے تو وہ بادل کو حرکت میں لاتی (اٹھاتی) ہیں پھر ہم اسے ایک مردہ (اجاڑ) شہر کی طرف لے جاتے ہیں پھر ہم اس کے ذریعہ سے زمین کو اس کے مردہ (اجاڑ) ہونے کے بعد زندہ (سرسبز) کر دیتے ہیں اسی طرح (قیامت کے دن لوگوں کا) جی اٹھنا ہوگا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdclxx{جو کوئی عزت کا طلبگار ہے (تو وہ سمجھ لے) کہ ساری عزت اللہ ہی کیلئے ہے (لہٰذا وہ خدا سے طلب کرے) اچھے اور پاکیزہ کلام اس کی طرف بلند ہوتے ہیں اور نیک عمل انہیں بلند کرتا ہے (یا اللہ نیک عمل کو بلند کرتا ہے) اور جو لوگ (آپ کے خلاف) برائیوں کے منصوبے بناتے ہیں (بری تدبیریں کرتے ہیں) ان کیلئے سخت عذاب ہے (اور ان کا مکر و فریب آخرکار) نیست و نابود ہو جائے گا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxi{اور اللہ ہی نے تمہیں مٹی سے پیدا کیا ہے پھر نطفے سے پھر تمہیں جوڑا جوڑا (نر و مادہ) بنا دیا اور کوئی عورت حاملہ نہیں ہوتی اور بچہ نہیں جنتی مگر اس (اللہ) کے علم سے اور نہ کسی شخص کی عمر میں زیادتی ہوتی ہے اور نہ کمی ہوتی ہے مگر یہ کہ وہ ایک کتاب (لوحِ محفوظ) میں موجود ہے اور یقیناً یہ بات اللہ کیلئے آسان ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxii{اور پانی کے دونوں (ذخیرے) برابر نہیں ہیں یہ ایک میٹھا پیاس بجھانے والا ہے (اور) پینے میں خوشگوار اور دوسرا سخت کھاری اور کڑوا ہے اور تم ہر ایک سے تازہ گوشت کھاتے ہو اور زیور برآمد کرکے پہنتے ہو اور تم اس کی کشتیوں کو دیکھتے ہو کہ وہ پانی کو چیرتی پھاڑتی چلی جاتی ہیں تاکہ تم اللہ کا فضل (رزق) تلاش کرو اور تاکہ شکر گزار بنو۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiii{وہ رات کو دن کے اندر داخل کرتا ہے اور اسی نے سورج اور چاند کو مسخر کر رکھا ہے (ان میں سے) ہر ایک (اپنی) مقررہ میعاد تک رواں دواں ہے یہ ہے اللہ تمہارا پروردگار! اسی کی حکومت ہے اور اسے چھوڑ کر جنہیں تم پکارتے ہو وہ کھجور کی گٹھلی کے چھلکے کے بھی مالک نہیں ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiv{اگر تم انہیں پکارو تو وہ تمہاری پکار کو سن نہیں سکتے۔ اور اگر (بالفرض) سنیں بھی تو وہ تمہاری التجا کو قبول نہیں کر سکتے اور قیامت کے دن تمہارے اس شرک کا انکار کریں گے (اس سے بیزاری کا اعلان کریں گے) اور خدائے خبیر کی طرح تمہیں اور کوئی خبر نہیں دے سکتا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxv{اے لوگو! تم (سب) اللہ کے محتاج ہو اور اللہ ہی بے نیاز ہے جو قابلِ تعریف ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvi{وہ اگر چاہے تو تم سب کو (عدم آباد کی طرف) لے جائے اور (تمہاری جگہ) کوئی نئی مخلوق لے آئے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvii{اور ایسا کرنا اللہ کیلئے کوئی مشکل کام نہیں ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxviii{اور کوئی بوجھ اٹھانے والا (گنہگار) کسی دوسرے کا بوجھ نہیں اٹھائے گا اور اگر کوئی بھاری بوجھ والا اس کے اٹھانے کیلئے (کسی کو) بلائے گا تو اس میں سے کچھ بھی نہ اٹھایا جائے گا اگرچہ وہ رشتہ دار ہی کیوں نہ ہو؟ (اے رسول(ص)!) آپ صرف انہی لوگوں کو ڈرا سکتے ہیں جو بے دیکھے اپنے پروردگار سے ڈرتے ہیں اور جو (باقاعدہ) نماز پڑھتے ہیں اور جو (گناہوں سے) پاکیزگی اختیار کرتا ہے تو وہ اپنے ہی فائدہ کیلئے پاکباز رہتا ہے (آخرکار) اللہ ہی کی طرف (سب کی) بازگشت ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxix{اور اندھا اور آنکھوں والا برابر نہیں ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxx{اور نہ اندھیرا (کفر) اور اجالا (ایمان) برابر ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxi{اور نہ ہی (ٹھنڈا) سایہ (بہشت) اور تیز دھوپ (جہنم) برابر ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxii{اور نہ ہی زندے (مؤمنین) اور مردے (کافرین) برابر ہیں۔ بے شک اللہ جسے چاہتا ہے سنوارتا ہے (اے رسول) جو (کفار مردوں کی طرح) قبروں میں دفن ہیں آپ انہیں نہیں سنا سکتے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiii{آپ تو صرف ڈرانے والے ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiv{بیشک ہم نے آپ کو حق کے ساتھ بشیر و نذیر (بشارت دینے والا اور ڈرانے والا) بنا کر بھیجا ہے اور کوئی امت ایسی نہیں (گزری) جس میں کوئی ڈرانے والا نہ گزرا ہو۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxv{اور اگر یہ لوگ آپ کو جھٹلاتے ہیں (تو یہ کوئی نئی بات نہیں) ان سے پہلے والے لوگ بھی جھٹلا چکے ہیں ان کے رسول(ع) ان کے پاس کھلے ہوئے نشان (معجزے) اور (آسمانی) صحیفے اور روشن (واضح ہدایت دینے والی) کتابیں لے کر آئے تھے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvi{پھر میں نے کافروں کو پکڑ لیا (دیکھو) میری سزا کیسی سخت تھی؟\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvii{کیا تم نے نہیں دیکھا کہ اللہ نے آسمان سے پانی برسایا اور پھر ہم نے اس کے ذریعہ سے مختلف رنگوں کے پھل نکالے اور (اسی طرح) پہاڑوں میں بھی مختلف رنگوں کی گھاٹیاں ہیں کوئی سفید اور کوئی سرخ اور بعض حصے گہرے سیاہ۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxviii{اور انسانوں، چلنے پھرنے والے جانوروں اور چوپایوں میں بھی اسی طرح مختلف رنگ پائے جاتے ہیں اور اللہ کے بندوں میں سے صرف علماء ہی اس سے ڈرتے ہیں بے شک اللہ غالب ہے (اور) بڑا بخشنے والا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxix{بے شک جو لوگ (کماحقہٗ) کتاب اللہ کی تلاوت کرتے ہیں اور باقاعدہ نماز پڑھتے ہیں اور جو کچھ ہم نے انہیں دیا ہے اس سے پوشیدہ اور اعلانیہ طور پر خرچ کرتے ہیں وہ ایک ایسی تجارت کے امیدوار ہیں جس میں تباہی (خسارہ) نہیں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxc{تاکہ وہ (اللہ) انہیں پورا پورا اجر عطا فرمائے اور اپنے فضل و کرم سے اور زیادہ دے۔ بیشک وہ بڑا بخشنے والا، بڑا قدر دان ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxci{اور جو کتاب ہم نے بذریعۂ وحی آپ(ص) کی طرف بھیجی ہے وہ برحق ہے اور اپنے سے پہلے والی کتابوں کی تصدیق کرنے والی ہے بیشک اللہ اپنے بندوں (کے حالات) سے باخبر (اور) بڑا دیکھنے والا نگران ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcii{پھر ہم نے اس کا وارث ان کو بنایا جن کو ہم نے اپنے بندوں میں سے منتخب کر لیا ہے پس ان بندوں سے بعض تو اپنے نفس پر ظلم کرنے والے ہیں اور بعض معتدل ہیں اور بعض اللہ کے اذن (اور اس کی توفیق) سے نیکیوں میں سبقت لے جانے والے ہیں یہی تو بہت بڑا فضل ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciii{(ان کا صلہ) سدا بہار بہشت ہیں جن میں وہ داخل ہوں گے وہاں ان کو سونے کے کنگن اور موتی پہنائے جائیں گے اور وہاں ان کا لباس ریشمی ہوگا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciv{اور وہ (بطور شکرانۂ نعمت کہیں گے سب تعریف اللہ) کیلئے ہے (اور اس کا شکر ہے) جس نے ہم سے رنج و غم دور کر دیا ہے بیشک ہمارا پروردگار بڑا بخشنے والا، بڑا قدر دان ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcv{جس نے ہمیں اپنے فضل و کرم سے ایسی دائمی قیامت کی جگہ پر اتارا ہے جہاں نہ کوئی زحمت ہوتی ہے اور نہ ہی تھکن محسوس ہوتی ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvi{اور جن لوگوں نے کفر اختیار کیا ان کیلئے دوزخ کی آگ ہے (وہاں) نہ ان کی موت کا فیصلہ کیا جائے گا کہ وہ مر جائیں اور نہ ہی ان کیلئے عذابِ جہنم میں کوئی کمی کی جائے گی ہم اسی طرح ہر ناشکرے کو سزا دیتے ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvii{اور وہ (دوزخی) اس میں چیخیں چلائیں گے اے ہمارے پروردگار! ہمیں یہاں سے نکال (اور دارِ دنیا میں بھیج) تاکہ ہم نیک عمل کریں ایسے نہیں جیسے پہلے کرتے تھے (ارشادِ قدرت ہوگا) کیا ہم نے تمہیں اتنی عمر نہیں دی تھی جس میں نصیحت قبول کرنے والا نصیحت قبول کر سکتا تھا؟ اور (علاوہ بریں) تمہارے پاس ڈرانے والا بھی آیا تھا اب (اپنے کئے کا) مزہ چکھو (آج) ظالموں کا کوئی یار و مددگار نہیں ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcviii{بیشک اللہ آسمانوں اور زمین کی پوشیدہ چیزوں کا جاننے والا ہے۔ یقیناً وہ دلوں کے رازوں سے خوب واقف ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcix{وہ وہی ہے جس نے تمہیں (گزشتہ لوگوں کا) جانشین بنایا سو جو کوئی کفر کرے گا۔ تو اس کے کفر (کا وبال) اسی پر پڑے گا اور کافروں کا کفران کے پروردگار کے ہاں سوائے قہر و غضبِ الٰہی کے اور کسی چیز میں اضافہ نہیں کرتا اور کافروں کا کفر صرف ان کے خسارے اور گھاٹے میں اضافہ کرتا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcc{آپ(ص) کہہ دیجئے! (اے مشرکو) کیا تم نے کبھی اپنے (خودساختہ) شریکوں کو دیکھا بھی ہے جنہیں تم اللہ کو چھوڑ کر پکارتے ہو مجھے دکھاؤ انہوں نے زمین میں کیا پیدا کیا ہے؟ یا ان کی آسمانوں میں شرکت ہے یا ہم نے انہیں کوئی کتاب دی ہے کہ وہ اس کی بناء پر (اپنے شرک کے جواز کی) کوئی سند رکھتے ہوں؟ (کچھ بھی نہیں) بلکہ (یہ) ظالم لوگ ایک دوسرے سے محض پُر فریب وعدے کرتے ہیں۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcci{بے شک اللہ (اپنی قدرتِ کاملہ) سے آسمانوں اور زمین کو تھامے ہوئے ہے کہ وہ اپنی جگہ سے ہٹ نہ جائیں اور اگر وہ (بالفرض) ہٹ جائیں تو اس کے سوا انہیں کون تھام سکتا ہے؟ بے شک وہ (اللہ) بڑا بردبار (اور) بڑا بخشنے والا ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccii{اور یہ لوگ (کفارِ مکہ) بڑی سخت قَسمیں کھا کر کہتے تھے کہ اگر ان کے پاس کوئی ڈرانے والا (پیغمبر) آیا تو وہ ہر ایک قوم سے بڑھ کر ہدایت قبول کرنے والے ہوں گے لیکن جب ان کے پاس ڈرانے والا آگیا تو اس (کی آمد) نے ان کی نفرت۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcciii{زمین میں سرکشی کرنے اور بری سازشیں کرنے میں اضافہ ہی کیا حالانکہ بری سازشیں تو اس کو گھیرتی ہیں جو بری سازش کرتا ہے سو کیا اب یہ لوگ پہلے والے لوگوں کے ساتھ خدا کے طریقۂ کار کا انتظار کر رہے ہیں (کہ ان کے ساتھ بھی وہی ہو) تم خدا کے دستور (طریقۂ کار) میں کوئی تبدیلی نہیں پاؤگے (کہ مقررہ قاعدے سے پھر جائے)۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcciv{کیا یہ لوگ زمین میں چلتے پھرتے نہیں ہیں کہ وہ دیکھتے کہ ان سے پہلے والے لوگوں کا انجام کیا ہوا تھا حالانکہ وہ قوت و طاقت میں ان سے بڑھے ہوئے تھے آسمانوں اور زمین میں کوئی ایسی چیز نہیں ہے جو اللہ کو عاجز (بے بس) کر سکے۔ وہ بڑا جاننے والا، بڑا قدرت رکھنے والا ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccv{اور اگر خدا لوگوں کا ان کے (برے) اعمال کی پاداش میں جلدی مواخذہ کرتا (پکڑتا) تو روئے زمین پر کوئی جاندار نہ چھوڑتا لیکن ان کو ایک مقررہ مدت تک مہلت دیتا ہے تو جب ان کی مدت پوری ہو جائے گی تو اللہ اپنے بندوں کو خوب دیکھنے والا (نگران) ہے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccvi{\basmalahur یاسین(ص)۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccvii{قرآنِ حکیم کی قسم۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccviii{یقیناً آپ(ص) (خدا کے) رسولوں میں سے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccix{(اور) سیدھے راستے پر ہی ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccx{(یہ قرآنِ) عزیز (غالب اور) بڑے مہربان کا نازل کیا ہوا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxi{تاکہ آپ اس قوم کو ڈرائیں جس کے باپ دادا کو (براہِ راست کسی پیغمبر سے) ڈرایا نہیں گیا اس لئے وہ غافل ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxii{ان میں سے اکثر پر (ان کے تعصب و عناد کی وجہ سے) یہ بات ثابت ہو چکی ہے کہ وہ ایمان نہیں لائیں گے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiii{ہم نے (ان کے پیہم کفر و عناد کی وجہ سے گویا) ان کی گردنوں میں (گمراہی اور شیطان کی غلامی کے) طوق ڈال دیئے ہیں جو ان کی ٹھوڑیوں تک آگئے ہیں اس لئے وہ سر اوپر اٹھائے ہوئے ہیں (لہٰذا وہ سر جھکا نہیں سکتے)۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiv{اور ہم نے ایک دیوار ان کے آگے کھڑی کر دی ہے اور ایک دیوار ان کے پیچھے کھڑی کر دی ہے (اس طرح) ہم نے انہیں ڈھانک دیا ہے پس وہ کچھ دیکھ نہیں سکتے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxv{ان کیلئے (دونوں باتیں) برابر ہیں خواہ آپ انہیں ڈرائیں یا نہ ڈرائیں وہ ایمان نہیں لائیں گے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvi{آپ تو صرف اس شخص کو ڈرا سکتے ہیں جو نصیحت کی پیروی کرے اور بے دیکھے خدائے رحمن سے ڈرے پس ایسے شخص کو مغفرت (بخشش) اور عمدہ اجر کی خوشخبری دے دیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvii{بے شک ہم ہی مُردوں کو زندہ کرتے ہیں اور ان کے وہ اعمال لکھ لیتے ہیں جو وہ آگے بھیج چکے ہیں اور ان کے وہ آثار بھی ثبت کرتے ہیں جو وہ اپنے پیچھے چھوڑ جاتے ہیں اور ہم نے ہر چیز کو امامِ مبین میں جمع کر دیا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccxviii{اور (ان کو سمجھانے کیلئے) بطورِ مثال ایک خاص بستی کا قصہ سنائیں جب ان کے پاس (ہمارے) پیغام رساں آئے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdccxix{(پہلے) ہم نے ان کی طرف دو (رسول) بھیجے تو انہوں نے ان دونوں کو جھٹلایا تو ہم نے انہیں تیسرے (رسول) کے ساتھ تقویت دی۔ چنانچہ تینوں نے کہا کہ ہم تمہارے پاس بھیجے گئے ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccxx{ان لوگوں نے کہا تم بس ہمارے ہی جیسے انسان ہو اور خدائے رحمٰن نے (تم پر) کوئی چیز نازل نہیں کی ہے تم بالکل جھوٹ بول رہے ہو۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxi{رسولوں(ع) نے کہا کہ ہمارا پروردگار خوب جانتا ہے کہ ہم تمہاری طرف بھیجے گئے ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxii{اور ہماری ذمہ داری صرف یہ ہے کہ ہم (خدا کا پیغام) صاف صاف پہنچا دیں۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiii{تو بستی والوں نے کہا کہ ہم تو تمہیں اپنے لئے فالِ بد سمجھتے ہیں (کہ تمہارے آنے سے قحط پڑ گیا ہے) اگر تم باز نہ آئے تو ہم تمہیں سنگسار کر دیں گے اور ہماری طرف سے تمہیں دردناک سزا ملے گی۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiv{رسولوں نے کہا کہ تمہاری فالِ بد تو تمہارے ساتھ ہے! کیا اگر تمہیں نصیحت کی جائے (تو یہ بات بدشگونی ہے)؟ حقیقت یہ ہے کہ تم حد سے بڑھ جانے والے لوگ ہو۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxv{اور ایک شخص شہر کے پرلے سرے سے دوڑتا ہوا آیا اور کہا اے میری قوم! رسولوں(ع) کی پیروی کرو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvi{ان لوگوں کی پیروی کرو جو تم سے کوئی معاوضہ نہیں مانگتے اور خود ہدایت یافتہ بھی ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvii{مجھے کیا ہوگیا ہے کہ میں اس ہستی کی عبادت نہ کروں جس نے مجھے پیدا کیا ہے حالانکہ تم سب اسی کی طرف لوٹائے جاؤگے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxviii{کیا میں اسے چھوڑ کر ایسے خداؤں کو اختیار کروں کہ اگر خدائے رحمن مجھے کوئی نقصان پہنچانا چاہے تو ان کی سفارش مجھے کوئی فائدہ نہ پہنچا سکے اور نہ ہی وہ مجھے چھڑا سکیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxix{(اگر میں ایسا کروں) تو میں اس وقت کھلی ہوئی گمراہی میں مبتلا ہوں گا۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxx{میں تو تمہارے پروردگار پر ایمان لے آیا ہوں تم میری بات (کان لگا کر) سنو (اور ایمان لے آؤ)۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxi{(انجامِ کار ان لوگوں نے اس مؤمن کو سنگسار کر دیا اور اس سے) کہا گیا کہ بہشت میں داخل ہو جا۔ وہ کہنے لگا کاش میری قوم کو معلوم ہو جاتا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxii{کہ میرے پروردگار نے کس وجہ سے مجھے بخش دیا ہے اور مجھے معزز لوگوں میں سے قرار دیا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiii{اور ہم نے اس (کی شہادت) کے بعد نہ تو اس کی قوم پر آسمان سے کوئی لشکر اتارا اور نہ ہی ہم کو (اتنی سی بات کیلئے لشکر) اتارنے کی ضرورت تھی۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiv{وہ (سزا) تو صرف ایک مہیب آواز (چنگھاڑ) تھی جس سے وہ ایک دم بجھ کر رہ گئے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxv{افسوس ہے (ایسے) بندوں پر کہ جب بھی ان کے پاس کوئی رسول آتا ہے تو یہ اس کا مذاق اڑاتے ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvi{کیا انہوں نے نہیں دیکھا کہ ہم ان سے پہلے کتنی قوموں کو ہلاک کر چکے ہیں (اور) وہ کبھی ان کی طرف لوٹ کر نہیں آئیں گے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvii{(ہاں البتہ) وہ سب (ایک بار) ہماری بارگاہ میں حاضر کئے جائیں گے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxviii{اور (ہماری نشانیوں میں سے) ان کیلئے ایک نشانی وہ مردہ زمین ہے جسے ہم نے زندہ کر دیا اور اس سے دانہ (غلہ) نکالا جس سے وہ کھاتے ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxix{اور ہم نے اس (زمین) میں کھجوروں اور انگوروں کے باغات پیدا کئے اور اس سے چشمے جاری کر دیئے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdccxl{تاکہ وہ اس کے پھلوں سے کھائیں حالانکہ یہ ان کے ہاتھوں کی کارگزاری نہیں ہے کیا یہ لوگ (اس پر بھی) شکر ادا نہیں کرتے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdccxli{پاک ہے وہ ذات جس نے سب اقسام کے جوڑے جوڑے پیدا کئے ہیں خواہ (نباتات) ہو جسے زمین اگاتی ہے یا خود ان کے نفوس ہوں (بنی نوع انسان) یا وہ چیزیں ہوں جن کو یہ نہیں جانتے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlii{اور ان کیلئے ایک نشانی رات بھی ہے جس سے ہم دن کو کھینچ لیتے ہیں تو ایک دم وہ اندھیرے میں رہ جاتے ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliii{اور (ایک نشانی) سورج ہے جو اپنے مقررہ ٹھکانے (مدار) کی طرف چل رہا ہے (گردش کر رہا ہے) یہ اندازہ اس (خدا) کا مقرر کیا ہوا ہے جو غالب ہے (اور) بڑا علم والا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliv{اور (ایک نشانی) چاند بھی ہے جس کی ہم نے منزلیں مقرر کر دی ہیں یہاں تک کہ وہ (آخر میں) کھجور کی پرانی شاخ کی طرح ہو جاتا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlv{نہ سورج کے بس میں ہے کہ چاند کو جا پکڑے اور نہ ہی رات کیلئے ممکن ہے کہ وہ دن پر سبقت لے جائے اور سب (اپنے) ایک ایک فلک (دائرہ) میں تیر رہے ہیں۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvi{اور ان کیلئے (قدرتِ خدا کی) ایک نشانی یہ بھی ہے کہ ہم نے ان کی نسل کو بھری ہوئی کشتی (نوح(ع)) میں سوار کیا۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvii{اور ان کیلئے (خشکی اور تری) میں کشتی کی مانند اور سواریاں پیدا کی ہیں جن پر وہ سوار ہوتے ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlviii{اور اگر ہم چاہیں تو انہیں غرق کر دیں پھر نہ کوئی ان کا فریاد رس ہو اور نہ ہی وہ چھڑائے جا سکیں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlix{مگر یہ کہ ہماری رحمت (شاملِ حال) ہو جائے اور ایک (خاص) وقت تک بہرہ مند کرنا منظور ہو۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccl{اور جب ان سے کہا جاتا ہے کہ ڈرو اس (انجام و عذاب) سے جو تمہارے آگے ہے اور اس سے ڈرو جو تمہارے پیچھے ہے کہ تم پر رحم کیا جائے (تو وہ اس کی پرواہ نہیں کرتے)۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccli{اور ان کے پروردگار کی نشانیوں میں سے کوئی نشانی بھی ان کے پاس نہیں آتی مگر یہ کہ وہ اس سے روگردانی کرتے ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcclii{اور جب ان سے کہا جاتا ہے کہ اللہ نے تمہیں جو کچھ عطا کیا ہے اس سے (کچھ) راہِ خدا میں بھی خرچ کرو تو کافر اہلِ ایمان سے کہتے ہیں کیا ہم اسے کھلائیں جسے اگر خدا چاہتا تو خود کھلا دیتا؟ تم لوگ کھلی ہوئی گمراہی میں مبتلا ہو۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdccliii{اور وہ (کافر) کہتے ہیں کہ اگر تم سچے ہو تو بتاؤ کہ یہ (قیامت کا) وعدہ وعید کب پورا ہوگا؟\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdccliv{وہ صرف ایک مہیب آواز (چنگھاڑ) یعنی نَفَخ صُور کا انتظار کر رہے ہیں جو انہیں اپنی گرفت میں لے لے گی جبکہ یہ لوگ (اپنے معاملات میں) باہم لڑ جھگڑ رہے ہوں گے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcclv{(اس وقت) وہ نہ کوئی وصیت کر سکیں گے اور نہ ہی اپنے گھر والوں کی طرف واپس جا سکیں گے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvi{اور جب (دوبارہ) صور پھونکا جائے گا تو وہ ایک دم اپنی قبروں سے (نکل کر) اپنے پروردگار کی طرف تیز تیز چلنے لگیں گے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvii{(اس وقت گھبرا کر) کہیں گے ہائے افسوس! کس نے ہمیں ہماری خوابگاہ سے اٹھایا؟ (جواب دیا جائے گا) یہ وہی (قیامت) ہے جس کا خدائے رحمن نے وعدہ (وعید) کیا تھا اور پیغمبروں(ع) نے بھی سچ کہا تھا۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcclviii{بس وہ ایک مہیب آواز (چنگھاڑ) ہوگی پھر سب کے سب ہمارے حضور حاضر کر دیئے جائیں گے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcclix{پس آج کے دن کسی پر کچھ بھی ظلم نہیں کیا جائے گا اور تمہیں بدلہ نہیں دیا جائے گا مگر انہی اعمال کا جو تم کیا کرتے تھے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcclx{بے شک آج بہشتی لوگ اپنے مشغلہ میں خوش ہوں گے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxi{وہ اور ان کی بیویاں (گھنے) سایوں میں مسندوں پر تکیہ لگائے بیٹھے ہوں گے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxii{وہاں ان کے (کھانے پینے) کیلئے (ہر قسم کے) پھل ہوں گے اور وہ سب کچھ ہوگا جو وہ طلب کریں گے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiii{(انہیں) مہربان (پروردگار) کی طرف سے سلام کہا جائے گا۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiv{(ارشادِ قدرت ہوگا) اے مجرمو! الگ ہو جاؤ۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxv{اے اولادِ آدم! کیا میں نے تمہیں حکم نہیں دیا تھا کہ شیطان کی پرستش نہ کرنا؟ کہ وہ تمہارا کھلا ہوا دشمن ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvi{ہاں البتہ میری عبادت کرو کہ یہی سیدھا راستہ ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvii{(اس کے باوجود) اس نے تم میں سے ایک کثیر گروہ کو گمراہ کر دیا کیا تم اتنا بھی نہیں سمجھتے تھے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxviii{یہ ہے وہ جہنم جس سے تمہیں ڈرایا جاتا تھا۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxix{آج اپنے کفر کی پاداش میں اس میں داخل ہو جاؤ (اور اس کی آگ تاپو)۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxx{آج ہم ان کے مونہوں پر مہر لگا دیں گے اور ہم سے ان کے ہاتھ کلام کریں گے اور ان کے پاؤں گواہی دیں گے اس کے بارے میں جو کچھ وہ کیا کرتے تھے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxi{اور اگر ہم چاہتے تو ان کی آنکھوں کو مٹا دیتے پھر وہ راستہ کی طرف دوڑتے تو ان کو کہاں نظر آتا؟\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxii{اور اگر ہم چاہتے تو انہیں ان کی جگہ پر مسخ کرکے رکھ دیتے کہ نہ آگے بڑھ سکتے اور نہ پیچھے پلٹ سکتے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiii{اور جس کو ہم لمبی عمر دیتے ہیں اسے خلقت (ساخت) میں الٹ دیتے ہیں کیا وہ عقل سے کام نہیں لیتے؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiv{اور ہم نے انہیں شعر و شاعری نہیں سکھائی اور نہ ہی یہ ان کے شایانِ شان ہے یہ تو بس ایک نصیحت اور واضح قرآن ہے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxv{تاکہ آپ(ص) (اس کی ذریعہ سے) انہیں ڈرائیں جو زندہ (دل) ہیں اور تاکہ کافروں پر حجت تمام ہو جائے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvi{کیا یہ لوگ نہیں دیکھتے (غور نہیں کرتے) کہ ہم نے ان کیلئے اپنے دست ہائے قدرت سے بنائی ہوئی چیزوں میں سے مویشی پیدا کئے (چنانچہ اب) یہ ان کے مالک ہیں۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvii{اور ہم نے ان (مویشیوں) کو ان کا مطیع کر دیا ہے پس ان میں سے بعض پر وہ سوار ہوتے ہیں اور بعض کا گوشت کھاتے ہیں۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxviii{اور ان کیلئے ان میں اور بھی طرح طرح کے فائدے اور پینے کی چیزیں (دودھ وغیرہ) بھی ہیں تو کیا یہ لوگ شکر ادا نہیں کرتے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxix{اور کیا انہوں نے اللہ کو چھوڑ کر اور خدا بنا لئے ہیں کہ شاید ان کی مدد کی جائے گی۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxx{حالانکہ وہ ان کی (کچھ بھی) مدد نہیں کر سکتے (بلکہ) وہ (کفار) ان (بتوں) کی حفاظت اور ان کے (دفاع) کیلئے حاضر باش لشکر ہیں۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxi{(اے پیغمبر(ص)) ان لوگوں کی باتیں آپ کو رنجیدہ نہ کریں بے شک ہم خوب جانتے ہیں جو کچھ وہ چھپاتے ہیں اور جو کچھ وہ ظاہر کرتے ہیں۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxii{کیا انسان یہ نہیں دیکھتا (اس پر غور نہیں کرتا) کہ ہم نے اسے نطفہ سے پیدا کیا ہے سو وہ یکایک (ہمارا) کھلا ہوا مخالف بن گیا۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiii{وہ ہمارے لئے مثالیں پیش کرتا ہے اور اپنی خلقت کو بھول گیا ہے وہ کہتا ہے کہ ان ہڈیوں کو کون زندہ کرے گا جبکہ وہ بالکل بوسیدہ ہو چکی ہوں؟\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiv{آپ(ص) کہہ دیجئے! انہیں وہی (خدا دوبارہ) زندہ کرے گا جس نے انہیں پہلی بار پیدا کیا تھا وہ ہر مخلوق کو خوب جانتا ہے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxv{(خدا) جس نے تمہارے لئے سرسبز درخت سے آگ پیدا کی ہے اس سے (اور) آگ سلگاتے ہو۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvi{کیا وہ (قادرِ مطلق) جس نے آسمانوں اور زمین کو پیدا کیا اس بات پر قادر نہیں ہے کہ ان (لوگوں) جیسے (دوبارہ) پیدا کرے؟ ہاں وہ بڑا پیدا کرنے والا (اور) بڑا جاننے والا ہے۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvii{اس کا معاملہ تو بس یوں ہے کہ جب وہ کسی چیز کے پیدا کرنے کا ارادہ کرتا ہے تو کہہ دیتا ہے کہ ہو جا تو وہ (فوراً) ہو جاتی ہے۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxviii{پس پاک ہے وہ ذات جس کے قبضۂ قدرت میں ہر چیز کی حکومت ہے اور اسی کی طرف تم لوٹائے جاؤگے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxix{\basmalahur باقاعدہ طور پر صف باندھنے والی ہستیوں کی قسم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccxc{(برائی سے) جھڑکنے (اور) ڈانٹنے والی ہستیوں کی قسم۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccxci{پھر ذکر (قرآن) کی تلاوت کرنے والی ہستیوں کی قسم۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcii{تمہارا الٰہ (خدا) ایک ہی ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciii{جو آسمانوں اور زمین کا اور جو کچھ ان کے درمیان ہے (سب کا) پروردگار ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciv{بے شک ہم نے آسمانِ دنیا کو ستاروں کی آرائش سے آراستہ کیا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcv{اور ہر سرکش و شیطان کی (دراندازی سے اسے) محفوظ کر دیا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvi{(اب) ملاءِ اعلیٰ (عالمِ بالا) کی باتوں کو کان لگا کر نہیں سن سکتے اور وہ ہر طرف سے مارے جاتے ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvii{(ان کو) دھتکارنے (اور بھگانے) کیلئے اور ان کیلئے دائمی عذاب ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcviii{مگر یہ کہ کوئی شیطان (فرشتوں کی) کوئی اڑتی ہوئی خبر اچک لے تو ایک تیز شعلہ اس کا پیچھا کرتا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcix{پس آپ(ص) ان سے پوچھئے کہ آیا ان کی خلقت زیادہ سخت ہے یا ان کی جن کو ہم نے پیدا کیا؟ بے شک ہم نے انہیں ایک لیس دار مٹی سے پیدا کیا ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccc{تم تو (ان کے انکار پر) تعجب کرتے ہو مگر وہ اس کا مذاق اڑا رہے ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccci{اور جب انہیں نصیحت کی جاتی ہے تو وہ قبول نہیں کرتے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcccii{اور جب کوئی نشانی (معجزہ) دیکھتے ہیں تو اس کا مذاق اڑاتے ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccciii{اور کہتے ہیں کہ یہ تو کھلا ہوا جادو ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccciv{بھلا جب ہم مر جائیں گے اور (مر کر) مٹی اور ہڈیاں ہو جائیں گے تو کیا ہم (زندہ کر کے) اٹھائے جائیں گے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcccv{یا کیا ہمارے اگلے باپ دادا بھی (اٹھائے جائیں گے؟)\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvi{آپ کہیے کہ ہاں اور تم (اس وقت) ذلیل و خوار ہوگے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvii{بس وہ قیامت تو صرف ایک جھڑک ہوگی (اس کے بعد) ایک دم (زندہ ہو کر ادھر اُدھر) دیکھ رہے ہوں گے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcccviii{اور کہیں گے ہائے ہماری بدبختی! یہ تو جزا (و سزا) کا دن ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcccix{(ہاں) یہ وہی فیصلہ کا دن ہے جسے تم جھٹلایا کرتے تھے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcccx{(فرشتوں کو حکم ہوگا کہ) جن لوگوں نے ظلم کیا اور ان کے ہم مشربوں کو اور اللہ کو چھوڑ کر جن کی یہ پرستش کرتے تھے ان سب کو جمع کرو۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxi{اور پھر سب کو دوزخ کا راستہ دکھاؤ۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxii{اور انہیں ٹھہراؤ (ابھی) ان سے کچھ پوچھنا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiii{تمہیں کیا ہوگیا ہے کہ تم ایک دوسرے کی مدد نہیں کرتے؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiv{بلکہ وہ تو آج سرِ تسلیم خم کئے ہوئے ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxv{اور (اس کے بعد) ایک دوسرے کی طرف متوجہ ہوں گے (اور) باہم سوال و جواب کریں گے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvi{(کمزور گروہ دوسرے بڑے گروہ سے) کہے گا کہ تم ہی ہمارے پاس دائیں جانب سے (بڑی شد و مد سے) آیا کرتے تھے (اور ہمیں کفر پر آمادہ کرتے تھے)۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvii{وہ کہیں گے بلکہ تم خود ہی ایمان نہیں لائے تھے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxviii{اور ہمارا تم پر کوئی زور نہیں تھا بلکہ تم خود ہی سرکش لوگ تھے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxix{سو ہم پر ہمارے پروردگار کی بات پوری ہوگئی ہے اب ہم (سب عذابِ خداوندی کا مزہ) چکھنے والے ہیں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxx{پس ہم نے تمہیں گمراہ کیا (کیونکہ) ہم خود بھی گمراہ تھے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxi{سو وہ سب اس دن عذاب میں باہم شریک ہوں گے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxii{بے شک ہم مجرموں کے ساتھ ایسا ہی سلوک کرتے ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiii{وہ ایسے (شریر) لوگ تھے کہ جب ان سے کہا جاتا تھا کہ اللہ کے سوا کوئی حقیقی معبود نہیں ہے تو یہ تکبر کیا کرتے تھے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiv{اور کہتے تھے کہ آیا ایک دیوانے شاعر کی خاطر ہم اپنے خداؤں کو چھوڑ دیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxv{حالانکہ وہ (دینِ) حق لے کر آیا تھا اور (سارے) رسولوں(ص) کی تصدیق کی تھی۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvi{(اے مجرمو!) تم ضرور دردناک عذاب کا مزہ چکھنے والے ہو۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvii{اور تمہیں اسی کا بدلہ دیا جائے گا جو کچھ تم کیا کرتے تھے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxviii{ہاں البتہ اللہ کے برگزیدہ بندے (اس سے مستثنیٰ ہوں گے)۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxix{یہ وہ (خوش نصیب) ہیں جن کیلئے معلوم و معین رزق ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxx{یعنی طرح طرح کے میوے اور وہ عزت و اکرام کے ساتھ ہوں گے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxi{باغہائے بہشت میں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxii{(مرصع) پلنگوں پر آمنے سامنے بیٹھے ہوں گے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiii{(شرابِ طہور کے) جام چشموں سے پُر کرکے ان کے درمیان گردش کر رہے ہوں گے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiv{(یعنی بالکل) سفید براق شراب جو پینے والوں کیلئے بڑی لذیذ ہوگی۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxv{نہ اس میں دردِ سر و بدحواسی ہوگی اور نہ ہی مدہوشی کی وجہ سے وہ بہکی ہوئی باتیں کریں گے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvi{اور ان کے پاس نگاہیں نیچے رکھنے والی (باحیا) اور غزال چشم (بیویاں) ہوں گی۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvii{(وہ رنگ و روپ اور نزاکت میں) گویا چھپے ہوئے انڈے ہیں۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxviii{پھر وہ (بہشتی لوگ) ایک دوسرے کی طرف متوجہ ہوں گے اور سوال و جواب کریں گے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxix{(چنانچہ) ان میں سے ایک کہے گا کہ (دنیا میں) میرا ایک رفیق تھا۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxl{جو (مجھ سے) کہتا تھا کہ آیا تم بھی (قیامت کی) تصدیق کرتے ہو؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxli{کب جب مر جائیں گے اور (سڑ گل کر) مٹی اور ہڈیاں ہو جائیں گے تو (اس وقت زندہ کرکے) ہمیں جزا و سزا دی جائے گی؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlii{پھر وہ (اپنے جنتی ساتھیوں سے) کہے گا کیا تم اسے جھانک کر دیکھنا چاہتے ہو؟ (کہ اب وہ رفیق کہاں اور کس حال میں ہے؟)\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliii{پھر جب وہ جھانک کر دیکھے گا تو اسے جہنم کے وسط میں پائے گا۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliv{اس وقت (اس سے خطاب کرکے) کہے گا کہ خدا کی قسم تو تو مجھے ہلاک کرنا ہی چاہتا تھا۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlv{اور اگر میرے پروردگار کا فضل و کرم نہ ہوتا تو آج میں بھی اس گروہ میں شامل ہوتا جو پکڑ کر لایا گیا ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvi{(جنتی لوگ) کہیں گے کیا اب تو ہم نہیں مریں گے؟\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvii{سوائے پہلی موت کے اور نہ ہی ہمیں کوئی عذاب ہوگا۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlviii{بے شک یہ بڑی کامیابی ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlix{ایسی ہی کامیابی کیلئے عمل کرنے والوں کو عمل کرنا چاہیے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcccl{کیا یہ ضیافت اچھی ہے یا زقوم کا درخت؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcccli{جسے ہم نے ظالموں کیلئے آزمائش بنایا۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdccclii{وہ ایک درخت ہے جو جہنم کی گہرائی سے نکلتا ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliii{اس کے شگوفے ایسے ہیں جیسے شیطانوں کے سر۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliv{جہنمی لوگ اسے کھائیں گے اور اسی سے پیٹ بھریں گے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdccclv{(پھر زقوم کھانے کے بعد) انہیں (پینے کیلئے) کھولتا ہوا پانی ملا کر دیا جائے گا۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvi{پھر ان کی بازگشت جہنم ہی کی طرف ہوگی۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvii{ان لوگوں نے اپنے باپ دادا کو گمراہ پایا۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdccclviii{اور یہ (بے سوچے سمجھے) انہی کے نقش قدم پر دوڑتے رہے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdccclix{اور بے شک ان سے پہلے بھی اگلوں میں اکثر لوگ گمراہ ہو چکے تھے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdccclx{اور ہم نے ان میں ڈرانے والے (رسول) بھیجے تھے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxi{تو دیکھو کہ ڈرائے ہوؤں کا انجام کیا ہوا؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxii{ہاں البتہ اللہ کے برگزیدہ بندے اس سے مستثنیٰ ہیں۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiii{اور یقینا نوح(ع) نے ہم کو پکارا تو ہم کیا اچھا جواب دینے والے تھے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiv{اور ہم نے انہیں اور ان کے اہل کو سخت تکلیف سے نجات دی۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxv{اور ہم نے انہی کی نسل کو باقی رہنے والا بنایا۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvi{اور ہم نے بعد میں آنے والے لوگوں میں ان کا ذکرِ خیر باقی رکھا۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvii{تمام جہانوں میں نوح(ع) پر سلام ہو۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxviii{بیشک ہم نیکی کرنے والوں کو ایسی ہی جزا دیتے ہیں۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxix{بے شک وہ ہمارے ایماندار بندوں میں سے تھے۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxx{پھر دوسرے لوگوں کو ہم نے غرق کر دیا۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxi{اور انہی (نوح(ع)) کے پیروکاروں میں سے ابراہیم(ع) بھی تھے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxii{جبکہ وہ اپنے پروردگار کی بارگاہ میں قلبِ سلیم کے ساتھ حاضر ہوئے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiii{جبکہ انہوں نے اپنے باپ (یعنی چچا) اور اپنی قوم سے کہا کہ تم کس چیز کی عبادت کرتے ہو؟\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiv{کیا تم اللہ کو چھوڑ کر جھوٹے گھڑے ہوئے خداؤں کو چاہتے ہو۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxv{آخر تمام جہانوں کے پروردگار کے بارے میں تمہارا کیا خیال ہے؟\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvi{پھر آپ نے ستاروں پر ایک نگاہ ڈالی۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvii{اور کہا کہ میں بیمار ہونے والا ہوں۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxviii{اس پر وہ لوگ پیٹھ پھیر کر ان کے پاس سے چلے گئے۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxix{پس چپکے سے ان کے دیوتاؤں کی طرف گئے اور (ان سے) کہا کہ تم کھاتے کیوں نہیں؟\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxx{تمہیں کیا ہوگیا ہے کہ تم بولتے بھی نہیں ہو۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxi{پھر ان پر پَل پڑے اور اپنے دائیں ہاتھ سے خوب ضربیں لگائیں۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxii{پھر وہ لوگ دوڑتے ہوئے ان (ابراہیم(ع)) کے پاس آئے۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiii{آپ(ع) نے کہا کیا تم ان چیزوں کی پرستش کرتے ہو جنہیں خود تراشتے ہو؟\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiv{حالانکہ اللہ ہی نے تم کو پیدا کیا ہے اور ان چیزوں کو بھی جو تم بناتے ہو۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxv{ان لوگوں نے کہا کہ ان کیلئے ایک آتش کدہ بناؤ اور اسے دہکتی ہوئی آگ میں ڈال دو۔\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvi{سو انہوں نے آپ(ع) کے خلاف چال چلنا چاہی مگر ہم نے انہی کو نیچا دکھا دیا۔\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvii{آپ(ع) نے فرمایا کہ میں اپنے پروردگار کی طرف جاتا ہوں وہ میری راہنمائی فرمائے گا۔\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxviii{(اور عرض کیا) اے میرے پروردگار مجھے ایک بیٹا عطا فرما جو صالحین میں سے ہو۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxix{(اس دعا کے بعد) ہم نے ان کو ایک حلیم و بردبار بیٹے کی بشارت دی۔\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxc{پس جب وہ لڑکا آپ کے ساتھ چلنے پھرنے کے قابل ہوا تو آپ(ع) نے فرمایا (اے بیٹا) میں نے خواب میں دیکھا ہے کہ میں تمہیں ذبح کر رہا ہوں تم غور کرکے بتاؤ کہ تمہاری رائے کیا ہے؟ عرض کیا بابا جان! آپ کو جو حکم دیا گیا ہے وہ بجا لائیے اللہ نے چاہا تو آپ مجھے صبر کرنے والوں میں سے پائیں گے۔\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxci{پس جب دونوں (باپ بیٹے) نے سرِ تسلیم خم کر دیا اور باپ نے بیٹے کو پیشانی کے بل لٹا دیا۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcii{تو ہم نے ندا دی اے ابراہیم(ع)!\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciii{تم نے (اپنے) خواب کو سچ کر دکھایا بے شک ہم نیکوکاروں کو اسی طرح جزا دیتے ہیں۔\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciv{بے شک یہ ایک کھلی ہوئی آزمائش تھی۔\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcv{اور ہم نے ایک عظیم قربانی کے عوض اس کو چھڑا لیا۔\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvi{اور ہم نے اس کا ذکر خیر آنے والوں میں چھوڑا۔\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvii{سلام ہو ابراہیم(ع) پر۔\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcviii{ہم اسی طرح نیکوکاروں کو جزا دیتے ہیں۔\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcix{یقیناً وہ ہمارے ایمانداروں میں سے تھے۔\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmcm{اور ہم نے انہیں اسحاق(ع) کی بشارت دی جو نیک بندوں میں سے نبی ہوں گے۔\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmcmi{اور ہم نے انہیں اور اسحاق(ع) کو برکت عطا کی اور ان دونوں کی اولاد میں سے نیوکار بھی ہوں گے اور اپنے نفس پر کھلا ظلم کرنے والے بھی۔\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmcmii{بے شک ہم نے موسیٰ(ع) و ہارون(ع) پر (بھی) احسان کیا۔\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmcmiii{اور ہم نے ان دونوں کو اور ان کی قوم کو عظیم کرب و بلا سے نجات دی۔\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmcmiv{اور ہم نے ان کی مدد کی (جس کی وجہ سے) وہی غالب رہے۔\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmcmv{اور ہم نے ان دونوں کو واضح کتاب (توراۃ) عطا کی۔\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmmcmvi{اور ہم نے (ہی) ان دونوں کو راہِ راست دکھائی۔\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmcmvii{اور ہم نے آئندہ آنے والوں میں ان کا ذکرِ خیر باقی رکھا۔\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmcmviii{موسیٰ(ع) و ہارون(ع) پر سلام ہو۔\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmcmix{اسی طرح ہم نیکوکاروں کو جزا دیتے ہیں۔\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmcmx{بیشک یہ دونوں ہمارے مؤمن بندوں میں سے تھے۔\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmcmxi{اور بے شک الیاس(ع) (بھی) پیغمبروں میں سے تھے۔\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmcmxii{(وہ وقت یاد کرو) جب انہوں نے اپنی قوم سے کہا کہ تم (اللہ سے) ڈرتے نہیں ہو؟\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiii{کیا تم بعل (نامی بت) کو پکارتے ہو (اور اس کی پرستش کرتے ہو) اور بہترین خالق اللہ کو چھوڑتے ہو۔\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiv{جو تمہارا بھی پروردگار ہے اور تمہارے پہلے والے آباء و اجداد کا بھی پروردگار ہے۔\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmcmxv{سو ان لوگوں نے انہیں جھٹلایا۔ لہٰذا وہ (سزا کیلئے) ضرور (پکڑ کر) حاضر کئے جائیں گے۔\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvi{ہاں البتہ جو اللہ کے مخلص اور برگزیدہ بندے ہیں وہ اس سے مستثنیٰ ہیں۔\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvii{اور ہم نے آئندہ آنے والوں میں ان کا ذکرِ خیر باقی رکھا۔\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmcmxviii{سلام ہو الیاس(ع)‌(ع)(ع) پر۔\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmcmxix{ہم اسی طرح نیکوکاروں کو جزا دیتے ہیں۔\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmcmxx{بیشک وہ مؤمن بندوں میں سے تھے۔\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxi{اور یقیناً لوط(ع) (بھی) پیغمبروں میں سے تھے۔\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxii{جب کہ ہم نے انہیں اور ان کے گھر والوں کو نجات دی۔\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiii{سوائے ایک بڑھیا (بیوی) کے جو پیچھے رہ جانے والوں میں سے تھی۔\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiv{پھر دوسروں کو ہم نے تہس نہس کر دیا۔\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxv{اور تم لوگ صبح بھی ان (کی ویران شدہ بستیوں) پر سے گزرتے ہو۔\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvi{اور شام کو بھی کیا پھر بھی عقل سے کام نہیں لیتے؟\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvii{اور یقیناً یونس(ع) (بھی) پیغمبروں میں سے تھے۔\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxviii{جبکہ وہ (سوار ہونے کیلئے) بھری ہوئی کشتی کی طرف بھاگ کر گئے۔\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxix{پھر وہ قرعہ اندازی میں شریک ہوئے تو وہ پھینک دیئے گئے۔\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxx{تو انہیں مچھلی نے نگل لیا درآنحالیکہ کہ وہ (اپنے آپ کو) ملامت کر رہے تھے۔\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxi{پس اگر وہ تسبیح (خدا) کرنے والوں میں سے نہ ہوتے۔\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxii{تو (دوبارہ) اٹھائے جانے والے دن (قیامت) تک اسی (مچھلی) کے پیٹ میں رہتے۔\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiii{سو ہم نے انہیں (مچھلی کے پیٹ سے نکال کر) ایک کھلے میدان میں ڈال دیا۔ اس حال میں کہ وہ بیمار تھے۔\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiv{اور ہم نے ان پر (سایہ کرنے کیلئے) کدو کا ایک درخت لگا دیا۔\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxv{اور ہم نے ان کو ایک لاکھ یا اس سے کچھ زیادہ لوگوں کی طرف بھیجا۔\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvi{پس وہ ایمان لائے تو ہم نے انہیں ایک مدت تک (زندگی سے) لطف اندوز ہونے دیا۔\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvii{ان سے ذرا پوچھئے! کہ تمہارے پروردگار کیلئے بیٹیاں ہیں اور خود ان کیلئے بیٹے؟\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxviii{کیا ہم نے فرشتوں کو عورت پیدا کیا اور وہ دیکھ رہے تھے؟\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxix{آگاہ ہو جاؤ کہ یہ دروغ بافی کرتے ہیں۔\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmcmxl{جب کہتے ہیں کہ اللہ کے اولاد ہے اور بلاشبہ وہ جھوٹے ہیں۔\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmcmxli{کیا اللہ نے بیٹوں کے مقابلہ میں بیٹیوں کو ترجیح دی۔\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlii{تمہیں کیا ہوگیا ہے تم کیا فیصلہ کرتے ہو؟\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliii{کیا تم اتنا بھی نہیں سمجھتے؟\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliv{کیا تمہارے پاس کوئی واضح دلیل ہے؟\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlv{اگر تم سچے ہو تو پھر اپنی وہ دستاویز پیش کرو۔\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvi{کیا ان لوگوں نے اس (خدا) اور جنوں کے درمیان کوئی رشتہ ناطہ قرار دیا ہے؟ حالانکہ خود جنات جانتے ہیں کہ وہ (جزا و سزا کیلئے) پکڑ کر حاضر کئے جائیں گے۔\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvii{پاک ہے اللہ (ان غلطیوں سے) جو وہ بیان کرتے ہیں۔\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlviii{ہاں البتہ اللہ کے مخلص اور برگزیدہ بندے اس سے مستثنیٰ ہیں۔\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlix{سو تم اور جن کی تم پرستش کرتے ہو۔\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmcml{تم (سب مل کر بھی) اللہ سے کسی کو پھیر نہیں سکتے۔\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmcmli{سوائے اس کے جو دوزخ کی بھڑکتی آگ کو تاپنے والا ہے۔\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmcmlii{اور (فرشتوں) میں سے کوئی ایسا نہیں مگر یہ کہ اس کا ایک خاص مقام ہے۔\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmcmliii{اور بے شک ہم صف بستہ حاضر ہیں۔\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmcmliv{اور بے شک ہم تسبیح و تقدیس کرنے والے ہیں۔\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmcmlv{اور (کفار بعثتِ نبوی(ص) سے پہلے) کہا کرتے تھے۔\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvi{تو اگر ہمارے پاس پہلے والے لوگوں کی طرح کوئی نصیحت (والی کتاب) ہوتی۔\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvii{تو یقیناً ہم اللہ کے برگزیدہ بندوں میں سے ہوتے۔\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcmlviii{اور جب وہ (کتاب آئی) تو اس کا انکار کر دیا سو عنقریب (اس کا انجام) معلوم کر لیں گے۔\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmcmlix{اور ہمارا وعدہ پہلے ہو چکا ہے اپنے ان بندوں کے ساتھ جو رسول ہیں۔\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmcmlx{کہ یقیناً ان کی نصرت اور مدد کی جائے گی۔\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxi{اور ہمارا لشکر بہرحال غالب آنے والا ہے۔\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxii{سو ایک مدت تک ان سے بے اعتنائی کیجئے۔\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiii{اور انہیں دیکھتے رہئے اور عنقریب وہ خود بھی (اپنا انجام) دیکھ لیں گے۔\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiv{کیا وہ ہمارے عذاب کیلئے جلدی کرتے ہیں؟\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxv{تو جب وہ ان کے ہاں نازل ہو جائے گا تو وہ بڑی بری صبح ہوگی ڈرائے ہوؤں کیلئے۔\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvi{اور ایک مدت تک ان سے بے توجہی کیجئے۔\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvii{اور دیکھئے وہ بھی دیکھ رہے ہیں۔\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxviii{پاک ہے آپ کا پروردگار جوکہ عزت کا مالک ہے ان (غلط) باتوں سے جو وہ بیان کرتے ہیں۔\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxix{اور سلام ہو رسولوں(ع) پر۔\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxx{اور ہر طرح کی تعریف ہے اس اللہ کیلئے جو سارے جہانوں کا پروردگار ہے۔\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxi{\basmalahur ص! قَسم ہے نصیحت والے قرآن کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxii{آپ(ص) کی (نبوت برحق ہے) بلکہ وہ لوگ جنہوں نے کفر اختیار کیا ہے وہ تکبر اور مخالفت میں مبتلا ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiii{ہم نے ان سے پہلے کتنی قومیں ہلاک کر دیں۔ پس (عذاب کے وقت) وہ پکارنے لگیں مگر وہ وقت خلاصی کا نہ تھا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiv{اور وہ اس بات پر تعجب کر رہے ہیں کہ ان کے پاس ایک ڈرانے والا (پیغمبر(ص)) انہی میں سے آیا ہے اور کافر کہتے ہیں کہ یہ (شخص) جادوگر (اور) بڑا جھوٹا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxv{کیا اس نے بہت سے خداؤں کو ایک خدا بنا دیا؟ بے شک یہ بڑی عجیب بات ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvi{اور ان کے بڑے لوگ (سردار) یہ کہتے ہوئے (آپ(ص) کے پاس سے) اٹھ کھڑے ہوئے (اور قوم سے کہا) چلو اور اپنے معبودوں (کی عبادت) پر صبر و ثبات سے قائم رہو (ڈٹے رہو) یقیناً اس بات میں (اس شخص کی) کوئی غرض ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvii{ہم نے تو یہ بات (کسی) پچھلے مذہب (عیسائیت) میں (بھی) نہیں سنی یہ تو محض ایک من گھڑت بات ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxviii{کیا ہم میں سے صرف اسی شخص پر الذکر (قرآن) اتارا گیا ہے؟ دراصل یہ لوگ میرے ذکر (کتاب) کے بارے میں شک میں مبتلا ہیں بلکہ انہوں نے ابھی میرے عذاب کا مزہ نہیں چکھا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxix{کیا تمہارے غالب اور فیاض پروردگار کی رحمت کے خزانے ان کے پاس ہیں؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxx{یا کیا آسمانوں اور زمین اور جو کچھ ان کے درمیان ہے کی حکومت ان کیلئے ہے (اگر ایسا ہے) تو پھر انہیں چاہیے کہ سیڑھیاں لگا کر چڑھ جائیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxi{یہ (کفار کے) لشکروں میں سے ایک لشکر ہے جسے وہاں (بمقامِ بدر) شکست ہوگی۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxii{اور ان سے پہلے قومِ نوح و عاد اور میخوں والا فرعون۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiii{اور ثمود اور قومِ لوط(ع) اور ایکہ والے (اپنے نبیوں کو) جھٹلا چکے ہیں یہ لوگ بڑے بڑے گروہ تھے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiv{ان سب نے رسولوں(ع) کو جھٹلایا تو ہمارے عذاب کے مستوجب ہوئے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxv{اور یہ لوگ بس ایک چنگھاڑ (دوسری نَفَخ) کا انتظار کر رہے ہیں جس کے بعد کچھ دیر نہ ہوگی۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvi{اور وہ (ازراہِ مذاق) کہتے ہیں کہ ہمارے پروردگار کے (عذاب میں سے) ہمارا حصہ ہمیں حساب کے دن (قیامت) سے پہلے دے دے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvii{(اے میرے رسول(ص)) جو کچھ یہ لوگ کہتے ہیں اس پر صبر کیجئے! اور ہمارے بندے داؤد(ع) کو یاد کیجئے جو قوت والے تھے بے شک وہ ہر معاملہ میں (اللہ کی طرف) بڑے رجوع کرنے والے تھے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxviii{ہم نے پہاڑوں کو ان کے ساتھ مسخر کر دیا تھا جو شام اور صبح کے وقت ان کے ساتھ تسبیح کرتے تھے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxix{اور پرندوں کو بھی (جو تسبیح کے وقت) جمع ہو جاتے تھے (اور) سب (پہاڑ و پرند) ان کے فرمانبردار تھے (اور ان کی آواز پر آواز ملاتے تھے)۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcmxc{اور ہم نے ان کی حکومت کو مضبوط کر دیا تھا اور ان کو حکمت و دانائی اور فیصلہ کُن بات کرنے کی صلاحیت عطا کی تھی۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcmxci{(اے رسول(ص)) کیا آپ تک مقدمہ والوں کی خبر پہنچی ہے جب وہ دیوار پھاند کر (ان کے) محرابِ عبادت میں داخل ہوگئے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcii{جب وہ اس طرح (اچانک اندر) جنابِ داؤد(ع) کے پاس پہنچ گئے تو وہ ان سے گھبرا گئے انہوں نے کہا کہ آپ ڈریں نہیں ہم دو فریقِ مقدمہ ہیں ہم میں سے ایک نے دوسرے پر زیادتی کی آپ ہمارے درمیان حق کے ساتھ فیصلہ کر دیجئے اور بے انصافی نہ کیجئے اور راہِ راست کی طرف ہماری راہنمائی کیجئے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciii{(وجۂ نزاع یہ ہے کہ) یہ میرا بھائی ہے اس کے پاس ننانوے دنبیاں ہیں اور میرے پاس صرف ایک دنبی ہے اس پر بھی وہ کہتا ہے کہ یہ ایک دنبی بھی میرے حوالے کر دے اور گفتگو میں مجھے دباتا ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciv{داؤد(ع) نے کہا اس شخص نے اتنی دنبیوں کے ساتھ تیری دنبی ملانے کا مطالبہ کرکے تجھ پر ظلم کیا ہے اور اکثر شرکاء اسی طرح ایک دوسرے پر زیادتی کرتے ہیں سوائے ان کے جو ایمان لاتے ہیں اور نیک عمل کرتے ہیں اور ایسے لوگ بہت کم ہیں اور (یہ بات کہتے ہوئے) داؤد (ع) نے خیال کیا کہ ہم نے ان کا امتحان لیا ہے تو انہوں نے اپنے پروردگار سے مغفرت طلب کی اور اس کے حضور جھک گئے اور توبہ و انابہ کرنے لگے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcv{اور ہم نے انہیں معاف کر دیا اور بے شک ان کیلئے ہمارے ہاں (خاص) تقرب اور اچھا انجام ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvi{اے داؤد(ع)! ہم نے تم کو زمین میں خلیفہ مقرر کیا ہے پس حق و انصاف کے ساتھ لوگوں میں فیصلہ کیا کرو اور خواہشِ نفس کی پیروی نہ کرو کہ وہ تمہیں اللہ کی راہ سے بھٹکا دے گی اور جو اللہ کی راہ سے بھٹک جاتے ہیں ان کیلئے سخت عذاب ہے اس لئے انہوں نے یوم الحساب (قیامت) کو بھلا دیا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvii{اور ہم نے آسمان و زمین کو اور جو کچھ ان کے درمیان ہے بے فائدہ پیدا نہیں کیا یہ ان لوگوں کا گمان ہے جو کافر ہیں پس کافروں کیلئے دوزخ کی بربادی ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcviii{کیا ہم ان لوگوں کو جو ایمان لائے اور نیک عمل کرتے رہے ان لوگوں کی مانند بنا دیں گے جو زمین میں فساد کرتے ہیں؟ یا کیا ہم پرہیزگاروں کو بدکاروں جیسا کر دیں گے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcix{یہ وہ بابرکت کتاب ہے جو ہم نے آپ پر نازل کی ہے تاکہ لوگ اس کی آیتوں میں غور کریں اور تاکہ اہلِ عقل و فہم نصیحت حاصل کریں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmm{اور ہم نے داؤد(ع) کو سلیمان(ع) (جیسا بیٹا) عطا کیا وہ بہت اچھا بندہ (اور اللہ کی طرف) بڑا رجوع کرنے والا تھا۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmi{(اور وہ وقت یاد کرنے کے لائق ہے) جب شام (سہ پہر) کے وقت میں عمدہ گھوڑے (معائنہ کیلئے) ان پر پیش کئے گئے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmii{تو انہوں نے کہا کہ میں مال (گھوڑوں) کی محبت میں اپنے پروردگار کی یاد سے غافل ہوگیا یہاں تک کہ وہ (آفتاب) پردہ میں چھپ گیا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmiii{(حکم دیا) ان (گھوڑوں) کو میرے پاس واپس لاؤ اور وہ ان کی پنڈلیوں اور گردنوں پر ہاتھ پھیرنے لگے (قطع کرنا شروع کیا)۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmiv{اور ہم نے سلیمان(ع) کو (اس طرح) آزمائش میں ڈالا کہ ان کے تخت پر ایک (بے جان) جسم ڈال دیا پھر انہوں نے (ہماری طرف) رجوع کیا۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmv{(اور) کہا اے میرے پروردگار مجھے معاف کر اور مجھے ایسی سلطنت عطا کر جو میرے بعد کسی کیلئے زیبا نہ ہو۔ بیشک تو بڑا عطا کرنے والا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmvi{اور ہم نے ان کیلئے ہوا کو مسخر کر دیا تھا جو ان کے حکم سے جہاں وہ چاہتے تھے آرام سے چلتی تھی۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmvii{اور شیاطین بھی (مسخر کر دیئے) جو کچھ معمار تھے اور اور کچھ غوطہ خور۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmviii{اور ان کے علاوہ (کچھ ایسے سرکش بھی تھے) جو زنجیروں میں جکڑے ہوئے تھے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmix{یہ ہماری عطا ہے (آپ(ع) کو اختیار ہے) جسے چاہے عطا کر اور جس سے چاہے روک رکھ۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmx{اور بے شک ان (سلیمان(ع)) کیلئے ہمارے ہاں (خاص) قرب حاصل ہے اور بہتر انجام ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxi{اور ہمارے بندۂ (خاص) ایوب(ع) کو یاد کرو جب انہوں نے اپنے پروردگار کو پکارا کہ شیطان نے مجھے سختی اور اذیت پہنچائی ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmxii{(ہم نے حکم دیا کہ) اپنا پاؤں (زمین پر) مارو۔ یہ ٹھنڈا پانی ہے نہانے کیلئے اور پینے کیلئے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmxiii{اور ہم نے اپنی خاص رحمت اور صاحبانِ عقل و فکر کیلئے بطورِ نصیحت انہیں نہ صرف ان کے اہل و عیال واپس دیئے (بلکہ) اتنے ہی اور بڑھا دیئے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmxiv{اور (ہم نے کہا) اپنے ہاتھ میں (شاخوں کا) ایک مُٹھا لو اور اس سے مارو اور قَسم نہ توڑو۔ بے شک ہم نے انہیں صبر کرنے والا پایا بڑا اچھا بندہ (اور ہماری طرف) بڑا رجوع کرنے والا۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmxv{اور ہمارے (خاص) بندوں ابراہیم(ع)، اسحاق(ع) اور یعقوب(ع) کو یاد کرو جو قوت و بصیرت والے تھے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmxvi{اور ہم نے ان کو ایک خاص صفت کے ساتھ مخصوص کیا تھا اور وہ آخرت کی یاد تھی۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmxvii{اور وہ یقیناً ہمارے نزدیک برگزیدہ (اور) نیکوکار لوگوں میں سے تھے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmxviii{اور اسماعیل(ع)، الیسع(ع) اور ذوالکفل(ع) کو یاد کرو یہ سب نیک لوگوں میں سے تھے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmxix{یہ ایک نصیحت ہے اور بے شک پرہیزگاروں کیلئے اچھا ٹھکانہ ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmxx{(یعنی) ہمیشہ رہنے والے (سدابہار) باغات جن کے سب دروازے ان کیلئے کھلے ہوں گے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmxxi{وہ ان میں تکیے لگائے بیٹھے ہوں گے اور وہ وہاں بہت سے میوے اور مشروبات طلب کرتے ہوں گے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmxxii{اور ان کے پاس نیچی نگاہوں والی ہم عمر بیویاں ہوں گی۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiii{یہ وہ (نعمت) ہے جن کا حساب کے دن تمہیں عطا کرنے کا وعدہ کیا جاتا ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiv{یہ ہمارا (خاص) رزق ہے جو ختم ہونے والا نہیں ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmxxv{یہ بات تو ہو چکی (کہ پرہیزگاروں کا انجام یہ ہے) اور سرکش کا انجام بہت برا ہے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvi{(یعنی) دوزخ جس میں داخل ہوں گے پس وہ بہت ہی برا بچھونا ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvii{یہ (حاضر ہے) کھولتا ہوا پانی اور پیپ پس چاہیے کہ وہ اسے چکھیں۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmxxviii{اور اس کے علاوہ اسی قسم کی دوسری چیزیں بھی ہوں گی۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmxxix{یہ ایک اور فوج ہے جو تمہارے ساتھ (جہنم میں) داخل ہو رہی ہے ان کیلئے کوئی خوش آمدید نہیں ہے یہ بھی جہنم میں داخل ہونے والے ہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmxxx{وہ (ان کے جواب میں کہیں گے) تمہارے لئے خوش آمدید نہ ہو تم ہی یہ (دن) ہمارے سامنے لائے ہو! تو (جہنم) کیا برا ٹھکانا ہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxi{پھر وہ کہیں گے اے ہمارے پروردگار! جو (کمبخت) روزِ بد ہمارے آگے لایا ہے اسے دوزخ میں عذاب دے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxii{وہ کہیں گے کہ کیا بات ہے ہم یہاں ان لوگوں کو نہیں دیکھ رہے جن کو ہم (دنیا میں) برے لوگوں میں شمار کرتے تھے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiii{کیا ہم نے بلاوجہ ان کا مذاق اڑایا تھا یا نگاہیں ان کی طرف سے چوک رہی ہیں؟\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiv{یہ بات بالکل سچی ہے کہ دوزخ والے آپس میں جھگڑیں گے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxv{آپ کہہ دیجئے! کہ میں تو صرف (عذابِ خدا سے) ایک ڈرانے والا ہوں اور اللہ کے سوا جو یکتا اور غالب ہے اور کوئی خدا نہیں ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvi{وہی آسمانوں اور زمین اور جو کچھ ان کے درمیان ہے کا پروردگار ہے (اور وہ) بڑا زبردست (اور) بڑا بخشنے والا ہے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvii{کہیے وہ (قرآن یا قیامت) بہت بڑی خبر ہے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxviii{جس سے تم منہ پھیرتے ہو۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxix{مجھے تو ملاءِ اعلیٰ (عالمِ بالا) کی کوئی خبر نہ تھی جبکہ وہ (فرشتے) آپس میں بحث کر رہے تھے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmxl{میری طرف اس لئے وحی کی جاتی ہے کہ میں ایک کھلا ہوا ڈرانے والا ہوں۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmxli{(وہ وقت یاد کرنے کے قابل ہے) جب تمہارے پروردگار نے فرشتوں سے کہا کہ میں گیلی مٹی سے ایک بشر (انسان) پیدا کرنے والا ہوں۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmxlii{جب میں اسے تیار کر لوں اور اس میں اپنی خاص روح پھونک دوں تو تم اس کے سامنے سجدہ ریز ہو جانا۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmxliii{تو (حسب الحکم) سب فرشتوں نے سجدہ کیا۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmxliv{سوائے ابلیس کے کہ اس نے تکبر کیا اور کافروں میں سے ہوگیا۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmxlv{ارشاد ہوا اے ابلیس! تجھے کس چیز نے روکا کہ اس کے سامنے سجدہ کرے جسے میں نے اپنی طاقت و قدرت سے پیدا کیا ہے؟ کیا تو نے تکبر کیا ہے یا تو سرکشوں میں سے ہوگیا ہے؟\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvi{اس نے کہا میں اس (آدم(ع)) سے بہتر ہوں (کیونکہ) تو نے مجھے آگ سے پیدا کیا ہے اور اسے گیلی مٹی سے پیدا کیا ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvii{ارشاد ہوا تو یہاں (جنت) سے نکل جا کیونکہ تو راندۂ درگاہ ہے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmxlviii{اور یقیناً قیامت تک تجھ پر میری لعنت ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmxlix{اس نے کہا اے پروردگار! مجھے اس دن تک مہلت دے جب لوگ دوبارہ اٹھائے جائیں گے۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmml{ارشاد ہوا (جا) تجھے مہلت دی گئی ہے۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmli{مگر اس دن تک جس کا وقت (تجھے) معلوم ہے۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmlii{ابلیس نے کہا تیری عزت کی قسم! میں سب لوگوں کو گمراہ کروں گا۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmliii{سوائے تیرے منتخب اور برگزیدہ بندوں کے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmliv{ارشاد ہوا کہ پھر حق یہ ہے اور میں حق ہی کہتا ہوں۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmlv{کہ میں بھی دوزخ بھر دوں گا تجھ سے اور ان لوگوں سے جو تیری پیروی کریں گے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmlvi{آپ(ص) کہہ دیجئے! کہ اس (تبلیغِ رسالت) پر تم سے کوئی معاوضہ نہیں مانگتا اور نہ ہی میں بناوٹ کرنے والوں میں سے ہوں۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmlvii{یہ (قرآن) نہیں ہے مگر سب جہانوں کیلئے نصیحت۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmlviii{اور تمہیں کچھ مدت کے بعد اس کی خبر معلوم ہو جائے گی۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmlix{\basmalahur یہ کتاب (قرآن) اس خدا کی طرف سے نازل کی گئی ہے جو (سب پر) غالب ہے (اور) بڑا حکمت والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmlx{(اے رسول(ص)) بے شک ہم نے حق کے ساتھ یہ کتاب آپ کی طرف نازل کی ہے تو بس آپ اسی کی عبات کریں اس کے لئے دین کو خالص کرتے ہوئے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmlxi{خبردار! خالص دین صرف اللہ کیلئے ہے اور جن لوگوں نے اس کے سوا ولی و سرپرست بنائے ہیں اور (تاویل یہ کرتے ہیں کہ) ہم ان کی صرف اسی لئے عبادت کرتے ہیں کہ وہ ہمیں اللہ کا مقرب بنا دیں گے۔ بے شک اللہ ان کے درمیان فیصلہ کرے گا ان باتوں میں جن کے بارے میں وہ اختلاف کرتے ہیں۔ بے شک اللہ ایسے شخص کو ہدایت نہیں دیتا جو جھوٹا (اور) بڑا ناشکرا ہو۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmlxii{اگر اللہ چاہتا کہ (کسی کو) اپنا بیٹا بنائے تو اپنی مخلوق میں سے جس کو چاہتا منتخب کر لیتا وہ اس سے پاک ہے وہی اللہ ہے جو یکتا (اور سب پر) غالب ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiii{اس نے آسمانوں اور زمین کو حق (حکمت) کے ساتھ پیدا کیا ہے وہ رات کو دن پر اور دن کو رات پر لپیٹتا ہے اور اس نے سورج اور چاند کو (اس طرح) مسخر کر رکھا ہے کہ ہر ایک ایک مقررہ مدت تک رواں دواں ہے آگاہ ہو جاؤ کہ وہ (سب پر) غالب ہے (اور) بڑا بخشنے والا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiv{اس نے تم (سب) کو ایک نفس سے پیدا کیا پھر اسی (کی جنس) سے اس کا جوڑا (شریک حیات) پیدا کیا اور پھر تمہارے لئے (تعداد میں) چوپایوں کے آٹھ جوڑے پیدا کئے وہ تمہیں تمہاری ماؤں کے پیٹوں میں (تدریجاً) پیدا کرتا ہے۔ ایک خلقت کے بعد دوسری خلقت تین تاریک پردوں میں یہ اللہ تمہارا پروردگار ہے اسی کی حکومت ہے اس کے سوا کوئی الٰہ (خدا) نہیں ہے تم کدھر پھیرے جاتے ہو؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmlxv{اگر تم کفر (انکار و ناشکری کرو) تو بے شک وہ تم سے بے نیاز ہے اور وہ اپنے بندوں کیلئے (ناشکراپن) پسند نہیں کرتا اور اللہ کا تم شکر ادا کرو تو وہ اسے تمہارے لئے پسند کرتا ہے اور کوئی بوجھ اٹھانے والا کسی کا بوجھ نہیں اٹھائے گا اور پھر تم سب کی بازگشت تمہارے پروردگار کی طرف ہے وہ تمہیں بتائے گا جو کچھ تم کرتے رہے ہو بے شک وہ سینوں کے رازوں کو جاننے والا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvi{اور جب انسان کو کوئی تکلیف پہنچتی ہے تو وہ دل سے رجوع کرکے اپنے پروردگار کو پکارتا ہے اور پھر جب وہ اپنی طرف سے اسے کوئی نعمت عطا کرتا ہے تو وہ اس (تکلیف) کو بھول جاتا ہے جس کیلئے وہ پہلے اسے پکار رہا تھا اور اللہ کیلئے ہمسر (شریک) ٹھہرانے لگتا ہے تاکہ اس کے راستہ سے (لوگوں کو) گمراہ کرے۔ آپ(ص) کہہ دیجئے! تھوڑے دن اپنے کفر (ناشکرے پن) سے فائدہ اٹھا لے (انجامِ کار) یقیناً تو دوزخ والوں سے ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvii{بھلا جو شخص رات کی گھڑیوں میں کبھی سجدہ کرکے اور کبھی قیام کرکے خدا کی عبادت کرتا ہے اور (اس کے باوجود) آخرت سے ڈرتا ہے اور اپنے پروردگار کی رحمت کا امیدوار ہے؟ (تو کیا وہ شخص جو ایسا نہیں ہے یکساں ہو سکتے ہیں؟) کہیے کیا علم والے اور جاہل برابر ہو سکتے ہیں؟ بے شک نصیحت تو صرف صاحبانِ عقل ہی حاصل کرتے ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmlxviii{کہہ دیجئے! اے میرے وہ بندو جو ایمان لائے ہو! اپنے پروردگار (کی نافرمانی) سے ڈرو۔ (اور یاد رکھو) جو لوگ اس دنیا میں نیک عمل کرتے ہیں ان کیلئے (آخرت میں) نیک صلہ ہے اور اللہ کی زمین وسیع (کشادہ) ہے بے شک صبر کرنے والوں کو ان کا اجر بے حساب دیا جائے گا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmlxix{کہہ دیجئے! کہ مجھے حکم دیا گیا ہے کہ میں دین کو اس کیلئے خالص کرکے (مکمل اخلاص کے ساتھ) اس کی عبادت کروں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmlxx{اور مجھے حکم دیا گیا ہے کہ میں سب مسلمانوں سے پہلے مسلمان ہوں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxi{کہئے کہ اگر میں اپنے پروردگار کی نافرمانی کروں تو ایک بڑے دن (قیامت) کے عذاب سے ڈرتا ہوں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxii{آپ(ص) کہئے کہ میں اللہ کی عبادت کرتا ہوں اسی کیلئے اپنے دین کو خالص کرتے ہوئے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiii{تم اس کے سوا جن کی چاہو عبادت (کرو) نیز کہہ دیجئے کہ اصلی خسارے والے تو وہ ہیں جنہوں نے اپنے آپ کو اور اپنے گھر والوں کو قیامت کے دن خسارے میں میں ڈالا آگاہ ہو جاؤ کہ یہی کھلا ہوا خسارہ ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiv{ان (بدبختوں) کیلئے ان کے اوپر بھی آگ کے سائبان ہوں گے اور ان کے نیچے سے بھی یہی وہ (عذاب) ہے جس سے خدا اپنے بندوں کو ڈراتا ہے اے میرے بندو! مجھ سے ڈرو۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxv{اور جن (خوش بخت) لوگوں نے طاغوت (معبودانِ باطل) کی عبادت سے اجتناب کیا اور اللہ کی طرف رجوع کیا ان کیلئے خوشخبری ہے (اے نبی(ص)) میرے ان بندوں کو خوشخبری دے دو۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvi{جو (ہر کہنے والے کی) بات کو غور سے سنتے ہیں اور اس میں سے بہترین بات کی پیروی کرتے ہیں یہی وہ لوگ ہیں جن کو اللہ ہدایت دیتا ہے اور یہی صاحبانِ عقل ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvii{بھلا جس پر عذاب کا حکم ثابت ہو چکا تو کیا آپ اسے چھڑا سکتے ہیں جو (دوزخ کی) آگ میں ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxviii{البتہ جو لوگ اپنے پروردگار سے ڈرتے رہے ان کیلئے ایسے بالا خانے ہیں کہ جن کے اوپر اور بالا خانے بنے ہوئے ہیں جن کے نیچے سے نہریں جاری ہیں یہ اللہ کا وعدہ ہے اور اللہ کبھی (اپنے) وعدے کے خلاف نہیں کرتا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxix{کیا تم نے نہیں دیکھا کہ اللہ آسمان سے پانی اتارتا ہے اور پھر زیرِ زمین اس کے چشمے جاری کر دیتا ہے پھر اس سے مختلف قسم کی رنگ برنگی کھیتیاں برآمد کرتا ہے پھر وہ (پک کر) خشک ہونے لگتی ہیں تم انہیں زرد دیکھتے ہو پھر انہیں ریزہ ریزہ کر دیتا ہے۔ بے شک اس میں صاحبانِ عقل کیلئے نصیحت ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxx{کیا وہ شخص جس کے سینہ کو اللہ نے (قبولِ) اسلام کیلئے کھول دیا ہے اور وہ اپنے پروردگار کی طرف سے نور (ہدایت) پر ہے (قسی القلب لوگوں کی طرح ہو سکتا ہے) بربادی ہے ان کیلئے جن کے دل ذکرِ خدا سے سخت ہوگئے ہیں یہ لوگ کھلی ہوئی گمراہی میں ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxi{اللہ ہی نے بہترین کلام نازل کیا ہے یعنی ایسی کتاب جس کی آیتیں آپس میں ملتی جلتی ہیں (اور) بار بار دہرائی جاتی ہیں اس (کے پڑھنے) سے ان لوگوں کے رونگٹے کھڑے ہو جاتے ہیں جو اپنے پروردگار سے ڈرتے ہیں پھر ان کے جسم اور ان کے دل اللہ کے ذکر کی طرف نرم (مائل) ہو جاتے ہیں یہ اللہ کی ہدایت ہے جس کے ذریعہ سے وہ جس کی چاہتا ہے راہنمائی کرتا ہے اور جسے چاہتا ہے گمراہی میں چھوڑ دیتا ہے اس کیلئے کوئی راہنما نہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxii{بھلا وہ (احمق) شخص جو قیامت کے دن اپنے چہرہ سے اپنے آپ کو سخت عذاب سے بچاتا ہے؟ (اس عذاب سے محفوظ شخص کی مانند ہو سکتا ہے؟) اور ظالموں سے کہا جائے گا کہ (آج) مزہ چکھو اس کمائی کا جو تم کیا کرتے تھے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiii{جو لوگ ان سے پہلے تھے انہوں نے (حق کو) جھٹلایا آخر ان پر وہاں سے عذاب آیا جدھر سے ان کو خیال نہ تھا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiv{تو خدا نے ان کو اس دنیاوی زندگی میں ذلت و رسوائی کا مزہ چکھایا اور آخرت کا عذاب اس سے بھی بڑا ہے کاش وہ لوگ جانتے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxv{اور بے شک ہم نے اس قرآن میں ہر قسم کی مثالیں پیش کی ہیں تاکہ وہ نصیحت حاصل کریں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvi{یہ ایسا قرآن جو عربی زبان میں ہے جس میں کوئی کَجی نہیں ہے تاکہ وہ (ڈریں) پرہیزگاری اختیار کریں۔ اللہ نے ایک مثال بیان کی ہے کہ ایک غلام ہے جس کے کئی بد اخلاق مالک ہیں اور ایک دوسرا شخص ہے جو پورا ایک مالک کا ہے (ان دونوں) کا حال یکساں ہے؟ الحمد ﷲ! مگر اکثر لوگ (یہ حقیقت) جانتے نہیں ہیں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvii{(اے پیغمبر(ص)) بے شک آپ نے بھی مرنا ہے اور وہ لوگ بھی مرنے والے ہیں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxviii{پھر تم سب قیامت کے دن اپنے پروردگار کی بارگاہ میں جھگڑوگے (اور وہ حق و باطل کا فیصلہ کرے گا)۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxix{پس اس شخص سے بڑھ کر اور کون ظالم ہوگا جو خدا پر جھوٹ باندھے اور جب سچائی اس کے پاس آئے تو وہ اسے جھٹلائے۔ کیا جہنم میں کافروں کا ٹھکانہ نہیں ہے؟\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmxc{اور جو شخص سچائی لے کر آیا اور جس نے اس کی تصدیق کی تو یہی لوگ پرہیزگار ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmxci{ان کیلئے پروردگار کے پاس وہ سب کچھ ہے جو وہ چاہیں گے یہ نیکوکاروں کی جزا ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmxcii{تاکہ اللہ ان کے بدترین اعمال کو معاف کرے اور انہیں ان کے بہترین اعمال کی جزا عطا فرمائے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmxciii{کیا اللہ اپنے بندہ کیلئے کافی نہیں ہے؟ اور یہ لوگ آپ کو اللہ کے سوا دوسروں سے ڈراتے ہیں اور جس کو خدا گمراہی میں چھوڑ دے اس کو کوئی ہدایت دینے والا نہیں ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmxciv{اور جسے خدا ہدایت دے اسے کوئی گمراہ کرنے والا نہیں ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmxcv{کیا اللہ زبردست (اور) انتقام لینے والا نہیں ہے؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvi{اور اگر آپ(ص) اُن سے پوچھیں کہ آسمانوں اور زمین کو کس نے پیدا کیا ہے؟ تو وہ یقینا کہیں گے کہ اللہ نے آپ(ص) کہیے! تمہارا کیا خیال ہے؟ جن کو تم اللہ کے سوا پکارتے ہو اگر اللہ مجھے کچھ نقصان پہنچانا چاہے تو کیا یہ اس کی جانب سے نقصان کو دور کر دیں گے؟ یا اگر اللہ مجھ پر کچھ رحمت کرنا چاہے تو کیا یہ اس کی رحمت کو روک سکتے ہیں؟ بس آپ(ص) کہہ دیجئے! کہ میرے لئے اللہ کافی ہے۔ بھروسہ کرنے والے اسی پر بھروسہ کرتے ہیں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvii{آپ(ص) کہہ دیجئے! اے میری قوم! تم اپنی جگہ (اپنے طریقہ پر) کام کئے جاؤ۔ میں اپنا کام کرتا ہوں عنقریب تمہیں معلوم ہو جائے گا۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmxcviii{کہ کس پر رسوا کرنے والا عذاب آتا ہے اور کس پر دائمی عذاب اترتا ہے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxcix{(اے رسول(ص)) بیشک ہم نے یہ کتاب سب انسانوں (کی ہدایت) کیلئے حق کے ساتھ آپ(ص) پر اتاری ہے جو ہدایت حاصل کرے گا تو وہ اپنے لئے کرے گا اور جو گمراہی اختیار کرے گا تو اس کی گمراہی کا وبال اسی پر پڑے گا آپ(ص) ان کے ذمہ دار نہیں ہیں۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmc{اللہ ہی روحوں کو ان کی موت کے وقت قبض کرتا ہے اور جن کی موت (ابھی) نہیں آئی (تو ان کی روحیں) نیند کے وقت قبض کرتا ہے پھر جن (روحوں کی) موت کا فیصلہ کرتا ہے انہیں روک لیتا ہے اور دوسری روحوں کو ایک مقررہ مدت تک چھوڑ دیتا ہے۔ بیشک اس میں غور و فکر کرنے والوں کیلئے (قدرتِ خدا کی) نشانیاں ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmci{کیا ان لوگوں نے اللہ کو چھوڑ کر دوسروں کو شفیع (سفارشی) بنا رکھا ہے آپ(ص) کہہ دیجئے! کہ اگرچہ وہ (سفارشی) نہ کسی چیز کے مالک ہوں اور نہ ہی عقل و شعور رکھتے ہوں؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcii{آپ(ص) کہہ دیجئے کہ شفاعت پوری کی پوری اللہ کے قبضۂ قدرت میں ہے (اور) اسی کیلئے آسمانوں اور زمین کی بادشاہی ہے پھر تم اسی کی طرف لوٹائے جاؤگے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmciii{اور جب خدا کی توحید (اس کی وحدت و یکتائی) کا ذکر کیا جاتا ہے تو جو لوگ آخرت پر ایمان نہیں رکھتے ان کے دل کڑھنے لگتے ہیں اور جب اس کے دوسرے (مزعومہ شرکاء) کا ذکر کیا جاتا ہے تو وہ یکایک خوش ہو جاتے ہیں۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmciv{آپ(ص) کہہ دیجئے! اے اللہ! اے آسمانوں اور زمین کے پیدا کرنے والے (اور) اے غائب و حاضر کے جاننے والے! تو ہی اپنے بندوں کے درمیان فیصلہ کرے گا ان چیزوں کے بارے میں جن میں وہ باہم اختلاف کیا کرتے تھے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcv{اور جن لوگوں نے (کفر و شرک کرکے) ظلم کیا اگر ان کے پاس وہ سب کچھ ہو جو زمین میں ہے اور اتنی اور بھی تو وہ یہ سب کچھ قیامت کے دن برے عذاب سے بچنے کیلئے فدیہ دے دیں اور (اس دن) اللہ کی طرف سے وہ کچھ ظاہر ہوگا جس کا انہیں گمان بھی نہیں تھا۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcvi{اور وہاں ان پر ان کی کمائی کی برائیاں ظاہر ہو جائیں گی اور انہیں وہ (عذاب) گھیر لے گا جس کا وہ مذاق اڑایا کرتے تھے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcvii{اور جب انسان کو کوئی تکلیف پہنچتی ہے تو وہ ہمیں پکارتا ہے اور پھر جب ہم اسے اپنی جانب سے کوئی نعمت عطا کرتے ہیں تو وہ کہتا ہے کہ یہ تو مجھے اپنے علم و ہنر کی بنا پر دی گئی ہے بلکہ وہ ایک آزمائش ہے لیکن اکثر لوگ نہیں جانتے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcviii{ایسی بات ان لوگوں نے بھی کہی تھی جو ان سے پہلے تھے تو (ہماری گرفت کے وقت) ان کی کوئی کمائی ان کے کام نہ آئی۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcix{تو انہوں نے جو کچھ کمایا تھا اس کے برے نتائج ان تک پہنچے اور جو ان لوگوں میں سے ظالم ہیں ان تک بھی۔ ان کی برائی کے برے نتائج پہنچیں گے اور وہ (اللہ کو) عاجز نہیں کر سکتے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcx{کیا وہ نہیں جانتے کہ اللہ جس کا چاہتا ہے رزق کشادہ کرتا ہے اور جس کا چاہتا ہے تنگ کر دیتا ہے بے شک اس میں ایمان والوں کیلئے (قدرت کی) بڑی نشانیاں ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcxi{آپ(ص) کہہ دیجئے! کہ اے میرے بندو! جنہوں نے (گناہ پر گناہ کرکے) اپنی جانوں پر زیادتی کی ہے اللہ کی رحمت سے ناامید نہ ہو۔ بے شک اللہ سب گناہوں کو بخش دیتا ہے کیونکہ وہ بڑا بخشنے والا (اور) بڑا رحم کرنے والا ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcxii{اور اپنے پروردگار کی طرف رجوع کرو اور اس کے فرمانبردار بن جاؤ قبل اس کے کہ تم پر عذاب آجائے پھر تمہاری کوئی مدد نہیں کی جائے گی۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiii{اور اس بہترین کلام و پیغام کی پیروی کرو جو تمہارے پروردگار کی طرف سے تمہاری طرف اتارا گیا ہے پیشتر اس کے کہ تم پر اچانک عذاب آجائے اور تمہیں خبر بھی نہ ہو۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiv{مبادا کوئی شخص یہ کہے ہائے افسوس! میری اس کوتاہی پر جو میں نے خدا کی جناب میں کی اور میں تو مذاق اڑانے والوں میں شامل رہا۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxv{یا کوئی یہ کہے کہ اگر اللہ مجھے ہدایت دیتا تو میں بھی متقیوں میں سے ہوتا۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvi{یا کوئی عذاب دیکھ کر یہ کہے کاش مجھے ایک بار (دنیا میں دوبارہ جانے کا) موقع ملتا تو میں بھی نیکوکاروں میں سے ہو جاتا۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvii{ہاں (کیوں نہیں) تیرے پاس میری آیتیں آئی تھیں مگر تو نے انہیں جھٹلایا اور تکبر کیا اور تو کافروں میں سے تھا۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxviii{اور قیامت کے دن تم دیکھوگے کہ جن لوگوں نے خدا پر جھوٹ باندھا تھا ان کے چہرے سیاہ ہوں گے۔ کیا تکبر کرنے والوں کا ٹھکانا جہنم نہیں ہے؟\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxix{اور اللہ متقیوں کو ان کی کامیابی کی وجہ سے اس طرح نجات دے گا کہ انہیں نہ کوئی تکلیف پہنچے گی اور نہ ہی وہ غمگین ہوں گے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxx{اور وہی ہر چیز کا پیدا کرنے والا ہے اور وہی ہر چیز پر نگہبان ہے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxi{اور آسمانوں اور زمین (کے خزانوں) کی کنجیاں اسی کے پاس ہیں اور جو لوگ اللہ کی آیتوں کا انکار کرتے ہیں وہی نقصان اٹھانے والے ہیں۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxii{آپ(ص) کہہ دیجئے! اے جاہلو! کیا تم (پھر بھی) مجھ سے غیر اللہ کی عبادت کرنے کی فرمائش کرتے ہو؟\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiii{بیشک آپ(ص) کی طرف بھی وحی کی جا چکی ہے اور ان (انبیاء(ع)) کی طرف بھی جو آپ سے پہلے تھے کہ اگر (بفرضِ محال) آپ نے بھی شرک کیا تو آپ کے عمل ضائع ہو جائیں گے اور آپ نقصان اٹھانے والوں میں سے ہو جائیں گے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiv{(اے نبی(ص)) بلکہ آپ بس اللہ ہی کی عبادت کیجئے اور شکر گزار بندوں میں سے ہو جائیے۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxv{اور ان لوگوں نے اللہ کی اس طرح قدر نہیں کی جس طرح کہ اس کی قدر کرنی چاہیے تھی۔ حالانکہ قیامت کے دن ساری زمین اس کی مٹھی میں ہوگی اور سب آسمان بھی اس کے دائیں ہاتھ میں لپٹے ہوں گے وہ پاک ہے اور برتر ہے اس شرک سے جو وہ کرتے ہیں۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvi{اور (پہلی بار) صور پھونکا جائے گا تو جو آسمانوں میں ہیں وہ بھی اور جو زمین میں وہ بھی سب بے ہوش ہو کر گر پڑیں گے سوائے ان کے جن کو اللہ چاہے گا (وہ بے ہوش نہیں ہوں گے) پھر دوبارہ پھونکا جائے گا تو وہ ایک دم کھڑے ہوکر (ِادھر اُدھر) دیکھنے لگیں گے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvii{اور زمین اپنے پروردگار کے نور سے چمک اٹھے گی اور نامۂ اعمال رکھ دیا جائے گا اور ان پر ظلم نہیں کیا جائے گا۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxviii{اور ہر شخص نے جو کچھ عمل کیا ہوگا اسے اس کا پورا پورا بدلہ دیا جائے گا اور لوگ جو کچھ کرتے ہیں ہیں اللہ اسے خوب جانتا ہے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxix{اور جن لوگوں نے کفر اختیار کیا وہ (اس خدائی فیصلہ کے بعد) جہنم کی طرف گروہ در گروہ ہانکے جائیں گے یہاں تک کہ جب وہ اس کے پاس پہنچیں گے تو اس کے دروازے کھول دیئے جائیں گے اور اس کے داروغے ان سے کہیں گے کہ کیا تمہارے پاس تمہی میں سے کچھ رسول(ع) نہیں آئے تھے جو تمہیں تمہارے پروردگار کی آیتیں پڑھ کر سناتے تھے اور تمہیں اس دن کے پیش آنے سے ڈراتے تھے وہ (جواب میں) کہیں گے کہ ہاں (آئے تو تھے) لیکن (ہم نے نہ مانا کیونکہ) کافروں پر عذاب کا فیصلہ ہو چکا تھا۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxx{(پھر ان سے) کہا جائے گا کہ جہنم کے دروازوں میں داخل ہو جاؤ اس میں ہمیشہ رہنے کیلئے کتنا برا ٹھکانا ہے متکبروں کا۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxi{اور جو لوگ اپنے پروردگار سے ڈرتے رہتے تھے وہ گروہ در گروہ بہشت کی طرف لے جائے جائیں گے یہاں تک کہ جب وہ اس کے پاس پہنچیں گے اور اس کے دروازے کھولے جا چکے ہوں گے اور اس کے نگہبان ان سے کہیں گے سلامٌ علیکم (سلام ہو تم پر) تم پاک ہو! اب تم اس میں داخل ہو جاؤ ہمیشہ رہنے کیلئے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxii{اور وہ کہیں گے کہ سب تعریف (اور شکر) ہے اس خدا کا جس نے ہم سے کیا ہوا اپنا وعدہ سچا کر دکھایا اور ہمیں (اس) زمین کا وارث بنایا کہ اب ہم جنت میں جہاں چاہیں گے وہاں رہیں گے۔ کتنا اچھا صلہ ہے (نیک) عمل کرنے والوں کا۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiii{اور آپ فرشتوں کو دیکھیں گے کہ وہ عرش (الٰہی) کے اردگرد اپنے پروردگار کی تسبیح (تقدیس) کر رہے ہوں گے اور ان (لوگوں) کے درمیان حق (و انصاف) کے ساتھ فیصلہ کر دیا جائے گا ہر قِسم کی تعریف اس اللہ کیلئے ہے جو تمام جہانوں کا پروردگار ہے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiv{\basmalahur حا۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxv{اس کتاب (قرآن) کا نزول اس اللہ کی طرف سے ہے جو زبردست (اور) بڑا جاننے والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvi{جو گناہ معاف کرنے والا (اور) توبہ قبول کرنے والا، سخت سزا دینے والا (اور) عطا و بخشش والا ہے اس کے سوا کوئی الٰہ (خدا) نہیں ہے سب کی بازگشت اسی کی طرف ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvii{اللہ کی آیتوں کے بارے میں صرف کافر ہی جھگڑا کرتے ہیں۔ لہٰذا ان لوگوں کا (مختلف) شہروں میں (آزادی) کے ساتھ گھومنا پھرنا کہیں آپ کو دھوکہ میں نہ ڈال دے (کہ انہیں عذاب نہیں ہوگا)۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxviii{ان سے پہلے نوح(ع) کی قوم نے (نوح(ع) کو) جھٹلایا اور ان کے بعد اور بہت سے گروہوں نے (اپنے رسولوں(ع) کو) جھٹلایا اور ہر امت نے ارادہ کیا کہ اپنے رسول(ع) کو گرفتار کرے (اور پھر شہید کر دے) اور ناحق طریقہ پر جھگڑا کیا تاکہ اس کے ذریعہ سے حق کو شکست دے۔ سو (انجامِ کار) میں نے ان کو پکڑ لیا تو میرا عذاب کیسا (سخت) تھا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxix{اور اسی طرح آپ(ص) کے پروردگار کا یہ فیصلہ کافروں پر ثابت ہو چکا کہ وہ سب دوزخی ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcxl{جو (فرشتے) عرش کو اٹھائے ہوئے ہیں اور جو اس کے اردگرد میں وہ سب اپنے پروردگار کی حمد کے ساتھ تسبیح کرتے ہیں اور وہ اس پر ایمان رکھتے ہیں اور ایمان والوں کیلئے مغفرت طلب کرتے ہیں کہ اے ہمارے پروردگار تو اپنی رحمت اور اپنے علم سے ہر چیز کا احاطہ کئے ہوئے ہے۔ پس تو ان لوگوں کو بخش دے جو توبہ کرتے ہیں اور تیرے راستہ کی پیروی کرتے ہیں اور انہیں دوزخ کے عذاب سے بچا لے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcxli{اے ہمارے پروردگار! اور ان کو ان ہمیشہ رہنے والے بہشتوں میں داخل کر جن کا تو نے ان سے وعدہ کیا ہے اور ان کے آباء و اجداد، بیویوں اور اولاد میں سے جو صالح اور لائق ہوں ان کو بھی (بخش دے اور وہیں ان کے ہمراہ داخل کر) بے شک تو غالب ہے (اور) بڑا حکمت والا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlii{اور ان کو برائیوں سے بچا اور جس کو تو نے قیامت کے دن برائیوں سے بچا لیا بس تو نے اس پر رحمت فرمائی اور یہی بہت بڑی کامیابی ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliii{بے شک جن لوگوں نے کفر اختیار کیا (قیامت کے دن) ان کو پکار کر کہا جائے گا کہ جتنا (آج) تم اپنے آپ سے بیزار ہو۔ اللہ اس سے زیادہ اس وقت تم سے بیزار (ناراض) ہوتا تھا جب تمہیں ایمان کی دعوت دی جاتی تھی اور تم کفر اختیار کرتے تھے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliv{وہ کہیں گے اے ہمارے پروردگار! تو نے ہمیں دو بار موت دی اور دو بار زندہ کیا بس اب ہم اپنے گناہوں کا اعتراف کرتے ہیں کیا اب (یہاں سے) نکلنے کی کوئی صورت ہے؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlv{(جواب ملے گا کہ) یہ اس لئے ہے کہ جب (تمہیں) خدائے واحد و یکتا کی طرف بلایا جاتا تھا تو تم انکار کر دیتے تھے اور اگر کسی کو اس کا شریک بنایا جاتا تھا تو تم جان لیتے تھے اب فیصلہ اللہ کے اختیار میں ہے جو عالیشان ہے (اور) بزرگ ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvi{وہ (اللہ) وہی ہے جو تمہیں اپنی (قدرت کی ) نشانیاں دکھاتا ہے اور تمہارے لئے آسمان سے رزق نازل کرتا ہے اور ان (نشانیوں) سے نصیحت صرف وہی حاصل کرتا ہے جو (اس کی طرف) رجوع کرتا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvii{پس اللہ ہی کو پکارو اس کے لئے دین کو (شرک و ریا سے) خالص کرتے ہوئے چاہے کافر ناپسند کریں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlviii{(وہ) بلند درجوں والا (اور) عرش کا مالک ہے وہ اپنے بندوں میں سے جس پر چاہتا ہے اپنے حکم سے روح (وحی) کو نازل کرتا ہے تاکہ وہ بارگاہِ الٰہی میں حضوری والے دن سے ڈرائے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlix{وہ دن جب لوگ ظاہر ہوں گے ان کی کوئی بات اللہ پر پوشیدہ نہ ہوگی (آواز آئے گی) آج کس کی حکومت ہے؟ (جواب ملے گا) صرف اللہ کی جو واحد و یکتا ہے اور ہر چیز پر غالب ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcl{آج ہر شخص کو اس کے کئے کا بدلہ دیا جائے گا آج کچھ بھی ظلم نہ ہوگا بیشک اللہ جلد حساب لینے والا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcli{اور لوگوں کو اس دن (قیامت) سے ڈرائیے جو قریب آنے والا ہے جس دن دل (کھینچ کر) گلوں تک آجائیں گے (اور) وہ غم و غصہ سے بھرے ہوئے ہوں گے۔ ظالموں کیلئے کوئی (مخلص) دوست نہ ہوگا اور نہ کوئی ایسا سفارشی جس کی بات مانی جائے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmclii{وہ آنکھوں کی مجرمانہ جنبش کو جانتا ہے اور ان باتوں کو بھی جن کو سینے چھپاتے ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcliii{اور اللہ حق کے ساتھ فیصلہ کرے گا اور جنہیں وہ لوگ اللہ کے سوا پکارتے ہیں وہ کسی چیز کا فیصلہ نہیں کر سکتے۔ بیشک اللہ بڑا سننے والا (اور) بڑا دیکھنے والا ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcliv{کیا یہ لوگ زمین پر چلتے پھرتے نہیں ہیں کہ دیکھیں کہ ان لوگوں کا انجام کیا ہوا جو ان سے پہلے تھے؟ قوت کے لحاظ سے اور زمین میں چھوڑے ہوئے آثار کے اعتبار سے ان سے زیادہ طاقتور تھے تو اللہ نے ان کے گناہوں کی پاداش میں ان کو پکڑا تو ان کو اللہ (کی گرفت) سے بچانے والا کوئی نہ تھا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmclv{(ان کا یہ انجام) اس لئے ہوا کہ ان کے رسول(ع) ان کے پاس کھلی نشانیاں (معجزے) لے کر آتے تھے تو وہ کفر کرتے تھے۔ آخرکار اللہ نے انہیں پکڑ لیا بیشک وہ بڑا طاقتور (اور) سخت سزا دینے والا ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmclvi{بیشک ہم نے موسیٰ(ع) کو فرعون، ہامان اور قارون کی طرف اپنی نشانیوں (معجزوں) اور کھلی ہوئی دلیلوں کے ساتھ بھیجا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmclvii{تو انہوں نے کہا کہ یہ ایک جادوگر (اور) بڑا جھوٹا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmclviii{سو جب وہ ہماری طرف سے حق لے کر ان کے پاس آئے تو انہوں نے کہا کہ جو لوگ ان کے ساتھ ایمان لائے ہیں ان کے بیٹوں کو قتل کر دو اور ان کی عورتوں (لڑکیوں) کو زندہ چھوڑ دو۔ اور کافروں کی( ہر) تدبیر گمراہی میں (رائیگاں) ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmclix{اور فرعون نے کہا کہ مجھے چھوڑ دو۔ میں موسیٰ(ع) کو قتل کر دوں اور وہ (اپنی مدد کیلئے) اپنے پرورگار کو پکارے مجھے اندیشہ ہے کہ وہ کہیں تمہارا دین (شرک) نہ بدل دے۔ یا زمین میں فساد برپا نہ کر دے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmclx{اور موسیٰ(ع) نے کہا کہ میں اپنے اور تمہارے پروردگار سے پناہ مانگتا ہوں جو مجھے ہر اس متکبر (کے شر) سے بچائے جو روزِ حساب (قیامت) پر ایمان نہیں رکھتا۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmclxi{اور فرعون کے خاندان میں سے ایک مردِ مؤمن نے کہا جو اپنے ایمان کو چھپائے رکھتا تھا۔ کیا تم ایک شخص کو صرف اس بات پر قتل کرنا چاہتے ہو کہ وہ کہتا ہے کہ میرا پروردگار اللہ ہے؟ حالانکہ وہ تمہارے پروردگار کی طرف سے تمہارے پاس بیّنات (معجزات) لے کر آیا ہے اگر وہ جھوٹا ہے تو اس کے جھوٹ کا وبال اسی پر پڑے گا اور اگر وہ سچا ہے تو جس (عذاب) کی وہ تمہیں دھمکی دیتا ہے تو اس کا کچھ حصہ تو تمہیں پہنچ کر رہے گا۔ بیشک اللہ اس شخص کو ہدایت نہیں دیتا جو حد سے بڑھنے والا اور بڑا جھوٹا ہو۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmclxii{اے میری قوم! (بے شک) آج تمہاری حکومت ہے (اور) اس سر زمین میں تمہیں غلبہ بھی حاصل ہے لیکن اگر اللہ کا عذاب ہم پر آگیا تو کون ہماری مدد کرے گا؟ (اور اس سے ہمیں کون بچائے گا؟) (مؤمن کی یہ بات سن کر) فرعون نے کہا میں تمہیں وہی رائے دیتا ہوں۔ جو میں (درست) سمجھتا ہوں اور میں تمہاری راہنمائی صرف اسی راستہ کی طرف کرتا ہوں جو سیدھا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiii{اور جو شخص ایمان لایا تھا وہ کہنے لگا۔ اے میری قوم! مجھے تمہاری نسبت ڈر ہے کہ تم پر (تباہ شدہ) گروہوں جیسا دن نہ آجائے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiv{جیسا حال قومِ نوح(ع) اور عاد و ثمود اور ان کے بعد والوں کا ہوا تھا اور اللہ تو (اپنے بندوں پر ظلم کا ارادہ (بھی) نہیں کرتا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmclxv{اے میری قوم! میں تمہارے بارے میں چیخ و پکار والے دن سے ڈرتا ہوں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvi{جس دن تم پیٹھ پھیر کر (دوزخ کی طرف) بھاگوگے تمہیں اللہ کے (عذاب) سے کوئی بچانے والا نہ ہوگا اور جس کو اللہ گمراہی میں چھوڑ دے اسے کوئی ہدایت کرنے والا نہیں ہوتا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvii{اور (اے میری قوم) اس سے پہلے تمہارے پاس یوسف(ع) کھلی ہوئی دلیلیں (معجزات) لے کر آئے مگر تم برابر شک ہی میں پڑے رہے یہاں تک کہ جب وہ وفات پا گئے تو تم نے کہا (اب) اللہ ان کے بعد ہرگز کوئی رسول نہیں بھیجے گا۔ اسی طرح اللہ اس شخص کو گمراہی میں چھوڑتا ہے جو حد سے بڑھنے والا (اور) شک کرنے والا ہوتا ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmclxviii{جو لوگ آیاتِ الٰہی میں جھگڑے کرتے ہیں بغیر کسی دلیل کے جو ان کے پاس آئی ہو۔ یہ روش اللہ اور اہلِ ایمان کے نزدیک سخت مبغوض (اور ناپسندیدہ) ہے اللہ اسی طرح ہر منکر و سرکش کے دل پر مہر لگا دیتا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmclxix{اور فرعون نے کہا اے ہامان! میرے لئے ایک اونچا محل بنا (بنوا) تاکہ میں (اس پر چڑھ کر) راستوں تک پہنچ جاؤں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmclxx{یعنی آسمانوں کے راستوں تک (اور پھر وہاں سے) موسیٰ(ع) کے خدا کو جھانک کر دیکھوں اور میں تو اسے جھوٹا سمجھتا ہوں اور اسی طرح فرعون کیلئے اس کا بدعمل خوشنما بنا دیا گیا اور وہ (سیدھے) راستہ سے روک دیا گیا اور فرعون کی ہر تدبیر (چالبازی) غارت ہی گئی (اور اس کی تباہی پر منتج ہوئی)۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxi{اور جو شخص ایمان لا چکا تھا اس نے کہا اے میری قوم! میری پیروی کرو۔ میں تمہیں سیدھا راستہ دکھاؤں گا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxii{اے میری قوم! یہ دنیا کی زندگی محض (چند روزہ) فائدہ ہے اور مستقل قیام گاہ تو آخرت ہی ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiii{کوئی برائی کرتا ہے تو اسے بدلہ بھی اس کے برابر ملے گا اور جو کوئی نیک کام کرتا ہے خواہ مرد ہو یا عورت بشرطیکہ وہ مؤمن ہو تو یہ بہشت میں داخل ہوں گے جہاں انہیں بے حساب رزق دیا جائے گا۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiv{اور اے میری قوم! (یہ کیا ہے؟) میں تمہیں نجات کی طرف بلاتا ہوں اور تم مجھے آتشِ دوزخ کی طرف بلاتے ہو۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxv{تم مجھے دعوت دیتے ہو کہ میں اللہ کا انکار کروں اور ایسی چیز کو اس کا شریک بناؤں جس کا مجھے علم نہیں ہے اور میں تمہیں اس خدا کی طرف بلاتا ہوں جو (ہر چیز پر) غالب ہے (اور) بڑا بخشنے والا ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvi{یقیناً تم مجھے ایسی چیز کی دعوت دیتے ہو جو نہ دنیا میں کارآمد ہے اور نہ آخرت میں اور ہم سب کی بازگشت خدا ہی کی طرف سے اور جو حد سے بڑھنے والے ہیں وہی جہنمی ہیں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvii{تم عنقریب یاد کروگے جو میں (آج) کہہ رہا ہوں اور میں اپنا معاملہ اللہ کے سپرد کرتا ہوں بے شک وہ (اپنے) بندوں کا خوب نگران ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxviii{پس اللہ نے اس (مردِ مؤمن) کو ان لوگوں کی تدبیروں اور چالوں کی برائیوں سے بچا لیا اور فرعون والوں کو برے عذاب نے گھیر لیا۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxix{(اور اب تو) دوزخ کی آگ ہے جس پر انہیں صبح و شام پیش کیا جا رہا ہے اور جس دن قیامت قائم ہوگی (حکم ہوگا) فرعون والوں کو سخت ترین عذاب میں داخل کرو۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxx{اور وہ وقت یاد کرو جب یہ لوگ جہنم میں ایک دوسرے سے جھگڑیں گے تو کمزور لوگ بڑا بننے والوں سے کہیں گے کہ ہم تو تمہارے تابع تھے کیا تم آگ کا کچھ حصہ ہم سے ہٹا سکتے ہو؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxi{وہ بڑا بننے والے کہیں گے ہم سب اسی میں پڑے ہیں اور اللہ نے اپنے بندوں کے درمیان فیصلہ کر دیا ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxii{اور جو لوگ دوزخ میں ہوں گے وہ جہنم کے داروغوں سے کہیں گے کہ اپنے پروردگار سے دعا کرو کہ ہمارے عذاب میں ایک دن کی ہی تخفیف کر دے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiii{وہ (جواب میں کہیں گے) کیا تمہارے پاس کھلی ہوئی دلیلیں لے کر تمہارے رسول(ع) نہیں آتے رہے تھے؟ وہ کہیں گے کہ ہاں اس پر داروغے کہیں گے کہ تم خود ہی دعا مانگو اور کافروں کی دعا و پکار بالکل گم شدہ ہے (اکارت جانے والی ہے)۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiv{بے شک ہم اپنے رسولوں(ع) کی اور ایمان والوں کی اس دنیاوی زندگی میں بھی مدد کرتے رہتے ہیں اور اس دن بھی کریں گے جب گواہ (گواہی دینے کیلئے) کھڑے ہوں گے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxv{جس دن ظالموں کو ان کی معذرت کوئی فائدہ نہ دے گی اور ان کیلئے لعنت ہوگی ان کیلئے (دوزخ کا) بہت برا گھر ہوگا۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvi{اور بالیقین ہم نے موسیٰ(ع) کو ہدایت عطا فرمائی اور بنی اسرائیل کو ایسی کتاب (توراۃ) کا وارث بنایا۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvii{جو صاحبانِ عقل کیلئے سراپا ہدایت اور نصیحت تھی۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxviii{آپ صبر (و ثبات) سے کام لیجئے! اللہ کا وعدہ برحق ہے اور (تہمت) گناہ پر استغفار کرتے رہیے اور صبح و شام اپنے پروردگار کی حمد کے ساتھ اس کی تسبیح کیجئے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxix{یقیناً جو لوگ اللہ کی آیتوں کے بارے میں (آپ(ص) سے) جھگڑتے ہیں بغیر کسی سند کے جو ان کے پاس آئی ہو ان کے سینوں میں تکبر (بڑائی) کے سوا اور کچھ نہیں ہے جس تک وہ کبھی پہنچنے والے نہیں ہیں آپ(ص) اللہ کی پناہ مانگئے! بے شک وہ بڑا سننے (اور) بڑا دیکھنے والا ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxc{بے شک آسمانوں اور زمین کا پیدا کرنا انسانوں کے پیدا کرنے سے زیادہ بڑا کام ہے لیکن اکثر لوگ جانتے نہیں ہیں۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxci{اور اندھا اور آنکھ والا برابر نہیں ہو سکتے اور اسی طرح ایماندار اور نیکوکار اور بدکار بھی یکساں نہیں ہو سکتے مگر تم لوگ بہت کم نصیحت قبول کرتے ہو۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcii{یقیناً قیامت آنے والی ہے اس میں کوئی شک نہیں ہے مگر اکثر لوگ نہیں مانتے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciii{اور تمہارا پروردگار کہتا ہے کہ تم مجھ سے دعا کرو۔ میں تمہاری دعا قبول کروں گا اور جو لوگ میری (اس) عبادت سے تکبر کرتے ہیں وہ عنقریب ذلیل و خوار ہوکر جہنم میں داخل ہوں گے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciv{وہ اللہ ہی ہے جس نے تمہارے لئے رات بنائی تاکہ تم اس میں آرام (اور سکون حاصل) کرو اور دن کو روشن بنایا (تاکہ تم اس میں کام کرو) بے شک اللہ لوگوں پر بڑا فضل و کرم کرنے والا ہے مگر اکثر لوگ شکر ادا نہیں کرتے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcv{یہی اللہ تمہارا پروردگار ہے جو ہر چیز کا پیدا کرنے والا ہے اس کے سوا کوئی الٰہ (خدا) نہیں ہے تم کدھر بہکائے جا رہے ہو؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvi{اسی طرح وہ لوگ (بھی) بہکائے جاتے رہے ہیں جو اللہ کی آیتوں کا انکار کرتے تھے۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvii{وہ اللہ ہی ہے جس نے زمین کو تمہارے لئے قرارگاہ اور آسمان کو عمارت (چھت) بنایا اور تمہاری صورت گری کی اور تمہاری صورتوں کو حسین (و جمیل) بنایا اور تمہیں کھانے کیلئے پاکیزہ غذائیں عطا کیں یہی اللہ تمہارا پروردگار ہے پس بڑا ہی بابرکت الٰہ ہے جو سارے جہانوں کا پروردگار ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcviii{وہی (حقیقی) زندہ ہے اس کے سوا کوئی الٰہ (خدا) نہیں ہے سو اسی کو پکارو دین کو اس کیلئے خالص کرتے ہوئے۔ ہر قسم کی تعریف اللہ کیلئے ہے جو تمام جہانوں کا پروردگار ہے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcix{آپ(ص) کہہ دیجئے! کہ مجھے منع کر دیا گیا ہے کہ میں ان کی عبادت کروں جنہیں تم اللہ کو چھوڑ کر پکارتے ہو جبکہ میرے پروردگار کی طرف سے میرے پاس کھلی ہوئی دلیلیں آچکی ہیں اور مجھے حکم دیا گیا ہے کہ میں رب العالمین کے سامنے اپنا سر تسلیم خم کر دوں (اس کا فرمانبردار بندہ بنوں)۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcc{اللہ وہی ہے جس نے تمہیں مٹی سے پیدا کیا پھر نطفہ سے پھر خون کے لوتھڑے سے پھر تمہیں (شکمِ مادر سے) بچہ بنا کر نکالا۔ پھر (تمہاری پرورش کی) تاکہ تم اپنی پوری طاقت (جوانی) کو پہنچو (پھر زندہ رکھتا ہے) تاکہ تم بوڑھے ہو جاؤ اور تم میں سے کوئی پہلے اٹھا لیا جاتا ہے (یہ سب کچھ اس لئے ہے کہ تم مقررہ وقت تک پہنچ جاؤ اور عقل سے کام لو (خدا کی قدرت و حکمت کو سمجھو)۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcci{وہ وہی ہے جو زندہ کرتا ہے اور مارتا ہے وہ جب کسی کام کا فیصلہ کر لیتا ہے تو اس سے کہتا ہے کہ ہو جا تو وہ ہو جاتا ہے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmccii{کیا تم نے ان لوگوں کو نہیں دیکھا جو اللہ کی آیتوں کے بارے میں جھگڑتے رہتے ہیں وہ کدھر پھرائے جا رہے ہیں؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcciii{جن لوگوں نے اس کتاب (قرآنِ مجید) کو جھٹلایا اور اس (پیغام) کو بھی جس کے ساتھ ہم نے اپنے پیغمبروں کو بھیجا تو انہیں بہت جلد (اس کا انجام) معلوم ہو جائے گا۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcciv{جب طوق ان کی گردنوں میں ہوں گے اور (پاؤں میں) زنجیریں ان کو گھسیٹتے ہوئے لایا جائے گا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmccv{کھولتے ہوئے پانی میں۔ پھر آتشِ دوزخ میں جھونک دیئے جائیں گے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmccvi{پھر ان سے کہا جائے گا (آج) وہ کہاں ہیں جنہیں تم اللہ کو چھوڑ کر شریک مانتے تھے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmccvii{وہ کہیں گے وہ تو ہم سے غائب ہوگئے بلکہ ہم تو اس سے پہلے (خدا کے سوا) کسی چیز کو پکارتے ہی نہ تھے خدا اسی طرح کافروں کو گمراہی میں چھوڑ دیتا ہے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmccviii{یہ اس لئے ہے کہ تم زمین میں ناحق خوش ہوا کرتے تھے اور (اپنے مال و اقتدار پر) اِترایا کرتے تھے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmccix{(اب تم جہنم کے دروازوں میں داخل ہو جاؤ اس میں ہمیشہ پڑے رہنے کیلئے۔ پس کیا برا ٹھکانہ ہے تکبر کرنے والوں کا۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmccx{آپ(ص) صبر کیجئے یقیناً اللہ کا وعدہ برحق ہے پھر جس (عذاب) کی ہم انہیں دھمکی دیتے رہے ہیں خواہ اس کا کچھ حصہ آپ کو (آنکھوں سے) دکھا دیں یا اس سے پہلے آپ کو دنیا سے اٹھا لیں۔ بہرحال ان سب کی بازگشت تو ہماری طرف ہی ہے (وہ اس سے بچ نہیں سکتے)۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmccxi{ہم نے آپ(ص) سے پہلے بہت سے رسول بھیجے جن میں سے بعض کے حالات آپ سے بیان کر دیئے ہیں اور بعض ایسے ہیں کہ جن کے حالات آپ سے بیان نہیں کئے اور کسی رسول کیلئے یہ ممکن نہ تھا کہ اللہ کے اذن (حکم) کے بغیر کوئی معجزہ پیش کرے اور جب اللہ کا حکم آجائے گا تو حق کے ساتھ فیصلہ کر دیا جائے گا اور اس وقت باطل والے خسارے میں رہیں گے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmccxii{اللہ وہی ہے جس نے تمہارے لئے چوپائے بنائے ہیں تاکہ تم ان میں سے بعض پر سوار ہو اور بعض کا (گوشت) کھاؤ۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiii{اور تمہارے لئے ان میں اور بھی فائدے ہیں اور تاکہ تم ان پر سوار ہو کر اپنے دلوں کی حاجت تک پہنچ سکو اور تم ان پر اور کشتیوں پر سوار کئے جاتے ہو۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiv{اور وہ (اللہ) تمہیں اپنی (قدرت و حکمت کی) نشانیاں دکھاتا ہے سو تم اللہ کی کن کن نشانیوں کا انکار کروگے؟\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmccxv{کیا وہ زمین میں چلتے پھرتے نہیں کہ ان لوگوں کا انجام دیکھتے جو ان سے پہلے گزرے ہیں جو تعداد میں ان سے زیادہ تھے اور طاقت میں اور زمین میں اپنی چھوڑی ہوئی نشانیوں کے اعتبار سے ان سے بڑھے ہوئے تھے لیکن ان کی سب کمائی کچھ ان کے کام نہ آئی۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvi{جب ان کے رسول ان کے پاس بیّنات (معجزات) لے کر آئے تو وہ اپنے اس علم پر نازاں و فرحاں رہے جو ان کے پاس تھا اور (انجامِ کار) اسی (عذاب) نے انہیں گھیر لیا جس کا وہ مذاق اڑایا کرتے تھے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvii{پھر جب انہوں نے ہمارا عذاب کو دیکھا تو کہنے لگے کہ ہم خدائے واحد و یکتا پر ایمان لاتے ہیں اور ان سب چیزوں کا انکار کرتے ہیں جنہیں ہم اس کے ساتھ شریک ٹھہراتے تھے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmccxviii{پس ہمارا عذاب دیکھ لینے کے بعد ان کے ایمان نے انہیں کوئی فائدہ نہ پہنچایا۔ یہی اللہ کا طریقہ ہے جو (ہمیشہ سے) اس کے بندوں میں جاری ہے اور اس وقت کافر لوگ خسارے میں رہ گئے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmccxix{\basmalahur حا۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmccxx{یہ (قرآن) رحمٰن و رحیم خدا کی طرف سے نازل کردہ ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxi{یہ ایسی کتاب ہے جس کی آیتیں تفصیل سے بیان کر دی گئی ہیں ان لوگوں کیلئے جو علم رکھتے ہیں عربی زبان کے قرآن کی صورت میں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxii{یہ (قرآن) خوشخبری دینے والا اور ڈرانے والا ہے مگر اکثر لوگوں نے اس سے روگردانی کی ہے۔ پس وہ سنتے ہی نہیں ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiii{اور وہ کہتے ہیں کہ آپ(ص) جس چیز کی طرف ہمیں دعوت دیتے ہیں اس سے ہمارے دلوں پر غلاف چڑھے ہوئے ہیں اور ہمارے کانوں میں گرانی ہے اور ہمارے تمہارے درمیان پردہ حائل ہے آپ اپنا کام کیجئے ہم اپنا کام کر رہے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiv{آپ(ص) کہہ دیجئے! کہ میں بھی تمہاری ہی طرح بشر ہوں (مگر فرق یہ ہے) کہ مجھے وحی کی جاتی ہے کہ تمہارا الٰہ (خدا) بس ایک ہی الٰہ (خدا) ہے تو تم سیدھے اسی کی طرف رخ رکھو اور اس سے مغفرت طلب کرو اور بربادی ہے ان مشرکوں کیلئے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxv{جو زکوٰۃ ادا نہیں کرتے اور وہ قیامت کے منکر ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvi{جو لوگ ایمان لائے اور نیک عمل کئے ان کیلئے وہ اجر ہے جو ختم ہونے والا نہیں ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvii{آپ(ص) کہہ دیجئے! کیا تم اس ذات کا انکار کرتے ہو جس نے زمین کو پیدا کیا اور دوسروں کو اس کا ہمسر قرار دیتے ہو؟ وہی تو سارے جہانوں کا پروردگار ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxviii{اور اسی نے زمین میں اس کے اوپر پہاڑ بنائے اور اس میں برکت رکھ دی اور اس میں تمام طلبگاروں کی ضرورت کے برابر چار دن کی مدت میں صحیح انداز سے سامانِ معیشت مہیا کر دیا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxix{پھر وہ آسمان کی طرف متوجہ ہوا جبکہ وہ دھوئیں کی شکل میں تھا اور اس سے اور زمین سے کہا کہ تم خوشی سے آؤ یا نخوشی سے تو دونوں نے کہا ہم خوشی خوشی آتے ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxx{پس اس (اللہ) نے انہیں دو دن میں سات آسمان بنا دیا اور ہر آسمان میں اس کے معاملہ کی وحی کر دی اور ہم نے آسمان دنیا کو چراغوں (ستاروں) سے زینت بخشی اور اسے محفوظ کر دیا یہ اس (خدا) کی منصوبہ بندی ہے جو (ہر چیز پر) غالب ہے اور بڑا جاننے والا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxi{پس اگر یہ لوگ روگردانی کریں تو آپ(ص) کہہ دیجئے! کہ میں نے تو تمہیں اس (آسمانی) کڑک سے ڈرا دیا ہے جو عاد والی کڑک کی مانند ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxii{جبکہ ان کے پاس (اللہ کے) رسول(ع) ان کے آگے اور ان کے پیچھے سے آئے (اس پیغام کے ساتھ) کہ اللہ کے سوا کسی کی عبادت نہ کرو۔ مگر انہوں نے (جواب میں) کہا کہ اگر ہمارا پروردگار چاہتا تو (ہماری طرف) فرشتے نازل کرتا۔ لہٰذا جس (پیغام) کے ساتھ تم بھیجے گئے ہو ہم اس کا انکار کرتے ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiii{سو قومِ عاد نے زمین میں ناحق سرکشی کی اور کہا کہ ہم سے بڑھ کر کون طاقتور ہے؟ کیا انہوں نے یہ نہ دیکھا کہ (اور نہ یہ سوچا) کہ جس نے انہیں پیدا کیا ہے کہ وہ ان سے بڑھ کر طاقتور ہے وہ (ہمیشہ) ہماری آیتوں کا انکار کرتے رہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiv{سو ہم نے ان پر خاص منحوس دنوں میں تیز و تند (طوفانی) ہوا بھیجی تاکہ ہم انہیں زندگانئِ دنیا میں ذلت آمیز عذاب کا مزہ چکھائیں اور آخرت کا عذاب تو زیادہ رسوا کن ہوگا اور ان کی کوئی مدد نہیں کی جائے گی۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxv{رہے ثمود! ہم نے ان کی راہنمائی کی مگر انہوں نے ہدایت پر اندھے پن (گمراہی) کو ترجیح دی۔ پس ان کو ذلت کے عذاب کی کڑک نے پکڑ لیا ان کے کرتوتوں کی پاداش میں جو وہ کیا کرتے تھے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvi{اور ہم نے ان لوگوں کو نجات دی جو ایمان لاتے تھے اور (ہماری نافرمانی سے) ڈرتے تھے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvii{اور جس دن اللہ کے دشمن دوزخ کی طرف جمع کئے جائیں گے اور پھر ترتیب وار کھڑے کئے جائیں گے (یا پھر روکے جائیں گے)۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxviii{یہاں تک کہ جب وہ وہاں پہنچ جائیں تو ان کے کان اور ان کی آنکھیں اور ان کی کھالیں ان کے برخلاف ان کے اعمال کی گواہی دیں گی۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxix{اور وہ اپنی کھالوں سے کہیں گے کہ تم نے ہمارے خلاف گواہی کیوں دی؟ تو وہ کہیں گی کہ ہمیں اسی اللہ نے گویائی عطا کی ہے جس نے ہر چیز کو گویائی دی اور اسی نے تمہیں پہلی مرتبہ پیدا کیا تھا اور پھر اسی کی طرف تمہاری بازگشت ہوگی۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxl{اور تم (گناہ کرتے وقت) اپنے آپ کو اس بات سے چھپا ہی نہیں سکتے تھے کہ تمہارے کان، تمہاری آنکھیں اور تمہاری کھالیں تمہاری خلاف گواہی دیں لیکن تم نے یہ گمان کیا کہ اللہ تمہارے بہت سے اعمال کو نہیں جانتا جو تم کرتے ہو۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxli{تمہارے اسی گمان نے جو تم نے اپنے پروردگار کی نسبت کیا تھا تمہیں تباہ کر دیا اور تم خسارہ اٹھانے والوں میں سے ہوگئے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlii{پس اب اگر وہ صبر کریں بھی تو ان کا ٹھکانا دوزخ ہے اور اگر وہ (خدا کو) راضی کرنا چاہیں تو وہ ان لوگوں میں سے نہیں ہوں گے جن پر (اللہ) راضی ہوا۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliii{اور ہم نے ان کے لئے کچھ ساتھی مقرر کر دیئے ہیں جنہوں نے ان کے اگلے اور پچھلے (کرتوتوں کو) خوشنما بنا دیا اور ان پر وہی بات ثابت ہوگئی (عذابِ الٰہی) جو جِنوں اور انسانوں کے ان گروہوں پر ثابت ہے جو ان سے پہلے گزر چکے تھے بے شک وہ سب نقصان اٹھانے والوں میں سے تھے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliv{اور کافر کہتے ہیں کہ اس قرآن کو نہ سنو اور اس کی (تلاوت کے دوران) شوروغل مچا دیا کرو شاید اس طرح تم غالب آجاؤ۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlv{ہم ان کافروں کو ضرور سخت عذاب کا مزہ چکھائیں گے اور وہ بدترین عمل کرتے ہیں ہم انہیں ضرور ان کی بدترین سزا دیں گے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvi{یہ دشمنانِ خدا کی سزا ہے یعنی دوزخ۔ ان کیلئے اسی میں ہمیشہ ہمیشہ رہنے کا گھر ہے یہ ان کے اس جرم کی سزا ہے کہ وہ ہماری آیتوں کا انکار کیا کرتے تھے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvii{اور کافر لوگ کہیں گے کہ اے ہمارے پروردگار! ہمیں دونوں قسم یعنی جنوں اور انسانوں میں سے وہ (شیطان) دکھا جنہوں نے ہمیں گمراہ کیا تھا تاکہ ہم انہیں اپنے پاؤں کے نیچے روندیں تاکہ وہ پست ترین اشخاص سے ہو جائیں (ذلیل و خوار ہوں)۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlviii{بے شک جن لوگوں نے کہا کہ ہمارا پروردگار اللہ ہے اور پھر اس پر قائم اور ثابت قدم رہے ان پر فرشتے نازل ہوتے ہیں (ان سے کہتے ہیں کہ) تم نہ ڈرو اور نہ غم کرو اور اس جنت کی بشارت پر خوش ہو جاؤ جس کا تم سے وعدہ کیا گیا ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlix{ہم زندگانئِ دنیا میں بھی تمہارے ساتھی ہیں اور آخرت میں بھی اور وہاں تمہارے لئے وہ سب کچھ ہے جو تمہارے دل چاہیں گے اور اس میں ہر چیز موجود ہے جو تم طلب کروگے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccl{(یہ سب کچھ) غفور و رحیم پروردگار کی طرف سے مہمانی کے طور پر ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccli{اور اس شخص سے بہتر بات کس کی ہوگی جو اللہ کی طرف بلائے اور نیک عمل بجا لائے اور کہے کہ میں مسلمانوں (خدا کے فرمانبردار بندوں) میں سے ہوں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcclii{اور بھلائی اور برائی برابر نہیں ہیں آپ(ص) (بدی کا) احسن طریقہ سے دفعیہ کریں تو آپ دیکھیں گے کہ آپ میں اور جس میں دشمنی تھی وہ گویا آپ کا جگری دوست بن گیا۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccliii{اور یہ صفت انہی لوگوں کو نصیب ہوتی ہے جو صبر کرتے ہیں اور یہ طریقۂ کار انہی کو سکھایا جاتا ہے جو بڑے نصیب والے ہوتے ہیں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccliv{اور (اے مخاطب) اگر تمہیں شیطان کی طرف سے کوئی وسوسہ محسوس ہو تو اس سے اللہ کی پناہ مانگ۔ بے شک وہ بڑا سننے والا (اور) بڑا جاننے والا ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcclv{اور اللہ کی نشانیوں میں رات، دن، سورج اور چاند بھی ہیں تم نہ سورج کو سجدہ کرو اور نہ چاند کو (بلکہ) اس اللہ کو سجدہ کرو جس نے انہیں پیدا کیا ہے اگر تم اسی کی عبادت کرتے ہو (اور اسی کو مستحقِ عبادت سمجھتے ہو)۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvi{اور اگر یہ لوگ تکبر کریں (اور قبولِ حق سے انکار کریں) تو جو فرشتے آپ کے پروردگار کے پاس ہیں وہ رات دن اس کی تسبیح (و تقدیس) کرتے ہیں اور وہ تھکتے نہیں ہیں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvii{اور اس کی نشانیوں میں سے ایک یہ بھی ہے کہ تم دیکھتے ہو کہ زمین جمود اور افسردگی کی حالت میں پڑی ہے اور جب ہم اس پر پانی برساتے ہیں تو جنبش میں آتی ہے (ابھرتی ہے) اور اس میں بالیدگی آجاتی ہے (پھول جاتی ہے) بیشک جس نے اسے زندہ کیا ہے وہی مُردوں کو زندہ کرنے والا ہے بلاشبہ وہ ہر چیز پر بڑی قدرت رکھنے والا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcclviii{بے شک وہ لوگ جو ہماری آیتوں میں کجروی کرتے ہیں (اور انہیں الٹے معنی پہناتے ہیں) وہ ہم پر پوشیدہ نہیں ہیں بھلا وہ شخص جو دوزخ میں ڈالا جائے وہ بہتر ہے یا وہ جو قیامت کے دن امن و اطمینان کے ساتھ آئے؟ تم جو چاہو کرو جو کچھ تم کرتے ہو اللہ اسے خوب دیکھ رہا ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcclix{جن لوگوں نے ذکر (قرآن) کا انکار کیا جب وہ ان کے پاس آیا حالانکہ وہ ایک زبردست (معزز) کتاب ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcclx{باطل کا اس کے پاس گزر نہیں ہے وہ نہ اس کے آگے سے آسکتا ہے اور نہ پیچھے سے یہ اس ذات کی طرف سے نازل شدہ ہے جو بڑی حکمت والی ہے (اور) قابلِ ستائش ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxi{(اے رسول(ص)) آپ سے وہی کچھ کہا جا رہا ہے جو آپ سے پہلے گزرے ہوئے رسولوں(ع) سے کہا گیا ہے بیشک آپ کا پروردگار بڑا بخشش والا بھی ہے اور بڑے دردناک عذاب والا بھی۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxii{اگر ہم اس (قرآن) کو عجمی زبان میں بنا کر نازل کرتے تو یہ لوگ کہتے کہ اس کی آیتیں صاف صاف (کھول کر) کیوں بیان نہیں کی گئیں؟ آپ(ص) کہہ دیجئے کہ یہ ایمان لانے والوں کیلئے ہدایت اور شفا ہے اور جو ایمان نہیں لاتے ان کے کانوں میں گرانی (بہرہ پن) ہے اور وہ ان کے حق میں نابینائی ہے اور یہ لوگ (بہرہ پن کی وجہ سے گویا) بہت دور راستہ کی جگہ سے پکارے جا رہے ہیں۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiii{اور ہم ہی نے موسیٰ(ع) کو کتاب (توراۃ) عطا کی تھی تو اس میں اختلاف کیا گیا ہے اور اگر تمہارے پروردگار کی طرف سے ایک بات پہلے طے نہ ہو چکی ہوتی تو ان (اختلاف کرنے والوں) میں فیصلہ کر دیا جاتا اور بیشک وہ ایک تردد انگیز شک میں پڑے ہوئے ہیں۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiv{جو کوئی نیک کام کرتا ہے وہ اپنے ہی لئے کرتا ہے اور جو شخص برائی کرتا ہے تو اس کا وبال بھی اسی پر ہے اور آپ(ص) کا پروردگار بندوں پر ظلم کرنے والا نہیں ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxv{ساعت (قیامت) کا علم اسی (اللہ) کی طرف لوٹایا جاتا ہے اور کوئی پھل اپنے غلافوں سے نہیں نکلتا اور نہ کوئی مادہ حاملہ ہوتی ہے اور نہ بچہ جنتی ہے مگر اسی (اللہ) کے علم کے ساتھ اور جس دن وہ (اللہ) ان (مشرکین) کو پکارے گا (اور پوچھے گا کہ)میرے شریک کہاں ہیں؟ وہ کہیں گے کہ ہم تجھے بتا چکے ہیں (عرض کر چکے ہیں) کہ ہم میں سے کوئی بھی اس کی گواہی دینے والا نہیں ہے(اور نہ کوئی ہے)۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvi{اور جن کو وہ پہلے پکارا کرتے تھے وہ سب (اس دن) گم ہو جائیں گے اور وہ سمجھ جائیں گے کہ اب ان کے لئے چھٹکارا نہیں ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvii{انسان بھلائی کی دعا کرتے ہوئے نہیں تھکتا اور اگر اسے کوئی تکلیف پہنچ جائے تو ایکدم بالکل مایوس و ناامید ہو جاتا ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxviii{اور اگر ہم اسے اس تکلیف کے بعد جو اسے پہنچتی تھی اپنی رحمت کامزہ چکھا دیتے ہیں تو وہ کہتا ہے یہ تو میرے ہی لئے ہے (میں اس کامستحق ہوں) نیز کہتا ہے کہ میں خیال نہیں کرتا کہ قیامت قائم ہوگی اور اگر میں اپنے پروردگار کی طرف کبھی لوٹایا بھی گیا تو یقیناً میرے لئے اس کے ہاں بھی بہتری ہوگی ہم کافروں کو ضرور ان کے ان اعمال سے آگاہ کریں گے جو وہ کرتے رہے اور انہیں سخت عذاب کامزہ چکھائیں گے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxix{اور جب ہم انسان کو کوئی کچھ نعمت عطا کرتے ہیں تو وہ (تکبر سے)منہ پھیر لیتا ہے اور پہلو تہی کرنے لگتا ہے اورجب اسے کوئی تکلیف پہنچتی ہے تو پھر لمبی چوڑی دعائیں کرنے لگتا ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxx{آپ(ص) کہہ دیجئے! اے کافرو! تم(غور کر کے)مجھے بتاؤ کہ اگر یہ (قرآن) اللہ کی طرف سے ہے پھر تم نے اس کا انکار کیا تو اس سے بڑھ کر کون گمراہ ہے جو مخالفت میں بہت دور نکل جائے؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxi{ہم انہیں نشانیاں دکھائیں گے آفاق و کائنات میں بھی اور خود ان کی ذات میں بھی تاکہ ان پر واضح ہو جائے کہ وہ (اللہ) بالکل حق ہے۔ کیا تمہارے پروردگار کے لئے یہ امر کافی نہیں ہے کہ وہ ہر چیز پر شاہد ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxii{یاد رکھو۔ یہ لوگ اپنے پروردگارکی بارگاہ میں حاضری و حضوری کے بارے میں شک میں مبتلا ہیں آگاہ ہو جاؤ کہ وہ (اللہ) ہر چیز کااحاطہ کئے ہوئے ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiii{\basmalahur حا۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiv{عین۔ سین۔ قاف۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxv{(اے رسول(ص)) اسی طرح اللہ غالب اور بڑا حکمت والا ہے آپ(ص) کی طرف اور آپ(ص) سے پہلے گزرے ہوئے رسولوں(ع) کی طرف وحی کرتا رہا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvi{جو کچھ آسمانوں میں ہے اور زمین میں ہے وہ اسی (اللہ) کا ہے وہ بلند و برتر اور عظیم الشان ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvii{قریب ہے کہ آسمان اپنے اوپر سے شگافتہ ہوجائیں اور فرشتے اپنے پروردگار کی حمد و تعریف کے ساتھ اس کی تسبیح کرتے ہیں اور اہلِ زمین کیلئے مغفرت طلب کرتے ہیں۔آگاہ رہو کہ اللہ یقیناً بڑابخشنے والا (اور) بڑا مہربان ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxviii{اور جن لوگوں نے اس کے سوا سرپرست (اور کارساز) بنا رکھے ہیں اللہ ان سب پر نگہبان ہے اور آپ ان کے ذمہ دار نہیں ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxix{اور اسی طرح ہم نے وحی کے ذریعہ یہ قرآن عربی زبان میں آپ کی طرف بھیجا ہے تاکہ آپ اہلِ مکہ اور اس کے گِردو پیش رہنے والوں کو ڈرائیں اورجمع ہو نے کے دن (قیامت) سے ڈرائیں جس (کے آنے) میں کوئی شک نہیں ہے (اس دن) ایک گروہ جنت میں جائے گااور ایک گروہ دوزخ میں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxx{اور اگر اللہ (زبردستی) چاہتا تو سب کو ایک امت بنا دیتا۔ لیکن وہ جسے چاہتا ہے اپنی رحمت میں داخل کرتا ہے اور جو ظالم ہیں ان کا کوئی سرپرست اور مددگار نہیں ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxi{کیا ان لوگوں نے اللہ کو چھوڑ کر اور سرپرست (کارساز) بنا لئے ہیں (حالانکہ) حقیقی سرپرست (اور کارساز) تواللہ ہی ہے اور وہی مُردوں کو زندہ کرتا ہے اور وہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxii{اور جس چیز کے بارے میں تمہارے درمیان اختلاف پیدا ہو تو اس کا فیصلہ اللہ کے حوالے ہے۔ یہی اللہ میرا پروردگار ہے جس پرمیں توکل کرتا ہوں اور اسی کی طرف رجوع کرتا ہوں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiii{(وہ) آسمانوں اور زمین کا پیدا کرنے والا ہے اسی نے تمہاری جنس سے تمہارے لئے جوڑے پیدا کئے اور چوپایوں میں سے بھی جوڑے بنائے ہیں اس کے ذریعہ سے تمہیں پھیلاتا ہے (کائنات کی) کوئی چیز اس کی مثل (مانند) نہیں ہے وہ بڑا سننے والا اور بڑا دیکھنے والا ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiv{آسمانوں اور زمین (کے خزانوں) کی کنجیاں اسی کے قبضۂ قدرت میں ہیں جس کا چاہتا ہے رزق کشادہ کرتا ہے اور (جس کا چاہتا ہے) تنگ کرتا ہے۔ بےشک وہ ہر چیز کا بڑا جا ننے والا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxv{اس نے تمہارے لئے وہی دین مقرر کیا ہے جس کا اس نے نوح(ع) کو حکم دیا تھا اور جو ہم نے بذریعۂ وحی آپ(ص) کی طرف بھیجا ہے اور جس کا ہم نے ابراہیم(ع)، موسیٰ(ع) اور عیسیٰ(ع) کو حکم دیا تھا یعنی اس دین کو قائم رکھنا اور اس میں تفرقہ نہ ڈالنا۔ مشرکین پر وہ بات بہت شاق ہے جس کی طرف آپ(ص) انہیں دعوت دیتے ہیں اللہ جسے چاہتا ہے اپنی بارگاہ کیلئے منتخب کر لیتا ہے اور جو اس کی طرف رجوع کرتا ہے وہ اسے اپنی طرف (پہنچنے کا) راستہ دکھاتا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvi{اور وہ لوگ تفرقہ میں نہیں پڑے مگر بعد اس کے کہ ان کے پاس علم آچکا تھا یہ (تفرقہ) محض باہمی ضدا ضدی (اور باہمی حسد) سے ہے اور اگر آپ کے پروردگار کی طرف سے یہ بات طے نہ ہوچکی ہوتی کہ ان لوگوں کو ایک مقررہ مدت تک مہلت دی جائے تو ان کے درمیان فیصلہ ہوچکا ہوتا اور جو لوگ ان کے بعد کتاب کے وارث بنائے گئے وہ اس کے بارے میں اضطراب انگیز شک میں گرفتار ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvii{پس آپ(ص) اس (دین) کی طرف دعوت دیتے رہیں اور ثابت قدم رہیں جس طرح آپ(ص) کو حکم دیا گیا ہے اور ان لوگوں کی خواہشات کی پیروی نہ کریں اور کہیں کہ میں ہر اس کتاب پر ایمان رکھتا ہوں جو اللہ نے نازل کی ہے اور مجھے حکم دیا گیا ہے کہ میں تمہارے درمیان عدل و انصاف کروں۔ اللہ ہی ہمارا پروردگار ہے اور تمہارا بھی پروردگار ہے ہمارے اعمال ہمارے لئے ہیں اور تمہارے اعمال تمہارے لئے ہیں۔ ہمارے، تمہارے درمیان کوئی بحث درکار نہیں ہے اللہ ہم سب کو (ایک دن) جمع کرے گا اور اسی کی طرف بازگشت ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxviii{اور جو لوگ اللہ کے(دین) کے بارے میں(بلا وجہ) جھگڑا کرتے ہیں بعد اس کے کہ اسے قبول بھی کیا جاچکا ہے ان کی حجت بازی ان کے پروردگار کے نزدیک باطل ہے اور ان پر(خدا کا) غضب ہے ان کیلئے سخت عذاب ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxix{اللہ وہ ہے جس نے کتاب کو حق کے ساتھ نازل کیا ہے اور میزان کو بھی اور تمہیں کیا خبر شاید قیامت قریب ہی ہو۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxc{جو لوگ اس پر ایمان نہیں رکھتے تو اس کے لئے جلدی کرتے ہیں اور جو ایمان رکھتے ہیں وہ اس سے ڈرتے ہیں اور جا نتے ہیں کہ وہ برحق ہے آگاہ رہو جو قیامت کے بارے میں شک کرتے ہیں (تکرار کرتے ہیں) وہ بڑی کھلی گمراہی میں ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxci{اللہ اپنے بندوں پر بہت مہربان ہے جسے چاہتا ہے رزق عطا کرتا ہے وہ بڑا طاقتور (اور) زبردست ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcii{جوشخص آخرت کی کھیتی چاہتا ہے تو ہم اس کی کھیتی میں اضافہ کردیتے ہیں اور جو (صرف) دنیا کی کھیتی چاہتا ہے تو ہم اس میں سے اسے کچھ دے دیتے ہیں مگر اس کا آخرت میں کوئی حصہ نہیں ہوتا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciii{کیا ان کے کچھ ایسے شریک (خدا) ہیں جنہوں نے ان کیلئے ایسا دین مقرر کیا ہے جس کی اللہ نے اجازت نہیں دی اور اگر فیصلہ کے متعلق طےشدہ بات نہ ہوتی تو ان کے درمیان فیصلہ کر دیا گیا ہوتا اور جو لوگ ظالم ہیں ان کے لئے دردناک عذاب ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciv{تم ظالموں کو دیکھو گے کہ وہ اپنے کئے ہوئے کاموں (کے انجام) سے ڈر رہے ہوں گے اور وہ (وبال) ان پر پڑ کر رہے گا اور جو لوگ ایمان لائے اور انہوں نے نیک عمل بھی کئے وہ بہشتوں کے باغوں میں ہوں گے وہ جو کچھ چاہیں گے اپنے پروردگار کے ہاں سے پائیں گے یہی بڑا فضل ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcv{یہ وہ بات ہے جس کی خوشخبری خدا اپنے ان بندوں کو دیتا ہے جو ایمان لائے اور نیک اعمال بھی کئے آپ(ص) کہیے کہ میں تم سے اس(تبلیغ و رسالت) پر کوئی معاوضہ نہیں مانگتا سوائے اپنے قرابتداروں کی محبت کے اورجو کوئی نیک کام کرے گا ہم اسکی نیکی میں اضافہ کردیں گے یقیناً اللہ بڑا بخشنے والا(اور) بڑا قدردان ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvi{کیا وہ کہتے ہیں کہ اس(رسول(ص)) نے خدا پر جھوٹا بہتان باندھا ہے اگر اللہ چاہے تو تمہارے دل پر مہر لگا دے اور اللہ باطل کو مٹا دیتا ہے اور حق کو اپنی باتوں سے حق ثابت کرتا ہے بےشک وہ سینوں کی چھپی ہوئی باتوں (رازوں) کو خوب جانتا ہے۔ وہ وہی ہے جو اپنے بندوں کو خوب جانتا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvii{اور اللہ اپنے بندوں کی توبہ قبول کرتا ہے اور برائیوں کو معاف کرتا ہے اور وہ جانتا ہے جو کچھ تم کرتے ہو۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcviii{اور وہ ان لوگوں کی دعائیں قبول کرتا ہے جو ایمان لائے اور نیک عمل بھی کئے اورانہیں اپنے فضل و کرم سے اور زیادہ عطا کرتا ہے اور کافروں کیلئے سخت عذاب ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcix{اور اگر خدا اپنے تمام بندوں کی روزی کشادہ کر دیتا تو وہ زمین میں بغاوت پھیلا دیتے اور وہ بندوں کے حالات کو جا ننے والا اور خوب دیکھنے والا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccc{وہ وہی ہے جو بارش برساتا ہے قابلِ ستائش ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccci{اور اس کی نشانیوں میں سے آسمانوں اور زمین کی تخلیق اور جو چلنے پھر نے والے جاندار ان کے درمیان پھیلائے ہیں ان کا پیدا کرنا بھی ہے اور وہ ان کو جمع کرنے پر جب چاہے گا قادر ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcccii{اور تمہیں جو مصیبت بھی پہنچتی ہے وہ تمہارے اپنے ہاتھوں کے کئے ہوئے(کاموں) کی وجہ سے پہنچتی ہے اور وہ بہت سے(کاموں سے) درگزرکرتا ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccciii{اور تم زمین میں خدا کو عاجز و بےبس نہیں کر سکتے اور نہ ہی اللہ کے سوا تمہارا کوئی کارساز ہے اور نہ کوئی مددگار۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccciv{اور اس کی قدرت کی نشانیوں میں سے وہ بڑے بڑے پہاڑ جیسے (بحری) جہاز ہیں جو سمندر میں چلتے ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcccv{اگر وہ چاہے تو ہوا کو ٹھہرا دے تو وہ (جہاز) اس کی سطح پر کھڑے کے کھڑے رہ جائیں بےشک اس میں ہر بڑے صبر کرنے(اور) بڑے شکر کرنے والے کیلئے نشانیاں ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvi{یا اگر وہ چاہے تو ان (جہازوں) کو تباہ کر دے ان لوگوں کے (برے) اعمال کی وجہ سے اور اگر چاہے تو (ان کے) بہت سے (لوگوںیا گناہوں سے) درگزر فرمائے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvii{اور تاکہ ان لوگوں کو معلوم ہو جائے جو ہماری آیتوں کے بارے میں جھگڑتے ہیں کہ ان کیلئے کوئی جائے فرار نہیں ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcccviii{جو کچھ تمہیں دیا گیا ہے وہ صرف دنیٰوی زندگی کا (چند روزہ) ساز و سامان ہے اور جو کچھ اللہ کے پاس ہے وہ بہتر بھی ہے اور زیادہ پائیدار بھی ان لوگوں کیلئے جو ایمان لائے ہیں اور اپنے پروردگار پر بھروسہ رکھتے ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcccix{اور وہ جو بڑے گناہوں اور بےحیائی کے کاموں سے پرہیز کرتے ہیں اور جب ان کو غصہ آتا ہے تو معاف کر دیتے ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcccx{اور جو اپنے پروردگار کے حکم کو مانتے ہیں اور نماز قائم کرتے ہیں اور ان کے (تمام) کام باہمی مشورہ سے طے ہوتے ہیں اور جو کچھ ہم نے انہیں دیا ہے وہ اس سے خرچ کرتے ہیں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxi{اور جب ان پر تعدی و زیادتی کی جاتی ہے تو وہ (واجبی) بدلہ لیتے ہیں۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxii{اور برائی کا بدلہ تو ویسے ہی برائی ہے اور جو معاف کر دے اورا صلاح کرے تو اس کا اجر خدا کے ذمہ ہے بیشک وہ (اللہ) ظالموں کو پسند نہیں کرتا۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiii{اور جو شخض بھی ظلم کے بعد بدلہ لے اس کے اوپر کوئی الزام نہیں ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiv{اور (ملامت) تو صرف ان لوگوں پر ہے جو لوگوں پر ظلم کرتے ہیں اور زمین میں ناحق سرکشی کرتے ہیں ایسے ہی لوگوں کیلئے دردناک عذاب ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxv{البتہ جوشخص صبر کرے اور درگزر کرے تو یہ بڑے ہمت کے کاموں میں سے ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvi{اور جس کو اللہ گمراہی میں چھوڑ دے تو اس کے بعد اس کا کوئی سرپرست و کارساز نہیں ہے اورتم ظالموں کو دیکھو گے کہ جب وہ عذاب دیکھیں گے تو (گھبرا کر) کہیں گے کہایا (دنیا میں) واپسی کا کوئی راستہ ہے؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvii{اور تم انہیں دیکھو گے کہ جب وہ دوزخ کے سامنے پیش کئے جائیں گے تو ذلت سے جھکے ہوئے ہوں گے (اور) کنکھیوں (چھپی نگاہ) سے دیکھتے ہوں گے اور اہلِ ایمان کہیں گے کہ حقیقی خسارہ اٹھا نے والے وہی لوگ ہیں جنہوں نے قیامت کے دن اپنے آپ کو اور اپنے اہل و عیال کو خسارہ میں ڈالا۔ آگاہ ہو کہ ظالم لوگ دائمی عذاب میں رہیں گے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxviii{اور اللہ کے سوا ان کے کوئی حامی و مددگار نہیں ہوں گے جو اللہ کے مقابلہ میں ان کی مدد کریں اور جسے اللہ گمراہی میں چھوڑ دے تو اس کے لئے کوئی راستہ نہیں ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxix{(اے لوگو) اپنے پروردگار کی دعوت پر لبیک کہواس سے پہلے کہ وہ دن آئے جو اللہ کی طرف سے ٹلنے والا نہیں ہے اس دن نہ تمہارے لئے کوئی جائے پناہ ہوگی اور نہ انکار کی کوئی گنجائش ہوگی (اور نہ ہی تمہاری طرف سے کوئی روک ٹوک کرنے والا ہوگا)۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxx{اور اگر وہ رُوگردانی کریں تو ہم نے آپ کو ان کا نگہبان مقرر کر کے نہیں بھیجا آپ کی ذمہداری صرف پہنچا دینا ہے اور ہم جب انسان کو اپنی رحمت کامزہ چکھاتے ہیں تو وہ اس سے خوش ہوجاتا ہے اور اگر انہیں ان کے اعمال کی پاداش میں کوئی تکلیف پہنچتی ہے تو انسان بڑا ناشکرا بن جاتا ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxi{آسمانوں اور زمین کی بادشاہی اللہ ہی کے لئے ہے وہ جو چاہتا ہے پیدا کرتا ہے اور جس کو چاہتا ہے لڑکیاں عطا کرتا ہے اور جسے چاہتا ہے لڑکے عنایت کرتا ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxii{اورجسے چاہتا ہے لڑکے لڑکیاں جمع کر دیتا ہے اور جسے چاہتا ہے بانجھ بنا دیتا ہے۔ بےشک وہ بڑا جا ننے والا (اور) بڑا قدرت رکھنے والا ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiii{اور کسی بشر کا یہ مقام نہیں کہ اللہ اس سے کلام کرے مگر وحی کے ذریعہ سےیا پردہ کے پیچھے سےیا وہ کوئی پیغام بر (فرشتہ) بھیجے اور اس کے حکم سے جو وہ چاہے وحی کرے۔ بیشک وہ بزرگ و برتر (اور) بڑا حکمت والا ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiv{اور اسی طرح ہم نے آپ کی طرف وحی کی صورت میں اپنی ایک (خاص) روح بھیجی آپ نہیں جانتے تھے کہ کتاب کیا ہے اور نہ یہ جا نتے تھے کہ ایمان کیا ہے؟ لیکن ہم نے اسے ایک نور بنایا جس سے ہم اپنے بندوں میں سے جسے چاہتے ہیں ہدایت دیتے ہیں اور یقیناً آپ سیدھے راستہ کی طرف راہنمائی کرتے ہیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxv{اس اللہ کے راستہ کی طرف جس کا وہ سب کچھ ہے جو آسمانوں اور زمین میں ہے خبردار! سب (تمام) معاملات کی بازگشت اللہ ہی کی طرف ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvi{\basmalahur حا۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvii{قَسم ہے اس واضح کتاب کی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxviii{کہ ہم نے اس کو عربی زبان کا قرآن بنایا ہے تاکہ تم سمجھو۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxix{بےشک وہ (قرآن) اصل کتاب (لوحِ محفوظ) میں جو ہمارے پاس ہے بلند مرتبہ (اور) حکمت والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxx{کیا ہم محض اس لئے نصیحت سے منہ پھیرلیں کہ تم حد سے تجاوز کرنے والے لوگ ہو۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxi{اور ہم نے پہلے لوگوں میں کتنے ہی نبی(ع) بھیجے ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxii{اور ان کے پاس کوئی نبی(ع) نہیںایا مگریہ کہ وہ اس کامذاق اڑاتے تھے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiii{پھر ہم نے ان لوگوں کو ہلاک کر دیا جو ان (موجودہ منکرین) سے زیادہ طاقتور تھے اور پہلے لوگوں کی مثال (حالت) گزر چکی ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiv{اور اگر آپ ان سے پوچھیں کہ آسمانوں اور زمین کو کس نے پیدا کیا ہے؟ تو وہ ضرور کہیں گے کہ انہیں اس ہستی نے پیدا کیا ہے جو غالب ہے اور ہمہ دان۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxv{وہی جس نے زمین کو تمہارے لئے گہوارہ بنایا اور اس میں تمہارے لئے راستے بنا دئیے تاکہ تم (منزل تک) راہ پاؤ۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvi{اور جس نے ایک خاص مقدارمیں آسمان سے پا نی اتارا پھر ہم نے اس سے مردہ (خشک) زمین کو زندہ کر دیا اسی طرح تم (قبروں سے) نکالے جاؤ گے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvii{اور جس نے تمام اِقسام کی چیزیں پیدا کیں اور تمہارے لئے کشتیاں اور چوپائے بنائے جن پر تم سوار ہوتے ہو۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxviii{تاکہ تم ان کی پیٹھوں پر جم کر بیٹھو اور پھر اپنے پروردگار کی نعمت کو یاد کرو اور کہو پاک ہے وہ ذات جس نے ان چیزوں کو ہمارے لئے مسخر کر دیا اور ہم ایسے نہ تھے کہ ان کو اپنے قابو میں کرتے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxix{اور بےشک ہم اپنے پروردگار کی طرف لو ٹنے والے ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxl{اور ان لوگوں نے خدا کے بندوں میں سے اس کا جزو قرار دیا ہے بیشک انسان کھلا ہوا ناشکراہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxli{کیا خدا نے اپنی مخلوق میں سے اپنے لئے بیٹیاں منتخب کی ہیں اور تمہیں بیٹوں کے ساتھ مخصوص کر دیا؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlii{اور جب ان میں سے کسی کو اس (بیٹی) کی بشارت دی جاتی ہے جسے وہ خدا کی صفت قرار دیتا ہے تو اس کا چہرہ سیاہ ہو جاتا ہے اور اس کا دل غم سے بھر جاتا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliii{کیا (خدا کیلئے وہ ہے) جو زیوروں میں پرورش پائے اور بحث و تکرار میں اپنا مدعا واضح نہ کر سکے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliv{اور انہوں نے فرشتوں کو جو خدائے رحمٰن کے خاص بندے ہیں عورتیں قرار دے رکھا ہے کیا وہ ان کی پیدائش (اور جسمانی ساخت) کے وقت موجود تھے ان کی گواہی لکھ لی جائے گی اور ان سے بازپرس کی جائے گی۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlv{اور وہ کہتے ہیں کہ اگر اللہ چاہتا تو ہم ان (بتوں) کی عبادت نہ کرتے انہیں اس بارے میں کوئی علم نہیں ہے۔ وہ محض اٹکل پچو باتیں کرتے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvi{کیا ہم نے انہیں اس سے پہلے کوئی کتاب دی ہے جسے وہ مضبوطی سے پکڑے ہوئے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvii{بلکہ وہ تو کہتے ہیں کہ ہم نے اپنے باپ دادا کو ایک طریقہ پر دیکھا ہے اور ہم انہی کے نقشِ قدم پر راہ یاب ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlviii{اور اسی طرح ہم نے آپ(ص) سے پہلے کسی بستی میں کوئی ڈرا نے والا (پیغمبر(ع)) نہیں بھیجا مگر یہ کہ وہاں آسودہ حال لوگوں نے کہا کہ ہم نے اپنے باپ دادا کو ایک طریقہ پر پایا اور ہم تو انہی کے نقوشِ پاکی پیروی کر رہے ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlix{اس (نذیر) نے کہا گرچہ میں تمہارے پاس اس سے زیادہ ہدایت بخش طریقہلے کرایا ہوں جس پر تم نے اپنے باپ دادا کو پایا ہے؟ ان لوگوں نے کہا کہ تم جس(دین) کے ساتھ بھیجے گئے ہو ہم اس کے منکر ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcccl{سو ہم نے ان سے انتقام لیا تو دیکھو کہ جھٹلا نے والوں کا کیا انجام ہوا؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcccli{اور وہ وقت یاد کرو جب ابراہیم(ع) نے اپنے باپ (تایا) اور اپنی قوم سے کہا میں ان سے بیزار ہوں جن کی تم عبادت کرتے ہو۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccclii{مگر وہ جس نے مجھے پیدا کیا اور وہی میری راہنمائی کرے گا (میں صرف اسی کی عبادت کرتا ہوں)۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliii{اور وہ (ابراہیم(ع)) اسی (عقیدۂ توحید) کو اپنی اولاد میں باقی رہنے والا کلمہ قرار دے گئے تاکہ وہ اس کی طرف رجوع کریں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliv{اور (باوجود ان کی خلاف ورزی کرنے کے) میں ان کو اور ان کے باپ دادا کو دنیا کے ساز و سامان سے بہرہ مندہ کرتا رہا یہاں تک کہ انکے پاس حق اور کھول کر بیان کرنے والا رسول آگیا۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccclv{اور جب ان کے پاس حق آگیا تو انہوں نے کہا کہ یہ تو جادو ہے اور ہم اس کے منکر ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvi{اور وہ کہتے ہیں کہ یہ قرآن دو (مشہور) بستیوں (مکہ و طائف) کے کسی بڑے آدمی پر کیوں نہیں نازل کیا گیا؟\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvii{کیا یہ لوگ آپ کے پروردگار کی رحمت تقسیم کرتے ہیں؟ (حالانکہ) دنیاوی زندگی میں ان کے درمیان ان کی روزی ہم نے تقسیم کر دی ہے اور ہم نے بعض کو بعض پر کئی درجے فوقیت دی ہے تاکہ وہ ایک دوسرے سے خد متلے سکیں اور آپ کے پروردگار کی رحمت اس مال و دولت سے بہتر ہے جو وہ جمع کرتے ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccclviii{اور اگر یہ بات نہ ہوتی کہ سب لوگ ایک ہی طریقے کے ہو جائیں گے تو ہم خدائے رحمٰن کا انکار کرنے والوں کے مکانوں کی چھتیں اور سیڑھیاں جن پر وہ چڑھتے ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmccclix{اور ان کے گھروں کے دروازے اور تخت جن پر وہ تکیہ لگاتے ہیں سب چا ندی اور سونے کے بنوا دیتے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccclx{اور یہ سب کچھ دنیاوی زندگی کا ساز و سامان ہے اور تمہارے پروردگار کے ہاں آخرت تو متقیوں کے لئے ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxi{اور جوشخص خدا کی یاد سے اندھا بنتا ہے تو ہم اس کیلئے ایک شیطان مقرر کر دیتے ہیں جو اس کا ساتھی ہوتا ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxii{اور وہ (شیاطین) ان (اندھوں) کو راہ (راست) سے روکتے ہیں اور وہ خیال کرتے ہیں کہ وہ ہدایت یافتہ ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiii{یہاں تک کہ جب وہ ہمارے پاس آئیگا تو (اپنے شیطان سے) کہے گا اے کاش! میرے اور تیرے درمیان مشرقومغرب کی دوری ہوتی تو بہت برا ساتھی ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiv{(ان سے کہا جائے گا کہ) جب تم (دنیا میں) ظلم کر چکے تو (آج) یہ بات تمہیں کوئی فائدہ نہیں پہنچا سکتی تم سب عذاب میں ایک دوسرے کے شریک ہو۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxv{کیا آپ(ص) بہروں کو سنائیں گےیا اندھوں کو راہ دکھائیں گے اور ان کو جو کھلی ہوئی گمراہی میں ہیں؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvi{پس اگر ہم آپ کو (دنیا سے) اٹھائیں تو پھر بھی ہم ان لوگوں سے بدلہ لینے والے ہیں۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvii{یا ہم ان کو (آپ کے عینِ حیات) وہ (عذاب) دکھا دیں گے جس کا ہم نے ان سے وعدہ کیا ہے سو ہم ان پر پوری طرح قادر ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxviii{پس آپ(ص) مضبوطی سے اسے تھامے رہیں جس کی آپ(ص) کی طرف وحی کی گئی ہے۔ یقیناً آپ سیدھے راستہ پر ہیں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxix{اور بےشک وہ (قرآن) آپ(ص) کیلئے اور آپ(ص) کی قوم کیلئے بڑا شرف اور اعزاز ہے اور عنقریب تم لوگوں سے اس کے بارے میں پوچھا جائے گا۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxx{آپ(ص) پیغمبروں(ع) سے پوچھیں جنہیں ہم نے آپ(ص) سے پہلے بھیجا تھا کہایا ہم نے خدائے رحمٰن کے علاوہ بھی کوئی ایسے خدا مقرر کئے تھے جن کی عبادت کی جائے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxi{اور بےشک ہم نے موسیٰ (ع) کو اپنی نشانیاں (معجزے) دے کر فرعون اور اس کے عمائدِ سلطنت کے پاس بھیجا۔ پس آپ(ع) نے (ان سے) کہا کہ میں عالمین کے پروردگار کا رسول(ع) ہوں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxii{پس جب وہ ہماری نشانیوں کے ساتھ ان کے پاس آئے تو وہ لوگ ان (نشانیوں) پر ہنسنے لگے (مذاق اڑا نے لگے)۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiii{اور ہم انہیں کوئی نشانی نہیں دکھاتے تھے مگر وہ پہلی سے بڑی ہوتی تھی اور ہم نے انہیں عذاب میں پکڑا تاکہ وہ (اپنی روش سے) باز آئیں۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiv{اور انہوں نے کہا کہ اے جادوگر! اپنے پروردگار سے ہمارے لئے دعا کرو۔ہم ضرور ہدایت پا جائیں گے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxv{تو جب ہم نے ان سے عذاب دور کر دیا تو ایکدم وہ عہد توڑ دیتے تھے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvi{اور فرعون نے اپنی قوم میں منادی کرائی اے میری قوم! کیا مصر کی سلطنت میری نہیں ہے؟ اور یہ نہریں جو میرے نیچے بہہ رہی ہیں تو کیا تم دیکھتے نہیں ہو؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvii{(مجھے بتا‎ؤ) کیا میں اس سے بہتر نہیں ہوں جو ذلیل و حقیر ہے اور صاف بول بھی نہیں سکتا۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxviii{(اگر یہ برحق نبی ہے) تو اس پر سو نے کے کنگن کیوں نہیں اتارے گئے؟ یا اس کے ہمراہ فرشتے پر باندھ کر آتے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxix{اس طرح اس (فرعون) نے اپنی قوم کو احمق بنایا اور انہوں نے اس کی اطاعت کی۔ بےشک یہ نافرمان قِسم کے لوگ تھے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxx{پس انہوں نے ہمیں ناراض کیا تو ہم نے ان سے انتقام لیا اور ان سب کو غرق کر دیا۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxi{اور انہیں گیا گزرا اور بعد والوں کیلئے نمونۂ عبرت بنا دیا۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxii{اور جب ابنِ مریم (ع) (عیسےٰ(ع)) کی مثال دی گئی تو ایک دم آپ(ص) کی قوم والے چیخنے چلا نے لگے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiii{اور کہنے لگے کہ ہمارے معبود بہتر ہیں یاوہ(عیسیٰ(ع))؟ وہ یہ بات محض آپ(ص) سے کج بحثی کیلئے کرتے ہیں بلکہ یہ لوگ تو ہیں ہی بڑے جھگڑالو۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiv{وہ (عیسیٰ (ع)) تو بس ہمارا ایک بندہ تھا جس پر ہم نے انعام کیا اور اسے بنی اسرائیل کیلئے ایک مثال (نمونہ) بنا دیا۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxv{اگر ہم چاہیں تو تمہارے بدلے زمین میں فرشتے بسا دیں جو تمہارے جانشین ہوں۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvi{وہ(عیسیٰ(ع)) تو صرف قیامت کی ایک نشانی ہے تم لوگ اس میں شک نہ کرو اور میری پیروی کرو۔ یہی سیدھا راستہ ہے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvii{(دیکھو خیال رکھنا کہیں) شیطان تمہیں اس سے روک نہ دے۔ بےشک وہ تمہارا کھلا ہوا دشمن ہے۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxviii{اور جب عیسیٰ(ع) کھلی نشانیاں (معجزے)لے کر آئے تو کہا میں تمہارے پاس حکمتلے کرایا ہوں تاکہ تم پر بعض وہ باتیں واضح کردوں جن میں تم اختلاف کرتے ہو سو تم اللہ سے (آپ(ع) کی نافرمانی سے) ڈرو اور میری اطاعت کرو۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxix{بےشک اللہ ہی میرا پروردگار ہے اور تمہارا بھی پروردگار۔ تو تم اسی کی عبادت کرو یہی سیدھا راستہ ہے۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxc{پس مختلف گروہوں نے آپس میں اختلاف کیا پس تباہی ظالموں کیلئے ایک بڑے دردناک دن (قیامت) کے عذاب سے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxci{کیا یہ لوگ بس قیامت کا انتظار کر رہے ہیں کہ وہ اچانک ان پر آجائے کہ انہیں خبر بھی نہ ہو۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcii{اس دن سب دوست ایک دوسرے کے دشمن ہوں گے سوائے پرہیزگاروں کے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciii{(خدا ان سے فرمائے گا) اے میرے بندو! آج نہ تم پر کوئی خوف ہے اور نہ ہی تم غمگین ہو گے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciv{(یہ وہ لوگ ہیں) جو ہماری آیتوں پر ایمان لائے اور مطیع و فرمانبردار بن کر رہے۔\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcv{(حکم ہوگا) تم اور تمہاری بیویاں جنت میں داخل ہو جاؤ تم خوش کئے جاؤ گے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvi{ان پر سو نے کے تھال اور جام گردش میں ہوں گے اور وہاں ہر وہ چیز موجود ہوگی جو دل چاہیں گے اور آنکھوں کو لذت ملے گی اور تم اس میں ہمیشہ رہو گے۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvii{یہ وہ جنت ہے جس کے تم وارث بنائے گئے ہواپنے ان اعمال کے صلہ میں جو تم کرتے تھے۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcviii{تمہارے لئے اس میں بہت سے میوے ہیں جن سے تم کھاؤ گے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcix{بےشک مجرم لوگ دوزخ کے عذاب میں ہمیشہ رہیں گے۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcd{وہ عذاب کبھی ان سے ہلکا نہیں کیا جائے گا اور وہ اس میں مایوس ہو کر پڑے رہیں گے۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcdi{اور ہم نے ان پر ظلم نہیں کیا لیکن وہ خود (اپنے اوپر) ظلم کرنے والے تھے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcdii{اور وہ پکاریں گے کہ اے مالک! تمہارا پروردگار ہمارا کام ہی تمام کر دے (تو بہتر) وہ کہے گا کہ تم یوں ہی پڑے رہو گے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiii{بےشک ہم تمہارے پاس (دین) حقلے کر آئے مگر تم میں سے اکثر حق کو ناپسند کرتے رہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiv{کیا انہوں نے کوئی قطعی فیصلہ کر لیا ہے تو ہم بھی کوئی فیصلہ کر لیتے ہیں۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmcdv{کیا وہ خیال کرتے ہیں کہ ہم ان کے رازوں اور ان کی سرگوشیوں کو نہیں سنتے؟ ہاں (ہم سنتے ہیں) اور ہمارے فرشتے ان کے پاس لکھتے بھی جاتے ہیں۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvi{آپ(ص) کہہ دیجئے! کہ اگر خدائے رحمٰن کی کوئی اولاد ہوتی تو سب سے پہلا عبادت گزار میں ہوتا۔\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvii{پاک ہے آسمانوں اور زمین کا پروردگار جو عرش کامالک ہے اس سے جو یہ لوگ بیان کرتے ہیں۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmcdviii{آپ ان کو چھوڑیں کہ وہ بحث کریں اور تفریح کریں (کھیلیں) یہاں تک کہ ان کو اس دن سے سابقہ پڑے جس کا ان سے وعدہ کیا جا رہا ہے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmcdix{اور وہ وہی ہے جو آسمان میں بھی خدا ہے اور زمین میں بھی وہی خدا ہے اور وہ بڑا حکمت والا، بڑا جاننے والا ہے۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmcdx{بڑی بابرکت ہے وہ ذات جس کے قبضۂ قدرت میں آسمانوں اور زمین اور ہر اس چیز کی بادشاہی ہے جو کچھ ان دونوں کے درمیان ہے اسی کے پاس قیامت کا عِلم ہے اور اسی کی طرف تم لوٹائے جاؤ گے۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxi{اورجن کو یہ لوگ اللہ کے سوا پکارتے ہیں وہ سفارش کرنے کا کوئی اختیار نہیں رکھتے۔ سوائے ان کے جو حق کی گواہی دیں اور وہ جانتے بھی ہوں۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxii{اور اگر آپ(ص) ان سے پوچھیں کہ انہیں کس نے پیدا کیا؟ تو وہ کہیں گے کہ اللہ نے تو وہ کہاں بھٹکتے پھرتے ہیں۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiii{اور اسی (اللہ) کو رسول(ص) کے اس قول کا عِلم ہے کہ اے میرے پروردگار! یہ لوگ ایمان نہیں لاتے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiv{(اے رسول(ص)) درگزر کرو۔اور کہو سلام ہو (خداحافظ) عنقریب انہیں (اپنا انجام) معلوم ہو جائے گا۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxv{\basmalahur حا۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvi{قَسم ہے اس کتابِ مبین کی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvii{ہم نے اس (کتاب) کو ایک بابرکت رات (شبِ قدر) میں نازل کیا ہے بےشک ہم (عذاب سے) ڈرانے والے رہے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxviii{اس(رات) میں ہر حکمت والے معاملہ کا فیصلہ کیا جاتا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxix{ہمارے(خاص) حکم سے بےشک ہم ہی (ہر کتاب اور رسول(ع) کے) بھیجنے والے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxx{خاص تمہارے پروردگار کی رحمت سے یقیناً وہ بڑا سننے والا (اور) بڑا جاننے والا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxi{جو آسمانوں اور زمین اور جو کچھ ان کے درمیان ہے سب کا پروردگار ہے اگر تم یقین کرنے والے ہو۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxii{اس کے سوا کوئی الٰہ (خدا) نہیں ہے وہی زندہ کرتا ہے اور وہی مارتا ہے تمہارا بھی پروردگار ہے اور تمہارے اگلے باپ داداؤں کا بھی پروردگار ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiii{مگر وہ لوگ تو شک میں پڑے ہوئے کھیل رہے ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiv{آپ اس دن کا انتظار کریں جب آسمان ایک کھلے ہوئے دھویں کے ساتھ آئے گا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxv{جو لوگوں پر چھا جائے گا یہ ایک دردناک عذاب ہوگا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvi{(اس وقت کفار بھی کہیں گے) اے ہمارے پروردگار! ہم سے یہ عذاب دور فرما۔ ہم ایمان لاتے ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvii{اب ان کو کہاں سے نصیحت حاصل ہوگی؟ جبکہ ان کے پاس کھول کر بیان کرنے والا رسول(ع) آچکا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxviii{پھر انہوں نے اس سے منہ موڑا اور کہا کہ یہ تو سکھایا ہوا ایک دیوانہ ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxix{بےشک (اگر) ہم کچھ وقت کیلئے یہ عذاب ہٹا بھی دیں تو تم لوگ لوٹ کر وہی کچھ کرو گے جو پہلے کرتے تھے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxx{جس دن ہم سخت پکڑ پکڑیں گے اس دن ہم پورا بدلہ لیں گے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxi{ہم نے ان سے پہلے فرعون کی قوم کو آزمایا تھا اور ان کے پاس ایک معزز رسول(ع)ایا تھا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxii{(اوران سے کہاتھا کہ) اللہ کے بندوں کو میرے حوالے کرو میں ایک امانت دار رسول(ع) ہوں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiii{اور یہ کہ تم اللہ کے مقابلہ میں سرکشی نہ کرو میں تمہارے پاس واضح دلیل (سند) پیش کرتا ہوں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiv{اور میں نے اپنے اور تمہارے پروردگار سے پناہ مانگ لی ہے کہ تم مجھے سنگسار کرو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxv{اور اگر تم مجھ پر ایمان نہیں لاتے تو پھر مجھ سے الگ ہی رہو۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvi{پس اس (رسول) نے اپنے پروردگار سے دعا مانگی کہ یہ بڑے مجرم لوگ ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvii{(ارشاد ہوا) تم میرے بندوں کو ہمراہلے کر راتوں رات نکل جاؤ کیونکہ تمہاراتعاقب کیا جائے گا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxviii{اور تم سمندر کو اس کے حال (سکون) پہ چھوڑ دو۔ بیشک وہ (دشمن) ایسا لشکر ہے جو غرق ہو نے والا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxix{وہ کتنے باغ اور چشمے چھوڑ گئے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxl{اور کھیتیاں اور عمدہ مقامات۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxli{اور آرام و راحت کا ساز و سامان جس میں وہ خوش و خرم رہتے تھے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlii{اور ہم نے ان چیزوں کا وارث ایک قوم کو بنا دیا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliii{پس ان کی بربادی پر نہ آسمان رویا اور نہ زمین اور نہ ہی ان کو مہلت دی گئی۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliv{اور ہم نے بنی اسرائیل کو رسوا کن عذاب سے نجات دی۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlv{جو فرعون کی طرف سے تھا بےشک وہ سرکش اور حد سے نکل جا نے والوں میں سے تھا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvi{اور ہم نے جان بوجھ کر ان کو تمام جہانوں والوں پر ترجیح دی۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvii{اور ہم نے ان کو ایسی نشانیاں عطا کیں جن میں کھلی ہوئی آزمائش تھی۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlviii{بیشک یہ لوگ کہتے ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlix{کہ بس ہماری یہی پہلی موت ہی ہے اس کے بعد ہم (دوبارہ) نہیں اٹھائے جائیں گے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcdl{اگر تم سچے ہو تو ہمارے باپ داداؤں کو لاؤ۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcdli{(قوت کے لحاظ سے) یہ بہتر ہیں یا قومِ تبع اور ان سے پہلے ہم نے ان کو ہلاک کر دیا کہ وہ مجرم تھے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlii{ہم نے آسمانوں کو، زمین کو اور جو کچھ ان کے درمیان ہے کو کھیل کے طور پر پیدانہیں کیا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliii{ہم نے ان کو پیدا نہیں کیا مگر حق (و حکمت) کے ساتھ مگر ان کے اکثر لوگ (یہ حقیقت) نہیں جانتے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliv{بےشک فیصلہ کا دن (قیامت) ان سب کا طے شدہ وقت ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlv{جس دن کوئی دوست کسی دوست کوکوئی فائدہ نہیں پہنچاسکے گا اور نہ ہی ان کی مدد کی جائے گی۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvi{مگر وہ جس پر اللہ رحم کرے بےشک وہ بڑا غالب (اور) بڑا رحم کرنے والا ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvii{بیشک زقوم کا درخت۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlviii{گنہگار کی غذا ہوگا۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlix{پگھلے ہوئے تانبےکی طرح پیٹوں میں جوش کھائے گا۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlx{جس طرح گرم کھولتا ہوا پانی ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxi{اس کو پکڑو۔اور اسے گھسیٹتے ہوئے جہنم کے وسط تکلے جاؤ۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxii{اور پھر اس کے سر پر کھولتے ہوئے پانی کا عذاب انڈیل دو۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiii{مزا چکھ تُو تو بڑا معزز اور مکرم ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiv{یہ وہی ہے جس میں تم شک کیا کرتے تھے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxv{بےشک جو پرہیزگار لوگ ہیں وہ امن و سکون کی جگہ پر ہوں گے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvi{یعنی باغوں میں اور چشموں میں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvii{وہ سندس و اسبترق (باریک اور دبیز ریشم) کے کپڑے پہنے ہوئے آمنے سامنے بیٹھے ہوں گے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxviii{یہ بات اسی طرح ہے اور ہم ان کی گوری رنگت اور بڑی آنکھوں والی عورتوں (حوروں) سے شادی کریں گے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxix{وہ اس میں بڑے امن و سکون کے ساتھ ہر قِسم کے میوے طلب کریں گے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxx{وہ وہاں پہلے والی موت کے سوا موت کامزہ نہیں چکھیں گے اور اللہ نے انہیں دوزخ کے عذاب سے بچا لیا ہے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxi{یہ سب کچھ آپ کے پروردگار کے فضل و کرم سے ہوگا اور یہ بڑی کامیابی ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxii{پس ہم نے اس (قرآن) کو آپ کی زبان پر بالکل آسان بنا دیا تاکہ وہ نصیحت حاصل کریں۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiii{(اچھا) آپ انتظار کیجئے! یقیناً وہ بھی انتظار کر رہے ہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiv{\basmalahur حا۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxv{یہ کتاب اللہ کی طرف سے نازل کی گئی ہے جو غالب ہے (اور) بڑا حکمت والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvi{بےشک آسمانوں اور زمین میں اہلِ ایمان کے لئے (خدا کی توحید و قدرت کی) بہت سی نشانیاں ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvii{اورخود تمہاری پیدائش میں اور ان حیوانات میں جن کو وہ (زمین میں) پھیلا رہا ہے یقین رکھنے والوں کیلئے نشانیاں ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxviii{اور رات اور دن کی آمد ورفت میں اس (ذریعہ) رزق (بارش) میں جو اللہ نے آسمانوں سے نازل کیا اور اس سے زمین کو زندہ کر دیا اس کی موت کے بعد اور ہواؤں کی گردش میں بھی نشانیاں ہیں ان لوگوں کیلئے جو عقل سے کام لیتے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxix{یہ اللہ کی آیتیں ہیں جو ہم حق کے ساتھ آپ کو پڑھ کر سنا رہے ہیں تو آخر اللہ اور اس کی آیتوں کے بعد وہ کونسی بات ہے جس پر وہ ایمان لائیں گے؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxx{ہلاکت ہے ہر اس بڑے جھوٹے (اور) بڑے گنہگار کے لئے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxi{جو اللہ کی آیتوں کو سنتا ہے جب اس کے سامنے پڑھی جاتی ہیں پھر وہ تکبر کے ساتھ اس طرح اَڑا رہتا ہے کہ گویا اس نے انہیں سنا ہی نہیں۔ بس تم اسے دردناک عذاب کی خبر دے دو۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxii{اور جب اس کو ہماری آیات میں سے کسی کا علم ہوتا ہے تو وہ ان کو مذاق بنا لیتا ہے ایسے لوگوں کیلئے رسوا کُن عذاب ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiii{ان کے آگے جہنم ہے اور انہوں نے جو کچھ کیا کمایا ہے وہ انہیں کوئی فائدہ نہ دے گا اور نہ ہی وہ ان کے کام آئیں گے جن کو انہوں نے اللہ کے سوا کارساز بنا رکھا ہے اور ان کیلئے بڑا عذاب ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiv{یہ ہدایت ہے (اور وہ لوگ جنہوں نے اپنے پرودرگار کی آیتوں کا انکار کیا ان کیلئے) سخت قِسم کا دردناک عذاب ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxv{اللہ وہی ہے جس نے تمہارے لئے سمندر کومسخر کر دیا تاکہ اس کے حکم سے اس میں کشتیاں چلیں اور تاکہ تم اس کا فضل (رزق) تلاش کرو۔ اور تاکہ تم شکر کرو۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvi{اوراس نے آسمانوں اور زمین کی سب چیزوں کو تمہارے لئے مسخر کر دیا ہے۔ بےشک اس میں غورو فکر کرنے والوں کیلئے (خدا کی قدرت و حکمت کی) نشانیاں ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvii{(اے رسول(ص)) ایمان والوں سے کہیے! کہ وہ ان لوگوں سے درگزر کریں جو اللہ کے (خاص) دنوں کی امید نہیں رکھتے تاکہ اللہ ایک قوم کو اس کے ان سارے اعمال کا بدلہ دے جو وہ کیا کرتے تھے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxviii{جو کوئی نیک عمل کرتا ہے وہ اپنے فائدہ کیلئے کرتا ہے اورجو کوئی بر ائی کرتا ہے اس کا وبال بھی اسی پر پڑتا ہے پھر تم سب اپنے پروردگار کی طرف لوٹائے جاؤ گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxix{اور یقیناً ہم نے بنی اسرائیل کو کتاب، حُکم اور نبوت عطا فرمائی اور ان کو پاکیزہ رزق عطا فرمایا اور ان کو دنیا جہان والوں پر فضیلت عطا کی۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxc{اورہم نے انہیں دین کے معاملہ میں کھلے دلائل عطا کئے پس انہوں نے اس میں اختلاف نہیں کیا مگر علم آجانے کے بعد محض باہمی ضد اور ظلم کی وجہ سے۔ بےشک قیامت کے دن آپ(ص) کا پروردگار ان کے درمیان فیصلہ کرے گا جن چیزوں میں وہ باہم اختلاف کرتے تھے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxci{(اے رسول(ص)) پھر ہم نے آپ(ص) کو ایک واضح شریعت پر قائم کیا ہے پس آپ(ص) اس کی پیروی کیجئے! اور ان لوگوں کی خواہش کی پیروی نہ کیجئے جو علم نہیں رکھتے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcii{وہ اللہ کے مقابلہ میں آپ(ص) کو ہرگز کچھ بھی فائدہ نہیں پہنچائیں گے۔ یقیناً ظالم لوگ ایک دوسرے کے ساتھی ہوتے ہیں اور اللہ تو پرہیزگاروں کا ساتھی (اور پُشت پناہ) ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciii{یہ(قرآن) لوگوں کے لئے بصیرتوں کا سرمایہ اور یقین رکھنے والوں کیلئے ہدایت و رحمت کا باعث ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciv{کیا وہ لوگ جنہوں نے برائیوں کا ارتکاب کیا ہے وہ خیال کرتے ہیں کہ ہم ان کو ان لوگوں کی مانند قرار دیں گے جو ایمان لائے اور نیک عمل کرتے رہے؟ ان کا جینا اور مرنا یکساں ہو جائے گا؟ بہت براہے وہ فیصلہ جو وہ کر رہے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcv{اور اللہ نے آسمانوں اور زمین کو حق و حکمت کے ساتھ پیدا کیا ہے اور تاکہ ہر شخص کو اس کے کئے کا بدلہ دیاجائے اور ان پر (ہرگز) ظلم نہیں کیا جائے گا۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvi{کیا آپ(ص) نے اس شخص کو دیکھا ہے جس نے اپنی خواہشِ نفس کو اپنا خدا بنا رکھاہے اوراللہ نے باوجود علم کے اسے گمراہی میں چھوڑ دیا ہے اور اس کے کان اور دل پر مہر لگا دی ہے اور اس کی آنکھ پر پر دہ ڈال دیا ہے اللہ کے بعد کون ایسے شخص کو ہدایت کر سکتا ہے؟ کیا تم نصیحت حاصل نہیں کرتے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvii{اور وہ کہتے ہیں کہ ہماری زندگی تو بس یہی دنیٰوی زندگی ہے۔ یہیں ہم مرتے ہیں اور یہیں جیتے ہیں اور ہمیں صرف گردشِ زمانہ ہلاک کرتی ہے حالانکہ انہیں اس (حقیقت) کا کوئی علم نہیں ہے وہ محض گمان کی بناء پر ایسا کہتے ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcviii{اور جب ان کے سامنے ہماری کھلی ہوئی آیتیں پڑھی جاتی ہیں تو ان کے پاس کوئی حجت اور دلیل نہیں ہوتی سوائے اس کے کہ کہتے ہیں کہ اگر تم سچے ہو تو ہمارے باپ دادا کو (زندہ کر کے) لاؤ۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcix{آپ(ص) کہہ دیجئے! اللہ ہی تمہیں زندہ رکھتا ہے وہی تمہیں موت دیتا ہے پھر وہی تمہیں قیامت کے دن اکٹھا کرے گا جس کے آنے میں کوئی شک نہیں ہے لیکن اکثر لوگ (اس حقیقت کو) جانتے نہیں ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmd{آسمانوں اور زمین میں اللہ ہی کی بادشاہی ہے اور جس دن قیامت قائم ہوگی اس دن باطل پرست لوگ خسارہ اٹھائیں گے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdi{اور آپ دیکھیں گے کہ اس وقت ہر گروہ گھٹنوں کے بل گرا ہوا اپنے (فیصلے کامنتظر) ہوگا اور ہر گروہ کو اس کی کتاب (صحیفۂ عمل) کی طرف بلایا جائے گا (اور ان سے کہا جائے گا کہ) آج تمہیں اس کا بدلہ دیا جائے گا جو کچھ تم کیا کرتے تھے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdii{یہ ہماری کتاب (دفترِ عمل) ہے جو تمہارے بارے میں حق و سچ کے ساتھ بولتی ہے ہم لکھتے (لکھواتے) رہتے تھے جو کچھ تم کرتے تھے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdiii{جو لوگ ایمان لائے اور نیک عمل کرتے رہے ان کا پروردگار انہیں اپنی رحمت میں داخل کرے گااوریہی واضح کامیابی ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdiv{اور جن لوگوں نے کفر اختیار کیا (ان سے کہا جائے گا) میری آیتیں تمہیں پڑھ کر نہیں سنائی جاتی تھیں؟ مگر تم نے تکبر کیا اور تم مجرم لوگ تھے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdv{اورجب (تم سے) کہا جاتا تھا کہ اللہ کا وعدہ برحق ہے اور قیامت میں کوئی شک نہیں ہے تو تم کہتے تھے کہ ہم نہیں جانتے کہ قیامت کیا ہے؟ بس ایک گمان ہے جو ہم کرتے ہیں اور ہمیں اس کا یقین نہیں ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdvi{(اس وقت) ان کے اعمال کی برائیاں واضح ہو جائیں گی اور وہ چیز ان کو گھیرے گی جس کا وہ مذاق اڑایا کرتے تھے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdvii{اور (ان سے کہا) جائے گا کہ آج ہم تمہیں اس طرح نظر انداز کریں گے جس طرح تم نے اس دن کی ملاقات (حاضری) کو بُھلا دیا تھا۔ تمہارا ٹھکانہ دوزخ ہے اور تمہارا کوئی مددگار نہیں ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdviii{یہ اس لئے کہ تم نے اللہ کی آیتوں کامذاق اڑایا تھا اوردنیاوی زندگی نے تمہیں دھوکہ میں مبتلا کیا۔ پس وہ آج نہ تو اس (دوزخ) سے نکالے جائیں گے اور نہ ان کو معذرت (خدا کو راضی) کرنے کاموقع دیا جائے گا۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdix{ہر قِسم کی تعریف اللہ کیلئے ہے جو آسمانوں اور زمین کا بلکہ سارے جہانوں کا پروردگار ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdx{اسی کیلئے کِبریائی ہے اور وہ بڑا غالب (اور) بڑی حکمت والا ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdxi{\basmalahur حا۔ میم۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxii{(یہ) کتابِ عزیز و حکیم (غالب اور بڑے حکمت والے خدا) کی طرف سے نازل کی گئی ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiii{ہم نے آسمانوں اور زمین کو اور جو کچھ ان کے درمیان ہے کو پیدا نہیں کیا مگر حق و حکمت کے ساتھ اور ایک مقررہ مدت تک اور جو کافر لوگ ہیں وہ جس چیز سے ڈرائے جاتے ہیں وہ اس سے رُوگردانی کرتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiv{آپ(ص) کہہ دیجئے! کہ کیا تم نے کبھی غور کیا ہے کہ جن کو تم اللہ کے سوا پکارتے ہو مجھے دکھاؤ کہ انہوں نے زمین میں سے کیا پیدا کیا ہے؟ یا آسمانوں کی تخلیق میں ان کی کچھ شرکت ہے؟ میرے پاس پہلے کی کوئی کتاب لاؤ! یا کوئی عِلمی روایت(اور علمی ثبوت) لاؤ اگر تم سچے ہو۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdxv{اور اس شخص سے زیادہ گمراہ کون ہوگا جو اللہ کو چھوڑ کر ان کو پکارے جو قیامت تک اس کو جواب نہیں دے سکتے بلکہ وہ ان کی دعا و پکار سے غافل ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvi{اور جب سب لوگ جمع کئے جائیں گے تو وہ (معبود) ان کے دشمن ہوں گے اور ان کی عبادت کا انکار کریں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvii{اور جب ان کو ہماری واضح آیتیں پڑھ کر سنائی جاتی ہیں تو (یہ) کافر لوگ حق کے بارے میں کہتے ہیں جبکہ ان کے پاس آگیا کہ یہ تو کھلا ہوا جادو ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxviii{کیا وہ کہتے ہیں کہ اس (رسول(ص)) نے اسے خود گھڑ لیا ہے؟ آپ(ص) کہیے کہ اگر میں نے اسے گھڑ لیا ہے تو تم لوگ اللہ کے مقابلہ میں میرے لئے کچھ بھی نہیں کر سکتے (ذرا بھی مجھے نہیں بچا سکتے) (قرآن کے متعلق) تم جن باتوں میں مشغول ہو وہ (اللہ) ان کو خوب جانتا ہے اور وہی میرے اور تمہارے درمیان بطور گواہ کافی ہے اور بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxix{آپ کہہ دیجئے کہ رسولوں(ع) میں سے میں کوئی انوکھا نہیں ہوں اور میں (از خود) نہیں جانتا کہ میرے ساتھ کیا کیاجائے گا؟ اور تمہارے ساتھ کیا کیا جائے گا اور میں تو صرف اس کی پیروی کرتا ہوں جس کی مجھے وحی کی جاتی ہے اور میں نہیں ہوں مگر کھلا ہوا ڈرانے والا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxx{آپ کہیے کیا تم نے کبھی غور کیا ہے کہ اگر وہ (قرآن) اللہ کی طرف سے ہوا اور تم نے اس کا انکار کیا درآنحالیکہ تم بنی اسرائیل میں سے ایک گواہ اس جیسی (کتاب پر) گواہی دے چکا اور ایمان بھی لا چکا مگر تم نے تکبر کیا؟ بیشک اللہ ظالم لوگوں کو ہدایت نہیں دیتا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxi{اور کافر لوگ ایمان لانے والوں کی نسبت کہتے ہیں کہ اگر وہ (قرآن و اسلام) کوئی اچھی چیز ہوتا تو یہ لوگ اس کی طرف ہم پر سبقت نہلے جاتے اب چونکہ انہوں نے اس (قرآن) سے ہدایت نہیں پائی تو وہ ضرور کہیں گے کہ یہ تو پرانا جھوٹ ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxii{حالانکہ اس سے پہلے موسیٰ(ع) کی کتاب (توراۃ) بھی راہنماورحمت تھی اور یہ کتاب (قرآن) تو اس کی تصدیق کرنے والی ہے (اور) عربی زبان میں ہے تاکہ ظالموں کو ڈرائے اور نیکوکاروں کے لئے خوشخبری ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiii{بےشک جن لوگوں نے کہا کہ ہمارا پروردگار اللہ ہے اور پھر اس (اقرار) پر ثابت و برقرار رہے تو انہیں کوئی خوف نہیں ہے اور نہ ہی وہ غمگین ہوں گے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiv{یہی لوگ بہشتی ہیں جس میں وہ ہمیشہ رہیں گے یہ صِلہ ہے ان کے ان اعمال کا جو وہ (دنیا میں) کیا کرتے تھے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxv{اور ہم نے انسان کو اپنے والدین کے ساتھ نیک سلوک کرنے کا حکم دیا ہے اس کی ماں نے زحمت کے ساتھ اسے پیٹ میں رکھا اور زحمت کے ساتھ اسے جنم دیا اور اس کا حمل اور دودھ چھڑانا تیس مہینوں میں ہوا۔ یہاں تک کہ جب وہ اپنی پوری طاقت کو پہنچا (جوان ہوا) اور پورے چالیس سال کا ہوگیا تو اس نے کہا اے میرے پروردگار! تو مجھے توفیق عطا فرما کہ میں تیرے اس احسان کاشکر ادا کروں جو تو نے مجھ پر اور میرے والدین پر کیا ہے اور یہ کہ میں ایسا نیک عمل کروں جسے تو پسند کرتا ہے اور میرے لئے میری اولاد میں بھی صالحیت پیدا فرما میں تیری بارگاہ میں توبہ (رجوع) کرتا ہوں اور میں مسلمانوں(فرمانبرداروں) میں سے ہوں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvi{یہی وہ لوگ ہیں جن کے بہترین اعمال کو ہم قبول کرتے ہیں اور ان کی برائیوں سے درگزر کرتے ہیں یہ بہشتیوں میں ہوں گے اس سچے وعدہ کی بناء پر جو برابر ان سے کیا جاتا رہا ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvii{اور جس نے اپنے والدین سے کہا تُف ہے تم پر کیا تم دونوں مجھ سے وعدہ کرتے ہو کہ میں (دوبارہ قبر سے) نکالا جاؤں گا۔ حالانکہ مجھ سے پہلے کئی نسلیں گزر چکی ہیں (اور کوئی ایک بھی زندہ نہ ہوا) اور وہ دونوں اللہ سے فریاد کرتے ہیں (اور کہتے ہیں) وائے ہو تجھ پر ایمانلے آ۔ بےشک اللہ کا وعدہ سچاہے(مگر) وہ کہتا ہے کہ یہ سب اگلے لوگوں کی (پرانی) کہانیاں ہیں۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxviii{یہ وہ لوگ ہیں جن پر اللہ کے قول (عذاب) کا فیصلہ نافذ ہو چکا ہے۔ ان گروہوں کے ساتھ جو جنوں اور انسانوں میں سے پہلے گزر چکے ہیں۔یقیناً وہ لوگ گھاٹے میں تھے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxix{اور ہر ایک کیلئے ان کے اعمال کے مطابق درجے ہوں گے تاکہ ان کو ان کے اعمال کا پورا پورا بدلہ مل جائے اور ان پر ظلم نہیں کیا جائے گا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxx{اور جس دن کافروں کو دوزخ کے سامنے لایا جائے گا (تو ان سے کہا جائے گا کہ) تم اپنے حصے کی نعمتیں دنیاوی زندگی میںلے چکے اور ان سے فائدہ اٹھا چکے آج تمہیں ذلت کا عذاب دیا جائے گا بوجہ اس کے کہ تم زمین میں ناحق تکبر کرتے تھے اور نافرمانیاں کرتے تھے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxi{(اے رسول(ص)) قومِ عاد کے بھائی (جنابِ ہود(ع)) کاذکر کیجئے جبکہ انہوں نے اپنی قوم کو مقامِ احقاف (ریت کے ٹیلوں والی بستی) میں ڈرایا تھا جبکہ بہت سے ڈرانے والے ان سے پہلے بھی گزر چکے اوران کے بعد بھی (جنابِ ہود(ع) نے کہا کہ) اللہ کے سوا کسی کی عبادت نہ کرو (ورنہ) مجھے تمہارے بارے میں ایک بڑے (ہولناک) دن کے عذاب کا اندیشہ ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxii{ان قوم والوں نے کہا کہ کیا تم اس لئے ہمارے پاس آئے ہو کہ ہمیں اپنے معبودوں سے منحرف کردو۔ لاؤ ہمارے پاس وہ (عذاب) جس کی دھمکی تم ہمیں دیتے ہواگر تم سچے ہو۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiii{جنابِ ہود(ع) نے کہا اس (نزولِ عذاب) کا علم تو بس اللہ کے پاس ہے میں تو صرف تم تک وہ (پیغام) پہنچا رہا ہوں جس کے ساتھ میں بھیجا گیا ہوں۔ لیکن میں تمہیں دیکھ رہا ہوں کہ تم بالکل جاہل قوم ہو۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiv{پس جب انہوں نے (عذاب) کو ایک بادل کی صورت میں اپنی وادیوں کی طرف آتے ہوئے دیکھا تو کہنے لگے کہ یہ بادل تو ہم پر برسنے والا ہے بلکہ یہ وہ (عذاب) ہے جس کی تم جلدی کر رہے تھے (یہ تند و تیز) ہوا ہے جس میں دردناک عذاب ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxv{وہ اپنے پروردگار کے حکم سے ہر چیز کو تباہ و برباد کر دے گی۔ چنانچہ وہ ایسے ہو گئے کہ ان کے مکانوں کے سوا وہاں کچھ نظر نہیں آتا تھا ہم مجرم قوم کو اسی طرح سزا دیا کرتے ہیں۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvi{ہم نے ان لوگوں کو ان کاموں کی قدرت دی تھی جو تمہیں بھی نہیں دی اور ہم نے ان کو کان، آنکھیں اور دل دیئے تھے مگر ان کے کانوں اور آنکھوں اور دلوں نے کچھ بھی فائدہ نہ پہنچایا کیونکہ وہ آیاتِ الہیہ کا انکار کیا کرتے تھے اور ان کو اس چیز نے گھیر لیا جس کا وہ مذاق اڑایا کرتے تھے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvii{اور ہم نے تمہارے اردگرد کی کئی بستیوں کو ہلاک و برباد کر دیا اور ہم نے اپنی (قدرت کی) نشانیاں پھیر پھیر کر(مختلف انداز سے) پیش کیں تاکہ وہ باز آجائیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxviii{تو انہوں نے ان کی مدد کیوں نہ کی جن کو انہوں نے خدا کے تقرب کیلئے معبود بنا رکھا تھا بلکہ وہ تو ان سے غائب ہو گئے، یہ تھا ان کا جھوٹ اور ان کا بہتان جو وہ باندھتے تھے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxix{اور (وہ وقت یاد کرو) جب ہم نے جنات کے کچھ افراد کو آپ(ص) کی طرف متوجہ کیا تاکہ وہ غور سے قرآن سنیں۔ پس وہ اس جگہ پہنچے (جہاں قرآن پڑھا جا رہاتھا) تو (آپس میں کہنے لگے) خاموش ہو کر سنو پس جب (قرآن) پڑھا جا چکا تو وہ اپنی قوم کی طرف ڈرانے والے بن کر لوٹے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdxl{انہوں نے کہا اے ہماری قوم! ہم نے ایک کتاب سنی ہے جو موسٰی (ع)ٰ کے بعد نازل کی گئی ہے جو پہلی کتابوں کی تصدیق کرتی ہے (اور جو) حق اور سیدھے راستے کی طرف راہنمائی کرتی ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdxli{اے ہماری قوم! اللہ کیطرف بلانے والے کی دعوت پر لبیک کہو اور اس پر ایمانلے آؤ۔ اللہ تمہارے گناہ معاف کر دے گا اور تمہیں دردناک عذاب سے پناہ دے گا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlii{اور جو کوئی اللہ کی طرف بلانے والے کی آواز پر لبیک نہیں کہے گا تو وہ زمین میں اللہ کو عاجز نہیں کرسکتا (اس کے قابو سے باہر نہیں نکل سکتا) اور نہ اللہ کے سوا اس کے لئے کوئی مددگار و سازگار ہے ایسے لوگ کھلی ہوئی گمراہی میں ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliii{کیا ان لوگوں نے نہیں دیکھا کہ اللہ نے آسمانوں اور زمین کو پیدا کیا ہے اور ان کے پیدا کرنے سے تھکا نہیں ہے وہ اس پر قادر ہے کہ مُردوں کو زندہ کرے۔ ہاں بےشک وہ ہر چیز پر بڑی قدرت رکھتا ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliv{اور جس دن کافر دوزخ کے سامنے پیش کئے جائیں گے (ان سے کہا جائے گا) کیا یہ حقیقت نہیں ہے؟ وہ کہیں گے کہ ہاں ہمیں قَسم ہے اپنے پروردگار کی! ارشاد ہوگا اپنے کفر و انکارکی پاداش میں عذاب کا مزہ چکھو۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlv{(اے رسول(ص)) آپ(ص) اسی طرح صبر کریں جس طرح اولوالعزم رسولوں(ع) نے صبر کیا ہے اور ان کیلئے جلدی نہ کریں جس دن وہ دیکھیں گے (وہ عذاب) جس کا ان سے وعدہ کیا جا رہا ہے تو وہ محسوس کریں گے کہ وہ (دنیا میں) دن کی ایک گھڑی سے زیادہ نہیں رہے۔ بس یہ پیغام پہنچا دینا ہے۔ انجامِ کار ہلاک و برباد وہی ہوں گے جو فاسق و فاجر ہیں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvi{\basmalahur جن لوگوں نے کفر کیا اور (دوسرے لوگوں کو بھی) اللہ کے راستے سے روکا اس (اللہ) نے ان کے اعمال کو رائیگاں کر دیا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvii{اور جو لوگ ایمان لائے اور نیک اعمال بھی کئے اور اس (قرآن) پر بھی ایمان لائے جو (حضرت) محمد (ص) پر نازل کیا گیا ہے جو کہ ان کے پروردگار کی طرف سے حق ہے تو اللہ نے ان کی برائیوں کا کفارہ ادا کر دیا (برائیاں دور کر دیں) اور انکی حالت کو درست کر دیا۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlviii{یہ اس لئے ہوا کہ جن لوگوں نے کفر کیا انہوں نے باطل کی پیروی کی اور جو ایمان لائے انہوں نے اپنے پروردگار کی طرف سے حق کی پیروی کی اسی طرح خدا لوگوں کے حالات و اوصاف بیان کرتا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlix{پس جب کافروں سے تمہاری مڈبھیڑ ہوجائے تو ان کی گردنیں اڑاؤ۔ یہاں تک کہ جب خوب خون ریزی کر چکو (خوب قتل کر لو) تو پھر ان کو مضبوط باندھ لو اس کے بعد (تمہیں اختیار ہے)یا تو احسان کرو (رہا کردو)یا فدیہلے لو یہاں تک کہ جنگ میں اپنے ہتھیار ڈال دے (یہ حکم) اسی طرح ہے اور اگر خدا چاہتا تو خود ہی ان سے انتقاملے لیتا لیکن وہ تم لوگوں کے بعض کو بعض سے آزمانا چاہتا ہے اور جو لوگ اللہ کی راہ میں قتل ہو گئے تو اللہ ان کے اعمال کو ہرگز ضائع نہیں کرے گا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdl{اور (منزلِ مقصود کی طرف) ان کی راہنمائی کرے گا اور ان کی حالت کو درست کرے گا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdli{اور ان کو بہشت میں داخل کرے گا جس کا وہ ان سے تعارف کرا چکا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdlii{اے ایمان والو! اگر تم اللہ کی مدد کرو گے تو اللہ تمہاری مدد کرے گا (اور تمہیں ثابت قدم رکھے گا)۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdliii{اور جن لوگوں نے کفر اختیار کیا تو ان کیلئے ہلاکت ہے اور اللہ نے ان کے اعمال کو رائیگاں کر دیا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdliv{یہ اس لئے ہے کہ انہوں نے اسے ناپسند کیا جو اللہ نے نازل کیا ہے۔ پس اس (اللہ) نے ان کے سب اعمال اکارت کر دئیے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdlv{کیا یہ لوگ زمین میں چلتے پھرتے نہیں کہ دیکھتے کہ ان لوگوں کا انجام کیا ہوا جو ان سے پہلے تھے اللہ نے ان کو ہلاک کر دیا اور ان کافروں کیلئے بھی ایسے ہی انجام ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvi{یہ اس لئے ہے کہ اللہ اہلِ ایمان کا سرپرست ہے اور جو کافر ہیں ان کا کوئی سرپرست اور کارساز نہیں ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvii{بےشک اللہ ان لوگوں کو جو ایمان لائے اور نیک عمل کئے ان بہشتوں میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی اور جن لوگوں نے کفر کیا وہ (دنیا میں) بہرہ مند ہو رہے ہیں (عیش کر رہے ہیں) اور اس طرح کھا رہے ہیں جس طرح چوپائے کھاتے ہیں اور (ان کا آخری) ٹھکانہ دوزخ ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdlviii{اور کتنی ہی ایسی بستیاں تھیں جو تمہاری اس بستی سے زیادہ طاقتور تھیں جس نے تمہیں نکالا ہے کہ ہم نے انہیں ہلاک کر دیا پس ان کا کوئی مددگار نہ تھا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdlix{کیا وہ جو اپنے پروردگار کی طرف سے واضح دلیل پر ہے اس شخص کی طرح ہو سکتا ہے جس کی بدعملی اس کی نگاہ میں خوشنما بنا دی گئی ہے اور وہ اپنی خواہشات کی پیروی کرتے ہیں؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdlx{وہ جنت جس کا پرہیزگاروں سے وعدہ کیا گیا ہے اس کی صفت یہ ہے کہ اس میں ایسے پانی کی نہریں ہیں جس میں تغیر نہیں ہوتا اور ایسے دودھ کی نہریں ہیں جس کا مزہ نہیں بدلتا اور ایسے شراب کی نہریں ہیں جو پینے والوں کے لئے لذیذ ہے اور ایسے شہد کی نہریں ہیں جو صاف شفاف ہے اور ان کیلئے وہاں ہر قسم کے پھل ہیں اور ان کے پروردگار کی طرف سے بخشش ہے کیا ایسے (پرہیزگار) لوگ ان لوگوں جیسے ہو سکتے ہیں جو ہمیشہ دوزخ میں رہیں گے اور ان کو ایسا گرم پانی پلایا جائے گا جو ان کی آنتوں کو ٹکڑے ٹکڑے کر دے گا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxi{اور ان میں سے ایسے لوگ بھی ہیں جو (بظاہر) تمہاری طرف کان لگا کر (بات سنتے ہیں) یہاں تک کہ جب آپ کے پاس سے باہر جاتے ہیں تو ان (خاص) لوگوں سے پوچھتے ہیں جن کو علم عطا کیا گیا ہے کہ انہوں (رسول(ص)) نے ابھی کیا کہاتھا؟ یہی وہ لوگ ہیں جن کے دلوں پر خدا نے مہر لگا دی ہے اور اپنی خواہشات کی پیروی کرتے ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxii{اور جن لوگوں نے ہدایت طلب کی ہے اللہ ان کی ہدایت میں اور اضافہ کرتا ہے اور ان کو (ان کے حصے کی) پرہیزگاری عطا کرتا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiii{سو یہ لوگ تو بس اب قیامت کا انتظار کر رہے ہیں کہ اچانک ان پر آجائے تو اس کے آثار و علا مات تو آہی چکے ہیں اور جب وہ آجائے گی تو پھر ان کو نصیحت حاصل کرنے کاموقع کہاں رہے گا؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiv{(اے رسول(ص)) خوب جان لیں کہ اللہ کے سوا کوئی خدانہیں ہے اور خدا سے اپنے ذنب اور مؤمن مردوں اور مؤمن عورتوں کی مغفرت طلب کریں۔ اللہ تمہاری گردش (چلنے پھر نے) کی جگہ کو اور تمہارے ٹھکانے کو جانتا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxv{اور جو لوگ ایمان لائے ہیں وہ کہتے ہیں کہ (جہاد کے بارے میں) کوئی سورہ کیوں نازل نہیں کی جاتی؟ پس جب ایک محکم سورہ نازل کی جاتی ہے اور اس میں قتل و قتال کا ذکر ہوتا ہے تو آپ(ص) ان لوگوں کو دیکھئے گا کہ جن کے دلوں میں (نفاق کی) بیماری ہے وہ آپ(ص) کی طرف اس طرح دیکھتے ہیں جس طرح وہ شخص دیکھتا ہے جس پر موت کی غشی طاری ہو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvi{ان کے لئے بہتر تو یہ تھا کہ اطاعت کرتے اور اچھی بات کہتے اور جب (جہاد کا) قطعی فیصلہ ہو جاتا تو اگر یہ اللہ سے (اپنے عہد میں) سچے ثابت ہوتے تو ان کے لئے بہتر ہوتا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvii{پھرتم سے یہی توقع ہے کہ اگر تم حاکم بن جاؤ (تمہیں اقتدار مل جائے) تو تم زمین میں فساد برپا کرو۔اور اپنی قرابتوں کو قطع کرو۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxviii{یہی وہ لوگ ہیں جن پر اللہ نے لعنت کی ہے اور انہیں بہرا بنا دیا ہے اور ان کی آنکھوں کو اندھا کر دیا ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxix{کیا یہ لوگ قرآن میں غور و فکر نہیں کرتے؟ یا ان کے دلوں پر تالے لگے ہوئے ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxx{جو لوگ پیٹھ پھیر کر (کفر کی طرف) پیچھے پلٹ گئے بعد اس کے کہ ان پر ہدایت واضح ہو گئی تھی۔ شیطان نے انہیں فریب دیا اورانہیں دور دور کی سجھائی۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxi{یہ اس لئے ہے کہ انہوں نے ان لوگوں سے کہا جو اللہ کی نازل کردہ (کتاب) کو ناپسند کرتے ہیں کہ ہم بعض معاملات میں تمہاری بات مان لیں گے اللہ ان کی رازداری کو جانتا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxii{اس وقت ان کا کیا حال ہوگا جب فرشتے ان کی روحیں قبض کریں گے اور ان کے چہروں اور پشتوں پر مارتے ہوں گے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiii{یہ سب اس وجہ سے ہوگا کہ انہوں نے اس چیز کی پیروی کی جو اللہ کی ناراضی کا با عث تھی اور اس کی خوشنودی کو ناپسند کیا پس اللہ نے ان کے اعمال کو اکارت کر دیا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiv{کیا وہ لوگ جن کے دلوں میں بیماری ہے یہ خیال کرتے ہیں کہ اللہ کبھی ان کے (سینوں کے) کینوں کو ظاہر نہیں کرے گا۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxv{اگر ہم چاہیں تو وہ لوگ آپ کو دکھا دیں اور آپ انہیں علامتوں سے پہچان لیں اور (خاص کر) آپ انہیں ان کے اندازِ گفتگو سے تو ضرور پہچان لیں گے اور اللہ تم سب کے اعمال کو جانتا ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvi{اور ہم ضرور تم لوگوں کو آزمائیںگے تاکہ ہم تم میں سے جہاد کرنے والوں اور ثابت قدم رہنے والوں کو معلوم (و ممیز) کریں اور تمہارے حالات کی جانچ کر لیں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvii{بےشک جن لوگوں نے کفر کیا اور (دوسرے لوگوں کو) اللہ کی راہ سے روکا اور پیغمبر کی مخالفت کی بعد اس کے کہ ان پر ہدایت واضح ہو چکی تھی وہ اللہ کو ہرگز کوئی نقصان نہیں پہنچا سکیں گے (ہاں البتہ) اللہ ان کے اعمال کو اکارت کر دے گا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxviii{اے ایمان والو! اطاعت کرو اللہ کی اور اطاعت کرو رسول(ص) کی اور (ان کی مخالفت کر کے) اپنے اعمال کو برباد نہ کرو۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxix{بےشک جن لوگوں نے کفر کیا اور (لوگوں کو) اللہ کے راستے سے روکا اور پھر وہ کفر ہی کی حالت میں مر گئے اللہ ان کو کبھی نہیں بخشے گا۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxx{پس تم کمزور نہ پڑو (اور ہمت نہ ہارو) اور (دشمن کو) صلح کی دعوت نہ دو حالانکہ تم ہی غالب رہو گے اور اللہ تمہارے اعمال (کے ثوا ب) میں ہرگز کمی نہیں کرے گا۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxi{یہ دنیا کی زندگی تو بس کھیل اور تماشا ہے اگر تم ایمان لاؤ اور تقویٰ اختیار کرو تو وہ (خدا) تمہیں تمہارے اجر عطا کرے گا اور تم سے تمہارے مال نہیں مانگے گا۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxii{اور اگر وہ تم سے وہ (مال) مانگے اورپھر اصرار بھی کرے تو تم بخل کرو گے اور وہ تمہارے دلی کینوں (اور دلی ناگواریوں) کو ظاہر کر دے گا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiii{ہاں تم ہی ایسے لوگ ہو کہ تمہیں دعوت دی جاتی ہے کہ اللہ کی راہ میں خرچ کرو تو تم میں سے کچھ لوگ بُخل کرنے لگتے ہیں اور جو بُخل کرتا ہے وہ (دراصل) اپنے ہی نفس سے بُخل کرتا ہے اور اللہ بےنیاز ہے البتہ تم (اس کے) محتاج ہو اور اگر تم رُوگردانی کروگے تو وہ تمہاری جگہ دوسری قوم کولے آئے گا پھر وہ تم جیسے نہیں ہوں گے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiv{\basmalahur (اے رسول(ص)) بےشک ہم نے آپ(ص) کو ایک فتحِ مبین (نمایاں فتح) عطا کی ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxv{تاکہ اللہ ان (لوگوں کی نظر میں) آپ(ص) کے تمام اگلے اور پچھلے گناہ بخش دے اور آپ پر اپنی نعمت تام و تمام کرے اور آپ(ص) کو منزلِ مقصود تک پہنچا ئے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvi{اور تاکہ اللہ آپ کی زبردست مدد کرے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvii{وہ (اللہ) وہی ہے جس نے اہلِ ایمان کے دلوں میں سکون و اطمینان اتارا تاکہ وہ اپنے (پہلے) ایمان کے ساتھ ایمان میں اور بڑھ جائیں اور آسمانوں اور زمین کے سب لشکر اللہ ہی کے ہیں اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxviii{(یہ اس لئے ہے) تاکہ وہ مؤمن مَردوں اور مؤمن عورتوں کو ایسے بہشتوں میں داخل کرے جن کے نیچے نہریں رواں دواں ہیں اور وہ ان میں ہمیشہ رہیں گے اور تاکہ ان کی برائیاں ان سے دور کر دے (ان کا کفارہ کر دے) اور یہ اللہ کے نزدیک بڑی کامیابی ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxix{اور تاکہ وہ (اللہ) منافق مَردوں اور منافق عورتوں، مشرک مَردوں اور مشرک عورتوں کو سزا دے جو اللہ کے بارے میں برے گمان کرتے ہیں برائی کی گردش انہی پر ہے اللہ ان پر غضبناک ہے اور ان پر لعنت کی ہے اور ان کیلئے جہنم تیار کر رکھی ہے اور وہ بہت برا انجام ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxc{اور آسمانوں اور زمین کے تمام لشکر اللہ ہی کے ہیں اور خدا (سب پر) غالب اور بڑا حکمت والا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxci{(اے رسول(ص)) بےشک ہم نے آپ(ص) کو گواہ بنا کر اور بشارت دینے والا اور ڈرانے والا بنا کر بھیجا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcii{تاکہ تم لوگ اللہ پر اور اس کے رسول(ص) پر ایمان لاؤ اور رسول(ص) کی مدد کرو اور اس کی تعظیم و توقیر کرو اورصبح و شام اس (اللہ) کی تسبیح کرو۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciii{(اے رسول(ص)) جو لوگ آپ سے بیعت کرتے ہیں وہ (دراصل) اللہ کی بیعت کرتے ہیں اللہ کا ہاتھ ان کے ہاتھوں کے اوپر ہے پس جو (اس عہد کو) توڑے گا تو اس کے توڑنے کا وبال اسی کی ذات پر ہوگا اور جو اس عہد کو پورا کرے گا جو اس نے اللہ سے کیا ہے تو اللہ اسے بڑا اجر عطا کرے گا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciv{صحرائی عربوں میں سے جو (سفرِ حدیبیہ میں) پیچھے چھوڑ دئیے گئے تھے وہ عنقریب کہیں گے کہ ہمارے مال اور اہل و عیال نے ہمیں مشغول رکھا (اس لئے آپ(ص) کے ہمراہ نہ جا سکے) تو آپ(ص) ہمارے لئے (خدا سے) بخشش کی دعا کیجئے! وہ اپنی زبانوں سے وہ بات کہتے ہیں جو ان کے دلوں میں نہیں ہے آپ(ص) کہیے! کون ہے جو اللہ کے مقابلے میں تمہارے لئے کچھ اختیار رکھتا ہے؟ اگر وہ تمہیں نقصان پہنچانا چاہے یانفع پہنچانا چاہے بلکہ تم جو کچھ کرتے ہو اللہ اس سے خوب باخبر ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcv{(اصل بات یہ ہے کہ) تم نے خیال کیا تھا کہ رسول(ص) اور اہلِ ایمان اب کبھی بھی اپنے گھر والوں کی طرف لوٹ کر نہیں آئیں گے اور یہ بات تمہارے دلوں میں خوشنما بنا دی گئی اور تم نے بہت برے گمان کئے (اسی طرح) تم برباد ہو نے والی جماعت بن گئے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvi{اور جو کوئی اللہ اور اس کے رسول(ص) پر ایمان نہ لائے تو ہم نے ان کافروں کیلئے بھڑکتی ہوئی آگ (دوزخ) تیار کر رکھی ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvii{اور آسمانوں اور زمین کی بادشاہی اللہ ہی کیلئے ہے جس کو چاہے بخش دے اور جس کو چاہے عذاب دے اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcviii{جب تم (جنگِ خیبر میں) غنیمتیں حاصل کرنے کیلئے چلوگے تو جو پیچھے چھوڑ دئیے گئے وہ ضرور کہیں گے کہ ہمیں بھی اجازت دو کہ ہم آپ کے پیچھے آئیں وہ چاہتے ہیں کہ اللہ کی بات کو بدل دیں۔ آپ(ص) کہہ دیجئے! کہ تم اب کبھی ہمارے پیچھے نہیں آسکتے! اللہ پہلے ہی ایسی بات کہہ چکا ہے اس پر وہ ضرور کہیں گے کہ بلکہ تم ہم سے حسد کرتے ہو بلکہ یہ (کم عقل) بہت ہی کم بات سمجھتے ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcix{آپ(ص) ان پیچھے والے صحرائی عربوں سے کہیے! عنقریب تمہیں ایک سخت جنگجو قوم کے خلاف جہاد کیلئے بلایا جائے گا تم ان سے لڑوگےیا وہ اسلام لائیں گے پس اگر تم نے اطاعت کی تو اللہ تمہیں بہت اچھا اجر عطا کرے گا۔ اور اگر تم نے اسی طرح منہ موڑا جس طرح پہلے منہ موڑا تھا تو وہ تمہیں (دردناک) عذاب دے گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdc{اندھے پر کوئی مضائقہ نہیں ہے اورنہ ہی لنگڑے پر کوئی حرج ہے اور نہ مریض پر کوئی گناہ اور جو خدا اور رسول(ص) کی اطاعت کرے گا۔ تو اللہ اسے ان بہشتوں میں داخل کرے گا جن کے نیچے نہریں رواں دواں ہیں اور جو رُوگردانی کرے گا تو اسے دردناک عذاب دے گا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdci{بےشک اللہ مؤمنین سے راضی ہوا جب کہ وہ درخت کے نیچے آپ(ص) سے بیعت کر رہے تھے تو اس نے جان لیا جو کچھ ان کے دلوں میں تھا۔ پس اس نے ان پر سکون و اطمینان نازل کیا اور انہیں انعام میں ایک قریبی فتح عنا یت فرمائی۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcii{اور بہت سی غنیمتیں بھی جن کو وہ (عنقریب) حاصل کریں گے اللہ (ہر چیز) پرغالب ہے، بڑا حکمت والا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdciii{اللہ نے تم سے (اور بھی) بہت سی غنیمتوں کا وعدہ کیا ہے جن کو تم حاصل کرو گے پس یہ (فتحِ خیبر) تو اس نے فوری طور پر تمہیں دے دی اور لوگوں کے ہاتھ تم سے روک دئیے تاکہ یہ مؤمنین کیلئے (ہماری قدرت و نصرت) کی ایک نشانی ہو جائے اور وہ تمہیں سیدھے راستے کی طرف رہنمائی کرے (اس پر چلائے)۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdciv{اور غنیمتیں بھی ہیں جن پر تم ابھی قادر نہیں ہوئے اور اللہ نے ان کو گھیر رکھا ہے (اس کے قبضہ میں ہیں) اور اللہ ہر چیز پر پوری طرح قادر ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcv{اور اگر (یہ) کافر لوگ تم سے جنگ کرتے تو ضرور پیٹھ پھیر کر بھاگ جاتے اور پھر وہ (اپنے لئے) کوئی حامی و مددگار نہ پاتے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvi{یہی اللہ کا دستور ہے جوپہلے سے چلا آرہا ہے اور تم اللہ کے دستور میں ہرگز کوئی تبدیلی نہیں پاؤ گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvii{اور وہ (اللہ) وہی ہے جس نے مکہ کی وادی میں روک دئیے تھے ان کے ہاتھ تم سے اور تمہارے ہاتھ ان سے بعد اس کے کہ تمہیں ان پر غلبہ عطا کر دیا تھا اور تم جو کچھ کر رہے ہو اللہ اسے خوب دیکھ رہا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcviii{یہ وہی لوگ ہیں جنہوں نے کفر کیا اور تمہیں مسجد الحرام سے روکا اور قربانی کے جانوروں کو بھی روکے رکھا کہ وہ اپنی قربانی کی جگہ نہ پہنچ سکے اور اگر (مکہ میں) ایسے مؤمن مرد اور مؤمن عورتیں نہ ہوتیں جن کو تم نہیں جانتے (اور یہ خوف نہ ہوتا کہ) تم انہیں لاعلمی میں روند ڈالوگے اور پھر ان کی وجہ سے تم پر الزام آتا (تو جنگ نہ روکی جاتی) مگر روکی اس لئے گئی تاکہ اللہ جسے چاہے اپنی رحمت میں داخل کرے اگر وہ (اہلِ ایمان) الگ ہو جاتے تو ہم ان (اہلِ مکہ) میں سے کافروں کو دردناک سزا دیتے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcix{(وہ وقت یاد کرو) جب کافروں نے اپنے دلوں میں عصبیت پیدا کی اور عصبیت بھی جاہلیت والی اللہ نے اپنا سکون و اطمینان اپنے رسول(ص) اور اہلِ ایمان پر نازل فرمایا اور انہیں پرہیزگاری کی بات کا پابند رکھا کہ وہی اس کے زیادہ حقدار تھے اور اس کے اہل بھی اور اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcx{(اللہ) اس بات کو جانتا تھا جو تم نہیں جانتے تھے تو اس نے اس (تعبیرِ خواب) سے پہلے تمہیں ایک قریبی فتح عطا کر دی۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxi{وہ (اللہ) وہی ہے جس نے اپنے رسول(ص) کو ہدایت اور دینِ حق کے ساتھ بھیجا تاکہ اس کو تمام دینوں پر غالب کر دے اور (اس بات کی) گواہی کیلئے اللہ کافی ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxii{محمد (ص) اللہ کے رسول ہیں اور جو لوگ ان کے ساتھ ہیں وہ کافروں پر سخت ہیں اور آپس میں مہربان ہیں تم انہیں دیکھو گے کہ وہ (کبھی) رکوع (اور کبھی) سجود کر رہے ہیں (اور) اللہ کے فضل و کرم اور اس کی خوشنودی کے طلبگار ہیں ان کی علامت ان کے چہروں پر سجدہ کے نشان سے نمایاں ہے ان کی توراۃ میں اور انجیل میں توصیف یوں ہے جیسے ایک کھیتی جس نے اپنی کونپل نکالی پھر اس کو تقویت دی اور وہ مضبوط و موٹی ہوئی پھر اپنے تنے پر کھڑی ہوگئی وہ کسانوں کو خوش کرتی ہے تاکہ ان کے ذریعہ سے کفار کے دل جلائے اللہ نے ان لوگوں سے جو ایمان لائے اور نیک عمل کئے، مغفرت اور بڑے اجرو ثواب کا وعدہ کر رکھا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiii{\basmalahur اے ایمان والو! تم (کسی کام میں) خدا اور رسول(ص) سے آگے نہ بڑھو (سبقت نہ کرو) اور اللہ (کی نافرمانی) سے ڈرو۔ بےشک اللہ بڑا سننے والا، بڑا جاننے والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiv{اے ایمان والو! تم اپنی آوازوں کو نبی(ص) کی آواز پر بلند نہ کیا کرو جس طرح تم آپس میں ایک دوسرے کے ساتھ اونچی آواز میں کرتے ہو کہیں ایسا نہ ہو کہ تمہارے اعمال اکارت ہو جائیں اورتمہیں خبر بھی نہ ہو۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxv{جو لوگ رسولِ خدا(ص) کے پاس (بات کرتے ہوئے) اپنی آوازیں پست رکھتے ہیں یہی وہ لوگ ہیں جن کے دلوں کو اللہ نے پرہیزگاری کیلئے آزمایا ہے ان کے لئے مغفرت اور اجرِ عظیم ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvi{اے رسول(ص)) جو لوگ آپ کو حجروں میں باہر سے پکارتے ہیں ان میں سے اکثر عقل سے کام نہیں لیتے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvii{اور اگر وہ اتنا صبر کرتے کہ آپ خود ان کے پاس باہر نکل کر آجائیں تو یہ ان کیلئے بہتر ہوتا اور اللہ بڑا بخشنے والا اور بڑا رحم کرنے والا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxviii{اے ایمان والو! اگر کوئی فاسق تمہارے پاس کوئی خبر لائے تو تحقیق کر لیا کرو کہیں ایسا نہ ہو کہ تم کسی قوم کو لاعلمی میں نقصان پہنچا دو اور پھر اپنے کئے پر پچھتاؤ۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxix{اور خوب جان لو کہ تمہارے درمیان رسولِ خدا(ص) موجود ہیں اگر وہ بہت سے معاملات میں تمہاری بات مان لیا کریں تو تم زحمت و مشقت میں پڑ جاؤ گے لیکن اللہ نے ایمان کو تمہارا محبوب بنایا ہے اور اسے تمہارے دلوں میں مرغوب بنایا (آراستہ کیا) اور کفر، فسق اور نافرمانی کو تمہارے نزدیک مبغوض بنایا (اور تم کو ان سے متنفر کیا) یہی لوگ راہِ راست پر ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxx{اللہ کے فضل و کرم اور اس کے انعام و احسان سے اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxi{اور اگر مسلمانوں کے دو گروہ آپس میں لڑ پڑیں تو تم ان کے درمیان صلح کراؤ پھر اگر ان میں سے ایک گروہ دوسرے پر تعدی و زیادتی کرے تو تم سب ظلم وزیادتی کرنے والے سے لڑو۔ یہاں تک کہ وہ حکمِ الٰہی کی طرف لوٹ آئے پس اگر وہ لوٹ آئے تو پھر تم ان دونوں کے درمیان عدل و انصاف کے ساتھ صلح کرا دو اور انصاف کرو۔ بےشک اللہ انصاف کرنے والوں سے محبت کرتا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxii{بےشک اہلِ اسلام و ایمان آپس میں بھائی بھائی ہیں تو تم اپنے دو بھائیوں میں صلح کراؤ اور اللہ (کی عصیاں کاری) سے ڈرو تاکہ تم پر رحم کیا جائے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiii{اے ایمان والو! کوئی قوم کسی قوم کامذاق نہ اڑائے ہو سکتا ہے کہ وہ ان سے بہتر ہوں اور نہ عورتیں عورتوں کامذاق اڑائیں ہو سکتا ہے کہ وہ ان سے بہتر ہوں اور نہ آپس میں ایک دوسرے کو طعنہ دو اور نہ ایک دوسرے کو برے القاب کے ساتھ پکارو۔ ایمان لانے کے بعد فاسق کہلانا کتنا برا نام ہے اور جو توبہ نہیں کریں گے (باز نہیں آئیں گے) وہی لوگ ظالم ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiv{اے ایمان والو! بہت سے گمانوں سے پرہیز کرو (بچو) کیونکہ بعض گمان گناہ ہوتے ہیں اور تجسس نہ کرو اور کوئی کسی کی غیبت نہ کرے کیا تم میں سے کوئی اس بات کو پسند کرے گا کہ وہ اپنے مُردہ بھائی کا گوشت کھا ئے؟ اس سے تمہیں کراہت آتی ہے اور اللہ (کی نافرمانی) سے ڈرو بےشک اللہ بڑا توبہ قبول کرنے والا، رحم کرنے والا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxv{اے لوگو! ہم نے تمہیں ایک مرد (آدم(ع)) اور ایک عورت (حوا(ع)) سے پیدا کیا ہے اور پھر تمہیں مختلف خاندانوں اور قبیلوں میں تقسیم کر دیا ہے تاکہ تم ایک دوسرے کو پہچان سکو۔ بےشک اللہ کے نزدیک تم میں سے زیادہ معزز و مکرم وہ ہے جو تم میں سے زیادہ پرہیزگار ہے یقیناً اللہ بڑا جاننے والا ہے، بڑا باخبر ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvi{اعراب (صحرائی عرب) کہتے ہیں کہ ہم ایمان لائے ہیں ان سے کہئے کہ تم ایمان نہیں لائے بلکہ یوں کہو کہ ہم اسلام لائے ہیں اور ایمان تو ابھی تمہارے دلوں میں داخل ہوا ہی نہیں ہے اور اگر تم اللہ اور اس کے رسول(ص) کی اطاعت کرو گے تو وہ (اللہ) تمہارے اعمال سے کچھ بھی کمی نہیں کرے گا۔ بےشک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvii{مؤمن تو پس وہی ہیں جو اللہ اور اس کے رسول پر ایمان لائے اور پھر کبھی شک نہیں کیا اور اپنے مالوں اور جانوں کے ساتھ اللہ کی راہ میں جہاد (بھی) کیا یہی لوگ سچے ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxviii{آپ(ص) کہہ دیجئے کہ کیا تم اللہ کو اپنے دین سے آگاہ کرتے ہو؟ حالانکہ اللہ وہ کچھ جانتا ہے جو آسمانوں میں ہے اور جو زمین میں ہے اللہ ہر شے کو جانتا ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxix{(اے رسول(ص)) یہ لوگ اسلام لا کر آپ(ص) پر احسان جتاتے ہیں کہئے تم اپنے اسلام کا مجھ پر احسان نہ جتاؤ بلکہ تم پر اللہ کا احسان ہے کہ اس نے تمیں ایمان لانے کی ہدایت (توفیق) دی اگر تم (اپنے دعوائے ایمان میں) سچے ہو۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxx{بےشک اللہ آسمانوں اور زمین کے سب غیب جانتا ہے اور تم جو کچھ کر رہے ہواللہ وہ سب کچھ خوب دیکھ رہا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxi{\basmalahur ق۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxii{قَسم ہے باعظمت قرآن کی (پیغمبرِ اسلام (ص) میرے سچے رسول ہیں) لیکن ان لوگوں کو اس بات پر تعجب ہے کہ انہی میں سے ایک ڈرانے والا (رسول) ان کے پاسایا ہے تو کافر کہتے ہیں کہ یہ ایک عجیب چیز ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiii{کیا جب ہم مر جائیں گے اور مٹی ہو جائیں گے (تو دوبارہ زندہ ہوں گے) یہ تو بڑی بعید (از عقل) بات ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiv{ہم خوب جانتے ہیں (ان اجزاء کو) جو زمین (کھا کر) ان میں سے کم کرتی ہے اور ہمارے پاس تو ایک ایسی کتاب ہے جس میں (سب کچھ) محفوظ ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxv{بلکہ (دراصل بات تو یہ ہے کہ) انہوں نے (دینِ) حق کو جھٹلایا جبکہ وہ ان کے پاسایا پس وہ ایک الجھی ہوئی بات میں مبتلا ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvi{کیا انہوں نے آسمان کی طرف نہیں دیکھا جو ان کے اوپر ہے کہ ہم نے اسے کس طرح بنایا ہے؟ اور آراستہ کیا ہے جس میں کوئی رخنہ نہیں ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvii{اور ہم نے زمین کو پھیلایا اور اس میں پہاڑ گاڑ دئیے اور اس میں ہر قِسم کی خوشنما چیزیں اگائیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxviii{ہر اس بندے کی بصیرت اور یاددہانی کے لئے جو اپنے رب کی طرف رجوع کرنے والا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxix{اور ہم نے آسمان سے برکت والا پانی اتارا اور اس سے باغات اور کاٹے جانے والی کھیتی کا غلہ اگایا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxl{اور کھجور کے بلند وبالا درخت جن میں تہہ بہ تہہ خوشے لگتے ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxli{بندوں کی روزی کے لئے اور ہم اس مردہ زمین کو زندہ کرتے ہیں اسی طرح (مردوں کا) زمین سے نکلنا ہوگا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlii{ان سے پہلے نوح(ع) کی قوم، اصحابِ رس اور ثمود نے جھٹلایا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliii{نیز عاد، فرعون، لوط(ع) کے بھائی۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliv{اور ایکہ والے اور تبع کی قوم ان سب نے پیغمبروں(ع) کو جھٹلایا آخر میری وعید کے مستحق ہو ئے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlv{کیا ہم پہلی بار کی پیدائش سے تھک گئے ہیں؟ (ایسا نہیں ہے) بلکہ یہ لوگ ازسرِنو پیدائش کے بارے میں شبہ میں مبتلا ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvi{بےشک ہم نے انسان کو پیدا کیا ہے اور ہم وہ وسوسے جانتے ہیں جو اس کا نفس ڈالتا ہے اور ہم اس کی شہ رگ (حیات) سے بھی زیادہ اس کے قریب ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvii{جبکہ دو اخذ کرنے والے (کراماً کاتبین) ایک دائیں جانب بیٹھا ہے اور دوسرا بائیں جانب (اور ہر چیز کو لکھ رہے ہیں)۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlviii{وہ کوئی لفظ بھی نہیں بولتا مگر یہ کہ اس کے پاس نگران تیار موجود ہوتا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlix{اور موت کی بےہوشی حق کے ساتھ آپہنچی۔ یہی وہ چیز ہے جس سے تو گریز کرتا رہتا تھا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcl{اور صور پھونکا جائے گا یہی وعید کا دن ہوگا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcli{اور ہر شخص اس طرح آئے گا کہ اس کے ساتھ ہانکنے والا اور ایک گواہ ہوگا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdclii{اے غا فل) تو اس دن سے غفلت میں رہا تو (آج) ہم نے تیری آنکھوں سے تیرا پردہ ہٹا دیا سو آج تیری نگاہ بڑی تیز ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliii{اور اس کا (زندگی بھر کا) ساتھی کہے گا کہ جو میرے پاس تھا وہ حاضر ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliv{تم دونوں جہنم میں جھونک دو ہر بڑے کافر کو جو(حق سے) عناد رکھتا تھا۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdclv{جو نیکی و خیرات سے بڑا روکنے والا، حد سے بڑھنے والا اور شک کرنے والا اور دوسروں کو شک میں ڈالنے والا تھا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvi{جس نے اللہ کے ساتھ اوروں کو بھی خدا بنا رکھا تھا۔ پس اس کو سخت عذاب میں جھونک دو۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvii{اس کا ساتھی (شیطان) کہے گا اے ہمارے پروردگار! میں نے تو اسے سرکش نہیں بنایا تھا مگر وہ خود ہی سخت گمراہی میں تھا۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdclviii{ارشاد ہوگا میرے سامنے جھگڑا نہ کرو اور میں نے تو تمہیں پہلے عذاب سے ڈرایا تھا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdclix{میرے ہاں بات بدلی نہیں جاتی اور نہ ہی میں بندوں پر ظلم کرنے والا ہوں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdclx{وہ دن یاد کرو جس دن ہم جہنم سے کہیں گے کیا تو بھر گئی ہے؟ اور وہ کہے گی کیا کچھ اور بھی ہے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxi{اور جنت پرہیزگاروں کے قریب کر دی جائے گی اور دور نہیں ہوگی۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxii{یہ (جنت) وہ ہے جس کا تم سے وعدہ کیا جاتا تھا (تم میں سے) ہر اس شخص کے لئے جو اللہ کی طرف رجوع کرنے والا (اور حدودِ الٰہی) کی بڑی حفاظت کرنے والا ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiii{جو بِن دیکھے خدائے رحمٰن سے ڈرتا ہے اور ایسے دل کے ساتھایا ہے جو (خدا کی طرف) رجوع کرنے والا ہے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiv{تم اس(جنت) میں سلامتی کے ساتھ داخل ہو جاؤ یہ (حیاتِ) ابدی کا دن ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxv{وہاں ان کیلئے وہ سب کچھ ہوگا جو وہ چاہیں گے اور ہمارے پاس تو (ان کے لئے) اور بھی زیادہ ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvi{اور ہم (کفارِ مکہ) سے پہلے کتنی ہی قوموں کو ہلاک کر چکے ہیں جو قوت و طاقت میں ان سے زیادہ طاقتور تھیں وہ (مختلف) شہروں میں گھو متے پھرتے تھے تو ان کو کوئی جائے پناہ ملی؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvii{اس میں بڑی عبرت و نصیحت ہے اس کے لئے جس کے پاس دل ہویا حضورِ قلب سے کان لگائے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxviii{بےشک ہم نے آسمانوں اور زمین کو اور جو کچھ ان کے درمیان ہے کو چھ دن میں پیدا کیا ہے اور ہم کو تھکان نے چھوا تک نہیں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxix{وہ لوگ جو کچھ کہتے ہیں اس پر صبر کیجئے اور سورج کے طلوع و غروب سے پہلے اپنے پروردگار کی حمد کے ساتھ تسبیح کیجئے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxx{اور رات کے کچھ حصے میں اس کی تسبیح کیجئے اور (نمازوں کا) سجدہ کرنے کے بعد بھی۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxi{اور غور سے سنو اس دن کا حال جب ایک منادی بہت قریب سے ندا دے گا۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxii{جس دن سب لوگ ایک زوردار آواز کو بالیقین سنیں گے وہی دن (قبروں سے) نکلنے کا ہوگا۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiii{یقیناً ہم ہی جِلاتے ہیں ہم ہی مارتے ہیں اور ہماری ہی طرف سب کی بازگشت ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiv{اس دن زمین ان پر پھٹ جائے گی اور وہ تیز تیز برآمد ہوں گے یہ حشر (جمع کرنا) ہمارے لئے بالکل آسان ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxv{جو کچھ لوگ کہتے ہیں ہم خوب جانتے ہیں اور آپ(ص) ان پر جبر کرنے والے نہیں ہیں پس آپ(ص) قرآن کے ذریعہ سے اسے نصیحت کریں جو میری تہدید سے ڈرے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvi{\basmalahur قَسم ہے ان (ہواؤں) کی جو گرد و غبار اڑاتی ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvii{پھر ان (بادلوں) کی جو پانی کا بوجھ اٹھانے والے ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxviii{پھر ان (کشتیوں) کی جو دھیمی رفتار سے چلنے والی ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxix{پھر ان (فرشتوں کی) جو معاملہ کے تقسیم کرنے والے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxx{بےشک تم سے جو وعدہ کیا گیا ہے وہ سچا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxi{اور بےشک جزا وسزا ضرور واقع ہو نے والی ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxii{اور قَسم ہے راستوں والے آسمان کی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiii{تم مختلف (بےجوڑ) باتوں میں پڑے ہوئے ہو۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiv{اس (دین) سے پھرتا وہی ہے جو (حق سے) پھرا ہوا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxv{غارت ہوں اٹکل پچو باتیں بنانے والے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvi{جو غفلت کے عالم میں مدہوش ہیں (بھولے پڑے ہیں)۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvii{وہ پوچھتے ہیں کہ جزا و سزا کا دن کب آئے گا؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxviii{جس دن یہ لوگ آگ میں تپائے جائیں گے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxix{اور) ان سے کہا جائے گا کہ اپنے فتنہ کا مزا چکھو یہی وہ عذاب ہے جس کی تم جلدی کیا کرتے تھے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxc{بےشک پرہیزگار لوگ بہشتوں اور باغوں میں ہوں گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxci{اور ان کا پروردگار جو کچھ انہیں عطا کرے گا وہلے رہے ہوں گے بےشک وہ اس (دن) سے پہلے ہی (دنیا میں) نیکوکار تھے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcii{یہ لوگ رات کو بہت کم سویا کرتے تھے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciii{اور صبح سحر کے وقت مغفرت طلب کیا کرتے تھے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciv{اور ان کے مالوں میں سے سوال کرنے والے اور سوال نہ کرنے والے محتاج سب کا حصہ تھا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcv{اور زمین میں یقین کرنے والوں کے لئے (ہماری قدرت کی) نشانیاں ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvi{اور خود تمہارے وجود کے اندر بھی۔ کیا تم دیکھتے نہیں ہو؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvii{اور آسمان میں تمہاری روزی بھی ہے اور وہ چیز بھی جس کا تم سے وعدہ وعید کیا جاتا ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcviii{پس قَسم ہے آسمان و زمین کے پروردگار کی کہ یہ بات حق ہے جیسے کہ تم بو لتے ہو۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcix{(اے حبیب(ص)!) کیا آپ تک ابراہیم (‌ع) کے معزز مہمانوں کی بات پہنچی ہے؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcc{کہ جب وہ آپ(ع) کے پاس آئے تو سلام کیا آپ(ع) نے بھی (جواب میں) سلام کیا۔ (پھر دل میں کہا) کچھ اجنبی لوگ ہیں۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcci{پس چپکے سے اپنے گھر والوں کے پاس گئے اور (تھوڑی دیر میں) ایک موٹا تازہ (بھنا ہوا) بچھڑالے آئے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccii{جسے مہمانوں کے سامنے پیش کیا (مگر جب انہوں نے ہاتھ نہ بڑھائے تو) کہا آپ کھاتے کیوں نہیں؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciii{(مگر جب انہوں نے پھر بھی کچھ نہ کھایا) تو آپ(ع) نے ان لوگوں سے اپنے اندر کچھ خوف محسوس کیا ان (مہمانوں نے) کہا ڈرئیے نہیں! اور پھر انہیں ایک صاحبِ علم بیٹے کی ولادت کی خوشخبری دی۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciv{پس آپ(ع) کی بیوی (سارہ) چیختی ہوئی آئی اور اس نے اپنا منہ پیٹ لیا اور کہا بوڑھی، بانجھ؟ (بچہ کس طرح ہوگا؟)\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccv{انہوں نے کہا! تمہارے پروردگار نے ایسا ہی کہا ہے بےشک وہ بڑا علیم و حکیم ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvi{آپ (ابراہیم(ع)) نے کہا اے فرستادو آخر تمہاری مہم کیا ہے؟\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvii{انہوں نے کہا کہ ہم ایک مجرم قوم (قومِ لوط(ع)) کی طرف بھیجے گئے ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccviii{تاکہ ہم ان پر ایسے سنگ گل (سخت مٹی کے پتھر) برسائیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccix{جو آپ(ع) کے پروردگار کی طرف سے نشان زدہ ہیں حد سے بڑھنے والوں کیلئے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccx{سو وہاں جتنے اہلِ ایمان تھے ہم نے ان کو نکال لیا۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxi{اور ہم نے ایک گھر کے سوا اور مسلمانوں کا کوئی گھر نہ پایا۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxii{اور ہم نے اس (واقعہ) میں ایک نشانی چھوڑ دی ہے ان لوگوں کے لئے جو دردناک عذاب سے ڈرتے ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiii{اور جنابِ موسیٰ (ع) کے قصہ میں بھی (ایک نشانی ہے) جبکہ ہم نے ان کو فرعون کے پاس ایک واضح سند کے ساتھ بھیجا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiv{تو اس نے اپنی طاقت کے بِرتے پر رُوگردانی کی اور کہا کہ (یہ شخص) جادوگر ہےیا دیوانہ؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxv{انجامِ کار ہم نے اسے اور اس کے لشکر کو پکڑا اور سب کو سمندر میں پھینک دیا درآنحالیکہ وہ قابلِ ملامت تھا۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvi{اور قبیلۂ عاد (کی داستان) میں بھی (نشانی موجود ہے) جبکہ ہم نے ان پر ایک ایسی بےبرکت ہوا بھیجی۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvii{جو جس چیز سے بھی گزرتی تھی اسے ریزہ ریزہ کر دیتی تھی۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxviii{اور قبیلۂ ثمود کی سرگزشت میں بھی (ایک نشانی ہے) جبکہ ان سے کہا گیا کہ تم ایک خاص وقت تک (دنیا کی نعمتوں) سے فائدہ اٹھا لو۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxix{تو انہوں نے اپنے پروردگار کے حکم سے سرکشی کی تو ان کو ایک کڑک نے پکڑ لیا درآنحالیکہ وہ دیکھ رہے تھے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxx{(اس کے بعد) وہ نہ تو کھڑے ہی ہو سکے اور نہ ہی اپنی کوئی مدافعت کر سکے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxi{اور قومِ نوح(ع) کا بھی اس سے پہلے (یہی حال ہوا) ہم نے اسے ہلاک کر دیا کیونکہ وہ بڑے نافرمان لوگ تھے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxii{اور ہم نے آسمان کو (اپنی) قدرت سے بنایا اور بیشک ہم زیادہ وسعت دینے والے ہیں۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiii{اور ہم نے زمین کافرش بچھایا تو ہم کتنے اچھے فرش بچھانے والے ہیں۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiv{اور ہم نے ہر چیز کے جو ڑے پیدا کئے (ہر چیز کو دو دو قِسم کابنایا) تاکہ تم نصیحت حاصل کرو۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxv{بس تم اللہ کی طرف دوڑو۔ میں تمہیں اس سے کھلا ہوا ڈرانے والا ہوں۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvi{اور اللہ کے ساتھ کوئی اور خدا نہ بناؤ۔ بےشک میں تمہیں اس (کے قہر) سے کھلا ہوا ڈرانے والا ہوں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvii{اسی طرح وہ لوگ جو ان سے پہلے گزرے ہیں (ان کے پاس) کوئی ایسا رسول نہیںایا جسے انہوں نے جادوگریا دیوانہ نہ کہا ہو۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxviii{اور کیا یہ ایک دوسرے کو اس بات کی وصیت کرتے آرہے ہیں؟ (نہیں) بلکہ یہ لوگ سرکش ہیں۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxix{سو آپ(ص) ان سے منہ پھیر لیجئے آپ پر کوئی الزام نہیں ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxx{اور انہیں سمجھاتے رہیے کہ یہ یاددہانی ایمان والوں کو فائدہ پہنچاتی ہے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxi{اور میں نے جِنوں اور انسانوں کو پیدا نہیں کیا مگر اس لئے کہ وہ میری عبادت کریں۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxii{میں ان سے روزی نہیں چاہتا اور نہ یہ چاہتا ہوں کہ وہ مجھے کھلائیں۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiii{بےشک اللہ بڑا روزی دینے والا ہے، قوت والا (اور) بڑا مضبوط ہے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiv{جو لوگ ظالم ہیں ان کیلئے (عذاب کا) وہی حصہ ہے جیسا ان جیسوں کا تھا۔ پس وہ جلدی نہ کریں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxv{انجامِ کار تباہی ہے کافروں کے لئے اس دن سے جس کا ان سے وعدہ وعید کیا جا رہاہے۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvi{\basmalahur قَسم ہے طور کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvii{اور ایک کتاب کی جو لکھی ہوئی ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxviii{کھلے ورق میں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxix{اور قَسم ہے اس گھر کی جو آباد ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxl{اور اس چھت کی جو بلند ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxli{اور اس سمندر کی جو موجزن ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlii{بےشک تمہارے پروردگار کا عذاب واقع ہونے والا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliii{جس کو ٹالنے والا کوئی نہیں ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliv{جس دن آسمان تھرتھرانے لگے گا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlv{اور پہاڑ چلنے لگیں گے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvi{پس تباہی ہوگی اس دن جھٹلانے والوں کیلئے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvii{جو بےہودہ اور فضول باتوں میں کھیل رہے ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlviii{جس دن ان کو دھکیل دھکیل کر آتشِ دوزخ کی طرف لایا جائے گا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlix{یہی ہے وہ آگ جسے تم جھٹلاتے تھے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccl{کیا یہ(آگ) جادو ہے؟ یا تمہیں نظر نہیں آتا؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccli{پس اس میں داخل ہو جاؤ! اب تم صبر کرویا نہ کرو دونوں تمہارے حق میں برابر ہیں تمہیں ویسا ہی بدلہ دیا جائے گا جیسا تم کیا کرتے تھے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclii{بےشک پرہیزگار لوگ باغہائے بہشت اور نعمتوں میں ہوں گے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliii{وہ خوش و خرم ہوں گے ان نعمتوں سے جو ان کا پروردگار انہیں عطا فر مائے گا اور ان کا پروردگار انہیں دوزخ کے عذاب سے بچائے گا۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliv{(ارشاد ہوگا) کھاؤ اور پیؤ مبارک ہو! ان اعمال کے صلہ میں جو تم کرتے تھے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclv{وہ بچھے ہوئے پلنگوں پر تکیہ لگائے ہوئے ہوں گے اور ہم ان کی حور العین (یعنی گوری رنگت کی کشادہ چشم عورتوں) سے شادی کر دیں گے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvi{اور جو لوگ ایمان لائے اور ان کی اولاد نے بھی ایمان کے ساتھ ان کی اتباع (پیروی) کی تو ہم ان کی اولاد کو (جنت میں) ان کے ساتھ ملا دیں گے اور ان کے اعمال میں کچھ بھی کمی نہیں کریں گے ہر شخص اپنے عمل کے بدلے میں گروی ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvii{اور ہم انہیں پسند کے میوے اور گوشت دیتے رہیں گے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclviii{اور وہ وہاں ایسے جامِ شراب پر چھینا جھپٹی بھی کریں گے جس میں نہ کوئی لغو بات ہوگی اور نہ گنہگار ٹھہرانے کی۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclix{اور ان کے غلام (خدمت کیلئے) چکر لگا رہے ہوں گے (جو حُسن و جمال میں) گویا چھپے ہوئے موتی ہوں گے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclx{وہ (جنتی) ایک دوسرے کی طرف متوجہ ہو کر باہم سوال و جواب کریں گے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxi{وہ کہیں گے کہ ہم اس سے پہلے اپنے گھر بار میں (اپنے انجام سے) ڈرتے رہتے تھے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxii{پس اللہ نے ہم پر (اپنا) فضل و کرم فرمایا اور ہمیں گرم لو کے عذاب سے بچا لیا۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiii{بےشک ہم اس سے پہلے (دنیا میں) بھی اسی سے دعا مانگا کرتے تھے یقیناً وہ بڑا احسان کرنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiv{آپ(ص) یاددہانی کرتے رہیے! کہ آپ اپنے پروردگار کے فضل و کرم سے نہ کاہن ہیں اور نہ مجنون۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxv{کیا وہ یہ کہتے ہیں کہ یہ ایک شاعر ہیں (اور) ہم ان کے بارے میں گردشِ زمانہ کا انتظار کر رہے ہیں؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvi{آپ کہئے! کہ تم انتظار کرو میں بھی تمہارے ساتھ انتظار کرنے والوں میں سے ہوں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvii{کیا ان کی عقلیں ان کو ان (فضول) باتوں کا حُکم دیتی ہیںیا یہ سرکش لوگ ہیں؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxviii{یا وہ یہ کہتے ہیں کہ انہوں (رسول(ص)) نے خود قرآن گھڑ لیا ہے بلکہ (اصل بات یہ ہے کہ) وہ ایمان لانا ہی نہیں چاہتے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxix{اگر وہ سچے ہیں تو پھر ایسا کلاملے آئیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxx{آیا وہ بغیر کسی (خالق) کے پیدا کئے گئے ہیںیا وہ خود (اپنے) پیدا کرنے والے ہیں؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxi{یا انہوں نے آسمانوں اور زمین کو پیدا کیا ہے؟ بلکہ وہ یقین ہی نہیں رکھتے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxii{یا ان کے پاس آپ(ص) کے پروردگار کے خزانے ہیںیا یہ ان پر حاکم (مجاز) ہیں؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiii{یا ان کے پاس کوئی سیڑھی ہے (جس پر چڑھ کر) وہ (آسمانی خفیہ باتیں) سن لیتے ہیں؟ (اگر ایسا ہے) تو پھر ان کا سننے والا کوئی کھلی ہوئی دلیل پیش کرے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiv{کیا اللہ کے لئے بیٹیاں ہیں اور تمہارے لئے بیٹے؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxv{کیا آپ ان سے کوئی اجرت مانگتے ہیں کہ وہ تاوان کے بوجھ سے دبےجا رہے رہیں؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvi{یاان کے پاس غیب کا علم ہے کہ وہ (اس کی بناء پر) لکھتے جاتے ہیں؟\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvii{یا وہ کوئی چال چلنا چاہتے ہیں؟ تو جو لوگ کافر ہیں وہ خود اپنی چال کا شکار ہیں۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxviii{یا اللہ کے سوا ان کا کوئی اور خدا ہے؟ پاک ہے اللہ اس شرک سے جو وہ کرتے ہیں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxix{اور اگر وہ آسمان سے کوئی ٹکڑا گرتا ہوا دیکھیں تو کہتے ہیں کہ یہ تہہ در تہہ بادل ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxx{پس انہیں (اپنے حال پر) چھوڑ دیجئے یہاں تک کہ وہ اپنے اس دن تک پہنچ جائیں جس میں وہ غش کھا کر گر جائیں گے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxi{جس دن ان کی کوئی چال ان کے کسی کام نہ آئے گی اور نہ ہی ان کی کوئی مدد کی جائے گی۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxii{بےشک جو لوگ ظالم ہیں ان کیلئے اس سے پہلے (دنیا میں) بھی ایک عذاب ہے لیکن ان میں سے اکثر جانتے نہیں ہیں۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiii{آپ(ص) اپنے پروردگار کے فیصلے کیلئے صبر کیجئے! آپ(ص) ہماری نظروں (نگہبانی) میں ہیں آپ(ص) اپنے پروردگار کی تسبیح کیجئے اس کی حمد کے ساتھ۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiv{جس وقت آپ(ص) اٹھتے ہیں اوررات کے کچھ حصہ میں بھی اس کی تسبیح کریں اور ستاروں کے پیچھے ہٹتے وقت بھی۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxv{\basmalahur قَسم ہے ستارے کی جبکہ وہ ڈوبنے لگے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvi{کہ تمہارا یہ ساتھی (پیغمبرِ اسلام(ص)) نہ گمراہ ہوا ہے اور نہ بہکا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvii{اور وہ (اپنی) خواہشِ نفس سے بات نہیں کرتا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxviii{وہ تو بس وحی ہے جو ان کی طرف کی جاتی ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxix{ان کو ایک زبردست قوت والے نے تعلیم دی ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxc{جو بڑا صاحبِ قدرت (یا بڑا دانا و حکیم) ہے پھر (وہ اپنی اصلی شکل میں) کھڑا ہوا۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxci{جبکہ وہ آسمان کے بلند ترین کنارہ پر تھا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcii{پھر وہ قریب ہوا اور زیادہ قریب ہوا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciii{یہاں تک دو کمان کے برابریا اس سے بھی کم فاصلہ رہ گیا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciv{پس اس (اللہ) نے اپنے بندہ (خاص) کی طرف وحی کی جو وحی کی۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcv{(رسول(ص) کے) دل نے جھوٹ نہیں کہا (جھٹلایا نہیں) جو کچھ (مصطفٰی(ص) کی) آنکھ نے دیکھا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvi{کیا تم لوگ آپ(ص) سے اس بات پر جھگڑتے ہو جو کچھ انہوں نے دیکھا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvii{اور آپ(ص) نے ایک بار اور بھی۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcviii{اترتے ہوئے سدرۃ المنتہی کے پاس دیکھا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcix{جہاں جنت الماوی (آرام سے رہنے کا بہشت) ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccc{جب کہ سدرہ پر چھا رہا تھا (وہ نور) جو چھا رہا تھا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccci{نہ آنکھ چندھیائی اور نہ حدسے بڑھی۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccii{یقیناً آپ(ص) نے اپنے پروردگار کی بڑی بڑی نشانیاں دیکھیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciii{کیا تم نے کبھی لات و عزیٰ۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciv{اور تیسرے منات کو کبھی دیکھا ہے (ان کی اصلیت میں غور کیا ہے؟)\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccv{کیا تمہارے لئے لڑکے ہیں اور اس(اللہ) کے لئے لڑکیاں؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvi{یہ تقسیم تو بڑی ظالمانہ ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvii{یہ نہیں ہیں مگر صرف چند نام جو تم نے اور تمہارے باپ دادانے رکھ لئے ہیں جس پر اللہ نے کوئی دلیل (سند) نہیں نازل کی یہ لوگ محض وہم و گمان کی پیروی کر رہے ہیں اور خواہشاتِ نفس کی حالانکہ ان کے پاس ان کے پروردگار کی طرف سے ہدایت و رہنمائی آچکی۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccviii{کیا انسان کو وہ چیز مل سکتی ہے جس کی وہ تمنا کرتا ہے؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccix{پس اللہ کے قبضۂ قدرت میں ہے آخرت بھی اور دنیا بھی (یعنی انجام بھی اور آغاز بھی)۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccx{اور آسمانوں میں کتنے ہی فرشتے ہیں جن کی سفارش کچھ بھی فائدہ نہیں دے سکتی مگر بعد اس کے کہ اللہ جس کے لئے چاہے اجازت دے اور پسند کرے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxi{بےشک جو لوگ آخرت پر ایمان نہیں رکھتے وہ فرشتوں کو عورتوں کے نام سے موسوم کرتے ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxii{حالانکہ انہیں اس کا کوئی علم نہیں ہے وہ مخصوص ظن و گمان کی پیروی کرتے ہیں اور ظنِ حق کے مقابلہ میں ذرا بھی کام نہیں دے سکتا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiii{(اے رسول(ص)) آپ اس سے رُوگردانی کیجئے! جو ہمارے ذکر سے رُوگردانی کرتا ہے اور جو زندگانئ دنیا کے سوا اور کچھ نہیں چاہتا۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiv{ان لوگوں کامبلغ علم یہی ہے (ان کے علم کی رسائی کی حد یہی ہے) آپ(ص) کا پروردگار ہی بہتر جانتا ہے کہ اس کے راستہ سے بھٹکا ہوا کون ہے؟ اور وہی بہتر جانتا ہے کہ راہِ راست پر کون ہے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxv{اور جو آسمانوں میں ہے اور جو کچھ زمین میں ہے وہ اللہ ہی کا ہے تاکہ وہ برا کام کرنے والوں کو ان کے (برے) کاموں کا بدلہ دے اور نیک کرنے والوں کو اچھی جزا عطا کرے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvi{جو کہ بڑے گناہوں اور بےحیائی کے کاموں سے پرہیز کرتے ہیں مگر یہ کہ کچھ ہلکے گناہ سر زد ہو جائیں۔ بےشک آپ کا پروردگار وسیع مغفرت والا ہے وہ تمہیں (اس وقت سے) خوب جانتا ہے جب اس نے تمہیں زمین سے پیدا کیا اور جب تم اپنی ماؤں کے پیٹوں میں جنین کی صورت میں تھے پس تم اپنے آپ کی پاکی کے دعوے نہ کرو۔ وہ (اللہ) بہتر جانتا ہے کہ واقعی پرہیزگار کون ہے؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvii{(اے رسول(ص)) کیا آپ(ص) نے اس شخص کو دیکھا ہے جس نے رُوگردانی کی۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxviii{اس نے تھوڑا سا (مال) دیا اور پھر ہاتھ روک لیا۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxix{کیا اس کے پاس غیب کا علم ہے پس وہ دیکھ رہا ہے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxx{کیا اسے اس بات کی خبر نہیں پہنچی جو موسیٰ (ع) کے صحیفوں میں ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxi{اور اس ابراہیم (ع) کے صحیفوں میں جس نے وفاداری کا حق ادا کر دیا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxii{کہ کوئی بوجھ اٹھانے والا کسی دوسرے کا بوجھ نہیں اٹھائے گا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiii{اور یہ کہ انسان کے لئے وہی کچھ ہے جس کی وہ کوشش کرتا ہے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiv{اور اس کی سعی و کوشش عنقریب دیکھی جائے گی۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxv{اور پھر اسے پوری جزا دی جائے گی۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvi{اور یہ کہ سب کی انتہا آپ(ص) کے پروردگار کی طرف ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvii{بےشک وہی ہنساتا ہے اور رلاتا ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxviii{اور وہی مارتا ہے اور جِلاتا ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxix{اور یہ کہ اسی نے نر اور مادہ کے جوڑے پیدا کئے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxx{(وہ بھی) ایک نطفہ سے (جو رحم میں) ٹپکایا جاتا ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxi{اور بیشک دوبارہ پیدا کرنا اسی (اللہ) کے ذمہ ہے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxii{اور یہ کہ وہی سرمایہ دار بناتا ہے اور وہی فقیر و نادار بناتا ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiii{اور یہ کہ وہ شعریٰ نامی ستارے کا پروردگار ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiv{اور یہ کہ اسی نے عادِ اول (قومِ ہود) کو ہلاک کیا۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxv{اور ثمود کو بھی اس طرح ہلاک کیا کہ کسی کو باقی نہیں چھوڑا۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvi{اوران سب سے پہلے قومِ نوح(ع) کو بھی (برباد کیا) بےشک وہ بڑے ظالم اور بڑے سرکش تھے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvii{(لوط (ع)) کی الٹی ہوئی ان (بستیوں) کو بھی دے مارا۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxviii{پس ان (بستیوں) کو ڈھانک لیا اس (آفت) نے جس نے ڈھانک لیا۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxix{پس تو اے مخاطب اپنے پروردگار کی کن کن نعمتوں میں شک کرے گا۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxl{یہ (رسول(ص)) بھی ڈرانے والا ہے پہلے ڈرانے والے (رسولوں(ع)) سے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxli{قریب آنے والی (قیامت) قریب آگئی ہے۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlii{اللہ کے سوا اس کا کوئی ہٹانے والانہیں ہے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliii{کیا تم اس بات سے تعجب کرتے ہو؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliv{اور ہنستے ہو اور روتے نہیں۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlv{اور تم غفلت میں مدہوش ہو۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvi{پس اللہ کے لئے سجدہ کرو اور(اسی کی) عبادت کرو۔\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvii{\basmalahur (قیامت کی) گھڑی قریب آگئی اور چاند پھٹ گیا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlviii{اور اگر وہ کوئی نشانی (معجزہ) دیکھتے ہیں تو منہ پھیر لیتے ہیں اور کہتے ہیں کہ یہ تو مستقل جادو ہے (جو پہلے سے چلا آرہا ہے)۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlix{اور انہوں نے (رسول(ص) کو) جھٹلایا اور اپنی خواہشات کی پیروی کی اور ہر کام کا وقت مقرر ہے اور ثابت ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccl{اور ان کے پاس ایسی (سابقہ قوموں کی) ایسی خبریں آچکی ہیں جن میں (سرکشی کرنے والوں کیلئے) کافی سامانِ عبرت ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccli{یعنی نہایت اعلیٰ حکمت اور دانشمندی مگر تنبیہات (ان کو) کوئی فائدہ نہیں دیتیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclii{(اے رسول(ص)) ان لوگوں سے رخ پھیر لیجئے جس دن ایک پکارنے والا ایک سخت ناگوار چیز کی طرف بلائے گا۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliii{(شدتِ خوف سے) آنکھیں جھکائے ہوئے قبروں سے یوں نکل پڑیں گے کہ گویا بکھری ہوئی ہڈیاں ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliv{(دہشت سے) گردنیں بڑھائے پکارنے والے کی طرف دوڑتے جا رہے ہوں گے (اس دن) کافر کہیں گے کہ یہ بڑا دشوار دن ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclv{ان سے پہلے قومِ نوح(ع) نے جھٹلایا سو انہوں نے ہمارے بندۂ خاص کو جھٹلایا اور ان پر جھوٹا ہو نے کا الزام لگایا اور اسے جھڑکا بھی گیا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvi{آخر کار اس (نوح(ع)) نے اپنے پروردگار کو پکارا کہ میں مغلوب ہوں۔ لہٰذا تو (ان سے) بدلہلے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvii{پس ہم نے موسلادھار بارش کے ساتھ آسمان کے دروازے کھول دئیے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclviii{اور ہم نے زمین سے چشمے جاری کر دئیے پس (دونوں) پانی آپس میں مل گئے ایک کام کیلئے جو مقدر ہو چکا تھا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclix{اور ہم نے اس (نوح(ع)) کو تختوں اور میخوں والی (کشتی) پر سوار کیا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclx{جو ہماری آنکھوں کے سا منے (ہماری نگرانی میں) چلتی تھی اور (یہ سب کچھ) اس شخص (نوح(ع)) کا بدلہ لینے کیلئے کیا گیا جس کی ناقدری کی گئی تھی۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxi{اور ہم نے اسکو نشانی کے طور پر باقی رکھا تو کوئی ہے نصیحت قبول کرنے والا؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxii{پس(دیکھو) کیسا تھا میرا عذاب اور میرا ڈراوا؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiii{بیشک ہم نے قرآن کو نصیحت حاصل کرنے کیلئے آسان بنا دیا ہے سو کوئی ہے نصیحت حاصل کرنے والا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiv{قومِ عاد نے بھی (اپنے نبی(ع) کو) جھٹلایا تو دیکھو کیسا تھا میرا عذاب اور میرے ڈراوے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxv{ہم نے ان پر تیز و تند آندھی بھیجی دائمی نحوست والے دن میں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvi{وہ (آندھی) اس طرح آدمیوں کو اکھاڑ پھینکتی تھی کہ گویا وہ جڑ سے اکھڑے ہوئے کھجور کے تنے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvii{پس (دیکھو) کیسا تھا میرا عذاب اور میرے ڈراوے؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxviii{بلاشبہ ہم نے نصیحت حاصل کرنے کیلئے قرآن کو آسان بنا دیا تو کوئی ہے نصیحت حاصل کرنے والا؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxix{قومِ ثمود نے ڈرانے والوں (پیغمبروں(ع)) کو جھٹلایا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxx{پس انہوں نے کہا کہ ہم ایک ایسے شخص کی پیروی کریں جو ہم ہی میں سے ہے؟ اس صو رت میں تو ہم گمراہی اور دیوانگی میں پڑ جائیں گے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxi{کیا ہم سب میں سے صرف اسی پر وحی نازل کی گئی ہے؟ بلکہ وہ بڑا جھوٹا (اور) شیخی باز ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxii{انہیں بہت جلد کل کلاں معلوم ہو جائے گا کہ کون بڑا جھوٹا (اور) شیخی باز ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiii{ہم ایک (خاص) اونٹنی ان کی آزمائش کے لئے بھیج رہے ہیں پس تم (اے صالح(ع) انجامِ کار) انتظار کرو اور صبر کرو۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiv{اور انہیں آگاہ کر دو کہ پانی ان کے درمیان تقسیم ہوگیا ہے اور ہر ایک اپنی باری پر حاضر ہوگا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxv{پس ان لوگوں (یہودیوں) نے اپنے ساتھی (قدار) کو پکارا پس اس نے (اونٹنی کو) پکڑ کر اس کی کونچیں کاٹ دیں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvi{تو کیسا تھا میرا عذاب اورمیرے ڈراوے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvii{ہم نے ان پر ایک ہی چنگھاڑ بھیجی تو وہ باڑھ لگانے والے کی روندی ہوئی باڑہ کی طرح ہو کر رہ گئے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxviii{اور ہم نے نصیحت حاصل کرنے کیلئے قرآن کو آسان بنا دیاتو کوئی ہے نصیحت حاصل کرنے والا؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxix{قومِ لوط(ع) نے ڈرانے والوں کو جھٹلایا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxx{ہم نے ان پر پتھر برسانے والی ہوا بھیجی صرف آلِ لوط(ع) اس سے محفوظ رہے ہم نے سحر کے وقت ان کو نجات دی۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxi{خاص اپنے فضل و کرم سے ہم اسی طرح شکر کرنے والے کو جزا دیتے ہیں۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxii{بلاشبہ انہوں (لوط(ع)) نے انہیں سخت گرفت سے ڈرایا تھا مگر وہ ڈرانے کے بارے میں شک میں مبتلا رہے (اورجھگڑتے رہے)۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiii{اور ان لوگوں نے ان کے مہمانوں کے بارے میں برے ارادہ سے ان پر ڈول ڈالے تو ہم نے ان کی آنکھیں موند دیں تو میرے عذاب اور ڈراوے کا مزہ چکھو۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiv{اور (پھر) صبح سویرے ان پر دائمی عذاب آپہنچا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxv{پس میرے عذاب اور ڈراوے کامزہ چکھو۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvi{بےشک ہم نے قرآن کو نصیحت حاصل کرنے کیلئے آسان بنا دیا ہے کوئی ہے نصیحت حاصل کرنے والا؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvii{اور فرعون والوں کے پاس بھی ڈرانے والے آئے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxviii{تو انہوں نے ہماری ساری نشانیوں کو جھٹلایا تو ہم نے انہیں اس طرح پکڑا جس طرح کوئی زبردست اقتدار والا (طا قتور) پکڑتا ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxix{کیا تمہارے کافر ان لوگوں سے بہتر ہیں یا تمہارے لئے (آسمانی) کتابوں میں معافی کا پروانہ لکھا ہوا ہے؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxc{یا وہ کہتے ہیں کہ ہم ایک ایسی جماعت ہیں جو غالب رہیںگے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxci{عنقریب یہ جماعت شکست کھائے گی اور یہ سب پیٹھ پھیر کر بھاگ جائیں گے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcii{بلکہ ان کے وعدہ کا اصل وقت تو قیامت ہے اور قیامت بڑی سخت (ہولناک) اور بڑی تلخ ہے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciii{بےشک مجرم لوگ گمراہی اور دیوانگی میں مبتلا ہیں۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciv{جس دن یہ لوگ منہ کے بل آگ میں گھسیٹے جائیں گے (کہا جائے گا) اب آگ کا مزہ چکھو۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcv{بےشک ہم نے ہر چیز کو خاص اندازہ سے پیدا کیا ہے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvi{اور ہمارا حکم نہیں ہوتا مگر ایک جو آنکھ جھپکنے میں واقع ہو جاتا ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvii{بےشک ہم تمہارے ہم مشرب لوگوں کو ہلاک کر چکے ہیں تو ہے کوئی نصیحت حاصل کرنے والا؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcviii{اور جو کچھ ان لوگوں نے کیا تھا وہ سب نامۂ اعمال میں درج ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcix{اور ہر چھوٹی اور بڑی بات (اس میں) درج ہے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcm{بےشک پرہیزگار لوگ بہشتوں اور نہروں میں ہوں گے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmi{صداقت و سچائی کے محل میں بڑی عظیم قدرت والے بادشاہ (خدا) کے حضور میں (مقرب ہوں گے)۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmii{\basmalahur خدائے رحمٰن۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiii{نے قرآن کی تعلیم دی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiv{اسی نے انسان کو پیدا کیا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmv{اسی نے اسے بولنا (مافی الضمیر بیان کرنا) سکھایا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvi{سورج اور چاند ایک (خاص) حساب کے پابند ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvii{اور سبزیاں، بیلیں اور درخت (اسی کو) سجدہ کرتے ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmviii{اس نے آسمان کو بلند کیا اور میزان (عدل) رکھ دی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmix{تاکہ تم میزان (تولنے) میں زیادتی نہ کرو۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmx{اور انصاف کے ساتھ ٹھیک طریقہ پر تولو اور وزن (تولنے) میں کمی نہ کرو۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxi{اور اس نے زمین کو تمام مخلوق کیلئے بنایا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxii{اس میں (ہر طرح کے) میوے ہیں اور کھجور کے غلافوں والے درخت ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiii{اور بھوسہ والا اناج بھی اور خوشبودار پھول بھی۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiv{سو (اے جن و انس) تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxv{اس نے انسان کو ٹھیکرے کی طرح کھنکھناتی ہوئی مٹی سے پیدا کیا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvi{اور جنات کو پیدا کیا آگ کے شعلہ سے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvii{سو (اے جن و انس) تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxviii{وہی دونوں مشرقوں کا پروردگار ہے اور وہی دونوں مغربوں کا مالک و پروردگار ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxix{سو (اے جن و انس) تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxx{اسی نے دو دریا جاری کئے جو آپس میں مل رہے ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxi{ان دونوں کے درمیان ایک فاصلہ ہے جس سے وہ تجاوز نہیں کرتے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxii{سو(اے جن و انس) تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiii{ان دونوں دریاؤں سے موتی اور مونگے نکلتے ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiv{سو (اے جن و انس) تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤگے؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxv{اور اسی کے لئے وہ (جہاز) ہیں جو سمندروں میں پہاڑوں کی طرح اٹھے ہوئے ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvi{سو (اے جن و انس) تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvii{جو بھی روئے زمین پر ہیں وہ سب فنا ہونے والے ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxviii{اور آپ(ص) کے پروردگار کی ذات باقی رہے گی جو عظمت و اکرام والی ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxix{تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxx{آسمانوں اور زمین میں جو بھی ہیں اسی سے (اپنی حاجتیں) مانگتے ہیں وہ ہر روز (بلکہ ہر آن) ایک نئی شان میں ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxi{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxii{اے جن وانس ہم عنقریب (تمہاری خبر لینے کیلئے) تمہاری طرف متوجہ ہو نے والے ہیں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiii{تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiv{اے گروہِ جن و انس! اگر تم سے ہو سکے تو تم آسمانوں اور زمین کی حدود سے باہر نکل جاؤ (لیکن) تم طاقت اور زور کے بغیر نہیں نکل سکتے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxv{تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvi{تم دونوں پر آگ کاشعلہ اور دھواں چھوڑا جائے گا پھر تم اپنا بچاؤ نہ کر سکو گے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvii{تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxviii{(اس وقت کیا حالت ہوگی) جب آسمان پھٹ جائے گا اور (رنگے ہوئے) سرخ چمڑے کی طرح لال ہو جائے گا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxix{تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxl{پس اس دن کسی انسان یا جن سے اس کے گناہ کے متعلق سوال نہیں کیا جائے گا۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxli{تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlii{مجرم اپنے چہروں (اپنی علامتوں) سے پہچان لئے جائیں گے اور پھر پیشانیوں اور پاؤں سے پکڑے جائیں گے (اور جہنم میں پھینک دئیے جائیں گے)۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliii{سو تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliv{یہی وہ دوزخ ہے جسے مجرم لوگ جھٹلایا کرتے تھے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlv{وہ (مجرم) اس (دوزخ) اور اس کے انتہائی کھولتے ہوئے پانی کے درمیان گردش کرتے رہیں گے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvi{پس اے جن و انس! سو تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvii{اور جو شخص اپنے پروردگار کی بارگاہ میں حاضری سے ڈرتا ہے اس کے لئے دو باغ ہیں۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlviii{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟ ۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlix{دونوں باغ بہت سی شاخوں والے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcml{پس تم اپنے پروردگار کی کن کن نعمتوں جھٹلاؤگے؟\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcmli{ان دونوں باغوں میں دو چشمے جاری ہوں گے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlii{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliii{ان دونوں باغوں میں ہر پھل کی دو قِسمیں ہوں گی۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliv{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤگے؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlv{وہ ایسے بچھونوں پر تکیہ لگائے بیٹھے ہوں گے جن کے استر دبیز ریشم کے ہوں گے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvi{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvii{اور دونوں باغوں کے تیار پھل (ان کے) بہت ہی نزدیک ہوں گے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlviii{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlix{ان جنتوں میں نیچی نگاہ والی (حوریں) ہوں گی جن کو ان (جنتیوں) سے پہلے نہ کسی انسان نے چھوا ہوگا اور نہ کسی جن نے۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlx{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxi{وہ(حوریں) ایسی ہوں گی جیسے یاقوت اور مرجان۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxii{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤگے؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiii{نیکی کا بدلہ نیکی کے سوا اور کیا ہے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiv{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxv{ان دونوں باغوں کے علاوہ دو باغ اور بھی ہیں۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvi{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvii{دونوں گہرے سبز سیاہی مائل۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxviii{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxix{ان دو باغوں میں دو چشمے ہوں گے جوش مارتے ہوئے۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxx{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxi{ان میں پھل، کھجور اور انار ہوں گے۔\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxii{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤگے؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiii{ان میں اچھی سیرت و صورت والی (حوریں) ہوں گی۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiv{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxv{ان (جنتیوں سے پہلے کسی انسان یا جن نے انہیں چھوا بھی نہیں ہوگا۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvi{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvii{وہ (جنتی لوگ) سبز رنگ کے بچھونوں اور خوبصورت گدوں پر تکیہ لگائے بیٹھے ہوں گے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxviii{پس تم اپنے پروردگار کی کن کن نعمتوں کو جھٹلاؤ گے؟\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxix{بابرکت ہے تمہارے پروردگار کانام جو بڑی عظمت اور کرا مت والا ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxx{\basmalahur جب واقعہ ہو نے والی (قیامت) واقع ہو جائے گی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxi{جس کے واقع ہو نے میں کوئی جھوٹ نہیں ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxii{وہ (کسی کو) پست کرنے والی اور (کسی کو) بلند کرنے والی ہوگی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiii{جب زمین بالکل ہلا ڈالی جائے گی۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiv{اور پہاڑ ٹوٹ کر ریزہ ریزہ ہو جائیں گے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxv{(اور) پراگندہ غبار کی طرح ہو جائیں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvi{اورتم لوگ تین قسم کے ہو جاؤ گے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvii{پس (ایک قِسم) دائیں ہاتھ والوں کی ہوگی وہ دائیں ہاتھ والے کیا اچھے ہیں؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxviii{اور(دوسری قِسم) بائیں ہاتھ والوں کی ہوگی اور بائیں ہاتھ والے کیا برے ہیں؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxix{اور (تیسری قِسم) سبقت کرنے والوں کی ہوگی وہ تو سبقت کرنے والے ہی ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxc{وہی لوگ خاص مقرب (بارگاہ) ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxci{(یہ لوگ) عیش و آرام کے باغوں میں ہوں گے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcii{ان کی بڑی جماعت اگلوں میں سے ہوگی۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciii{اور بہت تھوڑے پچھلوں میں سے ہوں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciv{مرصع تختوں پر تکیہ لگائے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcv{آمنے سامنے بیٹھے ہوں گے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvi{ان کے پاس ایسے غلمان (نوخیز لڑکے) ہوں گے جو ہمیشہ غلمان ہی رہیں گے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvii{(شرابِ طہور سے بھرے ہو ئے) آبخورے، آفتابے اور پاک و صاف شراب کے پیالے (یعنی جام، صراحی سبو و ساغر) لئے گردش کر رہے ہوں گے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcviii{جس سے نہ دردِ سر ہوگا اور نہ عقل میں فتور آئے گا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcix{اور وہ (غلمان) طرح طرح کے پھل پیش کریں گے وہ جسے چاہیں چن لیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmm{اور پرندوں پرندوں کے گوشت بھی جس کی وہ خواہش کریں گے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmi{(اور ان کیلئے) گوری رنگت والی غزال چشم حوریں بھی ہوں گی۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmii{جو چھپا کر رکھے ہوئے موتیوں کی طرح (حسین) ہوں گی۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmiii{یہ سب کچھ ان کے ان اعمال کی جزا ہے جو وہ کیا کرتے تھے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmiv{وہ اس میں کوئی فضول اور گناہ والی بات نہیں سنیں گے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmv{مگر صرف سلام و دعا کی آواز آئے گی۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmvi{اور وہ دائیں ہاتھ والے اور وہ دائیں والے کیا اچھے ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmvii{وہ ایسی بیری کے درختوں میں ہوں گے جن میں کانٹے نہیں ہوں گے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmviii{اورتہہ بہ تہہ کیلوں میں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmix{اور (دور تک) پھیلے ہوئے سایوں میں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmx{اور بہتے ہوئے پانی میں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmxi{اور بہت سے پھلوں میں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmxii{جو نہ کبھی ختم ہوں گے اور نہ کوئی روک ٹوک ہوگی۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiii{اور اونچے بچھونوں پر ہوں گے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiv{ہم نے (حوروں) کو خاص نئے سرے سے پیدا کیا ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmxv{پھر ان کو کنواریاں بنایا ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvi{(اور) پیار کرنے والیاں اور ہم عمر ہیں۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvii{یہ سب نعمتیں دائیں ہاتھ والوں کے لئے ہیں۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmxviii{ایک بڑی جماعت اگلوں میں سے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmxix{اور ایک بڑی جماعت پچھلوں میں سے ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmxx{اور بائیں ہاتھ والے اور کیا برے ہیں بائیں ہاتھ والے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxi{وہ لو کی لپٹ (سخت تپش) اور کھولتے ہوئے پانی۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxii{اور سیاہ دھوئیں کے سایہ میں ہوں گے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiii{جو نہ ٹھنڈا ہوگااور نہ نفع بخش۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiv{(کیونکہ) وہ اس سے پہلے (دنیا میں) خوشحال (اور عیش و عشرت میں) تھے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxv{اور وہ بڑے گناہ پر اصرار کرتے تھے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvi{اور کہتے تھے کہ جب ہم مر جائیں گے اور مٹی اور ہڈیاں ہو جائیں گے تو کیا ہم دوبارہ اٹھائے جائیں گے؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvii{اور کیا ہمارے پہلے باپ دادا بھی (اٹھائے جائیں گے؟)\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxviii{آپ(ص) کہہ دیجئے! کہ بےشک اگلے اور پچھلے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxix{سب ایک دن کے مقرروقت پر اکٹھے کئے جائیں گے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxx{پھر تم اے گمراہو اور جھٹلانے والو۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxi{تم (تلخ ترین درخت) زقوم سے کھاؤ گے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxii{اور اسی سے (اپنے) پیٹ بھرو گے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiii{اور اوپر سے کھولتا ہوا پانی پیو گے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiv{جس طرح سخت پیاسے اونٹ (بےتحاشا) پانی پیتے ہیں۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxv{جزا و سزا کے دن یہ ان کی مہمانی ہوگی۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvi{ہم نے ہی تمہیں پیدا کیا ہے پھر تم (قیامت کی) تصدیق کیوں نہیں کرتے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvii{کیا تم نے کبھی غور کیا ہے کہ جو نطفہ تم ٹپکاتے ہو۔\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxviii{کیا تم اسے(آدمی بنا کر) پیدا کرتے ہو یا ہم پیدا کرنے و الے ہیں۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxix{ہم نے ہی تمہارے درمیان موت (کا نظام) مقرر کیا ہے اور ہم اس سے عاجز نہیں ہیں۔\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmmxl{کہ ہم تمہاری جگہ تم جیسے اور لوگ پیدا کر دیں اور تم کو ایسی صورت میں (یا ایسے عالَم میں) پیدا کر دیں جس کو تم نہیں جانتے۔\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmmxli{اور تم (اپنی) پہلی پیدائش کو تو جانتے ہی ہو پھر نصیحت کیوں نہیں حاصل کرتے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlii{کیا تم نے کبھی غور کیا ہے کہ تم جو کچھ (بیج) بوتے ہو۔\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliii{کیا تم اس کو اگاتے ہو یا ہم اگانے والے ہیں۔\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliv{اگر ہم چاہیں تو اس (پیداوار) کو (خشک کر کے) چُورا چُورا کر دیں تو تم باتیں بناتے رہ جاؤ۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlv{کہ ہم پر تاوان پڑگیا۔\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvi{بلکہ ہم بالکل محروم ہو گئے۔\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvii{کیا تم نے کبھی غور کیا ہے کہ وہ پانی جو تم پیتے ہو۔\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlviii{کیا تم نے اسے بادل سے اتارا ہے یا ہم (اس کے) اتارنے والے ہیں؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlix{اگر ہم چاہتے تو اسے سخت بھاری بنا دیتے پھر تم شکر کیوں نہیں کرتے؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmml{کیا تم نے کبھی غور کیا ہے کہ وہ آگ جو تم سلگاتے ہو۔\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmmli{آیا تم نے اس کا درخت پیدا کیا ہے یا ہم پیدا کرنے والے ہیں۔\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmmlii{ہم نے ہی اسے یاددہانی کا ذریعہ اور مسافروں کیلئے فائدہ کی چیز بنایا ہے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmmliii{پس تم اپنے عظیم پروردگار کے نام کی تسبیح کرو۔\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmmliv{پس میں ستاروں کے (ڈو بنے کے) مقامات کی قَسم کھاتا ہوں۔\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmmlv{اور اگر تم سمجھو تو یہ بہت بڑی قَسم ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvi{بےشک یہ قرآن بڑی عزت والا ہے۔\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvii{نگاہوں سے پوشیدہ ایک کتاب کے اندر ہے۔\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmmlviii{اسے پاک لوگوں کے سوا کوئی نہیں چھو سکتا۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmmlix{یہ تمام جہانوں کے پروردگار کی طرف سے نازل کردہ ہے۔\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmmlx{کیا تم اس کتاب سے بےاعتنائی کرتے ہو؟\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxi{اور تم نے اپنے حصہ کی روزی یہی قرار دی ہے کہ اسے جھٹلاتے ہو۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxii{(اگر تم کسی کے محکوم نہیں) تو جب (مرنے والے کی) روح حلق تک پہنچ جاتی ہے۔\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiii{اور تم اس وقت دیکھ رہے ہوتے ہو۔\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiv{اور اس وقت ہم تم سے زیادہ مرنے والے کے قریب ہوتے ہیں مگر تم دیکھتے نہیں۔\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxv{پس اگر تمہیں کوئی جزا و سزا ملنے والی نہیں ہے۔\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvi{تو پھر اس (روح) کو کیوں واپس لوٹا نہیں لیتے اگر تم (اس انکار میں) سچے ہو۔\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvii{پس اگر وہ (مرنے والا) مقربین میں سے ہے۔\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxviii{تو اس کے لئے راحت، خوشبودار عذاب اور نعمت بھری جنت ہے۔\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxix{اور اگر وہ اصحاب الیمین میں سے ہے (تواس سے کہا جاتا ہے)۔\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxx{تمہارے لئے سلامتی ہو تو اصحاب الیمین میں سے ہے۔\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxi{اور اگر وہ جھٹلانے والے گمراہوں میں سے ہے۔\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxii{تو پھر اس کی مہمانی کھولتے ہوئے پانی سے ہوگی۔\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiii{اور دوزخ کی تپش (اور) اس میں داخلہ ہے۔\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiv{(جو کچھ بیان ہوا) بےشک یہ حق الیقین (قطعی حق) ہے۔\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxv{پس اپنے عظیم پروردگار کے نام کی تسبیح کرو۔\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvi{\basmalahur ہر وہ چیز جو آسمانوں اور زمین میں ہے وہ اللہ کی تسبیح کرتی ہے وہ (ہر چیز پر) غالب (اور) بڑا حکمت والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvii{آسمانوں اور زمین کی سلطنت اسی کے لئے ہے وہی حیات دیتا ہے اور وہی موت دیتا ہے اور وہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxviii{وہی اول ہے اور وہی آخر، وہی ظاہرہے اور وہی باطن اور وہ ہر چیز کا خوب جاننے والا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxix{وہ وہی ہے جس نے آسمانوں اور زمین کو چھ دن میں پیدا کیا پھر عرش پر غالب ہوا (اپنا اقتدار قائم کیا) وہ اسے بھی جانتا ہے جو زمین کے اندر داخل ہوتا ہے اور اسے بھی جو اس سے باہر نکلتا ہے اور اسے بھی جانتا ہے جو کچھ آسمان سے اترتا ہے اور جو کچھ اس کی طرف چڑھتا ہے اور وہ تمہارے ساتھ ہوتا ہے تم جہاں بھی ہو اور تم جو کچھ کرتے ہواللہ اسے دیکھ رہا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxx{آسمانوں اور زمین کی بادشاہت اسی کیلئے ہے اور تمام معاملات کی باز گشت اللہ ہی کی طرف ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxi{وہی رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے اور وہ دلوں کے بھیدوں کو خوب جانتا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxii{اللہ اور اس کے رسول(ص) پر ایمان لاؤ اور اس (مال) میں سے (اس کی راہ میں) خرچ کرو جس میں اس نے تمہیں (دوسروں) کا جانشین بنایا ہے پس جو لوگ تم میں سے ایمان لائے اور (مال) خرچ کیا ان کیلئے بڑا اجر ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiii{تمہیں کیا ہوا ہے کہ تم اللہ پر ایمان نہیں لاتے حالانکہ (اس کا) رسول تمہیں بلا رہا ہے کہ اپنے پروردگار پر ایمان لاؤ اور وہ (اللہ) تم سے عہد و پیمان لے چکا ہے اگر تم مؤمن ہو۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiv{وہ وہی ہے جو اپنے بندۂ خاص پر واضح آیات نازل کرتا ہے تاکہ تمہیں (کفر و شرک) کی تاریکیوں سے نکال کر (ایمان کی) روشنی کی طرف لے آئے اور بےشک اللہ تم پر بڑا مہربان ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxv{اورتمہیں کیا ہوگیا ہے کہ تم (اپنے مال) اللہ کی راہ میں خرچ نہیں کرتے حالانکہ آسمانوں اور زمین کی میراث (ترکہ) اللہ ہی کیلئے ہے تم میں سے جنہوں نے فتح (مکہ) سے پہلے مال خرچ کیا اور جنگ کی وہ اور وہ جنہوں نے فتحِ مکہ کے بعد مال خرچ کیا اور جنگ کی برابر نہیں ہو سکتے (بلکہ پہلے والوں کا) درجہ بہت بڑا ہے اگرچہ اللہ نے دونوں سے بھلائی کا وعدہ کیا ہے تم جو کچھ کرتے ہواللہ اس سے بڑا باخبر ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvi{کون ہے جو اللہ کو قرضۂ حسنہ دے تاکہ وہ اسے اس کے لئے (کئی گنا) بڑھائے اور اس کے لئے بہترین اجر ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvii{جس دن تم دیکھو گے کہ مؤمن مَردوں اور مؤمن عورتوں کا نور ان کے آگے اور ان کے دائیں جانب دوڑ رہا ہوگا آج تمہیں مبارک ہو ان باغہائے بہشت کی جن کے نیچے نہریں جاری ہیں ہمیشہ ان میں رہو گے یہی وہ کامیابی ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxviii{جس دن منافق مَرد اور منافق عورتیں ایمان والوں سے کہیں گے کہ ذرا ہمارا انتظار کروکہ ہم بھی تمہارے نور سے کچھ روشنی حاصل کر لیں (ان سے کہا جائے گا کہ) تم پیچھے کی (دنیا میں) لوٹ جاؤ پھر وہیں روشنی تلاش کرو پس ان کے اور اہلِ ایمان کے درمیان ایک دیوار کھڑی کر دی جائے گی جس کا ایک دروزاہ ہوگا اس کے اندر کی طرف رحمت ہوگی اور اس کے باہر کے طرف عذاب ہوگا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxix{وہ (منافق) اہلِ ایمان کو پکا ریں گے کہ کیا ہم تمہارے ساتھ نہ تھے؟ وہ کہیں گے ہاں تھے مگر تم نے اپنے آپ کو فتنہ (گمراہی) میں ڈالا اور (ہمارے بارے میں گردشوں کا) انتظار کیا (کہ نتیجہ کیا برآمد ہوتا ہے) اور شک و شبہ میں مبتلا رہے اور جھوٹی امیدوں نے تمہیں دھوکہ دیا یہاں تک کہ اللہ کا فیصلہ آگیا اور دھوکہ باز (شیطان) نے تمہیں اللہ کے بارے میں دھوکہ میں رکھا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmxc{پس آج نہ تم سے کوئی فدیہ قبول کیا جائے گا اور نہ ان سے جنہوں نے کفر کیا تم سب کا ٹھکانہ آتشِ دوزخ ہے وہی تمہارے لئے اولیٰ اور (سزوار) ہے وہ بہت بری جائے بازگشت ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmxci{کیا اہلِ ایمان کیلئے ابھی وہ وقت نہیںایا کہ ان کے دل خدا کی یاد اور (خدا کے) نازل کردہ حق کیلئے نرم ہوں اور وہ ان لوگوں کی طرح نہ ہو جائیں جن کو اس سے پہلے کتاب دی گئی تھی پس ان پر طویل مدت گزر گئی تو ان کے دل سخت ہوئے اور (آج) ان میں سے اکثر فاسق (نافرمان) ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcii{خوب جان لو کہ اللہ زمین کو زندہ کرتا ہے اس کی موت کے بعد اور ہم نے اپنی آیات تمہارے لئے واضح طور پر بیان کر دی ہیں تاکہ تم عقل سے کام لو۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciii{بیشک صدقہ دینے والے مرد اور صدقہ دینے والی عورتیں اور جنہوں نے اللہ کو قرضۂ حسنہ دیا ان کیلئے اس میں (کئی گنا) اضافہ کر دیا جائے گا اور ان کیلئے بہترین اجر ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciv{اور جو لوگ اللہ اور اس کے رسولوں(ع) پر ایمان لائے وہی لوگ اپنے پروردگار کے نزدیک صدیق اور شہید ہیں ان کیلئے ان کا اجر اور ان کا ثواب ہے اور جنہوں نے کفر کیا اور ہماری آیات کو جھٹلایا وہی لوگ دوزخ والے ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcv{اور خوب جان لو کہ دنیا کی زندگی کھیل تماشہ، ظاہری زیب و زینت، باہمی فخر و مباہات اورمال و اولاد میں ایک دوسرے سے بڑھ جانے کی کوشش ہے اس کے سو اکچھ نہیں ہے۔ اس (کے عارضی ہو نے) کی مثال ایسی ہے جیسے بارش کہ اس کی نباتات (پیداوار) کافروں (کسانوں) کو حیرت میں ڈال دیتی ہے پھر وہ خشک ہو کر پکنے لگتی ہے تو تم دیکھتے ہو کہ وہ زرد ہو گئی ہے پھر وہ ریزہ ریزہ ہوجاتی ہے اور (کفار کیلئے) آخرت میں سخت عذاب ہے اور (مؤمنین کیلئے) اللہ کی طرف سے بخشش اور خوشنودی ہے اور دنیاوی زندگی دھوکے کے ساز و سامان کے سوا کچھ نہیں ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvi{ایک دوسرے سے آگے بڑھنے کی کوشش کرو اپنے پروردگار کی مغفرت اور اس جنت کی طرف جس کی چوڑائی آسمان و زمین کی چوڑائی کے برابر ہے جو ان لوگوں کیلئے تیار کی گئی ہے جو اللہ اور اس کے رسولوں(ع) پر ایمان لائیں اور یہ اللہ کا فضل و کرم ہے جسے چاہتا ہے عطا فرماتا ہے اور اللہ بڑا ہی فضل والا ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvii{کوئی بھی مصیبت زمین میں آتی ہے اور نہ تمہاری جانوں میں مگر وہ ایک کتاب (لوحِ محفوظ) میں لکھی ہوئی ہوتی ہے قبل اس کے کہ ہم ان (جانوں) کو پیدا کر دیں بیشک یہ بات اللہ کیلئے آسان ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcviii{(یہ سب اس لئے ہے) تاکہ جو چیز تم سے کھو جائے اس پر افسوس نہ کرو اور جو کچھ وہ (اللہ) تمہیں دے اس پر اِتراؤ نہیں کیونکہ اللہ ہر اِترانے والے، فخر کرنے والے کو پسند نہیں کرتا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcix{جو خود بُخل کرتے ہیں اور دوسروں کو بھی بُخل کا حکم دیتے ہیں اور جو (احکامِ الٰہی سے) رُوگردانی کرے تو بےشک اللہ بےنیاز ہے (اور) سِتُودہ صفات ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmc{یقیناً ہم نے اپنے رسولوں(ع) کو کھلی ہوئی دلیلوں (معجزوں) کے ساتھ بھیجا اور ان کے ساتھ کتاب اور میزان نازل کی تاکہ لوگ عدل و انصاف پر قائم ہوں اور ہم نے لوہا نازل کیا (پیدا کیا) جس میں بڑی قوت ہے (اور شدید ہیبت ہے) اور لوگوں کے لئے فائدے بھی ہیں تاکہ اللہ دیکھے کہ کون دیکھے بغیر اس کی اور اس کے رسولوں(ع) کی کون مدد کرتا ہے؟ بےشک اللہ بڑا طاقتور (اور) زبردست ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmci{اور بےشک ہم نے نوح (ع) اور ابراہیم (ع) کو رسول بنا کر بھیجا اور ان دونوں کی اولاد میں نبوت اور کتاب قرار دی (جاری کر دی) پس ان میں سے بعض تو ہدایت یافتہ ہیں اور ان میں اکثر فاسق (بدکا ر) ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcii{پھر ہم نے انہی کے نقشِ قدم پر اپنے اور رسول(ع) بھیجے اور انہی کے پیچھے عیسیٰ (ع) بن مریم (ع) کو بھیجا اور انہیں انجیل عطا کی اور جن لوگوں نے ان کی پیروی کی ہم نے ان کے دلوں میں شفقت اور رحمت رکھ دی اور رہبانیت انہوں نے خود ایجاد کی ہم نے اسے ان پر فرض نہیں کیا تھا۔ ہاں البتہ انہوں نے اسے خدا کی خوشنودی کی خاطر اسے اختیار کیا تھا پھر انہوں نے اس کی پوری رعایت نہ کی تو جو لوگ ان میں ایمان لائے ہم نے ان کو ان کا اجر عطا کیا اور ان میں سے اکثر لوگ فاسق (نافرمان) ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmciii{اے ایمان والو! اللہ (کی نافرمانی) سے ڈرو اور اس کے رسول(ع) پر (کماحقہٗ) ایمان لاؤ وہ تمہیں اپنی رحمت کے دو حصے عطا فر مائے گا اور تمہیں وہ نور عطا کرے گا کہ جس کی روشنی میں تم چلوگے اور (تمہارے قصور) تمہیں بخش دے گا اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmciv{تاکہ اہلِ کتاب یہ نہ جانیں کہ یہ لوگ (مسلمان) اللہ کے فضل میں سے کسی چیز پر کوئی اختیار نہیں رکھتے اور یہ کہ فضل اللہ کے قبضۂ قدرت میں ہے جسے چاہتا ہے عطا کرتا ہے اور اللہ بڑے فضل و کرم والا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcv{\basmalahur بےشک اللہ نے اس عورت کی بات سن لی ہے جو اپنے شوہر کے بارے میں آپ(ص) سے بحث و تکرار کررہی ہے اور اللہ سے شکوہ و شکایت کر رہی ہے اور اللہ تم دونوں کی گفتگو سن رہا ہے بےشک اللہ بڑا سننے والا، بڑا دیکھنے والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvi{تم میں سے جو لوگ اپنی بیویوں سے ظہار کرتے ہیں وہ ان کی مائیں نہیں ہیں (کیونکہ) ان کی مائیں تو بس وہی ہیں جنہوں نے انہیں جَنا ہے البتہ یہ لوگ ایک بہت بری بات اور جھوٹ کہتے ہیں اور بلاشبہ اللہ بڑا درگزر کرنے والا، بڑا بخشنے والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvii{اور جو لوگ اپنی بیویوں سے ظہار کریں اور پھر اپنی کہی ہوئی بات سے رجوع کرنا چاہیں تو قبل اس کے کہ باہمی ازدواجی تعلق قائم کریں (شوہر کو) ایک غلام آزاد کرنا ہوگا۔ یہ بات ہے جس کی تمہیں نصیحت کی جاتی ہے اور تم جو کچھ کرتے ہو اللہ اس سے پوری طرح باخبر ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcviii{اور جوشخص (غلام) نہ پائے تو جنسی تعلق قائم کرنے سے پہلے دو ماہ پے در پے (لگاتار) روزے رکھنا ہوں گے اور جو اس پر بھی قدرت نہ رکھتا ہو تو پھر ساٹھ مسکینوں کو کھانا کھلانا ہے یہ اس لئے کہ تم اللہ اور اس کے رسول(ص) پر ایمان لاؤ (تمہارا ایمان راسخ ہو) یہ اللہ کی مقرر کردہ حدیں ہیں اور کافروں کیلئے دردناک عذاب ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcix{بےشک جو لوگ اللہ اور اس کے رسول(ص) کی مخالفت کرتے ہیں وہ اسی طرح ذلیل و خوار ہوں گے جس طرح وہ (مخالف) لوگ ذلیل و خوار ہوئے جو ان سے پہلے تھے اور ہم نے کھلی ہوئی آیتیں نازل کر دی ہیں اور کافروں کیلئے ذلیل کرنے والا عذاب ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcx{جس دن اللہ ان سب کو زندہ کر کے اٹھائے گا تو انہیں بتائے گا جو کچھ انہوں نے کیا تھا اللہ نے تو (ان کے اعمال کو) محفوظ رکھا مگر وہ بھول گئے اور اللہ ہر چیز پر شاہد ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxi{کیا تم نے نہیں دیکھا (غور نہیں کیا) کہ اللہ وہ سب کچھ جانتا ہے جو آسمانوں میں ہے اور جو کچھ زمین میں ہے کہیں بھی تین آدمیوں کی سرگوشی نہیں ہوتی مگر وہ ان کا چوتھا ہوتاہے اور نہ پانچ کی ہوتی ہے مگر وہ ان کا چھٹا ہوتا ہے اور نہ اس سے کم اور نہ زیادہ مگر یہ کہ وہ جہاں بھی ہوں اللہ ان کے ساتھ ہوتا ہے پھر وہ قیامت کے دن انہیں بتائے گا کہ انہوں نے کیا کچھ کیا ہے؟ یقیناً اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxii{کیا تم نے ان لوگوں کی طرف نہیں دیکھاجنہیں (اسلام کے خلاف) سرگوشیاں کرنے سے منع کیا گیا تھا وہ پھر وہی کام کرتے ہیں جس سے ان کو منع کیا گیا تھا اور وہ گناہ، ظلم و زیادتی اور رسول(ص) کی نافرمانی کی سرگوشیاں (خفیہ میٹنگیں) کرتے ہیں اور جب آپ(ص) کے پاس آتے ہیں تو آپ(ص) کو کس طرح سلام کرتے ہیں جس طرح اللہ نے آپ(ص) کو سلام نہیں کیا اور اپنے دلوں میں کہتے ہیں کہ (اگر یہ برحق نبی(ص) ہیں تو) اللہ ہماری ان باتوں پر ہم پر عذاب کیوں نازل نہیں کرتا؟ ان کے لئے جہنم کافی ہے جس میں وہ پڑیں گے (اور اس کی تپش اٹھائیں گے) سو وہ کیا برا ٹھکانہ ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiii{اے ایمان والو! تم جب کوئی سرگوشی (خفیہ بات) کرو تو گناہ، ظلم و زیادتی اور رسول(ص) کی نافرمانی کے بارے میں سرگوشی نہ کرو بلکہ نیکی کرنے اور تقویٰ اختیار کرنے کی سرگوشی کرو اور اللہ (کی نافرمانی سے) ڈرو جس کے پاس جمع کئے جاؤ گے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiv{(کافروں کی یہ) سرگوشی شیطان کی طرف سے ہے تاکہ وہ اہلِ ایمان کو رنج و غم پہنچائے حالانکہ وہ اللہ کے اذن کے بغیر انہیں کچھ بھی نقصان نہیں پہنچا سکتا اور ایمان والوں کو اللہ پر ہی بھروسہ کرنا چاہیے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxv{اے ایمان والو! جب تم سے کہا جائے کہ (آنے والوں کیلئے) مجلسوں میں جگہ کشادہ کرو تو کشادہ کر دیا کرو اللہ تمہیں کشادگی دے گااور جب کہا جائے کہ اٹھ جاؤ تو اٹھ جایا کرو اللہ ان لوگوں کے جو تم میں سے ایمان لائے ہیں اور جن کو علم دیا گیا ہے ان کے در جے بلند کرتا ہے اور تم جو کچھ کرتے ہواللہ اس سے بڑا باخبر ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvi{اے ایمان والو! جب تم پیغمبر سے تنہائی میں کوئی بات کرنا چاہو تو اپنی اس رازدارانہ بات سے پہلے کچھ صدقہ دے دیا کرو یہ بات تمہارے لئے بہتر ہے اور پاکیزہ تر ہے اور اگر اس کے لئے کچھ نہ پاؤ تو بلاشبہ اللہ بڑا بخشنے والا، بڑا مہربان ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvii{کیا تم اس بات سے ڈر گئے کہ (رسول(ص) سے) تنہائی میں بات کرنے سے پہلے صدقہ دو! اب جبکہ تم نے ایسانہیں کیا اور اللہ نے تمہاری توبہ قبول کر لی تو بس نماز قائم کرو اور زکوٰۃد و اور اللہ اور اس کے رسول(ص) کی اطاعت کرو اور تم جو کچھ کرتے ہواللہ اس سے اچھی طرح باخبر ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxviii{کیا تم نے ایسے لوگوں کو نہیں دیکھا جو ایسے لوگوں سے دوستی کرتے ہیں جن پر اللہ نے غضب نازل کیا ہے وہ نہ تم میں سے ہیں اور نہ ان میں سے ہیں اور وہ جانتے بوجھتے ہوئے جھوٹی بات پر قَسمیں کھاتے ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxix{اللہ نے ان کیلئے سخت عذاب تیار کر رکھا ہے بےشک یہ لوگ بہت برے کام کرتے ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxx{انہوں نے اپنی قَسموں کو ڈھال بنا رکھا ہے پس وہ (لوگوں کو) اللہ کی راہ سے روکتے ہیں تو ان کے لئے ذلیل کرنے والا عذاب ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxi{ان کے مال اور ان کی اولاد انہیں ذرا بھی اللہ (کے عذاب) سے نہیں بچا سکیں گے یہ لوگ دوزخ والے ہیں وہ اسی میں ہمیشہ رہیں گے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxii{جس دن اللہ ان سب کو (دوبارہ) اٹھائے گا تو وہ اس کے سامنے بھی اسی طرح قَسمیں کھائیں گے جس طرح تمہارے سامنے کھاتے ہیں اور خیال کریں گے کہ وہ کسی چیز (بنیاد) پر ہیں خبردار! یہ لوگ بالکل جھوٹے ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiii{شیطان نے ان پر غلبہ پا لیا ہے اور اس نے انہیں خدا کی یاد بُھلا دی ہے یہ لوگ شیطان کا گروہ ہیں آگاہ ہو کہ شیطانی گروہ ہی گھاٹا اٹھانے والا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiv{جو لوگ اللہ اور اس کے رسول(ص) کی مخالفت کرتے ہیں وہ ذلیل ترین لوگوں میں سے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxv{اللہ نے لکھ دیا ہے کہ میں اور میرے رسول(ص) ہی غالب آکر رہیں گے بےشک اللہ طاقتور (اور) زبردست ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvi{تم کوئی ایسی قوم نہیں پاؤگے جو اللہ اور آخرت کے دن پر ایمان رکھتی ہو (اور پھر) وہ دوستی رکھے ان لوگوں سے جو خدا و رسول(ص) کے مخالف ہیں اگرچہ وہ (مخالف) ان کے باپ یا ان کے بیٹے یا ان کے بھائی ہی ہوں یا ان کے قبیلے والے یہ وہ لوگ ہیں کہ اللہ نے ان کے دلوں میں ایمان ثبت کر دیا ہے اور اپنی ایک خاص روح سے ان کی تائید کی ہے اور انہیں ایسے باغہائے بہشت میں داخل کرے گا جن کے نیچے نہریں جاری ہیں جن میں وہ ہمیشہ رہیں گے اللہ ان سے راضی ہے اور وہ اس سے راضی ہیں یہ لوگ اللہ کا گروہ ہیں آگاہ رہو کہ اللہ کا گروہ ہی فلاح پانے والا (اور کامیاب ہونے والا) ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvii{\basmalahur اللہ ہی کی تسبیح کرتی ہے ہر وہ چیز جو آسمانوں میں ہے اور جو زمین میں ہے اور وہ زبردست، بڑا حکمت والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxviii{وہ وہی ہے جس نے اہلِ کتاب کے کافروں (بنی نضیر) کو پہلی بار اکٹھا کر کے ان کے گھروں سے نکال دیا۔ تمہیں گمان بھی نہ تھا کہ وہ نکل جائیںگے اور وہ بھی خیال کرتے تھے کہ ان کے قلعے انہیں اللہ (کی گر فت) سے بچا لیں گے تو اللہ (کا قہر) ایسی جگہ سےایا جہاں سے ان کو خیال بھی نہیں تھا اور اس نے ان کے دلوں میں (رسول(ص) کا) رعب ڈال دیا تو وہ اپنے ہی ہاتھوں سے اپنے گھروں کو خراب و برباد کر رہے تھے اور اہلِ ایمان کے ہاتھوں سے بھی عبرت حاصل کرو اے دیدۂ بینا رکھنے والو۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxix{اور اگر اللہ نے ان کے حق میں جلا وطنی نہ لکھ دی ہوتی تووہ دنیا ہی میں ان کو عذاب دیتا اور آخرت میں تو ان کے لئے دوزخ کا عذاب ہے ہی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxx{یہ اس لئے ہے کہ انہوں نے اللہ اور اس کے رسول(ص) کی مخالفت کی اور جو اللہ کی مخالفت کرتا ہے تو یقیناً اللہ سخت سزا دینے والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxi{تم لوگوں نے کھجوروں کے جو درخت کاٹے یا جن کو ان کی جڑوں پر کھڑا رہنے دیا یہ سب اللہ کی اجازت سے تھا اور تاکہ وہ فاسقوں کو رسوا کرے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxii{اور اللہ نے ان لوگوں (بنی نضیر) سے جو مال بطور فئے اپنے رسول(ص) کو دلوایا تو تم لوگوں نے اس پر نہ گھوڑے دوڑائے اور نہ اونٹ پس اس میں تمہارا کوئی حق نہیں ہے لیکن اللہ اپنے رسولوں(ع) کو جس پر چاہتا تسلط دے دیتا ہے اور اللہ ہر چیز پر بڑی قدرت رکھتا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiii{تو اللہ نے ان بستیوں والوں کی طرف سے جو مال بطور فئے اپنے رسول(ص) کو دلوایا ہے وہ بس اللہ کا ہے اور پیغمبر(ص) کا اور(رسول(ص) کے) قرابتداروں (ان کے) یتیموں اور (ان کے) مسکینوں اور مسافروں کا ہے تاکہ وہ مالِ فئے تمہارے دولتمندوں کے درمیان ہی گردش نہ کرتا رہے اور جو کچھ رسول(ص) تمہیں دیں وہ لے لو اور جس سے منع کریں اس سے رک جاؤ اور اللہ (کی نافرمانی) سے ڈرو۔ بےشک اللہ سخت سزا دینے والا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiv{(نیز وہ مال) ان غریب مہاجروں کیلئے ہے جن کو اپنے گھروں اور مالوں سے نکال دیا گیا یہ اللہ کا فضل اور اس کی خوشنودی چاہتے ہیں اور اللہ اور اس کے رسول(ص) کی مدد کرتے ہیں اور یہی سچے لوگ ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxv{(اور یہ مال) ان کیلئے بھی ہے جو ان (مہاجرین) سے پہلے ان دیار (دارالہجرت مدینہ) میں ٹھکانا بنائے ہوئے ہیں اور ایمان لائے ہوئے ہیں اور جو ہجرت کرکے ان کے پاس آتا ہے وہ اس سے محبت کرتے ہیں اور جو کچھ ان (مہاجرین) کو دیا جائے وہ اس کی اپنے دلوں میں کوئی ناخوشی محسوس نہیں کرتے اور وہ اپنے اوپر دوسروں کو ترجیح دیتے ہیں اگرچہ خود ضرورت مند ہوں (فاقہ میں ہوں) اور جسے اپنے نفس کے حرص سے بچا لیا گیا وہی فلاح پانے والے ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvi{اور جو ان کے بعد آئے (ان کا بھی اس مال میں حصہ ہے) جو کہتے ہیں اے ہمارے پروردگار ہمیں بخش دے اور ہمارے ان بھائیوں کو بھی بخش دے جنہوں نے ایمان لانے میں ہم پر سبقت کی اور ہمارے دلوں میں اہلِ ایمان کے لئے کینہ پیدا نہ کر۔ اے ہمارے پروردگار یقیناً تو بڑا شفقت کرنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvii{کیا تم نے منافقوں کو نہیں دیکھا جو اپنے کافر اہلِ کتاب بھائیوں سے کہتے ہیں کہ اگر تم (اپنے گھروں سے) نکالے گئے تو ہم بھی تمہارے ساتھ (شہر سے) نکل جائیں گے اور ہم تمہارے معاملہ میں کبھی کسی کی اطاعت نہیں کریں گے اور اگرتم سے جنگ کی گئی تو ہم ضرور تمہاری مدد کریں گے اور اللہ گواہی دیتا ہے کہ یہ لوگ بالکل جھوٹے ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxviii{اگر وہ نکالے گئے تو یہ ان کے ساتھ نہیں نکلیں گے اور اگر ان سے جنگ کی گئی تو یہ ان کی مدد نہیں کریں گے اور اگر ان کی مدد کی بھی تو ضرور پیٹھ پھیر کر بھاگیں گے پھر ان کی کوئی مدد نہیں کی جائے گی۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxix{یقیناً تم لوگوں کا ڈر ان کے دلوں میں اللہ سے زیادہ ہے یہ اس لئے کہ یہ ایسے لوگ ہیں جو سمجھ نہیں رکھتے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxl{یہ سب مل کر کبھی تم سے (کھلے میدان میں) جنگ نہیں کریں گے مگر قلعہ بند بسیتوں میں (بیٹھ کر) یا دیواروں کے پیچھے سے (چھپ کر) وہ آپس میں بڑے قوی ہیں اور تم خیال کرتے ہو کہ وہ متحد ہیں حالانکہ ان کے دل متفرق ہیں یہ اس لئے ہے کہ یہ بےعقل لوگ ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxli{یہ ان لوگوں کی طرح ہیں جو ان سے کچھ ہی پہلے اپنے کرتوتوں کا مزہ چکھ چکے ہیں اور ان کیلئے دردناک عذاب ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlii{اور یہ شیطان کی مانند ہیں جو (پہلے) انسان سے کہتا ہے کہ کفر اختیار کر اور جب وہ کافر ہو جاتا ہے تو وہ (شیطان) کہتا ہے کہ میں تجھ سے بیزار ہوں میں اللہ سے ڈرتا ہوں جو رب العالمین ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliii{تو ان دونوں (شیطان اور اس کے مرید) کا انجام یہ ہوا کہ دونوں دوزخ میں ہیں (اور) ہمیشہ ہمیشہ اسی میں رہیں گے اور یہی ظالموں کی سزا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliv{اے ایمان والو! اللہ (کی مخالفت سے) ڈرو اور ہر شخص کو یہ دیکھنا چاہیے کہ اس نے کل (قیامت) کیلئے آگے کیا بھیجا ہے اللہ سے ڈرو بےشک جو کچھ تم کرتے ہو اللہ اس سے اچھی طرح باخبر ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlv{اور ان لوگوں کی طرح نہ ہو جاؤ جو اللہ کو بھول گئے تواللہ نے ان کو اپنا آپ بھلا دیا یہی لوگ فاسق (نافرمان) ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvi{دوزخ والے اور جنت والے برابر نہیں ہیں جنت والے کامیاب ہو نے والے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvii{اگر ہم اس قرآن کو کسی پہاڑ پر نازل کرتے تو تم دیکھتے کہ وہ خدا کے خوف سے جھک جاتا اور پاش پاش ہو جاتا اور یہ مثالیں ہم اس لئے لوگوں کیلئے بیان کرتے ہیں تاکہ وہ غور و فکر کریں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlviii{وہی وہ اللہ ہے جس کے سوا کوئی الٰہ نہیں ہے ہر غائب اور حاضر کا جاننے والا ہے (اور) وہی رحمٰن و رحیم ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlix{وہی اللہ ہے جس کے سوا کوئی الٰہ نہیں ہے وہ (حقیقی) بادشاہ، (ہر عیب سے) مقدس (پاک)، سراپا سلامتی، امن و امان دینے والا، نگہبانی کرنے والا، غالب آنے والا زور آور (یا سرکشوں کو زیر کرنے والا) اور کبریائی و بڑائی والا ہے (اور) اللہ اس شرک سے پاک ہے جو لوگ کرتے ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcl{وہی اللہ (ہر چیز کا) ٹھیک اندازے کے مطابق پیدا کرنے والا (وجود میں لانے والا) اور صورت گری کرنے والا ہے اسی کیلئے سارے اچھے نام ہیں (اور) اسی کی تسبیح کرتی ہے ہر وہ چیز جو آسمانوں میں ہے اور جو زمین میں ہے اور وہ غالب آنے والا (اور) بڑا حکمت والا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcli{\basmalahur اے ایمان والو! تم میرے اور اپنے دشمن کو اپنا ایسا (جگری) دوست نہ بناؤ کہ ان سے محبت کا اظہار کرنے لگو حالانکہ وہ اس (دینِ) حق کے منکر ہیں جو تمہارے پاس آیا ہے اور وہ رسولِ خدا(ص) کو اور خود تم کو محض اس بنا پر جلا وطن کرتے ہیں کہ تم اپنے پروردگار اللہ پر ایمان لائے ہو (یہ سب کچھ کرو) اگر تم میری راہ میں جہاد کرنے اور میری خوشنودی حاصل کرنے کیلئے (اپنے گھروں سے) نکلے ہو؟ تم چھپ کر ان کو دوستی کا پیغام بھیجتے ہو حالانکہ میں خوب جانتا ہوں جو کچھ تم چھپاتے ہو اور جو کچھ تم ظاہر کرتے ہواور جو تم میں سے ایسا کرے وہ راہِ راست سے بھٹک گیا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclii{اگر یہ لوگ تم پر قابو پا جائیں تو وہ تمہارے دشمن ہی ہوں گے اور برائی کے ساتھ (تمہیں آزار پہنچانے کیلئے) تمہاری طرف اپنے ہاتھ بڑھائیں گے اور اپنی زبانیں بھی اور وہ چاہیں گے کہ کاش تم کافر ہو جاؤ۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliii{تمہارے رشتہ دار اور تمہاری اولاد قیامت کے دن تمہارے کام نہ آئیں گے اللہ تمہارے درمیان جدائی ڈال دے گا اور جو کچھ تم کرتے ہو اللہ اسے اچھی طرح دیکھ رہا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliv{یقیناً تم لوگوں کیلئے (جنابِ) ابراہیم(ع) اوران کے ساتھیوں میں ایک عمدہ نمونہ ہے جبکہ انہوں نے اپنی قوم سے کہا کہ ہم تم سے بیزار ہیں اور ان سے بھی جن کی تم اللہ کے سوا پرستش کرتے ہو ہم تمہارے (اور تمہارے دین کے) منکر ہیں اور ہمارے اور تمہارے درمیان ہمیشہ کیلئے عداوت اور بغض پیدا ہوگیا یہاں تک کہ تم اللہ واحد (لا شریک لہٗ) پر ایمان لاؤ۔ ہاں البتہ ابراہیم (ع) نے اپنے (منہ بولے) باپ (اور اصل چچا) سے صرف یہ کہا تھا کہ میں تمہارے لئے مغفرت طلب کروں گا مگر میں اللہ کے سامنے تمہارے لئے کسی نفع کا مالک و مختار نہیں ہوں اے ہمارے پروردگار! ہم نے تجھ پر بھروسہ کیا ہے اور تیری ہی طرف رجوع کیا ہے اور تیری ہی طرف لَوٹنا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclv{اے ہمارے پروردگار! ہمیں کافروں کیلئے فتنہ نہ بنا اور ہمیں بخش دے اے ہمارے پروردگار! یقیناً تو غالب (اور) بڑی حکمت والا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvi{بےشک تمہارے لئے ان لوگوں کے اندر عمدہ نمونہ موجود ہے جو اللہ اور روزِ آخرت کا امیدوار ہے (اعتقاد رکھتا ہے) اور جو رُوگردانی کرے تو اللہ بےنیاز ہے اور حمد کا سزاوار ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvii{بہت ممکن ہے کہ اللہ تمہارے درمیان اور ان لوگون کے درمیان جن سے (آج) تمہاری دشمنی ہے کبھی محبت پیدا کر دے اور اللہ بڑی قدرت والا ہے اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclviii{اللہ تمہیں اس بات سے منع نہیں کرتا کہ جن لوگون نے دین کے معاملہ میں تم سے جنگ نہیں کی اور نہ ہی تمہیں تمہارے گھروں سے نکالا ہے کہ تم ان کے ساتھ نیکی کرو اور ان کے ساتھ انصاف کرو بےشک اللہ انصاف کرنے والوں کو دوست رکھتا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclix{اللہ تو صرف تمہیں ان لوگوں سے دوستی کرنے سے منع کرتا ہے جنہوں نے دین کے بارے میں تم سے جنگ کی اور تمہیں تمہارے گھروں سے نکالا اور تمہارے نکا لنے میں ایک دوسرے کی مدد کی اور جو ان سے دوستی کرے گا وہی ظالم ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclx{اے ایمان والو! جب مؤمن عورتیں ہجرت کر کے تمہارے پاس آئیں تو ان کا امتحان لے لیا کرو اللہ ان کے ایمان کی (اصلیت) کو بہتر جانتا ہے پس اگر تمہیں معلوم ہو جائے کہ وہ مؤمن ہیں تو پھر انہیں کافروں کی طرف واپس نہ کرو۔ نہ وہ (مؤمن عورتیں) ان (کافروں) کیلئے حلال ہیں اور نہ وہ (کافر) ان عورتوں کیلئے حلال ہیں اور ان (کافر شوہروں) نے (حق مہر وغیرہ کے سلسلہ میں) جو کچھ خرچ کیا ہے وہ انہیں ادا کر دو اور تمہارے لئے کوئی مضائقہ نہیں ہے کہ تم ان سے نکاح کرو جبکہ تم ان کے مہر ان کو ادا کر دو اور تم (بھی) کافر عورتوں کو (اپنے نکاح میں) روکے نہ رکھو اور تم نے (ان پر جو مہر) خرچ کیا ہے وہ (ان سے) واپس مانگ لو اورکافر بھی (مسلمان بیویوں سے مہر واپس) مانگ لیں جو انہوں نے خرچ کیا ہے یہ اللہ کا فیصلہ ہے جو تمہارے درمیان فیصلہ کرتا ہے اور اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxi{اور اگر تمہاری بیویوں میں سے کوئی (کفر یا ارتداد کی وجہ سے) کافروں کے پاس چلی جائے پھر تم ظفریاب ہو جاؤ (تو مالِ غنیمت میں سے) ان لوگوں کو جن کی بیویاں چلی گئی ہیں اتنا مال دو جتنا انہوں نے خرچ کیا ہو اور اللہ سے ڈرو جس پر تم ایمان رکھتے ہو۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxii{اے نبی(ص)! جب مؤمن عورتیں بیعت کرنے کیلئے آپ کے پاس آئیں تو ان سے ان شرائط پر لو کہ وہ کسی چیز کو اللہ کا شریک نہیں ٹھہرائیں گی، چوری نہیں کریں گی، زنا نہیں کریں گی، اپنی اولاد کو قتل نہیں کریں گی، اور اپنے ہاتھوں اور پاؤں کے درمیان کوئی بہتان گھڑ کر (اپنے شوہروں پر) نہیں باندھیں گی (کسی غیر کے بچے کو شوہر کا بچہ قرار نہیں دیں گی)، اور نہ ہی کسی نیکی کے کام میں آپ(ص) کی نافرمانی کریں گی ان سے بیعت لے لیجئے اور اللہ سے ان کیلئے دعائے مغفرت کیجئے۔ بےشک اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiii{اے ایمان والو! ان لوگوں سے دوستی نہ کرو جن پر اللہ نے اپنا غضب نازل کیا ہے وہ آخرت سے اس طرح ناامید ہیں جس طرح کافر لوگ قبروں میں گڑے ہوئے مردوں (کے دوبارہ زندہ ہونے) سے ناامید ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiv{\basmalahur ہر وہ چیز جو آسمانوں میں ہے اور ہر وہ چیز جو زمین میں ہے اللہ کی تسبیح کرتی ہے اور وہ (سب پر) غالب ہے (اور) بڑا حکمت والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxv{اے ایمان والو! تم وہ بات کیوں کہتے ہو جو کرتے نہیں ہو؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvi{اللہ کے نزدیک یہ بڑی ناراضی کی بات ہے کہ تم کہو ایسی بات جو کرو نہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvii{بےشک خدا ان (مجاہدوں) کو دوست رکھتا ہے جو اس کی راہ میں یوں صف بستہ ہو کر (پَراجما کر) جنگ کرتے ہیں کہ گویا وہ سیسہ پلائی ہوئی دیوار ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxviii{اور وہ وقت یاد کرو جب موسیٰ(ع) نے اپنی قوم سے کہا کہ میری قوم! تم کیوں مجھے اذیت دیتے ہو؟ حالانکہ تم خوب جانتے ہو کہ میں تمہاری طرف اللہ کا(بھیجا ہوا) رسول ہوں۔ پس جب وہ لوگ ٹیڑھے ہوگئے تو اللہ نے ان کے دلوں کو (اور بھی) ٹیڑھا کر دیا اور اللہ فاسقوں کو ہدایت نہیں دیتا (انہیں منزلِ مقصود تک نہیں پہنچاتا)\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxix{اور وہ وقت یاد کرو جب عیسیٰ(ع) بن مریم(ع) نے کہا کہ اے بنی اسرائیل! میں تمہاری طرف اللہ کا (بھیجا ہوا) رسول ہوں میں اس تورات کی تصدیق کرنے والا ہوں جو مجھ سے پہلے آئی ہے (اور جو موجود ہے) اورخوشخبری دینے والا ہوں ایک رسول(ص) کی جو میرے بعد آئے گا جس کا نام احمد(ص) ہوگا پھر جب وہ کھلی نشانیاں (معجزے) لے کر ان کے پاس آئے تو ان لوگوں نے کہا کہ یہ تو کھلا ہو جادو ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxx{اور اس شخص سے بڑا ظالم کون ہوگا جو اللہ پر جھوٹا بہتان باندھے حالانکہ اسے اسلام کی طرف بلایا جا رہا ہے اور اللہ ظالم لوگوں کو ہدایت نہیں دیتا (انہیں منزلِ مقصود تک نہیں پہنچاتا)\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxi{یہ لوگ چاہتے ہیں کہ اللہ کے نور کو اپنے منہ (پھونکوں) سے بجھا دیں حالانکہ اللہ اپنے نور کو کامل کرکے رہے گا اگرچہ کافر لوگ ناپسند ہی کریں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxii{وہ وہی ہے جس نے اپنے رسول(ص) کو ہدایت اور دینِ حق کے ساتھ بھیجا تاکہ اسے تمام دینوں پر غالب کر دے اگرچہ مشرکین ناپسند کریں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiii{اے ایمان والو! کیا میں تمہیں ایک تجارت بتا‎ؤں جو (اگر کرو تو) تمہیں دردناک عذاب سے بچالے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiv{(اور وہ یہ ہے کہ) تم اللہ اور اس کے رسول(ص) پر ایمان لاؤ اور اللہ کی راہ میں اپنے مال اور اپنی جان سے جہاد کرو یہ بات تمہارے لئے بہتر ہے اگر تم علم رکھتے ہو۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxv{(اگر ایسا کروگے تو) اللہ تمہارے گناہ بخش دے گا اور تمہیں ان باغہائے بہشت میں داخل کرے گا جن کے نیچے نہریں جاری ہیں اور ان پاکیزہ مکانوں میں داخل کرے گا جو ہمیشہ رہنے والے باغات میں ہوں گے یہی بہت بڑی کامیابی ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvi{اور ایک اور چیز بھی ہے جسے تم پسند کرتے ہو (وہ اس کے علاوہ ہے) یعنی اللہ کی مدد اور قریبی فتح و کامیابی اور ایمان والوں کو بشارت دے دیجئے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvii{اے ایمان والو! اللہ کے (دین کے) انصار و مددگار بنو جیسا کہ عیسٰی(ع) بن مریم(ع) نے حواریوں سے کہا تھا کہ اللہ کی طرف بلانے میں کون میرا مددگار ہے؟ حواریوں نے (جواب میں) کہا ہم اللہ کے (دین کے) مددگار ہیں تو بنی اسرائیل میں سے ایک گروہ ایمان لایا اور ایک گروہ نے کفر اختیار کیا تو جو ایمان لائے تھے ہم نے ان کے دشمن کے مقابلہ میں ان کی تائید کی پس وہ غالب ہو گئے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxviii{\basmalahur وہ سب چیزیں جو آسمانوں میں اور زمین میں ہیں اس اللہ کی تسبیح کرتی ہیں جو بادشاہ ہے (اور نقائص سے) پاک ہے زبردست ہے (اور) بڑا حکمت والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxix{وہ (اللہ) وہی ہے جس نے اُمّی قوم میں انہیں میں سے ایک رسول(ص) بھیجا جو ان کو اس (اللہ) کی آیتیں پڑھ کر سناتا ہے اور ان کو پاکیزہ بناتا ہے اور ان کو کتاب و حکمت کی تعلیم دیتا ہے اگرچہ اس سے پہلے یہ لوگ کھلی ہوئی گمراہی میں مبتلا تھے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxx{اور (آپ(ص) کو) ان لوگوں میں سے دوسروں کی طرف بھی بھیجا جو ابھی ان سے نہیں ملے ہیں اور وہ زبردست (اور) بڑا حکمت والا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxi{یہ اللہ کا فضل و کرم ہے جسے چاہتا ہے عطا کرتا ہے اور اللہ بڑے فضل و کرم والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxii{اور جن لوگوں (یہود) کو توراۃ کا حامل بنایا گیا مگر انہوں نے اسکو نہ اٹھایا ان کی مثال اس گدھے کی سی ہے جس نے بڑی بڑی کتابیں اٹھائی ہوئی ہوں اور کیا بری مثال ہے ان لوگوں کی جنہوں نے اللہ کی آیتوں کو جھٹلایا اور اللہ ظالموں کو ہدایت نہیں دیتا (انہیں منزلِ مقصود تک نہیں پہنچاتا)۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiii{آپ(ص) کہیے! اے یہودیو! اگر تمہارا خیال ہے کہ سب لوگوں کو چھوڑ کر تم ہی اللہ کے دوست ہو تو پھر موت کی تمنا کرو اگر تم (اپنے دعویٰ میں) سچے ہو۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiv{اور وہ ہرگز اس کی تمنا نہیں کریں گے اپنے ان (برے) اعمال کی وجہ سے جو وہ آگے بھیج چکے ہیں اور اللہ ظالموں کو اچھی طرح جانتا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxv{آپ(ص) کہہ دیجئے! کہ وہ موت جس سے تم بھاگتے ہو وہ بہرحال تم سے مل کر رہے گی پھر تم اس (خدا) کی بارگاہ میں لوٹائے جاؤ گے جو غائب اور حاضر کا جاننے والا ہے پھر وہ تمہیں بتائے گا جو کچھ تم کرتے رہے ہو۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvi{اے ایمان والو! جب تمہیں جمعہ کے دن والی نمازکے لئے پکارا جائے (اس کی اذان دی جائے) تو اللہ کے ذکر (نمازِ جمعہ) کی طرف تیز چل کر جاؤ اورخرید و فروخت چھوڑ دو۔ یہ بات تمہارے لئے بہتر ہے اگر تم جانتے ہو۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvii{پھر جب نماز تمام ہو چکے تو زمین میں پھیل جاؤ اور اللہ کا فضل (روزی) تلاش کرو اور اللہ کو بہت یاد کرو تاکہ تم فلاح پاؤ۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxviii{اور (کئی لوگوں کی حالت یہ ہے کہ) جب کوئی تجارت یا کھیل تماشہ دیکھتے ہیں تو اس کی طرف دوڑ پڑتے ہیں اور آپ(ص) کو کھڑا ہوا چھوڑ دیتے ہیں آپ(ص) کہہ دیجئے! کہ جو کچھ (اجر و ثوا ب) اللہ کے پاس ہے وہ کھیل تماشہ اور تجارت سے بہتر ہے اور اللہ بہترین رزق دینے والا ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxix{\basmalahur (اے رسول(ص)) جب منافق لوگ آپ کے پاس آتے ہیں تو کہتے ہیں کہ ہم گواہی دیتے ہیں کہ بےشک آپ اللہ کے رسول(ص) ہیں اور اللہ جانتا ہے کہ یقیناً آپ اس کے رسول(ص) ہیں لیکن اللہ گواہی دیتا ہے کہ منافق بالکل جھوٹے ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxc{انہوں نے اپنی قَسموں کو ڈھال بنا رکھا ہے پس اس طرح وہ خود اللہ کی راہ سے رکتے ہیں اور دوسروں کو روکتے ہیں بیشک بہت برا ہے وہ کام جو یہ کر رہے ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxci{یہ اس لئے ہے کہ یہ پہلے (بظاہر) ایمان لائے پھر کفر کیا تو ان کے دلوں پر (گویا) مہر لگا دی گئی ہے لہذا وہ کچھ نہیں سمجھتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcii{اور جب آپ(ص) انہیں دیکھیں گے تو ان کے جسم (اور ان کے قد و قا مت) آپ(ص) کو اچھے لگیں گے اور اگر وہ بات کریں گے تو آپ(ص) ان کی بات (توجہ) سے سنیں گے (مگر وہ عقل و ایمان سے خالی ہیں) گویا (کھوکھلی) لکڑیاں ہیں جو (دیوار وغیرہ سے) ٹیک لگا دی گئی ہیں وہ ہر چیخ کی آواز کو اپنے خلاف سمجھتے ہیں یہی (اصلی) دشمن ہیں ان سے بچ کے رہو اللہ ان کو غارت کرے یہ کہاں الٹے پھرائے جا رہے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciii{اور جب ان سے کہاجائے کہ آؤ اللہ کا پیغمبر تمہارے لئے مغفرت طلب کرے تو وہ اپنا سر پھیر لیتے ہیں اور آپ انہیں دیکھیں گے کہ وہ تکبر کرتے ہو ئے (آنے سے) رک جاتے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciv{ان کیلئے برابر ہے کہ آپ ان کیلئے مغفرت طلب کریں یا طلب نہ کریں اللہ ہرگز ان کو نہیں بخشے گا بےشک اللہ فاسقوں کو ہدایت نہیں دیتا (اورانہیں منزلِ مقصود تک نہیں پہنچاتا)۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcv{یہی وہ لوگ ہیں جو کہتے ہیں کہ جو لوگ رسولِ خدا(ص) کے پاس ہیں ان پر (اپنا مال) خرچ نہ کرو تاکہ وہ منتشر ہو جائیں حالانکہ آسمان اور زمین کے خزانے اللہ ہی کے ہیں مگر منافق لوگ سمجھتے نہیں ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvi{وہ کہتے ہیں کہ اگر ہم لَوٹ کرمدینہ گئے تو عزت والے لوگ وہاں سے ذلیل لوگوں کو نکال دیں گے حالانکہ ساری عزت تو صرف اللہ، اس کے رسول(ص) اور مؤمنین کیلئے ہے لیکن منافق لوگ (یہ حقیقت) جانتے نہیں ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvii{اے ایمان والو! تمہارا مال اور تمہاری اولاد تمہیں خدا کی یاد سے غافل نہ کردے اور جو ایسا کرے گا وہی لوگ گھاٹا اٹھانے والے ہیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcviii{اور جو کچھ ہم نے تمہیں رزق دیا ہے اس سے (میری راہ میں) خرچ کرو قبل اس سے کہ تم میں سے کسی کو موت آجائے اور پھر وہ کہے کہ میرے پروردگار! تونے مجھے کیوں نہ تھوڑی سی مدت تک مہلت دی کہ میں صدقہ دیتا اور نیکوکار بندوں میں سے ہو جاتا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcix{اورجب کسی شخص کی مدت پوری ہو جائے توخدا مزید مہلت نہیں دیتا اور اللہ جانتا ہے جو کچھ تم کرتے ہو۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcc{\basmalahur وہ سب چیزیں جو آسمانوں اور زمین میں ہیں اس اللہ کی تسبیح کرتی ہیں جو (حقیقی) بادشاہ ہے اور اسی کیلئے (ہر) تعریف ہے اور وہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcci{وہ وہی ہے جس نے تم (سب) کو پیدا کیا پھر تم میں سے کوئی کافر ہے اور کوئی مؤمن اور تم جو کچھ کرتے ہواللہ اسے خوب دیکھ رہا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccii{اس نے آسمانوں اور زمین کو حق کے ساتھ پیدا کیا ہے اوراس نے تمہاری صورت گری کی تو تمہاری بہت اچھی صورتیں بنائیں اور اسی کی طرف (سب نے) لوٹ کر جانا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciii{وہ ہر اس چیز کو جانتا ہے جو آسمانوں اور زمین میں ہے اوروہ اسے بھی جانتا ہے جو کچھ تم چھپاتے ہو اور جو کچھ تم ظاہر کرتے ہو اور اللہ تو سینوں کے بھیدوں کا بھی خوب جاننے والا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciv{کیا تمہیں ان لوگوں کی خبر نہیں پہنچی جنہوں نے اس سے پہلے کفر کیا اور اپنے کئے (کفر) کا وبال چکھا اور ان کے لئے دردناک عذاب ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccv{یہ اس لئے ہوا کہ ان کے رسول(ص) کھلی ہوئی دلیلیں لے کر ان کے پاس آتے رہے تو انہوں نے کہا کیا بشر ہماری رہبری کریں گے؟ پس(اس طرح) انہوں نے کفر اختیار کیا اور رُوگردانی کی اور اللہ نے (بھی ان کی) کوئی پروا نہ کی (کیونکہ) اللہ بےنیاز (اور) سزاوارِ حمد و ثنا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvi{کافر لوگ خیال کرتے ہیں کہ وہ (مر نے کے بعد) دوبارہ نہیں اٹھائے جائیں گے آپ(ص) کہئے! ہاں میرے پروردگار کی قَسم تم ضرور اٹھائے جاؤ گے پھر تمہیں بتایا جائے گا جو کچھ تم نے کیا ہوگا اور یہ کام اللہ کیلئے بالکل آسان ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvii{تو تم اللہ اور اس کے رسول(ص) پر ایمان لاؤ اور اس نور پر جو ہم نے نازل کیا ہے اور جو کچھ تم کرتے ہواللہ اس سے اچھی طرح باخبر ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccviii{(اس دن کو یاد کرو) جس دن اللہ تمہیں اجتماع والے دن جمع کرے گا یہی دن باہمی گھاٹا اٹھانے کا دن ہوگا اور جو اللہ پر ایمان لائے گا اور نیک عمل کرے گا اللہ اس سے اس کی برائیاں (گناہ) دور کرے گا اور اسے ان باغہائے بہشت میں داخل کرے گا جن کے نیچے سے نہریں رواں دواں ہوں گی وہ ان میں ہمیشہ ہمیشہ رہیں گے یہ بہت بڑی کامیابی ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccix{اور جن لوگوں نے کفر اختیار کیا اور ہماری آیتوں کو جھٹلایا یہی لوگ دوزخی ہیں جس میں وہ ہمیشہ رہیں گے اور وہ بہت برا ٹھکانا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccx{کوئی مصیبت (کسی پر) نہیں آتی مگر اللہ کے اذن و اجازت سے اور جو شخص اللہ پر ایمان لائے اللہ اس کے دل کو صحیح راستہ دکھاتا ہے اور اللہ ہر چیز کا بڑا جاننے والا ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxi{اور اطاعت کرو اللہ کی اور اطاعت کرو رسول(ص) کی پھر اگر تم رُوگردانی کرو گے تو ہمارے رسول(ص) پر کھول کر پیغام پہنچا دینے کے سوا کوئی ذمہ داری نہیں ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxii{اللہ وہ ہے جس کے سوا کوئی الٰہ نہیں ہے بس ایمان لانے والوں کو اللہ ہی پر بھروسہ کرنا چاہیے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiii{اے ایمان والو! تمہاری بعض بیویاں اور تمہاری بعض اولادیں تمہاری دشمن ہیں بس تم ان سے ڈرتے رہو (ہوشیار رہو) اور اگر معاف کرو، درگزر کرو اور بخش دو تو اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiv{تمہارے مال، تمہاری اولاد ایک بڑی آزمائش ہیں اور اللہ ہی ہے جس کے پاس بڑا اجر ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxv{اور جہاں تک ہو سکے اللہ (کی نافرمانی) سے ڈرو اور سنو اور اطاعت کرو اور (مال) خرچ کرو یہ تمہارے لئے بہتر ہے اور جو شخص اپنے نفس کے بُخل سے بچایا گیا تو وہی لوگ فلاح پانے والے ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvi{اگر خدا کو قرضۂ حسنہ دو تو اللہ اسے تمہارے لئے کئی گنا بڑھا دے گا اور تمہیں بخش دے گا اللہ بڑا قدردان (اور) بڑا بردبار ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvii{وہ غائب اور حاضر کا جاننے والا، زبردست(اور) بڑا حکمت والا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxviii{\basmalahur اے نبی(ص)! جب تم لوگ (اپنی) عورتوں کو طلاق دینے لگو تو انہیں عدت کے حساب سے طلاق دو اور پھر عدت کا شمار کرو اور اللہ (کی نافرمانی) سے ڈرو جو تمہارا پروردگار ہے۔ انہیں ان کے گھروں سے نہ نکالو اور نہ ہی وہ خود نکلیں مگر یہ کہ وہ کسی کھلی ہوئی بےحیائی کا ارتکاب کریں اور یہ اللہ کی (مقرر کی ہوئی) حدیں ہیں اور جو اللہ کے حدود سے تجاوز کرے گا تو وہ خود اپنے اوپر ظلم کرے گا تم نہیں جانتے شاید اللہ اس کے بعد کوئی نئی بات پیدا کر دے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxix{تو جب وہ اپنی (مقررہ) عدت کی مدت کو پہنچ جائیں تو ان کو یا تو قاعدہ (اور شائستہ طریقہ) سے (اپنے نکاح میں) روک لو یا پھر قاعدہ (اور اچھے طریقہ) سے جدا کر دو اور اپنے میں سے دو عادل آدمیوں کو گواہ بناؤ اور خدا کیلئے صحیح گواہی دو ان باتوں سے اس شخص کو نصیحت کی جاتی ہے جو اللہ اور آخرت کے دن پر ایمان رکھتا ہے اور جو کوئی خدا سے ڈرتا ہے اللہ اس کیلئے (مشکل سے نجات کا) راستہ پیدا کر دیتا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxx{اور اسے وہاں سے رزق دیتا ہے جہاں سے اسے سان گمان بھی نہیں ہوتا ہے اور جو کوئی اللہ پر بھروسہ کرتا ہے وہ (اللہ) اس کے لئے کافی ہے بےشک اللہ اپنا کام پورا کرنے والا ہے اور اللہ نے ہر چیز کیلئے ایک اندازہ مقرر کر رکھا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxi{اور تمہاری (مطلقہ) عورتوں میں سے جو حیض سے مایوس ہو چکی ہوں اگر ان کے بارے میں تمہیں کوئی شک ہو تو ان کی عدت تین ماہ ہے اور یہی حکم ان عورتوں کا ہے جنہیں (باوجود حیض کے سن و سال میں ہو نے کے کسی وجہ سے) حیض نہ آتا ہو اور حاملہ عورتوں کی میعاد وضعِ حمل ہے اور جو کوئی اللہ سے ڈرتا ہے تو اللہ اس کے معاملہ میں آسانی پیدا کر دیتا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxii{یہ اللہ کا حکم ہے جو اس نے تمہاری طرف نازل کیا ہے اور جو اللہ سے ڈرتا ہے تو اللہ اس سے اس کی برائیاں دور کر دیتا ہے اور اس کے اجر کو بڑا کرتا (بڑھاتا) ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiii{ان (مطلقہ عورتوں) کو (زمانۂ عدت میں) وہاں رکھو جہاں اپنی حیثیت کے مطابق تم خود رہتے ہو اور انہیں ضرر و زیاں نہ پہنچاؤ تاکہ ان پر تنگی کرو۔ اور اگر وہ حاملہ ہوں تو پھر ان پر خرچ کرو یہاں تک ان کا وضعِ حمل ہو جائے پھر اگر تمہارے لئے (بچہ) کو دودھ پلائیں تو تم انہیں ان کی اجرت دو اور منا سب طریقہ پر باہم طے کر لو اور اگر تمہیں باہم کوئی دشواری پیش آئے (اور باہمی اتفاق نہ ہو سکے) تو پھر کوئی اور عورت اسے دودھ پلائے گی۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiv{وسعت والے کو چاہیے کہ اپنی وسعت کے مطابق خرچ کرے اور جس کی روزی تنگ ہو تو جتنا اللہ نے اسے دیا ہے اس میں سے خرچ کرے اللہ نے جتنا کسی کو دیا ہے اس سے زیادہ اسے تکلیف نہیں دیتا عنقر یب اللہ تنگی کے بعد آسانی اور کشادگی پیدا کرے گا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxv{اور کتنی ہی ایسی بستیاں ہیں جنہوں نے اپنے پروردگار اور اس کے رسولوں(ع) کے حکم سے سرتابی کی تو ہم نے انکا سخت محاسبہ کیا اور انہیں انوکھی (سخت) سزا دی۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvi{پس انہوں نے اپنے کئے (کرتوت) کا وبال چکھا اور ان کے کام کا انجام گھاٹا تھا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvii{اللہ نے (آخرت میں) ان کیلئے سخت عذاب تیار کر رکھا ہے تواللہ (کی مخالفت) سے ڈرو۔ اے عقلمندو جو ایمان لائے ہو خدا نے تمہاری طرف ذکر نازل کیا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxviii{یعنی ایک ایسا رسول(ص) جو اللہ کی واضح آیتیں تمہیں پڑھ کر سناتا ہے تاکہ ان لوگوں کو جو ایمان لائیں اور نیک عمل کریں (کفر و شرک) کی تاریکیوں سے نکال کر (ایمان کے) نور کی طرف لائے اور جو کوئی اللہ پر ایمان لائے گا اور نیک عمل کرے گا تواللہ اسے ایسے باغہائے بہشت میں داخل کرے گا جن کے نیچے نہریں جاری ہیں وہ ان میں ہمیشہ ہمیشہ رہیں گے۔ بےشک اللہ نے ایسے (مؤمن) کو بہت اچھی روزی دی ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxix{اللہ وہ ہے جس نے سات آسمان پیدا کئے اور انہی کی طرح زمین بھی ان کے درمیان حکم (خدا) نازل ہوتا رہتا ہے تاکہ تمہیں معلوم ہو کہ اللہ ہر چیز پر بڑی قدرت رکھتا ہے اور یہ کہ اللہ نے ہر چیز کا (علمی) احاطہ کر رکھا ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxx{\basmalahur اے نبی(ص)! جو چیز اللہ نے آپ کیلئے حلال قرار دی ہے آپ اسے اپنی بیویوں کی خوشنودی حاصل کرنے کیلئے (اپنے اوپر) کیوں حرام ٹھہراتے ہیں اور اللہ بڑا بخشنے والا، بڑا رحم کرنے والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxi{بےشک اللہ نے تمہاری قَسموں (کی گرہ کے) کھولنے کا طریقہ مقررکر دیا ہے اللہ تمہارا مولیٰ (سرپرست و کارساز ہے) اور وہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxii{(وہ وقت یاد رکھنے کے لائق ہے) جب نبی(ص) نے اپنی بعض بیویوں سے راز کی ایک بات کہی اور جب اس نے وہ بات (کسی اور کو) بتا دی اور اللہ نے آپ(ص) کو اس (خیانت کاری) سے آگاہ کر دیا تو آپ(ص) نے اس (بیوی) کو کچھ بات جتا دی اور کچھ سے اعراض کیا (چشم پوشی کی) تو جب آپ(ص) نے اس (بیوی) کو یہ بات بتائی تو اس نے (ازراہِ تعجب) کہا کہ آپ(ص) کو اس کی کس نے خبر دی؟ فرمایا مجھے بڑے جاننے والے (اور) بڑے باخبر (خدا) نے خبر دی ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiii{اگر تم دونوں (اللہ کی بارگاہ میں) توبہ کر لو (تو بہتر ہے) کیونکہ تم دونوں کے دل ٹیڑھے ہو چکے ہیں اور اگر تم ان (پیغمبر(ص)) کے خلاف ایکا کرو گی (تو تم پیغمبر کا کچھ بھی نہیں بگاڑ سکو گی) کیونکہ یقیناً اللہ ان کا حامی ہے اور جبرائیل(ع) اور نیکوکار مؤمنین اور اس کے بعد سب فرشتے ان کے پشت پناہ (اور مددگار) ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiv{اگر پیغمبر(ص) تمہیں طلاق دے دیں تو بہت جلد اللہ ان کو تمہارے بدلے تم سے اچھی بیویاں دے دے گا جو (پکی و سچی) مسلمان ہونگی اور باایمان، اطاعت گزار اور فرمانبردار، توبہ کرنے والیاں عبادت گزار، روزہ دار اور شوہر دیدہ اور ابکار (کنواریاں)۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxv{اے ایمان والو! اپنے آپ کو اور اپنے اہل و عیال کو اس آتشِ دوزخ سے بچاؤ جس کا ایندھن آدمی اور پتھر ہوں گے اس پر ایسے فرشتے مقرر ہیں جو تُندخو اور درشت مزا ج ہیں انہیں جس بات کا حکم دیا گیا ہے وہ اس کی نافرمانی نہیں کرتے اور وہ وہی کام کرتے ہیں جس کا انہیں حکم دیا گیا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvi{اے کافر لوگو! آج تم عذر و معذرت نہ کرو تمہیں اسی کا بدلہ دیا جا رہا ہے جو تم کیا کرتے تھے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvii{اے ایمان والو! اللہ کی بارگاہ میں (سچے دل سے) خالص توبہ کرو۔ امید ہے کہ تمہارا پروردگار تم سے تمہاری برائیاں دور کر دے گا اور تمہیں ایسے بہشتوں میں داخل کرے گا جن کے نیچے نہریں جاری ہیں جس دن خدا (اپنے) نبی(ص) کو اور ان لوگوں کو جو آپ(ص) کے ساتھ ایمان لائے ہیں رسوا نہیں کرے گا (اس دن) ان کا نور ان کے آگے اور ان کے دائیں جانب تیز تیز چل رہا ہوگا (اور) وہ کہہ رہے ہوں گۓ اے ہمارے پروردگار! ہمارے لئے ہمارا نور مکمل کر اور ہماری مغفرت فرما بےشک تو ہر چیز پر بڑی قدرت رکھتا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxviii{اے نبی(ص)! کافروں اور منافقوں سے جہاد کیجئے اور ان پر سختی کیجئے اور ان کا ٹھکانہ جہنم ہے اور وہ بہت بری جائے بازگشت ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxix{اور اللہ کافروں کیلئے نوح(ع) اور لوط(ع) کی بیویوں کی مثال بیان کرتا ہے جو دونوں ہمارے بندوں میں سے دو نیک بندوں کی زوجیت میں تھیں پس انہوں نے ان کے ساتھ خیانت (غداری) کی تو وہ دونوں نیک بندے اللہ کے مقابلہ میں انہیں کچھ بھی فائدہ نہیں پہنچا سکے اور ان دونوں (بیویوں) سے کہا گیا کہ تم بھی دوزخ میں داخل ہو جاؤ اور داخل ہو نے والوں کے ساتھ۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxl{اوراللہ اہلِ ایمان کے لئے فرعون کی بیوی (آسیہ(ع)) کی مثال پیش کرتا ہے جبکہ اس نے کہا اے میرے پروردگار! میرے لئے جنت میں ایک گھر بنا اور مجھے فرعون اور اس کے (کافرانہ) عمل سے نجات دے اور مجھے ظالم قوم سے نجات دے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxli{اور (دوسری) مریم(ع) بنت عمران کی مثال بیان کرتا ہے جس نے اپنی شرمگاہ کی حفاظت کی تو ہم نے اس میں اپنی ایک (خاص) روح پھونک دی اور اس نے اپنے پروردگار کی باتوں (پیاموں) اور اس کی کتابوں کی تصدیق کی اور وہ فرمانبرداروں میں سے تھی۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlii{\basmalahur بابرکت ہے وہ (خدا) جس کے ہاتھ (قبضۂ قدرت) میں (کائنات کی) بادشاہی ہے اور وہ ہر چیز پر پوری قدرت رکھتا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliii{جس نے موت و حیات کو پیدا کیا تاکہ تمہیں آزمائے کہ تم میں سے عمل کے لحاظ سے سب سے زیادہ اچھا کون ہے؟ وہ بڑا زبردست (اور) بڑا بخشنے والا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliv{جس نے اوپر نیچے سات آسمان بنائے تم خدائے رحمٰن کی تخلیق میں کوئی خلل (اور بےنظمی) نہیں پاؤ گے پھر نگاہ اٹھا کر دیکھو تمہیں کوئی رخنہ نظر آتا ہے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlv{پھر دوبارہ نگاہ دوڑاؤ۔ تمہاری نگاہ تھک کر (ناکام) تمہاری طرف لوٹ آئے گی۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvi{بےشک ہم نے قریبی آسمان کو (تاروں) کے چراغوں سے آراستہ کیا ہے اور انہیں شیطانوں کو سنگسار کرنے (مار بھگانے) کا ذریعہ بنایا ہے اور ہم نے ان (شیطانوں) کیلئے دہکتی ہوئی آگ کا عذاب بھی تیار کر رکھا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvii{اور جن لوگوں نے اپنے پروردگار کا کفر (انکار) کیا ان کے لئے جہنم کا عذاب ہے اور وہ بہت ہی برا ٹھکانا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlviii{جب وہ اس میں جھونکے جائیں گے تو وہ اس کی زوردار (اور مہیب) آواز سنیں گے اور وہ جوش مار رہی ہوگی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlix{(گویا) وہ غیظ و غصہ سے پھٹی جاتی ہوگی جب اس میں کوئی گروہ جھونکا جائے گا تو اس کے دارو غے ان سے پو چھیں گے کہ تمہارے پاس کوئی ڈرانے والا (ہادی) نہیں آیا تھا؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccl{وہ کہیں گے ہاں بےشک ہمارے پاس ڈرانے والا آیا تھا مگر ہم نے (اسے) جھٹلایا اور کہا کہ اللہ نے کوئی بھی چیز نازل نہیں کی تم بڑی گمراہی میں مبتلا ہو۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccli{اور کہیں گے کاش ہم (اس وقت) سنتے یا سمجھتے تو (آج) دوزخ والوں میں سے نہ ہو تے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclii{پس وہ (اس وقت) اپنے گناہ کا اعتراف کر لیں گے پس لعنت ہوان دوزخ والوں پر۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliii{بےشک جو لوگ اپنے پروردگار سے اَن دیکھے ڈرتے ہیں ان کیلئے مغفرت ہے اور بڑا اجر و ثواب ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliv{اور تم اپنی بات آہستہ کرو یا بلند آواز سے کرو وہ (خدا) تو سینوں کے رازوں کو بھی جانتا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclv{کیا جس نے پیدا کیا ہے وہ نہیں جانتا حالانکہ وہ بڑا باریک بین اور بڑا باخبر ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvi{وہ (اللہ) وہی ہے جس نے زمین کو تمہارے لئے رام کر دیا تاکہ تم اس کے کاندھوں (راستوں) پر چلو اور اس (اللہ) کے (دئیے ہو ئے) رزق سے کھاؤ پھر اسی کی طرف(قبروں سے) اٹھ کر جانا ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvii{کیا تم اس (اللہ) سے بےخوف ہو گئے جس (کی حکومت) آسمان میں ہے کہ وہ تمہیں زمین میں دھنسا دے پھر وہ ایک دم تھر تھرانے لگے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclviii{کیا تم اس بات سے بےخوف ہو گئے ہو کہ آسمان والا تم پر پتھر بر سانے والی ہوا بھیج دے پھر تمہیں بہت جلد معلوم ہو جائے گا کہ میرا ڈرانا کیسا ہوتا ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclix{اور جو لوگ ان سے پہلے تھے انہوں نے بھی (حق کو) جھٹلایا تھا تو میری سخت گیری کیسی تھی؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclx{کیا یہ لوگ اپنے اوپر پرندوں کو نہیں دیکھتے جو پروں کو پھیلائے ہوئے (اڑتے ہیں) اور وہ (کبھی ان کو) سمیٹ بھی لیتے ہیں انہیں (خدا ئے) رحمٰن کے سوا اور کوئی (فضا میں) تھامے ہوئے نہیں ہے بےشک وہ ہر چیز کو دیکھ رہا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxi{آخر وہ کون ہے جو خدائے رحمٰن کے مقابلہ میں تمہارا لشکر بن کر تمہاری مدد کرے؟ کافر لوگ بالکل دھوکے میں پڑے ہوئے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxii{(بتا‎ؤ) وہ کون ہے جو تمہیں روزی دے اگر وہ (اللہ) اپنی روزی روک لے؟ بلکہ یہ لوگ سرکشی اور (حق سے) نفرت پر اڑے ہوئے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiii{بھلا جوشخص منہ کے بل گرتا ہوا چل رہا ہو وہ زیادہ ہدایت یافتہ (اورمنزلِ مقصود پر زیادہ پہنچنے والا) ہے یا وہ جو سیدھا راہِ راست پر چل رہا ہے؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiv{آپ(ص) کہہ دیجئے! وہی تو (خدا) ہے جس نے تمہیں پیدا کیا اور تمہارے لئے کان، آنکھیں اور دل (و دماغ) بنا ئے۔ (مگر) تم بہت کم شکر ادا کرتے ہو۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxv{آپ(ص) کہہ دیجئے! کہ وہ (اللہ) وہی ہے جس نے تمہیں زمین میں پھیلایا اور (قیامت کے دن) تم اسی کے پاس اکٹھے کئے جاؤ گے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvi{اور وہ (کافر لوگ) کہتے ہیں کہ (بتا‎ؤ) یہ وعدہ وعید کب پوراہوگا؟ اگر تم سچے ہو۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvii{آپ(ص) کہہ دیجئے کہ (اس کا) علم تو بس اللہ کے پاس ہے اور میں تو صرف ایک کھلا ہوا ڈرانے والا ہوں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxviii{پس وہ جب اس (قیامت) کو قریب آتے دیکھیں گے تو کافروں کے چہرے بگڑ جائیں گے اور (ان سے) کہاجائے گا کہ یہی وہ ہے جس کا تم مطالبہ کیا کرتے تھے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxix{آپ(ص) کہہ دیجئے! کہ کیا تم نے غور کیا ہے اگر (تمہاری خواہش کے مطابق) خدا مجھے اور میرے ساتھیوں کو ہلاک کر دے یا (ہماری خواہش کے مطابق) ہم پر رحم فرمائے (بہرحال) کافروں کو دردناک عذاب سے کون پناہ دے گا؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxx{آپ(ص) کہہ دیجئے! وہ خدائے رحمان ہے جس پر ہم ایمان لائے ہیں اور اسی پر توکل (بھروسہ) کرتے ہیں عنقریب تمہیں معلوم ہو جائے گا کہ کھلی ہوئی گمراہی میں کون ہے؟\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxi{آپ(ص) کہیے! کیا تم نے غور کیا ہے کہ اگر تمہارا پانی زمین کی تہہ میں اترجائے تو پھر تمہارے لئے (شیریں پانی کا) چشمہ کون لائے گا؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxii{\basmalahur نون! قَسم ہے قلم کی اور اس کی جو کچھ لوگ لکھتے ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiii{کہ آپ(ص) اپنے پروردگار کے فضل و کرم سے دیوانے نہیں ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiv{اور بےشک آپ(ص) کے لئے ایسا اجر ہے جو کبھی ختم ہو نے والانہیں ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxv{اور بےشک آپ(ص) خلقِ عظیم کے مالک ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvi{عنقریب آپ بھی دیکھیں گے اور وہ بھی دیکھ لیں گے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvii{کہ تم میں سے کون جُنون میں مبتلا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxviii{بےشک آپ(ص) کا پروردگار بہتر جانتا ہے کہ اس کی راہ سے بھٹکا ہواکون ہے؟ اور وہی انہیں خوب جانتا ہے جو ہدایت یافتہ ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxix{تو آپ(ص) جھٹلانے والوں کا کہنا نہ مانیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxx{وہ (کفار) تو چاہتے ہیں کہ آپ(ص) (اپنے فرضِ منصبی کی ادائیگی میں) ڈھیلے پڑجائیں تو وہ بھی (مخالفت میں) ڈھیلے ہو جائیں۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxi{اور آپ(ص) ہرگز ہر اس شخص کا کہنا نہ مانیں جو بہت (جھوٹی) قَسمیں کھانے والا ہے (اور) ذلیل ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxii{جو بڑی نکتہ چینی کرنے والا (اور) چلتا پھرتا چغل خور ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiii{کارِ خیر سے بڑا منع کرنے والا، حد سے بڑھنے والا (اور) بڑا گنہگار ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiv{سخت مزاج ہے اور ان (سب بری صفتوں) کے علاوہ وہ بداصل بھی ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxv{یہ سب کچھ اس بناء پر ہے کہ وہ مالدار اور اولاد والا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvi{جب اس کو ہماری آیتیں پڑھ کر سنائی جاتی ہیں تو وہ کہتا ہے کہ یہ تو اگلے لوگوں کے افسانے ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvii{ہم عنقریب اس کی سونڈ (نا ک) پر داغ لگائیں گے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxviii{ہم نے ان (کفارِ مکہ) کو اسی طرح آزمائش میں ڈالا ہے جس طرح ایک باغ والوں کو آزمائش میں ڈالا تھا جب انہوں نے قَسم کھائی تھی کہ وہ صبح سویرے ضرور اس کا پھل توڑ لیں گے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxix{اور انہوں نے کوئی استثناء نہیں کیا تھا (انشاء اللہ نہیں کہا تھا)۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxc{پھر (راتوں رات) جب کہ وہ لوگ ابھی سوئے ہوئے تھے آپ(ص) کے پروردگار کی طرف سے ایک آفت چکر لگا گئی۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxci{تو وہ (باغ) کٹی ہوئی فصل کی طرح ہوگیا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcii{پس انہوں نے صبح ہوتے ہی ایک دوسرے کو آواز دی۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciii{کہ اگر تم نے پھل توڑنا ہے تو سویرے سویرے اپنی کھیتی کی طرف چلو۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciv{تو وہ اس حال میں چل پڑے کہ چپکے چپکے ایک دوسرے سے کہتے جاتے تھے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcv{کہ خبردار! آج تمہارے پاس اس باغ میں کوئی مسکین نہ آنے پا ئے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvi{اور وہ اس (مسکین کو کچھ نہ دینے) پر قادر سمجھ کر نکلے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvii{اور جب باغ کو (برباد) دیکھا تو کہا کہ ہم راستہ بھول گئے ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcviii{بلکہ ہم محروم ہو گئے ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcix{جو ان میں سے بہتر آدمی تھا اس نے کہا کہ کیا میں نے تم سے نہیں کہا تھا کہ (خدا کی) تسبیح کیوں نہیں کرتے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccc{(تب) انہوں نے کہا کہ پاک ہے ہمارا پروردگار بےشک ہم ظالم تھے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmccci{پھر وہ ایک دوسرے کی طرف متوجہ ہو کر باہم لعنت ملامت کرنے لگے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccii{(اور) کہنے لگے وائے ہو ہم پر! بےشک ہم سرکش ہو گئے تھے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciii{امید ہے کہ ہمارا پروردگار ہمیں اس (باغ) کے بدلے اس سے بہتر باغ عطا کر دے ہم اپنے پروردگار کی طرف رجوع کرتے ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciv{اسی طرح عذاب آتا ہے اور آخرت کا عذاب تو (اس سے بھی) بہت بڑا ہے کاش کہ یہ لوگ جانتے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccv{بےشک پرہیزگاروں کیلئے ان کے پروردگار کے ہاں نعمت و آسائش کے باغات ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvi{کیا ہم فرمانبرداروں کو مجرموں کی مانند کر دیں گے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvii{تمہیں کیا ہوگیا ہے؟ تم کیسے فیصلے کرتے ہو؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccviii{کیا تمہارے پاس کوئی (آسمانی) کتاب ہے جس میں تم (یہ) پڑھتے ہو؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccix{کہ تمہارے لئے اس میں وہ کچھ ہے جو تم پسند کرتے ہو؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccx{یا کیا تم نے ہم سے کچھ قَسمیں لی ہیں کہ قیامت میں تمہارے لئے وہی کچھ ہے جس کا تم حکم لگاؤ گے (فیصلہ کرو گے؟)\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxi{ان سے پوچھئے کہ ان میں سے کون ان (بےبنیاد باتوں) کا ضامن ہے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxii{یا انکے کچھ آدمی (ہمارے) شریک ہیں؟ تو اگر وہ سچے ہیں تو پھر اپنے وہ شریک پیش کریں۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiii{(وہ دن یاد کرنے کے لائق ہے) جب پنڈلی کھولی جائے گی (یعنی سخت وقت ہوگا) اور ان (کافروں) کو سجدہ کیلئے بلایا جائے گا تو (اس وقت) وہ سجدہ نہیں کر سکیں گے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiv{ان کی نگاہیں جھکی ہوئی ہوں گی (اور) ان پر ذلت چھائی ہوگی حالانکہ انہیں اس وقت (بھی دنیا میں) سجدہ کی دعوت دی جاتی تھی جب وہ صحیح و سالم تھے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxv{پس (اے رسول(ص)) آپ(ص) مجھے اور اس کو چھوڑ دیں جو اس کتاب کو جھٹلاتا ہے ہم انہیں اس طرح بتدریج تباہی کی طرف لے جائیںگے کہ ان کو خبر بھی نہ ہوگی۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvi{اور میں انہیں مہلت دے رہا ہوں۔ بےشک میری تدبیر بڑی مضبوط ہے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvii{کیا آپ(ص) ان سے کوئی اجرت طلب کرتے ہیں کہ وہ اس تاوان کے بوجھ تلے دبےجاتے ہیں؟\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxviii{یا کیا ان کے پاس غیب ہے سو جسے وہ لکھ رہے ہیں؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxix{پس آپ(ص) اپنے پروردگار کے فیصلے تک صبر کریں اور مچھلی والے (جنابِ یونس(ع)) کی طرح نہ ہوں جب انہوں نے اس حال میں (اپنے پروردگار کو) پکارا کہ وہ غم و غصہ سے بھرے ہوۓ تھے (یا مغموم تھے)۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxx{اگر ان کے پروردگار کا فضل و کرم ان کے شاملِ حال نہ ہوتا تو انہیں اس حال میں چٹیل میدان میں پھینک دیا جاتا کہ وہ مذموم ہوتے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxi{مگر ان کے پروردگار نے انہیں منتخب کر لیا اور انہیں (اپنے) نیکوکار بندوں سے بنا دیا۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxii{اور جب کافر ذکر (قرآن) سنتے ہیں تو ایسا معلوم ہوتا ہے کہ وہ اپنی (تیز و تند) نظروں سے آپ(ص) کو (راہِ راست) سے پھسلا دیں گے اور کہتے ہیں کہ یہ ضرور دیوانہ ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiii{حالانکہ وہ (قرآن) تو تمام جہانوں کیلئے نصیحت ہے۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiv{\basmalahur برحق واقع ہو نے والی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxv{کیا ہے وہ برحق واقع ہو نے والی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvi{اور (اے مخاطب) تم کیا جانو کہ کیا ہے وہ برحق واقع ہو نے والی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvii{قبیلۂ ثمود اور عاد نے کھڑکھڑانے والی (قیامت) کو جھٹلایا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxviii{پس ثمود تو ایک حد سے بڑھے ہوئے حادثہ سے ہلاک کئے گئے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxix{اور بنی عاد ایک حد سے زیادہ تیز و تند (اور سرد) آندھی سے ہلاک کئے گئے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxx{اللہ نے اسے مسلسل سات رات اور آٹھ دن تک ان پر مسلط رکھا تم (اگر وہاں ہوتے تو) دیکھتے کہ وہ اس طرح گرے پڑے ہیں کہ گویا وہ کھجور کے کھوکھلے تنے ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxi{تو تمہیں ان کا کوئی باقی بچ جانے والا نظر آتا ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxii{اور فرعون اور اس سے پہلے والوں اور الٹی ہوئی بسیتوں (والوں) نے (یہی) خطا کی۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiii{(یعنی) اپنے پروردگار کے رسول(ع) کی نافرمانی کی تو اس (اللہ) نے ان کو حد سے بڑھی ہوئی گرفت میں لے لیا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiv{اور پانی جب حد سے بڑھ گیا تو ہم نے تم کو (یعنی تمہارے آباء و اجداد کو) کشتی میں سوار کیا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxv{تاکہ ہم اس (وا قعہ) کو تمہارے لئے یادگار بنا دیں اور یاد رکھنے والے کان اسے محفوظ رکھیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvi{سو جب ایک بار صور پھونکا جائے گا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvii{اور زمین اور پہاڑوں کو ایک ہی دفعہ پاش پاش کر دیا جائے گا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxviii{تو اس دن واقع ہو نے والی (قیامت) واقع ہو جائے گی۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxix{اور آسمان پھٹ جائے گا اور وہ اس دن بالکل کمزور ہو جائے گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxl{اور فرشتے اس کے کناروں پر ہوں گے اور آپ(ص) کے پرورگار کے عرش کو اس دن آٹھ (فرشتے) اٹھائے ہوں گے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxli{اس دن تم (اپنے پروردگار کی بارگاہ میں) پیش کئے جاؤ گے اور تمہاری کوئی بات پوشیدہ نہ رہے گی۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlii{پس جس کا نامۂ اعمال اس کے دائیں ہاتھ میں دیا جائے گا وہ کہے گا آؤ پڑھو میرانامۂ اعمال۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliii{میں سمجھتا تھا کہ میں اپنے حساب کتاب سے دو چار ہو نے والا ہوں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliv{وہ ایک پسندیدہ زندگی میں ہوگا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlv{(یعنی) اس عالیشان بہشت میں ہوگا۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvi{جس کے تیار پھلوں کے خوشے جھکے ہوئے ہوں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvii{(ان سے کہاجائے گا) کھاؤ اور پیو مزے اور خوشگواری کے ساتھ ان اعمال کے صلے میں جو تم نے گزرے ہوئے دنوں میں کئے ہیں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlviii{اور جس کا نامۂ اعمال اس کے بائیں ہاتھ میں دیا جائے گا وہ کہے گا کہ کاش میرا نامۂ اعمال مجھے نہ دیا جاتا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlix{اور میں نہ جانتا کہ میرا حساب کتاب کیا ہے؟\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccl{اے کاش وہی موت (جو مجھے آئی تھی) فیصلہ کُن ہوتی۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccli{(ہا ئے) میرے مال نے مجھے کوئی فائدہ نہ دیا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclii{(آہ) میرا اقتدار ختم ہوگیا۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliii{(پھر حکم ہوگا) اسے پکڑو اور اسے طوق پہناؤ۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliv{پھر اسے جہنم میں جھونک دو۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclv{پھر اسے ایک ایسی زنجیر میں جس کی لمبائی ستر ہاتھ ہے جکڑ دو۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvi{(کیونکہ) یہ بزر گ و برتر خدا پر ایمان نہیں رکھتا تھا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvii{اور غریب کو کھانا کھلانے پر آمادہ نہیں کرتا تھا۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclviii{پس آج یہاں اس کا کوئی ہمدرد نہیں ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclix{اور نہ ہی اس کے لئے پیپ کے سوا کوئی کھانا ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclx{جسے خطا کاروں کے سوا اور کوئی نہیں کھاتا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxi{پس نہیں! میں قَسم کھاتا ہوں ان چیزوں کی جن کو تم دیکھتے ہو۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxii{اور ان کی جن کو تم نہیں دیکھتے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiii{بےشک یہ (قرآن) ایک معزز رسول(ص) کا کلام ہے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiv{یہ کسی شاعر کا کلام نہیں ہے (مگر) تم لوگ بہت کم ایمان لاتے ہو۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxv{اور نہ ہی یہ کسی کاہن کا کلام ہے (مگر) تم لوگ بہت کم نصیحت حاصل کرتے ہو۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvi{(بلکہ) یہ تو تمام جہانوں کے پروردگار کی طرف سے نازل شدہ ہے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvii{اگر وہ (نبی(ص)) اپنی طرف سے کوئی بات گھڑ کر ہماری طرف منسوب کرتا۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxviii{تو ہم اس کا دایاں ہاتھ پکڑ لیتے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxix{اور پھر ہم اس کی رگِ حیات کاٹ دیتے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxx{پھر تم میں سے کوئی بھی ہمیں اس سے روکنے والا نہ ہوتا۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxi{بےشک یہ(قرآن) پرہیزگاروں کیلئے ایک نصیحت ہے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxii{اور ہم خوب جانتے ہیں کہ تم میں سے کچھ لوگ (اس کے) جھٹلانے والے ہیں۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiii{اور یہ کافروں کیلئے با عثِ حسرت ہے۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiv{اور بےشک وہ یقینی حق ہے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxv{پس آپ(ص) اپنے عظمت والے پروردگار کے نام کی تسبیح کریں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvi{\basmalahur ایک سوال کرنے والے نے اس عذاب کا سوال کیا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvii{جو کافروں پر واقع ہونے والا ہے (اور) اسے کوئی ٹالنے والانہیں ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxviii{جو اس خدا کی طرف سے ہے جو بلندی کے زینوں والا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxix{فرشتے اور روح اس کی بارگاہ میں ایک ایسے دن میں چڑھ کر جاتے ہیں جس کی مقدار پچاس ہزار سال ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxx{(اے نبی(ص)) پس آپ(ص) بہترین صبر کیجئے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxi{یہ لوگ تو اس (روز) کو بہت دور سمجھتے ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxii{مگر ہم اسے بالکل قریب دیکھ رہے ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiii{جس دن آسمان پگھلی ہوئی دھات کی طرح ہو جائے گا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiv{اور پہاڑ دھنکی ہوئی رُوئی کی مانند ہو جائیں گے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxv{اور کوئی دوست کسی دو ست کو نہ پو چھے گا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvi{حالانکہ وہ ایک دوسرے کو دکھائے جائیں گے مجرم چاہے گا کہ اس دن کے عذاب سے بچنے کیلئے اپنے بیٹوں،\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvii{اپنی بیوی اور اپنے بھائی،\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxviii{اور اپنے قریبی کنبہ جو اسے پناہ دینے والا ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxix{اور رُوئے زمین کے سب لوگوں کو فدیہ میں دے دے اور پھر یہ (فدیہ) اسے نجات دلا دے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxc{ہرگز نہیں وہ تو بھڑکتی ہوئی آگ کا شعلہ ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxci{جو کھال کو ادھیڑ کر رکھ دے گا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcii{اور ہر اس شخص کو (اپنی طرف) بلائے گا جو پیٹھ پھرائے گااور رُوگردانی کرے گا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciii{اور جس نے (مال) جمع کیا اور پھر اسے سنبھال کر رکھا۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciv{بےشک انسان بےصبرا پیدا ہوا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcv{جب اسے کوئی تکلیف پہنچتی ہے تو وہ بہت گھبرا جاتا ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvi{اورجب اسے خوشحالی نصیب ہوتی ہے تو بہت بُخل کرتا ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvii{مگر وہ نمازی (اس عیب سے محفوظ ہیں)۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcviii{جو اپنی نمازوں پر مُداومَت کرتے ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcix{اورجن کے مالوں میں مقررہ حق ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcd{سا ئل اور محروم کا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdi{اور جو جزا و سزا کے دن کی تصدیق کرتے ہیں۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdii{اور جو اپنے پروردگار کے عذاب سے ڈرتے رہتے ہیں۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiii{کیونکہ ان کے پروردگار کا عذاب وہ چیز ہے جس سے کسی کو مطمئن نہیں ہونا چاہئے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiv{اور جو اپنی شرم گاہوں کی حفاظت کرتے ہیں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdv{سوائے اپنی بیویوں کے یا اپنی مملوکہ کنیزوں کے کہ اس میں ان پر کوئی ملامت نہیں ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvi{اور جو اس سے آگے بڑھے وہ حد سے تجاوز کرنے والے ہیں۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvii{اورجو اپنی امانتوں اورعہد و پیمان کا لحاظ رکھتے ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdviii{اور جو اپنی گواہیوں پر قائم رہتے ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdix{اور جو اپنی نمازوں کی حفاظت کرتے ہیں۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdx{یہی وہ لوگ ہیں جو عزت کے ساتھ باغہائے بہشت میں رہیں گے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxi{(اے نبی(ص)) ان کافروں کو کیا ہوگیا ہے کہ وہ ٹکٹکی باندھے آپ(ص) کی طرف دو ڑے چلے آرہے ہیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxii{دائیں اور بائیں طرف سے گروہ در گروہ۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiii{کیا ان میں سے ہر ایک یہ طمع و لالچ رکھتا ہے کہ اسے آرام و آسائش والے بہشت میں داخل کر دیا جائے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiv{ہرگز نہیں! ہم نے انہیں اس چیز (مادہ) سے پیدا کیا ہے جسے وہ خود جانتے ہیں۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxv{پس نہیں! میں قَسم کھاتا ہوں مشرقوں اور مغربوں کے پروردگار کی ہم پوری قدرت رکھتے ہیں۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvi{اس بات پر کہ ہم ان لوگوں کے بدلے ان سے بہتر لے آئیں اور ہم (ایسا کرنے سے) عاجز نہیں ہیں۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvii{تو آپ(ص) انہیں چھوڑئیے کہ وہ بےہودہ باتوں اور کھیل کود میں مشغول رہیں یہاں تک کہ وہ اپنے اس دن سے دوچار ہوں جس کا ان سے وعدہ وعید کیا جا رہا ہے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxviii{جس دن وہ قبروں سے اس طرح جلدی جلدی نکلیں گے گویا (اپنے بتوں کے) استھانوں کی طرف دوڑ رہے ہیں۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxix{ان کی آنکھیں جھکی ہوئی ہوں گی (اور) ان پر ذلت و رسوائی چھائی ہوگی۔ یہی وہ دن ہے جس کا ان سے وعدہ وعید کیا جاتا تھا۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxx{\basmalahur بےشک ہم نے نوح(ع) کو ان کی قوم کی طرف بھیجا کہ اپنی قوم کو ڈراؤ۔ اس سے پہلے کہ ان پر دردناک عذاب آجائے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxi{(چنانچہ) انہوں نے کہا کہ اے میری قوم! میں تمہیں ایک کھلا ہوا ڈرانے والا ہوں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxii{کہ تم (صرف) اللہ کی عبادت کرو اور اس (کی مخالفت) سے ڈرو اور میری اطاعت کرو۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiii{وہ (خدا) تمہارے (پہلے) گناہ بخش دے گا اور تمہیں ایک مقررہ مدت تک مہلت دے گا (باقی رکھے گا) بےشک جب اللہ کا مقررہ وقت آجاتا ہے تو پھر اسے مؤخر نہیں کیا جا سکتا کاش کہ تم (اس حقیقت کو) سمجھتے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiv{آپ(ع) (نوح(ع)) نے کہا اے مرے پروردگار میں نے اپنی قوم کو رات دن دعوت دی۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxv{مگر میری دعوت نے ان کے فرار (گریز) میں اور بھی اضافہ کیا۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvi{اور میں نے جب بھی انہیں دعوت دی کہ (وہ اس لائق ہوں کہ) تو انہیں بخش دے تو انہوں نے اپنی انگلیاں اپنے کانوں میں ٹھونس لیں اور اپنے کپڑے اپنے اوپر لپیٹ لئے اور (اپنی روش پر) اڑے رہے اور بڑا تکبر کرتے رہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvii{پھر بھی میں نے ان کو بآوازِ بلند دعوت دی۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxviii{پھر میں نے انہیں (ہر طرح دعوت دی) کھلم کھلا بھی اور چپکے چپکے بھی۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxix{(چنانچہ) میں نے (ان سے) کہا کہ اپنے پروردگار سے مغفرت طلب کرو وہ یقیناً بڑا بخشنے والا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxx{وہ تم پر آسمان سے موسلادھار بارش برسائے گا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxi{اور مال و اولاد سے تمہاری مدد فرمائے گا اور تمہارے لئے باغات پیدا کرے گا اور تمہارے لئے نہریں قرار دے گا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxii{تمہیں کیا ہوگیا ہے کہ تم اللہ کی عظمت کی پروانہیں کرتے؟\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiii{حالانکہ اس نے تمہیں طرح طرح سے خلق کیا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiv{کیا تم نہیں دیکھتے کہ اللہ نے کس طرح سات آسمان تہہ بر تہہ بنا ئے؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxv{اور ان میں چاند کو نور اور سورج کو چراغ بنایا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvi{اور تمہیں خاص طرح زمین سے اگایا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvii{پھر تمہیں اس میں لوٹائے گا اور پھر اسی سے (دوبارہ) نکالے گا۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxviii{اور اللہ نے ہی تمہارے لئے زمین کو بچھونا بنایا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxix{تاکہ تم اس کے کشادہ راستوں میں چلو پھرو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxl{نوح(ع) نے(بارگاہِ خداوندی میں) عرض کیا اے میرے پروردگار ان لوگوں نے میری نافرمانی کی ہے اور ان (بڑے) لوگوں کی پیروی کی ہے جن کے مال و اولاد نے ان کے خسارے میں اضافہ کیا ہے (اور کوئی فائدہ نہیں پہنچایا)۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxli{اور انہوں نے (میرے خلاف) بڑا مکر و فریب کیا ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlii{اور انہوں نے(عام لوگوں سے) کہا کہ (نوح(ع) کے کہنے پر) اپنے خداؤں کو ہرگز نہ چھوڑو۔ اور نہ ہی وَد اور سُواع کو چھوڑو اور نہ ہی یغوث و یعوق اور نسر کو چھوڑو۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliii{اور انہوں نے بہت سے لوگوں کو گمراہ کر دیا ہے (یا اللہ) تو بھی ان کی گمراہی کے سوا اور کسی چیز میں اضافہ نہ کر۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliv{(چنانچہ) وہ اپنی خطاؤں کی وجہ سے غرق کر دئیے گئے پھر آگ میں ڈال دئیے گئے پھر انہوں نے اللہ (کے عذاب) سے بچانے والے کوئی مددگار نہ پا ئے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlv{اور نوح(ع) نے کہا اے میرے پروردگار! تو ان کافروں میں سے کوئی بھی رُوئے زمین پر بسنے والا نہ چھوڑ۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvi{اگر تو انہیں چھوڑے گا تو یہ تیرے بندوں کو گمراہ کرینگے اور بدکار اور سخت کافر کے سوا کسی اور کو جنم نہیں دیں گے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvii{اے میرے پروردگار! مجھے اور میرے والدین کو بخش دے اور ہر اس شخص کو بخش دے جو مؤمن ہو کر میرے گھر میں داخل ہو اور سب مؤمنین و مؤمنات کی مغفرت فرما اور کافروں کی ہلاکت کے سوا اور کسی چیز میں اضافہ نہ کر۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlviii{\basmalahur (اے نبی (ص)) آپ(ص) کہئے! کہ مجھے وحی کی گئی ہے کہ جنات کے ایک گروہ نے (قرآن کو) توجہ کے ساتھ سنا پھر (جا کر اپنی قوم سے) کہا کہ ہم نے بڑا عجیب قرآن سنا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlix{جو بھلائی کی طرف راہنمائی کرتا ہے اس لئے ہم تو اس پر ایمان لے آئے اور اب ہم کسی کوبھی اپنے پروردگار کا شریک نہیں بنائیں گے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdl{اور یہ کہ ہمارے پروردگار کی شان بہت بلند ہے اس نے (اپنے لئے) نہ کوئی بیوی بنائی ہے اور نہ اولاد۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdli{اور یہ کہ ہمارے بےوقوف لوگ خدا کے بارے میں خلافِ حق (ناروا) باتیں کرتے رہتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlii{اور یہ کہ ہمارا خیال تھا کہ انسان اور جن خدا کے بارے میں ہرگز جھوٹی بات نہیں کہیں گے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliii{اور یہ کہ انسانوں میں سے کچھ لوگ جنات میں سے کچھ لوگوں کی پناہ لیا کرتے تھے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliv{اور یہ کہ انہوں (انسانوں) نے بھی تمہاری طرح یہ خیال کیا کہ اللہ کسی کو (دوبارہ زندہ کر کے) نہیں اٹھائے گا (یا کسی کو رسول بنا کر نہیں بھیجے گا)۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlv{اور یہ کہ ہم نے آسمان کو ٹٹولا تو اسے پایا کہ وہ سخت پہریداروں اور شہابوں سے بھر دیا گیا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvi{اور یہ کہ ہم (پہلے کچھ) سن گن لینے کیلئے آسمان کے بعض خاص مقامات پر بیٹھا کرتے تھے مگر اب جو (جن) سننے کی کوشش کرتا ہے تو وہ ایک شہاب کو اپنی گھات میں پاتا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvii{اور یہ کہ ہم نہیں سمجھتے کہ آیا زمین والوں کیلئے کسی برائی کا ارادہ کیا گیا ہے یا ان کے پروردگار نے ان کے ساتھ بھلائی کرنے کا ارادہ کیا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlviii{اور یہ کہ ہم میں سے کچھ نیک ہیں اور کچھ اور طرح اور ہم مختلف الرّائے لوگ تھے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlix{اور یہ کہ ہم سمجھتے ہیں کہ ہم زمین میں اللہ کو عاجز نہیں کر سکتے اور نہ ہی بھاگ کر اسے بےبس کر سکتے ہیں۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlx{اور یہ کہ ہم نے جب ہدایت کی بات سنی تو اس پر ایمان لے آئے پس جو اپنے پروردگار پر ایمان لائے گا تو اسے نہ کسی کمی (نقصان) کا خوف ہوگا اور نہ زیادتی کا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxi{اور یہ کہ ہم میں سے بعض مسلم (فرمانبردار) ہیں اور کچھ راہِ راست سے منحرف (نافرمان) ہیں پس جنہوں نے اسلام (فرمانبرداری) کی راہ اختیار کی تو انہوں نے بھلائی کا راستہ ڈھونڈھ لیا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxii{اور جو راہِ راست سے منحرف ہوں گے وہ جہنم کا ایندھن بنیں گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiii{اور یہ کہ اگر یہ لوگ راہِ راست پر ثابت قدم رہتے تو ہم انہیں خوب سیراب کرتے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiv{تاکہ اس نعمت سے ان کی آزمائش کریں اور جو شخص اپنے پروردگار کی یاد سے منہ موڑے گا خدا اسے ایسے سخت عذاب میں داخل کرے گا جو بڑھتا ہی جائے گا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxv{اور یہ کہ سجدہ کے مقامات خاص اللہ کیلئے ہیں لہذا اللہ کے ساتھ کسی اور کو نہ پکارو۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvi{اور یہ کہ جب بھی اللہ کا خاص بندہ (رسول (ص)) اس کو پکارنے کیلئے کھڑا ہوتا ہے تو (ایسا معلوم ہوتاہے کہ) لوگ اس پر ٹوٹ پڑیں گے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvii{آپ(ص) کہئے! کہ میں تو صرف اپنے پروردگار کو پکارتا ہوں اور کسی کو اس کا شریک قرار نہیں دیتا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxviii{کہیے! میں تمہارے لئے نہ کسی نقصان اور برائی کا اختیار رکھتا ہوں اور نہ کسی بھلائی کا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxix{آپ کہیے! کہ مجھے اللہ سے کوئی پناہ نہیں دے سکتا اور میں اس کے سوا اور کوئی جائے پناہ نہیں پاتا۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxx{(ہاں البتہ) میرا کام صرف یہ ہے کہ اللہ کی طرف سے تبلیغ کروں اور اس کے پیغامات (لوگوں تک) پہنچاؤں اور جو خدا اور اس کے رسول(ع) کی نافرمانی کرے گا تو اس کے لئے دوزخ کی آگ ہے جس میں (ایسے لوگ) ہمیشہ رہیں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxi{(یہ لوگ اپنی کجروی سے باز نہیں آئیں گے) یہاں تک کہ جب وہ وہ چیز (عذاب) دیکھ لیں گے جس کا ان سے وعدہ وعید کیا جا رہا ہے تو انہیں معلوم ہو جائے گا کہ مددگار اور تعداد کی حیثیت سے کون زیادہ کمزور ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxii{آپ(ص) کہہ دیجیے! کہ میں نہیں جانتا کہ جس چیز (عذاب) کا تم لوگوں سے وعدہ وعید کیا جارہا ہے کہ آیا وہ قریب ہے یا میرا پروردگار اس کیلئے کوئی طویل مدت مقرر کرتا ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiii{وہ (اللہ) عالِمُ الغیب ہے وہ اپنے غیب پر کسی کو مطلع نہیں کرتا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiv{سوائے اپنے اس رسول کے جسے وہ اس بات کے لئے منتخب کرتا ہے تو وہ اس کے آگے پیچھے محافظ (فرشتے) لگا دیتا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxv{تاکہ وہ معلوم کرے کہ انہوں نے اپنے پروردگار کے پیغامات کو پہنچا دیا ہے اور وہ ان کے حالات کا احاطہ کئے ہوئے ہے اور اس نے ہر چیز کو گن رکھا ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvi{\basmalahur اے کمبلی اوڑھنے والے (رسول(ص))۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvii{رات کو(نماز میں) کھڑے رہا کیجئے مگر (پوری رات نہیں بلکہ) تھوڑی رات۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxviii{یعنی آدھی رات یا اس میں سے بھی کچھ کم کر دیجئے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxix{یا اس سے کچھ بڑھا دیجئے! اور قرآن کو ٹھہر ٹھہر کر (اور واضح کر کے) پڑھا کیجئے! ۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxx{بےشک ہم آپ(ص) پر ایک بھاری کلام ڈالنے والے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxi{بےشک رات کا اٹھنا سخت روندتا ہے (اور سخت کوفت کا باعث ہے) مگر ذکر (خدا اور قرآن خوانی) کیلئے زیادہ موزوں اور ٹھیک ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxii{بلاشبہ دن میں آپ(ص) کیلئے بڑی مشغولیت ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiii{اور اپنے پروردگار کے نام کا ذکر کیجئے اور (سب سے کٹ کر) اسی کی طرف متوجہ ہو جائیے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiv{وہ مشرق و مغرب کا پروردگار ہے اس کے سوا کوئی خدا نہیں ہے۔ پس اسی کو اپنا کارساز بنائیے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxv{اور ان (کفار) کی باتوں پر صبر کیجئے! اور بڑی خوبصورتی کے ساتھ ان سے الگ ہو جائیے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvi{اور مجھے اور ان جھٹلانے والے اہلِ دولت کو چھوڑ دیجئے اور انہیں تھوڑی سی مہلت دیجئے!\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvii{ہمارے پاس ان کیلئے بیٹریاں اور دوزخ کی آگ ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxviii{اور گلے میں پھنس جانے والی غذا اور دردناک عذاب ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxix{یہ اس دن ہوگا جب زمین اور پہاڑ ہلنے لگیں گے اور پہاڑ ریت کے بکھر نے والے تودے بن جائیں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxc{ہم نے تمہاری طرف ایک رسول(ص) بھیجا ہے تم پر گواہ بنا کر جس طرح ہم نے فر عون کی طرف ایک رسول(ع) بھیجا تھا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxci{پھر جب فرعون نے رسول(ع) کی نافرمانی کی تو ہم نے اسے بڑا سخت پکڑا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcii{اگر تم نے کفر اختیار کیا تو اس دن کے عذاب سے کیونکر بچوگے جو بچوں کو بوڑھا بنا دے گا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciii{جس کی سختی سے آسمان پھٹ جائے گا (اور یہ) اللہ کا وعدہ ہے جو پورا ہو کر رہے گا۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciv{بےشک یہ ایک بڑی نصیحت ہے پس جو چاہے وہ اپنے پروردگار کی طرف راستہ اختیار کرے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcv{(اے رسول (ص)) یقیناً آپ(ص) کا پروردگار جانتا ہے کہ آپ(ص) کبھی رات کی دو تہائی کے قریب، کبھی نصف شب اور کبھی ایک تہائی (نماز کیلئے) قیام کرتے ہیں اور ایک گروہ آپ کے ساتھیوں میں سے بھی اور اللہ ہی رات اور دن کا اندازہ ٹھہراتا ہے (انہیں چھوٹا بڑا کرتا ہے) وہ جانتا ہے کہ تم لوگ (اس) وقت پر پوری طرح حاوی نہیں ہو سکتے (شمار نہیں کر سکتے) تو اس نے تمہارے حال پر توجہ (مہربانی) فرمائی تو اب جتنا قرآن تم آسانی سے پڑھ سکتے ہو اتنا ہی پڑھ لیا کرو وہ یہ بھی جانتا ہے کہ تم میں کچھ بیمار ہوں گے اور کچھ ایسے بھی ہوں گے جو اللہ کے فضل (روزی) کی تلاش میں زمین میں سفر کریں گے اور دوسرے لوگ ایسے بھی ہوں گے جو اللہ کی راہ میں جہاد کریں گے پس اتنا قرآن پڑھو جتنا میسر ہو اور نماز قائم کرو (پابندی سے پڑھو) اور زکوٰۃ ادا کرو اور اللہ کو قرضۂ حسنہ دو اور تم لوگ جو کچھ بھلائی (نیک عمل) اپنے لئے آگے بھیجو گے اسے اللہ کے ہاں موجود پاؤ گے وہی تمہارے لئے بہتر ہے اس کا ثواب بہت بڑا ہے اور اللہ سے مغفرت طلب کرو بےشک اللہ بڑا بخشنے والا اوربڑا رحم کرنے والا ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvi{\basmalahur اے چادر اوڑھنے والے (رسول(ص))۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvii{اٹھئے اور (لوگوں کو عذابِ الٰہی) سے ڈرائیے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcviii{اور اپنے پروردگار کی بڑائی بیان کیجئے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcix{اور اپنے کپڑے پاک رکھئے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmd{اور (بتوں کی) نجاست سے دور رہیے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdi{اور (کسی پر) احسان نہ کیجئے زیادہ حاصل کرنے کیلئے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdii{اور اپنے پروردگار کیلئے صبر کیجئے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiii{اور جب صور پھونکا جائے گا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiv{تو وہ دن بڑا سخت دن ہوگا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdv{اور کافروں پر آسان نہ ہوگا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvi{مجھے اور اس شخص کو چھوڑ دیجئے جسے میں نے تنہا پیدا کیا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvii{اور اسے پھیلا ہوا (فراواں) مال و زر دیا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdviii{اور پاس حاضر رہنے والے بیٹے دے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdix{اور اس کیلئے (سرداری کا) ہر قِسم کا سامان مہیا کیا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdx{پھر بھی وہ طمع رکھتا ہے کہ میں اسے زیادہ دوں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxi{ہرگز نہیں وہ تو ہماری آیتوں کا سخت مخالف ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxii{میں عنقریب (دوزخ کی) ایک سخت چڑھائی پر اسے چڑھا دوں گا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiii{اس نے سوچا اور ایک بات تجویز کی۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiv{سو وہ غارت ہو اس نے کیسی بات تجویز کی؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxv{پھر وہ غارت ہو اس نے کیسی بات تجویز کی؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvi{پھر اس نے دیکھا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvii{پھر اس نے تیوری چڑھائی اور منہ بنایا۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxviii{پھر پیٹھ پھیری اور تکبر کیا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxix{پھر کہا کہ یہ تو محض جادو ہے جو پہلوں سے نقل ہوتا ہوا آرہا ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxx{یہ نہیں ہے مگر آدمی کا کلام۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxi{میں عنقریب اسے دوزخ میں جھونکوں گا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxii{اور تم کیا سمجھو کہ دوزخ کیا ہے؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiii{وہ نہ (کوئی چیز) باقی رکھتی ہے اور نہ چھوڑتی ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiv{وہ کھال کو جھلس دینے والی ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxv{اس پر اُنیس فرشتے (دارو غے) مقرر ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvi{اور ہم نے دوزخ کے داروغے صرف فرشتے بنائے ہیں اور ہم نے ان کی تعداد کو کافروں کیلئے آزمائش کا ذریعہ بنایا ہے تاکہ اہلِ کتاب یقین کریں اور اہلِ ایمان کے ایمان میں اضافہ ہو جائے اور اہلِ کتاب اور اہلِ ایمان شک و شبہ نہ کریں اور جن کے دلوں میں بیماری ہے اور کافر لوگ کہیں گے کہ اس بیان سے اللہ کی کیا مراد ہے؟ اسی طرح اللہ جسے چاہتا ہے گمراہی میں چھوڑ دیتا ہے اور یہ (دوزخ کا) بیان نہیں ہے مگر انسانوں کے لئے نصیحت۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvii{ہرگز نہیں! قَسم ہے چاند کی۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxviii{اور رات کی جب وہ جانے لگے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxix{اور صبح کی جب وہ روشن ہو جائے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxx{وہ (دوزخ) بڑی چیزوں میں سے ایک بڑی چیز ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxi{(جو) انسانوں کیلئے ڈراوا ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxii{یعنی تم میں سے (ہر اس) شخص کیلئے جو آگے بڑھنا چاہے یا پیچھے ہٹنا چاہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiii{ہر شخص اپنے اعمال کے بدلے میں گروی ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiv{سوائے دائیں ہاتھ والے (جنتیوں) کے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxv{جو بہشت کے باغوں میں ہوں گے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvi{(اور) مجرموں سے سوال و جواب کرتے ہوں گے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvii{کہ تمہیں کیا چیز دوزخ میں لے گئی؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxviii{وہ کہیں گے کہ ہم نماز نہیں پڑھا کرتے تھے۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxix{اور مسکینوں کو کھانا نہیں کھلاتے تھے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxl{اور بےہودہ باتیں کرنے والوں کے ساتھ مل کر ہم بھی بےہودہ کام کرتے تھے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxli{اور ہم جزا و سزا کے دن کو جھٹلاتے تھے۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlii{یہاں تک کہ یقینی چیز (موت) ہمارے سامنے آگئی۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliii{تو ایسے لوگوں کو شفاعت کرنے والوں کی شفاعت کوئی فائدہ نہیں پہنچائے گی۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliv{سو انہیں کیا ہوگیا ہے کہ وہ نصیحت سے رُوگردانی کرتے ہیں؟\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlv{گویا وہ بدکے ہوئے گدھے ہیں۔\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvi{جوشیر سے (ڈر کر) بھاگے جا رہے ہیں۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvii{بلکہ ان میں سے ہر ایک شخص یہ چاہتا ہے کہ اسے کھلی ہوئی کتابیں دے دی جائیں۔\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlviii{ایسا نہیں ہے بلکہ وہ آخرت کا خوف نہیں رکھتے۔\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlix{ہرگز نہیں یہ تو ایک نصیحت ہے۔\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmdl{جو چاہے اس سے نصیحت حاصل کرے۔\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmdli{اور وہ اس سے نصیحت حاصل نہیں کریں گے مگر یہ کہ اللہ چاہے وہی اس کا حق دار ہے کہ اس سے ڈرا جائے اور وہی اس قابل ہے کہ مغفرت فرمائے۔\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlii{\basmalahur نہیں! میں قَسم کھاتا ہوں قیامت کے دن کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliii{اور نہیں! میں قَسم کھاتا ہوں ملامت کرنے والے نفس کی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliv{کیا انسان یہ گمان کرتا ہے کہ ہم اس کی (بوسیدہ) ہڈیوں کو جمع نہیں کریں گے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlv{ہاں ضرور جمع کریں گے ہم اس کی انگلیوں کے پور پور درست کرنے پر قادر ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvi{بلکہ انسان چاہتا ہے کہ اپنے آگے (آئندہ زندگی میں) بھی بدعملی کرتا رہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvii{(اس لئے) پوچھتا ہے کہ قیامت کا دن کب آئے گا؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlviii{پس جب نگاہ خیرہ ہو جائے گی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlix{اور چاند کو گہن لگ جائے گا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlx{اور سورج اور چاند اکٹھے کر دئیے جائیں گے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxi{اس دن انسان کہے گا کہ بھاگنے کی جگہ کہاں ہے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxii{ہرگز نہیں! کہیں کوئی پناہ گاہ نہیں ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiii{اس دن صرف آپ(ص) کے پروردگار کی طرف ٹھکانہ ہوگا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiv{اس دن انسان کو بتایا جائے گا کہ اس نے کیا (عمل) آگے بھیجا اور کیا پیچھے چھوڑا؟\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxv{بلکہ خود انسان اپنے حال کو خوب جانتا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvi{اگرچہ کتنے ہی بہانے پیش کرے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvii{(اے رسول (ص)) آپ(ص) اپنی زبان کو اس (قرآن) کے ساتھ حرکت نہ دیجئے تاکہ اسے جلدی جلدی (حفظ) کر لیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxviii{بیشک اس کا جمع کرنا اور اس کا پڑھانا ہماے ذمہ ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxix{پس جب ہم اسے پڑھیں تو آپ(ص) بھی اسی کے مطابق پڑھیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxx{پھر اس کا واضح کرنا بھی ہمارے ذمہ ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxi{ہرگز نہیں بلکہ تم جلدی ملنے والی (دنیا) سے محبت کرتے ہو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxii{اور آخرت (دیر سے آنے والی) کو چھوڑتے ہو۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiii{اس دن کچھ چہرے تر و تازہ ہوں گے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiv{اپنے پروردگار کی نعمت (و رحمت) کو دیکھ رہے ہوں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxv{اور کئی چہرے اس دن بےرونق ہوں گے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvi{وہ سمجھ رہے ہوں گے کہ ان کے ساتھ کمر توڑ دینے والا سلوک کیا جائے گا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvii{ہرگز نہیں جب جان (کھینچ کر) حلق تک پہنچ جائے گی۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxviii{اور کہاجائے گا کہ اب کون ہے جھاڑ پھونک کرنے والا؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxix{اور وہ سمجھ لے گا کہ اب (دنیا سے) جدائی کا وقت ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxx{اور پنڈلی سے پنڈلی لپٹ جائے گی۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxi{اس دن تمہارے پروردوگار کی طرف کھینچ کرجانا ہوگا۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxii{(اتنا کچھ سمجھانے کے باوجود اس مخصوص آدمی نے) نہ تصدیق کی اور نہ نماز پڑھی۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiii{بلکہ اس نے جھٹلایا اور منہ پھیر لیا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiv{پھر اکڑتا ہوا اپنے گھر والوں کی طرف چلا گیا۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxv{یہ (روش) تیرے ہی لئے سزاوار ہے اور تیرے ہی لائق ہے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvi{پھر یہ تیرے ہی لائق ہے اور تیرے ہی لئے سزوار ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvii{کیا انسان یہ گمان کرتا ہے کہ اسے یونہی مہمل چھوڑ دیا جائے گا؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxviii{کیاوہ شروع میں منی کا ایک قطرہ نہ تھا جو (رحم میں) ٹپکایا جاتا ہے؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxix{پھر وہ ایک لوتھڑا بنا پھر اس (خدا) نے اسے پیدا کیا اور پھر (اس کے) اعضاء درست کئے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxc{پھر اس سے دو قِسمیں بنائیں مرد و عورت۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxci{کیا وہ اس بات پر قادر نہیں ہے کہ وہ مُردوں کو پھر زندہ کر دے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcii{\basmalahur بےشک انسان پر زمانہ میں ایک ایسا وقت گزر چکا ہے جب وہ کوئی قابلِ ذکر چیز نہ تھا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciii{بےشک ہم نے انسان کو مخلوط نطفے سے پیدا کیا تاکہ ہم اسے آزمائیں پس اس لئے ہم نے اسے سننے والا (اور) دیکھنے والا بنایا۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciv{بلاشبہ ہم نے اسے راستہ دکھا دیا ہے اب چاہے شکر گزار بنے اور چاہے ناشکرا بنے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcv{بےشک ہم نے کافروں کیلئے زنجیریں، طوق اور بھڑکتی ہوئی آگ تیار کر رکھی ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvi{بلاشبہ نیکوکار (جنت میں شرابِ طہور کے) ایسے جام پئیں گے جن میں (آبِ کافور) کی آمیزش ہوگی۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvii{یعنی وہ ایک چشمہ ہے جس سے اللہ کے (خاص) بندے پئیں گے اور جدھر جائیں گے ادھر بہا کرلے جائیں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcviii{یہ وہ لوگ ہیں جو اپنی نذریں (منتیں) پوری کرتے ہیں اور اس دن سے ڈرتے ہیں جس کی سختی عام ہوگی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcix{اور وہ اس (اللہ) کی محبت میں مسکین، یتیم اور قیدی کو کھانا کھلاتے ہیں۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdc{(اور کہتے ہیں کہ) ہم تمہیں صرف اللہ کی خوشنودی کیلئے کھلاتے ہیں نہ تم سے کوئی جزا چاہتے ہیں اورنہ شکریہ۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdci{ہم تو اپنے پروردگار کی طرف سے ایک ایسے دن (کے عذاب) سے ڈرتے ہیں جو بڑا ترش اور سخت ہوگا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcii{پس اللہ ان کو اس دن کے شر سے بچائے گا اور انہیں (چہروں کی) تر و تازگی اور (دلوں کا) سُرور عطا فرمائے گا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciii{اور ان کے صبر کے صلہ میں انہیں بہشت اور ریشمی لباس عطا فرمائے گا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciv{وہ وہاں اونچی مسندوں پر تکیہ لگائے بیٹھے ہوں گے وہ وہاں نہ سورج (کی گرمی) دیکھیں گے اور نہ سردی کی ٹھٹھر۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcv{ان (باغہائے بہشت) کے سائے ان پر جھکے ہوئے ہوں گے اور ان کے میوے ان کی دسترس میں ہوں گے (کہ ہر وقت بلاتکلف کھا سکیں گے)۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvi{اور ان کے سامنے چاندی کے برتن اور شیشہ کے چمکدار گلاس گردش میں ہوں گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvii{اور شیشے بھی (کانچ کے نہیں بلکہ) چاندی کی قِسم سے ہوں گے جنہیں (منتظمین نے) پورے اندازے کے مطابق بنایا اور بھرا ہوگا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcviii{اور انہیں ایسی شرابِ طہور کے جام پلائے جائیں گے جن میں زنجیل (سونٹھ کے پانی) کی آمیزش ہوگی۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcix{یہ اس (جنت) میں ایک چشمہ ہے جسے سلسبیل کہاجاتا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcx{اور ان کی خدمت کیلئے ایسے لڑکے گردش کر رہے ہوں گے جو ہمیشہ ایک حالت میں رہیں گے جب تم انہیں دیکھو گے تو سمجھو گے کہ وہ بکھرے ہوئے موتی ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxi{تم وہاں جدھر بھی دیکھو گے وہیں عظیم نعمت اور عظیم بادشاہی دیکھو گے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxii{ان کے اوپر باریک ریشم کے سبز کپڑے ہوں گے اور دبیز ریشم کے کپڑے بھی اور انہیں چاندی کے کنگن پہنائے جائیں گے اور انکا پروردگار انہیں پاک و پاکیزہ شراب پلائے گا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiii{یہ تمہاری جزا ہے اور تمہاری کوشش شکرگزاری کے قابل ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiv{ہم ہی نے آپ پر تھوڑا تھوڑا کر کے قرآن نازل کیا ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxv{اور اپنے پروردگار کے حکم کی خاطر صبر کیجئے اور ان میں سے کسی گنہگار یا ناشکرگزار (منکر) کی بات نہ مانئیے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvi{اور صبح و شام اپنے پروردگار کانام یاد کیجئے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvii{اور رات کے ایک حصے میں اس کو سجدہ کیجئے اور رات کے طویل حصہ میں اس کی تسبیح کیجئے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxviii{بےشک یہ لوگ دنیائے عاجل سے محبت رکھتے ہیں اور (آگے آنے والے) ایک بھاری دن (قیامت) کو اپنے پسِ پشت ڈال رکھا ہے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxix{بےشک ہم نے ان کو پیدا کیا ہے اور ہم نے ہی ان کے جوڑ بند مضبوط کئے ہیں اور ہم ہی جب چاہیں گے تو ان کی جگہ انہی جیسے لوگ بدل دیں گے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxx{بےشک یہ ایک بڑی نصیحت ہے تو جو چاہے اپنے پروردگار کا راستہ اختیار کرے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxi{اور تم نہیں چاہتے ہو مگر وہی جو خدا چاہتا ہے بےشک اللہ بڑا جاننے والا، بڑا حکمت والا ہے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxii{وہ جسے چاہتا ہے اپنی رحمت میں داخل کرتا ہے اور اس نے ظالموں کیلئے دردناک عذاب تیار کر رکھا ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiii{\basmalahur قَسم ہے ان کی جو مسلسل چھوڑ دی جاتی ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiv{پھر (آندھی کی طرح) تیز و تند چلتی ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxv{جو (بادلوں کو) پھیلانے والی ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvi{پھر (انہیں) متفرق کر دیتی ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvii{پھر (دلوں میں) یاد (الٰہی) ڈالتی ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxviii{(حجت تمام کر کے) عذر قطع کرنے کیلئے یا ڈراوے کیلئے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxix{بےشک جس چیز کا تم سے وعدہ وعید کیا جا رہا ہے وہ ضرور واقع ہو نے والی ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxx{پس جب ستارے گرائے جائیں گے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxi{اور آسمان پھاڑ دیا جائے گا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxii{اور جب پہاڑ (ریزہ ریزہ کر کے) اڑا دیئے جائیں گے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiii{اور جب رسول(ع) وقتِ معیّن پر حاضر کئے جائیں گے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiv{(آخر) کس دن کیلئے یہ تاخیر کی گئی؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxv{فیصلے کے دن کے لئے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvi{تجھے کیا معلوم کہ فیصلے کا دن کیا ہے؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvii{تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxviii{کیا ہم نے پہلے والوں کو ہلاک نہیں کیا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxix{پھر ان کے پیچھے بھیجے گئے لوگوں کو۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxl{ہم مجرموں کے ساتھ ایسا ہی (سلوک) کرتے ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxli{تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlii{کیا ہم نے تمہیں ایک حقیر پانی سے پیدانہیں کیا؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliii{پھر ہم نے اس کو ایک محفوظ مقام (رحمِ مادر) میں رکھا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliv{ایک مقررہ مدت تک۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlv{(اس سے ثابت ہوا کہ) ہم قادر ہیں پس ہم کیسے اچھے قادر ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvi{(ہم کیسا اچھا اندازہ کرنے والے ہیں) تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvii{کیا ہم نے زمین کو سمیٹ کر رکھنے والی نہیں بنایا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlviii{زندوں کو بھی اور مُردوں کو بھی۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlix{اور ہم نے اس میں بلند و بالا پہاڑ بنائے اور تمہیں خوشگوار (اور میٹھے) پانی سے سیراب کیا۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcl{تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcli{(حکم ہوگا) جاؤ اس (دوزخ) کی طرف جسے تم جھٹلایا کرتے تھے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclii{جاؤ اس سایہ کی طرف جس کی تین شاخیں ہیں۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliii{جو نہ سایہدار ہے اور نہ آگ کے شعلوں سے بچاتا ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliv{وہ (دوزخ) اونچے مَحلوں کی مانند انگارے پھینکتی ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclv{گویا کہ وہ زرد رنگ کے اونٹ ہیں۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvi{تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvii{یہ وہ دن ہوگا جس میں وہ بول نہیں سکیں گے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclviii{اور نہ ہی انہیں اجازت دی جائے گی کہ معذرت کر سکیں۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclix{تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclx{یہ فیصلے کا دن ہے جس میں ہم نے تمہیں اور پہلے والوں کو جمع کر دیا ہے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxi{اگر تمہارے پاس (دوزخ سے بچنے کے لئے) کوئی تدبیر ہے تو میرے مقابلہ میں چلاؤ۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxii{تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiii{بےشک پرہیزگار لوگ (اس دن) (رحمتِ خدا کے) سایوں میں اور چشموں میں ہوں گے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiv{اور ان پھلوں میں ہوں گے جنہیں وہ چاہیں گے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxv{(ان سے کہاجائے گا) مزے سے کھاؤ اور پیو اپنے ان اعمال کے صلے میں جو تم (دنیا میں) کرتے رہے ہو۔\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvi{بےشک ہم نیکوکاروں کو اسی طرح جزا دیتے ہیں۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvii{تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxviii{(اے جھٹلانے والو) تم تھوڑے دن (دنیا میں) کھا لو اورفائدہ اٹھا لو (بہرحال) تم لوگ مجرم ہو۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxix{تباہی ہے اس دن کے جھٹلانے والوں کیلئے۔\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxx{اور جب ان سے کہا جاتا ہے کہ کہ رکوع کرو تو وہ رکوع نہیں کرتے۔\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxi{تباہی ہے اس دن کے جھٹلانے والوں کے لئے۔\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxii{(آخر) وہ لوگ اس (قرآن) کے بعد کس کلام پر ایمان لائیں گے؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiii{\basmalahur یہ لوگ کس چیز کے بارے میں ایک دوسرے سے سوال و جواب کر رہے ہیں؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiv{کیا اس بڑی خبر کے بارے میں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxv{جس کے متعلق وہ باہم اختلاف کر رہے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvi{ہرگز نہیں! عنقریب انہیں معلوم ہو جائے گا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvii{پھر ہرگز نہیں! عنقریب انہیں معلوم ہو جائے گا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxviii{کیا ہم نے زمین کو بچھونا نہیں بنایا؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxix{اور پہاڑوں کو میخیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxx{اور ہم نے تمہیں جوڑا جوڑا پیدا کیا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxi{اور تمہاری نیند کو راحت و آرام کا ذریعہ۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxii{اور رات کو پردہ پوش۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiii{اور دن کو تحصیلِ معاش کا وقت بنایا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiv{اور ہم نے تم پر سات مضبوط (آسمان) بنائے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxv{اور ہم ہی نے (دن میں) ایک نہایت روشن چراغ (سورج) بنایا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvi{اور ہم نے پانی سے لبریز بادلوں سے موسلادھار پانی برسایا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvii{تاکہ ہم اس کے ذریعہ سے غلہ اور سبزی اگائیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxviii{اور گھنے باغات۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxix{بےشک فیصلے کے دن (قیامت) کا ایک معیّن وقت ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxc{جس دن صور پھونکا جائے گا تو تم لوگ فوج در فوج آؤ گے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxci{اور آسمان کھول دیا جائے گا اور وہ دروازے ہی دروازے ہو جائے گا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcii{اور پہاڑ چلائے جائیں گے اور وہ بالکل سراب ہو جائیں گے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciii{بےشک جہنم گھات میں ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciv{جو سرکشوں کا ٹھکانہ ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcv{وہ اس میں مدتہائے دراز تک پڑے رہیں گے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvi{وہ اس میں نہ ٹھنڈک کامزہ چکھیں گے اور نہ کوئی پینے کی چیز۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvii{سوائے گرم پانی اور پیپ کے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcviii{یہ (ان کے اعمال) کے مطابق بدلہ ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcix{یہ لوگ (روزِ) حساب (قیامت) کی توقع ہی نہیں رکھتے تھے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcc{اور یہ ہماری آیتوں کو بےدریغ جھٹلاتے تھے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcci{اور ہم نے ہر چیز کو ایک نوشتہ میں شمار کر رکھا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccii{چکھو اس کامزہ ہم تمہارے عذاب میں اضافہ ہی کریں گے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciii{بےشک پرہیزگاروں کیلئے کامیابی و کامرانی ہے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciv{یعنی باغ اور انگور ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccv{اور اٹھتی جوانیوں والی ہم عمر لڑکیاں (حوریں)۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvi{اور چھلکتے ہوئے (شرابِ طہور کے) جام۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvii{وہ لوگ وہاں نہ کوئی بےہودہ بات سنیں گے اور نہ کوئی جھوٹ۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccviii{یہ تمہارے پروردگار کی طرف سے بطور عطیہ صلہ ہے جو کافی و وافی ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccix{یعنی وہ ربِ رحمان کی طرف سے جو آسمانوں اور زمین اور ان کے درمیان کی سب چیزوں کا پروردگار (اور مالک) ہے (جس کی ہیبت سے) لوگوں کو اس سے بات کرنے کایارا نہیں ہے۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccx{جس دن روح اور فرشتے صف باندھے کھڑے ہوں گے کوئی بات نہیں کرے گا مگر جسے خدائے رحمان اجازت دے گا اور وہ ٹھیک بات کہے گا۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxi{یہ دن برحق ہے پس جو چاہے اپنے پروردگار کی طرف اپنا ٹھکانہ بنائے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxii{بےشک ہم نے تمہیں عنقریب آنے والے عذاب سے ڈرا دیا ہے جس دن آدمی وہ (کمائی) دیکھے گا جو اس کے ہاتھوں نے آگے بھیجی ہوگی اور کافر کہے گا کہ کاش میں مٹی ہوتا۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiii{\basmalahur قَسم ہے ان (فرشتوں) کی جو (جسم میں ڈوب کر) سختی سے (جان) کھینچتے ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiv{اور قَسم ہے آہستگی اور آسانی سے (جان) نکالنے والوں کی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxv{اور قَسم ہے (فضاؤں کے اندر) تیر نے پھرنے والوں کی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvi{پھر قَسم ہے (تعمیلِ حکم میں) ایک دوسرے پر سبقت لے جانے والوں کی۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvii{پھر قَسم ہے ہر امر کا بندوبست کرنے والوں کی (کہ قیامت برحق ہے)۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxviii{جس دن تھرتھرانے والی (زمین وغیرہ) تھرتھرائے گی۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxix{اس کے پیچھے ایک اور آنے والی (مصیبت) آئے گی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxx{کچھ دل اس دن کانپ رہے ہوں گے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxi{ان کی آنکھیں (شدتِ خوف سے) جھکی ہوئی ہوں گی۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxii{وہ (کافر لوگ) کہتے ہیں کیا ہم پہلی حالت میں (الٹے پاؤں) واپس لائے جائیں گے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiii{کیا جب ہم بوسیدہ ہڈیاں ہو جائیں گے؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiv{کہتے ہیں یہ (واپسی) تو بڑے گھاٹے کی ہوگی۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxv{حالانکہ اس (واپسی) کیلئے ایک زور کی ڈانٹ پڑے گی۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvi{پھر وہ کھلے ہوئے میدان (قیامت) میں موجود ہوں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvii{(اے رسول(ص)) کیا آپ(ص) کو موسیٰ(ع) کے قصہ کی خبر پہنچی ہے؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxviii{جب ان کے پروردگار نے طویٰ کی مقدس وادی میں انہیں پکارا تھا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxix{کہ جاؤ فرعون کے پاس کہ وہ سرکش ہوگیا ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxx{پس اس سے کہو کہ کیا تو چاہتا ہے کہ پاکیزگی اختیار کرے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxi{اور (کیا تو چاہتا ہے کہ) میں تیرے پروردگار کی طرف تیری راہنمائی کروں تو تُو (اس سے) ڈرے؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxii{پس موسیٰ(ع) نے (وہاں جا کر) اسے ایک بہت بڑی نشانی دکھائی۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiii{تو اس نے جھٹلایا اور نافرمانی کی۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiv{پھر وہ پلٹا (اور مخالفانہ سرگرمیوں میں) کوشاں ہو گیا۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxv{یعنی (لوگوں کو) جمع کیا اور پکار کر کہا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvi{کہ میں تمہارا سب سے بڑا پرورگار ہوں۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvii{پس اللہ نے اسے آخرت اور دنیا کے (دوہرے) عذاب میں پکڑا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxviii{بےشک اس (قصہ) میں بڑی عبرت ہے ہر اس شخص کیلئے جو (خدا سے) ڈرے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxix{کیا تم لوگوں کا (دوبارہ) پیدا کرنا زیادہ مشکل ہے؟ یا آسمان کا؟ اللہ نے اس کو بنایا۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxl{اور اس کی چھت کو بلند کیا پھر اس کو درست کیا۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxli{اور اس کی رات کو تاریک بنایا اور اس کے دن کو ظاہر کیا۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlii{اس کے بعد زمین کو بچھایا۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliii{اور اس سے اس کا پانی اور چارہ نکالا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliv{اور پہاڑوں کو اس میں گاڑا۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlv{تمہارے اور تمہارے مو یشیوں کے لئے سامانِ زندگی کے طور پر۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvi{پس جب بڑی آفت (قیامت) آئے گی۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvii{جس دن انسان یاد کرے گا جو کچھ اس نے کیا ہوگا۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlviii{اور (ہر) دیکھنے والے کیلئے دوزخ ظاہر کر دی جائے گی۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlix{پس جس شخص نے سرکشی کی ہوگی۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccl{اور (آخرت پر) دنیٰوی زندگی کو ترجیح دی ہوگی۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccli{تو اس کا ٹھکانہ دوزخ ہوگا۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclii{اور جو شخص اپنے پروردگار کی بارگاہ میں حاضری سے ڈرتا رہا ہوگا اور (اپنے) نفس کو (اس کی) خواہش سے روکا ہوگا۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliii{تو اس کا ٹھکانہ جنت ہے۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliv{یہ لوگ آپ(ص) سے سوال کرتے ہیں کہ قیامت کب کھڑی (برپا) ہوگی۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclv{آپ(ص) کا اس کے وقت بتانے سے کیا تعلق؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvi{اس کی انتہا تو بس آپ(ص) کے پروردگار پر ہے۔\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvii{آپ(ص) تو بس ڈرانے والے ہیں اس شخص کو جو اس سے ڈرے۔\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclviii{جس دن یہ لوگ اس (قیامت) کو دیکھیں گے تو (انہیں ایسا محسوس ہوگا کہ) وہ (دنیا میں) نہیں ٹھہرے تھے۔ مگر ایک شام یا اس کی ایک صبح۔\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclix{\basmalahur (ایک شخص نے) تیوری چڑھائی اور منہ پھیر لیا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclx{کہ اس (پیغمبرِ اسلام (ص)) کے پاس ایک نابینا آیا۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxi{اور تمہیں کیا معلوم شاید وہ پاکیزہ ہو جاتا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxii{یا نصیحت حاصل کرتا اور نصیحت اسے فائدہ پہنچاتی۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiii{جوشخص مالدار ہے (یا بےپروائی کرتا ہے)۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiv{تو تم اس کی طرف تو توجہ کرتے ہو۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxv{حالانکہ تم پر کوئی الزام نہیں اگر وہ پاکیزہ نہیں ہوتا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvi{اور جو تمہارے پاس دوڑتا ہوا (شوق سے) آتا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvii{اور (خدا سے) ڈرتا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxviii{تو تم اس سے بےرُخی بر تتے ہو۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxix{ہرگز نہیں! یہ (قرآن) تو ایک نصیحت ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxx{جو چاہے اسے قبول کرے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxi{یہ (قرآن) ان صحیفوں میں درج ہے جو مکرم ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxii{بلند مر تبہ (اور) پاک و پاکیزہ ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiii{جو ایسے کاتبوں کے ہاتھوں سے (لکھے ہوئے) ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiv{جو معزز اور نیکوکار ہیں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxv{غارت ہو (منکر) انسان یہ کتنا بڑا ناشکرا ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvi{اللہ نے اسے کس چیز سے پیدا کیا ہے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvii{نطفہ سے اسے پیدا کیا ہے اور پھر اس کے اعضاء و جوا رح کا اندازہ مقرر کیا ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxviii{پھر (زندگی کا) راستہ اس کے لئے آسان کر دیا۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxix{پھر اس کو موت دی پھر اسے قبر میں پہنچایا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxx{پھر جب چاہے گا اسے دوبارہ زندہ کر دے گا۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxi{ہرگز نہیں (بایں ہمہ) اس نے اسے پورا نہ کیا جس کا (خدا نے) اسے حکم دیا تھا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxii{انسان کو چاہیے کہ وہ اپنی غذا کی طرف دیکھے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiii{ہم نے اچھی طرح خوب پانی برسایا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiv{پھر ہم نے زمین کو اچھی طرح شگافتہ کیا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxv{پھر ہم نے اس میں غلے۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvi{اور انگور اور ترکاریاں اگائیں۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvii{اور زیتون اور کجھوریں۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxviii{اور گھنے باغ۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxix{اور میوے اور چارا۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxc{جو تمہارے اور تمہارے مویشوں کیلئے سامانِ زندگی کے طور پر ہے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxci{پس جب کانوں کو پھاڑ دینے والی آواز آجائے گی۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcii{تو اس دن آدمی اپنے بھائی سے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciii{اور اپنی ماں اور اپنے باپ سے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciv{اور اپنی بیوی اور اپنے بیٹوں سے بھاگے گا۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcv{اس دن ان میں ہر شخص کا یہ عالم ہوگا جو اسے سب سے بےپروا کر دے گا۔\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvi{کچھ چہرے اس دن روشن ہوں گے۔\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvii{خنداں و شاداں (اور خوش و خرم) ہوں گے۔\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcviii{ور کچھ چہرے ایسے ہوں گے جن پر گرد و غبار پڑی ہوئی ہوگی۔\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcix{اور ان پر سیاہی چھائی ہوگی۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccc{اور یہی لوگ کافر و فاجر ہوں گے۔\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccci{\basmalahur جب سورج (کی بساط) لپیٹ دی جائے گی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccii{اور ستارے (بکھر کر) بےنور ہو جائیں گے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciii{اور جب پہاڑ چلا دئیے جائیں گے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciv{اور جب حاملہ اونٹیاں آوارہ پھریں گی۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccv{اور جب وحشی جانور اکٹھے کر دئیے جائیں گے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvi{اور جب سمندر بھڑکا دئیے جائیں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvii{اور جب جانیں (جِسموں سے) ملا دی جائیں گی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccviii{اور جب زندہ درگور کی ہوئی (لڑکی) سے پوچھا جائے گا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccix{کہ وہ کس گناہ پر قتل کی گئی؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccx{اور جب اعمال نامے کھولے جائیں گے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxi{اور جب آسمان کھول دیا جائے گا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxii{اور جب دوزخ بھڑکا دی جائے گی۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiii{اور جب جنت قریب لے آئی جائے گی۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiv{تب ہر شخص کو معلوم ہو جائے گا کہ اس نے کیا لا کر پیش کیا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxv{تو نہیں! میں قَسم کھاتا ہوں پیچھے ہٹنے والے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvi{سیدھے چلنے اور چھپ جانے والے ستاروں کی۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvii{اور قَسم کھاتا ہوں رات کی جب وہ جانے لگے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxviii{اور صبح کی جب وہ سانس لے کر آنے لگے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxix{بےشک یہ (قرآن) ایک معزز پیغامبر(ص) کا قول ہے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxx{جو قوت والا ہے اور مالکِ عرش کے نزدیک بلند مرتبہ ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxi{(وہاں) اس کا حکم مانا جاتا ہے اور پھر وہ امانتدار (بھی) ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxii{اور تمہارا ساتھی (پیغمبرِ اسلام (ص)) دیوانہ نہیں ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiii{اور اس (پیغمبر(ص)) نے اس (پیغامبر) کو روشن افق (کنارے) پر دیکھا ہے۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiv{اور وہ غیب کی باتوں کے معاملہ میں بخیل نہیں ہے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxv{اور وہ (قرآن) کسی مردود شیطان کا قول نہیں ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvi{تم کدھر جا رہے ہو؟\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvii{وہ نہیں ہے مگر تمام دنیا جہان کے لئے نصیحت۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxviii{یعنی اس کیلئے جو تم میں سے سیدھی راہ پر چلنا چاہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxix{اور تم نہیں چاہتے مگر وہی جو عالمین کا پرورگار چاہتا ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxx{\basmalahur اور جب آسمان پھٹ جائے گا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxi{اور جب ستارے بکھر جائیں گے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxii{اور جب سمندر بہہ پڑیں گے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiii{اور جب قبریں تہ و بالا کر دی جائیں گی۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiv{تب ہر شخص کو معلوم ہو جائے گا کہ اس نے آگے کیا بھیجا ہے اور پیچھے کیا چھوڑا ہے؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxv{اے انسان تجھے کس چیز نے اپنے (رحیم و) کریم پروردگار سے دھو کے میں ڈال رکھا ہے؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvi{جس نے تجھے پیدا کیا پھر (تیرے اعضاء کو) درست بنایا (اور) پھر تجھے متناسب بنایا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvii{جس شکل میں چاہا تجھے ترتیب دے دیا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxviii{ہرگز نہیں! بلکہ (اصل حقیقت یہ ہے کہ) تم جزا و سزا (کے دن) کو جھٹلاتے ہو۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxix{حالانکہ تم پر نگران (ملائکہ) مقرر ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxl{معزز لکھنے والے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxli{وہ جانتے ہیں جو کچھ تم کرتے ہو۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlii{بےشک نیکوکار لوگ عیش و آرام میں ہوں گے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliii{اور بدکار لوگ دوزخ میں ہوں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliv{وہ جزا (سزا) والے دن اس میں داخل ہوں گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlv{اور وہ اس سے اوجھل نہیں ہوں گے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvi{تمہیں کیا معلوم کہ وہ جزا و سزا کا دن کیا ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvii{(پھر سنو) تمہیں کیا معلوم کہ جزا (و سزا) والا دن کیا ہے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlviii{جس دن کوئی کسی دوسرے کے کام نہ آسکے گا اور اس دن معاملہ (اختیار) اللہ ہی کے قبضۂ قدرت میں ہوگا۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlix{\basmalahur بربادی ہے ناپ تول میں کمی کرنے (ڈنڈی مارنے) والوں کے لئے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccl{جب وہ (اپنے لئے) لوگوں سےناپ کر لیں تو پورا لیتے ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccli{اور جب لوگوں کو ناپ کر یا تول کر دیتے ہیں تو انہیں گھاٹا دیتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclii{کیا یہ لوگ خیال نہیں کرتے کہ وہ (دوبارہ زندہ کر کے) اٹھائے جائیں گے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliii{ایک بڑے (سخت) دن کیلئے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliv{جس دن تمام لوگ ربُ العالمین کی بارگاہ میں پیشی کیلئے کھڑے ہوں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclv{ہرگز نہیں! بےشک بدکاروں کا نامۂ اعمال سِجِّین (قید خانہ کے دفتر) میں ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvi{تمہیں کیا معلوم کہ سِجِّین کیا ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvii{یہ ایک لکھی ہوئی کتاب ہے (جس میں بدکاروں کے عمل درج ہیں)۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclviii{بربادی ہے اس دن جھٹلانے والوں کیلئے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclix{جو جزا و سزا کے دن (قیامت) کو جھٹلاتے ہیں۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclx{اور اس دن کو نہیں جھٹلاتا مگر وہ شخص جو حد سے گزر نے والا (اور) گنہگار ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxi{کہ جب اس کے سامنے ہماری آیتیں پڑھی جاتی ہیں تو وہ کہتا ہے کہ یہ تو پہلے زمانے والوں کے افسانے ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxii{ہرگز نہیں بلکہ ان کے دلوں پر ان کے اعمال کا زَنگ چڑھ گیا ہے جو وہ کرتے ہیں۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiii{ہرگز (ایسا نہیں کہ جزا وسزا نہ ہو) یہ لوگ اس دن اپنے پروردگار (کی رحمت سے) (محجوب اور محروم) رہیں گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiv{پھر یہ لوگ جہنم میں ڈالے جائیں گے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxv{پھر (ان سے) کہا جائے گا کہ یہی وہ جہنم ہے جس کو تم جھٹلاتے تھے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvi{ہرگز (ایسا) نہیں (کہ جزا و سزا نہ ہو) یقیناً نیکو کاروں کا نامۂ اعمال علیین (بلند مرتبہ لوگوں کے دفتر) میں ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvii{اور تمہیں کیا معلوم کہ علیین (بلند مرتبہ لوگوں کا دفتر) کیا ہے؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxviii{وہ ایک لکھی ہوئی کتاب ہے (جس میں نیکو کاروں کے عمل درج ہیں)۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxix{جس کامشاہدہ مقرب فرشتے کرتے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxx{بےشک نیکوکار لوگ عیش و آرام میں ہوں گے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxi{اونچی مسندوں پر بیٹھ کر دیکھ رہے ہونگے (نظارے کر رہے ہوں گے)۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxii{تم ان کے چہروں پر راحت و آرام کی شادابی محسوس کرو گے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiii{انہیں سر بمہر عمدہ شراب (طہور) پلائی جائے گی۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiv{جس پر مشک کی مہر ہوگی۔ اس چیز میں سبقت لے جانے والوں کو سبقت (اور رغبت) کرنی چاہیے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxv{ور اس (شراب میں) تسنیم کی آمیزش ہوگی۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvi{یہ وہ چشمہ ہے جس سے مقرب لوگ پئیں گے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvii{بےشک جو مجرم لوگ تھے وہ (دارِ دنیا میں) اہلِ ایمان پر ہنستے تھے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxviii{جب ان کے پاس سے گزرتے تھے تو آنکھیں مارا کرتے تھے۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxix{اور جب اپنے گھر والوں کی طرف لوٹتے تھے تو دل لگیاں کرتے ہوئے لوٹتے تھے۔\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxx{اور جب ان (اہلِ ایمان) کو دیکھتے تھے تو کہتے تھے کہ یہ بھٹکے ہوئے لوگ ہیں۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxi{حالانکہ وہ انکے نگران بنا کر نہیں بھیجے گئے تھے۔\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxii{پس آج اہلِ ایمان کافروں (اور منکروں) پر ہنستے ہوں گے۔\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiii{اونچی مسندوں پر بیٹھے ہوئے (ان کی حالت) دیکھ رہے ہونگے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiv{کیا کافروں کو ان کے کئے ہوئے (کرتوتوں) کا پورا بدلہ مل گیا ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxv{\basmalahur اور جب آسمان پھٹ جائے گا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvi{اور وہ اپنے پروردگار کا حکم سن لے گا (اور اس کی تعمیل کرے گا) اور اس پر لازم بھی یہی ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvii{اور جب زمین پھیلا دی جائے گی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxviii{اور جو کچھ اس کے اندر ہے وہ اسے باہر پھینک دے گی اور خالی ہو جائے گی۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxix{اور اپنے پروردگار کا حکم سنے گی اور (اس کی تعمیل کرے گی) اور اس پر لازم بھی یہی ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxc{اے انسان! تو کشاں کشاں اپنے پروردگار کی طرف (کھنچا چلا) جا رہا ہے اور اس کی بارگاہ میں حاضر ہو نے والا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxci{پس جس کا نامۂ اعمال اس کے دائیں ہاتھ میں دیا جائے گا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcii{تو اس سے آسان حساب لیا جائے گا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciii{اور وہ اپنے لوگوں کی طرف خوش و خرم لوٹے گا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciv{اور جس کا نامۂ اعمال اس کے پس پشت دیا جائے گا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcv{تو وہ موت (اور تباہی) کو پکارے گا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvi{اور (دوزخ کی) بھڑکتی ہوئی آگ میں داخل ہوگا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvii{یہ شخص (دنیا میں) اپنے لوگوں میں خوش خوش رہتا تھا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcviii{اس کا خیال تھا کہ وہ کبھی (اپنے خدا کے پاس) لوٹ کر نہیں جائے گا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcix{کیوں نہیں! بےشک اس کا پروردگار اسے خوب دیکھ رہا تھا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcm{پس نہیں! میں قَسم کھاتا ہوں شفق کی۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmi{اور رات کی اور ان چیزوں کی (قَسم کھاتا ہوں) جن کو وہ (رات) سمیٹ لیتی ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmii{اور چاند کی (قَسم کھاتا ہوں) جب وہ پورا ہو جائے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiii{تمہیں یونہی (تدریجاً) زینہ بہ زینہ چڑھنا ہے (اور ایک ایک منزل طے کرنی ہے)۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiv{تو انہیں کیا ہوگیا ہے کہ ایمان نہیں لاتے؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmv{اور جب ان کے سامنے قرآن پڑھا جاتا ہے تویہ سجدہ نہیں کرتے؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvi{بلکہ کافر لوگ تو الٹا (اسے) جھٹلاتے ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvii{اور اللہ بہتر جانتا ہے جو کچھ وہ (اپنے دلوں میں) جمع کر رہے ہیں۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmviii{آپ(ص) انہیں دردناک عذاب کی خبر دے دیجئے۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmix{ہاں البتہ جو لوگ ایمان لائے اور نیک اعمال کئے ان کیلئے کبھی ختم نہ ہو نے والا اجر و ثواب ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmx{\basmalahur قَسم ہے بُرجوں (قلعوں) والے آسمان کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxi{اور وعدہ کئے گئے دن (قیامت) کی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxii{اور گواہ کی قَسم اور اس چیز کی جس کی گواہی دی جائے گی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiii{غارت ہوئے خندق والے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiv{جس میں بھڑکتے ہوئے ایندھن والی آگ تھی۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxv{جب کہ وہ اس (خندق) کے کنارے پر بیٹھے ہوئے تھے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvi{اور وہ جو کچھ اہلِ ایمان کے ساتھ کر رہے تھے اس کو دیکھ رہے تھے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvii{اورانہوں نے اہلِ ایمان کی کسی چیز کو ناپسند نہیں کیا (اور ان میں کوئی عیب نظر نہیں آیا) سوائے اس کے کہ وہ اللہ پر ایمان لائے جو غالب ہے (اور) سزاوارِ ستائش ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxviii{وہ جس کی آسمانوں اور زمین میں بادشاہی ہے اور ہر چیز پر گواہ ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxix{جن لوگوں نے مؤمن مردوں اور مؤمن عورتوں پر ظلم و ستم کیا اور پھر توبہ بھی نہ کی تو ان کیلئے جہنم کا عذاب ہے اور آگ سے جلنے کی سزا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxx{بےشک جو لوگ ایمان لائے اور نیک عمل کئے ان کیلئے (جنت کے) باغ ہیں جن کے نیچے نہریں جاری ہیں یہ بڑی کامیابی ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxi{بےشک تمہارے پروردگار کی گرفت بڑی سخت ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxii{وہی پہلی بار پیدا کرنے والا ہے اور وہی دوبارہ پیدا کرے گا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiii{وہ بڑا بخشنے والا (اور) بڑا محبت کرنے والا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiv{وہ عرش کامالک (اور) بڑی شان والا ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxv{وہ جو چاہتا ہے وہ کر گزرتا ہے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvi{کیا تمہیں لشکروں کی خبر پہنچی ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvii{یعنی فرعون اور ثمود (کے لشکروں) کی۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxviii{بلکہ یہ کافر (و منکر) تو جھٹلانے میں لگے ہیں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxix{حالانکہ اللہ ان کو آگے پیچھے سے گھیرے ہوئے ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxx{بلکہ وہ بڑی شان والا قرآن ہے۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxi{جو لوحِ محفوظ میں ثبت ہے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxii{\basmalahur قَسم ہے آسمان کی اور رات کو نمودار ہو نے والے کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiii{اورتمہیں کیا معلوم کہ رات کو نمودار ہو نے والا کیا ہے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiv{وہ چمکتا ہوا تاراہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxv{کوئی متنفس ایسا نہیں ہے جس پرکوئی نگہبان نہ ہو۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvi{سو انسان کو دیکھنا چاہیے کہ وہ کس چیز سے پیدا کیا گیا ہے؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvii{اچھل کر نکلنے والے پانی سے پیدا کیا گیا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxviii{جو ریڑھ اور سینے کی ہڈیوں کے درمیان سے نکلتا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxix{بےشک وہ (خدا) اس کے لوٹا سکنے (دوبارہ پیدا کرنے) پر قادر ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxl{جس دن سب پوشیدہ راز کھل جائیں گے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxli{پس اس وقت نہ خود انسان کے پاس کوئی طاقت ہوگی اور نہ کوئی مددگار ہوگا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlii{قَسم ہے بارش والے آسمان کی۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliii{اور (نباتات کے ذریعہ سے) پھٹ جانے والی زمین کی۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliv{کہ وہ (قرآن) قولِ فیصل ہے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlv{کوئی ہنسی مذاق نہیں ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvi{بےشک وہ (کافر لوگ) کچھ چالیں چل رہے ہیں۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvii{اور میں بھی (ان کیخلاف) ایک چال چل رہا ہوں۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlviii{تو (اے رسول(ص)) ان (کافروں) کو مہلت دے دیجئے ان کو تھوڑی سی مہلت دے دیجئے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlix{\basmalahur (اے نبی(ص)) اپنے بلند و برتر پروردگار کے نام کی تسبیح کیجئے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcml{جس نے (ہر چیزکو) پیدا کیا پھر درست کیا (تناسب قائم کیا)۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmli{جس نے تقدیر مقرر کی (ہر چیز کا اندازہ مقرر کیا) اور (سیدھی) راہ دکھائی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlii{اس نے (جانوروں کیلئے) زمین سے چارہ نکالا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliii{پھر اسے (خشک کرکے) سیاہی مائل کوڑا بنا دیا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliv{ہم آپ(ص) کو (ایسا) پڑھائیں گے کہ پھر آپ(ص) نہیں بھولیں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlv{مگر جو اللہ چاہے (بھلا دے) بےشک وہ ظاہر کو بھی جانتا ہے اور اس کو بھی جو چھپا ہوا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvi{اور ہم آپ(ص) کو آسان (شریعت) کی سہولت دیں گے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvii{پس آپ(ص) نصیحت کیجئے اگر نصیحت کچھ فائدہ پہنچائے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlviii{وہ شخص نصیحت قبول کرے گا جو (خدا و آخرت سے) ڈرتا ہوگا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlix{اور جو بدبخت ہے وہ اس سے گریز کرے گا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlx{جو بڑی آگ میں داخل ہوگا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxi{پھر وہ اس میں نہ مرے گا نہ جئے گا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxii{وہ شخص فائز المرام ہوا جس نے اپنے آپ کو (بداعتقادی و بدعملی سے) پاک کیا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiii{اور اپنے پروردگار کا نام یاد کیا اور نماز پڑھی۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiv{مگر تم لوگ دنیا کی زندگی کو (آخرت پر) ترجیح دیتے ہو۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxv{حالانکہ آخرت بہتر ہے اور پائیدار ہے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvi{یقیناً یہ بات پہلے صحیفوں میں بھی ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvii{یعنی ابراہیم(ع) اور موسیٰ(ع) کے صحیفوں میں۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxviii{\basmalahur کیا تمہیں (کائنات پر) چھا جانے والی (مصیبت یعنی قیامت) کی خبر پہنچی ہے؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxix{اس دن کچھ چہرے ذلیل (اترے ہوئے) ہوں گے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxx{سخت محنت کرنے والے (نڈھال اور) تھکے ماندے ہوں گے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxi{وہ دہکتی ہوئی آگ میں پڑیں گے (اور جھلسیں گے)۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxii{انہیں کھولتے ہوئے چشمہ کا پانی پلایا جائے گا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiii{(وہاں) ان کیلئے کوئی کھانا نہ ہوگا سوائے خاردار جھاڑ کے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiv{جو نہ (انہیں) موٹا کرے گا اور نہ بھوک دور کرے گا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxv{(اور) کچھ چہرے اس دن تر و تازہ (اور با رونق) ہوں گے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvi{اپنی کاوش و کوشش پر خوش اور مطمئن ہوں گے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvii{(اور) عالیشان جنت میں ہوں گے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxviii{جہاں وہ کوئی بےہودہ بات نہیں سنیں گے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxix{اس میں چشمہ رواں دواں ہوگا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxx{اس میں اونچے اونچے تخت (بچھے ہوئے) ہوں گے۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxi{اور جام و ساغر رکھے ہوں گے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxii{اور گاؤ تکیے قطار در قطار لگے ہوئے ہوں گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiii{اور طرح طرح کے نفیس فرش و فروش بچھے ہوئے ہوں گے۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiv{کیا یہ لوگ اونٹ کو (غور سے) نہیں دیکھتے کہ وہ کیونکر پیدا کیا گیا ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxv{اور آسمان کی طرف نہیں دیکھتے کہ کیسے بلند کیا گیا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvi{اور پہاڑوں کی طرف نہیں دیکھتے کہ کیونکر کھڑے کئے گئے ہیں؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvii{اور زمین کی طرف نہیں دیکھتے کہ کیسے بچھائی گئی ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxviii{پس(اے رسول(ص)) آپ(ص) نصیحت کیجئے (اور سمجھائیے) کہ آپ(ص) نصیحت کرنے (اور سمجھانے) والے ہیں۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxix{آپ(ص) ان پر داروغہ نہیں ہیں۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxc{ہاں البتہ جو شخص رُوگردانی کرے گا اور کفر کرے گا۔\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxci{تو اللہ اس کو بڑا عذاب دے گا۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcii{یقیناً ان کی بازگشت ہماری طرف ہے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciii{پھر بیشک ان کا حساب کتاب ہمارے ذمہ ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciv{\basmalahur قَسم ہے صبح کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcv{اور دس (مقدس) راتوں کی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvi{اورجُفت اور طاق کی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvii{اور رات کی جبکہ (جانے کیلئے) چلنے لگے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcviii{کیا اس میں صاحبِ عقل کیلئے کوئی قسم ہے؟ (یعنی یقیناً ہے)۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcix{کیا آپ(ص) نے نہیں دیکھا کہ آپ(ص) کے پروردگار نے قومِ عاد کے ساتھ کیا کیا؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmm{یعنی اونچے ستونوں والے ارم کے ساتھ۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmi{جن کامثل (دنیا کے) شہروں میں پیدا نہیں کیا گیا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmii{اور قومِ ثمود کے ساتھ (کیا کیا؟) جنہوں نے وادی میں چٹانیں تراشی تھیں (اور عمارتیں بنائی تھیں)۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiii{اور فرعون میخوں والے کے ساتھ (کیا کیا؟)۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiv{ان لوگوں نے شہروں میں سرکشی کی تھی۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmv{اوران میں بہت فساد پھیلایا تھا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvi{تو آپ کے پروردگار نے ان پر عذاب کا کَوڑا برسایا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvii{بےشک آپ(ص) کا پروردگار (ایسے لوگوں کی) تاک میں ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmviii{لیکن انسان (کا حال یہ ہے کہ) جب اس کا پروردگار اسے آزماتا ہے اور اسے عزت و نعمت دیتا ہے تو وہ کہتا ہے کہ میرے پروردگار نے میری عزت افزائی کی۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmix{اور جب وہ (خدا) اسے اس طرح آزماتا ہے کہ اس کا رزق اس پر تنگ کر دیتا ہے تو وہ کہتا ہے کہ میرے پروردگار نے مجھے ذلیل کر دیا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmx{ہرگز نہیں! بلکہ تم لوگ یتیم کی عزت نہیں کرتے۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxi{اور مسکین کو کھانا کھلانے پر ایک دوسرے کو آمادہ نہیں کرتے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxii{اور وراثت کا سارا مال (حلال و حرام) سمیٹ کر کھا جاتے ہو۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiii{اورتم مال و منال سے بہت زیادہ محبت کرتے ہو۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiv{ہرگز نہیں! وہ وقت یاد کرو جب زمین کو توڑ کر ریزہ ریزہ کر دیا جائے گا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxv{اور تمہارا پروردگار (یعنی اس کا حکم) آجائے گا اور فرشتے قطار اندر قطار آئیں گے۔\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvi{اور اس دن جہنم (سامنے) لائی جائے گی اور اس دن انسان کو سمجھ آئے گی مگر اب سمجھ آنے کا کیا فائدہ؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvii{وہ کہے گا کہ کاش! میں نے اپنی (اس) زندگی کیلئے کچھ آگے بھیجا ہوتا۔\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxviii{پس اس دن نہ تو خدا کی طرح کوئی عذاب دے گا۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxix{اور نہ اس کے باندھنے کی طرح کوئی باندھ سکے گا۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxx{(ارشاد ہوگا) اے نفسِ مطمئن۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxi{تو اس حالت میں اپنے پروردگار کی طرف چل کہ تواس سے راضی ہے اور وہ تجھ سے راضی ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxii{پس تُو میرے (خاص) بندوں میں داخل ہو جا۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiii{اور میری جنت میں داخل ہو جا۔\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiv{\basmalahur نہیں! میں قَسم کھاتا ہوں اس شہر کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxv{درآنحالیکہ آپ(ص) اس شہر میں قیام پذیر ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvi{اور قَسم کھاتا ہوں باپ (آدم(ع)) کی اوراس کی اولاد کی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvii{یقیناً ہم نے انسان کو محنت و مشقت کیلئے پیدا کیا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxviii{کیا وہ یہ خیال کرتا ہے کہ اس پر کوئی قابو نہ پاسکے گا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxix{وہ کہتا ہے کہ میں نے بہت سا مال اڑادیا۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxx{کیا وہ خیال کرتا ہے کہ اسے کسی نے نہیں دیکھا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxi{کیا ہم نے اس کیلئے دو آنکھیں نہیں بنائیں؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxii{اور ایک زبان اور دو ہونٹ؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiii{اور ہم نے اسے دونوں راستے دکھا دئیے ہیں۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiv{مگر وہ (نیکی کی) دشوار گزار گھاٹی سے نہیں گزرا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxv{اور تمہیں کیا معلوم کہ وہ دشوار گزار گھاٹی کیا ہے؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvi{وہ کسی گردن کو (غلامی یا قرض سے) چھڑانا۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvii{یا بھوک کے دن۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxviii{کسی یتیم رشتہ دار کو۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxix{یاخاکسار مسکین کو کھانا کھلانا۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxl{پھر وہ ان لوگوں میں سے بھی ہوتا جو ایمان لائے اور ایک دوسرے کو صبر کرنے اور رحم کرنے کی وصیت کی۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxli{یہی لوگ داہنے (ہاتھ) والے ہیں۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlii{اور جن لوگوں نے ہماری آیتوں کا انکار کیا وہ بائیں (ہاتھ والے ہیں)۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliii{ان پر چَو طرفہ بند کی ہوئی آگ محیط ہوگی۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliv{\basmalahur قَسم ہے سورج اور اس کی ضیاء و شعا ع کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlv{اور چاند کی جب وہ اس (سورج) کے پیچھے آئے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvi{دن کی جب وہ اس (سورج) کو خوب روشن کر دے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvii{اور رات کی جب کہ وہ اسے ڈھانپ لے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlviii{اور آسمان کی اور اس (ذات) کی جس نے اسے بنایا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlix{اور زمین کی اور جس نے اسے بچھایا۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmml{اور انسانی نفس کی اور اس کی جس نے اسے درست بنایا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmli{پھر اسے اس کی بدکاری اور پرہیزگاری کا الہام (القاء) کیا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlii{بےشک وہ شخص فلاح پاگیا جس نے اس (نفس) کا تزکیہ کیا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliii{اور وہ شخص نامراد ہوا جس نے (گناہ سے آلودہ کر کے) اسے دبا دیا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliv{قومِ ثمود نے اپنی سرکشی کی وجہ سے (اپنے پیغمبر(ص) کو) جھٹلایا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlv{جب ان کا سب سے زیادہ بدبخت (آدمی) اٹھ کھڑا ہوا۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvi{تو اللہ کے رسول(ع) (صالح(ع)) نے ان لوگوں سے کہا کہ اللہ کی اونٹنی اور اس کے پانی پینے سے خبر دار رہنا (اس کا خیال رکھنا)۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvii{پس ان لوگوں نے ان (رسول(ع)) کو جھٹلایا اور اونٹنی کی کونچیں کاٹ دیں تو ان کے پروردگار نے ان کے گناہ (عظیم) کی پاداش میں ان پر ہلاکت نازل کی اور اسی (بستی) کو زمین کے برابر کر دیا۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlviii{اور اللہ کو اس واقعہ کے انجام کا کوئی خوف نہیں ہے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlix{\basmalahur قَسم ہے رات کی جب کہ وہ (دن کو) ڈھانپ لے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlx{اور قَسم ہے دن کی جب کہ وہ روشن ہو جائے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxi{اور اس ذات کی قَسم جس نے نر اور مادہ کو پیدا کیا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxii{یقیناً تمہاری کوششیں مختلف قِسم کی ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiii{تو جس نے (راہِ خدا میں) مال دیا اور پرہیزگاری اختیار کی۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiv{اور اچھی بات (اسلام) کی تصدیق کی۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxv{تو ہم اسے آسان راستہ کیلئے سہو لت دیں گے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvi{اور جس نے بُخل کیا اور (خدا سے) بےپرواہی کی۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvii{اور اچھی بات کو جھٹلایا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxviii{تو ہم اسے سخت راستے کی سہولت دیں گے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxix{اور اس کا مال اسے کوئی فائدہ نہ دے گا جب وہ (ہلاکت کے) گڑھے میں گرے گا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxx{بےشک راہ دکھانا ہمارے ذمہ ہے۔\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxi{اور بےشک آخرت اور دنیا ہمارے ہی قبضہ میں ہیں۔\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxii{سو میں نے تمہیں بھڑکتی ہوئی آگ سے ڈرایا ہے۔\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiii{اس میں وہ داخل ہوگا(اور جلے گا) جو بڑا بدبخت ہوگا۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiv{جس نے جھٹلایا اور رُوگردانی کی۔\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxv{اور جو بڑا پرہیزگار ہوگا وہ اس سے دور رکھا جائے گا۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvi{جو پاکیزگی حاصل کرنے کیلئے اپنا مال دیتا ہے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvii{اور اس پر کسی کا کوئی احسان نہیں ہے جس کا بدلہ دیا جائے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxviii{بلکہ وہ تو صرف اپنے بالا و برتر پروردگار کی خوشنودی چاہتا ہے۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxix{اور عنقریب وہ اس سے ضرور خوش ہوجائے گا۔\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxx{\basmalahur قَسم ہے روزِ روشن کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxi{اور رات کی جب کہ وہ آرام و سکون کے ساتھ چھا جائے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxii{(اے رسول(ص)) نہ آپ کے پروردگار نے آپ کو چھوڑا ہے اور نہ وہ ناراض ہوا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiii{یقیناً آپ کے لئے انجام (اور بعد کا دور) آغاز (پہلے دور) سے بہتر ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiv{اورعنقریب آپ(ص) کا پروردگار آپ(ص) کو اتنا عطا کرے گا کہ آپ(ص) خوش ہو جائینگے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxv{کیا خدانے آپ(ص) کو یتیم نہیں پایا؟ تو پناہ کی جگہ دی؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvi{اور آپ(ص) کو گمنام پایا تو (لوگوں کو آپ(ص) کی طرف) راہنمائی کی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvii{اور اللہ تعالیٰ نے آپ(ص) کونادار پایا سو مالدار بنا دیا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxviii{پس یتیم پر سختی نہ کیجئے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxix{اور سائل کو نہ جھڑکئے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxc{اور اپنے پروردگار کی نعمت کا اظہار کیجئے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxci{\basmalahur (اے رسول(ص)) کیا ہم نے آپ(ص) کے سینے کو کشادہ نہیں کر دیا؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcii{اور وہ بَوجھ آپ سے اتار دیا۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciii{جو آپ(ص) کی کمر کو توڑ رہا تھا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciv{اور آپ(ص) کے ذکر (آوازہ) کو بلند کیا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcv{یقیناً ہر دشواری کے ساتھ آسانی ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvi{بےشک ہر تنگی کے ساتھ فراخی ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvii{جب (کارِ رسا لت سے) فارغ ہوں تو (عبادت و ریا ضت کرنے میں) محنت کیجئے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcviii{اور اپنے پروردگار کی طرف رغبت کیجئے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcix{\basmalahur قَسم ہے انجیر اور زیتون کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmc{اور طُورِ سینا کی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmci{اور پُرامن شہر (مکہ) کی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcii{ہم نے انسان کو بہترین ساخت و انداز کے ساتھ پیدا کیا ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciii{پھر اسے (اس کی کج رفتاری کی وجہ سے) پست ترین حالت کی طرف لوٹا دیا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciv{سوائے ان لوگوں کے جو ایمان لائے اور نیک عمل کئے سو ان کیلئے ختم نہ ہو نے والا اجر ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcv{تواس کے بعد آپ(ص) کو جزا و سزا کے معاملہ میں کون جھٹلا سکتا ہے؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvi{کیا اللہ سبحانہٗ سب حاکموں سے بڑا حاکم نہیں ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvii{\basmalahur (اے رسول(ص)) اپنے پروردگار کے نام سے پڑھیے جس نے (سب کائنات کو) پیدا کیا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcviii{(بالخصوص) انسان کو جمے ہوئے خون کے ایک لوتھڑے سے پیدا کیا۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcix{پڑھئیے! اور آپ کا پروردگار بڑا کریم ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcx{جس نے قَلم کے ذریعہ سے علم سکھایا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxi{اور انسان کو وہ کچھ پڑھایا جو وہ نہیں جانتا تھا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxii{ہرگز نہیں! انسان (اس وقت) سرکشی کرنے لگتا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiii{جب وہ سمجھتا ہے کہ وہ (غنی) بےنیاز ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiv{بےشک آپ(ص) کے پروردگار کی طرف ہی (سب کی) بازگشت ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxv{کیا آپ(ص) نے اس شخص کو دیکھا ہے جو منع کرتا ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvi{ایک بندہ (خاص) کو جب وہ نماز پڑھتا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvii{بھلا دیکھئے تو! اگر وہ (بندۂ خاص) ہدایت پر ہے؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxviii{یا وہ پرہیزگاری کا حکم دیتا ہے؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxix{کیا آپ نے غور کیا ہے کہ اگر یہ شخص (حق کو) جھٹلاتا ہے اور (اس سے) رُوگردانی کرتا ہے توانجام کیا ہوگا؟\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxx{کیا وہ نہیں جانتا کہ اللہ (سب کچھ) دیکھ رہا ہے؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxi{ہرگز نہیں اگر وہ (اس سے) باز نہ آیا تو ہم اس کی پیشانی کے بال پکڑ کر کھینچیں گے۔\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxii{وہ پیشانی جو جھوٹی ہے اور گنہگار؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiii{پس وہ بلائے اپنے ہم نشینوں کو۔\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiv{ہم بھی دوزخ کے ہرکاروں (فرشتوں) کو بلائیں گے۔\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxv{ہرگز نہیں! اس کی بات نہ مانیے اورسجدہ کیجئے اور (اپنے پروردگار کا) قرب حاصل کیجئے۔\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvi{\basmalahur بےشک ہم نے اس (قرآن) کوشبِ قدر میں نازل کیا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvii{اور آپ کو کیا معلوم کہ شب قدر کیا ہے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxviii{شبِ قدر ہزار مہینوں سے بہتر ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxix{اس میں فرشتے اور روح اپنے پروردگار کی اجازت سے (سال بھر کی) ہر بات کا حکم لے کر اترتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxx{وہ (رات) سراسر سلامتی ہے طلوعِ صبح تک۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxi{\basmalahur اہلِ کتاب اور مشرکین میں سے جو لوگ کافر تھے وہ (اپنے کفر سے) باز آنے والے نہ تھے جب تک ان کے پاس ایک واضح دلیل نہ آجائے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxii{یعنی اللہ کا ایک رسول(ع) جو انہیں پاک و پاکیزہ صحیفے پڑھ کر سنا ئے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiii{جن میں بالکل درست باتیں لکھی ہوئی ہوں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiv{اور جن لوگوں کو کتاب دی گئی تھی (اور وہ اہلِ کتاب تھے) وہ تو واضح دلیل کے آجانے کے بعد ہی تفرقہ میں پڑے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxv{حالانکہ انہیں تو بس یہی حکم دیا گیا تھا کہ دین کو اسی کیلئے خالص کرتے ہوئے اللہ کی عبادت کریں بالکل یکسُو ہو کر اور نماز قائم کریں اور زکوٰۃ دیں اور یہی نہایت (صحیح اور) درست دین ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvi{بےشک جو اہلِ کتاب اور مشرکین کفر میں مبتلا ہیں وہ جہنم کی آگ میں پڑیں گے (اور) ہمیشہ اس میں رہیں گے یہی لوگ بدترینِ خلائق ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvii{اور بےشک جو لوگ ایمان لائے اور نیک عمل کئے وہی بہترینِ خلائق ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxviii{ان کی جزا ان کے پروردگار کے ہاں ہمیشگی کی جنتیں ہیں جن کے نیچے نہریں جاری ہیں وہ ان میں ہمیشہ ہمیشہ رہیں گے اللہ ان سے راضی ہے اور وہ اللہ سے راضی ہیں (یہ سب کچھ) اس کے لئے ہے جو اپنے پروردگار (کی حکم عدولی) سے ڈرتا ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxix{\basmalahur جب زمین پوری شدت سے ہلا ڈالی جائے گی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxl{اور زمین اپنے بوجھوں کو باہر نکال دے گی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxli{اور انسان کہے گا کہ اسے کیا ہوگیا ہے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlii{اس دن وہ اپنی تمام خبریں بیان کرے گی۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliii{کیونکہ تمہارے پروردگار کا اسے یہی حکم ہوگا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliv{اس دن لوگ متفرق طور پر (اپنی قبروں سے) نکلیں گے تاکہ انہیں ان کے اعمال (کے نتائج) دکھائے جائیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlv{تو جس نے ذرہ برابر نیکی کی ہوگی وہ اس (کی جزا) دیکھ لے گا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvi{اور جس نے ذرہ برابر بدی کی ہوگی وہ بھی اس (کی سزا) کو دیکھ لے گا۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvii{\basmalahur قَسم ہے ان گھوڑوں کی جو پھنکارے مارتے ہوئے دوڑتے ہیں۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlviii{پھر اپنی ٹاپوں کی ٹھوکر سے (پتھر سے) چنگاریاں نکا لتے ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlix{پھر صبح کے وقت (اچانک) چھاپہ مارتے ہیں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcl{تو اس طرح گَرد و غبار اڑاتے ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcli{پھر اسی حالت میں (دشمن کی) جماعت (لشکر) میں گھس جاتے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclii{بےشک انسان اپنے پروردگار کا بڑا ناشکرا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliii{اور وہ خود اس پر گواہ ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliv{اور وہ مال و دولت کی محبت میں بڑا سخت (گرفتار) ہے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclv{کیا وہ اس وقت کو نہیں جانتا جب قبروں سے نکال لیا جائے گا جو کچھ ان میں (دفن) ہے۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvi{اور جو کچھ سینوں میں (چھپا ہوا) ہے وہ ظاہر کر دیا جائے گا۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvii{اس دن ان کا پروردگار ان کے حالات سے بڑا باخبر ہوگا۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclviii{\basmalahur کھڑکھڑانے والی (بڑاحادثہ)۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclix{کیا ہے وہ کھڑکھڑانے والی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclx{اورآپ کو کیا معلوم کہ وہ کھڑکھڑانے والی کیا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxi{جس دن سب لوگ بکھرے ہوئے پروانوں کی طرح ہوں گے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxii{اور پہاڑ دھنکی ہوئی روئی کی مانند ہوں گے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiii{تو جس کی (نیکیوں کے) پلڑے بھاری ہوں گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiv{تو وہ دل پسند عیش و آرام میں ہوگا۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxv{اور جس کے (نیکیوں کے پلڑے) ہلکے ہوں گے۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvi{ان کا ٹھکانہ گہرا گڑھا (ھاویہ) ہوگا۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvii{اور تمہیں کیا معلوم کہ وہ (ھاویہ) کیا ہے۔\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxviii{وہ بھڑکتی ہوئی آگ ہے۔\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxix{\basmalahur تمہیں کثرت (مال و اولاد) کی مسابقت نے غفلت میں رکھا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxx{یہاں تک کہ تم قبروں میں جا پہنچے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxi{ہرگز نہیں! عنقریب تمہیں معلوم ہو جائے گا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxii{پھر ہرگز نہیں! عنقریب تمہیں معلوم ہو جائے گا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiii{ہرگز نہیں! اگر تم یقینی طور پر (اس روش کے انجام کو) جانتے (تو ہرگز ایسا نہ کرتے)۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiv{تم ضرور دوزخ کو دیکھو گے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxv{پھر تم لوگ (آخرت میں) ضرور یقین کی آنکھ سے اسے (یقینی دیکھنا) دیکھو گے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvi{پھر اس دن تم سے نعمتوں کے بارے میں ضرور بازپُرس کی جائے گی۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvii{\basmalahur قَسم ہے زمانے کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxviii{یقیناً (ہر) انسان گھاٹے میں ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxix{سوائے ان لوگوں کے جو ایمان لائے اور نیک عمل کئے اور ایک دوسرے کو حق کی وصیت کی اورصبر کی نصیحت کی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxx{\basmalahur تباہی ہے ہر اس شخص کیلئے جو (رُوبرُو) طعن و تشنیع کرنے والا (اور پسِ پشت) عیب جوئی کرنے والا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxi{جو مال جمع کرتا ہے اور اسے گن گن کر رکھتا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxii{کیا وہ خیال کرتا ہے کہ اس کا مال اسے ہمیشہ زندہ رکھے گا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiii{ہرگز نہیں وہ تو چکناچور کر دینے والی جگہ میں پھینک دیا جائے گا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiv{اور تمہیں کیا معلوم ہے کہ وہ چکناچور کردینے والی جگہ کیا ہے؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxv{وہ اللہ کی خوب بھڑکائی ہوئی آگ ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvi{جو دلوں تک جا پہنچے گی۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvii{جو چَو طرفہ طور پر ان پر بند کر دی جائے گی۔\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxviii{وہ لمبے لمبے ستونوں (جیسے شعلوں) میں (گِھرے ہوئے ہوں گے)۔\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxix{\basmalahur کیا آپ نے نہیں دیکھا کہ آپ کے پروردگار نے ہاتھی والوں کے ساتھ کیا (سلوک) کیا؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxc{کیا اس نے ان کی تدبیر و ترکیب کو بےکار نہیں کر دیا؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxci{ان پر (ہر سمت سے) ابابیل نامی پرندوں کے جھنڈ کے جھنڈ بھیج دیئے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcii{جو ان پر سنگِ گل (پکی ہوئی مٹی کے پتھر) مارتے تھے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciii{آخرکار اللہ نے انہیں (مویشیوں کے) کھائے ہوئے بھو سے کی طرح کر دیا۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciv{\basmalahur چونکہ (اللہ نے) قریش کو مانوس کر دیا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcv{یعنی جاڑے اور گرمی کے تجارتی سفر سے مانوس کر دیا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvi{تو ان کو چاہیے کہ اس گھر (خانۂ کعبہ) کے پروردگار کی عبادت کریں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvii{جس نے ان کو بھوک میں کھانے کو دیا اور خوف میں امن عطا کیا۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcviii{\basmalahur کیا آپ نے اس شخص کو دیکھا ہے جو جزا و سزا (کے دن) کو جھٹلاتا ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcix{پس یہی وہ ہے جو یتیم کو دھکے دیتا ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcc{اور کسی مسکین کو کھانا کھلانے پر (لوگوں) کو آمادہ نہیں کرتا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcci{تباہی ہے ان نمازیوں کیلئے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccii{جو اپنی نماز (کی ادائیگی) میں غفلت برتتے ہیں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciii{جو ریاکاری کرتے ہیں۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciv{اور معمولی روزمرہ ضرورت کی چیزیں بھی (لوگوں کو) نہیں دیتے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccv{\basmalahur (اے رسول(ص)) ہم نے آپ(ص) کو کوثر عطا کی ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvi{پس آپ(ص) اپنے پروردگار کے لئے نماز پڑھا کریں اور قربانی کریں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvii{بےشک آپ(ص) کا دشمن ہی نسل بُریدہ ہوگا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccviii{\basmalahur (اے رسول(ص)) آپ(ص) کہہ دیجئے اے کافرو۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccix{میں ان (بتوں) کی عبادت نہیں کرتا جن کی تم عبادت کرتے ہو۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccx{اور نہ تم اس (اللہ) کی عبادت کرنے والے ہو جس کی میں عبادت کرتا ہوں۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxi{اور نہ میں ان (بتوں) کی عبادت کرنے والا ہوں جن کی تم عبادت کرتے ہو۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxii{اور نہ تم (اللہ) کی عبادت کرنے والے ہو جس کی میں عبادت کرتا ہوں۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiii{تمہارے لئے تمہارا دین ہے اور میرے لئے میرا دین۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiv{\basmalahur جب اللہ کی مدد اور اس کی فتح و فیروزی آجائے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxv{اور آپ دیکھ لیں کہ لوگ فوج در فوج اللہ کے دین میں داخل ہو رہے ہیں۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvi{تو (اس وقت) اپنے پروردگار کی حمد کے ساتھ اس کی تسبیح کریں اور اس سے مغفرت طلب کیجئے۔ بیشک وہ بڑا توبہ قبول کرنے والا ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvii{\basmalahur ابولہب کے دونوں ہاتھ ٹوٹ جائیں اور وہ ہلاک و برباد ہوا۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxviii{اس کامال اور جو کچھ اس نے کمایا وہ اس کے کچھ کام نہ آیا۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxix{وہ عنقریب شعلہ زن آگ میں ڈالا جائے گا۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxx{اور (اس کے ساتھ) اس کی بیوی بھی جو ایندھن اٹھانے والی ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxi{اور اس کی گردن میں مُونج کی بٹی ہوئی رسی ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxii{\basmalahur (اے رسول(ص)) آپ(ص) کہہ دیجئے! کہ وہ (اللہ) ایک ہے۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiii{اللہ (ساری کائنات سے) بےنیاز ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiv{نہ اس کی کوئی اولاد ہے اور نہ وہ کسی کی اولاد ہے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxv{اور اس کا کوئی ہمسر نہیں ہے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvi{\basmalahur (اے رسول(ص)) آپ(ص) کہہ دیجئے کہ میں پناہ لیتا ہوں صبح کے پروردگار کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvii{ہر اس چیز کے شر سے جو اس نے پیدا کی ہے۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxviii{اور رات کی تاریکی کے شر سے جبکہ وہ چھا جائے۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxix{اوران کے شر سے جو گِرہوں میں پھونکے مارتی ہیں۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxx{اورحاسد کے شر سے جب وہ حسد کرے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxi{\basmalahur (اے رسول(ص)) آپ(ص) کہہ دیجئے! کہ میں پناہ لیتا ہوں سب لوگوں کے پروردگار کی۔\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxii{سب انسانوں کے بادشاہ کی۔\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiii{سب لوگوں کے الٰہ (خدا) کی۔\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiv{بار بار وسوسہ ڈالنے بار بار پسپا ہونے والے کے شر سے۔\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxv{جو لوگوں کے دلوں میں وسوسہ ڈالتا ہے۔\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxvi{خواہ وہ جِنوں میں سے ہوں یا انسانوں میں سے۔\qt@no{(6)}}%
%% End of file `qurantext-urvii.translation.def'.
