if not modules then modules = { } end modules ['simurgh-char-def'] = {
    version   = 0.01,
    comment   = "chracter definition",
    author    = "Vafa Khalighi",
    copyright = "Vafa Khalighi",
    license   = "see simurgh package documentation",
    derived   = "derived from char-def by Hans Hagen"
}

--[[
The first version of this table was generated from unicode tables but after that was
mostly updated manual using data present in ConTeXt and elsewhere. I did my best to
make this table as complete as needed for proper use in ConTeXt MkIV. All errors are
mine. If you find an error or ommision, just let me know.  This file is updated every
now and then using mtx-unicode where we check against the latest unicode txt files
(normally once per year around the tex live code freeze) and checked afterwards for
differences. We could save some bytes by sharing variant tables but it's not worth
the trouble. Some additional data is kept in other files.
]]--

characters = characters or { }

characters.data={
 [0x0000]={
  category="cc",
  description="NULL",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0000,
 },
 {
  adobename="controlSTX",
  category="cc",
  description="START OF HEADING",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0001,
 },
 {
  adobename="controlSOT",
  category="cc",
  description="START OF TEXT",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0002,
 },
 {
  adobename="controlETX",
  category="cc",
  description="END OF TEXT",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0003,
 },
 {
  adobename="controlEOT",
  category="cc",
  description="END OF TRANSMISSION",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0004,
 },
 {
  adobename="controlENQ",
  category="cc",
  description="ENQUIRY",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0005,
 },
 {
  adobename="controlACK",
  category="cc",
  description="ACKNOWLEDGE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0006,
 },
 {
  adobename="controlBEL",
  category="cc",
  description="BELL",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0007,
 },
 {
  adobename="controlBS",
  category="cc",
  description="BACKSPACE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0008,
 },
 {
  adobename="controlHT",
  category="cc",
  description="CHARACTER TABULATION",
  direction="s",
  linebreak="ba",
  unicodeslot=0x0009,
 },
 {
  adobename="controlLF",
  category="cc",
  description="LINE FEED (LF)",
  direction="b",
  linebreak="lf",
  unicodeslot=0x000A,
 },
 {
  adobename="controlVT",
  category="cc",
  description="LINE TABULATION",
  direction="s",
  linebreak="bk",
  unicodeslot=0x000B,
 },
 {
  adobename="controlFF",
  category="cc",
  description="FORM FEED (FF)",
  direction="ws",
  linebreak="bk",
  unicodeslot=0x000C,
 },
 {
  adobename="controlCR",
  category="cc",
  description="CARRIAGE RETURN (CR)",
  direction="b",
  linebreak="cr",
  unicodeslot=0x000D,
 },
 {
  adobename="controlSO",
  category="cc",
  description="SHIFT OUT",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x000E,
 },
 {
  adobename="controlSI",
  category="cc",
  description="SHIFT IN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x000F,
 },
 {
  adobename="controlDLE",
  category="cc",
  description="DATA LINK ESCAPE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0010,
 },
 {
  adobename="controlDC1",
  category="cc",
  description="DEVICE CONTROL ONE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0011,
 },
 {
  adobename="controlDC2",
  category="cc",
  description="DEVICE CONTROL TWO",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0012,
 },
 {
  adobename="controlDC3",
  category="cc",
  description="DEVICE CONTROL THREE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0013,
 },
 {
  adobename="controlDC4",
  category="cc",
  description="DEVICE CONTROL FOUR",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0014,
 },
 {
  adobename="controlNAK",
  category="cc",
  description="NEGATIVE ACKNOWLEDGE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0015,
 },
 {
  adobename="controlSYN",
  category="cc",
  description="SYNCHRONOUS IDLE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0016,
 },
 {
  adobename="controlETB",
  category="cc",
  description="END OF TRANSMISSION BLOCK",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0017,
 },
 {
  adobename="controlCAN",
  category="cc",
  description="CANCEL",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0018,
 },
 {
  adobename="controlEM",
  category="cc",
  description="END OF MEDIUM",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0019,
 },
 {
  adobename="controlSUB",
  category="cc",
  description="SUBSTITUTE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x001A,
 },
 {
  adobename="controlESC",
  category="cc",
  description="ESCAPE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x001B,
 },
 {
  adobename="controlFS",
  category="cc",
  description="INFORMATION SEPARATOR FOUR",
  direction="b",
  linebreak="cm",
  unicodeslot=0x001C,
 },
 {
  adobename="controlGS",
  category="cc",
  description="INFORMATION SEPARATOR THREE",
  direction="b",
  linebreak="cm",
  unicodeslot=0x001D,
 },
 {
  adobename="controlRS",
  category="cc",
  description="INFORMATION SEPARATOR TWO",
  direction="b",
  linebreak="cm",
  unicodeslot=0x001E,
 },
 {
  adobename="controlUS",
  category="cc",
  description="INFORMATION SEPARATOR ONE",
  direction="s",
  linebreak="cm",
  unicodeslot=0x001F,
 },
 {
  adobename="space",
  category="zs",
  cjkwd="na",
  description="SPACE",
  direction="ws",
  linebreak="sp",
  unicodeslot=0x0020,
 },
 {
  adobename="exclam",
  category="po",
  cjkwd="na",
  description="EXCLAMATION MARK",
  direction="on",
  linebreak="ex",
  mathclass="close",
  unicodeslot=0x0021,
 },
 {
  adobename="quotedbl",
  category="po",
  cjkwd="na",
  contextname="quotedbl",
  description="QUOTATION MARK",
  direction="on",
  linebreak="qu",
  mathclass="default",
  unicodeslot=0x0022,
 },
 {
  adobename="numbersign",
  category="po",
  cjkwd="na",
  description="NUMBER SIGN",
  direction="et",
  linebreak="al",
  unicodeslot=0x0023,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="dollar",
  category="sc",
  cjkwd="na",
  contextname="textdollar",
  description="DOLLAR SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x0024,
 },
 {
  adobename="percent",
  category="po",
  cjkwd="na",
  contextname="percent",
  description="PERCENT SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x0025,
 },
 {
  adobename="ampersand",
  category="po",
  cjkwd="na",
  description="AMPERSAND",
  direction="on",
  linebreak="al",
  unicodeslot=0x0026,
 },
 {
  adobename="quotesingle",
  category="po",
  cjkwd="na",
  contextname="quotesingle",
  description="APOSTROPHE",
  direction="on",
  linebreak="qu",
  mathclass="default",
  unicodeslot=0x0027,
 },
 {
  adobename="parenleft",
  category="ps",
  cjkwd="na",
  description="LEFT PARENTHESIS",
  direction="on",
  linebreak="op",
  mathclass="open",
  mathname="lparent",
  mirror=0x0029,
  textclass="open",
  unicodeslot=0x0028,
 },
 {
  adobename="parenright",
  category="pe",
  cjkwd="na",
  description="RIGHT PARENTHESIS",
  direction="on",
  linebreak="cp",
  mathclass="close",
  mathname="rparent",
  mirror=0x0028,
  textclass="close",
  unicodeslot=0x0029,
 },
 {
  adobename="asterisk",
  category="po",
  cjkwd="na",
  description="ASTERISK",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="ast",
  mathsymbol=0x2217,
  unicodeslot=0x002A,
 },
 {
  adobename="plus",
  category="sm",
  cjkwd="na",
  description="PLUS SIGN",
  direction="es",
  linebreak="pr",
  mathclass="binary",
  unicodeslot=0x002B,
 },
 {
  adobename="comma",
  category="po",
  cjkwd="na",
  contextname="textcomma",
  description="COMMA",
  direction="cs",
  linebreak="is",
  mathclass="punctuation",
  unicodeslot=0x002C,
 },
 {
  adobename="hyphen",
  category="pd",
  cjkwd="na",
  description="HYPHEN-MINUS",
  direction="es",
  linebreak="hy",
  mathextensible="h",
  mathfiller="relfill",
  mathsymbol=0x2212,
  unicodeslot=0x002D,
 },
 {
  adobename="period",
  category="po",
  cjkwd="na",
  comment="class needed for autopunctuation",
  contextname="textperiod",
  description="FULL STOP",
  direction="cs",
  linebreak="is",
  mathclass="punctuation",
  mathspec={
   {
    class="punctuation",
    name="ldotp",
   },
  },
  unicodeslot=0x002E,
 },
 {
  adobename="slash",
  category="po",
  cjkwd="na",
  comment="mathsymbol=0x2044",
  contextname="textslash",
  description="SOLIDUS",
  direction="cs",
  linebreak="sy",
  mathspec={
   {
    class="middle",
    unicode=0x2044,
   },
   {
    class="ordinary",
    unicode=0x2044,
   },
  },
  unicodeslot=0x002F,
 },
 {
  adobename="zero",
  category="nd",
  cjkwd="na",
  description="DIGIT ZERO",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0030,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="one",
  category="nd",
  cjkwd="na",
  description="DIGIT ONE",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0031,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="two",
  category="nd",
  cjkwd="na",
  description="DIGIT TWO",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0032,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="three",
  category="nd",
  cjkwd="na",
  description="DIGIT THREE",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0033,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="four",
  category="nd",
  cjkwd="na",
  description="DIGIT FOUR",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0034,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="five",
  category="nd",
  cjkwd="na",
  description="DIGIT FIVE",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0035,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="six",
  category="nd",
  cjkwd="na",
  description="DIGIT SIX",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0036,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="seven",
  category="nd",
  cjkwd="na",
  description="DIGIT SEVEN",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0037,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="eight",
  category="nd",
  cjkwd="na",
  description="DIGIT EIGHT",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0038,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="nine",
  category="nd",
  cjkwd="na",
  description="DIGIT NINE",
  direction="en",
  linebreak="nu",
  mathclass="number",
  unicodeslot=0x0039,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 {
  adobename="colon",
  category="po",
  cjkwd="na",
  comment="mathclass=punctuation,mathname=colon",
  description="COLON",
  direction="cs",
  linebreak="is",
  mathclass="relation",
  unicodeslot=0x003A,
 },
 {
  adobename="semicolon",
  category="po",
  cjkwd="na",
  description="SEMICOLON",
  direction="on",
  linebreak="is",
  mathclass="punctuation",
  unicodeslot=0x003B,
 },
 {
  adobename="less",
  category="sm",
  cjkwd="na",
  description="LESS-THAN SIGN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lt",
  mirror=0x003E,
  textclass="open",
  unicodeslot=0x003C,
 },
 {
  adobename="equal",
  category="sm",
  cjkwd="na",
  comment="mathclass=binary",
  description="EQUALS SIGN",
  direction="on",
  linebreak="al",
  mathextensible="h",
  mathfiller="equalfill",
  mathspec={
   {
    class="relation",
    name="eq",
   },
   {
    class="relation",
    name="Relbar",
   },
  },
  unicodeslot=0x003D,
 },
 {
  adobename="greater",
  category="sm",
  cjkwd="na",
  description="GREATER-THAN SIGN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gt",
  mirror=0x003C,
  textclass="close",
  unicodeslot=0x003E,
 },
 {
  adobename="question",
  category="po",
  cjkwd="na",
  description="QUESTION MARK",
  direction="on",
  linebreak="ex",
  mathclass="close",
  unicodeslot=0x003F,
 },
 {
  adobename="at",
  category="po",
  cjkwd="na",
  contextname="textat",
  description="COMMERCIAL AT",
  direction="on",
  linebreak="al",
  unicodeslot=0x0040,
 },
 {
  adobename="A",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER A",
  direction="l",
  lccode=0x0061,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0041,
 },
 {
  adobename="B",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER B",
  direction="l",
  lccode=0x0062,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0042,
 },
 {
  adobename="C",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER C",
  direction="l",
  lccode=0x0063,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0043,
 },
 {
  adobename="D",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER D",
  direction="l",
  lccode=0x0064,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0044,
 },
 {
  adobename="E",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER E",
  direction="l",
  lccode=0x0065,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0045,
 },
 {
  adobename="F",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER F",
  direction="l",
  lccode=0x0066,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0046,
 },
 {
  adobename="G",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER G",
  direction="l",
  lccode=0x0067,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0047,
 },
 {
  adobename="H",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER H",
  direction="l",
  lccode=0x0068,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0048,
 },
 {
  adobename="I",
  category="lu",
  cjkwd="na",
  contextname="dotlessI",
  description="LATIN CAPITAL LETTER I",
  direction="l",
  lccode=0x0069,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0049,
 },
 {
  adobename="J",
  category="lu",
  cjkwd="na",
  contextname="dotlessJ",
  description="LATIN CAPITAL LETTER J",
  direction="l",
  lccode=0x006A,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x004A,
 },
 {
  adobename="K",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER K",
  direction="l",
  lccode=0x006B,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x004B,
 },
 {
  adobename="L",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER L",
  direction="l",
  lccode=0x006C,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x004C,
 },
 {
  adobename="M",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER M",
  direction="l",
  lccode=0x006D,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x004D,
 },
 {
  adobename="N",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER N",
  direction="l",
  lccode=0x006E,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x004E,
 },
 {
  adobename="O",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER O",
  direction="l",
  lccode=0x006F,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x004F,
 },
 {
  adobename="P",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER P",
  direction="l",
  lccode=0x0070,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0050,
 },
 {
  adobename="Q",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER Q",
  direction="l",
  lccode=0x0071,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0051,
 },
 {
  adobename="R",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER R",
  direction="l",
  lccode=0x0072,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0052,
 },
 {
  adobename="S",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER S",
  direction="l",
  lccode=0x0073,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0053,
 },
 {
  adobename="T",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER T",
  direction="l",
  lccode=0x0074,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0054,
 },
 {
  adobename="U",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER U",
  direction="l",
  lccode=0x0075,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0055,
 },
 {
  adobename="V",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER V",
  direction="l",
  lccode=0x0076,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0056,
 },
 {
  adobename="W",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER W",
  direction="l",
  lccode=0x0077,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0057,
 },
 {
  adobename="X",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER X",
  direction="l",
  lccode=0x0078,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0058,
 },
 {
  adobename="Y",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER Y",
  direction="l",
  lccode=0x0079,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x0059,
 },
 {
  adobename="Z",
  category="lu",
  cjkwd="na",
  description="LATIN CAPITAL LETTER Z",
  direction="l",
  lccode=0x007A,
  linebreak="al",
  mathclass="variable",
  unicodeslot=0x005A,
 },
 {
  adobename="bracketleft",
  category="ps",
  cjkwd="na",
  description="LEFT SQUARE BRACKET",
  direction="on",
  linebreak="op",
  mathclass="open",
  mathname="lbracket",
  mirror=0x005D,
  textclass="open",
  unicodeslot=0x005B,
 },
 {
  adobename="backslash",
  category="po",
  cjkwd="na",
  contextname="textbackslash",
  description="REVERSE SOLIDUS",
  direction="on",
  linebreak="pr",
  mathclass="nothing",
  mathname="backslash",
  unicodeslot=0x005C,
 },
 {
  adobename="bracketright",
  category="pe",
  cjkwd="na",
  description="RIGHT SQUARE BRACKET",
  direction="on",
  linebreak="cp",
  mathclass="close",
  mathname="rbracket",
  mirror=0x005B,
  textclass="close",
  unicodeslot=0x005D,
 },
 {
  adobename="asciicircum",
  category="sk",
  cjkwd="na",
  contextname="textasciicircum",
  description="CIRCUMFLEX ACCENT",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  unicodeslot=0x005E,
 },
 {
  adobename="underscore",
  category="pc",
  cjkwd="na",
  contextname="textunderscore",
  description="LOW LINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x005F,
 },
 {
  adobename="grave",
  category="sk",
  cjkwd="na",
  contextname="textgrave",
  description="GRAVE ACCENT",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  mathname="grave",
  unicodeslot=0x0060,
 },
 {
  adobename="a",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER A",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0041,
  unicodeslot=0x0061,
 },
 {
  adobename="b",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER B",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0042,
  unicodeslot=0x0062,
 },
 {
  adobename="c",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER C",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0043,
  unicodeslot=0x0063,
 },
 {
  adobename="d",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER D",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0044,
  unicodeslot=0x0064,
 },
 {
  adobename="e",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER E",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0045,
  unicodeslot=0x0065,
 },
 {
  adobename="f",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER F",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0046,
  unicodeslot=0x0066,
 },
 {
  adobename="g",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER G",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0047,
  unicodeslot=0x0067,
 },
 {
  adobename="h",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER H",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0048,
  unicodeslot=0x0068,
 },
 {
  adobename="i",
  category="ll",
  cjkwd="na",
  contextname="idotaccent",
  description="LATIN SMALL LETTER I",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0049,
  unicodeslot=0x0069,
 },
 {
  adobename="j",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER J",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x004A,
  unicodeslot=0x006A,
 },
 {
  adobename="k",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER K",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x004B,
  unicodeslot=0x006B,
 },
 {
  adobename="l",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER L",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x004C,
  unicodeslot=0x006C,
 },
 {
  adobename="m",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER M",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x004D,
  unicodeslot=0x006D,
 },
 {
  adobename="n",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER N",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x004E,
  unicodeslot=0x006E,
 },
 {
  adobename="o",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER O",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x004F,
  unicodeslot=0x006F,
 },
 {
  adobename="p",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER P",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0050,
  unicodeslot=0x0070,
 },
 {
  adobename="q",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER Q",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0051,
  unicodeslot=0x0071,
 },
 {
  adobename="r",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER R",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0052,
  unicodeslot=0x0072,
 },
 {
  adobename="s",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER S",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0053,
  unicodeslot=0x0073,
 },
 {
  adobename="t",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER T",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0054,
  unicodeslot=0x0074,
 },
 {
  adobename="u",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER U",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0055,
  unicodeslot=0x0075,
 },
 {
  adobename="v",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER V",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0056,
  unicodeslot=0x0076,
 },
 {
  adobename="w",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER W",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0057,
  unicodeslot=0x0077,
 },
 {
  adobename="x",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER X",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0058,
  unicodeslot=0x0078,
 },
 {
  adobename="y",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER Y",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x0059,
  unicodeslot=0x0079,
 },
 {
  adobename="z",
  category="ll",
  cjkwd="na",
  description="LATIN SMALL LETTER Z",
  direction="l",
  linebreak="al",
  mathclass="variable",
  uccode=0x005A,
  unicodeslot=0x007A,
 },
 {
  adobename="braceleft",
  category="ps",
  cjkwd="na",
  contextname="textbraceleft",
  description="LEFT CURLY BRACKET",
  direction="on",
  linebreak="op",
  mathclass="open",
  mathname="lbrace",
  mirror=0x007D,
  textclass="open",
  unicodeslot=0x007B,
 },
 {
  adobename="verticalbar",
  category="sm",
  cjkwd="na",
  comment="mathclass=binary,mathname=bar",
  contextname="textbar",
  description="VERTICAL LINE",
  direction="on",
  linebreak="ba",
  mathspec={
   {
    class="nothing",
    name="arrowvert",
   },
   {
    class="delimiter",
    name="vert",
   },
   {
    class="open",
    name="lvert",
   },
   {
    class="close",
    name="rvert",
   },
   {
    class="relation",
    name="mid",
   },
  },
  unicodeslot=0x007C,
 },
 {
  adobename="braceright",
  category="pe",
  cjkwd="na",
  contextname="textbraceright",
  description="RIGHT CURLY BRACKET",
  direction="on",
  linebreak="cl",
  mathclass="close",
  mathname="rbrace",
  mirror=0x007B,
  textclass="close",
  unicodeslot=0x007D,
 },
 {
  adobename="asciitilde",
  category="sm",
  cjkwd="na",
  contextname="textasciitilde",
  description="TILDE",
  direction="on",
  linebreak="al",
  unicodeslot=0x007E,
 },
 {
  adobename="controlDEL",
  category="cc",
  description="DELETE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x007F,
 },
 {
  category="cc",
  description="NONE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0080,
 },
 {
  category="cc",
  description="NONE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0081,
 },
 {
  category="cc",
  description="BREAK PERMITTED HERE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0082,
 },
 {
  category="cc",
  description="NO BREAK HERE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0083,
 },
 {
  category="cc",
  description="NONE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0084,
 },
 {
  category="cc",
  description="NEXT LINE (NEL)",
  direction="b",
  linebreak="nl",
  unicodeslot=0x0085,
 },
 {
  category="cc",
  description="START OF SELECTED AREA",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0086,
 },
 {
  category="cc",
  description="END OF SELECTED AREA",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0087,
 },
 {
  category="cc",
  description="CHARACTER TABULATION SET",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0088,
 },
 {
  category="cc",
  description="CHARACTER TABULATION WITH JUSTIFICATION",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0089,
 },
 {
  category="cc",
  description="LINE TABULATION SET",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x008A,
 },
 {
  category="cc",
  description="PARTIAL LINE FORWARD",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x008B,
 },
 {
  category="cc",
  description="PARTIAL LINE BACKWARD",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x008C,
 },
 {
  category="cc",
  description="REVERSE LINE FEED",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x008D,
 },
 {
  category="cc",
  description="SINGLE SHIFT TWO",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x008E,
 },
 {
  category="cc",
  description="SINGLE SHIFT THREE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x008F,
 },
 {
  category="cc",
  description="DEVICE CONTROL STRING",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0090,
 },
 {
  category="cc",
  description="PRIVATE USE ONE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0091,
 },
 {
  category="cc",
  description="PRIVATE USE TWO",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0092,
 },
 {
  category="cc",
  description="SET TRANSMIT STATE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0093,
 },
 {
  category="cc",
  description="CANCEL CHARACTER",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0094,
 },
 {
  category="cc",
  description="MESSAGE WAITING",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0095,
 },
 {
  category="cc",
  description="START OF GUARDED AREA",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0096,
 },
 {
  category="cc",
  description="END OF GUARDED AREA",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0097,
 },
 {
  category="cc",
  description="START OF STRING",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0098,
 },
 {
  category="cc",
  description="NONE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x0099,
 },
 {
  category="cc",
  description="SINGLE CHARACTER INTRODUCER",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x009A,
 },
 {
  category="cc",
  description="CONTROL SEQUENCE INTRODUCER",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x009B,
 },
 {
  category="cc",
  description="STRING TERMINATOR",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x009C,
 },
 {
  category="cc",
  description="OPERATING SYSTEM COMMAND",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x009D,
 },
 {
  category="cc",
  description="PRIVACY MESSAGE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x009E,
 },
 {
  category="cc",
  description="APPLICATION PROGRAM COMMAND",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x009F,
 },
 {
  adobename="nonbreakingspace",
  category="zs",
  contextname="nobreakspace",
  description="NO-BREAK SPACE",
  direction="cs",
  linebreak="gl",
  specials={ "nobreak", 0x0020 },
  unicodeslot=0x00A0,
 },
 {
  adobename="exclamdown",
  category="po",
  cjkwd="a",
  contextname="exclamdown",
  description="INVERTED EXCLAMATION MARK",
  direction="on",
  linebreak="op",
  unicodeslot=0x00A1,
 },
 {
  adobename="cent",
  category="sc",
  cjkwd="na",
  contextname="textcent",
  description="CENT SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x00A2,
 },
 {
  adobename="sterling",
  category="sc",
  cjkwd="na",
  contextname="textsterling",
  description="POUND SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x00A3,
 },
 {
  adobename="currency",
  category="sc",
  cjkwd="a",
  contextname="textcurrency",
  description="CURRENCY SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x00A4,
 },
 {
  adobename="yen",
  category="sc",
  cjkwd="na",
  contextname="textyen",
  description="YEN SIGN",
  direction="et",
  linebreak="pr",
  mathclass="nothing",
  mathname="yen",
  unicodeslot=0x00A5,
 },
 {
  adobename="brokenbar",
  category="so",
  cjkwd="na",
  contextname="textbrokenbar",
  description="BROKEN BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x00A6,
 },
 {
  adobename="section",
  category="so",
  cjkwd="a",
  contextname="sectionmark",
  description="SECTION SIGN",
  direction="on",
  linebreak="ai",
  mathclass="box",
  mathname="S",
  unicodeslot=0x00A7,
 },
 {
  adobename="dieresis",
  category="sk",
  cjkwd="a",
  contextname="textdiaeresis",
  description="DIAERESIS",
  direction="on",
  linebreak="ai",
  mathclass="topaccent",
  mathname="ddot",
  specials={ "compat", 0x0020, 0x0308 },
  unicodeslot=0x00A8,
 },
 {
  adobename="copyright",
  category="so",
  contextname="copyright",
  description="COPYRIGHT SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x00A9,
 },
 {
  adobename="ordfeminine",
  category="ll",
  cjkwd="a",
  contextname="ordfeminine",
  description="FEMININE ORDINAL INDICATOR",
  direction="l",
  linebreak="ai",
  specials={ "super", 0x0061 },
  unicodeslot=0x00AA,
 },
 {
  adobename="guillemotleft",
  category="pi",
  contextname="leftguillemot",
  description="LEFT-POINTING DOUBLE ANGLE QUOTATION MARK",
  direction="on",
  linebreak="qu",
  mirror=0x00BB,
  textclass="open",
  unicodeslot=0x00AB,
 },
 {
  adobename="logicalnot",
  category="sm",
  cjkwd="na",
  contextname="textlognot",
  description="NOT SIGN",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="ordinary",
    name="lnot",
   },
   {
    class="ordinary",
    name="neg",
   },
  },
  unicodeslot=0x00AC,
 },
 {
  adobename="softhyphen",
  category="cf",
  cjkwd="a",
  contextname="softhyphen",
  description="SOFT HYPHEN",
  direction="bn",
  linebreak="ba",
  unicodeslot=0x00AD,
 },
 {
  adobename="registered",
  category="so",
  cjkwd="a",
  contextname="registered",
  description="REGISTERED SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x00AE,
 },
 {
  adobename="macron",
  category="sk",
  cjkwd="na",
  contextname="textmacron",
  description="MACRON",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  mathname="bar",
  specials={ "compat", 0x0020, 0x0304 },
  unicodeslot=0x00AF,
 },
 {
  adobename="degree",
  category="so",
  cjkwd="a",
  contextname="textdegree",
  description="DEGREE SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x00B0,
 },
 {
  adobename="plusminus",
  category="sm",
  cjkwd="a",
  contextname="textpm",
  description="PLUS-MINUS SIGN",
  direction="et",
  linebreak="pr",
  mathclass="binary",
  mathname="pm",
  unicodeslot=0x00B1,
 },
 {
  adobename="twosuperior",
  category="no",
  cjkwd="a",
  contextname="twosuperior",
  description="SUPERSCRIPT TWO",
  direction="en",
  linebreak="ai",
  specials={ "super", 0x0032 },
  unicodeslot=0x00B2,
 },
 {
  adobename="threesuperior",
  category="no",
  cjkwd="a",
  contextname="threesuperior",
  description="SUPERSCRIPT THREE",
  direction="en",
  linebreak="ai",
  specials={ "super", 0x0033 },
  unicodeslot=0x00B3,
 },
 {
  adobename="acute",
  category="sk",
  cjkwd="a",
  contextname="textacute",
  description="ACUTE ACCENT",
  direction="on",
  linebreak="bb",
  mathclass="topaccent",
  mathname="acute",
  specials={ "compat", 0x0020, 0x0301 },
  unicodeslot=0x00B4,
 },
 {
  adobename="mu1",
  category="ll",
  contextname="textmu",
  description="MICRO SIGN",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x03BC },
  uccode=0x039C,
  unicodeslot=0x00B5,
 },
 {
  adobename="paragraph",
  category="so",
  cjkwd="a",
  contextname="paragraphmark",
  description="PILCROW SIGN",
  direction="on",
  linebreak="ai",
  mathclass="box",
  mathname="P",
  unicodeslot=0x00B6,
 },
 {
  adobename="periodcentered",
  category="po",
  cjkwd="a",
  contextname="periodcentered",
  description="MIDDLE DOT",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="centerdot",
  unicodeslot=0x00B7,
 },
 {
  adobename="cedilla",
  category="sk",
  cjkwd="a",
  contextname="textcedilla",
  description="CEDILLA",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0020, 0x0327 },
  unicodeslot=0x00B8,
 },
 {
  adobename="onesuperior",
  category="no",
  cjkwd="a",
  contextname="onesuperior",
  description="SUPERSCRIPT ONE",
  direction="en",
  linebreak="ai",
  specials={ "super", 0x0031 },
  unicodeslot=0x00B9,
 },
 {
  adobename="ordmasculine",
  category="ll",
  cjkwd="a",
  contextname="ordmasculine",
  description="MASCULINE ORDINAL INDICATOR",
  direction="l",
  linebreak="ai",
  specials={ "super", 0x006F },
  unicodeslot=0x00BA,
 },
 {
  adobename="guillemotright",
  category="pf",
  contextname="rightguillemot",
  description="RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK",
  direction="on",
  linebreak="qu",
  mirror=0x00AB,
  textclass="close",
  unicodeslot=0x00BB,
 },
 {
  adobename="onequarter",
  category="no",
  cjkwd="a",
  contextname="onequarter",
  description="VULGAR FRACTION ONE QUARTER",
  direction="on",
  linebreak="ai",
  specials={ "fraction", 0x0031, 0x2044, 0x0034 },
  unicodeslot=0x00BC,
 },
 {
  adobename="onehalf",
  category="no",
  cjkwd="a",
  contextname="onehalf",
  description="VULGAR FRACTION ONE HALF",
  direction="on",
  linebreak="ai",
  specials={ "fraction", 0x0031, 0x2044, 0x0032 },
  unicodeslot=0x00BD,
 },
 {
  adobename="threequarters",
  category="no",
  cjkwd="a",
  contextname="threequarter",
  description="VULGAR FRACTION THREE QUARTERS",
  direction="on",
  linebreak="ai",
  specials={ "fraction", 0x0033, 0x2044, 0x0034 },
  unicodeslot=0x00BE,
 },
 {
  adobename="questiondown",
  category="po",
  cjkwd="a",
  contextname="questiondown",
  description="INVERTED QUESTION MARK",
  direction="on",
  linebreak="op",
  unicodeslot=0x00BF,
 },
 {
  adobename="Agrave",
  category="lu",
  contextname="Agrave",
  description="LATIN CAPITAL LETTER A WITH GRAVE",
  direction="l",
  lccode=0x00E0,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0300 },
  unicodeslot=0x00C0,
 },
 {
  adobename="Aacute",
  category="lu",
  contextname="Aacute",
  description="LATIN CAPITAL LETTER A WITH ACUTE",
  direction="l",
  lccode=0x00E1,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0301 },
  unicodeslot=0x00C1,
 },
 {
  adobename="Acircumflex",
  category="lu",
  contextname="Acircumflex",
  description="LATIN CAPITAL LETTER A WITH CIRCUMFLEX",
  direction="l",
  lccode=0x00E2,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0302 },
  unicodeslot=0x00C2,
 },
 {
  adobename="Atilde",
  category="lu",
  contextname="Atilde",
  description="LATIN CAPITAL LETTER A WITH TILDE",
  direction="l",
  lccode=0x00E3,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0303 },
  unicodeslot=0x00C3,
 },
 {
  adobename="Adieresis",
  category="lu",
  contextname="Adiaeresis",
  description="LATIN CAPITAL LETTER A WITH DIAERESIS",
  direction="l",
  lccode=0x00E4,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0308 },
  unicodeslot=0x00C4,
 },
 {
  adobename="Aring",
  category="lu",
  contextname="Aring",
  description="LATIN CAPITAL LETTER A WITH RING ABOVE",
  direction="l",
  lccode=0x00E5,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x030A },
  unicodeslot=0x00C5,
 },
 {
  adobename="AE",
  category="lu",
  cjkwd="a",
  contextname="AEligature",
  description="LATIN CAPITAL LETTER AE",
  direction="l",
  lccode=0x00E6,
  linebreak="al",
  shcode={ 0x0041, 0x0045 },
  unicodeslot=0x00C6,
 },
 {
  adobename="Ccedilla",
  category="lu",
  contextname="Ccedilla",
  description="LATIN CAPITAL LETTER C WITH CEDILLA",
  direction="l",
  lccode=0x00E7,
  linebreak="al",
  shcode=0x0043,
  specials={ "char", 0x0043, 0x0327 },
  unicodeslot=0x00C7,
 },
 {
  adobename="Egrave",
  category="lu",
  contextname="Egrave",
  description="LATIN CAPITAL LETTER E WITH GRAVE",
  direction="l",
  lccode=0x00E8,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0300 },
  unicodeslot=0x00C8,
 },
 {
  adobename="Eacute",
  category="lu",
  contextname="Eacute",
  description="LATIN CAPITAL LETTER E WITH ACUTE",
  direction="l",
  lccode=0x00E9,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0301 },
  unicodeslot=0x00C9,
 },
 {
  adobename="Ecircumflex",
  category="lu",
  contextname="Ecircumflex",
  description="LATIN CAPITAL LETTER E WITH CIRCUMFLEX",
  direction="l",
  lccode=0x00EA,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0302 },
  unicodeslot=0x00CA,
 },
 {
  adobename="Edieresis",
  category="lu",
  contextname="Ediaeresis",
  description="LATIN CAPITAL LETTER E WITH DIAERESIS",
  direction="l",
  lccode=0x00EB,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0308 },
  unicodeslot=0x00CB,
 },
 {
  adobename="Igrave",
  category="lu",
  contextname="Igrave",
  description="LATIN CAPITAL LETTER I WITH GRAVE",
  direction="l",
  lccode=0x00EC,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0300 },
  unicodeslot=0x00CC,
 },
 {
  adobename="Iacute",
  category="lu",
  contextname="Iacute",
  description="LATIN CAPITAL LETTER I WITH ACUTE",
  direction="l",
  lccode=0x00ED,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0301 },
  unicodeslot=0x00CD,
 },
 {
  adobename="Icircumflex",
  category="lu",
  contextname="Icircumflex",
  description="LATIN CAPITAL LETTER I WITH CIRCUMFLEX",
  direction="l",
  lccode=0x00EE,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0302 },
  unicodeslot=0x00CE,
 },
 {
  adobename="Idieresis",
  category="lu",
  contextname="Idiaeresis",
  description="LATIN CAPITAL LETTER I WITH DIAERESIS",
  direction="l",
  lccode=0x00EF,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0308 },
  unicodeslot=0x00CF,
 },
 {
  adobename="Eth",
  category="lu",
  cjkwd="a",
  contextname="Eth",
  description="LATIN CAPITAL LETTER ETH",
  direction="l",
  lccode=0x00F0,
  linebreak="al",
  unicodeslot=0x00D0,
 },
 {
  adobename="Ntilde",
  category="lu",
  contextname="Ntilde",
  description="LATIN CAPITAL LETTER N WITH TILDE",
  direction="l",
  lccode=0x00F1,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x0303 },
  unicodeslot=0x00D1,
 },
 {
  adobename="Ograve",
  category="lu",
  contextname="Ograve",
  description="LATIN CAPITAL LETTER O WITH GRAVE",
  direction="l",
  lccode=0x00F2,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0300 },
  unicodeslot=0x00D2,
 },
 {
  adobename="Oacute",
  category="lu",
  contextname="Oacute",
  description="LATIN CAPITAL LETTER O WITH ACUTE",
  direction="l",
  lccode=0x00F3,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0301 },
  unicodeslot=0x00D3,
 },
 {
  adobename="Ocircumflex",
  category="lu",
  contextname="Ocircumflex",
  description="LATIN CAPITAL LETTER O WITH CIRCUMFLEX",
  direction="l",
  lccode=0x00F4,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0302 },
  unicodeslot=0x00D4,
 },
 {
  adobename="Otilde",
  category="lu",
  contextname="Otilde",
  description="LATIN CAPITAL LETTER O WITH TILDE",
  direction="l",
  lccode=0x00F5,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0303 },
  unicodeslot=0x00D5,
 },
 {
  adobename="Odieresis",
  category="lu",
  contextname="Odiaeresis",
  description="LATIN CAPITAL LETTER O WITH DIAERESIS",
  direction="l",
  lccode=0x00F6,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0308 },
  unicodeslot=0x00D6,
 },
 {
  adobename="multiply",
  category="sm",
  cjkwd="a",
  contextname="textmultiply",
  description="MULTIPLICATION SIGN",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="times",
  unicodeslot=0x00D7,
 },
 {
  adobename="Oslash",
  category="lu",
  cjkwd="a",
  contextname="Ostroke",
  description="LATIN CAPITAL LETTER O WITH STROKE",
  direction="l",
  lccode=0x00F8,
  linebreak="al",
  shcode=0x004F,
  unicodeslot=0x00D8,
 },
 {
  adobename="Ugrave",
  category="lu",
  contextname="Ugrave",
  description="LATIN CAPITAL LETTER U WITH GRAVE",
  direction="l",
  lccode=0x00F9,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0300 },
  unicodeslot=0x00D9,
 },
 {
  adobename="Uacute",
  category="lu",
  contextname="Uacute",
  description="LATIN CAPITAL LETTER U WITH ACUTE",
  direction="l",
  lccode=0x00FA,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0301 },
  unicodeslot=0x00DA,
 },
 {
  adobename="Ucircumflex",
  category="lu",
  contextname="Ucircumflex",
  description="LATIN CAPITAL LETTER U WITH CIRCUMFLEX",
  direction="l",
  lccode=0x00FB,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0302 },
  unicodeslot=0x00DB,
 },
 {
  adobename="Udieresis",
  category="lu",
  contextname="Udiaeresis",
  description="LATIN CAPITAL LETTER U WITH DIAERESIS",
  direction="l",
  lccode=0x00FC,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0308 },
  unicodeslot=0x00DC,
 },
 {
  adobename="Yacute",
  category="lu",
  contextname="Yacute",
  description="LATIN CAPITAL LETTER Y WITH ACUTE",
  direction="l",
  lccode=0x00FD,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0301 },
  unicodeslot=0x00DD,
 },
 {
  adobename="Thorn",
  category="lu",
  cjkwd="a",
  contextname="Thorn",
  description="LATIN CAPITAL LETTER THORN",
  direction="l",
  lccode=0x00FE,
  linebreak="al",
  unicodeslot=0x00DE,
 },
 {
  adobename="germandbls",
  category="ll",
  cjkwd="a",
  contextname="ssharp",
  description="LATIN SMALL LETTER SHARP S",
  direction="l",
  linebreak="al",
  uccode={ 0x0053, 0x0053 },
  unicodeslot=0x00DF,
 },
 {
  adobename="agrave",
  category="ll",
  cjkwd="a",
  contextname="agrave",
  description="LATIN SMALL LETTER A WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0300 },
  uccode=0x00C0,
  unicodeslot=0x00E0,
 },
 {
  adobename="aacute",
  category="ll",
  cjkwd="a",
  contextname="aacute",
  description="LATIN SMALL LETTER A WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0301 },
  uccode=0x00C1,
  unicodeslot=0x00E1,
 },
 {
  adobename="acircumflex",
  category="ll",
  contextname="acircumflex",
  description="LATIN SMALL LETTER A WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0302 },
  uccode=0x00C2,
  unicodeslot=0x00E2,
 },
 {
  adobename="atilde",
  category="ll",
  contextname="atilde",
  description="LATIN SMALL LETTER A WITH TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0303 },
  uccode=0x00C3,
  unicodeslot=0x00E3,
 },
 {
  adobename="adieresis",
  category="ll",
  contextname="adiaeresis",
  description="LATIN SMALL LETTER A WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0308 },
  uccode=0x00C4,
  unicodeslot=0x00E4,
 },
 {
  adobename="aring",
  category="ll",
  contextname="aring",
  description="LATIN SMALL LETTER A WITH RING ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x030A },
  uccode=0x00C5,
  unicodeslot=0x00E5,
 },
 {
  adobename="ae",
  category="ll",
  cjkwd="a",
  contextname="aeligature",
  description="LATIN SMALL LETTER AE",
  direction="l",
  linebreak="al",
  shcode={ 0x0061, 0x0065 },
  uccode=0x00C6,
  unicodeslot=0x00E6,
 },
 {
  adobename="ccedilla",
  category="ll",
  contextname="ccedilla",
  description="LATIN SMALL LETTER C WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  specials={ "char", 0x0063, 0x0327 },
  uccode=0x00C7,
  unicodeslot=0x00E7,
 },
 {
  adobename="egrave",
  category="ll",
  cjkwd="a",
  contextname="egrave",
  description="LATIN SMALL LETTER E WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0300 },
  uccode=0x00C8,
  unicodeslot=0x00E8,
 },
 {
  adobename="eacute",
  category="ll",
  cjkwd="a",
  contextname="eacute",
  description="LATIN SMALL LETTER E WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0301 },
  uccode=0x00C9,
  unicodeslot=0x00E9,
 },
 {
  adobename="ecircumflex",
  category="ll",
  cjkwd="a",
  contextname="ecircumflex",
  description="LATIN SMALL LETTER E WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0302 },
  uccode=0x00CA,
  unicodeslot=0x00EA,
 },
 {
  adobename="edieresis",
  category="ll",
  contextname="ediaeresis",
  description="LATIN SMALL LETTER E WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0308 },
  uccode=0x00CB,
  unicodeslot=0x00EB,
 },
 {
  adobename="igrave",
  category="ll",
  cjkwd="a",
  contextname="igrave",
  description="LATIN SMALL LETTER I WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0300 },
  uccode=0x00CC,
  unicodeslot=0x00EC,
 },
 {
  adobename="iacute",
  category="ll",
  cjkwd="a",
  contextname="iacute",
  description="LATIN SMALL LETTER I WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0301 },
  uccode=0x00CD,
  unicodeslot=0x00ED,
 },
 {
  adobename="icircumflex",
  category="ll",
  contextname="icircumflex",
  description="LATIN SMALL LETTER I WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0302 },
  uccode=0x00CE,
  unicodeslot=0x00EE,
 },
 {
  adobename="idieresis",
  category="ll",
  contextname="idiaeresis",
  description="LATIN SMALL LETTER I WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0308 },
  uccode=0x00CF,
  unicodeslot=0x00EF,
 },
 {
  adobename="eth",
  category="ll",
  cjkwd="a",
  comment="contextname=eth",
  description="LATIN SMALL LETTER ETH",
  direction="l",
  linebreak="al",
  mathclass="ordinary",
  mathname="eth",
  uccode=0x00D0,
  unicodeslot=0x00F0,
 },
 {
  adobename="ntilde",
  category="ll",
  contextname="ntilde",
  description="LATIN SMALL LETTER N WITH TILDE",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x0303 },
  uccode=0x00D1,
  unicodeslot=0x00F1,
 },
 {
  adobename="ograve",
  category="ll",
  cjkwd="a",
  contextname="ograve",
  description="LATIN SMALL LETTER O WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0300 },
  uccode=0x00D2,
  unicodeslot=0x00F2,
 },
 {
  adobename="oacute",
  category="ll",
  cjkwd="a",
  contextname="oacute",
  description="LATIN SMALL LETTER O WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0301 },
  uccode=0x00D3,
  unicodeslot=0x00F3,
 },
 {
  adobename="ocircumflex",
  category="ll",
  contextname="ocircumflex",
  description="LATIN SMALL LETTER O WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0302 },
  uccode=0x00D4,
  unicodeslot=0x00F4,
 },
 {
  adobename="otilde",
  category="ll",
  contextname="otilde",
  description="LATIN SMALL LETTER O WITH TILDE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0303 },
  uccode=0x00D5,
  unicodeslot=0x00F5,
 },
 {
  adobename="odieresis",
  category="ll",
  contextname="odiaeresis",
  description="LATIN SMALL LETTER O WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0308 },
  uccode=0x00D6,
  unicodeslot=0x00F6,
 },
 {
  adobename="divide",
  category="sm",
  cjkwd="a",
  contextname="textdiv",
  description="DIVISION SIGN",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="div",
  unicodeslot=0x00F7,
 },
 {
  adobename="oslash",
  category="ll",
  cjkwd="a",
  contextname="ostroke",
  description="LATIN SMALL LETTER O WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  uccode=0x00D8,
  unicodeslot=0x00F8,
 },
 {
  adobename="ugrave",
  category="ll",
  cjkwd="a",
  contextname="ugrave",
  description="LATIN SMALL LETTER U WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0300 },
  uccode=0x00D9,
  unicodeslot=0x00F9,
 },
 {
  adobename="uacute",
  category="ll",
  cjkwd="a",
  contextname="uacute",
  description="LATIN SMALL LETTER U WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0301 },
  uccode=0x00DA,
  unicodeslot=0x00FA,
 },
 {
  adobename="ucircumflex",
  category="ll",
  contextname="ucircumflex",
  description="LATIN SMALL LETTER U WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0302 },
  uccode=0x00DB,
  unicodeslot=0x00FB,
 },
 {
  adobename="udieresis",
  category="ll",
  cjkwd="a",
  contextname="udiaeresis",
  description="LATIN SMALL LETTER U WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0308 },
  uccode=0x00DC,
  unicodeslot=0x00FC,
 },
 {
  adobename="yacute",
  category="ll",
  contextname="yacute",
  description="LATIN SMALL LETTER Y WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0301 },
  uccode=0x00DD,
  unicodeslot=0x00FD,
 },
 {
  adobename="thorn",
  category="ll",
  cjkwd="a",
  contextname="thorn",
  description="LATIN SMALL LETTER THORN",
  direction="l",
  linebreak="al",
  uccode=0x00DE,
  unicodeslot=0x00FE,
 },
 {
  adobename="ydieresis",
  category="ll",
  contextname="ydiaeresis",
  description="LATIN SMALL LETTER Y WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0308 },
  uccode=0x0178,
  unicodeslot=0x00FF,
 },
 {
  adobename="Amacron",
  category="lu",
  contextname="Amacron",
  description="LATIN CAPITAL LETTER A WITH MACRON",
  direction="l",
  lccode=0x0101,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0304 },
  unicodeslot=0x0100,
 },
 {
  adobename="amacron",
  category="ll",
  cjkwd="a",
  contextname="amacron",
  description="LATIN SMALL LETTER A WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0304 },
  uccode=0x0100,
  unicodeslot=0x0101,
 },
 {
  adobename="Abreve",
  category="lu",
  contextname="Abreve",
  description="LATIN CAPITAL LETTER A WITH BREVE",
  direction="l",
  lccode=0x0103,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0306 },
  unicodeslot=0x0102,
 },
 {
  adobename="abreve",
  category="ll",
  contextname="abreve",
  description="LATIN SMALL LETTER A WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0306 },
  uccode=0x0102,
  unicodeslot=0x0103,
 },
 {
  adobename="Aogonek",
  category="lu",
  contextname="Aogonek",
  description="LATIN CAPITAL LETTER A WITH OGONEK",
  direction="l",
  lccode=0x0105,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0328 },
  unicodeslot=0x0104,
 },
 {
  adobename="aogonek",
  category="ll",
  contextname="aogonek",
  description="LATIN SMALL LETTER A WITH OGONEK",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0328 },
  uccode=0x0104,
  unicodeslot=0x0105,
 },
 {
  adobename="Cacute",
  category="lu",
  contextname="Cacute",
  description="LATIN CAPITAL LETTER C WITH ACUTE",
  direction="l",
  lccode=0x0107,
  linebreak="al",
  shcode=0x0043,
  specials={ "char", 0x0043, 0x0301 },
  unicodeslot=0x0106,
 },
 {
  adobename="cacute",
  category="ll",
  contextname="cacute",
  description="LATIN SMALL LETTER C WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  specials={ "char", 0x0063, 0x0301 },
  uccode=0x0106,
  unicodeslot=0x0107,
 },
 {
  adobename="Ccircumflex",
  category="lu",
  contextname="Ccircumflex",
  description="LATIN CAPITAL LETTER C WITH CIRCUMFLEX",
  direction="l",
  lccode=0x0109,
  linebreak="al",
  shcode=0x0043,
  specials={ "char", 0x0043, 0x0302 },
  unicodeslot=0x0108,
 },
 {
  adobename="ccircumflex",
  category="ll",
  contextname="ccircumflex",
  description="LATIN SMALL LETTER C WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  specials={ "char", 0x0063, 0x0302 },
  uccode=0x0108,
  unicodeslot=0x0109,
 },
 {
  adobename="Cdotaccent",
  category="lu",
  contextname="Cdotaccent",
  description="LATIN CAPITAL LETTER C WITH DOT ABOVE",
  direction="l",
  lccode=0x010B,
  linebreak="al",
  shcode=0x0043,
  specials={ "char", 0x0043, 0x0307 },
  unicodeslot=0x010A,
 },
 {
  adobename="cdotaccent",
  category="ll",
  contextname="cdotaccent",
  description="LATIN SMALL LETTER C WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  specials={ "char", 0x0063, 0x0307 },
  uccode=0x010A,
  unicodeslot=0x010B,
 },
 {
  adobename="Ccaron",
  category="lu",
  contextname="Ccaron",
  description="LATIN CAPITAL LETTER C WITH CARON",
  direction="l",
  lccode=0x010D,
  linebreak="al",
  shcode=0x0043,
  specials={ "char", 0x0043, 0x030C },
  unicodeslot=0x010C,
 },
 {
  adobename="ccaron",
  category="ll",
  contextname="ccaron",
  description="LATIN SMALL LETTER C WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  specials={ "char", 0x0063, 0x030C },
  uccode=0x010C,
  unicodeslot=0x010D,
 },
 {
  adobename="Dcaron",
  category="lu",
  contextname="Dcaron",
  description="LATIN CAPITAL LETTER D WITH CARON",
  direction="l",
  lccode=0x010F,
  linebreak="al",
  shcode=0x0044,
  specials={ "char", 0x0044, 0x030C },
  unicodeslot=0x010E,
 },
 {
  adobename="dcaron",
  category="ll",
  contextname="dcaron",
  description="LATIN SMALL LETTER D WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  specials={ "char", 0x0064, 0x030C },
  uccode=0x010E,
  unicodeslot=0x010F,
 },
 {
  adobename="Dslash",
  category="lu",
  contextname="Dstroke",
  description="LATIN CAPITAL LETTER D WITH STROKE",
  direction="l",
  lccode=0x0111,
  linebreak="al",
  shcode=0x0044,
  unicodeslot=0x0110,
 },
 {
  adobename="dmacron",
  category="ll",
  cjkwd="a",
  contextname="dstroke",
  description="LATIN SMALL LETTER D WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  uccode=0x0110,
  unicodeslot=0x0111,
 },
 {
  adobename="Emacron",
  category="lu",
  contextname="Emacron",
  description="LATIN CAPITAL LETTER E WITH MACRON",
  direction="l",
  lccode=0x0113,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0304 },
  unicodeslot=0x0112,
 },
 {
  adobename="emacron",
  category="ll",
  cjkwd="a",
  contextname="emacron",
  description="LATIN SMALL LETTER E WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0304 },
  uccode=0x0112,
  unicodeslot=0x0113,
 },
 {
  adobename="Ebreve",
  category="lu",
  contextname="Ebreve",
  description="LATIN CAPITAL LETTER E WITH BREVE",
  direction="l",
  lccode=0x0115,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0306 },
  unicodeslot=0x0114,
 },
 {
  adobename="ebreve",
  category="ll",
  contextname="ebreve",
  description="LATIN SMALL LETTER E WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0306 },
  uccode=0x0114,
  unicodeslot=0x0115,
 },
 {
  adobename="Edotaccent",
  category="lu",
  contextname="Edotaccent",
  description="LATIN CAPITAL LETTER E WITH DOT ABOVE",
  direction="l",
  lccode=0x0117,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0307 },
  unicodeslot=0x0116,
 },
 {
  adobename="edotaccent",
  category="ll",
  contextname="edotaccent",
  description="LATIN SMALL LETTER E WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0307 },
  uccode=0x0116,
  unicodeslot=0x0117,
 },
 {
  adobename="Eogonek",
  category="lu",
  contextname="Eogonek",
  description="LATIN CAPITAL LETTER E WITH OGONEK",
  direction="l",
  lccode=0x0119,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0328 },
  unicodeslot=0x0118,
 },
 {
  adobename="eogonek",
  category="ll",
  contextname="eogonek",
  description="LATIN SMALL LETTER E WITH OGONEK",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0328 },
  uccode=0x0118,
  unicodeslot=0x0119,
 },
 {
  adobename="Ecaron",
  category="lu",
  contextname="Ecaron",
  description="LATIN CAPITAL LETTER E WITH CARON",
  direction="l",
  lccode=0x011B,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x030C },
  unicodeslot=0x011A,
 },
 {
  adobename="ecaron",
  category="ll",
  cjkwd="a",
  contextname="ecaron",
  description="LATIN SMALL LETTER E WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x030C },
  uccode=0x011A,
  unicodeslot=0x011B,
 },
 {
  adobename="Gcircumflex",
  category="lu",
  contextname="Gcircumflex",
  description="LATIN CAPITAL LETTER G WITH CIRCUMFLEX",
  direction="l",
  lccode=0x011D,
  linebreak="al",
  shcode=0x0047,
  specials={ "char", 0x0047, 0x0302 },
  unicodeslot=0x011C,
 },
 {
  adobename="gcircumflex",
  category="ll",
  contextname="gcircumflex",
  description="LATIN SMALL LETTER G WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  specials={ "char", 0x0067, 0x0302 },
  uccode=0x011C,
  unicodeslot=0x011D,
 },
 {
  adobename="Gbreve",
  category="lu",
  contextname="Gbreve",
  description="LATIN CAPITAL LETTER G WITH BREVE",
  direction="l",
  lccode=0x011F,
  linebreak="al",
  shcode=0x0047,
  specials={ "char", 0x0047, 0x0306 },
  unicodeslot=0x011E,
 },
 {
  adobename="gbreve",
  category="ll",
  contextname="gbreve",
  description="LATIN SMALL LETTER G WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  specials={ "char", 0x0067, 0x0306 },
  uccode=0x011E,
  unicodeslot=0x011F,
 },
 {
  adobename="Gdotaccent",
  category="lu",
  contextname="Gdotaccent",
  description="LATIN CAPITAL LETTER G WITH DOT ABOVE",
  direction="l",
  lccode=0x0121,
  linebreak="al",
  shcode=0x0047,
  specials={ "char", 0x0047, 0x0307 },
  unicodeslot=0x0120,
 },
 {
  adobename="gdotaccent",
  category="ll",
  contextname="gdotaccent",
  description="LATIN SMALL LETTER G WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  specials={ "char", 0x0067, 0x0307 },
  uccode=0x0120,
  unicodeslot=0x0121,
 },
 {
  adobename="Gcommaaccent",
  category="lu",
  contextname="Gcommaaccent",
  description="LATIN CAPITAL LETTER G WITH CEDILLA",
  direction="l",
  lccode=0x0123,
  linebreak="al",
  shcode=0x0047,
  specials={ "char", 0x0047, 0x0327 },
  unicodeslot=0x0122,
 },
 {
  adobename="gcommaaccent",
  category="ll",
  contextname="gcommaaccent",
  description="LATIN SMALL LETTER G WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  specials={ "char", 0x0067, 0x0327 },
  uccode=0x0122,
  unicodeslot=0x0123,
 },
 {
  adobename="Hcircumflex",
  category="lu",
  contextname="Hcircumflex",
  description="LATIN CAPITAL LETTER H WITH CIRCUMFLEX",
  direction="l",
  lccode=0x0125,
  linebreak="al",
  shcode=0x0048,
  specials={ "char", 0x0048, 0x0302 },
  unicodeslot=0x0124,
 },
 {
  adobename="hcircumflex",
  category="ll",
  contextname="hcircumflex",
  description="LATIN SMALL LETTER H WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  specials={ "char", 0x0068, 0x0302 },
  uccode=0x0124,
  unicodeslot=0x0125,
 },
 {
  adobename="Hbar",
  category="lu",
  cjkwd="a",
  contextname="Hstroke",
  description="LATIN CAPITAL LETTER H WITH STROKE",
  direction="l",
  lccode=0x0127,
  linebreak="al",
  shcode=0x0048,
  unicodeslot=0x0126,
 },
 {
  adobename="hbar",
  category="ll",
  cjkwd="a",
  contextname="hstroke",
  description="LATIN SMALL LETTER H WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  uccode=0x0126,
  unicodeslot=0x0127,
 },
 {
  adobename="Itilde",
  category="lu",
  contextname="Itilde",
  description="LATIN CAPITAL LETTER I WITH TILDE",
  direction="l",
  lccode=0x0129,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0303 },
  unicodeslot=0x0128,
 },
 {
  adobename="itilde",
  category="ll",
  contextname="itilde",
  description="LATIN SMALL LETTER I WITH TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0303 },
  uccode=0x0128,
  unicodeslot=0x0129,
 },
 {
  adobename="Imacron",
  category="lu",
  contextname="Imacron",
  description="LATIN CAPITAL LETTER I WITH MACRON",
  direction="l",
  lccode=0x012B,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0304 },
  unicodeslot=0x012A,
 },
 {
  adobename="imacron",
  category="ll",
  cjkwd="a",
  contextname="imacron",
  description="LATIN SMALL LETTER I WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0304 },
  uccode=0x012A,
  unicodeslot=0x012B,
 },
 {
  adobename="Ibreve",
  category="lu",
  contextname="Ibreve",
  description="LATIN CAPITAL LETTER I WITH BREVE",
  direction="l",
  lccode=0x012D,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0306 },
  unicodeslot=0x012C,
 },
 {
  adobename="ibreve",
  category="ll",
  contextname="ibreve",
  description="LATIN SMALL LETTER I WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0306 },
  uccode=0x012C,
  unicodeslot=0x012D,
 },
 {
  adobename="Iogonek",
  category="lu",
  contextname="Iogonek",
  description="LATIN CAPITAL LETTER I WITH OGONEK",
  direction="l",
  lccode=0x012F,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0328 },
  unicodeslot=0x012E,
 },
 {
  adobename="iogonek",
  category="ll",
  contextname="iogonek",
  description="LATIN SMALL LETTER I WITH OGONEK",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0328 },
  uccode=0x012E,
  unicodeslot=0x012F,
 },
 {
  adobename="Idotaccent",
  category="lu",
  contextname="Idotaccent",
  description="LATIN CAPITAL LETTER I WITH DOT ABOVE",
  direction="l",
  lccode=0x0069,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0307 },
  unicodeslot=0x0130,
 },
 {
  adobename="dotlessi",
  category="ll",
  cjkwd="a",
  contextname="dotlessi",
  description="LATIN SMALL LETTER DOTLESS I",
  direction="l",
  linebreak="al",
  uccode=0x0049,
  unicodeslot=0x0131,
 },
 {
  adobename="IJ",
  category="lu",
  cjkwd="a",
  contextname="IJligature",
  description="LATIN CAPITAL LIGATURE IJ",
  direction="l",
  lccode=0x0133,
  linebreak="al",
  shcode={ 0x0049, 0x004A },
  specials={ "compat", 0x0049, 0x004A },
  unicodeslot=0x0132,
 },
 {
  adobename="ij",
  category="ll",
  cjkwd="a",
  contextname="ijligature",
  description="LATIN SMALL LIGATURE IJ",
  direction="l",
  linebreak="al",
  shcode={ 0x0069, 0x006A },
  specials={ "compat", 0x0069, 0x006A },
  uccode=0x0132,
  unicodeslot=0x0133,
 },
 {
  adobename="Jcircumflex",
  category="lu",
  contextname="Jcircumflex",
  description="LATIN CAPITAL LETTER J WITH CIRCUMFLEX",
  direction="l",
  lccode=0x0135,
  linebreak="al",
  shcode=0x004A,
  specials={ "char", 0x004A, 0x0302 },
  unicodeslot=0x0134,
 },
 {
  adobename="jcircumflex",
  category="ll",
  contextname="jcircumflex",
  description="LATIN SMALL LETTER J WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x006A,
  specials={ "char", 0x006A, 0x0302 },
  uccode=0x0134,
  unicodeslot=0x0135,
 },
 {
  adobename="Kcommaaccent",
  category="lu",
  contextname="Kcommaaccent",
  description="LATIN CAPITAL LETTER K WITH CEDILLA",
  direction="l",
  lccode=0x0137,
  linebreak="al",
  shcode=0x004B,
  specials={ "char", 0x004B, 0x0327 },
  unicodeslot=0x0136,
 },
 {
  adobename="kcommaaccent",
  category="ll",
  contextname="kcommaaccent",
  description="LATIN SMALL LETTER K WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x006B,
  specials={ "char", 0x006B, 0x0327 },
  uccode=0x0136,
  unicodeslot=0x0137,
 },
 {
  adobename="kgreenlandic",
  category="ll",
  cjkwd="a",
  contextname="kkra",
  description="LATIN SMALL LETTER KRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0138,
 },
 {
  adobename="Lacute",
  category="lu",
  contextname="Lacute",
  description="LATIN CAPITAL LETTER L WITH ACUTE",
  direction="l",
  lccode=0x013A,
  linebreak="al",
  shcode=0x004C,
  specials={ "char", 0x004C, 0x0301 },
  unicodeslot=0x0139,
 },
 {
  adobename="lacute",
  category="ll",
  contextname="lacute",
  description="LATIN SMALL LETTER L WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  specials={ "char", 0x006C, 0x0301 },
  uccode=0x0139,
  unicodeslot=0x013A,
 },
 {
  adobename="Lcommaaccent",
  category="lu",
  contextname="Lcommaaccent",
  description="LATIN CAPITAL LETTER L WITH CEDILLA",
  direction="l",
  lccode=0x013C,
  linebreak="al",
  shcode=0x004C,
  specials={ "char", 0x004C, 0x0327 },
  unicodeslot=0x013B,
 },
 {
  adobename="lcommaaccent",
  category="ll",
  contextname="lcommaaccent",
  description="LATIN SMALL LETTER L WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  specials={ "char", 0x006C, 0x0327 },
  uccode=0x013B,
  unicodeslot=0x013C,
 },
 {
  adobename="Lcaron",
  category="lu",
  contextname="Lcaron",
  description="LATIN CAPITAL LETTER L WITH CARON",
  direction="l",
  lccode=0x013E,
  linebreak="al",
  shcode=0x004C,
  specials={ "char", 0x004C, 0x030C },
  unicodeslot=0x013D,
 },
 {
  adobename="lcaron",
  category="ll",
  contextname="lcaron",
  description="LATIN SMALL LETTER L WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  specials={ "char", 0x006C, 0x030C },
  uccode=0x013D,
  unicodeslot=0x013E,
 },
 {
  adobename="Ldotaccent",
  category="lu",
  cjkwd="a",
  contextname="Ldotmiddle",
  description="LATIN CAPITAL LETTER L WITH MIDDLE DOT",
  direction="l",
  lccode=0x0140,
  linebreak="al",
  shcode=0x004C,
  specials={ "compat", 0x004C, 0x00B7 },
  unicodeslot=0x013F,
 },
 {
  adobename="ldotaccent",
  category="ll",
  cjkwd="a",
  contextname="ldotmiddle",
  description="LATIN SMALL LETTER L WITH MIDDLE DOT",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  specials={ "compat", 0x006C, 0x00B7 },
  uccode=0x013F,
  unicodeslot=0x0140,
 },
 {
  adobename="Lslash",
  category="lu",
  cjkwd="a",
  contextname="Lstroke",
  description="LATIN CAPITAL LETTER L WITH STROKE",
  direction="l",
  lccode=0x0142,
  linebreak="al",
  shcode=0x004C,
  unicodeslot=0x0141,
 },
 {
  adobename="lslash",
  category="ll",
  cjkwd="a",
  contextname="lstroke",
  description="LATIN SMALL LETTER L WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  uccode=0x0141,
  unicodeslot=0x0142,
 },
 {
  adobename="Nacute",
  category="lu",
  contextname="Nacute",
  description="LATIN CAPITAL LETTER N WITH ACUTE",
  direction="l",
  lccode=0x0144,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x0301 },
  unicodeslot=0x0143,
 },
 {
  adobename="nacute",
  category="ll",
  cjkwd="a",
  contextname="nacute",
  description="LATIN SMALL LETTER N WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x0301 },
  uccode=0x0143,
  unicodeslot=0x0144,
 },
 {
  adobename="Ncommaaccent",
  category="lu",
  contextname="Ncommaaccent",
  description="LATIN CAPITAL LETTER N WITH CEDILLA",
  direction="l",
  lccode=0x0146,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x0327 },
  unicodeslot=0x0145,
 },
 {
  adobename="ncommaaccent",
  category="ll",
  contextname="ncommaaccent",
  description="LATIN SMALL LETTER N WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x0327 },
  uccode=0x0145,
  unicodeslot=0x0146,
 },
 {
  adobename="Ncaron",
  category="lu",
  contextname="Ncaron",
  description="LATIN CAPITAL LETTER N WITH CARON",
  direction="l",
  lccode=0x0148,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x030C },
  unicodeslot=0x0147,
 },
 {
  adobename="ncaron",
  category="ll",
  cjkwd="a",
  contextname="ncaron",
  description="LATIN SMALL LETTER N WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x030C },
  uccode=0x0147,
  unicodeslot=0x0148,
 },
 {
  adobename="quoterightn",
  category="ll",
  cjkwd="a",
  contextname="napostrophe",
  description="LATIN SMALL LETTER N PRECEDED BY APOSTROPHE",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x02BC, 0x006E },
  unicodeslot=0x0149,
 },
 {
  adobename="Eng",
  category="lu",
  cjkwd="a",
  contextname="Neng",
  description="LATIN CAPITAL LETTER ENG",
  direction="l",
  lccode=0x014B,
  linebreak="al",
  unicodeslot=0x014A,
 },
 {
  adobename="eng",
  category="ll",
  cjkwd="a",
  contextname="neng",
  description="LATIN SMALL LETTER ENG",
  direction="l",
  linebreak="al",
  uccode=0x014A,
  unicodeslot=0x014B,
 },
 {
  adobename="Omacron",
  category="lu",
  contextname="Omacron",
  description="LATIN CAPITAL LETTER O WITH MACRON",
  direction="l",
  lccode=0x014D,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0304 },
  unicodeslot=0x014C,
 },
 {
  adobename="omacron",
  category="ll",
  cjkwd="a",
  contextname="omacron",
  description="LATIN SMALL LETTER O WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0304 },
  uccode=0x014C,
  unicodeslot=0x014D,
 },
 {
  adobename="Obreve",
  category="lu",
  contextname="Obreve",
  description="LATIN CAPITAL LETTER O WITH BREVE",
  direction="l",
  lccode=0x014F,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0306 },
  unicodeslot=0x014E,
 },
 {
  adobename="obreve",
  category="ll",
  contextname="obreve",
  description="LATIN SMALL LETTER O WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0306 },
  uccode=0x014E,
  unicodeslot=0x014F,
 },
 {
  adobename="Ohungarumlaut",
  category="lu",
  contextname="Ohungarumlaut",
  description="LATIN CAPITAL LETTER O WITH DOUBLE ACUTE",
  direction="l",
  lccode=0x0151,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x030B },
  unicodeslot=0x0150,
 },
 {
  adobename="ohungarumlaut",
  category="ll",
  contextname="ohungarumlaut",
  description="LATIN SMALL LETTER O WITH DOUBLE ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x030B },
  uccode=0x0150,
  unicodeslot=0x0151,
 },
 {
  adobename="OE",
  category="lu",
  cjkwd="a",
  contextname="OEligature",
  description="LATIN CAPITAL LIGATURE OE",
  direction="l",
  lccode=0x0153,
  linebreak="al",
  shcode={ 0x004F, 0x0045 },
  unicodeslot=0x0152,
 },
 {
  adobename="oe",
  category="ll",
  cjkwd="a",
  contextname="oeligature",
  description="LATIN SMALL LIGATURE OE",
  direction="l",
  linebreak="al",
  shcode={ 0x006F, 0x0065 },
  uccode=0x0152,
  unicodeslot=0x0153,
 },
 {
  adobename="Racute",
  category="lu",
  contextname="Racute",
  description="LATIN CAPITAL LETTER R WITH ACUTE",
  direction="l",
  lccode=0x0155,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x0052, 0x0301 },
  unicodeslot=0x0154,
 },
 {
  adobename="racute",
  category="ll",
  contextname="racute",
  description="LATIN SMALL LETTER R WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x0072, 0x0301 },
  uccode=0x0154,
  unicodeslot=0x0155,
 },
 {
  adobename="Rcommaaccent",
  category="lu",
  contextname="Rcommaaccent",
  description="LATIN CAPITAL LETTER R WITH CEDILLA",
  direction="l",
  lccode=0x0157,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x0052, 0x0327 },
  unicodeslot=0x0156,
 },
 {
  adobename="rcommaaccent",
  category="ll",
  contextname="rcommaaccent",
  description="LATIN SMALL LETTER R WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x0072, 0x0327 },
  uccode=0x0156,
  unicodeslot=0x0157,
 },
 {
  adobename="Rcaron",
  category="lu",
  contextname="Rcaron",
  description="LATIN CAPITAL LETTER R WITH CARON",
  direction="l",
  lccode=0x0159,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x0052, 0x030C },
  unicodeslot=0x0158,
 },
 {
  adobename="rcaron",
  category="ll",
  contextname="rcaron",
  description="LATIN SMALL LETTER R WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x0072, 0x030C },
  uccode=0x0158,
  unicodeslot=0x0159,
 },
 {
  adobename="Sacute",
  category="lu",
  contextname="Sacute",
  description="LATIN CAPITAL LETTER S WITH ACUTE",
  direction="l",
  lccode=0x015B,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x0053, 0x0301 },
  unicodeslot=0x015A,
 },
 {
  adobename="sacute",
  category="ll",
  contextname="sacute",
  description="LATIN SMALL LETTER S WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x0073, 0x0301 },
  uccode=0x015A,
  unicodeslot=0x015B,
 },
 {
  adobename="Scircumflex",
  category="lu",
  contextname="Scircumflex",
  description="LATIN CAPITAL LETTER S WITH CIRCUMFLEX",
  direction="l",
  lccode=0x015D,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x0053, 0x0302 },
  unicodeslot=0x015C,
 },
 {
  adobename="scircumflex",
  category="ll",
  contextname="scircumflex",
  description="LATIN SMALL LETTER S WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x0073, 0x0302 },
  uccode=0x015C,
  unicodeslot=0x015D,
 },
 {
  adobename="Scedilla",
  category="lu",
  contextname="Scedilla",
  description="LATIN CAPITAL LETTER S WITH CEDILLA",
  direction="l",
  lccode=0x015F,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x0053, 0x0327 },
  unicodeslot=0x015E,
 },
 {
  adobename="scedilla",
  category="ll",
  contextname="scedilla",
  description="LATIN SMALL LETTER S WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x0073, 0x0327 },
  uccode=0x015E,
  unicodeslot=0x015F,
 },
 {
  adobename="Scaron",
  category="lu",
  contextname="Scaron",
  description="LATIN CAPITAL LETTER S WITH CARON",
  direction="l",
  lccode=0x0161,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x0053, 0x030C },
  unicodeslot=0x0160,
 },
 {
  adobename="scaron",
  category="ll",
  contextname="scaron",
  description="LATIN SMALL LETTER S WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x0073, 0x030C },
  uccode=0x0160,
  unicodeslot=0x0161,
 },
 {
  adobename="Tcommaaccent",
  category="lu",
  contextname="Tcedilla",
  description="LATIN CAPITAL LETTER T WITH CEDILLA",
  direction="l",
  lccode=0x0163,
  linebreak="al",
  shcode=0x0054,
  specials={ "char", 0x0054, 0x0327 },
  unicodeslot=0x0162,
 },
 {
  adobename="tcommaaccent",
  category="ll",
  contextname="tcedilla",
  description="LATIN SMALL LETTER T WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  specials={ "char", 0x0074, 0x0327 },
  uccode=0x0162,
  unicodeslot=0x0163,
 },
 {
  adobename="Tcaron",
  category="lu",
  contextname="Tcaron",
  description="LATIN CAPITAL LETTER T WITH CARON",
  direction="l",
  lccode=0x0165,
  linebreak="al",
  shcode=0x0054,
  specials={ "char", 0x0054, 0x030C },
  unicodeslot=0x0164,
 },
 {
  adobename="tcaron",
  category="ll",
  contextname="tcaron",
  description="LATIN SMALL LETTER T WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  specials={ "char", 0x0074, 0x030C },
  uccode=0x0164,
  unicodeslot=0x0165,
 },
 {
  adobename="Tbar",
  category="lu",
  cjkwd="a",
  contextname="Tstroke",
  description="LATIN CAPITAL LETTER T WITH STROKE",
  direction="l",
  lccode=0x0167,
  linebreak="al",
  shcode=0x0054,
  unicodeslot=0x0166,
 },
 {
  adobename="tbar",
  category="ll",
  cjkwd="a",
  contextname="tstroke",
  description="LATIN SMALL LETTER T WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  uccode=0x0166,
  unicodeslot=0x0167,
 },
 {
  adobename="Utilde",
  category="lu",
  contextname="Utilde",
  description="LATIN CAPITAL LETTER U WITH TILDE",
  direction="l",
  lccode=0x0169,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0303 },
  unicodeslot=0x0168,
 },
 {
  adobename="utilde",
  category="ll",
  contextname="utilde",
  description="LATIN SMALL LETTER U WITH TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0303 },
  uccode=0x0168,
  unicodeslot=0x0169,
 },
 {
  adobename="Umacron",
  category="lu",
  contextname="Umacron",
  description="LATIN CAPITAL LETTER U WITH MACRON",
  direction="l",
  lccode=0x016B,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0304 },
  unicodeslot=0x016A,
 },
 {
  adobename="umacron",
  category="ll",
  cjkwd="a",
  contextname="umacron",
  description="LATIN SMALL LETTER U WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0304 },
  uccode=0x016A,
  unicodeslot=0x016B,
 },
 {
  adobename="Ubreve",
  category="lu",
  contextname="Ubreve",
  description="LATIN CAPITAL LETTER U WITH BREVE",
  direction="l",
  lccode=0x016D,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0306 },
  unicodeslot=0x016C,
 },
 {
  adobename="ubreve",
  category="ll",
  contextname="ubreve",
  description="LATIN SMALL LETTER U WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0306 },
  uccode=0x016C,
  unicodeslot=0x016D,
 },
 {
  adobename="Uring",
  category="lu",
  contextname="Uring",
  description="LATIN CAPITAL LETTER U WITH RING ABOVE",
  direction="l",
  lccode=0x016F,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x030A },
  unicodeslot=0x016E,
 },
 {
  adobename="uring",
  category="ll",
  contextname="uring",
  description="LATIN SMALL LETTER U WITH RING ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x030A },
  uccode=0x016E,
  unicodeslot=0x016F,
 },
 {
  adobename="Uhungarumlaut",
  category="lu",
  contextname="Uhungarumlaut",
  description="LATIN CAPITAL LETTER U WITH DOUBLE ACUTE",
  direction="l",
  lccode=0x0171,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x030B },
  unicodeslot=0x0170,
 },
 {
  adobename="uhungarumlaut",
  category="ll",
  contextname="uhungarumlaut",
  description="LATIN SMALL LETTER U WITH DOUBLE ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x030B },
  uccode=0x0170,
  unicodeslot=0x0171,
 },
 {
  adobename="Uogonek",
  category="lu",
  contextname="Uogonek",
  description="LATIN CAPITAL LETTER U WITH OGONEK",
  direction="l",
  lccode=0x0173,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0328 },
  unicodeslot=0x0172,
 },
 {
  adobename="uogonek",
  category="ll",
  contextname="uogonek",
  description="LATIN SMALL LETTER U WITH OGONEK",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0328 },
  uccode=0x0172,
  unicodeslot=0x0173,
 },
 {
  adobename="Wcircumflex",
  category="lu",
  contextname="Wcircumflex",
  description="LATIN CAPITAL LETTER W WITH CIRCUMFLEX",
  direction="l",
  lccode=0x0175,
  linebreak="al",
  shcode=0x0057,
  specials={ "char", 0x0057, 0x0302 },
  unicodeslot=0x0174,
 },
 {
  adobename="wcircumflex",
  category="ll",
  contextname="wcircumflex",
  description="LATIN SMALL LETTER W WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0077,
  specials={ "char", 0x0077, 0x0302 },
  uccode=0x0174,
  unicodeslot=0x0175,
 },
 {
  adobename="Ycircumflex",
  category="lu",
  contextname="Ycircumflex",
  description="LATIN CAPITAL LETTER Y WITH CIRCUMFLEX",
  direction="l",
  lccode=0x0177,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0302 },
  unicodeslot=0x0176,
 },
 {
  adobename="ycircumflex",
  category="ll",
  contextname="ycircumflex",
  description="LATIN SMALL LETTER Y WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0302 },
  uccode=0x0176,
  unicodeslot=0x0177,
 },
 {
  adobename="Ydieresis",
  category="lu",
  contextname="Ydiaeresis",
  description="LATIN CAPITAL LETTER Y WITH DIAERESIS",
  direction="l",
  lccode=0x00FF,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0308 },
  unicodeslot=0x0178,
 },
 {
  adobename="Zacute",
  category="lu",
  contextname="Zacute",
  description="LATIN CAPITAL LETTER Z WITH ACUTE",
  direction="l",
  lccode=0x017A,
  linebreak="al",
  shcode=0x005A,
  specials={ "char", 0x005A, 0x0301 },
  unicodeslot=0x0179,
 },
 {
  adobename="zacute",
  category="ll",
  contextname="zacute",
  description="LATIN SMALL LETTER Z WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  specials={ "char", 0x007A, 0x0301 },
  uccode=0x0179,
  unicodeslot=0x017A,
 },
 {
  adobename="Zdotaccent",
  category="lu",
  contextname="Zdotaccent",
  description="LATIN CAPITAL LETTER Z WITH DOT ABOVE",
  direction="l",
  lccode=0x017C,
  linebreak="al",
  shcode=0x005A,
  specials={ "char", 0x005A, 0x0307 },
  unicodeslot=0x017B,
 },
 {
  adobename="zdotaccent",
  category="ll",
  contextname="zdotaccent",
  description="LATIN SMALL LETTER Z WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  specials={ "char", 0x007A, 0x0307 },
  uccode=0x017B,
  unicodeslot=0x017C,
 },
 {
  adobename="Zcaron",
  category="lu",
  contextname="Zcaron",
  description="LATIN CAPITAL LETTER Z WITH CARON",
  direction="l",
  lccode=0x017E,
  linebreak="al",
  shcode=0x005A,
  specials={ "char", 0x005A, 0x030C },
  unicodeslot=0x017D,
 },
 {
  adobename="zcaron",
  category="ll",
  contextname="zcaron",
  description="LATIN SMALL LETTER Z WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  specials={ "char", 0x007A, 0x030C },
  uccode=0x017D,
  unicodeslot=0x017E,
 },
 {
  adobename="slong",
  category="ll",
  contextname="slong",
  description="LATIN SMALL LETTER LONG S",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0073 },
  uccode=0x0053,
  unicodeslot=0x017F,
 },
 {
  adobename="bstroke",
  category="ll",
  contextname="bstroke",
  description="LATIN SMALL LETTER B WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0062,
  uccode=0x0243,
  unicodeslot=0x0180,
 },
 {
  adobename="Bhook",
  category="lu",
  contextname="Bhook",
  description="LATIN CAPITAL LETTER B WITH HOOK",
  direction="l",
  lccode=0x0253,
  linebreak="al",
  shcode=0x0042,
  unicodeslot=0x0181,
 },
 {
  adobename="Btopbar",
  category="lu",
  description="LATIN CAPITAL LETTER B WITH TOPBAR",
  direction="l",
  lccode=0x0183,
  linebreak="al",
  shcode=0x0042,
  unicodeslot=0x0182,
 },
 {
  adobename="btopbar",
  category="ll",
  description="LATIN SMALL LETTER B WITH TOPBAR",
  direction="l",
  linebreak="al",
  shcode=0x0062,
  uccode=0x0182,
  unicodeslot=0x0183,
 },
 {
  adobename="Tonesix",
  category="lu",
  description="LATIN CAPITAL LETTER TONE SIX",
  direction="l",
  lccode=0x0185,
  linebreak="al",
  unicodeslot=0x0184,
 },
 {
  adobename="tonesix",
  category="ll",
  description="LATIN SMALL LETTER TONE SIX",
  direction="l",
  linebreak="al",
  uccode=0x0184,
  unicodeslot=0x0185,
 },
 {
  adobename="Oopen",
  category="lu",
  description="LATIN CAPITAL LETTER OPEN O",
  direction="l",
  lccode=0x0254,
  linebreak="al",
  unicodeslot=0x0186,
 },
 {
  adobename="Chook",
  category="lu",
  contextname="Chook",
  description="LATIN CAPITAL LETTER C WITH HOOK",
  direction="l",
  lccode=0x0188,
  linebreak="al",
  shcode=0x0043,
  unicodeslot=0x0187,
 },
 {
  adobename="chook",
  category="ll",
  contextname="chook",
  description="LATIN SMALL LETTER C WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  uccode=0x0187,
  unicodeslot=0x0188,
 },
 {
  adobename="Dafrican",
  category="lu",
  contextname="Dafrican",
  description="LATIN CAPITAL LETTER AFRICAN D",
  direction="l",
  lccode=0x0256,
  linebreak="al",
  unicodeslot=0x0189,
 },
 {
  adobename="Dhook",
  category="lu",
  contextname="Dhook",
  description="LATIN CAPITAL LETTER D WITH HOOK",
  direction="l",
  lccode=0x0257,
  linebreak="al",
  shcode=0x0044,
  unicodeslot=0x018A,
 },
 {
  adobename="Dtopbar",
  category="lu",
  description="LATIN CAPITAL LETTER D WITH TOPBAR",
  direction="l",
  lccode=0x018C,
  linebreak="al",
  shcode=0x0044,
  unicodeslot=0x018B,
 },
 {
  adobename="dtopbar",
  category="ll",
  description="LATIN SMALL LETTER D WITH TOPBAR",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  uccode=0x018B,
  unicodeslot=0x018C,
 },
 {
  adobename="deltaturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED DELTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x018D,
 },
 {
  adobename="Ereversed",
  category="lu",
  description="LATIN CAPITAL LETTER REVERSED E",
  direction="l",
  lccode=0x01DD,
  linebreak="al",
  unicodeslot=0x018E,
 },
 {
  adobename="Schwa",
  category="lu",
  contextname="Schwa",
  description="LATIN CAPITAL LETTER SCHWA",
  direction="l",
  lccode=0x0259,
  linebreak="al",
  unicodeslot=0x018F,
 },
 {
  adobename="Eopen",
  category="lu",
  description="LATIN CAPITAL LETTER OPEN E",
  direction="l",
  lccode=0x025B,
  linebreak="al",
  unicodeslot=0x0190,
 },
 {
  adobename="Fhook",
  category="lu",
  contextname="Fhook",
  description="LATIN CAPITAL LETTER F WITH HOOK",
  direction="l",
  lccode=0x0192,
  linebreak="al",
  shcode=0x0046,
  unicodeslot=0x0191,
 },
 {
  adobename="florin",
  category="ll",
  contextname="fhook",
  description="LATIN SMALL LETTER F WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0066,
  uccode=0x0191,
  unicodeslot=0x0192,
 },
 {
  adobename="Ghook",
  category="lu",
  contextname="Ghook",
  description="LATIN CAPITAL LETTER G WITH HOOK",
  direction="l",
  lccode=0x0260,
  linebreak="al",
  shcode=0x0047,
  unicodeslot=0x0193,
 },
 {
  adobename="Gammaafrican",
  category="lu",
  description="LATIN CAPITAL LETTER GAMMA",
  direction="l",
  lccode=0x0263,
  linebreak="al",
  unicodeslot=0x0194,
 },
 {
  adobename="hv",
  category="ll",
  description="LATIN SMALL LETTER HV",
  direction="l",
  linebreak="al",
  uccode=0x01F6,
  unicodeslot=0x0195,
 },
 {
  adobename="Iotaafrican",
  category="lu",
  description="LATIN CAPITAL LETTER IOTA",
  direction="l",
  lccode=0x0269,
  linebreak="al",
  unicodeslot=0x0196,
 },
 {
  adobename="Istroke",
  category="lu",
  contextname="Istroke",
  description="LATIN CAPITAL LETTER I WITH STROKE",
  direction="l",
  lccode=0x0268,
  linebreak="al",
  shcode=0x0049,
  unicodeslot=0x0197,
 },
 {
  adobename="Khook",
  category="lu",
  contextname="Khook",
  description="LATIN CAPITAL LETTER K WITH HOOK",
  direction="l",
  lccode=0x0199,
  linebreak="al",
  shcode=0x004B,
  unicodeslot=0x0198,
 },
 {
  adobename="khook",
  category="ll",
  contextname="khook",
  description="LATIN SMALL LETTER K WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006B,
  uccode=0x0198,
  unicodeslot=0x0199,
 },
 {
  adobename="lbar",
  category="ll",
  contextname="lbar",
  description="LATIN SMALL LETTER L WITH BAR",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  uccode=0x023D,
  unicodeslot=0x019A,
 },
 {
  adobename="lambdastroke",
  category="ll",
  description="LATIN SMALL LETTER LAMBDA WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x019B,
 },
 {
  adobename="Mturned",
  category="lu",
  description="LATIN CAPITAL LETTER TURNED M",
  direction="l",
  lccode=0x026F,
  linebreak="al",
  unicodeslot=0x019C,
 },
 {
  adobename="Nhookleft",
  category="lu",
  description="LATIN CAPITAL LETTER N WITH LEFT HOOK",
  direction="l",
  lccode=0x0272,
  linebreak="al",
  shcode=0x004E,
  unicodeslot=0x019D,
 },
 {
  adobename="nlegrightlong",
  category="ll",
  description="LATIN SMALL LETTER N WITH LONG RIGHT LEG",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  uccode=0x0220,
  unicodeslot=0x019E,
 },
 {
  adobename="Ocenteredtilde",
  category="lu",
  description="LATIN CAPITAL LETTER O WITH MIDDLE TILDE",
  direction="l",
  lccode=0x0275,
  linebreak="al",
  shcode=0x004F,
  unicodeslot=0x019F,
 },
 {
  adobename="Ohorn",
  category="lu",
  contextname="Ohorn",
  description="LATIN CAPITAL LETTER O WITH HORN",
  direction="l",
  lccode=0x01A1,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x031B },
  unicodeslot=0x01A0,
 },
 {
  adobename="ohorn",
  category="ll",
  contextname="ohorn",
  description="LATIN SMALL LETTER O WITH HORN",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x031B },
  uccode=0x01A0,
  unicodeslot=0x01A1,
 },
 {
  adobename="Oi",
  category="lu",
  description="LATIN CAPITAL LETTER OI",
  direction="l",
  lccode=0x01A3,
  linebreak="al",
  unicodeslot=0x01A2,
 },
 {
  adobename="oi",
  category="ll",
  description="LATIN SMALL LETTER OI",
  direction="l",
  linebreak="al",
  uccode=0x01A2,
  unicodeslot=0x01A3,
 },
 {
  adobename="Phook",
  category="lu",
  contextname="Phook",
  description="LATIN CAPITAL LETTER P WITH HOOK",
  direction="l",
  lccode=0x01A5,
  linebreak="al",
  shcode=0x0050,
  unicodeslot=0x01A4,
 },
 {
  adobename="phook",
  category="ll",
  contextname="phook",
  description="LATIN SMALL LETTER P WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0070,
  uccode=0x01A4,
  unicodeslot=0x01A5,
 },
 {
  adobename="yr",
  category="lu",
  description="LATIN LETTER YR",
  direction="l",
  lccode=0x0280,
  linebreak="al",
  unicodeslot=0x01A6,
 },
 {
  adobename="Tonetwo",
  category="lu",
  description="LATIN CAPITAL LETTER TONE TWO",
  direction="l",
  lccode=0x01A8,
  linebreak="al",
  unicodeslot=0x01A7,
 },
 {
  adobename="tonetwo",
  category="ll",
  description="LATIN SMALL LETTER TONE TWO",
  direction="l",
  linebreak="al",
  uccode=0x01A7,
  unicodeslot=0x01A8,
 },
 {
  adobename="Esh",
  category="lu",
  description="LATIN CAPITAL LETTER ESH",
  direction="l",
  lccode=0x0283,
  linebreak="al",
  unicodeslot=0x01A9,
 },
 {
  adobename="eshreversedloop",
  category="ll",
  description="LATIN LETTER REVERSED ESH LOOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x01AA,
 },
 {
  adobename="tpalatalhook",
  category="ll",
  description="LATIN SMALL LETTER T WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  unicodeslot=0x01AB,
 },
 {
  adobename="Thook",
  category="lu",
  contextname="Thook",
  description="LATIN CAPITAL LETTER T WITH HOOK",
  direction="l",
  lccode=0x01AD,
  linebreak="al",
  shcode=0x0054,
  unicodeslot=0x01AC,
 },
 {
  adobename="thook",
  category="ll",
  contextname="thook",
  description="LATIN SMALL LETTER T WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  uccode=0x01AC,
  unicodeslot=0x01AD,
 },
 {
  adobename="Tretroflexhook",
  category="lu",
  description="LATIN CAPITAL LETTER T WITH RETROFLEX HOOK",
  direction="l",
  lccode=0x0288,
  linebreak="al",
  shcode=0x0054,
  unicodeslot=0x01AE,
 },
 {
  adobename="Uhorn",
  category="lu",
  contextname="Uhorn",
  description="LATIN CAPITAL LETTER U WITH HORN",
  direction="l",
  lccode=0x01B0,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x031B },
  unicodeslot=0x01AF,
 },
 {
  adobename="uhorn",
  category="ll",
  contextname="uhorn",
  description="LATIN SMALL LETTER U WITH HORN",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x031B },
  uccode=0x01AF,
  unicodeslot=0x01B0,
 },
 {
  adobename="Upsilonafrican",
  category="lu",
  description="LATIN CAPITAL LETTER UPSILON",
  direction="l",
  lccode=0x028A,
  linebreak="al",
  unicodeslot=0x01B1,
 },
 {
  adobename="Vhook",
  category="lu",
  contextname="Uhook",
  description="LATIN CAPITAL LETTER V WITH HOOK",
  direction="l",
  lccode=0x028B,
  linebreak="al",
  shcode=0x0056,
  unicodeslot=0x01B2,
 },
 {
  adobename="Yhook",
  category="lu",
  contextname="Yhook",
  description="LATIN CAPITAL LETTER Y WITH HOOK",
  direction="l",
  lccode=0x01B4,
  linebreak="al",
  shcode=0x0059,
  unicodeslot=0x01B3,
 },
 {
  adobename="yhook",
  category="ll",
  contextname="yhook",
  description="LATIN SMALL LETTER Y WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  uccode=0x01B3,
  unicodeslot=0x01B4,
 },
 {
  adobename="Zstroke",
  category="lu",
  contextname="Zstroke",
  description="LATIN CAPITAL LETTER Z WITH STROKE",
  direction="l",
  lccode=0x01B6,
  linebreak="al",
  shcode=0x005A,
  unicodeslot=0x01B5,
 },
 {
  adobename="zstroke",
  category="ll",
  contextname="zstroke",
  description="LATIN SMALL LETTER Z WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  uccode=0x01B5,
  unicodeslot=0x01B6,
 },
 {
  adobename="Ezh",
  category="lu",
  description="LATIN CAPITAL LETTER EZH",
  direction="l",
  lccode=0x0292,
  linebreak="al",
  unicodeslot=0x01B7,
 },
 {
  adobename="Ezhreversed",
  category="lu",
  description="LATIN CAPITAL LETTER EZH REVERSED",
  direction="l",
  lccode=0x01B9,
  linebreak="al",
  unicodeslot=0x01B8,
 },
 {
  adobename="ezhreversed",
  category="ll",
  description="LATIN SMALL LETTER EZH REVERSED",
  direction="l",
  linebreak="al",
  uccode=0x01B8,
  unicodeslot=0x01B9,
 },
 {
  adobename="ezhtail",
  category="ll",
  description="LATIN SMALL LETTER EZH WITH TAIL",
  direction="l",
  linebreak="al",
  shcode=0x0292,
  unicodeslot=0x01BA,
 },
 {
  adobename="twostroke",
  category="lo",
  description="LATIN LETTER TWO WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x01BB,
 },
 {
  adobename="Tonefive",
  category="lu",
  description="LATIN CAPITAL LETTER TONE FIVE",
  direction="l",
  lccode=0x01BD,
  linebreak="al",
  unicodeslot=0x01BC,
 },
 {
  adobename="tonefive",
  category="ll",
  description="LATIN SMALL LETTER TONE FIVE",
  direction="l",
  linebreak="al",
  uccode=0x01BC,
  unicodeslot=0x01BD,
 },
 {
  adobename="glottalinvertedstroke",
  category="ll",
  description="LATIN LETTER INVERTED GLOTTAL STOP WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x01BE,
 },
 {
  adobename="wynn",
  category="ll",
  description="LATIN LETTER WYNN",
  direction="l",
  linebreak="al",
  uccode=0x01F7,
  unicodeslot=0x01BF,
 },
 {
  adobename="clickdental",
  category="lo",
  description="LATIN LETTER DENTAL CLICK",
  direction="l",
  linebreak="al",
  unicodeslot=0x01C0,
 },
 {
  adobename="clicklateral",
  category="lo",
  description="LATIN LETTER LATERAL CLICK",
  direction="l",
  linebreak="al",
  unicodeslot=0x01C1,
 },
 {
  adobename="clickalveolar",
  category="lo",
  description="LATIN LETTER ALVEOLAR CLICK",
  direction="l",
  linebreak="al",
  unicodeslot=0x01C2,
 },
 {
  adobename="clickretroflex",
  category="lo",
  description="LATIN LETTER RETROFLEX CLICK",
  direction="l",
  linebreak="al",
  unicodeslot=0x01C3,
 },
 {
  adobename="DZcaron",
  category="lu",
  contextname="DZcaronligature",
  description="LATIN CAPITAL LETTER DZ WITH CARON",
  direction="l",
  lccode=0x01C6,
  linebreak="al",
  shcode=0x01F1,
  specials={ "compat", 0x0044, 0x017D },
  uccode=0x01C5,
  unicodeslot=0x01C4,
 },
 {
  adobename="Dzcaron",
  category="lt",
  contextname="Dzcaronligature",
  description="LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON",
  direction="l",
  lccode=0x01C6,
  linebreak="al",
  shcode=0x01F2,
  specials={ "compat", 0x0044, 0x017E },
  uccode=0x01C4,
  unicodeslot=0x01C5,
 },
 {
  adobename="dzcaron",
  category="ll",
  contextname="dzcaronligature",
  description="LATIN SMALL LETTER DZ WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x01F3,
  specials={ "compat", 0x0064, 0x017E },
  uccode=0x01C4,
  unicodeslot=0x01C6,
 },
 {
  adobename="LJ",
  category="lu",
  contextname="LJligature",
  description="LATIN CAPITAL LETTER LJ",
  direction="l",
  lccode=0x01C9,
  linebreak="al",
  shcode={ 0x004C, 0x004A },
  specials={ "compat", 0x004C, 0x004A },
  uccode=0x01C8,
  unicodeslot=0x01C7,
 },
 {
  adobename="Lj",
  category="lt",
  contextname="Ljligature",
  description="LATIN CAPITAL LETTER L WITH SMALL LETTER J",
  direction="l",
  lccode=0x01C9,
  linebreak="al",
  shcode={ 0x004C, 0x006A },
  specials={ "compat", 0x004C, 0x006A },
  uccode=0x01C7,
  unicodeslot=0x01C8,
 },
 {
  adobename="lj",
  category="ll",
  contextname="ljligature",
  description="LATIN SMALL LETTER LJ",
  direction="l",
  linebreak="al",
  shcode={ 0x006C, 0x006A },
  specials={ "compat", 0x006C, 0x006A },
  uccode=0x01C7,
  unicodeslot=0x01C9,
 },
 {
  adobename="NJ",
  category="lu",
  contextname="NJligature",
  description="LATIN CAPITAL LETTER NJ",
  direction="l",
  lccode=0x01CC,
  linebreak="al",
  shcode={ 0x004E, 0x004A },
  specials={ "compat", 0x004E, 0x004A },
  uccode=0x01CB,
  unicodeslot=0x01CA,
 },
 {
  adobename="Nj",
  category="lt",
  contextname="Njligature",
  description="LATIN CAPITAL LETTER N WITH SMALL LETTER J",
  direction="l",
  lccode=0x01CC,
  linebreak="al",
  shcode=0x004E,
  specials={ "compat", 0x004E, 0x006A },
  uccode=0x01CA,
  unicodeslot=0x01CB,
 },
 {
  adobename="nj",
  category="ll",
  contextname="njligature",
  description="LATIN SMALL LETTER NJ",
  direction="l",
  linebreak="al",
  shcode={ 0x006E, 0x006A },
  specials={ "compat", 0x006E, 0x006A },
  uccode=0x01CA,
  unicodeslot=0x01CC,
 },
 {
  adobename="Acaron",
  category="lu",
  contextname="Acaron",
  description="LATIN CAPITAL LETTER A WITH CARON",
  direction="l",
  lccode=0x01CE,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x030C },
  unicodeslot=0x01CD,
 },
 {
  adobename="acaron",
  category="ll",
  cjkwd="a",
  contextname="acaron",
  description="LATIN SMALL LETTER A WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x030C },
  uccode=0x01CD,
  unicodeslot=0x01CE,
 },
 {
  adobename="Icaron",
  category="lu",
  contextname="Icaron",
  description="LATIN CAPITAL LETTER I WITH CARON",
  direction="l",
  lccode=0x01D0,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x030C },
  unicodeslot=0x01CF,
 },
 {
  adobename="icaron",
  category="ll",
  cjkwd="a",
  contextname="icaron",
  description="LATIN SMALL LETTER I WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x030C },
  uccode=0x01CF,
  unicodeslot=0x01D0,
 },
 {
  adobename="Ocaron",
  category="lu",
  contextname="Ocaron",
  description="LATIN CAPITAL LETTER O WITH CARON",
  direction="l",
  lccode=0x01D2,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x030C },
  unicodeslot=0x01D1,
 },
 {
  adobename="ocaron",
  category="ll",
  cjkwd="a",
  contextname="ocaron",
  description="LATIN SMALL LETTER O WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x030C },
  uccode=0x01D1,
  unicodeslot=0x01D2,
 },
 {
  adobename="Ucaron",
  category="lu",
  contextname="Ucaron",
  description="LATIN CAPITAL LETTER U WITH CARON",
  direction="l",
  lccode=0x01D4,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x030C },
  unicodeslot=0x01D3,
 },
 {
  adobename="ucaron",
  category="ll",
  cjkwd="a",
  contextname="ucaron",
  description="LATIN SMALL LETTER U WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x030C },
  uccode=0x01D3,
  unicodeslot=0x01D4,
 },
 {
  adobename="Udieresismacron",
  category="lu",
  contextname="Udiaeresismacron",
  description="LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON",
  direction="l",
  lccode=0x01D6,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x00DC, 0x0304 },
  unicodeslot=0x01D5,
 },
 {
  adobename="udieresismacron",
  category="ll",
  cjkwd="a",
  contextname="udiaeresismacron",
  description="LATIN SMALL LETTER U WITH DIAERESIS AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x00FC, 0x0304 },
  uccode=0x01D5,
  unicodeslot=0x01D6,
 },
 {
  adobename="Udieresisacute",
  category="lu",
  contextname="Udiaeresisacute",
  description="LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE",
  direction="l",
  lccode=0x01D8,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x00DC, 0x0301 },
  unicodeslot=0x01D7,
 },
 {
  adobename="udieresisacute",
  category="ll",
  cjkwd="a",
  contextname="udiaeresisacute",
  description="LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x00FC, 0x0301 },
  uccode=0x01D7,
  unicodeslot=0x01D8,
 },
 {
  adobename="Udieresiscaron",
  category="lu",
  contextname="Udiaeresiscaron",
  description="LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON",
  direction="l",
  lccode=0x01DA,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x00DC, 0x030C },
  unicodeslot=0x01D9,
 },
 {
  adobename="udieresiscaron",
  category="ll",
  cjkwd="a",
  contextname="udiaeresiscaron",
  description="LATIN SMALL LETTER U WITH DIAERESIS AND CARON",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x00FC, 0x030C },
  uccode=0x01D9,
  unicodeslot=0x01DA,
 },
 {
  adobename="Udieresisgrave",
  category="lu",
  contextname="Udiaeresisgrave",
  description="LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE",
  direction="l",
  lccode=0x01DC,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x00DC, 0x0300 },
  unicodeslot=0x01DB,
 },
 {
  adobename="udieresisgrave",
  category="ll",
  cjkwd="a",
  contextname="udiaeresisgrave",
  description="LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x00FC, 0x0300 },
  uccode=0x01DB,
  unicodeslot=0x01DC,
 },
 {
  adobename="eturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED E",
  direction="l",
  linebreak="al",
  uccode=0x018E,
  unicodeslot=0x01DD,
 },
 {
  adobename="Adieresismacron",
  category="lu",
  contextname="Adiaeresismacron",
  description="LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON",
  direction="l",
  lccode=0x01DF,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x00C4, 0x0304 },
  unicodeslot=0x01DE,
 },
 {
  adobename="adieresismacron",
  category="ll",
  contextname="adiaeresismacron",
  description="LATIN SMALL LETTER A WITH DIAERESIS AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x00E4, 0x0304 },
  uccode=0x01DE,
  unicodeslot=0x01DF,
 },
 {
  adobename="Adotmacron",
  category="lu",
  contextname="Adotaccentmacron",
  description="LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON",
  direction="l",
  lccode=0x01E1,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0226, 0x0304 },
  unicodeslot=0x01E0,
 },
 {
  adobename="adotmacron",
  category="ll",
  contextname="adotaccentmacron",
  description="LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0227, 0x0304 },
  uccode=0x01E0,
  unicodeslot=0x01E1,
 },
 {
  adobename="AEmacron",
  category="lu",
  contextname="AEmacron",
  description="LATIN CAPITAL LETTER AE WITH MACRON",
  direction="l",
  lccode=0x01E3,
  linebreak="al",
  shcode=0x00C6,
  specials={ "char", 0x00C6, 0x0304 },
  unicodeslot=0x01E2,
 },
 {
  adobename="aemacron",
  category="ll",
  contextname="aemacron",
  description="LATIN SMALL LETTER AE WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x00E6,
  specials={ "char", 0x00E6, 0x0304 },
  uccode=0x01E2,
  unicodeslot=0x01E3,
 },
 {
  adobename="Gstroke",
  category="lu",
  contextname="Gstroke",
  description="LATIN CAPITAL LETTER G WITH STROKE",
  direction="l",
  lccode=0x01E5,
  linebreak="al",
  shcode=0x0047,
  unicodeslot=0x01E4,
 },
 {
  adobename="gstroke",
  category="ll",
  contextname="gstroke",
  description="LATIN SMALL LETTER G WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  uccode=0x01E4,
  unicodeslot=0x01E5,
 },
 {
  adobename="Gcaron",
  category="lu",
  contextname="Gcaron",
  description="LATIN CAPITAL LETTER G WITH CARON",
  direction="l",
  lccode=0x01E7,
  linebreak="al",
  shcode=0x0047,
  specials={ "char", 0x0047, 0x030C },
  unicodeslot=0x01E6,
 },
 {
  adobename="gcaron",
  category="ll",
  contextname="gcaron",
  description="LATIN SMALL LETTER G WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  specials={ "char", 0x0067, 0x030C },
  uccode=0x01E6,
  unicodeslot=0x01E7,
 },
 {
  adobename="Kcaron",
  category="lu",
  contextname="Kcaron",
  description="LATIN CAPITAL LETTER K WITH CARON",
  direction="l",
  lccode=0x01E9,
  linebreak="al",
  shcode=0x004B,
  specials={ "char", 0x004B, 0x030C },
  unicodeslot=0x01E8,
 },
 {
  adobename="kcaron",
  category="ll",
  contextname="kcaron",
  description="LATIN SMALL LETTER K WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x006B,
  specials={ "char", 0x006B, 0x030C },
  uccode=0x01E8,
  unicodeslot=0x01E9,
 },
 {
  adobename="Oogonek",
  category="lu",
  contextname="Oogonek",
  description="LATIN CAPITAL LETTER O WITH OGONEK",
  direction="l",
  lccode=0x01EB,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0328 },
  unicodeslot=0x01EA,
 },
 {
  adobename="oogonek",
  category="ll",
  contextname="oogonek",
  description="LATIN SMALL LETTER O WITH OGONEK",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0328 },
  uccode=0x01EA,
  unicodeslot=0x01EB,
 },
 {
  adobename="Oogonekmacron",
  category="lu",
  contextname="Oogonekmacron",
  description="LATIN CAPITAL LETTER O WITH OGONEK AND MACRON",
  direction="l",
  lccode=0x01ED,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x01EA, 0x0304 },
  unicodeslot=0x01EC,
 },
 {
  adobename="oogonekmacron",
  category="ll",
  contextname="oogonekmacron",
  description="LATIN SMALL LETTER O WITH OGONEK AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x01EB, 0x0304 },
  uccode=0x01EC,
  unicodeslot=0x01ED,
 },
 {
  adobename="Ezhcaron",
  category="lu",
  description="LATIN CAPITAL LETTER EZH WITH CARON",
  direction="l",
  lccode=0x01EF,
  linebreak="al",
  shcode=0x01B7,
  specials={ "char", 0x01B7, 0x030C },
  unicodeslot=0x01EE,
 },
 {
  adobename="ezhcaron",
  category="ll",
  description="LATIN SMALL LETTER EZH WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0292,
  specials={ "char", 0x0292, 0x030C },
  uccode=0x01EE,
  unicodeslot=0x01EF,
 },
 {
  adobename="jcaron",
  category="ll",
  contextname="jcaron",
  description="LATIN SMALL LETTER J WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x006A,
  specials={ "char", 0x006A, 0x030C },
  unicodeslot=0x01F0,
 },
 {
  adobename="DZ",
  category="lu",
  contextname="DZligature",
  description="LATIN CAPITAL LETTER DZ",
  direction="l",
  lccode=0x01F3,
  linebreak="al",
  specials={ "compat", 0x0044, 0x005A },
  uccode=0x01F2,
  unicodeslot=0x01F1,
 },
 {
  adobename="Dz",
  category="lt",
  contextname="Dzligature",
  description="LATIN CAPITAL LETTER D WITH SMALL LETTER Z",
  direction="l",
  lccode=0x01F3,
  linebreak="al",
  shcode=0x0044,
  specials={ "compat", 0x0044, 0x007A },
  uccode=0x01F1,
  unicodeslot=0x01F2,
 },
 {
  adobename="dz",
  category="ll",
  contextname="dzligature",
  description="LATIN SMALL LETTER DZ",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0064, 0x007A },
  uccode=0x01F1,
  unicodeslot=0x01F3,
 },
 {
  adobename="Gacute",
  category="lu",
  contextname="Gacute",
  description="LATIN CAPITAL LETTER G WITH ACUTE",
  direction="l",
  lccode=0x01F5,
  linebreak="al",
  shcode=0x0047,
  specials={ "char", 0x0047, 0x0301 },
  unicodeslot=0x01F4,
 },
 {
  adobename="gacute",
  category="ll",
  contextname="gacute",
  description="LATIN SMALL LETTER G WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  specials={ "char", 0x0067, 0x0301 },
  uccode=0x01F4,
  unicodeslot=0x01F5,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER HWAIR",
  direction="l",
  lccode=0x0195,
  linebreak="al",
  unicodeslot=0x01F6,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER WYNN",
  direction="l",
  lccode=0x01BF,
  linebreak="al",
  unicodeslot=0x01F7,
 },
 {
  category="lu",
  contextname="Ngrave",
  description="LATIN CAPITAL LETTER N WITH GRAVE",
  direction="l",
  lccode=0x01F9,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x0300 },
  unicodeslot=0x01F8,
 },
 {
  category="ll",
  contextname="ngrave",
  description="LATIN SMALL LETTER N WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x0300 },
  uccode=0x01F8,
  unicodeslot=0x01F9,
 },
 {
  adobename="Aringacute",
  category="lu",
  contextname="Aringacute",
  description="LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE",
  direction="l",
  lccode=0x01FB,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x00C5, 0x0301 },
  unicodeslot=0x01FA,
 },
 {
  adobename="aringacute",
  category="ll",
  contextname="aringacute",
  description="LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x00E5, 0x0301 },
  uccode=0x01FA,
  unicodeslot=0x01FB,
 },
 {
  adobename="AEacute",
  category="lu",
  contextname="AEacute",
  description="LATIN CAPITAL LETTER AE WITH ACUTE",
  direction="l",
  lccode=0x01FD,
  linebreak="al",
  shcode=0x00C6,
  specials={ "char", 0x00C6, 0x0301 },
  unicodeslot=0x01FC,
 },
 {
  adobename="aeacute",
  category="ll",
  contextname="aeacute",
  description="LATIN SMALL LETTER AE WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x00E6,
  specials={ "char", 0x00E6, 0x0301 },
  uccode=0x01FC,
  unicodeslot=0x01FD,
 },
 {
  adobename="Ostrokeacute",
  category="lu",
  contextname="Ostrokeacute",
  description="LATIN CAPITAL LETTER O WITH STROKE AND ACUTE",
  direction="l",
  lccode=0x01FF,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D8, 0x0301 },
  unicodeslot=0x01FE,
 },
 {
  adobename="ostrokeacute",
  category="ll",
  contextname="ostrokeacute",
  description="LATIN SMALL LETTER O WITH STROKE AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F8, 0x0301 },
  uccode=0x01FE,
  unicodeslot=0x01FF,
 },
 {
  adobename="Adblgrave",
  category="lu",
  contextname="Adoublegrave",
  description="LATIN CAPITAL LETTER A WITH DOUBLE GRAVE",
  direction="l",
  lccode=0x0201,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x030F },
  unicodeslot=0x0200,
 },
 {
  adobename="adblgrave",
  category="ll",
  contextname="adoublegrave",
  description="LATIN SMALL LETTER A WITH DOUBLE GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x030F },
  uccode=0x0200,
  unicodeslot=0x0201,
 },
 {
  adobename="Ainvertedbreve",
  category="lu",
  contextname="Ainvertedbreve",
  description="LATIN CAPITAL LETTER A WITH INVERTED BREVE",
  direction="l",
  lccode=0x0203,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0311 },
  unicodeslot=0x0202,
 },
 {
  adobename="ainvertedbreve",
  category="ll",
  contextname="ainvertedbreve",
  description="LATIN SMALL LETTER A WITH INVERTED BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0311 },
  uccode=0x0202,
  unicodeslot=0x0203,
 },
 {
  adobename="Edblgrave",
  category="lu",
  contextname="Edoublegrave",
  description="LATIN CAPITAL LETTER E WITH DOUBLE GRAVE",
  direction="l",
  lccode=0x0205,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x030F },
  unicodeslot=0x0204,
 },
 {
  adobename="edblgrave",
  category="ll",
  contextname="edoublegrave",
  description="LATIN SMALL LETTER E WITH DOUBLE GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x030F },
  uccode=0x0204,
  unicodeslot=0x0205,
 },
 {
  adobename="Einvertedbreve",
  category="lu",
  contextname="Einvertedbreve",
  description="LATIN CAPITAL LETTER E WITH INVERTED BREVE",
  direction="l",
  lccode=0x0207,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0311 },
  unicodeslot=0x0206,
 },
 {
  adobename="einvertedbreve",
  category="ll",
  contextname="einvertedbreve",
  description="LATIN SMALL LETTER E WITH INVERTED BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0311 },
  uccode=0x0206,
  unicodeslot=0x0207,
 },
 {
  adobename="Idblgrave",
  category="lu",
  contextname="Idoublegrave",
  description="LATIN CAPITAL LETTER I WITH DOUBLE GRAVE",
  direction="l",
  lccode=0x0209,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x030F },
  unicodeslot=0x0208,
 },
 {
  adobename="idblgrave",
  category="ll",
  contextname="idoublegrave",
  description="LATIN SMALL LETTER I WITH DOUBLE GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x030F },
  uccode=0x0208,
  unicodeslot=0x0209,
 },
 {
  adobename="Iinvertedbreve",
  category="lu",
  contextname="Iinvertedbreve",
  description="LATIN CAPITAL LETTER I WITH INVERTED BREVE",
  direction="l",
  lccode=0x020B,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0311 },
  unicodeslot=0x020A,
 },
 {
  adobename="iinvertedbreve",
  category="ll",
  contextname="iinvertedbreve",
  description="LATIN SMALL LETTER I WITH INVERTED BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0311 },
  uccode=0x020A,
  unicodeslot=0x020B,
 },
 {
  adobename="Odblgrave",
  category="lu",
  contextname="Odoublegrave",
  description="LATIN CAPITAL LETTER O WITH DOUBLE GRAVE",
  direction="l",
  lccode=0x020D,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x030F },
  unicodeslot=0x020C,
 },
 {
  adobename="odblgrave",
  category="ll",
  contextname="odoublegrave",
  description="LATIN SMALL LETTER O WITH DOUBLE GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x030F },
  uccode=0x020C,
  unicodeslot=0x020D,
 },
 {
  adobename="Oinvertedbreve",
  category="lu",
  contextname="Oinvertedbreve",
  description="LATIN CAPITAL LETTER O WITH INVERTED BREVE",
  direction="l",
  lccode=0x020F,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0311 },
  unicodeslot=0x020E,
 },
 {
  adobename="oinvertedbreve",
  category="ll",
  contextname="oinvertedbreve",
  description="LATIN SMALL LETTER O WITH INVERTED BREVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0311 },
  uccode=0x020E,
  unicodeslot=0x020F,
 },
 {
  adobename="Rdblgrave",
  category="lu",
  contextname="Rdoublegrave",
  description="LATIN CAPITAL LETTER R WITH DOUBLE GRAVE",
  direction="l",
  lccode=0x0211,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x0052, 0x030F },
  unicodeslot=0x0210,
 },
 {
  adobename="rdblgrave",
  category="ll",
  contextname="rdoublegrave",
  description="LATIN SMALL LETTER R WITH DOUBLE GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x0072, 0x030F },
  uccode=0x0210,
  unicodeslot=0x0211,
 },
 {
  adobename="Rinvertedbreve",
  category="lu",
  contextname="Rinvertedbreve",
  description="LATIN CAPITAL LETTER R WITH INVERTED BREVE",
  direction="l",
  lccode=0x0213,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x0052, 0x0311 },
  unicodeslot=0x0212,
 },
 {
  adobename="rinvertedbreve",
  category="ll",
  contextname="rinvertedbreve",
  description="LATIN SMALL LETTER R WITH INVERTED BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x0072, 0x0311 },
  uccode=0x0212,
  unicodeslot=0x0213,
 },
 {
  adobename="Udblgrave",
  category="lu",
  contextname="Udoublegrave",
  description="LATIN CAPITAL LETTER U WITH DOUBLE GRAVE",
  direction="l",
  lccode=0x0215,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x030F },
  unicodeslot=0x0214,
 },
 {
  adobename="udblgrave",
  category="ll",
  contextname="udoublegrave",
  description="LATIN SMALL LETTER U WITH DOUBLE GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x030F },
  uccode=0x0214,
  unicodeslot=0x0215,
 },
 {
  adobename="Uinvertedbreve",
  category="lu",
  contextname="Uinvertedbreve",
  description="LATIN CAPITAL LETTER U WITH INVERTED BREVE",
  direction="l",
  lccode=0x0217,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0311 },
  unicodeslot=0x0216,
 },
 {
  adobename="uinvertedbreve",
  category="ll",
  contextname="uinvertedbreve",
  description="LATIN SMALL LETTER U WITH INVERTED BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0311 },
  uccode=0x0216,
  unicodeslot=0x0217,
 },
 {
  adobename="Scommaaccent",
  category="lu",
  contextname="Scommaaccent",
  description="LATIN CAPITAL LETTER S WITH COMMA BELOW",
  direction="l",
  lccode=0x0219,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x0053, 0x0326 },
  unicodeslot=0x0218,
 },
 {
  adobename="scommaaccent",
  category="ll",
  contextname="scommaaccent",
  description="LATIN SMALL LETTER S WITH COMMA BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x0073, 0x0326 },
  uccode=0x0218,
  unicodeslot=0x0219,
 },
 {
  category="lu",
  contextname="Tcommaaccent",
  description="LATIN CAPITAL LETTER T WITH COMMA BELOW",
  direction="l",
  lccode=0x021B,
  linebreak="al",
  shcode=0x0054,
  specials={ "char", 0x0054, 0x0326 },
  unicodeslot=0x021A,
 },
 {
  category="ll",
  contextname="tcommaaccent",
  description="LATIN SMALL LETTER T WITH COMMA BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  specials={ "char", 0x0074, 0x0326 },
  uccode=0x021A,
  unicodeslot=0x021B,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER YOGH",
  direction="l",
  lccode=0x021D,
  linebreak="al",
  unicodeslot=0x021C,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER YOGH",
  direction="l",
  linebreak="al",
  uccode=0x021C,
  unicodeslot=0x021D,
 },
 {
  category="lu",
  contextname="Hcaron",
  description="LATIN CAPITAL LETTER H WITH CARON",
  direction="l",
  lccode=0x021F,
  linebreak="al",
  shcode=0x0048,
  specials={ "char", 0x0048, 0x030C },
  unicodeslot=0x021E,
 },
 {
  category="ll",
  contextname="hcaron",
  description="LATIN SMALL LETTER H WITH CARON",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  specials={ "char", 0x0068, 0x030C },
  uccode=0x021E,
  unicodeslot=0x021F,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER N WITH LONG RIGHT LEG",
  direction="l",
  lccode=0x019E,
  linebreak="al",
  shcode=0x004E,
  unicodeslot=0x0220,
 },
 {
  category="ll",
  contextname="dcurl",
  description="LATIN SMALL LETTER D WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  unicodeslot=0x0221,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER OU",
  direction="l",
  lccode=0x0223,
  linebreak="al",
  unicodeslot=0x0222,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER OU",
  direction="l",
  linebreak="al",
  uccode=0x0222,
  unicodeslot=0x0223,
 },
 {
  category="lu",
  contextname="Zhook",
  description="LATIN CAPITAL LETTER Z WITH HOOK",
  direction="l",
  lccode=0x0225,
  linebreak="al",
  shcode=0x005A,
  unicodeslot=0x0224,
 },
 {
  category="ll",
  contextname="zhook",
  description="LATIN SMALL LETTER Z WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  uccode=0x0224,
  unicodeslot=0x0225,
 },
 {
  category="lu",
  contextname="Adotaccent",
  description="LATIN CAPITAL LETTER A WITH DOT ABOVE",
  direction="l",
  lccode=0x0227,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0307 },
  unicodeslot=0x0226,
 },
 {
  category="ll",
  contextname="adotaccent",
  description="LATIN SMALL LETTER A WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0307 },
  uccode=0x0226,
  unicodeslot=0x0227,
 },
 {
  category="lu",
  contextname="Ecedilla",
  description="LATIN CAPITAL LETTER E WITH CEDILLA",
  direction="l",
  lccode=0x0229,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0327 },
  unicodeslot=0x0228,
 },
 {
  category="ll",
  contextname="ecedilla",
  description="LATIN SMALL LETTER E WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0327 },
  uccode=0x0228,
  unicodeslot=0x0229,
 },
 {
  category="lu",
  contextname="Odiaeresismacron",
  description="LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON",
  direction="l",
  lccode=0x022B,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D6, 0x0304 },
  unicodeslot=0x022A,
 },
 {
  category="ll",
  contextname="odiaeresismacron",
  description="LATIN SMALL LETTER O WITH DIAERESIS AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F6, 0x0304 },
  uccode=0x022A,
  unicodeslot=0x022B,
 },
 {
  category="lu",
  contextname="Otildemacron",
  description="LATIN CAPITAL LETTER O WITH TILDE AND MACRON",
  direction="l",
  lccode=0x022D,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D5, 0x0304 },
  unicodeslot=0x022C,
 },
 {
  category="ll",
  contextname="otildemacron",
  description="LATIN SMALL LETTER O WITH TILDE AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F5, 0x0304 },
  uccode=0x022C,
  unicodeslot=0x022D,
 },
 {
  category="lu",
  contextname="Odotaccent",
  description="LATIN CAPITAL LETTER O WITH DOT ABOVE",
  direction="l",
  lccode=0x022F,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0307 },
  unicodeslot=0x022E,
 },
 {
  category="ll",
  contextname="odotaccent",
  description="LATIN SMALL LETTER O WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0307 },
  uccode=0x022E,
  unicodeslot=0x022F,
 },
 {
  category="lu",
  contextname="Odotaccentmacron",
  description="LATIN CAPITAL LETTER O WITH DOT ABOVE AND MACRON",
  direction="l",
  lccode=0x0231,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x022E, 0x0304 },
  unicodeslot=0x0230,
 },
 {
  category="ll",
  contextname="odotaccentmacron",
  description="LATIN SMALL LETTER O WITH DOT ABOVE AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x022F, 0x0304 },
  uccode=0x0230,
  unicodeslot=0x0231,
 },
 {
  category="lu",
  contextname="Ymacron",
  description="LATIN CAPITAL LETTER Y WITH MACRON",
  direction="l",
  lccode=0x0233,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0304 },
  unicodeslot=0x0232,
 },
 {
  category="ll",
  contextname="ymacron",
  description="LATIN SMALL LETTER Y WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0304 },
  uccode=0x0232,
  unicodeslot=0x0233,
 },
 {
  category="ll",
  contextname="lcurl",
  description="LATIN SMALL LETTER L WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  unicodeslot=0x0234,
 },
 {
  category="ll",
  contextname="ncurl",
  description="LATIN SMALL LETTER N WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  unicodeslot=0x0235,
 },
 {
  category="ll",
  contextname="tcurl",
  description="LATIN SMALL LETTER T WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  unicodeslot=0x0236,
 },
 {
  category="ll",
  contextname="dotlessj",
  description="LATIN SMALL LETTER DOTLESS J",
  direction="l",
  linebreak="al",
  unicodeslot=0x0237,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER DB DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x0238,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER QP DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x0239,
 },
 {
  category="lu",
  contextname="Astroke",
  description="LATIN CAPITAL LETTER A WITH STROKE",
  direction="l",
  lccode=0x2C65,
  linebreak="al",
  shcode=0x0041,
  unicodeslot=0x023A,
 },
 {
  category="lu",
  contextname="Cstroke",
  description="LATIN CAPITAL LETTER C WITH STROKE",
  direction="l",
  lccode=0x023C,
  linebreak="al",
  shcode=0x0043,
  unicodeslot=0x023B,
 },
 {
  category="ll",
  contextname="cstroke",
  description="LATIN SMALL LETTER C WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  uccode=0x023B,
  unicodeslot=0x023C,
 },
 {
  category="lu",
  contextname="Lbar",
  description="LATIN CAPITAL LETTER L WITH BAR",
  direction="l",
  lccode=0x019A,
  linebreak="al",
  shcode=0x004C,
  unicodeslot=0x023D,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER T WITH DIAGONAL STROKE",
  direction="l",
  lccode=0x2C66,
  linebreak="al",
  shcode=0x0054,
  unicodeslot=0x023E,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER S WITH SWASH TAIL",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  unicodeslot=0x023F,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER Z WITH SWASH TAIL",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  unicodeslot=0x0240,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER GLOTTAL STOP",
  direction="l",
  lccode=0x0242,
  linebreak="al",
  unicodeslot=0x0241,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER GLOTTAL STOP",
  direction="l",
  linebreak="al",
  uccode=0x0241,
  unicodeslot=0x0242,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER B WITH STROKE",
  direction="l",
  lccode=0x0180,
  linebreak="al",
  shcode=0x0042,
  unicodeslot=0x0243,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER U BAR",
  direction="l",
  lccode=0x0289,
  linebreak="al",
  unicodeslot=0x0244,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER TURNED V",
  direction="l",
  lccode=0x028C,
  linebreak="al",
  unicodeslot=0x0245,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER E WITH STROKE",
  direction="l",
  lccode=0x0247,
  linebreak="al",
  shcode=0x0045,
  unicodeslot=0x0246,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER E WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  uccode=0x0246,
  unicodeslot=0x0247,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER J WITH STROKE",
  direction="l",
  lccode=0x0249,
  linebreak="al",
  shcode=0x004A,
  unicodeslot=0x0248,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER J WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x006A,
  uccode=0x0248,
  unicodeslot=0x0249,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER SMALL Q WITH HOOK TAIL",
  direction="l",
  lccode=0x024B,
  linebreak="al",
  unicodeslot=0x024A,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER Q WITH HOOK TAIL",
  direction="l",
  linebreak="al",
  shcode=0x0071,
  uccode=0x024A,
  unicodeslot=0x024B,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER R WITH STROKE",
  direction="l",
  lccode=0x024D,
  linebreak="al",
  shcode=0x0052,
  unicodeslot=0x024C,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER R WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  uccode=0x024C,
  unicodeslot=0x024D,
 },
 {
  category="lu",
  description="LATIN CAPITAL LETTER Y WITH STROKE",
  direction="l",
  lccode=0x024F,
  linebreak="al",
  shcode=0x0059,
  unicodeslot=0x024E,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER Y WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  uccode=0x024E,
  unicodeslot=0x024F,
 },
 {
  adobename="aturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0250,
 },
 {
  adobename="ascript",
  category="ll",
  cjkwd="a",
  description="LATIN SMALL LETTER ALPHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0251,
 },
 {
  adobename="ascriptturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED ALPHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0252,
 },
 {
  adobename="bhook",
  category="ll",
  contextname="bhook",
  description="LATIN SMALL LETTER B WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0062,
  uccode=0x0181,
  unicodeslot=0x0253,
 },
 {
  adobename="oopen",
  category="ll",
  description="LATIN SMALL LETTER OPEN O",
  direction="l",
  linebreak="al",
  uccode=0x0186,
  unicodeslot=0x0254,
 },
 {
  adobename="ccurl",
  category="ll",
  contextname="ccurl",
  description="LATIN SMALL LETTER C WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  unicodeslot=0x0255,
 },
 {
  adobename="dtail",
  category="ll",
  contextname="dtail",
  description="LATIN SMALL LETTER D WITH TAIL",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  uccode=0x0189,
  unicodeslot=0x0256,
 },
 {
  adobename="dhook",
  category="ll",
  contextname="dhook",
  description="LATIN SMALL LETTER D WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  uccode=0x018A,
  unicodeslot=0x0257,
 },
 {
  adobename="ereversed",
  category="ll",
  description="LATIN SMALL LETTER REVERSED E",
  direction="l",
  linebreak="al",
  unicodeslot=0x0258,
 },
 {
  adobename="schwa",
  category="ll",
  contextname="schwa",
  description="LATIN SMALL LETTER SCHWA",
  direction="l",
  linebreak="al",
  uccode=0x018F,
  unicodeslot=0x0259,
 },
 {
  adobename="schwahook",
  category="ll",
  contextname="schwahook",
  description="LATIN SMALL LETTER SCHWA WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0259,
  unicodeslot=0x025A,
 },
 {
  adobename="eopen",
  category="ll",
  description="LATIN SMALL LETTER OPEN E",
  direction="l",
  linebreak="al",
  uccode=0x0190,
  unicodeslot=0x025B,
 },
 {
  adobename="eopenreversed",
  category="ll",
  description="LATIN SMALL LETTER REVERSED OPEN E",
  direction="l",
  linebreak="al",
  unicodeslot=0x025C,
 },
 {
  adobename="eopenreversedhook",
  category="ll",
  description="LATIN SMALL LETTER REVERSED OPEN E WITH HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x025D,
 },
 {
  adobename="eopenreversedclosed",
  category="ll",
  description="LATIN SMALL LETTER CLOSED REVERSED OPEN E",
  direction="l",
  linebreak="al",
  unicodeslot=0x025E,
 },
 {
  adobename="jdotlessstroke",
  category="ll",
  contextname="dotlessjstroke",
  description="LATIN SMALL LETTER DOTLESS J WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x025F,
 },
 {
  adobename="ghook",
  category="ll",
  description="LATIN SMALL LETTER G WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  uccode=0x0193,
  unicodeslot=0x0260,
 },
 {
  adobename="gscript",
  category="ll",
  cjkwd="a",
  description="LATIN SMALL LETTER SCRIPT G",
  direction="l",
  linebreak="al",
  unicodeslot=0x0261,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL G",
  direction="l",
  linebreak="al",
  unicodeslot=0x0262,
 },
 {
  adobename="gammalatinsmall",
  category="ll",
  description="LATIN SMALL LETTER GAMMA",
  direction="l",
  linebreak="al",
  uccode=0x0194,
  unicodeslot=0x0263,
 },
 {
  adobename="ramshorn",
  category="ll",
  description="LATIN SMALL LETTER RAMS HORN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0264,
 },
 {
  adobename="hturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED H",
  direction="l",
  linebreak="al",
  unicodeslot=0x0265,
 },
 {
  adobename="hhook",
  category="ll",
  description="LATIN SMALL LETTER H WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  unicodeslot=0x0266,
 },
 {
  adobename="henghook",
  category="ll",
  description="LATIN SMALL LETTER HENG WITH HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x0267,
 },
 {
  adobename="istroke",
  category="ll",
  description="LATIN SMALL LETTER I WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  uccode=0x0197,
  unicodeslot=0x0268,
 },
 {
  adobename="iotalatin",
  category="ll",
  description="LATIN SMALL LETTER IOTA",
  direction="l",
  linebreak="al",
  uccode=0x0196,
  unicodeslot=0x0269,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL I",
  direction="l",
  linebreak="al",
  unicodeslot=0x026A,
 },
 {
  adobename="lmiddletilde",
  category="ll",
  description="LATIN SMALL LETTER L WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  uccode=0x2C62,
  unicodeslot=0x026B,
 },
 {
  adobename="lbelt",
  category="ll",
  description="LATIN SMALL LETTER L WITH BELT",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  unicodeslot=0x026C,
 },
 {
  adobename="lhookretroflex",
  category="ll",
  description="LATIN SMALL LETTER L WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  unicodeslot=0x026D,
 },
 {
  adobename="lezh",
  category="ll",
  description="LATIN SMALL LETTER LEZH",
  direction="l",
  linebreak="al",
  unicodeslot=0x026E,
 },
 {
  adobename="mturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED M",
  direction="l",
  linebreak="al",
  uccode=0x019C,
  unicodeslot=0x026F,
 },
 {
  adobename="mlonglegturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED M WITH LONG LEG",
  direction="l",
  linebreak="al",
  unicodeslot=0x0270,
 },
 {
  adobename="mhook",
  category="ll",
  description="LATIN SMALL LETTER M WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006D,
  unicodeslot=0x0271,
 },
 {
  adobename="nhookleft",
  category="ll",
  description="LATIN SMALL LETTER N WITH LEFT HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  uccode=0x019D,
  unicodeslot=0x0272,
 },
 {
  adobename="nhookretroflex",
  category="ll",
  description="LATIN SMALL LETTER N WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  unicodeslot=0x0273,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL N",
  direction="l",
  linebreak="al",
  unicodeslot=0x0274,
 },
 {
  adobename="obarred",
  category="ll",
  description="LATIN SMALL LETTER BARRED O",
  direction="l",
  linebreak="al",
  uccode=0x019F,
  unicodeslot=0x0275,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL OE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0276,
 },
 {
  adobename="omegalatinclosed",
  category="ll",
  description="LATIN SMALL LETTER CLOSED OMEGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0277,
 },
 {
  adobename="philatin",
  category="ll",
  description="LATIN SMALL LETTER PHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0278,
 },
 {
  adobename="rturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED R",
  direction="l",
  linebreak="al",
  unicodeslot=0x0279,
 },
 {
  adobename="rlonglegturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED R WITH LONG LEG",
  direction="l",
  linebreak="al",
  unicodeslot=0x027A,
 },
 {
  adobename="rhookturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED R WITH HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x027B,
 },
 {
  adobename="rlongleg",
  category="ll",
  description="LATIN SMALL LETTER R WITH LONG LEG",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  unicodeslot=0x027C,
 },
 {
  adobename="rhook",
  category="ll",
  description="LATIN SMALL LETTER R WITH TAIL",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  uccode=0x2C64,
  unicodeslot=0x027D,
 },
 {
  adobename="rfishhook",
  category="ll",
  description="LATIN SMALL LETTER R WITH FISHHOOK",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  unicodeslot=0x027E,
 },
 {
  adobename="rfishhookreversed",
  category="ll",
  description="LATIN SMALL LETTER REVERSED R WITH FISHHOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x027F,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL R",
  direction="l",
  linebreak="al",
  uccode=0x01A6,
  unicodeslot=0x0280,
 },
 {
  adobename="Rsmallinverted",
  category="ll",
  description="LATIN LETTER SMALL CAPITAL INVERTED R",
  direction="l",
  linebreak="al",
  unicodeslot=0x0281,
 },
 {
  adobename="shook",
  category="ll",
  description="LATIN SMALL LETTER S WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  unicodeslot=0x0282,
 },
 {
  adobename="esh",
  category="ll",
  description="LATIN SMALL LETTER ESH",
  direction="l",
  linebreak="al",
  uccode=0x01A9,
  unicodeslot=0x0283,
 },
 {
  adobename="dotlessjstrokehook",
  category="ll",
  description="LATIN SMALL LETTER DOTLESS J WITH STROKE AND HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x0284,
 },
 {
  adobename="eshsquatreversed",
  category="ll",
  description="LATIN SMALL LETTER SQUAT REVERSED ESH",
  direction="l",
  linebreak="al",
  unicodeslot=0x0285,
 },
 {
  adobename="eshcurl",
  category="ll",
  description="LATIN SMALL LETTER ESH WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x0283,
  unicodeslot=0x0286,
 },
 {
  adobename="tturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED T",
  direction="l",
  linebreak="al",
  unicodeslot=0x0287,
 },
 {
  adobename="tretroflexhook",
  category="ll",
  description="LATIN SMALL LETTER T WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  uccode=0x01AE,
  unicodeslot=0x0288,
 },
 {
  adobename="ubar",
  category="ll",
  description="LATIN SMALL LETTER U BAR",
  direction="l",
  linebreak="al",
  uccode=0x0244,
  unicodeslot=0x0289,
 },
 {
  adobename="upsilonlatin",
  category="ll",
  description="LATIN SMALL LETTER UPSILON",
  direction="l",
  linebreak="al",
  uccode=0x01B1,
  unicodeslot=0x028A,
 },
 {
  adobename="vhook",
  category="ll",
  description="LATIN SMALL LETTER V WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0076,
  uccode=0x01B2,
  unicodeslot=0x028B,
 },
 {
  adobename="vturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED V",
  direction="l",
  linebreak="al",
  uccode=0x0245,
  unicodeslot=0x028C,
 },
 {
  adobename="wturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED W",
  direction="l",
  linebreak="al",
  unicodeslot=0x028D,
 },
 {
  adobename="yturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED Y",
  direction="l",
  linebreak="al",
  unicodeslot=0x028E,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL Y",
  direction="l",
  linebreak="al",
  unicodeslot=0x028F,
 },
 {
  adobename="zretroflexhook",
  category="ll",
  description="LATIN SMALL LETTER Z WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  unicodeslot=0x0290,
 },
 {
  adobename="zcurl",
  category="ll",
  description="LATIN SMALL LETTER Z WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  unicodeslot=0x0291,
 },
 {
  adobename="ezh",
  category="ll",
  description="LATIN SMALL LETTER EZH",
  direction="l",
  linebreak="al",
  uccode=0x01B7,
  unicodeslot=0x0292,
 },
 {
  adobename="ezhcurl",
  category="ll",
  description="LATIN SMALL LETTER EZH WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x0292,
  unicodeslot=0x0293,
 },
 {
  adobename="glottalstop",
  category="lo",
  description="LATIN LETTER GLOTTAL STOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x0294,
 },
 {
  adobename="glottalstopreversed",
  category="ll",
  description="LATIN LETTER PHARYNGEAL VOICED FRICATIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0295,
 },
 {
  adobename="glottalstopinverted",
  category="ll",
  description="LATIN LETTER INVERTED GLOTTAL STOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x0296,
 },
 {
  adobename="cstretched",
  category="ll",
  description="LATIN LETTER STRETCHED C",
  direction="l",
  linebreak="al",
  unicodeslot=0x0297,
 },
 {
  adobename="bilabialclick",
  category="ll",
  description="LATIN LETTER BILABIAL CLICK",
  direction="l",
  linebreak="al",
  unicodeslot=0x0298,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL B",
  direction="l",
  linebreak="al",
  unicodeslot=0x0299,
 },
 {
  adobename="eopenclosed",
  category="ll",
  description="LATIN SMALL LETTER CLOSED OPEN E",
  direction="l",
  linebreak="al",
  unicodeslot=0x029A,
 },
 {
  adobename="Gsmallhook",
  category="ll",
  description="LATIN LETTER SMALL CAPITAL G WITH HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x029B,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL H",
  direction="l",
  linebreak="al",
  unicodeslot=0x029C,
 },
 {
  adobename="jcrossedtail",
  category="ll",
  description="LATIN SMALL LETTER J WITH CROSSED-TAIL",
  direction="l",
  linebreak="al",
  shcode=0x006A,
  unicodeslot=0x029D,
 },
 {
  adobename="kturned",
  category="ll",
  description="LATIN SMALL LETTER TURNED K",
  direction="l",
  linebreak="al",
  unicodeslot=0x029E,
 },
 {
  category="ll",
  description="LATIN LETTER SMALL CAPITAL L",
  direction="l",
  linebreak="al",
  unicodeslot=0x029F,
 },
 {
  adobename="qhook",
  category="ll",
  description="LATIN SMALL LETTER Q WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0071,
  unicodeslot=0x02A0,
 },
 {
  adobename="glottalstopstroke",
  category="ll",
  description="LATIN LETTER GLOTTAL STOP WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A1,
 },
 {
  adobename="glottalstopstrokereversed",
  category="ll",
  description="LATIN LETTER REVERSED GLOTTAL STOP WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A2,
 },
 {
  adobename="dzaltone",
  category="ll",
  description="LATIN SMALL LETTER DZ DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A3,
 },
 {
  adobename="dezh",
  category="ll",
  description="LATIN SMALL LETTER DEZH DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A4,
 },
 {
  adobename="dzcurl",
  category="ll",
  description="LATIN SMALL LETTER DZ DIGRAPH WITH CURL",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A5,
 },
 {
  adobename="ts",
  category="ll",
  description="LATIN SMALL LETTER TS DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A6,
 },
 {
  adobename="tesh",
  category="ll",
  description="LATIN SMALL LETTER TESH DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A7,
 },
 {
  adobename="tccurl",
  category="ll",
  description="LATIN SMALL LETTER TC DIGRAPH WITH CURL",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A8,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER FENG DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x02A9,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER LS DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x02AA,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER LZ DIGRAPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x02AB,
 },
 {
  category="ll",
  description="LATIN LETTER BILABIAL PERCUSSIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x02AC,
 },
 {
  category="ll",
  description="LATIN LETTER BIDENTAL PERCUSSIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x02AD,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER TURNED H WITH FISHHOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x02AE,
 },
 {
  category="ll",
  description="LATIN SMALL LETTER TURNED H WITH FISHHOOK AND TAIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x02AF,
 },
 {
  adobename="hsuperior",
  category="lm",
  description="MODIFIER LETTER SMALL H",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0068 },
  unicodeslot=0x02B0,
 },
 {
  adobename="hhooksuperior",
  category="lm",
  description="MODIFIER LETTER SMALL H WITH HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0266 },
  unicodeslot=0x02B1,
 },
 {
  adobename="jsuperior",
  category="lm",
  description="MODIFIER LETTER SMALL J",
  direction="l",
  linebreak="al",
  specials={ "super", 0x006A },
  unicodeslot=0x02B2,
 },
 {
  category="lm",
  description="MODIFIER LETTER SMALL R",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0072 },
  unicodeslot=0x02B3,
 },
 {
  adobename="rturnedsuperior",
  category="lm",
  description="MODIFIER LETTER SMALL TURNED R",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0279 },
  unicodeslot=0x02B4,
 },
 {
  adobename="rhookturnedsuperior",
  category="lm",
  description="MODIFIER LETTER SMALL TURNED R WITH HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x027B },
  unicodeslot=0x02B5,
 },
 {
  adobename="Rsmallinvertedsuperior",
  category="lm",
  description="MODIFIER LETTER SMALL CAPITAL INVERTED R",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0281 },
  unicodeslot=0x02B6,
 },
 {
  adobename="wsuperior",
  category="lm",
  description="MODIFIER LETTER SMALL W",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0077 },
  unicodeslot=0x02B7,
 },
 {
  adobename="ysuperior",
  category="lm",
  description="MODIFIER LETTER SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0079 },
  unicodeslot=0x02B8,
 },
 {
  adobename="primemod",
  category="lm",
  description="MODIFIER LETTER PRIME",
  direction="on",
  linebreak="al",
  unicodeslot=0x02B9,
 },
 {
  adobename="dblprimemod",
  category="lm",
  description="MODIFIER LETTER DOUBLE PRIME",
  direction="on",
  linebreak="al",
  unicodeslot=0x02BA,
 },
 {
  adobename="commaturnedmod",
  category="lm",
  description="MODIFIER LETTER TURNED COMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x02BB,
 },
 {
  adobename="apostrophemod",
  category="lm",
  description="MODIFIER LETTER APOSTROPHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x02BC,
 },
 {
  adobename="commareversedmod",
  category="lm",
  description="MODIFIER LETTER REVERSED COMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x02BD,
 },
 {
  adobename="ringhalfright",
  category="lm",
  description="MODIFIER LETTER RIGHT HALF RING",
  direction="l",
  linebreak="al",
  unicodeslot=0x02BE,
 },
 {
  adobename="ringhalfleft",
  category="lm",
  description="MODIFIER LETTER LEFT HALF RING",
  direction="l",
  linebreak="al",
  unicodeslot=0x02BF,
 },
 {
  adobename="glottalstopmod",
  category="lm",
  description="MODIFIER LETTER GLOTTAL STOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x02C0,
 },
 {
  adobename="glottalstopreversedmod",
  category="lm",
  description="MODIFIER LETTER REVERSED GLOTTAL STOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x02C1,
 },
 {
  adobename="arrowheadleftmod",
  category="sk",
  description="MODIFIER LETTER LEFT ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x02C2,
 },
 {
  adobename="arrowheadrightmod",
  category="sk",
  description="MODIFIER LETTER RIGHT ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x02C3,
 },
 {
  adobename="arrowheadupmod",
  category="sk",
  cjkwd="a",
  description="MODIFIER LETTER UP ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x02C4,
 },
 {
  adobename="arrowheaddownmod",
  category="sk",
  description="MODIFIER LETTER DOWN ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x02C5,
 },
 {
  adobename="circumflex",
  category="lm",
  comment="check special",
  contextname="textcircumflex",
  description="MODIFIER LETTER CIRCUMFLEX ACCENT",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  mathname="hat",
  specials={ "compat", 0x0020, 0x0302 },
  unicodeslot=0x02C6,
 },
 {
  adobename="caron",
  category="lm",
  cjkwd="a",
  comment="check special",
  contextname="textcaron",
  description="CARON",
  direction="on",
  linebreak="ai",
  mathclass="topaccent",
  mathname="check",
  specials={ "compat", 0x0020, 0x030C },
  unicodeslot=0x02C7,
 },
 {
  adobename="verticallinemod",
  category="lm",
  description="MODIFIER LETTER VERTICAL LINE",
  direction="on",
  linebreak="bb",
  unicodeslot=0x02C8,
 },
 {
  adobename="firsttonechinese",
  category="lm",
  cjkwd="a",
  description="MODIFIER LETTER MACRON",
  direction="on",
  linebreak="ai",
  unicodeslot=0x02C9,
 },
 {
  adobename="secondtonechinese",
  category="lm",
  cjkwd="a",
  description="MODIFIER LETTER ACUTE ACCENT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x02CA,
 },
 {
  adobename="fourthtonechinese",
  category="lm",
  cjkwd="a",
  description="MODIFIER LETTER GRAVE ACCENT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x02CB,
 },
 {
  adobename="verticallinelowmod",
  category="lm",
  description="MODIFIER LETTER LOW VERTICAL LINE",
  direction="on",
  linebreak="bb",
  unicodeslot=0x02CC,
 },
 {
  adobename="macronlowmod",
  category="lm",
  cjkwd="a",
  description="MODIFIER LETTER LOW MACRON",
  direction="on",
  linebreak="ai",
  unicodeslot=0x02CD,
 },
 {
  adobename="gravelowmod",
  category="lm",
  description="MODIFIER LETTER LOW GRAVE ACCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x02CE,
 },
 {
  adobename="acutelowmod",
  category="lm",
  description="MODIFIER LETTER LOW ACUTE ACCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x02CF,
 },
 {
  adobename="colontriangularmod",
  category="lm",
  cjkwd="a",
  description="MODIFIER LETTER TRIANGULAR COLON",
  direction="l",
  linebreak="ai",
  unicodeslot=0x02D0,
 },
 {
  adobename="colontriangularhalfmod",
  category="lm",
  description="MODIFIER LETTER HALF TRIANGULAR COLON",
  direction="l",
  linebreak="al",
  unicodeslot=0x02D1,
 },
 {
  adobename="ringhalfrightcentered",
  category="sk",
  description="MODIFIER LETTER CENTRED RIGHT HALF RING",
  direction="on",
  linebreak="al",
  unicodeslot=0x02D2,
 },
 {
  adobename="ringhalfleftcentered",
  category="sk",
  description="MODIFIER LETTER CENTRED LEFT HALF RING",
  direction="on",
  linebreak="al",
  unicodeslot=0x02D3,
 },
 {
  adobename="uptackmod",
  category="sk",
  description="MODIFIER LETTER UP TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x02D4,
 },
 {
  adobename="downtackmod",
  category="sk",
  description="MODIFIER LETTER DOWN TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x02D5,
 },
 {
  adobename="plusmod",
  category="sk",
  description="MODIFIER LETTER PLUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x02D6,
 },
 {
  adobename="minusmod",
  category="sk",
  description="MODIFIER LETTER MINUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x02D7,
 },
 {
  adobename="breve",
  category="sk",
  cjkwd="a",
  contextname="textbreve",
  description="BREVE",
  direction="on",
  linebreak="ai",
  mathclass="topaccent",
  mathname="breve",
  specials={ "compat", 0x0020, 0x0306 },
  unicodeslot=0x02D8,
 },
 {
  adobename="dotaccent",
  category="sk",
  cjkwd="a",
  contextname="textdotaccent",
  description="DOT ABOVE",
  direction="on",
  linebreak="ai",
  mathclass="topaccent",
  mathname="dot",
  specials={ "compat", 0x0020, 0x0307 },
  unicodeslot=0x02D9,
 },
 {
  adobename="ring",
  category="sk",
  cjkwd="a",
  contextname="textring",
  description="RING ABOVE",
  direction="on",
  linebreak="ai",
  mathclass="topaccent",
  mathname="mathring",
  specials={ "compat", 0x0020, 0x030A },
  unicodeslot=0x02DA,
 },
 {
  adobename="ogonek",
  category="sk",
  cjkwd="a",
  contextname="textogonek",
  description="OGONEK",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0020, 0x0328 },
  unicodeslot=0x02DB,
 },
 {
  adobename="tilde",
  category="sk",
  contextname="texttilde",
  description="SMALL TILDE",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  mathname="tilde",
  specials={ "compat", 0x0020, 0x0303 },
  unicodeslot=0x02DC,
 },
 {
  adobename="hungarumlaut",
  category="sk",
  cjkwd="a",
  contextname="texthungarumlaut",
  description="DOUBLE ACUTE ACCENT",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0020, 0x030B },
  unicodeslot=0x02DD,
 },
 {
  adobename="rhotichookmod",
  category="sk",
  description="MODIFIER LETTER RHOTIC HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x02DE,
 },
 {
  category="sk",
  cjkwd="a",
  description="MODIFIER LETTER CROSS ACCENT",
  direction="on",
  linebreak="bb",
  unicodeslot=0x02DF,
 },
 {
  adobename="gammasuperior",
  category="lm",
  description="MODIFIER LETTER SMALL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0263 },
  unicodeslot=0x02E0,
 },
 {
  category="lm",
  description="MODIFIER LETTER SMALL L",
  direction="l",
  linebreak="al",
  specials={ "super", 0x006C },
  unicodeslot=0x02E1,
 },
 {
  category="lm",
  description="MODIFIER LETTER SMALL S",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0073 },
  unicodeslot=0x02E2,
 },
 {
  adobename="xsuperior",
  category="lm",
  description="MODIFIER LETTER SMALL X",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0078 },
  unicodeslot=0x02E3,
 },
 {
  adobename="glottalstopreversedsuperior",
  category="lm",
  description="MODIFIER LETTER SMALL REVERSED GLOTTAL STOP",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0295 },
  unicodeslot=0x02E4,
 },
 {
  adobename="tonebarextrahighmod",
  category="sk",
  description="MODIFIER LETTER EXTRA-HIGH TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x02E5,
 },
 {
  adobename="tonebarhighmod",
  category="sk",
  description="MODIFIER LETTER HIGH TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x02E6,
 },
 {
  adobename="tonebarmidmod",
  category="sk",
  description="MODIFIER LETTER MID TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x02E7,
 },
 {
  adobename="tonebarlowmod",
  category="sk",
  description="MODIFIER LETTER LOW TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x02E8,
 },
 {
  adobename="tonebarextralowmod",
  category="sk",
  description="MODIFIER LETTER EXTRA-LOW TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x02E9,
 },
 {
  category="sk",
  description="MODIFIER LETTER YIN DEPARTING TONE MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x02EA,
 },
 {
  category="sk",
  description="MODIFIER LETTER YANG DEPARTING TONE MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x02EB,
 },
 {
  category="sk",
  description="MODIFIER LETTER VOICING",
  direction="on",
  linebreak="al",
  unicodeslot=0x02EC,
 },
 {
  category="sk",
  description="MODIFIER LETTER UNASPIRATED",
  direction="on",
  linebreak="al",
  unicodeslot=0x02ED,
 },
 {
  category="lm",
  description="MODIFIER LETTER DOUBLE APOSTROPHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x02EE,
 },
 {
  category="sk",
  description="MODIFIER LETTER LOW DOWN ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x02EF,
 },
 {
  category="sk",
  description="MODIFIER LETTER LOW UP ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F0,
 },
 {
  category="sk",
  description="MODIFIER LETTER LOW LEFT ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F1,
 },
 {
  category="sk",
  description="MODIFIER LETTER LOW RIGHT ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F2,
 },
 {
  category="sk",
  description="MODIFIER LETTER LOW RING",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F3,
 },
 {
  category="sk",
  description="MODIFIER LETTER MIDDLE GRAVE ACCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F4,
 },
 {
  category="sk",
  description="MODIFIER LETTER MIDDLE DOUBLE GRAVE ACCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F5,
 },
 {
  category="sk",
  description="MODIFIER LETTER MIDDLE DOUBLE ACUTE ACCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F6,
 },
 {
  category="sk",
  description="MODIFIER LETTER LOW TILDE",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F7,
 },
 {
  category="sk",
  description="MODIFIER LETTER RAISED COLON",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F8,
 },
 {
  category="sk",
  description="MODIFIER LETTER BEGIN HIGH TONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x02F9,
 },
 {
  category="sk",
  description="MODIFIER LETTER END HIGH TONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x02FA,
 },
 {
  category="sk",
  description="MODIFIER LETTER BEGIN LOW TONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x02FB,
 },
 {
  category="sk",
  description="MODIFIER LETTER END LOW TONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x02FC,
 },
 {
  category="sk",
  description="MODIFIER LETTER SHELF",
  direction="on",
  linebreak="al",
  unicodeslot=0x02FD,
 },
 {
  category="sk",
  description="MODIFIER LETTER OPEN SHELF",
  direction="on",
  linebreak="al",
  unicodeslot=0x02FE,
 },
 {
  category="sk",
  description="MODIFIER LETTER LOW LEFT ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x02FF,
 },
 {
  adobename="gravecomb",
  category="mn",
  cjkwd="a",
  description="COMBINING GRAVE ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0300,
 },
 {
  adobename="acutecomb",
  category="mn",
  cjkwd="a",
  description="COMBINING ACUTE ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0301,
 },
 {
  adobename="circumflexcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING CIRCUMFLEX ACCENT",
  direction="nsm",
  linebreak="cm",
  mathclass="topaccent",
  mathname="widehat",
  mathstretch="h",
  unicodeslot=0x0302,
 },
 {
  adobename="tildecomb",
  category="mn",
  cjkwd="a",
  description="COMBINING TILDE",
  direction="nsm",
  linebreak="cm",
  mathclass="topaccent",
  mathname="widetilde",
  mathstretch="h",
  unicodeslot=0x0303,
 },
 {
  adobename="macroncmb",
  category="mn",
  cjkwd="a",
  description="COMBINING MACRON",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0304,
 },
 {
  adobename="overlinecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING OVERLINE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0305,
 },
 {
  adobename="brevecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING BREVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0306,
 },
 {
  adobename="dotaccentcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOT ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0307,
 },
 {
  adobename="dieresiscmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DIAERESIS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0308,
 },
 {
  adobename="hookcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING HOOK ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0309,
 },
 {
  adobename="ringcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING RING ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x030A,
 },
 {
  adobename="hungarumlautcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE ACUTE ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x030B,
 },
 {
  adobename="caroncmb",
  category="mn",
  cjkwd="a",
  description="COMBINING CARON",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x030C,
 },
 {
  adobename="verticallineabovecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING VERTICAL LINE ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x030D,
 },
 {
  adobename="dblverticallineabovecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE VERTICAL LINE ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x030E,
 },
 {
  adobename="dblgravecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE GRAVE ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x030F,
 },
 {
  adobename="candrabinducmb",
  category="mn",
  cjkwd="a",
  description="COMBINING CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0310,
 },
 {
  adobename="breveinvertedcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING INVERTED BREVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0311,
 },
 {
  adobename="commaturnedabovecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING TURNED COMMA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0312,
 },
 {
  adobename="commaabovecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING COMMA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0313,
 },
 {
  adobename="commareversedabovecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING REVERSED COMMA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0314,
 },
 {
  adobename="commaaboverightcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING COMMA ABOVE RIGHT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0315,
 },
 {
  adobename="gravebelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING GRAVE ACCENT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0316,
 },
 {
  adobename="acutebelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING ACUTE ACCENT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0317,
 },
 {
  adobename="lefttackbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING LEFT TACK BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0318,
 },
 {
  adobename="righttackbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING RIGHT TACK BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0319,
 },
 {
  adobename="leftangleabovecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING LEFT ANGLE ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x031A,
 },
 {
  adobename="horncmb",
  category="mn",
  cjkwd="a",
  description="COMBINING HORN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x031B,
 },
 {
  adobename="ringhalfleftbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING LEFT HALF RING BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x031C,
 },
 {
  adobename="uptackbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING UP TACK BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x031D,
 },
 {
  adobename="downtackbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOWN TACK BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x031E,
 },
 {
  adobename="plusbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING PLUS SIGN BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x031F,
 },
 {
  adobename="minusbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING MINUS SIGN BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0320,
 },
 {
  adobename="hookpalatalizedbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING PALATALIZED HOOK BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0321,
 },
 {
  adobename="hookretroflexbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING RETROFLEX HOOK BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0322,
 },
 {
  adobename="dotbelowcomb",
  category="mn",
  cjkwd="a",
  contextname="textbottomdot",
  description="COMBINING DOT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0323,
 },
 {
  adobename="dieresisbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DIAERESIS BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0324,
 },
 {
  adobename="ringbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING RING BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0325,
 },
 {
  category="mn",
  cjkwd="a",
  contextname="textbottomcomma",
  description="COMBINING COMMA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0326,
 },
 {
  adobename="cedillacmb",
  category="mn",
  cjkwd="a",
  description="COMBINING CEDILLA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0327,
 },
 {
  adobename="ogonekcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING OGONEK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0328,
 },
 {
  adobename="verticallinebelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING VERTICAL LINE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0329,
 },
 {
  adobename="bridgebelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING BRIDGE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x032A,
 },
 {
  adobename="dblarchinvertedbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING INVERTED DOUBLE ARCH BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x032B,
 },
 {
  adobename="caronbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING CARON BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x032C,
 },
 {
  adobename="circumflexbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING CIRCUMFLEX ACCENT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x032D,
 },
 {
  adobename="brevebelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING BREVE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x032E,
 },
 {
  adobename="breveinvertedbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING INVERTED BREVE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x032F,
 },
 {
  adobename="tildebelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING TILDE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0330,
 },
 {
  adobename="macronbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING MACRON BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0331,
 },
 {
  adobename="lowlinecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING LOW LINE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0332,
 },
 {
  adobename="dbllowlinecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE LOW LINE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0333,
 },
 {
  adobename="tildeoverlaycmb",
  category="mn",
  cjkwd="a",
  description="COMBINING TILDE OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0334,
 },
 {
  adobename="strokeshortoverlaycmb",
  category="mn",
  cjkwd="a",
  description="COMBINING SHORT STROKE OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0335,
 },
 {
  adobename="strokelongoverlaycmb",
  category="mn",
  cjkwd="a",
  description="COMBINING LONG STROKE OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0336,
 },
 {
  adobename="solidusshortoverlaycmb",
  category="mn",
  cjkwd="a",
  description="COMBINING SHORT SOLIDUS OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0337,
 },
 {
  adobename="soliduslongoverlaycmb",
  category="mn",
  cjkwd="a",
  description="COMBINING LONG SOLIDUS OVERLAY",
  direction="nsm",
  linebreak="cm",
  mathclass="relation",
  mathname="not",
  unicodeslot=0x0338,
 },
 {
  adobename="ringhalfrightbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING RIGHT HALF RING BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0339,
 },
 {
  adobename="bridgeinvertedbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING INVERTED BRIDGE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x033A,
 },
 {
  adobename="squarebelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING SQUARE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x033B,
 },
 {
  adobename="seagullbelowcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING SEAGULL BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x033C,
 },
 {
  adobename="xabovecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING X ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x033D,
 },
 {
  adobename="tildeverticalcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING VERTICAL TILDE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x033E,
 },
 {
  adobename="dbloverlinecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE OVERLINE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x033F,
 },
 {
  adobename="gravetonecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING GRAVE TONE MARK",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0300 },
  unicodeslot=0x0340,
 },
 {
  adobename="acutetonecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING ACUTE TONE MARK",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0301 },
  unicodeslot=0x0341,
 },
 {
  adobename="perispomenigreekcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING GREEK PERISPOMENI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0342,
 },
 {
  adobename="koroniscmb",
  category="mn",
  cjkwd="a",
  description="COMBINING GREEK KORONIS",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0313 },
  unicodeslot=0x0343,
 },
 {
  adobename="dialytikatonoscmb",
  category="mn",
  cjkwd="a",
  description="COMBINING GREEK DIALYTIKA TONOS",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0308, 0x0301 },
  unicodeslot=0x0344,
 },
 {
  adobename="ypogegrammenigreekcmb",
  category="mn",
  cjkwd="a",
  description="COMBINING GREEK YPOGEGRAMMENI",
  direction="nsm",
  linebreak="cm",
  uccode=0x0399,
  unicodeslot=0x0345,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING BRIDGE ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0346,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING EQUALS SIGN BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0347,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE VERTICAL LINE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0348,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LEFT ANGLE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0349,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING NOT TILDE ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x034A,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING HOMOTHETIC ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x034B,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING ALMOST EQUAL TO ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x034C,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LEFT RIGHT ARROW BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x034D,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING UPWARDS ARROW BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x034E,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING GRAPHEME JOINER",
  direction="nsm",
  linebreak="gl",
  unicodeslot=0x034F,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING RIGHT ARROWHEAD ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0350,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LEFT HALF RING ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0351,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING FERMATA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0352,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING X BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0353,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LEFT ARROWHEAD BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0354,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING RIGHT ARROWHEAD BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0355,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING RIGHT ARROWHEAD AND UP ARROWHEAD BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0356,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING RIGHT HALF RING ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0357,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING DOT ABOVE RIGHT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0358,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING ASTERISK BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0359,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE RING BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x035A,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING ZIGZAG ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x035B,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE BREVE BELOW",
  direction="nsm",
  linebreak="gl",
  unicodeslot=0x035C,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE BREVE",
  direction="nsm",
  linebreak="gl",
  unicodeslot=0x035D,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE MACRON",
  direction="nsm",
  linebreak="gl",
  unicodeslot=0x035E,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE MACRON BELOW",
  direction="nsm",
  linebreak="gl",
  unicodeslot=0x035F,
 },
 {
  adobename="tildedoublecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE TILDE",
  direction="nsm",
  linebreak="gl",
  unicodeslot=0x0360,
 },
 {
  adobename="breveinverteddoublecmb",
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE INVERTED BREVE",
  direction="nsm",
  linebreak="gl",
  unicodeslot=0x0361,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING DOUBLE RIGHTWARDS ARROW BELOW",
  direction="nsm",
  linebreak="gl",
  unicodeslot=0x0362,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0363,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0364,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0365,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0366,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0367,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0368,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0369,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER H",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x036A,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER M",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x036B,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x036C,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER T",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x036D,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER V",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x036E,
 },
 {
  category="mn",
  cjkwd="a",
  description="COMBINING LATIN SMALL LETTER X",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x036F,
 },
 {
  category="lu",
  description="GREEK CAPITAL LETTER HETA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0370,
 },
 {
  category="ll",
  description="GREEK SMALL LETTER HETA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0371,
 },
 {
  category="lu",
  description="GREEK CAPITAL LETTER ARCHAIC SAMPI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0372,
 },
 {
  category="ll",
  description="GREEK SMALL LETTER ARCHAIC SAMPI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0373,
 },
 {
  adobename="numeralsigngreek",
  category="sk",
  description="GREEK NUMERAL SIGN",
  direction="on",
  linebreak="al",
  specials={ "char", 0x02B9 },
  unicodeslot=0x0374,
 },
 {
  adobename="numeralsignlowergreek",
  category="sk",
  description="GREEK LOWER NUMERAL SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x0375,
 },
 {
  category="lu",
  description="GREEK CAPITAL LETTER PAMPHYLIAN DIGAMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0376,
 },
 {
  category="ll",
  description="GREEK SMALL LETTER PAMPHYLIAN DIGAMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0377,
 },
 [0x037A]={
  adobename="ypogegrammeni",
  category="lm",
  description="GREEK YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0020, 0x0345 },
  unicodeslot=0x037A,
 },
 [0x037B]={
  category="ll",
  description="GREEK SMALL REVERSED LUNATE SIGMA SYMBOL",
  direction="l",
  linebreak="al",
  uccode=0x03FD,
  unicodeslot=0x037B,
 },
 [0x037C]={
  category="ll",
  description="GREEK SMALL DOTTED LUNATE SIGMA SYMBOL",
  direction="l",
  linebreak="al",
  uccode=0x03FE,
  unicodeslot=0x037C,
 },
 [0x037D]={
  category="ll",
  description="GREEK SMALL REVERSED DOTTED LUNATE SIGMA SYMBOL",
  direction="l",
  linebreak="al",
  uccode=0x03FF,
  unicodeslot=0x037D,
 },
 [0x037E]={
  adobename="questiongreek",
  category="po",
  description="GREEK QUESTION MARK",
  direction="on",
  linebreak="is",
  specials={ "char", 0x003B },
  unicodeslot=0x037E,
 },
 [0x0384]={
  adobename="tonos",
  category="sk",
  contextname="greektonos",
  description="GREEK TONOS",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0020, 0x0301 },
  unicodeslot=0x0384,
 },
 [0x0385]={
  adobename="dieresistonos",
  category="sk",
  contextname="greekdialytikatonos",
  description="GREEK DIALYTIKA TONOS",
  direction="on",
  linebreak="al",
  specials={ "char", 0x00A8, 0x0301 },
  unicodeslot=0x0385,
 },
 [0x0386]={
  adobename="Alphatonos",
  category="lu",
  contextname="greekAlphatonos",
  description="GREEK CAPITAL LETTER ALPHA WITH TONOS",
  direction="l",
  lccode=0x03AC,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x0391, 0x0301 },
  unicodeslot=0x0386,
 },
 [0x0387]={
  adobename="anoteleia",
  category="po",
  description="GREEK ANO TELEIA",
  direction="on",
  linebreak="al",
  specials={ "char", 0x00B7 },
  unicodeslot=0x0387,
 },
 [0x0388]={
  adobename="Epsilontonos",
  category="lu",
  contextname="greekEpsilontonos",
  description="GREEK CAPITAL LETTER EPSILON WITH TONOS",
  direction="l",
  lccode=0x03AD,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x0395, 0x0301 },
  unicodeslot=0x0388,
 },
 [0x0389]={
  adobename="Etatonos",
  category="lu",
  contextname="greekEtatonos",
  description="GREEK CAPITAL LETTER ETA WITH TONOS",
  direction="l",
  lccode=0x03AE,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x0397, 0x0301 },
  unicodeslot=0x0389,
 },
 [0x038A]={
  adobename="Iotatonos",
  category="lu",
  contextname="greekIotatonos",
  description="GREEK CAPITAL LETTER IOTA WITH TONOS",
  direction="l",
  lccode=0x03AF,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x0399, 0x0301 },
  unicodeslot=0x038A,
 },
 [0x038C]={
  adobename="Omicrontonos",
  category="lu",
  contextname="greekOmicrontonos",
  description="GREEK CAPITAL LETTER OMICRON WITH TONOS",
  direction="l",
  lccode=0x03CC,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x039F, 0x0301 },
  unicodeslot=0x038C,
 },
 [0x038E]={
  adobename="Upsilontonos",
  category="lu",
  contextname="greekUpsilontonos",
  description="GREEK CAPITAL LETTER UPSILON WITH TONOS",
  direction="l",
  lccode=0x03CD,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x03A5, 0x0301 },
  unicodeslot=0x038E,
 },
 [0x038F]={
  adobename="Omegatonos",
  category="lu",
  contextname="greekOmegatonos",
  description="GREEK CAPITAL LETTER OMEGA WITH TONOS",
  direction="l",
  lccode=0x03CE,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x03A9, 0x0301 },
  unicodeslot=0x038F,
 },
 [0x0390]={
  adobename="iotadieresistonos",
  category="ll",
  contextname="greekiotadialytikatonos",
  description="GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03CA, 0x0301 },
  unicodeslot=0x0390,
 },
 [0x0391]={
  adobename="Alpha",
  category="lu",
  cjkwd="a",
  contextname="greekAlpha",
  description="GREEK CAPITAL LETTER ALPHA",
  direction="l",
  lccode=0x03B1,
  linebreak="al",
  mathclass="variable",
  mathname="Alpha",
  unicodeslot=0x0391,
 },
 [0x0392]={
  adobename="Beta",
  category="lu",
  cjkwd="a",
  contextname="greekBeta",
  description="GREEK CAPITAL LETTER BETA",
  direction="l",
  lccode=0x03B2,
  linebreak="al",
  mathclass="variable",
  mathname="Beta",
  unicodeslot=0x0392,
 },
 [0x0393]={
  adobename="Gamma",
  category="lu",
  cjkwd="a",
  contextname="greekGamma",
  description="GREEK CAPITAL LETTER GAMMA",
  direction="l",
  lccode=0x03B3,
  linebreak="al",
  mathclass="variable",
  mathname="Gamma",
  unicodeslot=0x0393,
 },
 [0x0394]={
  adobename="Deltagreek",
  category="lu",
  cjkwd="a",
  contextname="greekDelta",
  description="GREEK CAPITAL LETTER DELTA",
  direction="l",
  lccode=0x03B4,
  linebreak="al",
  mathclass="variable",
  mathname="Delta",
  unicodeslot=0x0394,
 },
 [0x0395]={
  adobename="Epsilon",
  category="lu",
  cjkwd="a",
  contextname="greekEpsilon",
  description="GREEK CAPITAL LETTER EPSILON",
  direction="l",
  lccode=0x03B5,
  linebreak="al",
  mathclass="variable",
  mathname="Epsilon",
  unicodeslot=0x0395,
 },
 [0x0396]={
  adobename="Zeta",
  category="lu",
  cjkwd="a",
  contextname="greekZeta",
  description="GREEK CAPITAL LETTER ZETA",
  direction="l",
  lccode=0x03B6,
  linebreak="al",
  mathclass="variable",
  mathname="Zeta",
  unicodeslot=0x0396,
 },
 [0x0397]={
  adobename="Eta",
  category="lu",
  cjkwd="a",
  contextname="greekEta",
  description="GREEK CAPITAL LETTER ETA",
  direction="l",
  lccode=0x03B7,
  linebreak="al",
  mathclass="variable",
  mathname="Eta",
  unicodeslot=0x0397,
 },
 [0x0398]={
  adobename="Theta",
  category="lu",
  cjkwd="a",
  contextname="greekTheta",
  description="GREEK CAPITAL LETTER THETA",
  direction="l",
  lccode=0x03B8,
  linebreak="al",
  mathclass="variable",
  mathname="Theta",
  unicodeslot=0x0398,
 },
 [0x0399]={
  adobename="Iota",
  category="lu",
  cjkwd="a",
  contextname="greekIota",
  description="GREEK CAPITAL LETTER IOTA",
  direction="l",
  lccode=0x03B9,
  linebreak="al",
  mathclass="variable",
  mathname="Iota",
  unicodeslot=0x0399,
 },
 [0x039A]={
  adobename="Kappa",
  category="lu",
  cjkwd="a",
  contextname="greekKappa",
  description="GREEK CAPITAL LETTER KAPPA",
  direction="l",
  lccode=0x03BA,
  linebreak="al",
  mathclass="variable",
  mathname="Kappa",
  unicodeslot=0x039A,
 },
 [0x039B]={
  adobename="Lambda",
  category="lu",
  cjkwd="a",
  contextname="greekLambda",
  description="GREEK CAPITAL LETTER LAMDA",
  direction="l",
  lccode=0x03BB,
  linebreak="al",
  mathclass="variable",
  mathname="Lambda",
  unicodeslot=0x039B,
 },
 [0x039C]={
  adobename="Mu",
  category="lu",
  cjkwd="a",
  contextname="greekMu",
  description="GREEK CAPITAL LETTER MU",
  direction="l",
  lccode=0x03BC,
  linebreak="al",
  mathclass="variable",
  mathname="Mu",
  unicodeslot=0x039C,
 },
 [0x039D]={
  adobename="Nu",
  category="lu",
  cjkwd="a",
  contextname="greekNu",
  description="GREEK CAPITAL LETTER NU",
  direction="l",
  lccode=0x03BD,
  linebreak="al",
  mathclass="variable",
  mathname="Nu",
  unicodeslot=0x039D,
 },
 [0x039E]={
  adobename="Xi",
  category="lu",
  cjkwd="a",
  contextname="greekXi",
  description="GREEK CAPITAL LETTER XI",
  direction="l",
  lccode=0x03BE,
  linebreak="al",
  mathclass="variable",
  mathname="Xi",
  unicodeslot=0x039E,
 },
 [0x039F]={
  adobename="Omicron",
  category="lu",
  cjkwd="a",
  contextname="greekOmicron",
  description="GREEK CAPITAL LETTER OMICRON",
  direction="l",
  lccode=0x03BF,
  linebreak="al",
  mathclass="variable",
  mathname="Omicron",
  unicodeslot=0x039F,
 },
 [0x03A0]={
  adobename="Pi",
  category="lu",
  cjkwd="a",
  contextname="greekPi",
  description="GREEK CAPITAL LETTER PI",
  direction="l",
  lccode=0x03C0,
  linebreak="al",
  mathclass="variable",
  mathname="Pi",
  unicodeslot=0x03A0,
 },
 [0x03A1]={
  adobename="Rho",
  category="lu",
  cjkwd="a",
  contextname="greekRho",
  description="GREEK CAPITAL LETTER RHO",
  direction="l",
  lccode=0x03C1,
  linebreak="al",
  mathclass="variable",
  mathname="Rho",
  unicodeslot=0x03A1,
 },
 [0x03A3]={
  adobename="Sigma",
  category="lu",
  cjkwd="a",
  contextname="greekSigma",
  description="GREEK CAPITAL LETTER SIGMA",
  direction="l",
  lccode=0x03C3,
  linebreak="al",
  mathclass="variable",
  mathname="Sigma",
  unicodeslot=0x03A3,
 },
 [0x03A4]={
  adobename="Tau",
  category="lu",
  cjkwd="a",
  contextname="greekTau",
  description="GREEK CAPITAL LETTER TAU",
  direction="l",
  lccode=0x03C4,
  linebreak="al",
  mathclass="variable",
  mathname="Tau",
  unicodeslot=0x03A4,
 },
 [0x03A5]={
  adobename="Upsilon",
  category="lu",
  cjkwd="a",
  contextname="greekUpsilon",
  description="GREEK CAPITAL LETTER UPSILON",
  direction="l",
  lccode=0x03C5,
  linebreak="al",
  mathclass="variable",
  mathname="Upsilon",
  unicodeslot=0x03A5,
 },
 [0x03A6]={
  adobename="Phi",
  category="lu",
  cjkwd="a",
  contextname="greekPhi",
  description="GREEK CAPITAL LETTER PHI",
  direction="l",
  lccode=0x03C6,
  linebreak="al",
  mathclass="variable",
  mathname="Phi",
  unicodeslot=0x03A6,
 },
 [0x03A7]={
  adobename="Chi",
  category="lu",
  cjkwd="a",
  contextname="greekChi",
  description="GREEK CAPITAL LETTER CHI",
  direction="l",
  lccode=0x03C7,
  linebreak="al",
  mathclass="variable",
  mathname="Chi",
  unicodeslot=0x03A7,
 },
 [0x03A8]={
  adobename="Psi",
  category="lu",
  cjkwd="a",
  contextname="greekPsi",
  description="GREEK CAPITAL LETTER PSI",
  direction="l",
  lccode=0x03C8,
  linebreak="al",
  mathclass="variable",
  mathname="Psi",
  unicodeslot=0x03A8,
 },
 [0x03A9]={
  adobename="Omegagreek",
  category="lu",
  cjkwd="a",
  contextname="greekOmega",
  description="GREEK CAPITAL LETTER OMEGA",
  direction="l",
  lccode=0x03C9,
  linebreak="al",
  mathclass="variable",
  mathname="Omega",
  unicodeslot=0x03A9,
 },
 [0x03AA]={
  adobename="Iotadieresis",
  category="lu",
  contextname="greekIotadialytika",
  description="GREEK CAPITAL LETTER IOTA WITH DIALYTIKA",
  direction="l",
  lccode=0x03CA,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x0399, 0x0308 },
  unicodeslot=0x03AA,
 },
 [0x03AB]={
  adobename="Upsilondieresis",
  category="lu",
  contextname="greekUpsilondialytika",
  description="GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA",
  direction="l",
  lccode=0x03CB,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x03A5, 0x0308 },
  unicodeslot=0x03AB,
 },
 [0x03AC]={
  adobename="alphatonos",
  category="ll",
  contextname="greekalphatonos",
  description="GREEK SMALL LETTER ALPHA WITH TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03B1, 0x0301 },
  uccode=0x0386,
  unicodeslot=0x03AC,
 },
 [0x03AD]={
  adobename="epsilontonos",
  category="ll",
  contextname="greekepsilontonos",
  description="GREEK SMALL LETTER EPSILON WITH TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x03B5, 0x0301 },
  uccode=0x0388,
  unicodeslot=0x03AD,
 },
 [0x03AE]={
  adobename="etatonos",
  category="ll",
  contextname="greeketatonos",
  description="GREEK SMALL LETTER ETA WITH TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x03B7, 0x0301 },
  uccode=0x0389,
  unicodeslot=0x03AE,
 },
 [0x03AF]={
  adobename="iotatonos",
  category="ll",
  contextname="greekiotatonos",
  description="GREEK SMALL LETTER IOTA WITH TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03B9, 0x0301 },
  uccode=0x038A,
  unicodeslot=0x03AF,
 },
 [0x03B0]={
  adobename="upsilondieresistonos",
  category="ll",
  contextname="greekupsilondialytikatonos",
  description="GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03CB, 0x0301 },
  unicodeslot=0x03B0,
 },
 [0x03B1]={
  adobename="alpha",
  category="ll",
  cjkwd="a",
  contextname="greekalpha",
  description="GREEK SMALL LETTER ALPHA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="alpha",
  uccode=0x0391,
  unicodeslot=0x03B1,
 },
 [0x03B2]={
  adobename="beta",
  category="ll",
  cjkwd="a",
  contextname="greekbeta",
  description="GREEK SMALL LETTER BETA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="beta",
  uccode=0x0392,
  unicodeslot=0x03B2,
 },
 [0x03B3]={
  adobename="gamma",
  category="ll",
  cjkwd="a",
  contextname="greekgamma",
  description="GREEK SMALL LETTER GAMMA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="gamma",
  uccode=0x0393,
  unicodeslot=0x03B3,
 },
 [0x03B4]={
  adobename="delta",
  category="ll",
  cjkwd="a",
  contextname="greekdelta",
  description="GREEK SMALL LETTER DELTA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="delta",
  uccode=0x0394,
  unicodeslot=0x03B4,
 },
 [0x03B5]={
  adobename="epsilon",
  category="ll",
  cjkwd="a",
  contextname="greekepsilon",
  description="GREEK SMALL LETTER EPSILON",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="varepsilon",
  uccode=0x0395,
  unicodeslot=0x03B5,
 },
 [0x03B6]={
  adobename="zeta",
  category="ll",
  cjkwd="a",
  contextname="greekzeta",
  description="GREEK SMALL LETTER ZETA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="zeta",
  uccode=0x0396,
  unicodeslot=0x03B6,
 },
 [0x03B7]={
  adobename="eta",
  category="ll",
  cjkwd="a",
  contextname="greeketa",
  description="GREEK SMALL LETTER ETA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="eta",
  uccode=0x0397,
  unicodeslot=0x03B7,
 },
 [0x03B8]={
  adobename="theta",
  category="ll",
  cjkwd="a",
  contextname="greektheta",
  description="GREEK SMALL LETTER THETA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="theta",
  uccode=0x0398,
  unicodeslot=0x03B8,
 },
 [0x03B9]={
  adobename="iota",
  category="ll",
  cjkwd="a",
  contextname="greekiota",
  description="GREEK SMALL LETTER IOTA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="iota",
  uccode=0x0399,
  unicodeslot=0x03B9,
 },
 [0x03BA]={
  adobename="kappa",
  category="ll",
  cjkwd="a",
  contextname="greekkappa",
  description="GREEK SMALL LETTER KAPPA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="kappa",
  uccode=0x039A,
  unicodeslot=0x03BA,
 },
 [0x03BB]={
  adobename="lambda",
  category="ll",
  cjkwd="a",
  contextname="greeklambda",
  description="GREEK SMALL LETTER LAMDA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="lambda",
  uccode=0x039B,
  unicodeslot=0x03BB,
 },
 [0x03BC]={
  adobename="mugreek",
  category="ll",
  cjkwd="a",
  contextname="greekmu",
  description="GREEK SMALL LETTER MU",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="mu",
  uccode=0x039C,
  unicodeslot=0x03BC,
 },
 [0x03BD]={
  adobename="nu",
  category="ll",
  cjkwd="a",
  contextname="greeknu",
  description="GREEK SMALL LETTER NU",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="nu",
  uccode=0x039D,
  unicodeslot=0x03BD,
 },
 [0x03BE]={
  adobename="xi",
  category="ll",
  cjkwd="a",
  contextname="greekxi",
  description="GREEK SMALL LETTER XI",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="xi",
  uccode=0x039E,
  unicodeslot=0x03BE,
 },
 [0x03BF]={
  adobename="omicron",
  category="ll",
  cjkwd="a",
  contextname="greekomicron",
  description="GREEK SMALL LETTER OMICRON",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="omicron",
  uccode=0x039F,
  unicodeslot=0x03BF,
 },
 [0x03C0]={
  adobename="pi",
  category="ll",
  cjkwd="a",
  contextname="greekpi",
  description="GREEK SMALL LETTER PI",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="pi",
  uccode=0x03A0,
  unicodeslot=0x03C0,
 },
 [0x03C1]={
  adobename="rho",
  category="ll",
  cjkwd="a",
  contextname="greekrho",
  description="GREEK SMALL LETTER RHO",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="rho",
  uccode=0x03A1,
  unicodeslot=0x03C1,
 },
 [0x03C2]={
  adobename="sigmafinal",
  category="ll",
  contextname="greekfinalsigma",
  description="GREEK SMALL LETTER FINAL SIGMA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="varsigma",
  uccode=0x03A3,
  unicodeslot=0x03C2,
 },
 [0x03C3]={
  adobename="sigma",
  category="ll",
  cjkwd="a",
  contextname="greeksigma",
  description="GREEK SMALL LETTER SIGMA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="sigma",
  uccode=0x03A3,
  unicodeslot=0x03C3,
 },
 [0x03C4]={
  adobename="tau",
  category="ll",
  cjkwd="a",
  contextname="greektau",
  description="GREEK SMALL LETTER TAU",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="tau",
  uccode=0x03A4,
  unicodeslot=0x03C4,
 },
 [0x03C5]={
  adobename="upsilon",
  category="ll",
  cjkwd="a",
  contextname="greekupsilon",
  description="GREEK SMALL LETTER UPSILON",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="upsilon",
  uccode=0x03A5,
  unicodeslot=0x03C5,
 },
 [0x03C6]={
  adobename="phi",
  category="ll",
  cjkwd="a",
  contextname="greekphi",
  description="GREEK SMALL LETTER PHI",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="varphi",
  uccode=0x03A6,
  unicodeslot=0x03C6,
 },
 [0x03C7]={
  adobename="chi",
  category="ll",
  cjkwd="a",
  contextname="greekchi",
  description="GREEK SMALL LETTER CHI",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="chi",
  uccode=0x03A7,
  unicodeslot=0x03C7,
 },
 [0x03C8]={
  adobename="psi",
  category="ll",
  cjkwd="a",
  contextname="greekpsi",
  description="GREEK SMALL LETTER PSI",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="psi",
  uccode=0x03A8,
  unicodeslot=0x03C8,
 },
 [0x03C9]={
  adobename="omega",
  category="ll",
  cjkwd="a",
  contextname="greekomega",
  description="GREEK SMALL LETTER OMEGA",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="omega",
  uccode=0x03A9,
  unicodeslot=0x03C9,
 },
 [0x03CA]={
  adobename="iotadieresis",
  category="ll",
  contextname="greekiotadialytika",
  description="GREEK SMALL LETTER IOTA WITH DIALYTIKA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03B9, 0x0308 },
  uccode=0x03AA,
  unicodeslot=0x03CA,
 },
 [0x03CB]={
  adobename="upsilondieresis",
  category="ll",
  contextname="greekupsilondiaeresis",
  description="GREEK SMALL LETTER UPSILON WITH DIALYTIKA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03C5, 0x0308 },
  uccode=0x03AB,
  unicodeslot=0x03CB,
 },
 [0x03CC]={
  adobename="omicrontonos",
  category="ll",
  contextname="greekomicrontonos",
  description="GREEK SMALL LETTER OMICRON WITH TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x03BF, 0x0301 },
  uccode=0x038C,
  unicodeslot=0x03CC,
 },
 [0x03CD]={
  adobename="upsilontonos",
  category="ll",
  contextname="greekupsilontonos",
  description="GREEK SMALL LETTER UPSILON WITH TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03C5, 0x0301 },
  uccode=0x038E,
  unicodeslot=0x03CD,
 },
 [0x03CE]={
  adobename="omegatonos",
  category="ll",
  contextname="greekomegatonos",
  description="GREEK SMALL LETTER OMEGA WITH TONOS",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x03C9, 0x0301 },
  uccode=0x038F,
  unicodeslot=0x03CE,
 },
 [0x03CF]={
  category="lu",
  description="GREEK CAPITAL KAI SYMBOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x03CF,
 },
 [0x03D0]={
  adobename="betasymbolgreek",
  category="ll",
  description="GREEK BETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x03B2 },
  uccode=0x0392,
  unicodeslot=0x03D0,
 },
 [0x03D1]={
  adobename="thetasymbolgreek",
  category="ll",
  contextname="greekthetaalt",
  description="GREEK THETA SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="varTheta",
  specials={ "compat", 0x03B8 },
  uccode=0x0398,
  unicodeslot=0x03D1,
 },
 [0x03D2]={
  adobename="Upsilonhooksymbol",
  category="lu",
  description="GREEK UPSILON WITH HOOK SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x03A5 },
  unicodeslot=0x03D2,
 },
 [0x03D3]={
  adobename="Upsilonacutehooksymbolgreek",
  category="lu",
  description="GREEK UPSILON WITH ACUTE AND HOOK SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "char", 0x03D2, 0x0301 },
  unicodeslot=0x03D3,
 },
 [0x03D4]={
  adobename="Upsilondieresishooksymbolgreek",
  category="lu",
  description="GREEK UPSILON WITH DIAERESIS AND HOOK SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "char", 0x03D2, 0x0308 },
  unicodeslot=0x03D4,
 },
 [0x03D5]={
  adobename="phisymbolgreek",
  category="ll",
  contextname="greekphialt",
  description="GREEK PHI SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="phi",
  specials={ "compat", 0x03C6 },
  uccode=0x03A6,
  unicodeslot=0x03D5,
 },
 [0x03D6]={
  adobename="pisymbolgreek",
  category="ll",
  contextname="greekpialt",
  description="GREEK PI SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="varpi",
  specials={ "compat", 0x03C0 },
  uccode=0x03A0,
  unicodeslot=0x03D6,
 },
 [0x03D7]={
  category="ll",
  description="GREEK KAI SYMBOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x03D7,
 },
 [0x03D8]={
  category="lu",
  description="GREEK LETTER ARCHAIC KOPPA",
  direction="l",
  lccode=0x03D9,
  linebreak="al",
  unicodeslot=0x03D8,
 },
 [0x03D9]={
  category="ll",
  contextname="greekkoppa",
  description="GREEK SMALL LETTER ARCHAIC KOPPA",
  direction="l",
  linebreak="al",
  uccode=0x03D8,
  unicodeslot=0x03D9,
 },
 [0x03DA]={
  adobename="Stigmagreek",
  category="lu",
  description="GREEK LETTER STIGMA",
  direction="l",
  lccode=0x03DB,
  linebreak="al",
  unicodeslot=0x03DA,
 },
 [0x03DB]={
  category="ll",
  contextname="greekstigma",
  description="GREEK SMALL LETTER STIGMA",
  direction="l",
  linebreak="al",
  uccode=0x03DA,
  unicodeslot=0x03DB,
 },
 [0x03DC]={
  adobename="Digammagreek",
  category="lu",
  description="GREEK LETTER DIGAMMA",
  direction="l",
  lccode=0x03DD,
  linebreak="al",
  mathclass="variable",
  mathname="digamma",
  unicodeslot=0x03DC,
 },
 [0x03DD]={
  category="ll",
  contextname="greekdigamma",
  description="GREEK SMALL LETTER DIGAMMA",
  direction="l",
  linebreak="al",
  uccode=0x03DC,
  unicodeslot=0x03DD,
 },
 [0x03DE]={
  adobename="Koppagreek",
  category="lu",
  description="GREEK LETTER KOPPA",
  direction="l",
  lccode=0x03DF,
  linebreak="al",
  unicodeslot=0x03DE,
 },
 [0x03DF]={
  category="ll",
  contextname="greeknumkoppa",
  description="GREEK SMALL LETTER KOPPA",
  direction="l",
  linebreak="al",
  uccode=0x03DE,
  unicodeslot=0x03DF,
 },
 [0x03E0]={
  adobename="Sampigreek",
  category="lu",
  description="GREEK LETTER SAMPI",
  direction="l",
  lccode=0x03E1,
  linebreak="al",
  unicodeslot=0x03E0,
 },
 [0x03E1]={
  category="ll",
  contextname="greeksampi",
  description="GREEK SMALL LETTER SAMPI",
  direction="l",
  linebreak="al",
  uccode=0x03E0,
  unicodeslot=0x03E1,
 },
 [0x03E2]={
  adobename="Sheicoptic",
  category="lu",
  description="COPTIC CAPITAL LETTER SHEI",
  direction="l",
  lccode=0x03E3,
  linebreak="al",
  unicodeslot=0x03E2,
 },
 [0x03E3]={
  adobename="sheicoptic",
  category="ll",
  description="COPTIC SMALL LETTER SHEI",
  direction="l",
  linebreak="al",
  uccode=0x03E2,
  unicodeslot=0x03E3,
 },
 [0x03E4]={
  adobename="Feicoptic",
  category="lu",
  description="COPTIC CAPITAL LETTER FEI",
  direction="l",
  lccode=0x03E5,
  linebreak="al",
  unicodeslot=0x03E4,
 },
 [0x03E5]={
  adobename="feicoptic",
  category="ll",
  description="COPTIC SMALL LETTER FEI",
  direction="l",
  linebreak="al",
  uccode=0x03E4,
  unicodeslot=0x03E5,
 },
 [0x03E6]={
  adobename="Kheicoptic",
  category="lu",
  description="COPTIC CAPITAL LETTER KHEI",
  direction="l",
  lccode=0x03E7,
  linebreak="al",
  unicodeslot=0x03E6,
 },
 [0x03E7]={
  adobename="kheicoptic",
  category="ll",
  description="COPTIC SMALL LETTER KHEI",
  direction="l",
  linebreak="al",
  uccode=0x03E6,
  unicodeslot=0x03E7,
 },
 [0x03E8]={
  adobename="Horicoptic",
  category="lu",
  description="COPTIC CAPITAL LETTER HORI",
  direction="l",
  lccode=0x03E9,
  linebreak="al",
  unicodeslot=0x03E8,
 },
 [0x03E9]={
  adobename="horicoptic",
  category="ll",
  description="COPTIC SMALL LETTER HORI",
  direction="l",
  linebreak="al",
  uccode=0x03E8,
  unicodeslot=0x03E9,
 },
 [0x03EA]={
  adobename="Gangiacoptic",
  category="lu",
  description="COPTIC CAPITAL LETTER GANGIA",
  direction="l",
  lccode=0x03EB,
  linebreak="al",
  unicodeslot=0x03EA,
 },
 [0x03EB]={
  adobename="gangiacoptic",
  category="ll",
  description="COPTIC SMALL LETTER GANGIA",
  direction="l",
  linebreak="al",
  uccode=0x03EA,
  unicodeslot=0x03EB,
 },
 [0x03EC]={
  adobename="Shimacoptic",
  category="lu",
  description="COPTIC CAPITAL LETTER SHIMA",
  direction="l",
  lccode=0x03ED,
  linebreak="al",
  unicodeslot=0x03EC,
 },
 [0x03ED]={
  adobename="shimacoptic",
  category="ll",
  description="COPTIC SMALL LETTER SHIMA",
  direction="l",
  linebreak="al",
  uccode=0x03EC,
  unicodeslot=0x03ED,
 },
 [0x03EE]={
  adobename="Deicoptic",
  category="lu",
  description="COPTIC CAPITAL LETTER DEI",
  direction="l",
  lccode=0x03EF,
  linebreak="al",
  unicodeslot=0x03EE,
 },
 [0x03EF]={
  adobename="deicoptic",
  category="ll",
  description="COPTIC SMALL LETTER DEI",
  direction="l",
  linebreak="al",
  uccode=0x03EE,
  unicodeslot=0x03EF,
 },
 [0x03F0]={
  adobename="kappasymbolgreek",
  category="ll",
  description="GREEK KAPPA SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="ordinary",
  mathname="varkappa",
  specials={ "compat", 0x03BA },
  uccode=0x039A,
  unicodeslot=0x03F0,
 },
 [0x03F1]={
  adobename="rhosymbolgreek",
  category="ll",
  contextname="greekrhoalt",
  description="GREEK RHO SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x03C1 },
  uccode=0x03A1,
  unicodeslot=0x03F1,
 },
 [0x03F2]={
  adobename="sigmalunatesymbolgreek",
  category="ll",
  contextname="greeksigmalunate",
  description="GREEK LUNATE SIGMA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x03C2 },
  uccode=0x03F9,
  unicodeslot=0x03F2,
 },
 [0x03F3]={
  adobename="yotgreek",
  category="ll",
  description="GREEK LETTER YOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x03F3,
 },
 [0x03F4]={
  category="lu",
  description="GREEK CAPITAL THETA SYMBOL",
  direction="l",
  lccode=0x03B8,
  linebreak="al",
  specials={ "compat", 0x0398 },
  unicodeslot=0x03F4,
 },
 [0x03F5]={
  category="ll",
  contextname="greekepsilonalt",
  description="GREEK LUNATE EPSILON SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="epsilon",
  specials={ "compat", 0x03B5 },
  uccode=0x0395,
  unicodeslot=0x03F5,
 },
 [0x03F6]={
  category="sm",
  description="GREEK REVERSED LUNATE EPSILON SYMBOL",
  direction="on",
  linebreak="al",
  mathclass="variable",
  mathname="backepsilon",
  unicodeslot=0x03F6,
 },
 [0x03F7]={
  category="lu",
  description="GREEK CAPITAL LETTER SHO",
  direction="l",
  lccode=0x03F8,
  linebreak="al",
  unicodeslot=0x03F7,
 },
 [0x03F8]={
  category="ll",
  description="GREEK SMALL LETTER SHO",
  direction="l",
  linebreak="al",
  uccode=0x03F7,
  unicodeslot=0x03F8,
 },
 [0x03F9]={
  category="lu",
  contextname="greekSigmalunate",
  description="GREEK CAPITAL LUNATE SIGMA SYMBOL",
  direction="l",
  lccode=0x03F2,
  linebreak="al",
  specials={ "compat", 0x03A3 },
  unicodeslot=0x03F9,
 },
 [0x03FA]={
  category="lu",
  description="GREEK CAPITAL LETTER SAN",
  direction="l",
  lccode=0x03FB,
  linebreak="al",
  unicodeslot=0x03FA,
 },
 [0x03FB]={
  category="ll",
  description="GREEK SMALL LETTER SAN",
  direction="l",
  linebreak="al",
  uccode=0x03FA,
  unicodeslot=0x03FB,
 },
 [0x03FC]={
  category="ll",
  description="GREEK RHO WITH STROKE SYMBOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x03FC,
 },
 [0x03FD]={
  category="lu",
  description="GREEK CAPITAL REVERSED LUNATE SIGMA SYMBOL",
  direction="l",
  lccode=0x037B,
  linebreak="al",
  unicodeslot=0x03FD,
 },
 [0x03FE]={
  category="lu",
  description="GREEK CAPITAL DOTTED LUNATE SIGMA SYMBOL",
  direction="l",
  lccode=0x037C,
  linebreak="al",
  unicodeslot=0x03FE,
 },
 [0x03FF]={
  category="lu",
  description="GREEK CAPITAL REVERSED DOTTED LUNATE SIGMA SYMBOL",
  direction="l",
  lccode=0x037D,
  linebreak="al",
  unicodeslot=0x03FF,
 },
 [0x0400]={
  category="lu",
  contextname="cyrillicEgrave",
  description="CYRILLIC CAPITAL LETTER IE WITH GRAVE",
  direction="l",
  lccode=0x0450,
  linebreak="al",
  shcode=0x0415,
  specials={ "char", 0x0415, 0x0300 },
  unicodeslot=0x0400,
 },
 [0x0401]={
  adobename="afii10023",
  category="lu",
  cjkwd="a",
  contextname="cyrillicYO",
  description="CYRILLIC CAPITAL LETTER IO",
  direction="l",
  lccode=0x0451,
  linebreak="al",
  specials={ "char", 0x0415, 0x0308 },
  unicodeslot=0x0401,
 },
 [0x0402]={
  adobename="afii10051",
  category="lu",
  contextname="cyrillicDJE",
  description="CYRILLIC CAPITAL LETTER DJE",
  direction="l",
  lccode=0x0452,
  linebreak="al",
  unicodeslot=0x0402,
 },
 [0x0403]={
  adobename="afii10052",
  category="lu",
  contextname="cyrillicGJE",
  description="CYRILLIC CAPITAL LETTER GJE",
  direction="l",
  lccode=0x0453,
  linebreak="al",
  specials={ "char", 0x0413, 0x0301 },
  unicodeslot=0x0403,
 },
 [0x0404]={
  adobename="afii10053",
  category="lu",
  contextname="cyrillicIE",
  description="CYRILLIC CAPITAL LETTER UKRAINIAN IE",
  direction="l",
  lccode=0x0454,
  linebreak="al",
  unicodeslot=0x0404,
 },
 [0x0405]={
  adobename="afii10054",
  category="lu",
  contextname="cyrillicDZE",
  description="CYRILLIC CAPITAL LETTER DZE",
  direction="l",
  lccode=0x0455,
  linebreak="al",
  unicodeslot=0x0405,
 },
 [0x0406]={
  adobename="afii10055",
  category="lu",
  contextname="cyrillicII",
  description="CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I",
  direction="l",
  lccode=0x0456,
  linebreak="al",
  unicodeslot=0x0406,
 },
 [0x0407]={
  adobename="afii10056",
  category="lu",
  contextname="cyrillicYI",
  description="CYRILLIC CAPITAL LETTER YI",
  direction="l",
  lccode=0x0457,
  linebreak="al",
  specials={ "char", 0x0406, 0x0308 },
  unicodeslot=0x0407,
 },
 [0x0408]={
  adobename="afii10057",
  category="lu",
  contextname="cyrillicJE",
  description="CYRILLIC CAPITAL LETTER JE",
  direction="l",
  lccode=0x0458,
  linebreak="al",
  unicodeslot=0x0408,
 },
 [0x0409]={
  adobename="afii10058",
  category="lu",
  contextname="cyrillicLJE",
  description="CYRILLIC CAPITAL LETTER LJE",
  direction="l",
  lccode=0x0459,
  linebreak="al",
  unicodeslot=0x0409,
 },
 [0x040A]={
  adobename="afii10059",
  category="lu",
  contextname="cyrillicNJE",
  description="CYRILLIC CAPITAL LETTER NJE",
  direction="l",
  lccode=0x045A,
  linebreak="al",
  unicodeslot=0x040A,
 },
 [0x040B]={
  adobename="afii10060",
  category="lu",
  contextname="cyrillicTSHE",
  description="CYRILLIC CAPITAL LETTER TSHE",
  direction="l",
  lccode=0x045B,
  linebreak="al",
  unicodeslot=0x040B,
 },
 [0x040C]={
  adobename="afii10061",
  category="lu",
  contextname="cyrillicKJE",
  description="CYRILLIC CAPITAL LETTER KJE",
  direction="l",
  lccode=0x045C,
  linebreak="al",
  specials={ "char", 0x041A, 0x0301 },
  unicodeslot=0x040C,
 },
 [0x040D]={
  category="lu",
  contextname="cyrillicIgrave",
  description="CYRILLIC CAPITAL LETTER I WITH GRAVE",
  direction="l",
  lccode=0x045D,
  linebreak="al",
  shcode=0x0418,
  specials={ "char", 0x0418, 0x0300 },
  unicodeslot=0x040D,
 },
 [0x040E]={
  adobename="afii10062",
  category="lu",
  contextname="cyrillicUSHRT",
  description="CYRILLIC CAPITAL LETTER SHORT U",
  direction="l",
  lccode=0x045E,
  linebreak="al",
  specials={ "char", 0x0423, 0x0306 },
  unicodeslot=0x040E,
 },
 [0x040F]={
  adobename="afii10145",
  category="lu",
  contextname="cyrillicDZHE",
  description="CYRILLIC CAPITAL LETTER DZHE",
  direction="l",
  lccode=0x045F,
  linebreak="al",
  unicodeslot=0x040F,
 },
 [0x0410]={
  adobename="afii10017",
  category="lu",
  cjkwd="a",
  contextname="cyrillicA",
  description="CYRILLIC CAPITAL LETTER A",
  direction="l",
  lccode=0x0430,
  linebreak="al",
  unicodeslot=0x0410,
 },
 [0x0411]={
  adobename="afii10018",
  category="lu",
  cjkwd="a",
  contextname="cyrillicB",
  description="CYRILLIC CAPITAL LETTER BE",
  direction="l",
  lccode=0x0431,
  linebreak="al",
  unicodeslot=0x0411,
 },
 [0x0412]={
  adobename="afii10019",
  category="lu",
  cjkwd="a",
  contextname="cyrillicV",
  description="CYRILLIC CAPITAL LETTER VE",
  direction="l",
  lccode=0x0432,
  linebreak="al",
  unicodeslot=0x0412,
 },
 [0x0413]={
  adobename="afii10020",
  category="lu",
  cjkwd="a",
  contextname="cyrillicG",
  description="CYRILLIC CAPITAL LETTER GHE",
  direction="l",
  lccode=0x0433,
  linebreak="al",
  unicodeslot=0x0413,
 },
 [0x0414]={
  adobename="afii10021",
  category="lu",
  cjkwd="a",
  contextname="cyrillicD",
  description="CYRILLIC CAPITAL LETTER DE",
  direction="l",
  lccode=0x0434,
  linebreak="al",
  unicodeslot=0x0414,
 },
 [0x0415]={
  adobename="afii10022",
  category="lu",
  cjkwd="a",
  contextname="cyrillicE",
  description="CYRILLIC CAPITAL LETTER IE",
  direction="l",
  lccode=0x0435,
  linebreak="al",
  unicodeslot=0x0415,
 },
 [0x0416]={
  adobename="afii10024",
  category="lu",
  cjkwd="a",
  contextname="cyrillicZH",
  description="CYRILLIC CAPITAL LETTER ZHE",
  direction="l",
  lccode=0x0436,
  linebreak="al",
  unicodeslot=0x0416,
 },
 [0x0417]={
  adobename="afii10025",
  category="lu",
  cjkwd="a",
  contextname="cyrillicZ",
  description="CYRILLIC CAPITAL LETTER ZE",
  direction="l",
  lccode=0x0437,
  linebreak="al",
  unicodeslot=0x0417,
 },
 [0x0418]={
  adobename="afii10026",
  category="lu",
  cjkwd="a",
  contextname="cyrillicI",
  description="CYRILLIC CAPITAL LETTER I",
  direction="l",
  lccode=0x0438,
  linebreak="al",
  unicodeslot=0x0418,
 },
 [0x0419]={
  adobename="afii10027",
  category="lu",
  cjkwd="a",
  contextname="cyrillicISHRT",
  description="CYRILLIC CAPITAL LETTER SHORT I",
  direction="l",
  lccode=0x0439,
  linebreak="al",
  specials={ "char", 0x0418, 0x0306 },
  unicodeslot=0x0419,
 },
 [0x041A]={
  adobename="afii10028",
  category="lu",
  cjkwd="a",
  contextname="cyrillicK",
  description="CYRILLIC CAPITAL LETTER KA",
  direction="l",
  lccode=0x043A,
  linebreak="al",
  unicodeslot=0x041A,
 },
 [0x041B]={
  adobename="afii10029",
  category="lu",
  cjkwd="a",
  contextname="cyrillicL",
  description="CYRILLIC CAPITAL LETTER EL",
  direction="l",
  lccode=0x043B,
  linebreak="al",
  unicodeslot=0x041B,
 },
 [0x041C]={
  adobename="afii10030",
  category="lu",
  cjkwd="a",
  contextname="cyrillicM",
  description="CYRILLIC CAPITAL LETTER EM",
  direction="l",
  lccode=0x043C,
  linebreak="al",
  unicodeslot=0x041C,
 },
 [0x041D]={
  adobename="afii10031",
  category="lu",
  cjkwd="a",
  contextname="cyrillicN",
  description="CYRILLIC CAPITAL LETTER EN",
  direction="l",
  lccode=0x043D,
  linebreak="al",
  unicodeslot=0x041D,
 },
 [0x041E]={
  adobename="afii10032",
  category="lu",
  cjkwd="a",
  contextname="cyrillicO",
  description="CYRILLIC CAPITAL LETTER O",
  direction="l",
  lccode=0x043E,
  linebreak="al",
  unicodeslot=0x041E,
 },
 [0x041F]={
  adobename="afii10033",
  category="lu",
  cjkwd="a",
  contextname="cyrillicP",
  description="CYRILLIC CAPITAL LETTER PE",
  direction="l",
  lccode=0x043F,
  linebreak="al",
  unicodeslot=0x041F,
 },
 [0x0420]={
  adobename="afii10034",
  category="lu",
  cjkwd="a",
  contextname="cyrillicR",
  description="CYRILLIC CAPITAL LETTER ER",
  direction="l",
  lccode=0x0440,
  linebreak="al",
  unicodeslot=0x0420,
 },
 [0x0421]={
  adobename="afii10035",
  category="lu",
  cjkwd="a",
  contextname="cyrillicS",
  description="CYRILLIC CAPITAL LETTER ES",
  direction="l",
  lccode=0x0441,
  linebreak="al",
  unicodeslot=0x0421,
 },
 [0x0422]={
  adobename="afii10036",
  category="lu",
  cjkwd="a",
  contextname="cyrillicT",
  description="CYRILLIC CAPITAL LETTER TE",
  direction="l",
  lccode=0x0442,
  linebreak="al",
  unicodeslot=0x0422,
 },
 [0x0423]={
  adobename="afii10037",
  category="lu",
  cjkwd="a",
  contextname="cyrillicU",
  description="CYRILLIC CAPITAL LETTER U",
  direction="l",
  lccode=0x0443,
  linebreak="al",
  unicodeslot=0x0423,
 },
 [0x0424]={
  adobename="afii10038",
  category="lu",
  cjkwd="a",
  contextname="cyrillicF",
  description="CYRILLIC CAPITAL LETTER EF",
  direction="l",
  lccode=0x0444,
  linebreak="al",
  unicodeslot=0x0424,
 },
 [0x0425]={
  adobename="afii10039",
  category="lu",
  cjkwd="a",
  contextname="cyrillicH",
  description="CYRILLIC CAPITAL LETTER HA",
  direction="l",
  lccode=0x0445,
  linebreak="al",
  unicodeslot=0x0425,
 },
 [0x0426]={
  adobename="afii10040",
  category="lu",
  cjkwd="a",
  contextname="cyrillicC",
  description="CYRILLIC CAPITAL LETTER TSE",
  direction="l",
  lccode=0x0446,
  linebreak="al",
  unicodeslot=0x0426,
 },
 [0x0427]={
  adobename="afii10041",
  category="lu",
  cjkwd="a",
  contextname="cyrillicCH",
  description="CYRILLIC CAPITAL LETTER CHE",
  direction="l",
  lccode=0x0447,
  linebreak="al",
  unicodeslot=0x0427,
 },
 [0x0428]={
  adobename="afii10042",
  category="lu",
  cjkwd="a",
  contextname="cyrillicSH",
  description="CYRILLIC CAPITAL LETTER SHA",
  direction="l",
  lccode=0x0448,
  linebreak="al",
  unicodeslot=0x0428,
 },
 [0x0429]={
  adobename="afii10043",
  category="lu",
  cjkwd="a",
  contextname="cyrillicSHCH",
  description="CYRILLIC CAPITAL LETTER SHCHA",
  direction="l",
  lccode=0x0449,
  linebreak="al",
  unicodeslot=0x0429,
 },
 [0x042A]={
  adobename="afii10044",
  category="lu",
  cjkwd="a",
  contextname="cyrillicHRDSN",
  description="CYRILLIC CAPITAL LETTER HARD SIGN",
  direction="l",
  lccode=0x044A,
  linebreak="al",
  unicodeslot=0x042A,
 },
 [0x042B]={
  adobename="afii10045",
  category="lu",
  cjkwd="a",
  contextname="cyrillicERY",
  description="CYRILLIC CAPITAL LETTER YERU",
  direction="l",
  lccode=0x044B,
  linebreak="al",
  unicodeslot=0x042B,
 },
 [0x042C]={
  adobename="afii10046",
  category="lu",
  cjkwd="a",
  contextname="cyrillicSFTSN",
  description="CYRILLIC CAPITAL LETTER SOFT SIGN",
  direction="l",
  lccode=0x044C,
  linebreak="al",
  unicodeslot=0x042C,
 },
 [0x042D]={
  adobename="afii10047",
  category="lu",
  cjkwd="a",
  contextname="cyrillicEREV",
  description="CYRILLIC CAPITAL LETTER E",
  direction="l",
  lccode=0x044D,
  linebreak="al",
  unicodeslot=0x042D,
 },
 [0x042E]={
  adobename="afii10048",
  category="lu",
  cjkwd="a",
  contextname="cyrillicYU",
  description="CYRILLIC CAPITAL LETTER YU",
  direction="l",
  lccode=0x044E,
  linebreak="al",
  unicodeslot=0x042E,
 },
 [0x042F]={
  adobename="afii10049",
  category="lu",
  cjkwd="a",
  contextname="cyrillicYA",
  description="CYRILLIC CAPITAL LETTER YA",
  direction="l",
  lccode=0x044F,
  linebreak="al",
  unicodeslot=0x042F,
 },
 [0x0430]={
  adobename="afii10065",
  category="ll",
  cjkwd="a",
  contextname="cyrillica",
  description="CYRILLIC SMALL LETTER A",
  direction="l",
  linebreak="al",
  uccode=0x0410,
  unicodeslot=0x0430,
 },
 [0x0431]={
  adobename="becyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicb",
  description="CYRILLIC SMALL LETTER BE",
  direction="l",
  linebreak="al",
  uccode=0x0411,
  unicodeslot=0x0431,
 },
 [0x0432]={
  adobename="vecyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicv",
  description="CYRILLIC SMALL LETTER VE",
  direction="l",
  linebreak="al",
  uccode=0x0412,
  unicodeslot=0x0432,
 },
 [0x0433]={
  adobename="gecyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicg",
  description="CYRILLIC SMALL LETTER GHE",
  direction="l",
  linebreak="al",
  uccode=0x0413,
  unicodeslot=0x0433,
 },
 [0x0434]={
  adobename="decyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicd",
  description="CYRILLIC SMALL LETTER DE",
  direction="l",
  linebreak="al",
  uccode=0x0414,
  unicodeslot=0x0434,
 },
 [0x0435]={
  adobename="iecyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillice",
  description="CYRILLIC SMALL LETTER IE",
  direction="l",
  linebreak="al",
  uccode=0x0415,
  unicodeslot=0x0435,
 },
 [0x0436]={
  adobename="zhecyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrilliczh",
  description="CYRILLIC SMALL LETTER ZHE",
  direction="l",
  linebreak="al",
  uccode=0x0416,
  unicodeslot=0x0436,
 },
 [0x0437]={
  adobename="zecyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicz",
  description="CYRILLIC SMALL LETTER ZE",
  direction="l",
  linebreak="al",
  uccode=0x0417,
  unicodeslot=0x0437,
 },
 [0x0438]={
  adobename="iicyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillici",
  description="CYRILLIC SMALL LETTER I",
  direction="l",
  linebreak="al",
  uccode=0x0418,
  unicodeslot=0x0438,
 },
 [0x0439]={
  adobename="iishortcyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicishrt",
  description="CYRILLIC SMALL LETTER SHORT I",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0438, 0x0306 },
  uccode=0x0419,
  unicodeslot=0x0439,
 },
 [0x043A]={
  adobename="kacyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillick",
  description="CYRILLIC SMALL LETTER KA",
  direction="l",
  linebreak="al",
  uccode=0x041A,
  unicodeslot=0x043A,
 },
 [0x043B]={
  adobename="elcyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicl",
  description="CYRILLIC SMALL LETTER EL",
  direction="l",
  linebreak="al",
  uccode=0x041B,
  unicodeslot=0x043B,
 },
 [0x043C]={
  adobename="emcyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicm",
  description="CYRILLIC SMALL LETTER EM",
  direction="l",
  linebreak="al",
  uccode=0x041C,
  unicodeslot=0x043C,
 },
 [0x043D]={
  adobename="encyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicn",
  description="CYRILLIC SMALL LETTER EN",
  direction="l",
  linebreak="al",
  uccode=0x041D,
  unicodeslot=0x043D,
 },
 [0x043E]={
  adobename="ocyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillico",
  description="CYRILLIC SMALL LETTER O",
  direction="l",
  linebreak="al",
  uccode=0x041E,
  unicodeslot=0x043E,
 },
 [0x043F]={
  adobename="pecyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicp",
  description="CYRILLIC SMALL LETTER PE",
  direction="l",
  linebreak="al",
  uccode=0x041F,
  unicodeslot=0x043F,
 },
 [0x0440]={
  adobename="ercyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicr",
  description="CYRILLIC SMALL LETTER ER",
  direction="l",
  linebreak="al",
  uccode=0x0420,
  unicodeslot=0x0440,
 },
 [0x0441]={
  adobename="escyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillics",
  description="CYRILLIC SMALL LETTER ES",
  direction="l",
  linebreak="al",
  uccode=0x0421,
  unicodeslot=0x0441,
 },
 [0x0442]={
  adobename="tecyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillict",
  description="CYRILLIC SMALL LETTER TE",
  direction="l",
  linebreak="al",
  uccode=0x0422,
  unicodeslot=0x0442,
 },
 [0x0443]={
  adobename="ucyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicu",
  description="CYRILLIC SMALL LETTER U",
  direction="l",
  linebreak="al",
  uccode=0x0423,
  unicodeslot=0x0443,
 },
 [0x0444]={
  adobename="efcyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicf",
  description="CYRILLIC SMALL LETTER EF",
  direction="l",
  linebreak="al",
  uccode=0x0424,
  unicodeslot=0x0444,
 },
 [0x0445]={
  adobename="khacyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillich",
  description="CYRILLIC SMALL LETTER HA",
  direction="l",
  linebreak="al",
  uccode=0x0425,
  unicodeslot=0x0445,
 },
 [0x0446]={
  adobename="tsecyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicc",
  description="CYRILLIC SMALL LETTER TSE",
  direction="l",
  linebreak="al",
  uccode=0x0426,
  unicodeslot=0x0446,
 },
 [0x0447]={
  adobename="checyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicch",
  description="CYRILLIC SMALL LETTER CHE",
  direction="l",
  linebreak="al",
  uccode=0x0427,
  unicodeslot=0x0447,
 },
 [0x0448]={
  adobename="shacyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicsh",
  description="CYRILLIC SMALL LETTER SHA",
  direction="l",
  linebreak="al",
  uccode=0x0428,
  unicodeslot=0x0448,
 },
 [0x0449]={
  adobename="shchacyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicshch",
  description="CYRILLIC SMALL LETTER SHCHA",
  direction="l",
  linebreak="al",
  uccode=0x0429,
  unicodeslot=0x0449,
 },
 [0x044A]={
  adobename="hardsigncyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillichrdsn",
  description="CYRILLIC SMALL LETTER HARD SIGN",
  direction="l",
  linebreak="al",
  uccode=0x042A,
  unicodeslot=0x044A,
 },
 [0x044B]={
  adobename="yericyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicery",
  description="CYRILLIC SMALL LETTER YERU",
  direction="l",
  linebreak="al",
  uccode=0x042B,
  unicodeslot=0x044B,
 },
 [0x044C]={
  adobename="softsigncyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicsftsn",
  description="CYRILLIC SMALL LETTER SOFT SIGN",
  direction="l",
  linebreak="al",
  uccode=0x042C,
  unicodeslot=0x044C,
 },
 [0x044D]={
  adobename="ereversedcyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicerev",
  description="CYRILLIC SMALL LETTER E",
  direction="l",
  linebreak="al",
  uccode=0x042D,
  unicodeslot=0x044D,
 },
 [0x044E]={
  adobename="iucyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicyu",
  description="CYRILLIC SMALL LETTER YU",
  direction="l",
  linebreak="al",
  uccode=0x042E,
  unicodeslot=0x044E,
 },
 [0x044F]={
  adobename="iacyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicya",
  description="CYRILLIC SMALL LETTER YA",
  direction="l",
  linebreak="al",
  uccode=0x042F,
  unicodeslot=0x044F,
 },
 [0x0450]={
  category="ll",
  contextname="cyrillicegrave",
  description="CYRILLIC SMALL LETTER IE WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0435,
  specials={ "char", 0x0435, 0x0300 },
  uccode=0x0400,
  unicodeslot=0x0450,
 },
 [0x0451]={
  adobename="iocyrillic",
  category="ll",
  cjkwd="a",
  contextname="cyrillicyo",
  description="CYRILLIC SMALL LETTER IO",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0435, 0x0308 },
  uccode=0x0401,
  unicodeslot=0x0451,
 },
 [0x0452]={
  adobename="djecyrillic",
  category="ll",
  contextname="cyrillicdje",
  description="CYRILLIC SMALL LETTER DJE",
  direction="l",
  linebreak="al",
  uccode=0x0402,
  unicodeslot=0x0452,
 },
 [0x0453]={
  adobename="gjecyrillic",
  category="ll",
  contextname="cyrillicgje",
  description="CYRILLIC SMALL LETTER GJE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0433, 0x0301 },
  uccode=0x0403,
  unicodeslot=0x0453,
 },
 [0x0454]={
  adobename="ecyrillic",
  category="ll",
  contextname="cyrillicie",
  description="CYRILLIC SMALL LETTER UKRAINIAN IE",
  direction="l",
  linebreak="al",
  uccode=0x0404,
  unicodeslot=0x0454,
 },
 [0x0455]={
  adobename="dzecyrillic",
  category="ll",
  contextname="cyrillicdze",
  description="CYRILLIC SMALL LETTER DZE",
  direction="l",
  linebreak="al",
  uccode=0x0405,
  unicodeslot=0x0455,
 },
 [0x0456]={
  adobename="icyrillic",
  category="ll",
  contextname="cyrillicii",
  description="CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I",
  direction="l",
  linebreak="al",
  uccode=0x0406,
  unicodeslot=0x0456,
 },
 [0x0457]={
  adobename="yicyrillic",
  category="ll",
  contextname="cyrillicyi",
  description="CYRILLIC SMALL LETTER YI",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0456, 0x0308 },
  uccode=0x0407,
  unicodeslot=0x0457,
 },
 [0x0458]={
  adobename="jecyrillic",
  category="ll",
  contextname="cyrillicje",
  description="CYRILLIC SMALL LETTER JE",
  direction="l",
  linebreak="al",
  uccode=0x0408,
  unicodeslot=0x0458,
 },
 [0x0459]={
  adobename="ljecyrillic",
  category="ll",
  contextname="cyrilliclje",
  description="CYRILLIC SMALL LETTER LJE",
  direction="l",
  linebreak="al",
  uccode=0x0409,
  unicodeslot=0x0459,
 },
 [0x045A]={
  adobename="njecyrillic",
  category="ll",
  contextname="cyrillicnje",
  description="CYRILLIC SMALL LETTER NJE",
  direction="l",
  linebreak="al",
  uccode=0x040A,
  unicodeslot=0x045A,
 },
 [0x045B]={
  adobename="tshecyrillic",
  category="ll",
  contextname="cyrillictshe",
  description="CYRILLIC SMALL LETTER TSHE",
  direction="l",
  linebreak="al",
  uccode=0x040B,
  unicodeslot=0x045B,
 },
 [0x045C]={
  adobename="kjecyrillic",
  category="ll",
  contextname="cyrillickje",
  description="CYRILLIC SMALL LETTER KJE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x043A, 0x0301 },
  uccode=0x040C,
  unicodeslot=0x045C,
 },
 [0x045D]={
  category="ll",
  contextname="cyrillicigrave",
  description="CYRILLIC SMALL LETTER I WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0438,
  specials={ "char", 0x0438, 0x0300 },
  uccode=0x040D,
  unicodeslot=0x045D,
 },
 [0x045E]={
  adobename="ushortcyrillic",
  category="ll",
  contextname="cyrillicushrt",
  description="CYRILLIC SMALL LETTER SHORT U",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0443, 0x0306 },
  uccode=0x040E,
  unicodeslot=0x045E,
 },
 [0x045F]={
  adobename="dzhecyrillic",
  category="ll",
  contextname="cyrillicdzhe",
  description="CYRILLIC SMALL LETTER DZHE",
  direction="l",
  linebreak="al",
  uccode=0x040F,
  unicodeslot=0x045F,
 },
 [0x0460]={
  adobename="Omegacyrillic",
  category="lu",
  contextname="cyrillicOMEGA",
  description="CYRILLIC CAPITAL LETTER OMEGA",
  direction="l",
  lccode=0x0461,
  linebreak="al",
  unicodeslot=0x0460,
 },
 [0x0461]={
  adobename="omegacyrillic",
  category="ll",
  contextname="cyrillicomega",
  description="CYRILLIC SMALL LETTER OMEGA",
  direction="l",
  linebreak="al",
  uccode=0x0460,
  unicodeslot=0x0461,
 },
 [0x0462]={
  adobename="afii10146",
  category="lu",
  contextname="cyrillicYAT",
  description="CYRILLIC CAPITAL LETTER YAT",
  direction="l",
  lccode=0x0463,
  linebreak="al",
  unicodeslot=0x0462,
 },
 [0x0463]={
  adobename="yatcyrillic",
  category="ll",
  contextname="cyrillicyat",
  description="CYRILLIC SMALL LETTER YAT",
  direction="l",
  linebreak="al",
  uccode=0x0462,
  unicodeslot=0x0463,
 },
 [0x0464]={
  adobename="Eiotifiedcyrillic",
  category="lu",
  contextname="cyrillicEiotified",
  description="CYRILLIC CAPITAL LETTER IOTIFIED E",
  direction="l",
  lccode=0x0465,
  linebreak="al",
  unicodeslot=0x0464,
 },
 [0x0465]={
  adobename="eiotifiedcyrillic",
  category="ll",
  contextname="cyrilliceiotified",
  description="CYRILLIC SMALL LETTER IOTIFIED E",
  direction="l",
  linebreak="al",
  uccode=0x0464,
  unicodeslot=0x0465,
 },
 [0x0466]={
  adobename="Yuslittlecyrillic",
  category="lu",
  contextname="cyrillicLITTLEYUS",
  description="CYRILLIC CAPITAL LETTER LITTLE YUS",
  direction="l",
  lccode=0x0467,
  linebreak="al",
  unicodeslot=0x0466,
 },
 [0x0467]={
  adobename="yuslittlecyrillic",
  category="ll",
  contextname="cyrilliclittleyus",
  description="CYRILLIC SMALL LETTER LITTLE YUS",
  direction="l",
  linebreak="al",
  uccode=0x0466,
  unicodeslot=0x0467,
 },
 [0x0468]={
  adobename="Yuslittleiotifiedcyrillic",
  category="lu",
  contextname="cyrillicLITTLEYUSiotified",
  description="CYRILLIC CAPITAL LETTER IOTIFIED LITTLE YUS",
  direction="l",
  lccode=0x0469,
  linebreak="al",
  unicodeslot=0x0468,
 },
 [0x0469]={
  adobename="yuslittleiotifiedcyrillic",
  category="ll",
  contextname="cyrilliclittleyusiotified",
  description="CYRILLIC SMALL LETTER IOTIFIED LITTLE YUS",
  direction="l",
  linebreak="al",
  uccode=0x0468,
  unicodeslot=0x0469,
 },
 [0x046A]={
  adobename="Yusbigcyrillic",
  category="lu",
  contextname="cyrillicBIGYUS",
  description="CYRILLIC CAPITAL LETTER BIG YUS",
  direction="l",
  lccode=0x046B,
  linebreak="al",
  unicodeslot=0x046A,
 },
 [0x046B]={
  adobename="yusbigcyrillic",
  category="ll",
  contextname="cyrillicbigyus",
  description="CYRILLIC SMALL LETTER BIG YUS",
  direction="l",
  linebreak="al",
  uccode=0x046A,
  unicodeslot=0x046B,
 },
 [0x046C]={
  adobename="Yusbigiotifiedcyrillic",
  category="lu",
  contextname="cyrillicBIGYUSiotified",
  description="CYRILLIC CAPITAL LETTER IOTIFIED BIG YUS",
  direction="l",
  lccode=0x046D,
  linebreak="al",
  unicodeslot=0x046C,
 },
 [0x046D]={
  adobename="yusbigiotifiedcyrillic",
  category="ll",
  contextname="cyrillicbigyusiotified",
  description="CYRILLIC SMALL LETTER IOTIFIED BIG YUS",
  direction="l",
  linebreak="al",
  uccode=0x046C,
  unicodeslot=0x046D,
 },
 [0x046E]={
  adobename="Ksicyrillic",
  category="lu",
  contextname="cyrillicKSI",
  description="CYRILLIC CAPITAL LETTER KSI",
  direction="l",
  lccode=0x046F,
  linebreak="al",
  unicodeslot=0x046E,
 },
 [0x046F]={
  adobename="ksicyrillic",
  category="ll",
  contextname="cyrillicksi",
  description="CYRILLIC SMALL LETTER KSI",
  direction="l",
  linebreak="al",
  uccode=0x046E,
  unicodeslot=0x046F,
 },
 [0x0470]={
  adobename="Psicyrillic",
  category="lu",
  contextname="cyrillicPSI",
  description="CYRILLIC CAPITAL LETTER PSI",
  direction="l",
  lccode=0x0471,
  linebreak="al",
  unicodeslot=0x0470,
 },
 [0x0471]={
  adobename="psicyrillic",
  category="ll",
  contextname="cyrillicpsi",
  description="CYRILLIC SMALL LETTER PSI",
  direction="l",
  linebreak="al",
  uccode=0x0470,
  unicodeslot=0x0471,
 },
 [0x0472]={
  adobename="afii10147",
  category="lu",
  contextname="cyrillicFITA",
  description="CYRILLIC CAPITAL LETTER FITA",
  direction="l",
  lccode=0x0473,
  linebreak="al",
  unicodeslot=0x0472,
 },
 [0x0473]={
  adobename="fitacyrillic",
  category="ll",
  contextname="cyrillicfita",
  description="CYRILLIC SMALL LETTER FITA",
  direction="l",
  linebreak="al",
  uccode=0x0472,
  unicodeslot=0x0473,
 },
 [0x0474]={
  adobename="afii10148",
  category="lu",
  contextname="cyrillicIZHITSA",
  description="CYRILLIC CAPITAL LETTER IZHITSA",
  direction="l",
  lccode=0x0475,
  linebreak="al",
  unicodeslot=0x0474,
 },
 [0x0475]={
  adobename="izhitsacyrillic",
  category="ll",
  contextname="cyrillicizhitsa",
  description="CYRILLIC SMALL LETTER IZHITSA",
  direction="l",
  linebreak="al",
  uccode=0x0474,
  unicodeslot=0x0475,
 },
 [0x0476]={
  adobename="Izhitsadblgravecyrillic",
  category="lu",
  contextname="cyrillicIZHITSAdoublegrave",
  description="CYRILLIC CAPITAL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT",
  direction="l",
  lccode=0x0477,
  linebreak="al",
  shcode=0x0474,
  specials={ "char", 0x0474, 0x030F },
  unicodeslot=0x0476,
 },
 [0x0477]={
  adobename="izhitsadblgravecyrillic",
  category="ll",
  contextname="cyrillicizhitsadoublegrave",
  description="CYRILLIC SMALL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT",
  direction="l",
  linebreak="al",
  shcode=0x0475,
  specials={ "char", 0x0475, 0x030F },
  uccode=0x0476,
  unicodeslot=0x0477,
 },
 [0x0478]={
  adobename="Ukcyrillic",
  category="lu",
  contextname="cyrillicUK",
  description="CYRILLIC CAPITAL LETTER UK",
  direction="l",
  lccode=0x0479,
  linebreak="al",
  unicodeslot=0x0478,
 },
 [0x0479]={
  adobename="ukcyrillic",
  category="ll",
  contextname="cyrillicuk",
  description="CYRILLIC SMALL LETTER UK",
  direction="l",
  linebreak="al",
  uccode=0x0478,
  unicodeslot=0x0479,
 },
 [0x047A]={
  adobename="Omegaroundcyrillic",
  category="lu",
  contextname="cyrillicOMEGAround",
  description="CYRILLIC CAPITAL LETTER ROUND OMEGA",
  direction="l",
  lccode=0x047B,
  linebreak="al",
  unicodeslot=0x047A,
 },
 [0x047B]={
  adobename="omegaroundcyrillic",
  category="ll",
  contextname="cyrillicomegaround",
  description="CYRILLIC SMALL LETTER ROUND OMEGA",
  direction="l",
  linebreak="al",
  uccode=0x047A,
  unicodeslot=0x047B,
 },
 [0x047C]={
  adobename="Omegatitlocyrillic",
  category="lu",
  contextname="cyrillicOMEGAtitlo",
  description="CYRILLIC CAPITAL LETTER OMEGA WITH TITLO",
  direction="l",
  lccode=0x047D,
  linebreak="al",
  shcode=0x0460,
  unicodeslot=0x047C,
 },
 [0x047D]={
  adobename="omegatitlocyrillic",
  category="ll",
  contextname="cyrillicomegatitlo",
  description="CYRILLIC SMALL LETTER OMEGA WITH TITLO",
  direction="l",
  linebreak="al",
  shcode=0x0461,
  uccode=0x047C,
  unicodeslot=0x047D,
 },
 [0x047E]={
  adobename="Otcyrillic",
  category="lu",
  contextname="cyrillicOT",
  description="CYRILLIC CAPITAL LETTER OT",
  direction="l",
  lccode=0x047F,
  linebreak="al",
  unicodeslot=0x047E,
 },
 [0x047F]={
  adobename="otcyrillic",
  category="ll",
  contextname="cyrillicot",
  description="CYRILLIC SMALL LETTER OT",
  direction="l",
  linebreak="al",
  uccode=0x047E,
  unicodeslot=0x047F,
 },
 [0x0480]={
  adobename="Koppacyrillic",
  category="lu",
  contextname="cyrillicKOPPA",
  description="CYRILLIC CAPITAL LETTER KOPPA",
  direction="l",
  lccode=0x0481,
  linebreak="al",
  unicodeslot=0x0480,
 },
 [0x0481]={
  adobename="koppacyrillic",
  category="ll",
  contextname="cyrillickoppa",
  description="CYRILLIC SMALL LETTER KOPPA",
  direction="l",
  linebreak="al",
  uccode=0x0480,
  unicodeslot=0x0481,
 },
 [0x0482]={
  adobename="thousandcyrillic",
  category="so",
  description="CYRILLIC THOUSANDS SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0482,
 },
 [0x0483]={
  adobename="titlocyrilliccmb",
  category="mn",
  contextname="cyrillicTITLO",
  description="COMBINING CYRILLIC TITLO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0483,
 },
 [0x0484]={
  adobename="palatalizationcyrilliccmb",
  category="mn",
  contextname="cyrillicPALATALIZATION",
  description="COMBINING CYRILLIC PALATALIZATION",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0484,
 },
 [0x0485]={
  adobename="dasiapneumatacyrilliccmb",
  category="mn",
  contextname="cyrillicDASIAPNEUMATA",
  description="COMBINING CYRILLIC DASIA PNEUMATA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0485,
 },
 [0x0486]={
  adobename="psilipneumatacyrilliccmb",
  category="mn",
  contextname="cyrillicPSILIPNEUMATA",
  description="COMBINING CYRILLIC PSILI PNEUMATA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0486,
 },
 [0x0487]={
  category="mn",
  description="COMBINING CYRILLIC POKRYTIE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0487,
 },
 [0x0488]={
  category="me",
  description="COMBINING CYRILLIC HUNDRED THOUSANDS SIGN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0488,
 },
 [0x0489]={
  category="me",
  description="COMBINING CYRILLIC MILLIONS SIGN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0489,
 },
 [0x048A]={
  category="lu",
  contextname="cyrillicISHRTtail",
  description="CYRILLIC CAPITAL LETTER SHORT I WITH TAIL",
  direction="l",
  lccode=0x048B,
  linebreak="al",
  unicodeslot=0x048A,
 },
 [0x048B]={
  category="ll",
  contextname="cyrillicishrttail",
  description="CYRILLIC SMALL LETTER SHORT I WITH TAIL",
  direction="l",
  linebreak="al",
  uccode=0x048A,
  unicodeslot=0x048B,
 },
 [0x048C]={
  category="lu",
  contextname="cyrillicSEMISOFT",
  description="CYRILLIC CAPITAL LETTER SEMISOFT SIGN",
  direction="l",
  lccode=0x048D,
  linebreak="al",
  unicodeslot=0x048C,
 },
 [0x048D]={
  category="ll",
  contextname="cyrillicsemisoft",
  description="CYRILLIC SMALL LETTER SEMISOFT SIGN",
  direction="l",
  linebreak="al",
  uccode=0x048C,
  unicodeslot=0x048D,
 },
 [0x048E]={
  category="lu",
  contextname="cyrillicERtick",
  description="CYRILLIC CAPITAL LETTER ER WITH TICK",
  direction="l",
  lccode=0x048F,
  linebreak="al",
  shcode=0x0420,
  unicodeslot=0x048E,
 },
 [0x048F]={
  category="ll",
  contextname="cyrillicertick",
  description="CYRILLIC SMALL LETTER ER WITH TICK",
  direction="l",
  linebreak="al",
  shcode=0x0440,
  uccode=0x048E,
  unicodeslot=0x048F,
 },
 [0x0490]={
  adobename="afii10050",
  category="lu",
  contextname="cyrillicGHEupturn",
  description="CYRILLIC CAPITAL LETTER GHE WITH UPTURN",
  direction="l",
  lccode=0x0491,
  linebreak="al",
  shcode=0x0413,
  unicodeslot=0x0490,
 },
 [0x0491]={
  adobename="gheupturncyrillic",
  category="ll",
  contextname="cyrillicgheupturn",
  description="CYRILLIC SMALL LETTER GHE WITH UPTURN",
  direction="l",
  linebreak="al",
  shcode=0x0433,
  uccode=0x0490,
  unicodeslot=0x0491,
 },
 [0x0492]={
  adobename="Ghestrokecyrillic",
  category="lu",
  contextname="cyrillicGHEstroke",
  description="CYRILLIC CAPITAL LETTER GHE WITH STROKE",
  direction="l",
  lccode=0x0493,
  linebreak="al",
  shcode=0x0413,
  unicodeslot=0x0492,
 },
 [0x0493]={
  adobename="ghestrokecyrillic",
  category="ll",
  contextname="cyrillicghestroke",
  description="CYRILLIC SMALL LETTER GHE WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0433,
  uccode=0x0492,
  unicodeslot=0x0493,
 },
 [0x0494]={
  adobename="Ghemiddlehookcyrillic",
  category="lu",
  contextname="cyrillicGHEmidhook",
  description="CYRILLIC CAPITAL LETTER GHE WITH MIDDLE HOOK",
  direction="l",
  lccode=0x0495,
  linebreak="al",
  shcode=0x0413,
  unicodeslot=0x0494,
 },
 [0x0495]={
  adobename="ghemiddlehookcyrillic",
  category="ll",
  contextname="cyrillicghemidhook",
  description="CYRILLIC SMALL LETTER GHE WITH MIDDLE HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0433,
  uccode=0x0494,
  unicodeslot=0x0495,
 },
 [0x0496]={
  adobename="Zhedescendercyrillic",
  category="lu",
  contextname="cyrillicZHEdescender",
  description="CYRILLIC CAPITAL LETTER ZHE WITH DESCENDER",
  direction="l",
  lccode=0x0497,
  linebreak="al",
  shcode=0x0416,
  unicodeslot=0x0496,
 },
 [0x0497]={
  adobename="zhedescendercyrillic",
  category="ll",
  contextname="cyrilliczhedescender",
  description="CYRILLIC SMALL LETTER ZHE WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x0436,
  uccode=0x0496,
  unicodeslot=0x0497,
 },
 [0x0498]={
  adobename="Zedescendercyrillic",
  category="lu",
  contextname="cyrillicZDSC",
  description="CYRILLIC CAPITAL LETTER ZE WITH DESCENDER",
  direction="l",
  lccode=0x0499,
  linebreak="al",
  shcode=0x0417,
  unicodeslot=0x0498,
 },
 [0x0499]={
  adobename="zedescendercyrillic",
  category="ll",
  contextname="cyrilliczdsc",
  description="CYRILLIC SMALL LETTER ZE WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x0437,
  uccode=0x0498,
  unicodeslot=0x0499,
 },
 [0x049A]={
  adobename="Kadescendercyrillic",
  category="lu",
  contextname="cyrillicKADC",
  description="CYRILLIC CAPITAL LETTER KA WITH DESCENDER",
  direction="l",
  lccode=0x049B,
  linebreak="al",
  shcode=0x041A,
  unicodeslot=0x049A,
 },
 [0x049B]={
  adobename="kadescendercyrillic",
  category="ll",
  contextname="cyrillickadc",
  description="CYRILLIC SMALL LETTER KA WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x043A,
  uccode=0x049A,
  unicodeslot=0x049B,
 },
 [0x049C]={
  adobename="Kaverticalstrokecyrillic",
  category="lu",
  contextname="cyrillicKAvertstroke",
  description="CYRILLIC CAPITAL LETTER KA WITH VERTICAL STROKE",
  direction="l",
  lccode=0x049D,
  linebreak="al",
  shcode=0x041A,
  unicodeslot=0x049C,
 },
 [0x049D]={
  adobename="kaverticalstrokecyrillic",
  category="ll",
  contextname="cyrillickavertstroke",
  description="CYRILLIC SMALL LETTER KA WITH VERTICAL STROKE",
  direction="l",
  linebreak="al",
  shcode=0x043A,
  uccode=0x049C,
  unicodeslot=0x049D,
 },
 [0x049E]={
  adobename="Kastrokecyrillic",
  category="lu",
  contextname="cyrillicKAstroke",
  description="CYRILLIC CAPITAL LETTER KA WITH STROKE",
  direction="l",
  lccode=0x049F,
  linebreak="al",
  shcode=0x041A,
  unicodeslot=0x049E,
 },
 [0x049F]={
  adobename="kastrokecyrillic",
  category="ll",
  contextname="cyrillickastroke",
  description="CYRILLIC SMALL LETTER KA WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x043A,
  uccode=0x049E,
  unicodeslot=0x049F,
 },
 [0x04A0]={
  adobename="Kabashkircyrillic",
  category="lu",
  contextname="cyrillicKAbashkir",
  description="CYRILLIC CAPITAL LETTER BASHKIR KA",
  direction="l",
  lccode=0x04A1,
  linebreak="al",
  unicodeslot=0x04A0,
 },
 [0x04A1]={
  adobename="kabashkircyrillic",
  category="ll",
  contextname="cyrillickabashkir",
  description="CYRILLIC SMALL LETTER BASHKIR KA",
  direction="l",
  linebreak="al",
  uccode=0x04A0,
  unicodeslot=0x04A1,
 },
 [0x04A2]={
  adobename="Endescendercyrillic",
  category="lu",
  contextname="cyrillicENDC",
  description="CYRILLIC CAPITAL LETTER EN WITH DESCENDER",
  direction="l",
  lccode=0x04A3,
  linebreak="al",
  shcode=0x041D,
  unicodeslot=0x04A2,
 },
 [0x04A3]={
  adobename="endescendercyrillic",
  category="ll",
  contextname="cyrillicendc",
  description="CYRILLIC SMALL LETTER EN WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x043D,
  uccode=0x04A2,
  unicodeslot=0x04A3,
 },
 [0x04A4]={
  adobename="Enghecyrillic",
  category="lu",
  contextname="cyrillicENGHE",
  description="CYRILLIC CAPITAL LIGATURE EN GHE",
  direction="l",
  lccode=0x04A5,
  linebreak="al",
  unicodeslot=0x04A4,
 },
 [0x04A5]={
  adobename="enghecyrillic",
  category="ll",
  contextname="cyrillicenghe",
  description="CYRILLIC SMALL LIGATURE EN GHE",
  direction="l",
  linebreak="al",
  uccode=0x04A4,
  unicodeslot=0x04A5,
 },
 [0x04A6]={
  adobename="Pemiddlehookcyrillic",
  category="lu",
  contextname="cyrillicPEmidhook",
  description="CYRILLIC CAPITAL LETTER PE WITH MIDDLE HOOK",
  direction="l",
  lccode=0x04A7,
  linebreak="al",
  shcode=0x041F,
  unicodeslot=0x04A6,
 },
 [0x04A7]={
  adobename="pemiddlehookcyrillic",
  category="ll",
  contextname="cyrillicpemidhook",
  description="CYRILLIC SMALL LETTER PE WITH MIDDLE HOOK",
  direction="l",
  linebreak="al",
  shcode=0x043F,
  uccode=0x04A6,
  unicodeslot=0x04A7,
 },
 [0x04A8]={
  adobename="Haabkhasiancyrillic",
  category="lu",
  contextname="cyrillicHA",
  description="CYRILLIC CAPITAL LETTER ABKHASIAN HA",
  direction="l",
  lccode=0x04A9,
  linebreak="al",
  unicodeslot=0x04A8,
 },
 [0x04A9]={
  adobename="haabkhasiancyrillic",
  category="ll",
  contextname="cyrillicha",
  description="CYRILLIC SMALL LETTER ABKHASIAN HA",
  direction="l",
  linebreak="al",
  uccode=0x04A8,
  unicodeslot=0x04A9,
 },
 [0x04AA]={
  adobename="Esdescendercyrillic",
  category="lu",
  contextname="cyrillicSDSC",
  description="CYRILLIC CAPITAL LETTER ES WITH DESCENDER",
  direction="l",
  lccode=0x04AB,
  linebreak="al",
  shcode=0x0421,
  unicodeslot=0x04AA,
 },
 [0x04AB]={
  adobename="esdescendercyrillic",
  category="ll",
  contextname="cyrillicsdsc",
  description="CYRILLIC SMALL LETTER ES WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x0441,
  uccode=0x04AA,
  unicodeslot=0x04AB,
 },
 [0x04AC]={
  adobename="Tedescendercyrillic",
  category="lu",
  contextname="cyrillicTEDC",
  description="CYRILLIC CAPITAL LETTER TE WITH DESCENDER",
  direction="l",
  lccode=0x04AD,
  linebreak="al",
  shcode=0x0422,
  unicodeslot=0x04AC,
 },
 [0x04AD]={
  adobename="tedescendercyrillic",
  category="ll",
  contextname="cyrillictedc",
  description="CYRILLIC SMALL LETTER TE WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x0442,
  uccode=0x04AC,
  unicodeslot=0x04AD,
 },
 [0x04AE]={
  adobename="Ustraightcyrillic",
  category="lu",
  contextname="cyrillicYstr",
  description="CYRILLIC CAPITAL LETTER STRAIGHT U",
  direction="l",
  lccode=0x04AF,
  linebreak="al",
  unicodeslot=0x04AE,
 },
 [0x04AF]={
  adobename="ustraightcyrillic",
  category="ll",
  contextname="cyrillicystr",
  description="CYRILLIC SMALL LETTER STRAIGHT U",
  direction="l",
  linebreak="al",
  uccode=0x04AE,
  unicodeslot=0x04AF,
 },
 [0x04B0]={
  adobename="Ustraightstrokecyrillic",
  category="lu",
  contextname="cyrillicYstrstroke",
  description="CYRILLIC CAPITAL LETTER STRAIGHT U WITH STROKE",
  direction="l",
  lccode=0x04B1,
  linebreak="al",
  unicodeslot=0x04B0,
 },
 [0x04B1]={
  adobename="ustraightstrokecyrillic",
  category="ll",
  contextname="cyrillicystrstroke",
  description="CYRILLIC SMALL LETTER STRAIGHT U WITH STROKE",
  direction="l",
  linebreak="al",
  uccode=0x04B0,
  unicodeslot=0x04B1,
 },
 [0x04B2]={
  adobename="Hadescendercyrillic",
  category="lu",
  contextname="cyrillicHADC",
  description="CYRILLIC CAPITAL LETTER HA WITH DESCENDER",
  direction="l",
  lccode=0x04B3,
  linebreak="al",
  shcode=0x0425,
  unicodeslot=0x04B2,
 },
 [0x04B3]={
  adobename="hadescendercyrillic",
  category="ll",
  contextname="cyrillichadc",
  description="CYRILLIC SMALL LETTER HA WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x0445,
  uccode=0x04B2,
  unicodeslot=0x04B3,
 },
 [0x04B4]={
  adobename="Tetsecyrillic",
  category="lu",
  contextname="cyrillicTETSE",
  description="CYRILLIC CAPITAL LIGATURE TE TSE",
  direction="l",
  lccode=0x04B5,
  linebreak="al",
  unicodeslot=0x04B4,
 },
 [0x04B5]={
  adobename="tetsecyrillic",
  category="ll",
  contextname="cyrillictetse",
  description="CYRILLIC SMALL LIGATURE TE TSE",
  direction="l",
  linebreak="al",
  uccode=0x04B4,
  unicodeslot=0x04B5,
 },
 [0x04B6]={
  adobename="Chedescendercyrillic",
  category="lu",
  contextname="cyrillicCHEDC",
  description="CYRILLIC CAPITAL LETTER CHE WITH DESCENDER",
  direction="l",
  lccode=0x04B7,
  linebreak="al",
  shcode=0x0427,
  unicodeslot=0x04B6,
 },
 [0x04B7]={
  adobename="chedescendercyrillic",
  category="ll",
  contextname="cyrillicchedc",
  description="CYRILLIC SMALL LETTER CHE WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x0447,
  uccode=0x04B6,
  unicodeslot=0x04B7,
 },
 [0x04B8]={
  adobename="Cheverticalstrokecyrillic",
  category="lu",
  contextname="cyrillicCHEvertstroke",
  description="CYRILLIC CAPITAL LETTER CHE WITH VERTICAL STROKE",
  direction="l",
  lccode=0x04B9,
  linebreak="al",
  shcode=0x0427,
  unicodeslot=0x04B8,
 },
 [0x04B9]={
  adobename="cheverticalstrokecyrillic",
  category="ll",
  contextname="cyrillicchevertstroke",
  description="CYRILLIC SMALL LETTER CHE WITH VERTICAL STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0447,
  uccode=0x04B8,
  unicodeslot=0x04B9,
 },
 [0x04BA]={
  adobename="Shhacyrillic",
  category="lu",
  contextname="cyrillicSHHA",
  description="CYRILLIC CAPITAL LETTER SHHA",
  direction="l",
  lccode=0x04BB,
  linebreak="al",
  unicodeslot=0x04BA,
 },
 [0x04BB]={
  adobename="shhacyrillic",
  category="ll",
  contextname="cyrillicshha",
  description="CYRILLIC SMALL LETTER SHHA",
  direction="l",
  linebreak="al",
  uccode=0x04BA,
  unicodeslot=0x04BB,
 },
 [0x04BC]={
  adobename="Cheabkhasiancyrillic",
  category="lu",
  contextname="cyrillicCHEabkhasian",
  description="CYRILLIC CAPITAL LETTER ABKHASIAN CHE",
  direction="l",
  lccode=0x04BD,
  linebreak="al",
  unicodeslot=0x04BC,
 },
 [0x04BD]={
  adobename="cheabkhasiancyrillic",
  category="ll",
  contextname="cyrilliccheabkhasian",
  description="CYRILLIC SMALL LETTER ABKHASIAN CHE",
  direction="l",
  linebreak="al",
  uccode=0x04BC,
  unicodeslot=0x04BD,
 },
 [0x04BE]={
  adobename="Chedescenderabkhasiancyrillic",
  category="lu",
  contextname="cyrillicCHEDCabkhasian",
  description="CYRILLIC CAPITAL LETTER ABKHASIAN CHE WITH DESCENDER",
  direction="l",
  lccode=0x04BF,
  linebreak="al",
  unicodeslot=0x04BE,
 },
 [0x04BF]={
  adobename="chedescenderabkhasiancyrillic",
  category="ll",
  contextname="cyrillicchedcabkhasian",
  description="CYRILLIC SMALL LETTER ABKHASIAN CHE WITH DESCENDER",
  direction="l",
  linebreak="al",
  uccode=0x04BE,
  unicodeslot=0x04BF,
 },
 [0x04C0]={
  adobename="palochkacyrillic",
  category="lu",
  contextname="cyrillicPALOCHKA",
  description="CYRILLIC LETTER PALOCHKA",
  direction="l",
  lccode=0x04CF,
  linebreak="al",
  unicodeslot=0x04C0,
 },
 [0x04C1]={
  adobename="Zhebrevecyrillic",
  category="lu",
  contextname="cyrillicZHEbreve",
  description="CYRILLIC CAPITAL LETTER ZHE WITH BREVE",
  direction="l",
  lccode=0x04C2,
  linebreak="al",
  shcode=0x0416,
  specials={ "char", 0x0416, 0x0306 },
  unicodeslot=0x04C1,
 },
 [0x04C2]={
  adobename="zhebrevecyrillic",
  category="ll",
  contextname="cyrilliczhebreve",
  description="CYRILLIC SMALL LETTER ZHE WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0436,
  specials={ "char", 0x0436, 0x0306 },
  uccode=0x04C1,
  unicodeslot=0x04C2,
 },
 [0x04C3]={
  adobename="Kahookcyrillic",
  category="lu",
  contextname="cyrillicKAhook",
  description="CYRILLIC CAPITAL LETTER KA WITH HOOK",
  direction="l",
  lccode=0x04C4,
  linebreak="al",
  shcode=0x041A,
  unicodeslot=0x04C3,
 },
 [0x04C4]={
  adobename="kahookcyrillic",
  category="ll",
  contextname="cyrillickahook",
  description="CYRILLIC SMALL LETTER KA WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x043A,
  uccode=0x04C3,
  unicodeslot=0x04C4,
 },
 [0x04C5]={
  category="lu",
  contextname="cyrillicELtail",
  description="CYRILLIC CAPITAL LETTER EL WITH TAIL",
  direction="l",
  lccode=0x04C6,
  linebreak="al",
  shcode=0x041B,
  unicodeslot=0x04C5,
 },
 [0x04C6]={
  category="ll",
  contextname="cyrilliceltail",
  description="CYRILLIC SMALL LETTER EL WITH TAIL",
  direction="l",
  linebreak="al",
  shcode=0x043B,
  uccode=0x04C5,
  unicodeslot=0x04C6,
 },
 [0x04C7]={
  adobename="Enhookcyrillic",
  category="lu",
  contextname="cyrillicENhook",
  description="CYRILLIC CAPITAL LETTER EN WITH HOOK",
  direction="l",
  lccode=0x04C8,
  linebreak="al",
  shcode=0x041D,
  unicodeslot=0x04C7,
 },
 [0x04C8]={
  adobename="enhookcyrillic",
  category="ll",
  contextname="cyrillicenhook",
  description="CYRILLIC SMALL LETTER EN WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x043D,
  uccode=0x04C7,
  unicodeslot=0x04C8,
 },
 [0x04C9]={
  category="lu",
  contextname="cyrillicENtail",
  description="CYRILLIC CAPITAL LETTER EN WITH TAIL",
  direction="l",
  lccode=0x04CA,
  linebreak="al",
  shcode=0x041D,
  unicodeslot=0x04C9,
 },
 [0x04CA]={
  category="ll",
  contextname="cyrillicentail",
  description="CYRILLIC SMALL LETTER EN WITH TAIL",
  direction="l",
  linebreak="al",
  shcode=0x043D,
  uccode=0x04C9,
  unicodeslot=0x04CA,
 },
 [0x04CB]={
  adobename="Chekhakassiancyrillic",
  category="lu",
  contextname="cyrillicCHEkhakassian",
  description="CYRILLIC CAPITAL LETTER KHAKASSIAN CHE",
  direction="l",
  lccode=0x04CC,
  linebreak="al",
  unicodeslot=0x04CB,
 },
 [0x04CC]={
  adobename="chekhakassiancyrillic",
  category="ll",
  contextname="cyrillicchekhakassian",
  description="CYRILLIC SMALL LETTER KHAKASSIAN CHE",
  direction="l",
  linebreak="al",
  uccode=0x04CB,
  unicodeslot=0x04CC,
 },
 [0x04CD]={
  category="lu",
  contextname="cyrillicEMtail",
  description="CYRILLIC CAPITAL LETTER EM WITH TAIL",
  direction="l",
  lccode=0x04CE,
  linebreak="al",
  shcode=0x041C,
  unicodeslot=0x04CD,
 },
 [0x04CE]={
  category="ll",
  contextname="cyrillicemtail",
  description="CYRILLIC SMALL LETTER EM WITH TAIL",
  direction="l",
  linebreak="al",
  shcode=0x043C,
  uccode=0x04CD,
  unicodeslot=0x04CE,
 },
 [0x04CF]={
  category="ll",
  description="CYRILLIC SMALL LETTER PALOCHKA",
  direction="l",
  linebreak="al",
  uccode=0x04C0,
  unicodeslot=0x04CF,
 },
 [0x04D0]={
  adobename="Abrevecyrillic",
  category="lu",
  contextname="cyrillicAbreve",
  description="CYRILLIC CAPITAL LETTER A WITH BREVE",
  direction="l",
  lccode=0x04D1,
  linebreak="al",
  shcode=0x0410,
  specials={ "char", 0x0410, 0x0306 },
  unicodeslot=0x04D0,
 },
 [0x04D1]={
  adobename="abrevecyrillic",
  category="ll",
  contextname="cyrillicabreve",
  description="CYRILLIC SMALL LETTER A WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0430,
  specials={ "char", 0x0430, 0x0306 },
  uccode=0x04D0,
  unicodeslot=0x04D1,
 },
 [0x04D2]={
  adobename="Adieresiscyrillic",
  category="lu",
  contextname="cyrillicAdiaeresis",
  description="CYRILLIC CAPITAL LETTER A WITH DIAERESIS",
  direction="l",
  lccode=0x04D3,
  linebreak="al",
  shcode=0x0410,
  specials={ "char", 0x0410, 0x0308 },
  unicodeslot=0x04D2,
 },
 [0x04D3]={
  adobename="adieresiscyrillic",
  category="ll",
  contextname="cyrillicadiaeresis",
  description="CYRILLIC SMALL LETTER A WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0430,
  specials={ "char", 0x0430, 0x0308 },
  uccode=0x04D2,
  unicodeslot=0x04D3,
 },
 [0x04D4]={
  adobename="Aiecyrillic",
  category="lu",
  contextname="cyrillicAE",
  description="CYRILLIC CAPITAL LIGATURE A IE",
  direction="l",
  lccode=0x04D5,
  linebreak="al",
  unicodeslot=0x04D4,
 },
 [0x04D5]={
  adobename="aiecyrillic",
  category="ll",
  contextname="cyrillicae",
  description="CYRILLIC SMALL LIGATURE A IE",
  direction="l",
  linebreak="al",
  uccode=0x04D4,
  unicodeslot=0x04D5,
 },
 [0x04D6]={
  adobename="Iebrevecyrillic",
  category="lu",
  contextname="cyrillicEbreve",
  description="CYRILLIC CAPITAL LETTER IE WITH BREVE",
  direction="l",
  lccode=0x04D7,
  linebreak="al",
  shcode=0x0415,
  specials={ "char", 0x0415, 0x0306 },
  unicodeslot=0x04D6,
 },
 [0x04D7]={
  adobename="iebrevecyrillic",
  category="ll",
  contextname="cyrillicebreve",
  description="CYRILLIC SMALL LETTER IE WITH BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0435,
  specials={ "char", 0x0435, 0x0306 },
  uccode=0x04D6,
  unicodeslot=0x04D7,
 },
 [0x04D8]={
  adobename="Schwacyrillic",
  category="lu",
  contextname="cyrillicSCHWA",
  description="CYRILLIC CAPITAL LETTER SCHWA",
  direction="l",
  lccode=0x04D9,
  linebreak="al",
  unicodeslot=0x04D8,
 },
 [0x04D9]={
  adobename="schwacyrillic",
  category="ll",
  contextname="cyrillicschwa",
  description="CYRILLIC SMALL LETTER SCHWA",
  direction="l",
  linebreak="al",
  uccode=0x04D8,
  unicodeslot=0x04D9,
 },
 [0x04DA]={
  adobename="Schwadieresiscyrillic",
  category="lu",
  contextname="cyrillicSCHWAdiaeresis",
  description="CYRILLIC CAPITAL LETTER SCHWA WITH DIAERESIS",
  direction="l",
  lccode=0x04DB,
  linebreak="al",
  shcode=0x04D8,
  specials={ "char", 0x04D8, 0x0308 },
  unicodeslot=0x04DA,
 },
 [0x04DB]={
  adobename="schwadieresiscyrillic",
  category="ll",
  contextname="cyrillicschwadiaeresis",
  description="CYRILLIC SMALL LETTER SCHWA WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x04D9,
  specials={ "char", 0x04D9, 0x0308 },
  uccode=0x04DA,
  unicodeslot=0x04DB,
 },
 [0x04DC]={
  adobename="Zhedieresiscyrillic",
  category="lu",
  contextname="cyrillicZHEdiaeresis",
  description="CYRILLIC CAPITAL LETTER ZHE WITH DIAERESIS",
  direction="l",
  lccode=0x04DD,
  linebreak="al",
  shcode=0x0416,
  specials={ "char", 0x0416, 0x0308 },
  unicodeslot=0x04DC,
 },
 [0x04DD]={
  adobename="zhedieresiscyrillic",
  category="ll",
  contextname="cyrilliczhediaeresis",
  description="CYRILLIC SMALL LETTER ZHE WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0436,
  specials={ "char", 0x0436, 0x0308 },
  uccode=0x04DC,
  unicodeslot=0x04DD,
 },
 [0x04DE]={
  adobename="Zedieresiscyrillic",
  category="lu",
  contextname="cyrillicZEdiaeresis",
  description="CYRILLIC CAPITAL LETTER ZE WITH DIAERESIS",
  direction="l",
  lccode=0x04DF,
  linebreak="al",
  shcode=0x0417,
  specials={ "char", 0x0417, 0x0308 },
  unicodeslot=0x04DE,
 },
 [0x04DF]={
  adobename="zedieresiscyrillic",
  category="ll",
  contextname="cyrilliczediaeresis",
  description="CYRILLIC SMALL LETTER ZE WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0437,
  specials={ "char", 0x0437, 0x0308 },
  uccode=0x04DE,
  unicodeslot=0x04DF,
 },
 [0x04E0]={
  adobename="Dzeabkhasiancyrillic",
  category="lu",
  contextname="cyrillicDZEabkhasian",
  description="CYRILLIC CAPITAL LETTER ABKHASIAN DZE",
  direction="l",
  lccode=0x04E1,
  linebreak="al",
  unicodeslot=0x04E0,
 },
 [0x04E1]={
  adobename="dzeabkhasiancyrillic",
  category="ll",
  contextname="cyrillicdzeabkhasian",
  description="CYRILLIC SMALL LETTER ABKHASIAN DZE",
  direction="l",
  linebreak="al",
  uccode=0x04E0,
  unicodeslot=0x04E1,
 },
 [0x04E2]={
  adobename="Imacroncyrillic",
  category="lu",
  contextname="cyrillicImacron",
  description="CYRILLIC CAPITAL LETTER I WITH MACRON",
  direction="l",
  lccode=0x04E3,
  linebreak="al",
  shcode=0x0418,
  specials={ "char", 0x0418, 0x0304 },
  unicodeslot=0x04E2,
 },
 [0x04E3]={
  adobename="imacroncyrillic",
  category="ll",
  contextname="cyrillicimacron",
  description="CYRILLIC SMALL LETTER I WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0438,
  specials={ "char", 0x0438, 0x0304 },
  uccode=0x04E2,
  unicodeslot=0x04E3,
 },
 [0x04E4]={
  adobename="Idieresiscyrillic",
  category="lu",
  contextname="cyrillicIdiaeresis",
  description="CYRILLIC CAPITAL LETTER I WITH DIAERESIS",
  direction="l",
  lccode=0x04E5,
  linebreak="al",
  shcode=0x0418,
  specials={ "char", 0x0418, 0x0308 },
  unicodeslot=0x04E4,
 },
 [0x04E5]={
  adobename="idieresiscyrillic",
  category="ll",
  contextname="cyrillicidiaeresis",
  description="CYRILLIC SMALL LETTER I WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0438,
  specials={ "char", 0x0438, 0x0308 },
  uccode=0x04E4,
  unicodeslot=0x04E5,
 },
 [0x04E6]={
  adobename="Odieresiscyrillic",
  category="lu",
  contextname="cyrillicOdiaeresis",
  description="CYRILLIC CAPITAL LETTER O WITH DIAERESIS",
  direction="l",
  lccode=0x04E7,
  linebreak="al",
  shcode=0x041E,
  specials={ "char", 0x041E, 0x0308 },
  unicodeslot=0x04E6,
 },
 [0x04E7]={
  adobename="odieresiscyrillic",
  category="ll",
  contextname="cyrillicodiaeresis",
  description="CYRILLIC SMALL LETTER O WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x043E,
  specials={ "char", 0x043E, 0x0308 },
  uccode=0x04E6,
  unicodeslot=0x04E7,
 },
 [0x04E8]={
  adobename="Obarredcyrillic",
  category="lu",
  contextname="cyrillicObarred",
  description="CYRILLIC CAPITAL LETTER BARRED O",
  direction="l",
  lccode=0x04E9,
  linebreak="al",
  unicodeslot=0x04E8,
 },
 [0x04E9]={
  adobename="obarredcyrillic",
  category="ll",
  contextname="cyrillicobarred",
  description="CYRILLIC SMALL LETTER BARRED O",
  direction="l",
  linebreak="al",
  uccode=0x04E8,
  unicodeslot=0x04E9,
 },
 [0x04EA]={
  adobename="Obarreddieresiscyrillic",
  category="lu",
  contextname="cyrillicObarreddiaeresis",
  description="CYRILLIC CAPITAL LETTER BARRED O WITH DIAERESIS",
  direction="l",
  lccode=0x04EB,
  linebreak="al",
  specials={ "char", 0x04E8, 0x0308 },
  unicodeslot=0x04EA,
 },
 [0x04EB]={
  adobename="obarreddieresiscyrillic",
  category="ll",
  contextname="cyrillicobarreddiaeresis",
  description="CYRILLIC SMALL LETTER BARRED O WITH DIAERESIS",
  direction="l",
  linebreak="al",
  specials={ "char", 0x04E9, 0x0308 },
  uccode=0x04EA,
  unicodeslot=0x04EB,
 },
 [0x04EC]={
  category="lu",
  contextname="cyrillicEdiaeresis",
  description="CYRILLIC CAPITAL LETTER E WITH DIAERESIS",
  direction="l",
  lccode=0x04ED,
  linebreak="al",
  shcode=0x042D,
  specials={ "char", 0x042D, 0x0308 },
  unicodeslot=0x04EC,
 },
 [0x04ED]={
  category="ll",
  contextname="cyrillicediaeresis",
  description="CYRILLIC SMALL LETTER E WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x044D,
  specials={ "char", 0x044D, 0x0308 },
  uccode=0x04EC,
  unicodeslot=0x04ED,
 },
 [0x04EE]={
  adobename="Umacroncyrillic",
  category="lu",
  contextname="cyrillicUmacron",
  description="CYRILLIC CAPITAL LETTER U WITH MACRON",
  direction="l",
  lccode=0x04EF,
  linebreak="al",
  shcode=0x0423,
  specials={ "char", 0x0423, 0x0304 },
  unicodeslot=0x04EE,
 },
 [0x04EF]={
  adobename="umacroncyrillic",
  category="ll",
  contextname="cyrillicumacron",
  description="CYRILLIC SMALL LETTER U WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0443,
  specials={ "char", 0x0443, 0x0304 },
  uccode=0x04EE,
  unicodeslot=0x04EF,
 },
 [0x04F0]={
  adobename="Udieresiscyrillic",
  category="lu",
  contextname="cyrillicUdiaeresis",
  description="CYRILLIC CAPITAL LETTER U WITH DIAERESIS",
  direction="l",
  lccode=0x04F1,
  linebreak="al",
  shcode=0x0423,
  specials={ "char", 0x0423, 0x0308 },
  unicodeslot=0x04F0,
 },
 [0x04F1]={
  adobename="udieresiscyrillic",
  category="ll",
  contextname="cyrillicudiaeresis",
  description="CYRILLIC SMALL LETTER U WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0443,
  specials={ "char", 0x0443, 0x0308 },
  uccode=0x04F0,
  unicodeslot=0x04F1,
 },
 [0x04F2]={
  adobename="Uhungarumlautcyrillic",
  category="lu",
  contextname="cyrillicUdoubleacute",
  description="CYRILLIC CAPITAL LETTER U WITH DOUBLE ACUTE",
  direction="l",
  lccode=0x04F3,
  linebreak="al",
  shcode=0x0423,
  specials={ "char", 0x0423, 0x030B },
  unicodeslot=0x04F2,
 },
 [0x04F3]={
  adobename="uhungarumlautcyrillic",
  category="ll",
  contextname="cyrillicudoubleacute",
  description="CYRILLIC SMALL LETTER U WITH DOUBLE ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0443,
  specials={ "char", 0x0443, 0x030B },
  uccode=0x04F2,
  unicodeslot=0x04F3,
 },
 [0x04F4]={
  adobename="Chedieresiscyrillic",
  category="lu",
  contextname="cyrillicCHEdiaeresis",
  description="CYRILLIC CAPITAL LETTER CHE WITH DIAERESIS",
  direction="l",
  lccode=0x04F5,
  linebreak="al",
  shcode=0x0427,
  specials={ "char", 0x0427, 0x0308 },
  unicodeslot=0x04F4,
 },
 [0x04F5]={
  adobename="chedieresiscyrillic",
  category="ll",
  contextname="cyrillicchediaeresis",
  description="CYRILLIC SMALL LETTER CHE WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0447,
  specials={ "char", 0x0447, 0x0308 },
  uccode=0x04F4,
  unicodeslot=0x04F5,
 },
 [0x04F6]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER GHE WITH DESCENDER",
  direction="l",
  lccode=0x04F7,
  linebreak="al",
  shcode=0x0413,
  unicodeslot=0x04F6,
 },
 [0x04F7]={
  category="ll",
  description="CYRILLIC SMALL LETTER GHE WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x0433,
  uccode=0x04F6,
  unicodeslot=0x04F7,
 },
 [0x04F8]={
  adobename="Yerudieresiscyrillic",
  category="lu",
  contextname="cyrillicYERUdiaeresis",
  description="CYRILLIC CAPITAL LETTER YERU WITH DIAERESIS",
  direction="l",
  lccode=0x04F9,
  linebreak="al",
  shcode=0x042B,
  specials={ "char", 0x042B, 0x0308 },
  unicodeslot=0x04F8,
 },
 [0x04F9]={
  adobename="yerudieresiscyrillic",
  category="ll",
  contextname="cyrillicyerudiaeresis",
  description="CYRILLIC SMALL LETTER YERU WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x044B,
  specials={ "char", 0x044B, 0x0308 },
  uccode=0x04F8,
  unicodeslot=0x04F9,
 },
 [0x04FA]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER GHE WITH STROKE AND HOOK",
  direction="l",
  lccode=0x04FB,
  linebreak="al",
  shcode=0x0413,
  unicodeslot=0x04FA,
 },
 [0x04FB]={
  category="ll",
  description="CYRILLIC SMALL LETTER GHE WITH STROKE AND HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0433,
  uccode=0x04FA,
  unicodeslot=0x04FB,
 },
 [0x04FC]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER HA WITH HOOK",
  direction="l",
  lccode=0x04FD,
  linebreak="al",
  shcode=0x0425,
  unicodeslot=0x04FC,
 },
 [0x04FD]={
  category="ll",
  description="CYRILLIC SMALL LETTER HA WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0445,
  uccode=0x04FC,
  unicodeslot=0x04FD,
 },
 [0x04FE]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER HA WITH STROKE",
  direction="l",
  lccode=0x04FF,
  linebreak="al",
  shcode=0x0425,
  unicodeslot=0x04FE,
 },
 [0x04FF]={
  category="ll",
  description="CYRILLIC SMALL LETTER HA WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0445,
  uccode=0x04FE,
  unicodeslot=0x04FF,
 },
 [0x0500]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER KOMI DE",
  direction="l",
  lccode=0x0501,
  linebreak="al",
  unicodeslot=0x0500,
 },
 [0x0501]={
  category="ll",
  description="CYRILLIC SMALL LETTER KOMI DE",
  direction="l",
  linebreak="al",
  uccode=0x0500,
  unicodeslot=0x0501,
 },
 [0x0502]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER KOMI DJE",
  direction="l",
  lccode=0x0503,
  linebreak="al",
  unicodeslot=0x0502,
 },
 [0x0503]={
  category="ll",
  description="CYRILLIC SMALL LETTER KOMI DJE",
  direction="l",
  linebreak="al",
  uccode=0x0502,
  unicodeslot=0x0503,
 },
 [0x0504]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER KOMI ZJE",
  direction="l",
  lccode=0x0505,
  linebreak="al",
  unicodeslot=0x0504,
 },
 [0x0505]={
  category="ll",
  description="CYRILLIC SMALL LETTER KOMI ZJE",
  direction="l",
  linebreak="al",
  uccode=0x0504,
  unicodeslot=0x0505,
 },
 [0x0506]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER KOMI DZJE",
  direction="l",
  lccode=0x0507,
  linebreak="al",
  unicodeslot=0x0506,
 },
 [0x0507]={
  category="ll",
  description="CYRILLIC SMALL LETTER KOMI DZJE",
  direction="l",
  linebreak="al",
  uccode=0x0506,
  unicodeslot=0x0507,
 },
 [0x0508]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER KOMI LJE",
  direction="l",
  lccode=0x0509,
  linebreak="al",
  unicodeslot=0x0508,
 },
 [0x0509]={
  category="ll",
  description="CYRILLIC SMALL LETTER KOMI LJE",
  direction="l",
  linebreak="al",
  uccode=0x0508,
  unicodeslot=0x0509,
 },
 [0x050A]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER KOMI NJE",
  direction="l",
  lccode=0x050B,
  linebreak="al",
  unicodeslot=0x050A,
 },
 [0x050B]={
  category="ll",
  description="CYRILLIC SMALL LETTER KOMI NJE",
  direction="l",
  linebreak="al",
  uccode=0x050A,
  unicodeslot=0x050B,
 },
 [0x050C]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER KOMI SJE",
  direction="l",
  lccode=0x050D,
  linebreak="al",
  unicodeslot=0x050C,
 },
 [0x050D]={
  category="ll",
  description="CYRILLIC SMALL LETTER KOMI SJE",
  direction="l",
  linebreak="al",
  uccode=0x050C,
  unicodeslot=0x050D,
 },
 [0x050E]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER KOMI TJE",
  direction="l",
  lccode=0x050F,
  linebreak="al",
  unicodeslot=0x050E,
 },
 [0x050F]={
  category="ll",
  description="CYRILLIC SMALL LETTER KOMI TJE",
  direction="l",
  linebreak="al",
  uccode=0x050E,
  unicodeslot=0x050F,
 },
 [0x0510]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER REVERSED ZE",
  direction="l",
  lccode=0x0511,
  linebreak="al",
  unicodeslot=0x0510,
 },
 [0x0511]={
  category="ll",
  description="CYRILLIC SMALL LETTER REVERSED ZE",
  direction="l",
  linebreak="al",
  uccode=0x0510,
  unicodeslot=0x0511,
 },
 [0x0512]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER EL WITH HOOK",
  direction="l",
  lccode=0x0513,
  linebreak="al",
  shcode=0x041B,
  unicodeslot=0x0512,
 },
 [0x0513]={
  category="ll",
  description="CYRILLIC SMALL LETTER EL WITH HOOK",
  direction="l",
  linebreak="al",
  shcode=0x043B,
  uccode=0x0512,
  unicodeslot=0x0513,
 },
 [0x0514]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER LHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0514,
 },
 [0x0515]={
  category="ll",
  description="CYRILLIC SMALL LETTER LHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0515,
 },
 [0x0516]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER RHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0516,
 },
 [0x0517]={
  category="ll",
  description="CYRILLIC SMALL LETTER RHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0517,
 },
 [0x0518]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER YAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0518,
 },
 [0x0519]={
  category="ll",
  description="CYRILLIC SMALL LETTER YAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0519,
 },
 [0x051A]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x051A,
 },
 [0x051B]={
  category="ll",
  description="CYRILLIC SMALL LETTER QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x051B,
 },
 [0x051C]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x051C,
 },
 [0x051D]={
  category="ll",
  description="CYRILLIC SMALL LETTER WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x051D,
 },
 [0x051E]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER ALEUT KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x051E,
 },
 [0x051F]={
  category="ll",
  description="CYRILLIC SMALL LETTER ALEUT KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x051F,
 },
 [0x0520]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER EL WITH MIDDLE HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x0520,
 },
 [0x0521]={
  category="ll",
  description="CYRILLIC SMALL LETTER EL WITH MIDDLE HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x0521,
 },
 [0x0522]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER EN WITH MIDDLE HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x0522,
 },
 [0x0523]={
  category="ll",
  description="CYRILLIC SMALL LETTER EN WITH MIDDLE HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x0523,
 },
 [0x0524]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER PE WITH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0x0524,
 },
 [0x0525]={
  category="ll",
  description="CYRILLIC SMALL LETTER PE WITH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0x0525,
 },
 [0x0526]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER SHHA WITH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0x0526,
 },
 [0x0527]={
  category="ll",
  description="CYRILLIC SMALL LETTER SHHA WITH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0x0527,
 },
 [0x0531]={
  adobename="Aybarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER AYB",
  direction="l",
  lccode=0x0561,
  linebreak="al",
  unicodeslot=0x0531,
 },
 [0x0532]={
  adobename="Benarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER BEN",
  direction="l",
  lccode=0x0562,
  linebreak="al",
  unicodeslot=0x0532,
 },
 [0x0533]={
  adobename="Gimarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER GIM",
  direction="l",
  lccode=0x0563,
  linebreak="al",
  unicodeslot=0x0533,
 },
 [0x0534]={
  adobename="Daarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER DA",
  direction="l",
  lccode=0x0564,
  linebreak="al",
  unicodeslot=0x0534,
 },
 [0x0535]={
  adobename="Echarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER ECH",
  direction="l",
  lccode=0x0565,
  linebreak="al",
  unicodeslot=0x0535,
 },
 [0x0536]={
  adobename="Zaarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER ZA",
  direction="l",
  lccode=0x0566,
  linebreak="al",
  unicodeslot=0x0536,
 },
 [0x0537]={
  adobename="Eharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER EH",
  direction="l",
  lccode=0x0567,
  linebreak="al",
  unicodeslot=0x0537,
 },
 [0x0538]={
  adobename="Etarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER ET",
  direction="l",
  lccode=0x0568,
  linebreak="al",
  unicodeslot=0x0538,
 },
 [0x0539]={
  adobename="Toarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER TO",
  direction="l",
  lccode=0x0569,
  linebreak="al",
  unicodeslot=0x0539,
 },
 [0x053A]={
  adobename="Zhearmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER ZHE",
  direction="l",
  lccode=0x056A,
  linebreak="al",
  unicodeslot=0x053A,
 },
 [0x053B]={
  adobename="Iniarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER INI",
  direction="l",
  lccode=0x056B,
  linebreak="al",
  unicodeslot=0x053B,
 },
 [0x053C]={
  adobename="Liwnarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER LIWN",
  direction="l",
  lccode=0x056C,
  linebreak="al",
  unicodeslot=0x053C,
 },
 [0x053D]={
  adobename="Xeharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER XEH",
  direction="l",
  lccode=0x056D,
  linebreak="al",
  unicodeslot=0x053D,
 },
 [0x053E]={
  adobename="Caarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER CA",
  direction="l",
  lccode=0x056E,
  linebreak="al",
  unicodeslot=0x053E,
 },
 [0x053F]={
  adobename="Kenarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER KEN",
  direction="l",
  lccode=0x056F,
  linebreak="al",
  unicodeslot=0x053F,
 },
 [0x0540]={
  adobename="Hoarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER HO",
  direction="l",
  lccode=0x0570,
  linebreak="al",
  unicodeslot=0x0540,
 },
 [0x0541]={
  adobename="Jaarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER JA",
  direction="l",
  lccode=0x0571,
  linebreak="al",
  unicodeslot=0x0541,
 },
 [0x0542]={
  adobename="Ghadarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER GHAD",
  direction="l",
  lccode=0x0572,
  linebreak="al",
  unicodeslot=0x0542,
 },
 [0x0543]={
  adobename="Cheharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER CHEH",
  direction="l",
  lccode=0x0573,
  linebreak="al",
  unicodeslot=0x0543,
 },
 [0x0544]={
  adobename="Menarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER MEN",
  direction="l",
  lccode=0x0574,
  linebreak="al",
  unicodeslot=0x0544,
 },
 [0x0545]={
  adobename="Yiarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER YI",
  direction="l",
  lccode=0x0575,
  linebreak="al",
  unicodeslot=0x0545,
 },
 [0x0546]={
  adobename="Nowarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER NOW",
  direction="l",
  lccode=0x0576,
  linebreak="al",
  unicodeslot=0x0546,
 },
 [0x0547]={
  adobename="Shaarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER SHA",
  direction="l",
  lccode=0x0577,
  linebreak="al",
  unicodeslot=0x0547,
 },
 [0x0548]={
  adobename="Voarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER VO",
  direction="l",
  lccode=0x0578,
  linebreak="al",
  unicodeslot=0x0548,
 },
 [0x0549]={
  adobename="Chaarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER CHA",
  direction="l",
  lccode=0x0579,
  linebreak="al",
  unicodeslot=0x0549,
 },
 [0x054A]={
  adobename="Peharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER PEH",
  direction="l",
  lccode=0x057A,
  linebreak="al",
  unicodeslot=0x054A,
 },
 [0x054B]={
  adobename="Jheharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER JHEH",
  direction="l",
  lccode=0x057B,
  linebreak="al",
  unicodeslot=0x054B,
 },
 [0x054C]={
  adobename="Raarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER RA",
  direction="l",
  lccode=0x057C,
  linebreak="al",
  unicodeslot=0x054C,
 },
 [0x054D]={
  adobename="Seharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER SEH",
  direction="l",
  lccode=0x057D,
  linebreak="al",
  unicodeslot=0x054D,
 },
 [0x054E]={
  adobename="Vewarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER VEW",
  direction="l",
  lccode=0x057E,
  linebreak="al",
  unicodeslot=0x054E,
 },
 [0x054F]={
  adobename="Tiwnarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER TIWN",
  direction="l",
  lccode=0x057F,
  linebreak="al",
  unicodeslot=0x054F,
 },
 [0x0550]={
  adobename="Reharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER REH",
  direction="l",
  lccode=0x0580,
  linebreak="al",
  unicodeslot=0x0550,
 },
 [0x0551]={
  adobename="Coarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER CO",
  direction="l",
  lccode=0x0581,
  linebreak="al",
  unicodeslot=0x0551,
 },
 [0x0552]={
  adobename="Yiwnarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER YIWN",
  direction="l",
  lccode=0x0582,
  linebreak="al",
  unicodeslot=0x0552,
 },
 [0x0553]={
  adobename="Piwrarmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER PIWR",
  direction="l",
  lccode=0x0583,
  linebreak="al",
  unicodeslot=0x0553,
 },
 [0x0554]={
  adobename="Keharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER KEH",
  direction="l",
  lccode=0x0584,
  linebreak="al",
  unicodeslot=0x0554,
 },
 [0x0555]={
  adobename="Oharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER OH",
  direction="l",
  lccode=0x0585,
  linebreak="al",
  unicodeslot=0x0555,
 },
 [0x0556]={
  adobename="Feharmenian",
  category="lu",
  description="ARMENIAN CAPITAL LETTER FEH",
  direction="l",
  lccode=0x0586,
  linebreak="al",
  unicodeslot=0x0556,
 },
 [0x0559]={
  adobename="ringhalfleftarmenian",
  category="lm",
  description="ARMENIAN MODIFIER LETTER LEFT HALF RING",
  direction="l",
  linebreak="al",
  unicodeslot=0x0559,
 },
 [0x055A]={
  adobename="apostrophearmenian",
  category="po",
  description="ARMENIAN APOSTROPHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x055A,
 },
 [0x055B]={
  adobename="emphasismarkarmenian",
  category="po",
  description="ARMENIAN EMPHASIS MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x055B,
 },
 [0x055C]={
  adobename="exclamarmenian",
  category="po",
  description="ARMENIAN EXCLAMATION MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x055C,
 },
 [0x055D]={
  adobename="commaarmenian",
  category="po",
  description="ARMENIAN COMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x055D,
 },
 [0x055E]={
  adobename="questionarmenian",
  category="po",
  description="ARMENIAN QUESTION MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x055E,
 },
 [0x055F]={
  adobename="abbreviationmarkarmenian",
  category="po",
  description="ARMENIAN ABBREVIATION MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x055F,
 },
 [0x0561]={
  adobename="aybarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER AYB",
  direction="l",
  linebreak="al",
  uccode=0x0531,
  unicodeslot=0x0561,
 },
 [0x0562]={
  adobename="benarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER BEN",
  direction="l",
  linebreak="al",
  uccode=0x0532,
  unicodeslot=0x0562,
 },
 [0x0563]={
  adobename="gimarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER GIM",
  direction="l",
  linebreak="al",
  uccode=0x0533,
  unicodeslot=0x0563,
 },
 [0x0564]={
  adobename="daarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER DA",
  direction="l",
  linebreak="al",
  uccode=0x0534,
  unicodeslot=0x0564,
 },
 [0x0565]={
  adobename="echarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER ECH",
  direction="l",
  linebreak="al",
  uccode=0x0535,
  unicodeslot=0x0565,
 },
 [0x0566]={
  adobename="zaarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER ZA",
  direction="l",
  linebreak="al",
  uccode=0x0536,
  unicodeslot=0x0566,
 },
 [0x0567]={
  adobename="eharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER EH",
  direction="l",
  linebreak="al",
  uccode=0x0537,
  unicodeslot=0x0567,
 },
 [0x0568]={
  adobename="etarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER ET",
  direction="l",
  linebreak="al",
  uccode=0x0538,
  unicodeslot=0x0568,
 },
 [0x0569]={
  adobename="toarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER TO",
  direction="l",
  linebreak="al",
  uccode=0x0539,
  unicodeslot=0x0569,
 },
 [0x056A]={
  adobename="zhearmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER ZHE",
  direction="l",
  linebreak="al",
  uccode=0x053A,
  unicodeslot=0x056A,
 },
 [0x056B]={
  adobename="iniarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER INI",
  direction="l",
  linebreak="al",
  uccode=0x053B,
  unicodeslot=0x056B,
 },
 [0x056C]={
  adobename="liwnarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER LIWN",
  direction="l",
  linebreak="al",
  uccode=0x053C,
  unicodeslot=0x056C,
 },
 [0x056D]={
  adobename="xeharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER XEH",
  direction="l",
  linebreak="al",
  uccode=0x053D,
  unicodeslot=0x056D,
 },
 [0x056E]={
  adobename="caarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER CA",
  direction="l",
  linebreak="al",
  uccode=0x053E,
  unicodeslot=0x056E,
 },
 [0x056F]={
  adobename="kenarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER KEN",
  direction="l",
  linebreak="al",
  uccode=0x053F,
  unicodeslot=0x056F,
 },
 [0x0570]={
  adobename="hoarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER HO",
  direction="l",
  linebreak="al",
  uccode=0x0540,
  unicodeslot=0x0570,
 },
 [0x0571]={
  adobename="jaarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER JA",
  direction="l",
  linebreak="al",
  uccode=0x0541,
  unicodeslot=0x0571,
 },
 [0x0572]={
  adobename="ghadarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER GHAD",
  direction="l",
  linebreak="al",
  uccode=0x0542,
  unicodeslot=0x0572,
 },
 [0x0573]={
  adobename="cheharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER CHEH",
  direction="l",
  linebreak="al",
  uccode=0x0543,
  unicodeslot=0x0573,
 },
 [0x0574]={
  adobename="menarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER MEN",
  direction="l",
  linebreak="al",
  uccode=0x0544,
  unicodeslot=0x0574,
 },
 [0x0575]={
  adobename="yiarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER YI",
  direction="l",
  linebreak="al",
  uccode=0x0545,
  unicodeslot=0x0575,
 },
 [0x0576]={
  adobename="nowarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER NOW",
  direction="l",
  linebreak="al",
  uccode=0x0546,
  unicodeslot=0x0576,
 },
 [0x0577]={
  adobename="shaarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER SHA",
  direction="l",
  linebreak="al",
  uccode=0x0547,
  unicodeslot=0x0577,
 },
 [0x0578]={
  adobename="voarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER VO",
  direction="l",
  linebreak="al",
  uccode=0x0548,
  unicodeslot=0x0578,
 },
 [0x0579]={
  adobename="chaarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER CHA",
  direction="l",
  linebreak="al",
  uccode=0x0549,
  unicodeslot=0x0579,
 },
 [0x057A]={
  adobename="peharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER PEH",
  direction="l",
  linebreak="al",
  uccode=0x054A,
  unicodeslot=0x057A,
 },
 [0x057B]={
  adobename="jheharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER JHEH",
  direction="l",
  linebreak="al",
  uccode=0x054B,
  unicodeslot=0x057B,
 },
 [0x057C]={
  adobename="raarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER RA",
  direction="l",
  linebreak="al",
  uccode=0x054C,
  unicodeslot=0x057C,
 },
 [0x057D]={
  adobename="seharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER SEH",
  direction="l",
  linebreak="al",
  uccode=0x054D,
  unicodeslot=0x057D,
 },
 [0x057E]={
  adobename="vewarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER VEW",
  direction="l",
  linebreak="al",
  uccode=0x054E,
  unicodeslot=0x057E,
 },
 [0x057F]={
  adobename="tiwnarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER TIWN",
  direction="l",
  linebreak="al",
  uccode=0x054F,
  unicodeslot=0x057F,
 },
 [0x0580]={
  adobename="reharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER REH",
  direction="l",
  linebreak="al",
  uccode=0x0550,
  unicodeslot=0x0580,
 },
 [0x0581]={
  adobename="coarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER CO",
  direction="l",
  linebreak="al",
  uccode=0x0551,
  unicodeslot=0x0581,
 },
 [0x0582]={
  adobename="yiwnarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER YIWN",
  direction="l",
  linebreak="al",
  uccode=0x0552,
  unicodeslot=0x0582,
 },
 [0x0583]={
  adobename="piwrarmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER PIWR",
  direction="l",
  linebreak="al",
  uccode=0x0553,
  unicodeslot=0x0583,
 },
 [0x0584]={
  adobename="keharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER KEH",
  direction="l",
  linebreak="al",
  uccode=0x0554,
  unicodeslot=0x0584,
 },
 [0x0585]={
  adobename="oharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER OH",
  direction="l",
  linebreak="al",
  uccode=0x0555,
  unicodeslot=0x0585,
 },
 [0x0586]={
  adobename="feharmenian",
  category="ll",
  description="ARMENIAN SMALL LETTER FEH",
  direction="l",
  linebreak="al",
  uccode=0x0556,
  unicodeslot=0x0586,
 },
 [0x0587]={
  adobename="echyiwnarmenian",
  category="ll",
  description="ARMENIAN SMALL LIGATURE ECH YIWN",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0565, 0x0582 },
  unicodeslot=0x0587,
 },
 [0x0589]={
  adobename="periodarmenian",
  category="po",
  description="ARMENIAN FULL STOP",
  direction="l",
  linebreak="is",
  unicodeslot=0x0589,
 },
 [0x058A]={
  category="pd",
  description="ARMENIAN HYPHEN",
  direction="on",
  linebreak="ba",
  unicodeslot=0x058A,
 },
 [0x058F]={
  category="sc",
  description="ARMENIAN DRAM SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x058F,
 },
 [0x0591]={
  adobename="etnahtalefthebrew",
  category="mn",
  description="HEBREW ACCENT ETNAHTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0591,
 },
 [0x0592]={
  adobename="segoltahebrew",
  category="mn",
  description="HEBREW ACCENT SEGOL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0592,
 },
 [0x0593]={
  adobename="shalshelethebrew",
  category="mn",
  description="HEBREW ACCENT SHALSHELET",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0593,
 },
 [0x0594]={
  adobename="zaqefqatanhebrew",
  category="mn",
  description="HEBREW ACCENT ZAQEF QATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0594,
 },
 [0x0595]={
  adobename="zaqefgadolhebrew",
  category="mn",
  description="HEBREW ACCENT ZAQEF GADOL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0595,
 },
 [0x0596]={
  adobename="tipehalefthebrew",
  category="mn",
  description="HEBREW ACCENT TIPEHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0596,
 },
 [0x0597]={
  adobename="reviamugrashhebrew",
  category="mn",
  description="HEBREW ACCENT REVIA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0597,
 },
 [0x0598]={
  adobename="zarqahebrew",
  category="mn",
  description="HEBREW ACCENT ZARQA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0598,
 },
 [0x0599]={
  adobename="pashtahebrew",
  category="mn",
  description="HEBREW ACCENT PASHTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0599,
 },
 [0x059A]={
  adobename="yetivhebrew",
  category="mn",
  description="HEBREW ACCENT YETIV",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x059A,
 },
 [0x059B]={
  adobename="tevirlefthebrew",
  category="mn",
  description="HEBREW ACCENT TEVIR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x059B,
 },
 [0x059C]={
  adobename="gereshaccenthebrew",
  category="mn",
  description="HEBREW ACCENT GERESH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x059C,
 },
 [0x059D]={
  adobename="gereshmuqdamhebrew",
  category="mn",
  description="HEBREW ACCENT GERESH MUQDAM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x059D,
 },
 [0x059E]={
  adobename="gershayimaccenthebrew",
  category="mn",
  description="HEBREW ACCENT GERSHAYIM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x059E,
 },
 [0x059F]={
  adobename="qarneyparahebrew",
  category="mn",
  description="HEBREW ACCENT QARNEY PARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x059F,
 },
 [0x05A0]={
  adobename="telishagedolahebrew",
  category="mn",
  description="HEBREW ACCENT TELISHA GEDOLA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A0,
 },
 [0x05A1]={
  adobename="pazerhebrew",
  category="mn",
  description="HEBREW ACCENT PAZER",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A1,
 },
 [0x05A2]={
  category="mn",
  description="HEBREW ACCENT ATNAH HAFUKH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A2,
 },
 [0x05A3]={
  adobename="munahlefthebrew",
  category="mn",
  description="HEBREW ACCENT MUNAH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A3,
 },
 [0x05A4]={
  adobename="mahapakhlefthebrew",
  category="mn",
  description="HEBREW ACCENT MAHAPAKH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A4,
 },
 [0x05A5]={
  adobename="merkhalefthebrew",
  category="mn",
  description="HEBREW ACCENT MERKHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A5,
 },
 [0x05A6]={
  adobename="merkhakefulalefthebrew",
  category="mn",
  description="HEBREW ACCENT MERKHA KEFULA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A6,
 },
 [0x05A7]={
  adobename="dargalefthebrew",
  category="mn",
  description="HEBREW ACCENT DARGA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A7,
 },
 [0x05A8]={
  adobename="qadmahebrew",
  category="mn",
  description="HEBREW ACCENT QADMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A8,
 },
 [0x05A9]={
  adobename="telishaqetanahebrew",
  category="mn",
  description="HEBREW ACCENT TELISHA QETANA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05A9,
 },
 [0x05AA]={
  adobename="yerahbenyomolefthebrew",
  category="mn",
  description="HEBREW ACCENT YERAH BEN YOMO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05AA,
 },
 [0x05AB]={
  adobename="olehebrew",
  category="mn",
  description="HEBREW ACCENT OLE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05AB,
 },
 [0x05AC]={
  adobename="iluyhebrew",
  category="mn",
  description="HEBREW ACCENT ILUY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05AC,
 },
 [0x05AD]={
  adobename="dehihebrew",
  category="mn",
  description="HEBREW ACCENT DEHI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05AD,
 },
 [0x05AE]={
  adobename="zinorhebrew",
  category="mn",
  description="HEBREW ACCENT ZINOR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05AE,
 },
 [0x05AF]={
  adobename="masoracirclehebrew",
  category="mn",
  description="HEBREW MARK MASORA CIRCLE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05AF,
 },
 [0x05B0]={
  adobename="shevawidehebrew",
  category="mn",
  description="HEBREW POINT SHEVA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B0,
 },
 [0x05B1]={
  adobename="hatafsegolwidehebrew",
  category="mn",
  description="HEBREW POINT HATAF SEGOL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B1,
 },
 [0x05B2]={
  adobename="hatafpatahwidehebrew",
  category="mn",
  description="HEBREW POINT HATAF PATAH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B2,
 },
 [0x05B3]={
  adobename="hatafqamatswidehebrew",
  category="mn",
  description="HEBREW POINT HATAF QAMATS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B3,
 },
 [0x05B4]={
  adobename="hiriqwidehebrew",
  category="mn",
  description="HEBREW POINT HIRIQ",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B4,
 },
 [0x05B5]={
  adobename="tserewidehebrew",
  category="mn",
  description="HEBREW POINT TSERE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B5,
 },
 [0x05B6]={
  adobename="segolwidehebrew",
  category="mn",
  description="HEBREW POINT SEGOL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B6,
 },
 [0x05B7]={
  adobename="patahwidehebrew",
  category="mn",
  description="HEBREW POINT PATAH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B7,
 },
 [0x05B8]={
  adobename="qamatswidehebrew",
  category="mn",
  description="HEBREW POINT QAMATS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B8,
 },
 [0x05B9]={
  adobename="holamwidehebrew",
  category="mn",
  description="HEBREW POINT HOLAM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05B9,
 },
 [0x05BA]={
  category="mn",
  description="HEBREW POINT HOLAM HASER FOR VAV",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05BA,
 },
 [0x05BB]={
  adobename="qubutswidehebrew",
  category="mn",
  description="HEBREW POINT QUBUTS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05BB,
 },
 [0x05BC]={
  adobename="dageshhebrew",
  category="mn",
  description="HEBREW POINT DAGESH OR MAPIQ",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05BC,
 },
 [0x05BD]={
  adobename="siluqlefthebrew",
  category="mn",
  description="HEBREW POINT METEG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05BD,
 },
 [0x05BE]={
  adobename="maqafhebrew",
  category="po",
  description="HEBREW PUNCTUATION MAQAF",
  direction="r",
  linebreak="ba",
  unicodeslot=0x05BE,
 },
 [0x05BF]={
  adobename="rafehebrew",
  category="mn",
  description="HEBREW POINT RAFE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05BF,
 },
 [0x05C0]={
  adobename="paseqhebrew",
  category="po",
  description="HEBREW PUNCTUATION PASEQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x05C0,
 },
 [0x05C1]={
  adobename="shindothebrew",
  category="mn",
  description="HEBREW POINT SHIN DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05C1,
 },
 [0x05C2]={
  adobename="sindothebrew",
  category="mn",
  description="HEBREW POINT SIN DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05C2,
 },
 [0x05C3]={
  adobename="sofpasuqhebrew",
  category="po",
  description="HEBREW PUNCTUATION SOF PASUQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x05C3,
 },
 [0x05C4]={
  adobename="upperdothebrew",
  category="mn",
  description="HEBREW MARK UPPER DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05C4,
 },
 [0x05C5]={
  category="mn",
  description="HEBREW MARK LOWER DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05C5,
 },
 [0x05C6]={
  category="po",
  description="HEBREW PUNCTUATION NUN HAFUKHA",
  direction="r",
  linebreak="ex",
  unicodeslot=0x05C6,
 },
 [0x05C7]={
  category="mn",
  description="HEBREW POINT QAMATS QATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x05C7,
 },
 [0x05D0]={
  adobename="alefhebrew",
  category="lo",
  contextname="hebrewAlef",
  description="HEBREW LETTER ALEF",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D0,
 },
 [0x05D1]={
  adobename="bethebrew",
  category="lo",
  contextname="hebrewBet",
  description="HEBREW LETTER BET",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D1,
 },
 [0x05D2]={
  adobename="gimelhebrew",
  category="lo",
  contextname="hebrewGimel",
  description="HEBREW LETTER GIMEL",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D2,
 },
 [0x05D3]={
  adobename="dalettserehebrew",
  category="lo",
  contextname="hebrewDalet",
  description="HEBREW LETTER DALET",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D3,
 },
 [0x05D4]={
  adobename="hehebrew",
  category="lo",
  contextname="hebrewHe",
  description="HEBREW LETTER HE",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D4,
 },
 [0x05D5]={
  adobename="vavhebrew",
  category="lo",
  contextname="hebrewVav",
  description="HEBREW LETTER VAV",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D5,
 },
 [0x05D6]={
  adobename="zayinhebrew",
  category="lo",
  contextname="hebrewZayin",
  description="HEBREW LETTER ZAYIN",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D6,
 },
 [0x05D7]={
  adobename="hethebrew",
  category="lo",
  contextname="hebrewHet",
  description="HEBREW LETTER HET",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D7,
 },
 [0x05D8]={
  adobename="tethebrew",
  category="lo",
  contextname="hebrewTet",
  description="HEBREW LETTER TET",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D8,
 },
 [0x05D9]={
  adobename="yodhebrew",
  category="lo",
  contextname="hebrewYod",
  description="HEBREW LETTER YOD",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05D9,
 },
 [0x05DA]={
  adobename="finalkafshevahebrew",
  category="lo",
  contextname="hebrewKaffinal",
  description="HEBREW LETTER FINAL KAF",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05DA,
 },
 [0x05DB]={
  adobename="kafhebrew",
  category="lo",
  contextname="hebrewKaf",
  description="HEBREW LETTER KAF",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05DB,
 },
 [0x05DC]={
  adobename="lamedholamhebrew",
  category="lo",
  contextname="hebrewLamed",
  description="HEBREW LETTER LAMED",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05DC,
 },
 [0x05DD]={
  adobename="finalmemhebrew",
  category="lo",
  contextname="hebrewMemfinal",
  description="HEBREW LETTER FINAL MEM",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05DD,
 },
 [0x05DE]={
  adobename="memhebrew",
  category="lo",
  contextname="hebrewMem",
  description="HEBREW LETTER MEM",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05DE,
 },
 [0x05DF]={
  adobename="finalnunhebrew",
  category="lo",
  contextname="hebrewNunfinal",
  description="HEBREW LETTER FINAL NUN",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05DF,
 },
 [0x05E0]={
  adobename="nunhebrew",
  category="lo",
  contextname="hebrewNun",
  description="HEBREW LETTER NUN",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E0,
 },
 [0x05E1]={
  adobename="samekhhebrew",
  category="lo",
  contextname="hebrewSamekh",
  description="HEBREW LETTER SAMEKH",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E1,
 },
 [0x05E2]={
  adobename="ayinhebrew",
  category="lo",
  contextname="hebrewAyin",
  description="HEBREW LETTER AYIN",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E2,
 },
 [0x05E3]={
  adobename="finalpehebrew",
  category="lo",
  contextname="hebrewPefinal",
  description="HEBREW LETTER FINAL PE",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E3,
 },
 [0x05E4]={
  adobename="pehebrew",
  category="lo",
  contextname="hebrewPe",
  description="HEBREW LETTER PE",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E4,
 },
 [0x05E5]={
  adobename="finaltsadihebrew",
  category="lo",
  contextname="hebrewTsadifinal",
  description="HEBREW LETTER FINAL TSADI",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E5,
 },
 [0x05E6]={
  adobename="tsadihebrew",
  category="lo",
  contextname="hebrewTsadi",
  description="HEBREW LETTER TSADI",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E6,
 },
 [0x05E7]={
  adobename="qoftserehebrew",
  category="lo",
  contextname="hebrewQof",
  description="HEBREW LETTER QOF",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E7,
 },
 [0x05E8]={
  adobename="reshtserehebrew",
  category="lo",
  contextname="hebrewResh",
  description="HEBREW LETTER RESH",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E8,
 },
 [0x05E9]={
  adobename="shinhebrew",
  category="lo",
  contextname="hebrewShin",
  description="HEBREW LETTER SHIN",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05E9,
 },
 [0x05EA]={
  adobename="tavhebrew",
  category="lo",
  contextname="hebrewTav",
  description="HEBREW LETTER TAV",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05EA,
 },
 [0x05F0]={
  adobename="vavvavhebrew",
  category="lo",
  description="HEBREW LIGATURE YIDDISH DOUBLE VAV",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05F0,
 },
 [0x05F1]={
  adobename="vavyodhebrew",
  category="lo",
  description="HEBREW LIGATURE YIDDISH VAV YOD",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05F1,
 },
 [0x05F2]={
  adobename="yodyodhebrew",
  category="lo",
  description="HEBREW LIGATURE YIDDISH DOUBLE YOD",
  direction="r",
  linebreak="hl",
  unicodeslot=0x05F2,
 },
 [0x05F3]={
  adobename="gereshhebrew",
  category="po",
  description="HEBREW PUNCTUATION GERESH",
  direction="r",
  linebreak="al",
  unicodeslot=0x05F3,
 },
 [0x05F4]={
  adobename="gershayimhebrew",
  category="po",
  description="HEBREW PUNCTUATION GERSHAYIM",
  direction="r",
  linebreak="al",
  unicodeslot=0x05F4,
 },
 [0x0600]={
  arabic="u",
  category="cf",
  description="ARABIC NUMBER SIGN",
  direction="an",
  linebreak="al",
  unicodeslot=0x0600,
  visible="yes",
 },
 [0x0601]={
  arabic="u",
  category="cf",
  description="ARABIC SIGN SANAH",
  direction="an",
  linebreak="al",
  unicodeslot=0x0601,
  visible="yes",
 },
 [0x0602]={
  arabic="u",
  category="cf",
  description="ARABIC FOOTNOTE MARKER",
  direction="an",
  linebreak="al",
  unicodeslot=0x0602,
  visible="yes",
 },
 [0x0603]={
  arabic="u",
  category="cf",
  description="ARABIC SIGN SAFHA",
  direction="an",
  linebreak="al",
  unicodeslot=0x0603,
  visible="yes",
 },
 [0x0604]={
  arabic="u",
  category="cf",
  description="ARABIC SIGN SAMVAT",
  direction="an",
  linebreak="al",
  unicodeslot=0x0604,
 },
 [0x0606]={
  category="sm",
  description="ARABIC-INDIC CUBE ROOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x0606,
 },
 [0x0607]={
  category="sm",
  description="ARABIC-INDIC FOURTH ROOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x0607,
 },
 [0x0608]={
  arabic="u",
  category="sm",
  description="ARABIC RAY",
  direction="al",
  linebreak="al",
  unicodeslot=0x0608,
 },
 [0x0609]={
  category="po",
  description="ARABIC-INDIC PER MILLE SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x0609,
 },
 [0x060A]={
  category="po",
  description="ARABIC-INDIC PER TEN THOUSAND SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x060A,
 },
 [0x060B]={
  arabic="u",
  category="sc",
  description="AFGHANI SIGN",
  direction="al",
  linebreak="po",
  unicodeslot=0x060B,
 },
 [0x060C]={
  adobename="commaarabic",
  category="po",
  description="ARABIC COMMA",
  direction="cs",
  linebreak="is",
  unicodeslot=0x060C,
 },
 [0x060D]={
  category="po",
  description="ARABIC DATE SEPARATOR",
  direction="al",
  linebreak="is",
  unicodeslot=0x060D,
 },
 [0x060E]={
  category="so",
  description="ARABIC POETIC VERSE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x060E,
 },
 [0x060F]={
  category="so",
  description="ARABIC SIGN MISRA",
  direction="on",
  linebreak="al",
  unicodeslot=0x060F,
 },
 [0x0610]={
  category="mn",
  description="ARABIC SIGN SALLALLAHOU ALAYHE WASSALLAM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0610,
 },
 [0x0611]={
  category="mn",
  description="ARABIC SIGN ALAYHE ASSALLAM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0611,
 },
 [0x0612]={
  category="mn",
  description="ARABIC SIGN RAHMATULLAH ALAYHE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0612,
 },
 [0x0613]={
  category="mn",
  description="ARABIC SIGN RADI ALLAHOU ANHU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0613,
 },
 [0x0614]={
  category="mn",
  description="ARABIC SIGN TAKHALLUS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0614,
 },
 [0x0615]={
  category="mn",
  description="ARABIC SMALL HIGH TAH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0615,
 },
 [0x0616]={
  category="mn",
  description="ARABIC SMALL HIGH LIGATURE ALEF WITH LAM WITH YEH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0616,
 },
 [0x0617]={
  category="mn",
  description="ARABIC SMALL HIGH ZAIN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0617,
 },
 [0x0618]={
  category="mn",
  description="ARABIC SMALL FATHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0618,
 },
 [0x0619]={
  category="mn",
  description="ARABIC SMALL DAMMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0619,
 },
 [0x061A]={
  category="mn",
  description="ARABIC SMALL KASRA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x061A,
 },
 [0x061B]={
  adobename="semicolonarabic",
  category="po",
  description="ARABIC SEMICOLON",
  direction="al",
  linebreak="ex",
  unicodeslot=0x061B,
 },
 [0x061E]={
  category="po",
  description="ARABIC TRIPLE DOT PUNCTUATION MARK",
  direction="al",
  linebreak="ex",
  unicodeslot=0x061E,
 },
 [0x061F]={
  adobename="questionarabic",
  category="po",
  description="ARABIC QUESTION MARK",
  direction="al",
  linebreak="ex",
  unicodeslot=0x061F,
 },
 [0x0620]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KASHMIRI YEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0620,
 },
 [0x0621]={
  adobename="hamzasukunarabic",
  arabic="u",
  category="lo",
  description="ARABIC LETTER HAMZA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0621,
 },
 [0x0622]={
  adobename="alefmaddaabovearabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF WITH MADDA ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "char", 0x0627, 0x0653 },
  unicodeslot=0x0622,
 },
 [0x0623]={
  adobename="alefhamzaabovearabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF WITH HAMZA ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "char", 0x0627, 0x0654 },
  unicodeslot=0x0623,
 },
 [0x0624]={
  adobename="wawhamzaabovearabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER WAW WITH HAMZA ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0648,
  specials={ "char", 0x0648, 0x0654 },
  unicodeslot=0x0624,
 },
 [0x0625]={
  adobename="alefhamzabelowarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF WITH HAMZA BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "char", 0x0627, 0x0655 },
  unicodeslot=0x0625,
 },
 [0x0626]={
  adobename="yehhamzaabovearabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER YEH WITH HAMZA ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x064A,
  specials={ "char", 0x064A, 0x0654 },
  unicodeslot=0x0626,
 },
 [0x0627]={
  adobename="alefarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF",
  direction="al",
  linebreak="al",
  unicodeslot=0x0627,
 },
 [0x0628]={
  adobename="beharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0628,
 },
 [0x0629]={
  adobename="tehmarbutaarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER TEH MARBUTA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0629,
 },
 [0x062A]={
  adobename="teharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER TEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x062A,
 },
 [0x062B]={
  adobename="theharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER THEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x062B,
 },
 [0x062C]={
  adobename="jeemarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER JEEM",
  direction="al",
  linebreak="al",
  unicodeslot=0x062C,
 },
 [0x062D]={
  adobename="haharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH",
  direction="al",
  linebreak="al",
  unicodeslot=0x062D,
 },
 [0x062E]={
  adobename="khaharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER KHAH",
  direction="al",
  linebreak="al",
  unicodeslot=0x062E,
 },
 [0x062F]={
  adobename="dalarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x062F,
 },
 [0x0630]={
  adobename="thalarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER THAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x0630,
 },
 [0x0631]={
  adobename="rehyehaleflamarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0631,
 },
 [0x0632]={
  adobename="zainarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER ZAIN",
  direction="al",
  linebreak="al",
  unicodeslot=0x0632,
 },
 [0x0633]={
  adobename="seenarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN",
  direction="al",
  linebreak="al",
  unicodeslot=0x0633,
 },
 [0x0634]={
  adobename="sheenarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER SHEEN",
  direction="al",
  linebreak="al",
  unicodeslot=0x0634,
 },
 [0x0635]={
  adobename="sadarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER SAD",
  direction="al",
  linebreak="al",
  unicodeslot=0x0635,
 },
 [0x0636]={
  adobename="dadarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER DAD",
  direction="al",
  linebreak="al",
  unicodeslot=0x0636,
 },
 [0x0637]={
  adobename="taharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER TAH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0637,
 },
 [0x0638]={
  adobename="zaharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER ZAH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0638,
 },
 [0x0639]={
  adobename="ainarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER AIN",
  direction="al",
  linebreak="al",
  unicodeslot=0x0639,
 },
 [0x063A]={
  adobename="ghainarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER GHAIN",
  direction="al",
  linebreak="al",
  unicodeslot=0x063A,
 },
 [0x063B]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KEHEH WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x063B,
 },
 [0x063C]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KEHEH WITH THREE DOTS BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0x063C,
 },
 [0x063D]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FARSI YEH WITH INVERTED V",
  direction="al",
  linebreak="al",
  unicodeslot=0x063D,
 },
 [0x063E]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FARSI YEH WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x063E,
 },
 [0x063F]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FARSI YEH WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x063F,
 },
 [0x0640]={
  adobename="tatweelarabic",
  arabic="c",
  category="lm",
  description="ARABIC TATWEEL",
  direction="al",
  linebreak="al",
  unicodeslot=0x0640,
 },
 [0x0641]={
  adobename="feharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER FEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0641,
 },
 [0x0642]={
  adobename="qafarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER QAF",
  direction="al",
  linebreak="al",
  unicodeslot=0x0642,
 },
 [0x0643]={
  adobename="kafarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER KAF",
  direction="al",
  linebreak="al",
  unicodeslot=0x0643,
 },
 [0x0644]={
  adobename="lamarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER LAM",
  direction="al",
  linebreak="al",
  unicodeslot=0x0644,
 },
 [0x0645]={
  adobename="meemarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER MEEM",
  direction="al",
  linebreak="al",
  unicodeslot=0x0645,
 },
 [0x0646]={
  adobename="noonarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER NOON",
  direction="al",
  linebreak="al",
  unicodeslot=0x0646,
 },
 [0x0647]={
  adobename="heharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER HEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0647,
 },
 [0x0648]={
  adobename="wawarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER WAW",
  direction="al",
  linebreak="al",
  unicodeslot=0x0648,
 },
 [0x0649]={
  adobename="alefmaksuraarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER ALEF MAKSURA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0649,
 },
 [0x064A]={
  adobename="yeharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER YEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x064A,
 },
 [0x064B]={
  adobename="fathatanarabic",
  category="mn",
  description="ARABIC FATHATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x064B,
 },
 [0x064C]={
  adobename="dammatanarabic",
  category="mn",
  description="ARABIC DAMMATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x064C,
 },
 [0x064D]={
  adobename="kasratanarabic",
  category="mn",
  description="ARABIC KASRATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x064D,
 },
 [0x064E]={
  adobename="fathalowarabic",
  category="mn",
  description="ARABIC FATHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x064E,
 },
 [0x064F]={
  adobename="dammalowarabic",
  category="mn",
  description="ARABIC DAMMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x064F,
 },
 [0x0650]={
  adobename="kasraarabic",
  category="mn",
  description="ARABIC KASRA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0650,
 },
 [0x0651]={
  adobename="shaddafathatanarabic",
  category="mn",
  description="ARABIC SHADDA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0651,
 },
 [0x0652]={
  adobename="sukunarabic",
  category="mn",
  description="ARABIC SUKUN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0652,
 },
 [0x0653]={
  category="mn",
  description="ARABIC MADDAH ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0653,
 },
 [0x0654]={
  category="mn",
  description="ARABIC HAMZA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0654,
 },
 [0x0655]={
  category="mn",
  description="ARABIC HAMZA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0655,
 },
 [0x0656]={
  category="mn",
  description="ARABIC SUBSCRIPT ALEF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0656,
 },
 [0x0657]={
  category="mn",
  description="ARABIC INVERTED DAMMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0657,
 },
 [0x0658]={
  category="mn",
  description="ARABIC MARK NOON GHUNNA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0658,
 },
 [0x0659]={
  category="mn",
  description="ARABIC ZWARAKAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0659,
 },
 [0x065A]={
  category="mn",
  description="ARABIC VOWEL SIGN SMALL V ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x065A,
 },
 [0x065B]={
  category="mn",
  description="ARABIC VOWEL SIGN INVERTED SMALL V ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x065B,
 },
 [0x065C]={
  category="mn",
  description="ARABIC VOWEL SIGN DOT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x065C,
 },
 [0x065D]={
  category="mn",
  description="ARABIC REVERSED DAMMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x065D,
 },
 [0x065E]={
  category="mn",
  description="ARABIC FATHA WITH TWO DOTS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x065E,
 },
 [0x065F]={
  category="mn",
  description="ARABIC WAVY HAMZA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x065F,
 },
 [0x0660]={
  adobename="zerohackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT ZERO",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0660,
 },
 [0x0661]={
  adobename="onehackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT ONE",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0661,
 },
 [0x0662]={
  adobename="twohackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT TWO",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0662,
 },
 [0x0663]={
  adobename="threehackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT THREE",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0663,
 },
 [0x0664]={
  adobename="fourhackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT FOUR",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0664,
 },
 [0x0665]={
  adobename="fivehackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT FIVE",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0665,
 },
 [0x0666]={
  adobename="sixhackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT SIX",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0666,
 },
 [0x0667]={
  adobename="sevenhackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT SEVEN",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0667,
 },
 [0x0668]={
  adobename="eighthackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT EIGHT",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0668,
 },
 [0x0669]={
  adobename="ninehackarabic",
  category="nd",
  description="ARABIC-INDIC DIGIT NINE",
  direction="an",
  linebreak="nu",
  unicodeslot=0x0669,
 },
 [0x066A]={
  adobename="percentarabic",
  category="po",
  description="ARABIC PERCENT SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x066A,
 },
 [0x066B]={
  adobename="decimalseparatorpersian",
  category="po",
  description="ARABIC DECIMAL SEPARATOR",
  direction="an",
  linebreak="nu",
  unicodeslot=0x066B,
 },
 [0x066C]={
  adobename="thousandsseparatorpersian",
  category="po",
  description="ARABIC THOUSANDS SEPARATOR",
  direction="an",
  linebreak="nu",
  unicodeslot=0x066C,
 },
 [0x066D]={
  adobename="asteriskarabic",
  category="po",
  description="ARABIC FIVE POINTED STAR",
  direction="al",
  linebreak="al",
  unicodeslot=0x066D,
 },
 [0x066E]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER DOTLESS BEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x066E,
 },
 [0x066F]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER DOTLESS QAF",
  direction="al",
  linebreak="al",
  unicodeslot=0x066F,
 },
 [0x0670]={
  category="mn",
  description="ARABIC LETTER SUPERSCRIPT ALEF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0670,
 },
 [0x0671]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF WASLA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0671,
 },
 [0x0672]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF WITH WAVY HAMZA ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  unicodeslot=0x0672,
 },
 [0x0673]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF WITH WAVY HAMZA BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  unicodeslot=0x0673,
 },
 [0x0674]={
  arabic="u",
  category="lo",
  description="ARABIC LETTER HIGH HAMZA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0674,
 },
 [0x0675]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER HIGH HAMZA ALEF",
  direction="al",
  linebreak="al",
  specials={ "compat", 0x0627, 0x0674 },
  unicodeslot=0x0675,
 },
 [0x0676]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER HIGH HAMZA WAW",
  direction="al",
  linebreak="al",
  specials={ "compat", 0x0648, 0x0674 },
  unicodeslot=0x0676,
 },
 [0x0677]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER U WITH HAMZA ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x06C7,
  specials={ "compat", 0x06C7, 0x0674 },
  unicodeslot=0x0677,
 },
 [0x0678]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HIGH HAMZA YEH",
  direction="al",
  linebreak="al",
  specials={ "compat", 0x064A, 0x0674 },
  unicodeslot=0x0678,
 },
 [0x0679]={
  adobename="tteharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER TTEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0679,
 },
 [0x067A]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER TTEHEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x067A,
 },
 [0x067B]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x067B,
 },
 [0x067C]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER TEH WITH RING",
  direction="al",
  linebreak="al",
  shcode=0x062A,
  unicodeslot=0x067C,
 },
 [0x067D]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER TEH WITH THREE DOTS ABOVE DOWNWARDS",
  direction="al",
  linebreak="al",
  shcode=0x062A,
  unicodeslot=0x067D,
 },
 [0x067E]={
  adobename="peharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER PEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x067E,
 },
 [0x067F]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER TEHEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x067F,
 },
 [0x0680]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEHEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0680,
 },
 [0x0681]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH HAMZA ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x062D,
  unicodeslot=0x0681,
 },
 [0x0682]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH TWO DOTS VERTICAL ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x062D,
  unicodeslot=0x0682,
 },
 [0x0683]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NYEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0683,
 },
 [0x0684]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER DYEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0684,
 },
 [0x0685]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x062D,
  unicodeslot=0x0685,
 },
 [0x0686]={
  adobename="tcheharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER TCHEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0686,
 },
 [0x0687]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER TCHEHEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0687,
 },
 [0x0688]={
  adobename="ddalarabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER DDAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x0688,
 },
 [0x0689]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL WITH RING",
  direction="al",
  linebreak="al",
  shcode=0x062F,
  unicodeslot=0x0689,
 },
 [0x068A]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL WITH DOT BELOW",
  direction="al",
  linebreak="al",
  shcode=0x062F,
  unicodeslot=0x068A,
 },
 [0x068B]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL WITH DOT BELOW AND SMALL TAH",
  direction="al",
  linebreak="al",
  shcode=0x062F,
  unicodeslot=0x068B,
 },
 [0x068C]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAHAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x068C,
 },
 [0x068D]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DDAHAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x068D,
 },
 [0x068E]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DUL",
  direction="al",
  linebreak="al",
  unicodeslot=0x068E,
 },
 [0x068F]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL WITH THREE DOTS ABOVE DOWNWARDS",
  direction="al",
  linebreak="al",
  shcode=0x062F,
  unicodeslot=0x068F,
 },
 [0x0690]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL WITH FOUR DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x062F,
  unicodeslot=0x0690,
 },
 [0x0691]={
  adobename="rreharabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER RREH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0691,
 },
 [0x0692]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH SMALL V",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x0692,
 },
 [0x0693]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH RING",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x0693,
 },
 [0x0694]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH DOT BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x0694,
 },
 [0x0695]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH SMALL V BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x0695,
 },
 [0x0696]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH DOT BELOW AND DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x0696,
 },
 [0x0697]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x0697,
 },
 [0x0698]={
  adobename="jeharabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER JEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0698,
 },
 [0x0699]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH FOUR DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x0699,
 },
 [0x069A]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN WITH DOT BELOW AND DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0633,
  unicodeslot=0x069A,
 },
 [0x069B]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN WITH THREE DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0633,
  unicodeslot=0x069B,
 },
 [0x069C]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN WITH THREE DOTS BELOW AND THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0633,
  unicodeslot=0x069C,
 },
 [0x069D]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SAD WITH TWO DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0635,
  unicodeslot=0x069D,
 },
 [0x069E]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SAD WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0635,
  unicodeslot=0x069E,
 },
 [0x069F]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER TAH WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0637,
  unicodeslot=0x069F,
 },
 [0x06A0]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER AIN WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0639,
  unicodeslot=0x06A0,
 },
 [0x06A1]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER DOTLESS FEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x06A1,
 },
 [0x06A2]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FEH WITH DOT MOVED BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0641,
  unicodeslot=0x06A2,
 },
 [0x06A3]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FEH WITH DOT BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0641,
  unicodeslot=0x06A3,
 },
 [0x06A4]={
  adobename="veharabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER VEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x06A4,
 },
 [0x06A5]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FEH WITH THREE DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0641,
  unicodeslot=0x06A5,
 },
 [0x06A6]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER PEHEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x06A6,
 },
 [0x06A7]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER QAF WITH DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0642,
  unicodeslot=0x06A7,
 },
 [0x06A8]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER QAF WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0642,
  unicodeslot=0x06A8,
 },
 [0x06A9]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KEHEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x06A9,
 },
 [0x06AA]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SWASH KAF",
  direction="al",
  linebreak="al",
  unicodeslot=0x06AA,
 },
 [0x06AB]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KAF WITH RING",
  direction="al",
  linebreak="al",
  shcode=0x0643,
  unicodeslot=0x06AB,
 },
 [0x06AC]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KAF WITH DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0643,
  unicodeslot=0x06AC,
 },
 [0x06AD]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NG",
  direction="al",
  linebreak="al",
  unicodeslot=0x06AD,
 },
 [0x06AE]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KAF WITH THREE DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0643,
  unicodeslot=0x06AE,
 },
 [0x06AF]={
  adobename="gafarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER GAF",
  direction="al",
  linebreak="al",
  unicodeslot=0x06AF,
 },
 [0x06B0]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER GAF WITH RING",
  direction="al",
  linebreak="al",
  shcode=0x06AF,
  unicodeslot=0x06B0,
 },
 [0x06B1]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NGOEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x06B1,
 },
 [0x06B2]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER GAF WITH TWO DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x06AF,
  unicodeslot=0x06B2,
 },
 [0x06B3]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER GUEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x06B3,
 },
 [0x06B4]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER GAF WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x06AF,
  unicodeslot=0x06B4,
 },
 [0x06B5]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER LAM WITH SMALL V",
  direction="al",
  linebreak="al",
  shcode=0x0644,
  unicodeslot=0x06B5,
 },
 [0x06B6]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER LAM WITH DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0644,
  unicodeslot=0x06B6,
 },
 [0x06B7]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER LAM WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0644,
  unicodeslot=0x06B7,
 },
 [0x06B8]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER LAM WITH THREE DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0644,
  unicodeslot=0x06B8,
 },
 [0x06B9]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NOON WITH DOT BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0646,
  unicodeslot=0x06B9,
 },
 [0x06BA]={
  adobename="noonghunnaarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER NOON GHUNNA",
  direction="al",
  linebreak="al",
  unicodeslot=0x06BA,
 },
 [0x06BB]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER RNOON",
  direction="al",
  linebreak="al",
  unicodeslot=0x06BB,
 },
 [0x06BC]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NOON WITH RING",
  direction="al",
  linebreak="al",
  shcode=0x0646,
  unicodeslot=0x06BC,
 },
 [0x06BD]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NOON WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0646,
  unicodeslot=0x06BD,
 },
 [0x06BE]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HEH DOACHASHMEE",
  direction="al",
  linebreak="al",
  unicodeslot=0x06BE,
 },
 [0x06BF]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER TCHEH WITH DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0686,
  unicodeslot=0x06BF,
 },
 [0x06C0]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER HEH WITH YEH ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0647,
  specials={ "char", 0x06D5, 0x0654 },
  unicodeslot=0x06C0,
 },
 [0x06C1]={
  adobename="hehaltonearabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER HEH GOAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x06C1,
 },
 [0x06C2]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HEH GOAL WITH HAMZA ABOVE",
  direction="al",
  linebreak="al",
  specials={ "char", 0x06C1, 0x0654 },
  unicodeslot=0x06C2,
 },
 [0x06C3]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER TEH MARBUTA GOAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x06C3,
 },
 [0x06C4]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER WAW WITH RING",
  direction="al",
  linebreak="al",
  shcode=0x0648,
  unicodeslot=0x06C4,
 },
 [0x06C5]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER KIRGHIZ OE",
  direction="al",
  linebreak="al",
  unicodeslot=0x06C5,
 },
 [0x06C6]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER OE",
  direction="al",
  linebreak="al",
  unicodeslot=0x06C6,
 },
 [0x06C7]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER U",
  direction="al",
  linebreak="al",
  unicodeslot=0x06C7,
 },
 [0x06C8]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER YU",
  direction="al",
  linebreak="al",
  unicodeslot=0x06C8,
 },
 [0x06C9]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER KIRGHIZ YU",
  direction="al",
  linebreak="al",
  unicodeslot=0x06C9,
 },
 [0x06CA]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER WAW WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0648,
  unicodeslot=0x06CA,
 },
 [0x06CB]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER VE",
  direction="al",
  linebreak="al",
  unicodeslot=0x06CB,
 },
 [0x06CC]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FARSI YEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x06CC,
 },
 [0x06CD]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER YEH WITH TAIL",
  direction="al",
  linebreak="al",
  shcode=0x064A,
  unicodeslot=0x06CD,
 },
 [0x06CE]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER YEH WITH SMALL V",
  direction="al",
  linebreak="al",
  shcode=0x064A,
  unicodeslot=0x06CE,
 },
 [0x06CF]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER WAW WITH DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0648,
  unicodeslot=0x06CF,
 },
 [0x06D0]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER E",
  direction="al",
  linebreak="al",
  unicodeslot=0x06D0,
 },
 [0x06D1]={
  adobename="yehthreedotsbelowarabic",
  arabic="d",
  category="lo",
  description="ARABIC LETTER YEH WITH THREE DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x064A,
  unicodeslot=0x06D1,
 },
 [0x06D2]={
  adobename="yehbarreearabic",
  arabic="r",
  category="lo",
  description="ARABIC LETTER YEH BARREE",
  direction="al",
  linebreak="al",
  unicodeslot=0x06D2,
 },
 [0x06D3]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER YEH BARREE WITH HAMZA ABOVE",
  direction="al",
  linebreak="al",
  specials={ "char", 0x06D2, 0x0654 },
  unicodeslot=0x06D3,
 },
 [0x06D4]={
  category="po",
  description="ARABIC FULL STOP",
  direction="al",
  linebreak="ex",
  unicodeslot=0x06D4,
 },
 [0x06D5]={
  adobename="afii57534",
  arabic="r",
  category="lo",
  description="ARABIC LETTER AE",
  direction="al",
  linebreak="al",
  unicodeslot=0x06D5,
 },
 [0x06D6]={
  category="mn",
  description="ARABIC SMALL HIGH LIGATURE SAD WITH LAM WITH ALEF MAKSURA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06D6,
 },
 [0x06D7]={
  category="mn",
  description="ARABIC SMALL HIGH LIGATURE QAF WITH LAM WITH ALEF MAKSURA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06D7,
 },
 [0x06D8]={
  category="mn",
  description="ARABIC SMALL HIGH MEEM INITIAL FORM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06D8,
 },
 [0x06D9]={
  category="mn",
  description="ARABIC SMALL HIGH LAM ALEF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06D9,
 },
 [0x06DA]={
  category="mn",
  description="ARABIC SMALL HIGH JEEM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06DA,
 },
 [0x06DB]={
  category="mn",
  description="ARABIC SMALL HIGH THREE DOTS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06DB,
 },
 [0x06DC]={
  category="mn",
  description="ARABIC SMALL HIGH SEEN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06DC,
 },
 [0x06DD]={
  arabic="u",
  category="cf",
  description="ARABIC END OF AYAH",
  direction="an",
  linebreak="al",
  unicodeslot=0x06DD,
  visible="yes",
 },
 [0x06DE]={
  category="me",
  description="ARABIC START OF RUB EL HIZB",
  direction="on",
  linebreak="al",
  unicodeslot=0x06DE,
 },
 [0x06DF]={
  category="mn",
  description="ARABIC SMALL HIGH ROUNDED ZERO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06DF,
 },
 [0x06E0]={
  category="mn",
  description="ARABIC SMALL HIGH UPRIGHT RECTANGULAR ZERO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06E0,
 },
 [0x06E1]={
  category="mn",
  description="ARABIC SMALL HIGH DOTLESS HEAD OF KHAH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06E1,
 },
 [0x06E2]={
  category="mn",
  description="ARABIC SMALL HIGH MEEM ISOLATED FORM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06E2,
 },
 [0x06E3]={
  category="mn",
  description="ARABIC SMALL LOW SEEN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06E3,
 },
 [0x06E4]={
  category="mn",
  description="ARABIC SMALL HIGH MADDA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06E4,
 },
 [0x06E5]={
  category="lm",
  description="ARABIC SMALL WAW",
  direction="al",
  linebreak="al",
  unicodeslot=0x06E5,
 },
 [0x06E6]={
  category="lm",
  description="ARABIC SMALL YEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x06E6,
 },
 [0x06E7]={
  category="mn",
  description="ARABIC SMALL HIGH YEH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06E7,
 },
 [0x06E8]={
  category="mn",
  description="ARABIC SMALL HIGH NOON",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06E8,
 },
 [0x06E9]={
  category="so",
  description="ARABIC PLACE OF SAJDAH",
  direction="on",
  linebreak="al",
  unicodeslot=0x06E9,
 },
 [0x06EA]={
  category="mn",
  description="ARABIC EMPTY CENTRE LOW STOP",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06EA,
 },
 [0x06EB]={
  category="mn",
  description="ARABIC EMPTY CENTRE HIGH STOP",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06EB,
 },
 [0x06EC]={
  category="mn",
  description="ARABIC ROUNDED HIGH STOP WITH FILLED CENTRE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06EC,
 },
 [0x06ED]={
  category="mn",
  description="ARABIC SMALL LOW MEEM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x06ED,
 },
 [0x06EE]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL WITH INVERTED V",
  direction="al",
  linebreak="al",
  shcode=0x062F,
  unicodeslot=0x06EE,
 },
 [0x06EF]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH INVERTED V",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x06EF,
 },
 [0x06F0]={
  adobename="zeropersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT ZERO",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F0,
 },
 [0x06F1]={
  adobename="onepersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT ONE",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F1,
 },
 [0x06F2]={
  adobename="twopersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT TWO",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F2,
 },
 [0x06F3]={
  adobename="threepersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT THREE",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F3,
 },
 [0x06F4]={
  adobename="fourpersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT FOUR",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F4,
 },
 [0x06F5]={
  adobename="fivepersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT FIVE",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F5,
 },
 [0x06F6]={
  adobename="sixpersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT SIX",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F6,
 },
 [0x06F7]={
  adobename="sevenpersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT SEVEN",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F7,
 },
 [0x06F8]={
  adobename="eightpersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT EIGHT",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F8,
 },
 [0x06F9]={
  adobename="ninepersian",
  category="nd",
  description="EXTENDED ARABIC-INDIC DIGIT NINE",
  direction="en",
  linebreak="nu",
  unicodeslot=0x06F9,
 },
 [0x06FA]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SHEEN WITH DOT BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0634,
  unicodeslot=0x06FA,
 },
 [0x06FB]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER DAD WITH DOT BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0636,
  unicodeslot=0x06FB,
 },
 [0x06FC]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER GHAIN WITH DOT BELOW",
  direction="al",
  linebreak="al",
  shcode=0x063A,
  unicodeslot=0x06FC,
 },
 [0x06FD]={
  category="so",
  description="ARABIC SIGN SINDHI AMPERSAND",
  direction="al",
  linebreak="al",
  unicodeslot=0x06FD,
 },
 [0x06FE]={
  category="so",
  description="ARABIC SIGN SINDHI POSTPOSITION MEN",
  direction="al",
  linebreak="al",
  unicodeslot=0x06FE,
 },
 [0x06FF]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HEH WITH INVERTED V",
  direction="al",
  linebreak="al",
  shcode=0x0647,
  unicodeslot=0x06FF,
 },
 [0x0700]={
  category="po",
  description="SYRIAC END OF PARAGRAPH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0700,
 },
 [0x0701]={
  category="po",
  description="SYRIAC SUPRALINEAR FULL STOP",
  direction="al",
  linebreak="al",
  unicodeslot=0x0701,
 },
 [0x0702]={
  category="po",
  description="SYRIAC SUBLINEAR FULL STOP",
  direction="al",
  linebreak="al",
  unicodeslot=0x0702,
 },
 [0x0703]={
  category="po",
  description="SYRIAC SUPRALINEAR COLON",
  direction="al",
  linebreak="al",
  unicodeslot=0x0703,
 },
 [0x0704]={
  category="po",
  description="SYRIAC SUBLINEAR COLON",
  direction="al",
  linebreak="al",
  unicodeslot=0x0704,
 },
 [0x0705]={
  category="po",
  description="SYRIAC HORIZONTAL COLON",
  direction="al",
  linebreak="al",
  unicodeslot=0x0705,
 },
 [0x0706]={
  category="po",
  description="SYRIAC COLON SKEWED LEFT",
  direction="al",
  linebreak="al",
  unicodeslot=0x0706,
 },
 [0x0707]={
  category="po",
  description="SYRIAC COLON SKEWED RIGHT",
  direction="al",
  linebreak="al",
  unicodeslot=0x0707,
 },
 [0x0708]={
  category="po",
  description="SYRIAC SUPRALINEAR COLON SKEWED LEFT",
  direction="al",
  linebreak="al",
  unicodeslot=0x0708,
 },
 [0x0709]={
  category="po",
  description="SYRIAC SUBLINEAR COLON SKEWED RIGHT",
  direction="al",
  linebreak="al",
  unicodeslot=0x0709,
 },
 [0x070A]={
  category="po",
  description="SYRIAC CONTRACTION",
  direction="al",
  linebreak="al",
  unicodeslot=0x070A,
 },
 [0x070B]={
  category="po",
  description="SYRIAC HARKLEAN OBELUS",
  direction="al",
  linebreak="al",
  unicodeslot=0x070B,
 },
 [0x070C]={
  category="po",
  description="SYRIAC HARKLEAN METOBELUS",
  direction="al",
  linebreak="al",
  unicodeslot=0x070C,
 },
 [0x070D]={
  category="po",
  description="SYRIAC HARKLEAN ASTERISCUS",
  direction="al",
  linebreak="al",
  unicodeslot=0x070D,
 },
 [0x070F]={
  category="cf",
  description="SYRIAC ABBREVIATION MARK",
  direction="al",
  linebreak="al",
  unicodeslot=0x070F,
  visible="yes",
 },
 [0x0710]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER ALAPH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0710,
 },
 [0x0711]={
  category="mn",
  description="SYRIAC LETTER SUPERSCRIPT ALAPH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0711,
 },
 [0x0712]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER BETH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0712,
 },
 [0x0713]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER GAMAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x0713,
 },
 [0x0714]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER GAMAL GARSHUNI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0714,
 },
 [0x0715]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER DALATH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0715,
 },
 [0x0716]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER DOTLESS DALATH RISH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0716,
 },
 [0x0717]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER HE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0717,
 },
 [0x0718]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER WAW",
  direction="al",
  linebreak="al",
  unicodeslot=0x0718,
 },
 [0x0719]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER ZAIN",
  direction="al",
  linebreak="al",
  unicodeslot=0x0719,
 },
 [0x071A]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER HETH",
  direction="al",
  linebreak="al",
  unicodeslot=0x071A,
 },
 [0x071B]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER TETH",
  direction="al",
  linebreak="al",
  unicodeslot=0x071B,
 },
 [0x071C]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER TETH GARSHUNI",
  direction="al",
  linebreak="al",
  unicodeslot=0x071C,
 },
 [0x071D]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER YUDH",
  direction="al",
  linebreak="al",
  unicodeslot=0x071D,
 },
 [0x071E]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER YUDH HE",
  direction="al",
  linebreak="al",
  unicodeslot=0x071E,
 },
 [0x071F]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER KAPH",
  direction="al",
  linebreak="al",
  unicodeslot=0x071F,
 },
 [0x0720]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER LAMADH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0720,
 },
 [0x0721]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER MIM",
  direction="al",
  linebreak="al",
  unicodeslot=0x0721,
 },
 [0x0722]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER NUN",
  direction="al",
  linebreak="al",
  unicodeslot=0x0722,
 },
 [0x0723]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER SEMKATH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0723,
 },
 [0x0724]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER FINAL SEMKATH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0724,
 },
 [0x0725]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER E",
  direction="al",
  linebreak="al",
  unicodeslot=0x0725,
 },
 [0x0726]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER PE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0726,
 },
 [0x0727]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER REVERSED PE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0727,
 },
 [0x0728]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER SADHE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0728,
 },
 [0x0729]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER QAPH",
  direction="al",
  linebreak="al",
  unicodeslot=0x0729,
 },
 [0x072A]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER RISH",
  direction="al",
  linebreak="al",
  unicodeslot=0x072A,
 },
 [0x072B]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER SHIN",
  direction="al",
  linebreak="al",
  unicodeslot=0x072B,
 },
 [0x072C]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER TAW",
  direction="al",
  linebreak="al",
  unicodeslot=0x072C,
 },
 [0x072D]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER PERSIAN BHETH",
  direction="al",
  linebreak="al",
  unicodeslot=0x072D,
 },
 [0x072E]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER PERSIAN GHAMAL",
  direction="al",
  linebreak="al",
  unicodeslot=0x072E,
 },
 [0x072F]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER PERSIAN DHALATH",
  direction="al",
  linebreak="al",
  unicodeslot=0x072F,
 },
 [0x0730]={
  category="mn",
  description="SYRIAC PTHAHA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0730,
 },
 [0x0731]={
  category="mn",
  description="SYRIAC PTHAHA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0731,
 },
 [0x0732]={
  category="mn",
  description="SYRIAC PTHAHA DOTTED",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0732,
 },
 [0x0733]={
  category="mn",
  description="SYRIAC ZQAPHA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0733,
 },
 [0x0734]={
  category="mn",
  description="SYRIAC ZQAPHA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0734,
 },
 [0x0735]={
  category="mn",
  description="SYRIAC ZQAPHA DOTTED",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0735,
 },
 [0x0736]={
  category="mn",
  description="SYRIAC RBASA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0736,
 },
 [0x0737]={
  category="mn",
  description="SYRIAC RBASA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0737,
 },
 [0x0738]={
  category="mn",
  description="SYRIAC DOTTED ZLAMA HORIZONTAL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0738,
 },
 [0x0739]={
  category="mn",
  description="SYRIAC DOTTED ZLAMA ANGULAR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0739,
 },
 [0x073A]={
  category="mn",
  description="SYRIAC HBASA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x073A,
 },
 [0x073B]={
  category="mn",
  description="SYRIAC HBASA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x073B,
 },
 [0x073C]={
  category="mn",
  description="SYRIAC HBASA-ESASA DOTTED",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x073C,
 },
 [0x073D]={
  category="mn",
  description="SYRIAC ESASA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x073D,
 },
 [0x073E]={
  category="mn",
  description="SYRIAC ESASA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x073E,
 },
 [0x073F]={
  category="mn",
  description="SYRIAC RWAHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x073F,
 },
 [0x0740]={
  category="mn",
  description="SYRIAC FEMININE DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0740,
 },
 [0x0741]={
  category="mn",
  description="SYRIAC QUSHSHAYA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0741,
 },
 [0x0742]={
  category="mn",
  description="SYRIAC RUKKAKHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0742,
 },
 [0x0743]={
  category="mn",
  description="SYRIAC TWO VERTICAL DOTS ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0743,
 },
 [0x0744]={
  category="mn",
  description="SYRIAC TWO VERTICAL DOTS BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0744,
 },
 [0x0745]={
  category="mn",
  description="SYRIAC THREE DOTS ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0745,
 },
 [0x0746]={
  category="mn",
  description="SYRIAC THREE DOTS BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0746,
 },
 [0x0747]={
  category="mn",
  description="SYRIAC OBLIQUE LINE ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0747,
 },
 [0x0748]={
  category="mn",
  description="SYRIAC OBLIQUE LINE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0748,
 },
 [0x0749]={
  category="mn",
  description="SYRIAC MUSIC",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0749,
 },
 [0x074A]={
  category="mn",
  description="SYRIAC BARREKH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x074A,
 },
 [0x074D]={
  arabic="r",
  category="lo",
  description="SYRIAC LETTER SOGDIAN ZHAIN",
  direction="al",
  linebreak="al",
  unicodeslot=0x074D,
 },
 [0x074E]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER SOGDIAN KHAPH",
  direction="al",
  linebreak="al",
  unicodeslot=0x074E,
 },
 [0x074F]={
  arabic="d",
  category="lo",
  description="SYRIAC LETTER SOGDIAN FE",
  direction="al",
  linebreak="al",
  unicodeslot=0x074F,
 },
 [0x0750]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH WITH THREE DOTS HORIZONTALLY BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0628,
  unicodeslot=0x0750,
 },
 [0x0751]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH WITH DOT BELOW AND THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0628,
  unicodeslot=0x0751,
 },
 [0x0752]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0628,
  unicodeslot=0x0752,
 },
 [0x0753]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW AND TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0628,
  unicodeslot=0x0753,
 },
 [0x0754]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH WITH TWO DOTS BELOW AND DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0628,
  unicodeslot=0x0754,
 },
 [0x0755]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH WITH INVERTED SMALL V BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0628,
  unicodeslot=0x0755,
 },
 [0x0756]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH WITH SMALL V",
  direction="al",
  linebreak="al",
  shcode=0x0628,
  unicodeslot=0x0756,
 },
 [0x0757]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x062D,
  unicodeslot=0x0757,
 },
 [0x0758]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH THREE DOTS POINTING UPWARDS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x062D,
  unicodeslot=0x0758,
 },
 [0x0759]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL WITH TWO DOTS VERTICALLY BELOW AND SMALL TAH",
  direction="al",
  linebreak="al",
  shcode=0x062F,
  unicodeslot=0x0759,
 },
 [0x075A]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER DAL WITH INVERTED SMALL V BELOW",
  direction="al",
  linebreak="al",
  shcode=0x062F,
  unicodeslot=0x075A,
 },
 [0x075B]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH STROKE",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x075B,
 },
 [0x075C]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN WITH FOUR DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0633,
  unicodeslot=0x075C,
 },
 [0x075D]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER AIN WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0639,
  unicodeslot=0x075D,
 },
 [0x075E]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER AIN WITH THREE DOTS POINTING DOWNWARDS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0639,
  unicodeslot=0x075E,
 },
 [0x075F]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER AIN WITH TWO DOTS VERTICALLY ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0639,
  unicodeslot=0x075F,
 },
 [0x0760]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FEH WITH TWO DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0641,
  unicodeslot=0x0760,
 },
 [0x0761]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FEH WITH THREE DOTS POINTING UPWARDS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0641,
  unicodeslot=0x0761,
 },
 [0x0762]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KEHEH WITH DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x06A9,
  unicodeslot=0x0762,
 },
 [0x0763]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KEHEH WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x06A9,
  unicodeslot=0x0763,
 },
 [0x0764]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KEHEH WITH THREE DOTS POINTING UPWARDS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x06A9,
  unicodeslot=0x0764,
 },
 [0x0765]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER MEEM WITH DOT ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0645,
  unicodeslot=0x0765,
 },
 [0x0766]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER MEEM WITH DOT BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0645,
  unicodeslot=0x0766,
 },
 [0x0767]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NOON WITH TWO DOTS BELOW",
  direction="al",
  linebreak="al",
  shcode=0x0646,
  unicodeslot=0x0767,
 },
 [0x0768]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NOON WITH SMALL TAH",
  direction="al",
  linebreak="al",
  shcode=0x0646,
  unicodeslot=0x0768,
 },
 [0x0769]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER NOON WITH SMALL V",
  direction="al",
  linebreak="al",
  shcode=0x0646,
  unicodeslot=0x0769,
 },
 [0x076A]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER LAM WITH BAR",
  direction="al",
  linebreak="al",
  shcode=0x0644,
  unicodeslot=0x076A,
 },
 [0x076B]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH TWO DOTS VERTICALLY ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x076B,
 },
 [0x076C]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH HAMZA ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0631,
  unicodeslot=0x076C,
 },
 [0x076D]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN WITH TWO DOTS VERTICALLY ABOVE",
  direction="al",
  linebreak="al",
  shcode=0x0633,
  unicodeslot=0x076D,
 },
 [0x076E]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0x076E,
 },
 [0x076F]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH AND TWO DOTS",
  direction="al",
  linebreak="al",
  unicodeslot=0x076F,
 },
 [0x0770]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN WITH SMALL ARABIC LETTER TAH AND TWO DOTS",
  direction="al",
  linebreak="al",
  unicodeslot=0x0770,
 },
 [0x0771]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH SMALL ARABIC LETTER TAH AND TWO DOTS",
  direction="al",
  linebreak="al",
  unicodeslot=0x0771,
 },
 [0x0772]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0772,
 },
 [0x0773]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0773,
 },
 [0x0774]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0774,
 },
 [0x0775]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0775,
 },
 [0x0776]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0776,
 },
 [0x0777]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0x0777,
 },
 [0x0778]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0778,
 },
 [0x0779]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x0779,
 },
 [0x077A]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x077A,
 },
 [0x077B]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x077B,
 },
 [0x077C]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER HAH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0x077C,
 },
 [0x077D]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN WITH EXTENDED ARABIC-INDIC DIGIT FOUR ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x077D,
 },
 [0x077E]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER SEEN WITH INVERTED V",
  direction="al",
  linebreak="al",
  unicodeslot=0x077E,
 },
 [0x077F]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER KAF WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x077F,
 },
 [0x0780]={
  category="lo",
  description="THAANA LETTER HAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0780,
 },
 [0x0781]={
  category="lo",
  description="THAANA LETTER SHAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0781,
 },
 [0x0782]={
  category="lo",
  description="THAANA LETTER NOONU",
  direction="al",
  linebreak="al",
  unicodeslot=0x0782,
 },
 [0x0783]={
  category="lo",
  description="THAANA LETTER RAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0783,
 },
 [0x0784]={
  category="lo",
  description="THAANA LETTER BAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0784,
 },
 [0x0785]={
  category="lo",
  description="THAANA LETTER LHAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0785,
 },
 [0x0786]={
  category="lo",
  description="THAANA LETTER KAAFU",
  direction="al",
  linebreak="al",
  unicodeslot=0x0786,
 },
 [0x0787]={
  category="lo",
  description="THAANA LETTER ALIFU",
  direction="al",
  linebreak="al",
  unicodeslot=0x0787,
 },
 [0x0788]={
  category="lo",
  description="THAANA LETTER VAAVU",
  direction="al",
  linebreak="al",
  unicodeslot=0x0788,
 },
 [0x0789]={
  category="lo",
  description="THAANA LETTER MEEMU",
  direction="al",
  linebreak="al",
  unicodeslot=0x0789,
 },
 [0x078A]={
  category="lo",
  description="THAANA LETTER FAAFU",
  direction="al",
  linebreak="al",
  unicodeslot=0x078A,
 },
 [0x078B]={
  category="lo",
  description="THAANA LETTER DHAALU",
  direction="al",
  linebreak="al",
  unicodeslot=0x078B,
 },
 [0x078C]={
  category="lo",
  description="THAANA LETTER THAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x078C,
 },
 [0x078D]={
  category="lo",
  description="THAANA LETTER LAAMU",
  direction="al",
  linebreak="al",
  unicodeslot=0x078D,
 },
 [0x078E]={
  category="lo",
  description="THAANA LETTER GAAFU",
  direction="al",
  linebreak="al",
  unicodeslot=0x078E,
 },
 [0x078F]={
  category="lo",
  description="THAANA LETTER GNAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x078F,
 },
 [0x0790]={
  category="lo",
  description="THAANA LETTER SEENU",
  direction="al",
  linebreak="al",
  unicodeslot=0x0790,
 },
 [0x0791]={
  category="lo",
  description="THAANA LETTER DAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0791,
 },
 [0x0792]={
  category="lo",
  description="THAANA LETTER ZAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0792,
 },
 [0x0793]={
  category="lo",
  description="THAANA LETTER TAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0793,
 },
 [0x0794]={
  category="lo",
  description="THAANA LETTER YAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0794,
 },
 [0x0795]={
  category="lo",
  description="THAANA LETTER PAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0795,
 },
 [0x0796]={
  category="lo",
  description="THAANA LETTER JAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0796,
 },
 [0x0797]={
  category="lo",
  description="THAANA LETTER CHAVIYANI",
  direction="al",
  linebreak="al",
  unicodeslot=0x0797,
 },
 [0x0798]={
  category="lo",
  description="THAANA LETTER TTAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0798,
 },
 [0x0799]={
  category="lo",
  description="THAANA LETTER HHAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x0799,
 },
 [0x079A]={
  category="lo",
  description="THAANA LETTER KHAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x079A,
 },
 [0x079B]={
  category="lo",
  description="THAANA LETTER THAALU",
  direction="al",
  linebreak="al",
  unicodeslot=0x079B,
 },
 [0x079C]={
  category="lo",
  description="THAANA LETTER ZAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x079C,
 },
 [0x079D]={
  category="lo",
  description="THAANA LETTER SHEENU",
  direction="al",
  linebreak="al",
  unicodeslot=0x079D,
 },
 [0x079E]={
  category="lo",
  description="THAANA LETTER SAADHU",
  direction="al",
  linebreak="al",
  unicodeslot=0x079E,
 },
 [0x079F]={
  category="lo",
  description="THAANA LETTER DAADHU",
  direction="al",
  linebreak="al",
  unicodeslot=0x079F,
 },
 [0x07A0]={
  category="lo",
  description="THAANA LETTER TO",
  direction="al",
  linebreak="al",
  unicodeslot=0x07A0,
 },
 [0x07A1]={
  category="lo",
  description="THAANA LETTER ZO",
  direction="al",
  linebreak="al",
  unicodeslot=0x07A1,
 },
 [0x07A2]={
  category="lo",
  description="THAANA LETTER AINU",
  direction="al",
  linebreak="al",
  unicodeslot=0x07A2,
 },
 [0x07A3]={
  category="lo",
  description="THAANA LETTER GHAINU",
  direction="al",
  linebreak="al",
  unicodeslot=0x07A3,
 },
 [0x07A4]={
  category="lo",
  description="THAANA LETTER QAAFU",
  direction="al",
  linebreak="al",
  unicodeslot=0x07A4,
 },
 [0x07A5]={
  category="lo",
  description="THAANA LETTER WAAVU",
  direction="al",
  linebreak="al",
  unicodeslot=0x07A5,
 },
 [0x07A6]={
  category="mn",
  description="THAANA ABAFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07A6,
 },
 [0x07A7]={
  category="mn",
  description="THAANA AABAAFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07A7,
 },
 [0x07A8]={
  category="mn",
  description="THAANA IBIFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07A8,
 },
 [0x07A9]={
  category="mn",
  description="THAANA EEBEEFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07A9,
 },
 [0x07AA]={
  category="mn",
  description="THAANA UBUFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07AA,
 },
 [0x07AB]={
  category="mn",
  description="THAANA OOBOOFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07AB,
 },
 [0x07AC]={
  category="mn",
  description="THAANA EBEFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07AC,
 },
 [0x07AD]={
  category="mn",
  description="THAANA EYBEYFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07AD,
 },
 [0x07AE]={
  category="mn",
  description="THAANA OBOFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07AE,
 },
 [0x07AF]={
  category="mn",
  description="THAANA OABOAFILI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07AF,
 },
 [0x07B0]={
  category="mn",
  description="THAANA SUKUN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07B0,
 },
 [0x07B1]={
  category="lo",
  description="THAANA LETTER NAA",
  direction="al",
  linebreak="al",
  unicodeslot=0x07B1,
 },
 [0x07C0]={
  category="nd",
  description="NKO DIGIT ZERO",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C0,
 },
 [0x07C1]={
  category="nd",
  description="NKO DIGIT ONE",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C1,
 },
 [0x07C2]={
  category="nd",
  description="NKO DIGIT TWO",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C2,
 },
 [0x07C3]={
  category="nd",
  description="NKO DIGIT THREE",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C3,
 },
 [0x07C4]={
  category="nd",
  description="NKO DIGIT FOUR",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C4,
 },
 [0x07C5]={
  category="nd",
  description="NKO DIGIT FIVE",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C5,
 },
 [0x07C6]={
  category="nd",
  description="NKO DIGIT SIX",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C6,
 },
 [0x07C7]={
  category="nd",
  description="NKO DIGIT SEVEN",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C7,
 },
 [0x07C8]={
  category="nd",
  description="NKO DIGIT EIGHT",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C8,
 },
 [0x07C9]={
  category="nd",
  description="NKO DIGIT NINE",
  direction="r",
  linebreak="nu",
  unicodeslot=0x07C9,
 },
 [0x07CA]={
  arabic="d",
  category="lo",
  description="NKO LETTER A",
  direction="r",
  linebreak="al",
  unicodeslot=0x07CA,
 },
 [0x07CB]={
  arabic="d",
  category="lo",
  description="NKO LETTER EE",
  direction="r",
  linebreak="al",
  unicodeslot=0x07CB,
 },
 [0x07CC]={
  arabic="d",
  category="lo",
  description="NKO LETTER I",
  direction="r",
  linebreak="al",
  unicodeslot=0x07CC,
 },
 [0x07CD]={
  arabic="d",
  category="lo",
  description="NKO LETTER E",
  direction="r",
  linebreak="al",
  unicodeslot=0x07CD,
 },
 [0x07CE]={
  arabic="d",
  category="lo",
  description="NKO LETTER U",
  direction="r",
  linebreak="al",
  unicodeslot=0x07CE,
 },
 [0x07CF]={
  arabic="d",
  category="lo",
  description="NKO LETTER OO",
  direction="r",
  linebreak="al",
  unicodeslot=0x07CF,
 },
 [0x07D0]={
  arabic="d",
  category="lo",
  description="NKO LETTER O",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D0,
 },
 [0x07D1]={
  arabic="d",
  category="lo",
  description="NKO LETTER DAGBASINNA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D1,
 },
 [0x07D2]={
  arabic="d",
  category="lo",
  description="NKO LETTER N",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D2,
 },
 [0x07D3]={
  arabic="d",
  category="lo",
  description="NKO LETTER BA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D3,
 },
 [0x07D4]={
  arabic="d",
  category="lo",
  description="NKO LETTER PA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D4,
 },
 [0x07D5]={
  arabic="d",
  category="lo",
  description="NKO LETTER TA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D5,
 },
 [0x07D6]={
  arabic="d",
  category="lo",
  description="NKO LETTER JA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D6,
 },
 [0x07D7]={
  arabic="d",
  category="lo",
  description="NKO LETTER CHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D7,
 },
 [0x07D8]={
  arabic="d",
  category="lo",
  description="NKO LETTER DA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D8,
 },
 [0x07D9]={
  arabic="d",
  category="lo",
  description="NKO LETTER RA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07D9,
 },
 [0x07DA]={
  arabic="d",
  category="lo",
  description="NKO LETTER RRA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07DA,
 },
 [0x07DB]={
  arabic="d",
  category="lo",
  description="NKO LETTER SA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07DB,
 },
 [0x07DC]={
  arabic="d",
  category="lo",
  description="NKO LETTER GBA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07DC,
 },
 [0x07DD]={
  arabic="d",
  category="lo",
  description="NKO LETTER FA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07DD,
 },
 [0x07DE]={
  arabic="d",
  category="lo",
  description="NKO LETTER KA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07DE,
 },
 [0x07DF]={
  arabic="d",
  category="lo",
  description="NKO LETTER LA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07DF,
 },
 [0x07E0]={
  arabic="d",
  category="lo",
  description="NKO LETTER NA WOLOSO",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E0,
 },
 [0x07E1]={
  arabic="d",
  category="lo",
  description="NKO LETTER MA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E1,
 },
 [0x07E2]={
  arabic="d",
  category="lo",
  description="NKO LETTER NYA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E2,
 },
 [0x07E3]={
  arabic="d",
  category="lo",
  description="NKO LETTER NA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E3,
 },
 [0x07E4]={
  arabic="d",
  category="lo",
  description="NKO LETTER HA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E4,
 },
 [0x07E5]={
  arabic="d",
  category="lo",
  description="NKO LETTER WA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E5,
 },
 [0x07E6]={
  arabic="d",
  category="lo",
  description="NKO LETTER YA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E6,
 },
 [0x07E7]={
  arabic="d",
  category="lo",
  description="NKO LETTER NYA WOLOSO",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E7,
 },
 [0x07E8]={
  arabic="d",
  category="lo",
  description="NKO LETTER JONA JA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E8,
 },
 [0x07E9]={
  arabic="d",
  category="lo",
  description="NKO LETTER JONA CHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07E9,
 },
 [0x07EA]={
  arabic="d",
  category="lo",
  description="NKO LETTER JONA RA",
  direction="r",
  linebreak="al",
  unicodeslot=0x07EA,
 },
 [0x07EB]={
  category="mn",
  description="NKO COMBINING SHORT HIGH TONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07EB,
 },
 [0x07EC]={
  category="mn",
  description="NKO COMBINING SHORT LOW TONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07EC,
 },
 [0x07ED]={
  category="mn",
  description="NKO COMBINING SHORT RISING TONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07ED,
 },
 [0x07EE]={
  category="mn",
  description="NKO COMBINING LONG DESCENDING TONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07EE,
 },
 [0x07EF]={
  category="mn",
  description="NKO COMBINING LONG HIGH TONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07EF,
 },
 [0x07F0]={
  category="mn",
  description="NKO COMBINING LONG LOW TONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07F0,
 },
 [0x07F1]={
  category="mn",
  description="NKO COMBINING LONG RISING TONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07F1,
 },
 [0x07F2]={
  category="mn",
  description="NKO COMBINING NASALIZATION MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07F2,
 },
 [0x07F3]={
  category="mn",
  description="NKO COMBINING DOUBLE DOT ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x07F3,
 },
 [0x07F4]={
  category="lm",
  description="NKO HIGH TONE APOSTROPHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x07F4,
 },
 [0x07F5]={
  category="lm",
  description="NKO LOW TONE APOSTROPHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x07F5,
 },
 [0x07F6]={
  category="so",
  description="NKO SYMBOL OO DENNEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x07F6,
 },
 [0x07F7]={
  category="po",
  description="NKO SYMBOL GBAKURUNEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x07F7,
 },
 [0x07F8]={
  category="po",
  description="NKO COMMA",
  direction="on",
  linebreak="is",
  unicodeslot=0x07F8,
 },
 [0x07F9]={
  category="po",
  description="NKO EXCLAMATION MARK",
  direction="on",
  linebreak="ex",
  unicodeslot=0x07F9,
 },
 [0x07FA]={
  arabic="c",
  category="lm",
  description="NKO LAJANYALAN",
  direction="r",
  linebreak="al",
  unicodeslot=0x07FA,
 },
 [0x0800]={
  category="lo",
  description="SAMARITAN LETTER ALAF",
  direction="r",
  linebreak="al",
  unicodeslot=0x0800,
 },
 [0x0801]={
  category="lo",
  description="SAMARITAN LETTER BIT",
  direction="r",
  linebreak="al",
  unicodeslot=0x0801,
 },
 [0x0802]={
  category="lo",
  description="SAMARITAN LETTER GAMAN",
  direction="r",
  linebreak="al",
  unicodeslot=0x0802,
 },
 [0x0803]={
  category="lo",
  description="SAMARITAN LETTER DALAT",
  direction="r",
  linebreak="al",
  unicodeslot=0x0803,
 },
 [0x0804]={
  category="lo",
  description="SAMARITAN LETTER IY",
  direction="r",
  linebreak="al",
  unicodeslot=0x0804,
 },
 [0x0805]={
  category="lo",
  description="SAMARITAN LETTER BAA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0805,
 },
 [0x0806]={
  category="lo",
  description="SAMARITAN LETTER ZEN",
  direction="r",
  linebreak="al",
  unicodeslot=0x0806,
 },
 [0x0807]={
  category="lo",
  description="SAMARITAN LETTER IT",
  direction="r",
  linebreak="al",
  unicodeslot=0x0807,
 },
 [0x0808]={
  category="lo",
  description="SAMARITAN LETTER TIT",
  direction="r",
  linebreak="al",
  unicodeslot=0x0808,
 },
 [0x0809]={
  category="lo",
  description="SAMARITAN LETTER YUT",
  direction="r",
  linebreak="al",
  unicodeslot=0x0809,
 },
 [0x080A]={
  category="lo",
  description="SAMARITAN LETTER KAAF",
  direction="r",
  linebreak="al",
  unicodeslot=0x080A,
 },
 [0x080B]={
  category="lo",
  description="SAMARITAN LETTER LABAT",
  direction="r",
  linebreak="al",
  unicodeslot=0x080B,
 },
 [0x080C]={
  category="lo",
  description="SAMARITAN LETTER MIM",
  direction="r",
  linebreak="al",
  unicodeslot=0x080C,
 },
 [0x080D]={
  category="lo",
  description="SAMARITAN LETTER NUN",
  direction="r",
  linebreak="al",
  unicodeslot=0x080D,
 },
 [0x080E]={
  category="lo",
  description="SAMARITAN LETTER SINGAAT",
  direction="r",
  linebreak="al",
  unicodeslot=0x080E,
 },
 [0x080F]={
  category="lo",
  description="SAMARITAN LETTER IN",
  direction="r",
  linebreak="al",
  unicodeslot=0x080F,
 },
 [0x0810]={
  category="lo",
  description="SAMARITAN LETTER FI",
  direction="r",
  linebreak="al",
  unicodeslot=0x0810,
 },
 [0x0811]={
  category="lo",
  description="SAMARITAN LETTER TSAADIY",
  direction="r",
  linebreak="al",
  unicodeslot=0x0811,
 },
 [0x0812]={
  category="lo",
  description="SAMARITAN LETTER QUF",
  direction="r",
  linebreak="al",
  unicodeslot=0x0812,
 },
 [0x0813]={
  category="lo",
  description="SAMARITAN LETTER RISH",
  direction="r",
  linebreak="al",
  unicodeslot=0x0813,
 },
 [0x0814]={
  category="lo",
  description="SAMARITAN LETTER SHAN",
  direction="r",
  linebreak="al",
  unicodeslot=0x0814,
 },
 [0x0815]={
  category="lo",
  description="SAMARITAN LETTER TAAF",
  direction="r",
  linebreak="al",
  unicodeslot=0x0815,
 },
 [0x0816]={
  category="mn",
  description="SAMARITAN MARK IN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0816,
 },
 [0x0817]={
  category="mn",
  description="SAMARITAN MARK IN-ALAF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0817,
 },
 [0x0818]={
  category="mn",
  description="SAMARITAN MARK OCCLUSION",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0818,
 },
 [0x0819]={
  category="mn",
  description="SAMARITAN MARK DAGESH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0819,
 },
 [0x081A]={
  category="lm",
  description="SAMARITAN MODIFIER LETTER EPENTHETIC YUT",
  direction="r",
  linebreak="al",
  unicodeslot=0x081A,
 },
 [0x081B]={
  category="mn",
  description="SAMARITAN MARK EPENTHETIC YUT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x081B,
 },
 [0x081C]={
  category="mn",
  description="SAMARITAN VOWEL SIGN LONG E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x081C,
 },
 [0x081D]={
  category="mn",
  description="SAMARITAN VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x081D,
 },
 [0x081E]={
  category="mn",
  description="SAMARITAN VOWEL SIGN OVERLONG AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x081E,
 },
 [0x081F]={
  category="mn",
  description="SAMARITAN VOWEL SIGN LONG AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x081F,
 },
 [0x0820]={
  category="mn",
  description="SAMARITAN VOWEL SIGN AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0820,
 },
 [0x0821]={
  category="mn",
  description="SAMARITAN VOWEL SIGN OVERLONG A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0821,
 },
 [0x0822]={
  category="mn",
  description="SAMARITAN VOWEL SIGN LONG A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0822,
 },
 [0x0823]={
  category="mn",
  description="SAMARITAN VOWEL SIGN A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0823,
 },
 [0x0824]={
  category="lm",
  description="SAMARITAN MODIFIER LETTER SHORT A",
  direction="r",
  linebreak="al",
  unicodeslot=0x0824,
 },
 [0x0825]={
  category="mn",
  description="SAMARITAN VOWEL SIGN SHORT A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0825,
 },
 [0x0826]={
  category="mn",
  description="SAMARITAN VOWEL SIGN LONG U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0826,
 },
 [0x0827]={
  category="mn",
  description="SAMARITAN VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0827,
 },
 [0x0828]={
  category="lm",
  description="SAMARITAN MODIFIER LETTER I",
  direction="r",
  linebreak="al",
  unicodeslot=0x0828,
 },
 [0x0829]={
  category="mn",
  description="SAMARITAN VOWEL SIGN LONG I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0829,
 },
 [0x082A]={
  category="mn",
  description="SAMARITAN VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x082A,
 },
 [0x082B]={
  category="mn",
  description="SAMARITAN VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x082B,
 },
 [0x082C]={
  category="mn",
  description="SAMARITAN VOWEL SIGN SUKUN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x082C,
 },
 [0x082D]={
  category="mn",
  description="SAMARITAN MARK NEQUDAA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x082D,
 },
 [0x0830]={
  category="po",
  description="SAMARITAN PUNCTUATION NEQUDAA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0830,
 },
 [0x0831]={
  category="po",
  description="SAMARITAN PUNCTUATION AFSAAQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x0831,
 },
 [0x0832]={
  category="po",
  description="SAMARITAN PUNCTUATION ANGED",
  direction="r",
  linebreak="al",
  unicodeslot=0x0832,
 },
 [0x0833]={
  category="po",
  description="SAMARITAN PUNCTUATION BAU",
  direction="r",
  linebreak="al",
  unicodeslot=0x0833,
 },
 [0x0834]={
  category="po",
  description="SAMARITAN PUNCTUATION ATMAAU",
  direction="r",
  linebreak="al",
  unicodeslot=0x0834,
 },
 [0x0835]={
  category="po",
  description="SAMARITAN PUNCTUATION SHIYYAALAA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0835,
 },
 [0x0836]={
  category="po",
  description="SAMARITAN ABBREVIATION MARK",
  direction="r",
  linebreak="al",
  unicodeslot=0x0836,
 },
 [0x0837]={
  category="po",
  description="SAMARITAN PUNCTUATION MELODIC QITSA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0837,
 },
 [0x0838]={
  category="po",
  description="SAMARITAN PUNCTUATION ZIQAA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0838,
 },
 [0x0839]={
  category="po",
  description="SAMARITAN PUNCTUATION QITSA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0839,
 },
 [0x083A]={
  category="po",
  description="SAMARITAN PUNCTUATION ZAEF",
  direction="r",
  linebreak="al",
  unicodeslot=0x083A,
 },
 [0x083B]={
  category="po",
  description="SAMARITAN PUNCTUATION TURU",
  direction="r",
  linebreak="al",
  unicodeslot=0x083B,
 },
 [0x083C]={
  category="po",
  description="SAMARITAN PUNCTUATION ARKAANU",
  direction="r",
  linebreak="al",
  unicodeslot=0x083C,
 },
 [0x083D]={
  category="po",
  description="SAMARITAN PUNCTUATION SOF MASHFAAT",
  direction="r",
  linebreak="al",
  unicodeslot=0x083D,
 },
 [0x083E]={
  category="po",
  description="SAMARITAN PUNCTUATION ANNAAU",
  direction="r",
  linebreak="al",
  unicodeslot=0x083E,
 },
 [0x0840]={
  arabic="r",
  category="lo",
  description="MANDAIC LETTER HALQA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0840,
 },
 [0x0841]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AB",
  direction="r",
  linebreak="al",
  unicodeslot=0x0841,
 },
 [0x0842]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AG",
  direction="r",
  linebreak="al",
  unicodeslot=0x0842,
 },
 [0x0843]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AD",
  direction="r",
  linebreak="al",
  unicodeslot=0x0843,
 },
 [0x0844]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AH",
  direction="r",
  linebreak="al",
  unicodeslot=0x0844,
 },
 [0x0845]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER USHENNA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0845,
 },
 [0x0846]={
  arabic="r",
  category="lo",
  description="MANDAIC LETTER AZ",
  direction="r",
  linebreak="al",
  unicodeslot=0x0846,
 },
 [0x0847]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER IT",
  direction="r",
  linebreak="al",
  unicodeslot=0x0847,
 },
 [0x0848]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER ATT",
  direction="r",
  linebreak="al",
  unicodeslot=0x0848,
 },
 [0x0849]={
  arabic="r",
  category="lo",
  description="MANDAIC LETTER AKSA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0849,
 },
 [0x084A]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AK",
  direction="r",
  linebreak="al",
  unicodeslot=0x084A,
 },
 [0x084B]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AL",
  direction="r",
  linebreak="al",
  unicodeslot=0x084B,
 },
 [0x084C]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AM",
  direction="r",
  linebreak="al",
  unicodeslot=0x084C,
 },
 [0x084D]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AN",
  direction="r",
  linebreak="al",
  unicodeslot=0x084D,
 },
 [0x084E]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AS",
  direction="r",
  linebreak="al",
  unicodeslot=0x084E,
 },
 [0x084F]={
  arabic="r",
  category="lo",
  description="MANDAIC LETTER IN",
  direction="r",
  linebreak="al",
  unicodeslot=0x084F,
 },
 [0x0850]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AP",
  direction="r",
  linebreak="al",
  unicodeslot=0x0850,
 },
 [0x0851]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER ASZ",
  direction="r",
  linebreak="al",
  unicodeslot=0x0851,
 },
 [0x0852]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x0852,
 },
 [0x0853]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AR",
  direction="r",
  linebreak="al",
  unicodeslot=0x0853,
 },
 [0x0854]={
  arabic="r",
  category="lo",
  description="MANDAIC LETTER ASH",
  direction="r",
  linebreak="al",
  unicodeslot=0x0854,
 },
 [0x0855]={
  arabic="d",
  category="lo",
  description="MANDAIC LETTER AT",
  direction="r",
  linebreak="al",
  unicodeslot=0x0855,
 },
 [0x0856]={
  arabic="u",
  category="lo",
  description="MANDAIC LETTER DUSHENNA",
  direction="r",
  linebreak="al",
  unicodeslot=0x0856,
 },
 [0x0857]={
  arabic="u",
  category="lo",
  description="MANDAIC LETTER KAD",
  direction="r",
  linebreak="al",
  unicodeslot=0x0857,
 },
 [0x0858]={
  arabic="u",
  category="lo",
  description="MANDAIC LETTER AIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x0858,
 },
 [0x0859]={
  category="mn",
  description="MANDAIC AFFRICATION MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0859,
 },
 [0x085A]={
  category="mn",
  description="MANDAIC VOCALIZATION MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x085A,
 },
 [0x085B]={
  category="mn",
  description="MANDAIC GEMINATION MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x085B,
 },
 [0x085E]={
  category="po",
  description="MANDAIC PUNCTUATION",
  direction="r",
  linebreak="al",
  unicodeslot=0x085E,
 },
 [0x08A0]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER BEH WITH SMALL V BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A0,
 },
 [0x08A2]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER JEEM WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A2,
 },
 [0x08A3]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER TAH WITH TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A3,
 },
 [0x08A4]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER FEH WITH DOT BELOW AND THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A4,
 },
 [0x08A5]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER QAF WITH DOT BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A5,
 },
 [0x08A6]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER LAM WITH DOUBLE BAR",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A6,
 },
 [0x08A7]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER MEEM WITH THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A7,
 },
 [0x08A8]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER YEH WITH TWO DOTS BELOW AND HAMZA ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A8,
 },
 [0x08A9]={
  arabic="d",
  category="lo",
  description="ARABIC LETTER YEH WITH TWO DOTS BELOW AND DOT ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0x08A9,
 },
 [0x08AA]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER REH WITH LOOP",
  direction="al",
  linebreak="al",
  unicodeslot=0x08AA,
 },
 [0x08AB]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER WAW WITH DOT WITHIN",
  direction="al",
  linebreak="al",
  unicodeslot=0x08AB,
 },
 [0x08AC]={
  arabic="r",
  category="lo",
  description="ARABIC LETTER ROHINGYA YEH",
  direction="al",
  linebreak="al",
  unicodeslot=0x08AC,
 },
 [0x08E4]={
  category="mn",
  description="ARABIC CURLY FATHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08E4,
 },
 [0x08E5]={
  category="mn",
  description="ARABIC CURLY DAMMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08E5,
 },
 [0x08E6]={
  category="mn",
  description="ARABIC CURLY KASRA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08E6,
 },
 [0x08E7]={
  category="mn",
  description="ARABIC CURLY FATHATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08E7,
 },
 [0x08E8]={
  category="mn",
  description="ARABIC CURLY DAMMATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08E8,
 },
 [0x08E9]={
  category="mn",
  description="ARABIC CURLY KASRATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08E9,
 },
 [0x08EA]={
  category="mn",
  description="ARABIC TONE ONE DOT ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08EA,
 },
 [0x08EB]={
  category="mn",
  description="ARABIC TONE TWO DOTS ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08EB,
 },
 [0x08EC]={
  category="mn",
  description="ARABIC TONE LOOP ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08EC,
 },
 [0x08ED]={
  category="mn",
  description="ARABIC TONE ONE DOT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08ED,
 },
 [0x08EE]={
  category="mn",
  description="ARABIC TONE TWO DOTS BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08EE,
 },
 [0x08EF]={
  category="mn",
  description="ARABIC TONE LOOP BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08EF,
 },
 [0x08F0]={
  category="mn",
  description="ARABIC OPEN FATHATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F0,
 },
 [0x08F1]={
  category="mn",
  description="ARABIC OPEN DAMMATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F1,
 },
 [0x08F2]={
  category="mn",
  description="ARABIC OPEN KASRATAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F2,
 },
 [0x08F3]={
  category="mn",
  description="ARABIC SMALL HIGH WAW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F3,
 },
 [0x08F4]={
  category="mn",
  description="ARABIC FATHA WITH RING",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F4,
 },
 [0x08F5]={
  category="mn",
  description="ARABIC FATHA WITH DOT ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F5,
 },
 [0x08F6]={
  category="mn",
  description="ARABIC KASRA WITH DOT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F6,
 },
 [0x08F7]={
  category="mn",
  description="ARABIC LEFT ARROWHEAD ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F7,
 },
 [0x08F8]={
  category="mn",
  description="ARABIC RIGHT ARROWHEAD ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F8,
 },
 [0x08F9]={
  category="mn",
  description="ARABIC LEFT ARROWHEAD BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08F9,
 },
 [0x08FA]={
  category="mn",
  description="ARABIC RIGHT ARROWHEAD BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08FA,
 },
 [0x08FB]={
  category="mn",
  description="ARABIC DOUBLE RIGHT ARROWHEAD ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08FB,
 },
 [0x08FC]={
  category="mn",
  description="ARABIC DOUBLE RIGHT ARROWHEAD ABOVE WITH DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08FC,
 },
 [0x08FD]={
  category="mn",
  description="ARABIC RIGHT ARROWHEAD ABOVE WITH DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08FD,
 },
 [0x08FE]={
  category="mn",
  description="ARABIC DAMMA WITH DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x08FE,
 },
 [0x0900]={
  category="mn",
  description="DEVANAGARI SIGN INVERTED CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0900,
 },
 [0x0901]={
  adobename="candrabindudeva",
  category="mn",
  description="DEVANAGARI SIGN CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0901,
 },
 [0x0902]={
  adobename="anusvaradeva",
  category="mn",
  description="DEVANAGARI SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0902,
 },
 [0x0903]={
  adobename="visargadeva",
  category="mc",
  description="DEVANAGARI SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0903,
 },
 [0x0904]={
  category="lo",
  description="DEVANAGARI LETTER SHORT A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0904,
 },
 [0x0905]={
  adobename="adeva",
  category="lo",
  description="DEVANAGARI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0905,
 },
 [0x0906]={
  adobename="aadeva",
  category="lo",
  description="DEVANAGARI LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0906,
 },
 [0x0907]={
  adobename="ideva",
  category="lo",
  description="DEVANAGARI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0907,
 },
 [0x0908]={
  adobename="iideva",
  category="lo",
  description="DEVANAGARI LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0908,
 },
 [0x0909]={
  adobename="udeva",
  category="lo",
  description="DEVANAGARI LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0909,
 },
 [0x090A]={
  adobename="uudeva",
  category="lo",
  description="DEVANAGARI LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x090A,
 },
 [0x090B]={
  adobename="rvocalicdeva",
  category="lo",
  description="DEVANAGARI LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x090B,
 },
 [0x090C]={
  adobename="lvocalicdeva",
  category="lo",
  description="DEVANAGARI LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x090C,
 },
 [0x090D]={
  adobename="ecandradeva",
  category="lo",
  description="DEVANAGARI LETTER CANDRA E",
  direction="l",
  linebreak="al",
  unicodeslot=0x090D,
 },
 [0x090E]={
  adobename="eshortdeva",
  category="lo",
  description="DEVANAGARI LETTER SHORT E",
  direction="l",
  linebreak="al",
  unicodeslot=0x090E,
 },
 [0x090F]={
  adobename="edeva",
  category="lo",
  description="DEVANAGARI LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x090F,
 },
 [0x0910]={
  adobename="aideva",
  category="lo",
  description="DEVANAGARI LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0910,
 },
 [0x0911]={
  adobename="ocandradeva",
  category="lo",
  description="DEVANAGARI LETTER CANDRA O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0911,
 },
 [0x0912]={
  adobename="oshortdeva",
  category="lo",
  description="DEVANAGARI LETTER SHORT O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0912,
 },
 [0x0913]={
  adobename="odeva",
  category="lo",
  description="DEVANAGARI LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0913,
 },
 [0x0914]={
  adobename="audeva",
  category="lo",
  description="DEVANAGARI LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0914,
 },
 [0x0915]={
  adobename="kadeva",
  category="lo",
  description="DEVANAGARI LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0915,
 },
 [0x0916]={
  adobename="khadeva",
  category="lo",
  description="DEVANAGARI LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0916,
 },
 [0x0917]={
  adobename="gadeva",
  category="lo",
  description="DEVANAGARI LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0917,
 },
 [0x0918]={
  adobename="ghadeva",
  category="lo",
  description="DEVANAGARI LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0918,
 },
 [0x0919]={
  adobename="ngadeva",
  category="lo",
  description="DEVANAGARI LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0919,
 },
 [0x091A]={
  adobename="cadeva",
  category="lo",
  description="DEVANAGARI LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x091A,
 },
 [0x091B]={
  adobename="chadeva",
  category="lo",
  description="DEVANAGARI LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x091B,
 },
 [0x091C]={
  adobename="jadeva",
  category="lo",
  description="DEVANAGARI LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x091C,
 },
 [0x091D]={
  adobename="jhadeva",
  category="lo",
  description="DEVANAGARI LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x091D,
 },
 [0x091E]={
  adobename="nyadeva",
  category="lo",
  description="DEVANAGARI LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x091E,
 },
 [0x091F]={
  adobename="ttadeva",
  category="lo",
  description="DEVANAGARI LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x091F,
 },
 [0x0920]={
  adobename="tthadeva",
  category="lo",
  description="DEVANAGARI LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0920,
 },
 [0x0921]={
  adobename="ddadeva",
  category="lo",
  description="DEVANAGARI LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0921,
 },
 [0x0922]={
  adobename="ddhadeva",
  category="lo",
  description="DEVANAGARI LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0922,
 },
 [0x0923]={
  adobename="nnadeva",
  category="lo",
  description="DEVANAGARI LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0923,
 },
 [0x0924]={
  adobename="tadeva",
  category="lo",
  description="DEVANAGARI LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0924,
 },
 [0x0925]={
  adobename="thadeva",
  category="lo",
  description="DEVANAGARI LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0925,
 },
 [0x0926]={
  adobename="dadeva",
  category="lo",
  description="DEVANAGARI LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0926,
 },
 [0x0927]={
  adobename="dhadeva",
  category="lo",
  description="DEVANAGARI LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0927,
 },
 [0x0928]={
  adobename="nadeva",
  category="lo",
  description="DEVANAGARI LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0928,
 },
 [0x0929]={
  adobename="nnnadeva",
  category="lo",
  description="DEVANAGARI LETTER NNNA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0928, 0x093C },
  unicodeslot=0x0929,
 },
 [0x092A]={
  adobename="padeva",
  category="lo",
  description="DEVANAGARI LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x092A,
 },
 [0x092B]={
  adobename="phadeva",
  category="lo",
  description="DEVANAGARI LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x092B,
 },
 [0x092C]={
  adobename="badeva",
  category="lo",
  description="DEVANAGARI LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x092C,
 },
 [0x092D]={
  adobename="bhadeva",
  category="lo",
  description="DEVANAGARI LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x092D,
 },
 [0x092E]={
  adobename="madeva",
  category="lo",
  description="DEVANAGARI LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x092E,
 },
 [0x092F]={
  adobename="yadeva",
  category="lo",
  description="DEVANAGARI LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x092F,
 },
 [0x0930]={
  adobename="radeva",
  category="lo",
  description="DEVANAGARI LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0930,
 },
 [0x0931]={
  adobename="rradeva",
  category="lo",
  description="DEVANAGARI LETTER RRA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0930, 0x093C },
  unicodeslot=0x0931,
 },
 [0x0932]={
  adobename="ladeva",
  category="lo",
  description="DEVANAGARI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0932,
 },
 [0x0933]={
  adobename="lladeva",
  category="lo",
  description="DEVANAGARI LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0933,
 },
 [0x0934]={
  adobename="llladeva",
  category="lo",
  description="DEVANAGARI LETTER LLLA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0933, 0x093C },
  unicodeslot=0x0934,
 },
 [0x0935]={
  adobename="vadeva",
  category="lo",
  description="DEVANAGARI LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0935,
 },
 [0x0936]={
  adobename="shadeva",
  category="lo",
  description="DEVANAGARI LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0936,
 },
 [0x0937]={
  adobename="ssadeva",
  category="lo",
  description="DEVANAGARI LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0937,
 },
 [0x0938]={
  adobename="sadeva",
  category="lo",
  description="DEVANAGARI LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0938,
 },
 [0x0939]={
  adobename="hadeva",
  category="lo",
  description="DEVANAGARI LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0939,
 },
 [0x093A]={
  category="mn",
  description="DEVANAGARI VOWEL SIGN OE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x093A,
 },
 [0x093B]={
  category="mc",
  description="DEVANAGARI VOWEL SIGN OOE",
  direction="l",
  linebreak="cm",
  unicodeslot=0x093B,
 },
 [0x093C]={
  adobename="nuktadeva",
  category="mn",
  description="DEVANAGARI SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x093C,
 },
 [0x093D]={
  adobename="avagrahadeva",
  category="lo",
  description="DEVANAGARI SIGN AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x093D,
 },
 [0x093E]={
  adobename="aavowelsigndeva",
  category="mc",
  description="DEVANAGARI VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x093E,
 },
 [0x093F]={
  adobename="ivowelsigndeva",
  category="mc",
  description="DEVANAGARI VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x093F,
 },
 [0x0940]={
  adobename="iivowelsigndeva",
  category="mc",
  description="DEVANAGARI VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0940,
 },
 [0x0941]={
  adobename="uvowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0941,
 },
 [0x0942]={
  adobename="uuvowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0942,
 },
 [0x0943]={
  adobename="rvocalicvowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0943,
 },
 [0x0944]={
  adobename="rrvocalicvowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN VOCALIC RR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0944,
 },
 [0x0945]={
  adobename="ecandravowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN CANDRA E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0945,
 },
 [0x0946]={
  adobename="eshortvowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN SHORT E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0946,
 },
 [0x0947]={
  adobename="evowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0947,
 },
 [0x0948]={
  adobename="aivowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0948,
 },
 [0x0949]={
  adobename="ocandravowelsigndeva",
  category="mc",
  description="DEVANAGARI VOWEL SIGN CANDRA O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0949,
 },
 [0x094A]={
  adobename="oshortvowelsigndeva",
  category="mc",
  description="DEVANAGARI VOWEL SIGN SHORT O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x094A,
 },
 [0x094B]={
  adobename="ovowelsigndeva",
  category="mc",
  description="DEVANAGARI VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x094B,
 },
 [0x094C]={
  adobename="auvowelsigndeva",
  category="mc",
  description="DEVANAGARI VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x094C,
 },
 [0x094D]={
  adobename="viramadeva",
  category="mn",
  description="DEVANAGARI SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x094D,
 },
 [0x094E]={
  category="mc",
  description="DEVANAGARI VOWEL SIGN PRISHTHAMATRA E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x094E,
 },
 [0x094F]={
  category="mc",
  description="DEVANAGARI VOWEL SIGN AW",
  direction="l",
  linebreak="cm",
  unicodeslot=0x094F,
 },
 [0x0950]={
  adobename="omdeva",
  category="lo",
  description="DEVANAGARI OM",
  direction="l",
  linebreak="al",
  unicodeslot=0x0950,
 },
 [0x0951]={
  adobename="udattadeva",
  category="mn",
  description="DEVANAGARI STRESS SIGN UDATTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0951,
 },
 [0x0952]={
  adobename="anudattadeva",
  category="mn",
  description="DEVANAGARI STRESS SIGN ANUDATTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0952,
 },
 [0x0953]={
  adobename="gravedeva",
  category="mn",
  description="DEVANAGARI GRAVE ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0953,
 },
 [0x0954]={
  adobename="acutedeva",
  category="mn",
  description="DEVANAGARI ACUTE ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0954,
 },
 [0x0955]={
  category="mn",
  description="DEVANAGARI VOWEL SIGN CANDRA LONG E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0955,
 },
 [0x0956]={
  category="mn",
  description="DEVANAGARI VOWEL SIGN UE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0956,
 },
 [0x0957]={
  category="mn",
  description="DEVANAGARI VOWEL SIGN UUE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0957,
 },
 [0x0958]={
  adobename="qadeva",
  category="lo",
  description="DEVANAGARI LETTER QA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0915, 0x093C },
  unicodeslot=0x0958,
 },
 [0x0959]={
  adobename="khhadeva",
  category="lo",
  description="DEVANAGARI LETTER KHHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0916, 0x093C },
  unicodeslot=0x0959,
 },
 [0x095A]={
  adobename="ghhadeva",
  category="lo",
  description="DEVANAGARI LETTER GHHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0917, 0x093C },
  unicodeslot=0x095A,
 },
 [0x095B]={
  adobename="zadeva",
  category="lo",
  description="DEVANAGARI LETTER ZA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x091C, 0x093C },
  unicodeslot=0x095B,
 },
 [0x095C]={
  adobename="dddhadeva",
  category="lo",
  description="DEVANAGARI LETTER DDDHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0921, 0x093C },
  unicodeslot=0x095C,
 },
 [0x095D]={
  adobename="rhadeva",
  category="lo",
  description="DEVANAGARI LETTER RHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0922, 0x093C },
  unicodeslot=0x095D,
 },
 [0x095E]={
  adobename="fadeva",
  category="lo",
  description="DEVANAGARI LETTER FA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x092B, 0x093C },
  unicodeslot=0x095E,
 },
 [0x095F]={
  adobename="yyadeva",
  category="lo",
  description="DEVANAGARI LETTER YYA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x092F, 0x093C },
  unicodeslot=0x095F,
 },
 [0x0960]={
  adobename="rrvocalicdeva",
  category="lo",
  description="DEVANAGARI LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0960,
 },
 [0x0961]={
  adobename="llvocalicdeva",
  category="lo",
  description="DEVANAGARI LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0961,
 },
 [0x0962]={
  adobename="lvocalicvowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0962,
 },
 [0x0963]={
  adobename="llvocalicvowelsigndeva",
  category="mn",
  description="DEVANAGARI VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0963,
 },
 [0x0964]={
  adobename="danda",
  category="po",
  description="DEVANAGARI DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0964,
 },
 [0x0965]={
  adobename="dbldanda",
  category="po",
  description="DEVANAGARI DOUBLE DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0965,
 },
 [0x0966]={
  adobename="zerodeva",
  category="nd",
  description="DEVANAGARI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0966,
 },
 [0x0967]={
  adobename="onedeva",
  category="nd",
  description="DEVANAGARI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0967,
 },
 [0x0968]={
  adobename="twodeva",
  category="nd",
  description="DEVANAGARI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0968,
 },
 [0x0969]={
  adobename="threedeva",
  category="nd",
  description="DEVANAGARI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0969,
 },
 [0x096A]={
  adobename="fourdeva",
  category="nd",
  description="DEVANAGARI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x096A,
 },
 [0x096B]={
  adobename="fivedeva",
  category="nd",
  description="DEVANAGARI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x096B,
 },
 [0x096C]={
  adobename="sixdeva",
  category="nd",
  description="DEVANAGARI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x096C,
 },
 [0x096D]={
  adobename="sevendeva",
  category="nd",
  description="DEVANAGARI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x096D,
 },
 [0x096E]={
  adobename="eightdeva",
  category="nd",
  description="DEVANAGARI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x096E,
 },
 [0x096F]={
  adobename="ninedeva",
  category="nd",
  description="DEVANAGARI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x096F,
 },
 [0x0970]={
  adobename="abbreviationsigndeva",
  category="po",
  description="DEVANAGARI ABBREVIATION SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0970,
 },
 [0x0971]={
  category="lm",
  description="DEVANAGARI SIGN HIGH SPACING DOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x0971,
 },
 [0x0972]={
  category="lo",
  description="DEVANAGARI LETTER CANDRA A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0972,
 },
 [0x0973]={
  category="lo",
  description="DEVANAGARI LETTER OE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0973,
 },
 [0x0974]={
  category="lo",
  description="DEVANAGARI LETTER OOE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0974,
 },
 [0x0975]={
  category="lo",
  description="DEVANAGARI LETTER AW",
  direction="l",
  linebreak="al",
  unicodeslot=0x0975,
 },
 [0x0976]={
  category="lo",
  description="DEVANAGARI LETTER UE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0976,
 },
 [0x0977]={
  category="lo",
  description="DEVANAGARI LETTER UUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0977,
 },
 [0x0979]={
  category="lo",
  description="DEVANAGARI LETTER ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0979,
 },
 [0x097A]={
  category="lo",
  description="DEVANAGARI LETTER HEAVY YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x097A,
 },
 [0x097B]={
  category="lo",
  description="DEVANAGARI LETTER GGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x097B,
 },
 [0x097C]={
  category="lo",
  description="DEVANAGARI LETTER JJA",
  direction="l",
  linebreak="al",
  unicodeslot=0x097C,
 },
 [0x097D]={
  category="lo",
  description="DEVANAGARI LETTER GLOTTAL STOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x097D,
 },
 [0x097E]={
  category="lo",
  description="DEVANAGARI LETTER DDDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x097E,
 },
 [0x097F]={
  category="lo",
  description="DEVANAGARI LETTER BBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x097F,
 },
 [0x0981]={
  adobename="candrabindubengali",
  category="mn",
  description="BENGALI SIGN CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0981,
 },
 [0x0982]={
  adobename="anusvarabengali",
  category="mc",
  description="BENGALI SIGN ANUSVARA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0982,
 },
 [0x0983]={
  adobename="visargabengali",
  category="mc",
  description="BENGALI SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0983,
 },
 [0x0985]={
  adobename="abengali",
  category="lo",
  description="BENGALI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0985,
 },
 [0x0986]={
  adobename="aabengali",
  category="lo",
  description="BENGALI LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0986,
 },
 [0x0987]={
  adobename="ibengali",
  category="lo",
  description="BENGALI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0987,
 },
 [0x0988]={
  adobename="iibengali",
  category="lo",
  description="BENGALI LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0988,
 },
 [0x0989]={
  adobename="ubengali",
  category="lo",
  description="BENGALI LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0989,
 },
 [0x098A]={
  adobename="uubengali",
  category="lo",
  description="BENGALI LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x098A,
 },
 [0x098B]={
  adobename="rvocalicbengali",
  category="lo",
  description="BENGALI LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x098B,
 },
 [0x098C]={
  adobename="lvocalicbengali",
  category="lo",
  description="BENGALI LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x098C,
 },
 [0x098F]={
  adobename="ebengali",
  category="lo",
  description="BENGALI LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x098F,
 },
 [0x0990]={
  adobename="aibengali",
  category="lo",
  description="BENGALI LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0990,
 },
 [0x0993]={
  adobename="obengali",
  category="lo",
  description="BENGALI LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0993,
 },
 [0x0994]={
  adobename="aubengali",
  category="lo",
  description="BENGALI LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0994,
 },
 [0x0995]={
  adobename="kabengali",
  category="lo",
  description="BENGALI LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0995,
 },
 [0x0996]={
  adobename="khabengali",
  category="lo",
  description="BENGALI LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0996,
 },
 [0x0997]={
  adobename="gabengali",
  category="lo",
  description="BENGALI LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0997,
 },
 [0x0998]={
  adobename="ghabengali",
  category="lo",
  description="BENGALI LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0998,
 },
 [0x0999]={
  adobename="ngabengali",
  category="lo",
  description="BENGALI LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0999,
 },
 [0x099A]={
  adobename="cabengali",
  category="lo",
  description="BENGALI LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x099A,
 },
 [0x099B]={
  adobename="chabengali",
  category="lo",
  description="BENGALI LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x099B,
 },
 [0x099C]={
  adobename="jabengali",
  category="lo",
  description="BENGALI LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x099C,
 },
 [0x099D]={
  adobename="jhabengali",
  category="lo",
  description="BENGALI LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x099D,
 },
 [0x099E]={
  adobename="nyabengali",
  category="lo",
  description="BENGALI LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x099E,
 },
 [0x099F]={
  adobename="ttabengali",
  category="lo",
  description="BENGALI LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x099F,
 },
 [0x09A0]={
  adobename="tthabengali",
  category="lo",
  description="BENGALI LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A0,
 },
 [0x09A1]={
  adobename="ddabengali",
  category="lo",
  description="BENGALI LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A1,
 },
 [0x09A2]={
  adobename="ddhabengali",
  category="lo",
  description="BENGALI LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A2,
 },
 [0x09A3]={
  adobename="nnabengali",
  category="lo",
  description="BENGALI LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A3,
 },
 [0x09A4]={
  adobename="tabengali",
  category="lo",
  description="BENGALI LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A4,
 },
 [0x09A5]={
  adobename="thabengali",
  category="lo",
  description="BENGALI LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A5,
 },
 [0x09A6]={
  adobename="dabengali",
  category="lo",
  description="BENGALI LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A6,
 },
 [0x09A7]={
  adobename="dhabengali",
  category="lo",
  description="BENGALI LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A7,
 },
 [0x09A8]={
  adobename="nabengali",
  category="lo",
  description="BENGALI LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09A8,
 },
 [0x09AA]={
  adobename="pabengali",
  category="lo",
  description="BENGALI LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09AA,
 },
 [0x09AB]={
  adobename="phabengali",
  category="lo",
  description="BENGALI LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09AB,
 },
 [0x09AC]={
  adobename="babengali",
  category="lo",
  description="BENGALI LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09AC,
 },
 [0x09AD]={
  adobename="bhabengali",
  category="lo",
  description="BENGALI LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09AD,
 },
 [0x09AE]={
  adobename="mabengali",
  category="lo",
  description="BENGALI LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09AE,
 },
 [0x09AF]={
  adobename="yabengali",
  category="lo",
  description="BENGALI LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09AF,
 },
 [0x09B0]={
  adobename="rabengali",
  category="lo",
  description="BENGALI LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09B0,
 },
 [0x09B2]={
  adobename="labengali",
  category="lo",
  description="BENGALI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09B2,
 },
 [0x09B6]={
  adobename="shabengali",
  category="lo",
  description="BENGALI LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09B6,
 },
 [0x09B7]={
  adobename="ssabengali",
  category="lo",
  description="BENGALI LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09B7,
 },
 [0x09B8]={
  adobename="sabengali",
  category="lo",
  description="BENGALI LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09B8,
 },
 [0x09B9]={
  adobename="habengali",
  category="lo",
  description="BENGALI LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09B9,
 },
 [0x09BC]={
  adobename="nuktabengali",
  category="mn",
  description="BENGALI SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x09BC,
 },
 [0x09BD]={
  category="lo",
  description="BENGALI SIGN AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09BD,
 },
 [0x09BE]={
  adobename="aavowelsignbengali",
  category="mc",
  description="BENGALI VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x09BE,
 },
 [0x09BF]={
  adobename="ivowelsignbengali",
  category="mc",
  description="BENGALI VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x09BF,
 },
 [0x09C0]={
  adobename="iivowelsignbengali",
  category="mc",
  description="BENGALI VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x09C0,
 },
 [0x09C1]={
  adobename="uvowelsignbengali",
  category="mn",
  description="BENGALI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x09C1,
 },
 [0x09C2]={
  adobename="uuvowelsignbengali",
  category="mn",
  description="BENGALI VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x09C2,
 },
 [0x09C3]={
  adobename="rvocalicvowelsignbengali",
  category="mn",
  description="BENGALI VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x09C3,
 },
 [0x09C4]={
  adobename="rrvocalicvowelsignbengali",
  category="mn",
  description="BENGALI VOWEL SIGN VOCALIC RR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x09C4,
 },
 [0x09C7]={
  adobename="evowelsignbengali",
  category="mc",
  description="BENGALI VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x09C7,
 },
 [0x09C8]={
  adobename="aivowelsignbengali",
  category="mc",
  description="BENGALI VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  unicodeslot=0x09C8,
 },
 [0x09CB]={
  adobename="ovowelsignbengali",
  category="mc",
  description="BENGALI VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x09C7, 0x09BE },
  unicodeslot=0x09CB,
 },
 [0x09CC]={
  adobename="auvowelsignbengali",
  category="mc",
  description="BENGALI VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x09C7, 0x09D7 },
  unicodeslot=0x09CC,
 },
 [0x09CD]={
  adobename="viramabengali",
  category="mn",
  description="BENGALI SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x09CD,
 },
 [0x09CE]={
  category="lo",
  description="BENGALI LETTER KHANDA TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x09CE,
 },
 [0x09D7]={
  adobename="aulengthmarkbengali",
  category="mc",
  description="BENGALI AU LENGTH MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x09D7,
 },
 [0x09DC]={
  adobename="rrabengali",
  category="lo",
  description="BENGALI LETTER RRA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x09A1, 0x09BC },
  unicodeslot=0x09DC,
 },
 [0x09DD]={
  adobename="rhabengali",
  category="lo",
  description="BENGALI LETTER RHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x09A2, 0x09BC },
  unicodeslot=0x09DD,
 },
 [0x09DF]={
  adobename="yyabengali",
  category="lo",
  description="BENGALI LETTER YYA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x09AF, 0x09BC },
  unicodeslot=0x09DF,
 },
 [0x09E0]={
  adobename="rrvocalicbengali",
  category="lo",
  description="BENGALI LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x09E0,
 },
 [0x09E1]={
  adobename="llvocalicbengali",
  category="lo",
  description="BENGALI LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x09E1,
 },
 [0x09E2]={
  adobename="lvocalicvowelsignbengali",
  category="mn",
  description="BENGALI VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x09E2,
 },
 [0x09E3]={
  adobename="llvocalicvowelsignbengali",
  category="mn",
  description="BENGALI VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x09E3,
 },
 [0x09E6]={
  adobename="zerobengali",
  category="nd",
  description="BENGALI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09E6,
 },
 [0x09E7]={
  adobename="onebengali",
  category="nd",
  description="BENGALI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09E7,
 },
 [0x09E8]={
  adobename="twobengali",
  category="nd",
  description="BENGALI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09E8,
 },
 [0x09E9]={
  adobename="threebengali",
  category="nd",
  description="BENGALI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09E9,
 },
 [0x09EA]={
  adobename="fourbengali",
  category="nd",
  description="BENGALI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09EA,
 },
 [0x09EB]={
  adobename="fivebengali",
  category="nd",
  description="BENGALI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09EB,
 },
 [0x09EC]={
  adobename="sixbengali",
  category="nd",
  description="BENGALI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09EC,
 },
 [0x09ED]={
  adobename="sevenbengali",
  category="nd",
  description="BENGALI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09ED,
 },
 [0x09EE]={
  adobename="eightbengali",
  category="nd",
  description="BENGALI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09EE,
 },
 [0x09EF]={
  adobename="ninebengali",
  category="nd",
  description="BENGALI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x09EF,
 },
 [0x09F0]={
  adobename="ramiddlediagonalbengali",
  category="lo",
  description="BENGALI LETTER RA WITH MIDDLE DIAGONAL",
  direction="l",
  linebreak="al",
  shcode=0x09B0,
  unicodeslot=0x09F0,
 },
 [0x09F1]={
  adobename="ralowerdiagonalbengali",
  category="lo",
  description="BENGALI LETTER RA WITH LOWER DIAGONAL",
  direction="l",
  linebreak="al",
  shcode=0x09B0,
  unicodeslot=0x09F1,
 },
 [0x09F2]={
  adobename="rupeemarkbengali",
  category="sc",
  description="BENGALI RUPEE MARK",
  direction="et",
  linebreak="po",
  unicodeslot=0x09F2,
 },
 [0x09F3]={
  adobename="rupeesignbengali",
  category="sc",
  description="BENGALI RUPEE SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x09F3,
 },
 [0x09F4]={
  adobename="onenumeratorbengali",
  category="no",
  description="BENGALI CURRENCY NUMERATOR ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x09F4,
 },
 [0x09F5]={
  adobename="twonumeratorbengali",
  category="no",
  description="BENGALI CURRENCY NUMERATOR TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x09F5,
 },
 [0x09F6]={
  adobename="threenumeratorbengali",
  category="no",
  description="BENGALI CURRENCY NUMERATOR THREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x09F6,
 },
 [0x09F7]={
  adobename="fournumeratorbengali",
  category="no",
  description="BENGALI CURRENCY NUMERATOR FOUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x09F7,
 },
 [0x09F8]={
  adobename="denominatorminusonenumeratorbengali",
  category="no",
  description="BENGALI CURRENCY NUMERATOR ONE LESS THAN THE DENOMINATOR",
  direction="l",
  linebreak="al",
  unicodeslot=0x09F8,
 },
 [0x09F9]={
  adobename="sixteencurrencydenominatorbengali",
  category="no",
  description="BENGALI CURRENCY DENOMINATOR SIXTEEN",
  direction="l",
  linebreak="po",
  unicodeslot=0x09F9,
 },
 [0x09FA]={
  adobename="issharbengali",
  category="so",
  description="BENGALI ISSHAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x09FA,
 },
 [0x09FB]={
  category="sc",
  description="BENGALI GANDA MARK",
  direction="et",
  linebreak="pr",
  unicodeslot=0x09FB,
 },
 [0x0A01]={
  category="mn",
  description="GURMUKHI SIGN ADAK BINDI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A01,
 },
 [0x0A02]={
  adobename="bindigurmukhi",
  category="mn",
  description="GURMUKHI SIGN BINDI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A02,
 },
 [0x0A03]={
  category="mc",
  description="GURMUKHI SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0A03,
 },
 [0x0A05]={
  adobename="agurmukhi",
  category="lo",
  description="GURMUKHI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A05,
 },
 [0x0A06]={
  adobename="aagurmukhi",
  category="lo",
  description="GURMUKHI LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A06,
 },
 [0x0A07]={
  adobename="igurmukhi",
  category="lo",
  description="GURMUKHI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A07,
 },
 [0x0A08]={
  adobename="iigurmukhi",
  category="lo",
  description="GURMUKHI LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A08,
 },
 [0x0A09]={
  adobename="ugurmukhi",
  category="lo",
  description="GURMUKHI LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A09,
 },
 [0x0A0A]={
  adobename="uugurmukhi",
  category="lo",
  description="GURMUKHI LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A0A,
 },
 [0x0A0F]={
  adobename="eegurmukhi",
  category="lo",
  description="GURMUKHI LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A0F,
 },
 [0x0A10]={
  adobename="aigurmukhi",
  category="lo",
  description="GURMUKHI LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A10,
 },
 [0x0A13]={
  adobename="oogurmukhi",
  category="lo",
  description="GURMUKHI LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A13,
 },
 [0x0A14]={
  adobename="augurmukhi",
  category="lo",
  description="GURMUKHI LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A14,
 },
 [0x0A15]={
  adobename="kagurmukhi",
  category="lo",
  description="GURMUKHI LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A15,
 },
 [0x0A16]={
  adobename="khagurmukhi",
  category="lo",
  description="GURMUKHI LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A16,
 },
 [0x0A17]={
  adobename="gagurmukhi",
  category="lo",
  description="GURMUKHI LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A17,
 },
 [0x0A18]={
  adobename="ghagurmukhi",
  category="lo",
  description="GURMUKHI LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A18,
 },
 [0x0A19]={
  adobename="ngagurmukhi",
  category="lo",
  description="GURMUKHI LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A19,
 },
 [0x0A1A]={
  adobename="cagurmukhi",
  category="lo",
  description="GURMUKHI LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A1A,
 },
 [0x0A1B]={
  adobename="chagurmukhi",
  category="lo",
  description="GURMUKHI LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A1B,
 },
 [0x0A1C]={
  adobename="jagurmukhi",
  category="lo",
  description="GURMUKHI LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A1C,
 },
 [0x0A1D]={
  adobename="jhagurmukhi",
  category="lo",
  description="GURMUKHI LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A1D,
 },
 [0x0A1E]={
  adobename="nyagurmukhi",
  category="lo",
  description="GURMUKHI LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A1E,
 },
 [0x0A1F]={
  adobename="ttagurmukhi",
  category="lo",
  description="GURMUKHI LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A1F,
 },
 [0x0A20]={
  adobename="tthagurmukhi",
  category="lo",
  description="GURMUKHI LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A20,
 },
 [0x0A21]={
  adobename="ddagurmukhi",
  category="lo",
  description="GURMUKHI LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A21,
 },
 [0x0A22]={
  adobename="ddhagurmukhi",
  category="lo",
  description="GURMUKHI LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A22,
 },
 [0x0A23]={
  adobename="nnagurmukhi",
  category="lo",
  description="GURMUKHI LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A23,
 },
 [0x0A24]={
  adobename="tagurmukhi",
  category="lo",
  description="GURMUKHI LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A24,
 },
 [0x0A25]={
  adobename="thagurmukhi",
  category="lo",
  description="GURMUKHI LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A25,
 },
 [0x0A26]={
  adobename="dagurmukhi",
  category="lo",
  description="GURMUKHI LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A26,
 },
 [0x0A27]={
  adobename="dhagurmukhi",
  category="lo",
  description="GURMUKHI LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A27,
 },
 [0x0A28]={
  adobename="nagurmukhi",
  category="lo",
  description="GURMUKHI LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A28,
 },
 [0x0A2A]={
  adobename="pagurmukhi",
  category="lo",
  description="GURMUKHI LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A2A,
 },
 [0x0A2B]={
  adobename="phagurmukhi",
  category="lo",
  description="GURMUKHI LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A2B,
 },
 [0x0A2C]={
  adobename="bagurmukhi",
  category="lo",
  description="GURMUKHI LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A2C,
 },
 [0x0A2D]={
  adobename="bhagurmukhi",
  category="lo",
  description="GURMUKHI LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A2D,
 },
 [0x0A2E]={
  adobename="magurmukhi",
  category="lo",
  description="GURMUKHI LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A2E,
 },
 [0x0A2F]={
  adobename="yagurmukhi",
  category="lo",
  description="GURMUKHI LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A2F,
 },
 [0x0A30]={
  adobename="ragurmukhi",
  category="lo",
  description="GURMUKHI LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A30,
 },
 [0x0A32]={
  adobename="lagurmukhi",
  category="lo",
  description="GURMUKHI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A32,
 },
 [0x0A33]={
  category="lo",
  description="GURMUKHI LETTER LLA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0A32, 0x0A3C },
  unicodeslot=0x0A33,
 },
 [0x0A35]={
  adobename="vagurmukhi",
  category="lo",
  description="GURMUKHI LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A35,
 },
 [0x0A36]={
  adobename="shagurmukhi",
  category="lo",
  description="GURMUKHI LETTER SHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0A38, 0x0A3C },
  unicodeslot=0x0A36,
 },
 [0x0A38]={
  adobename="sagurmukhi",
  category="lo",
  description="GURMUKHI LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A38,
 },
 [0x0A39]={
  adobename="hagurmukhi",
  category="lo",
  description="GURMUKHI LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A39,
 },
 [0x0A3C]={
  adobename="nuktagurmukhi",
  category="mn",
  description="GURMUKHI SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A3C,
 },
 [0x0A3E]={
  adobename="aamatragurmukhi",
  category="mc",
  description="GURMUKHI VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0A3E,
 },
 [0x0A3F]={
  adobename="imatragurmukhi",
  category="mc",
  description="GURMUKHI VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0A3F,
 },
 [0x0A40]={
  adobename="iimatragurmukhi",
  category="mc",
  description="GURMUKHI VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0A40,
 },
 [0x0A41]={
  adobename="umatragurmukhi",
  category="mn",
  description="GURMUKHI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A41,
 },
 [0x0A42]={
  adobename="uumatragurmukhi",
  category="mn",
  description="GURMUKHI VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A42,
 },
 [0x0A47]={
  adobename="eematragurmukhi",
  category="mn",
  description="GURMUKHI VOWEL SIGN EE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A47,
 },
 [0x0A48]={
  adobename="aimatragurmukhi",
  category="mn",
  description="GURMUKHI VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A48,
 },
 [0x0A4B]={
  adobename="oomatragurmukhi",
  category="mn",
  description="GURMUKHI VOWEL SIGN OO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A4B,
 },
 [0x0A4C]={
  adobename="aumatragurmukhi",
  category="mn",
  description="GURMUKHI VOWEL SIGN AU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A4C,
 },
 [0x0A4D]={
  adobename="halantgurmukhi",
  category="mn",
  description="GURMUKHI SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A4D,
 },
 [0x0A51]={
  category="mn",
  description="GURMUKHI SIGN UDAAT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A51,
 },
 [0x0A59]={
  adobename="khhagurmukhi",
  category="lo",
  description="GURMUKHI LETTER KHHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0A16, 0x0A3C },
  unicodeslot=0x0A59,
 },
 [0x0A5A]={
  adobename="ghhagurmukhi",
  category="lo",
  description="GURMUKHI LETTER GHHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0A17, 0x0A3C },
  unicodeslot=0x0A5A,
 },
 [0x0A5B]={
  adobename="zagurmukhi",
  category="lo",
  description="GURMUKHI LETTER ZA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0A1C, 0x0A3C },
  unicodeslot=0x0A5B,
 },
 [0x0A5C]={
  adobename="rragurmukhi",
  category="lo",
  description="GURMUKHI LETTER RRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A5C,
 },
 [0x0A5E]={
  adobename="fagurmukhi",
  category="lo",
  description="GURMUKHI LETTER FA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0A2B, 0x0A3C },
  unicodeslot=0x0A5E,
 },
 [0x0A66]={
  adobename="zerogurmukhi",
  category="nd",
  description="GURMUKHI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A66,
 },
 [0x0A67]={
  adobename="onegurmukhi",
  category="nd",
  description="GURMUKHI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A67,
 },
 [0x0A68]={
  adobename="twogurmukhi",
  category="nd",
  description="GURMUKHI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A68,
 },
 [0x0A69]={
  adobename="threegurmukhi",
  category="nd",
  description="GURMUKHI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A69,
 },
 [0x0A6A]={
  adobename="fourgurmukhi",
  category="nd",
  description="GURMUKHI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A6A,
 },
 [0x0A6B]={
  adobename="fivegurmukhi",
  category="nd",
  description="GURMUKHI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A6B,
 },
 [0x0A6C]={
  adobename="sixgurmukhi",
  category="nd",
  description="GURMUKHI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A6C,
 },
 [0x0A6D]={
  adobename="sevengurmukhi",
  category="nd",
  description="GURMUKHI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A6D,
 },
 [0x0A6E]={
  adobename="eightgurmukhi",
  category="nd",
  description="GURMUKHI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A6E,
 },
 [0x0A6F]={
  adobename="ninegurmukhi",
  category="nd",
  description="GURMUKHI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0A6F,
 },
 [0x0A70]={
  adobename="tippigurmukhi",
  category="mn",
  description="GURMUKHI TIPPI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A70,
 },
 [0x0A71]={
  adobename="addakgurmukhi",
  category="mn",
  description="GURMUKHI ADDAK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A71,
 },
 [0x0A72]={
  adobename="irigurmukhi",
  category="lo",
  description="GURMUKHI IRI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A72,
 },
 [0x0A73]={
  adobename="uragurmukhi",
  category="lo",
  description="GURMUKHI URA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A73,
 },
 [0x0A74]={
  adobename="ekonkargurmukhi",
  category="lo",
  description="GURMUKHI EK ONKAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A74,
 },
 [0x0A75]={
  category="mn",
  description="GURMUKHI SIGN YAKASH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A75,
 },
 [0x0A81]={
  adobename="candrabindugujarati",
  category="mn",
  description="GUJARATI SIGN CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A81,
 },
 [0x0A82]={
  adobename="anusvaragujarati",
  category="mn",
  description="GUJARATI SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0A82,
 },
 [0x0A83]={
  adobename="visargagujarati",
  category="mc",
  description="GUJARATI SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0A83,
 },
 [0x0A85]={
  adobename="agujarati",
  category="lo",
  description="GUJARATI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A85,
 },
 [0x0A86]={
  adobename="aagujarati",
  category="lo",
  description="GUJARATI LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A86,
 },
 [0x0A87]={
  adobename="igujarati",
  category="lo",
  description="GUJARATI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A87,
 },
 [0x0A88]={
  adobename="iigujarati",
  category="lo",
  description="GUJARATI LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A88,
 },
 [0x0A89]={
  adobename="ugujarati",
  category="lo",
  description="GUJARATI LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A89,
 },
 [0x0A8A]={
  adobename="uugujarati",
  category="lo",
  description="GUJARATI LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A8A,
 },
 [0x0A8B]={
  adobename="rvocalicgujarati",
  category="lo",
  description="GUJARATI LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A8B,
 },
 [0x0A8C]={
  category="lo",
  description="GUJARATI LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A8C,
 },
 [0x0A8D]={
  adobename="ecandragujarati",
  category="lo",
  description="GUJARATI VOWEL CANDRA E",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A8D,
 },
 [0x0A8F]={
  adobename="egujarati",
  category="lo",
  description="GUJARATI LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A8F,
 },
 [0x0A90]={
  adobename="aigujarati",
  category="lo",
  description="GUJARATI LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A90,
 },
 [0x0A91]={
  adobename="ocandragujarati",
  category="lo",
  description="GUJARATI VOWEL CANDRA O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A91,
 },
 [0x0A93]={
  adobename="ogujarati",
  category="lo",
  description="GUJARATI LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A93,
 },
 [0x0A94]={
  adobename="augujarati",
  category="lo",
  description="GUJARATI LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A94,
 },
 [0x0A95]={
  adobename="kagujarati",
  category="lo",
  description="GUJARATI LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A95,
 },
 [0x0A96]={
  adobename="khagujarati",
  category="lo",
  description="GUJARATI LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A96,
 },
 [0x0A97]={
  adobename="gagujarati",
  category="lo",
  description="GUJARATI LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A97,
 },
 [0x0A98]={
  adobename="ghagujarati",
  category="lo",
  description="GUJARATI LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A98,
 },
 [0x0A99]={
  adobename="ngagujarati",
  category="lo",
  description="GUJARATI LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A99,
 },
 [0x0A9A]={
  adobename="cagujarati",
  category="lo",
  description="GUJARATI LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A9A,
 },
 [0x0A9B]={
  adobename="chagujarati",
  category="lo",
  description="GUJARATI LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A9B,
 },
 [0x0A9C]={
  adobename="jagujarati",
  category="lo",
  description="GUJARATI LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A9C,
 },
 [0x0A9D]={
  adobename="jhagujarati",
  category="lo",
  description="GUJARATI LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A9D,
 },
 [0x0A9E]={
  adobename="nyagujarati",
  category="lo",
  description="GUJARATI LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A9E,
 },
 [0x0A9F]={
  adobename="ttagujarati",
  category="lo",
  description="GUJARATI LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0A9F,
 },
 [0x0AA0]={
  adobename="tthagujarati",
  category="lo",
  description="GUJARATI LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA0,
 },
 [0x0AA1]={
  adobename="ddagujarati",
  category="lo",
  description="GUJARATI LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA1,
 },
 [0x0AA2]={
  adobename="ddhagujarati",
  category="lo",
  description="GUJARATI LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA2,
 },
 [0x0AA3]={
  adobename="nnagujarati",
  category="lo",
  description="GUJARATI LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA3,
 },
 [0x0AA4]={
  adobename="tagujarati",
  category="lo",
  description="GUJARATI LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA4,
 },
 [0x0AA5]={
  adobename="thagujarati",
  category="lo",
  description="GUJARATI LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA5,
 },
 [0x0AA6]={
  adobename="dagujarati",
  category="lo",
  description="GUJARATI LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA6,
 },
 [0x0AA7]={
  adobename="dhagujarati",
  category="lo",
  description="GUJARATI LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA7,
 },
 [0x0AA8]={
  adobename="nagujarati",
  category="lo",
  description="GUJARATI LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AA8,
 },
 [0x0AAA]={
  adobename="pagujarati",
  category="lo",
  description="GUJARATI LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AAA,
 },
 [0x0AAB]={
  adobename="phagujarati",
  category="lo",
  description="GUJARATI LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AAB,
 },
 [0x0AAC]={
  adobename="bagujarati",
  category="lo",
  description="GUJARATI LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AAC,
 },
 [0x0AAD]={
  adobename="bhagujarati",
  category="lo",
  description="GUJARATI LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AAD,
 },
 [0x0AAE]={
  adobename="magujarati",
  category="lo",
  description="GUJARATI LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AAE,
 },
 [0x0AAF]={
  adobename="yagujarati",
  category="lo",
  description="GUJARATI LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AAF,
 },
 [0x0AB0]={
  adobename="ragujarati",
  category="lo",
  description="GUJARATI LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AB0,
 },
 [0x0AB2]={
  adobename="lagujarati",
  category="lo",
  description="GUJARATI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AB2,
 },
 [0x0AB3]={
  adobename="llagujarati",
  category="lo",
  description="GUJARATI LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AB3,
 },
 [0x0AB5]={
  adobename="vagujarati",
  category="lo",
  description="GUJARATI LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AB5,
 },
 [0x0AB6]={
  adobename="shagujarati",
  category="lo",
  description="GUJARATI LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AB6,
 },
 [0x0AB7]={
  adobename="ssagujarati",
  category="lo",
  description="GUJARATI LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AB7,
 },
 [0x0AB8]={
  adobename="sagujarati",
  category="lo",
  description="GUJARATI LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AB8,
 },
 [0x0AB9]={
  adobename="hagujarati",
  category="lo",
  description="GUJARATI LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AB9,
 },
 [0x0ABC]={
  adobename="nuktagujarati",
  category="mn",
  description="GUJARATI SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0ABC,
 },
 [0x0ABD]={
  category="lo",
  description="GUJARATI SIGN AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0ABD,
 },
 [0x0ABE]={
  adobename="aavowelsigngujarati",
  category="mc",
  description="GUJARATI VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0ABE,
 },
 [0x0ABF]={
  adobename="ivowelsigngujarati",
  category="mc",
  description="GUJARATI VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0ABF,
 },
 [0x0AC0]={
  adobename="iivowelsigngujarati",
  category="mc",
  description="GUJARATI VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0AC0,
 },
 [0x0AC1]={
  adobename="uvowelsigngujarati",
  category="mn",
  description="GUJARATI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AC1,
 },
 [0x0AC2]={
  adobename="uuvowelsigngujarati",
  category="mn",
  description="GUJARATI VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AC2,
 },
 [0x0AC3]={
  adobename="rvocalicvowelsigngujarati",
  category="mn",
  description="GUJARATI VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AC3,
 },
 [0x0AC4]={
  adobename="rrvocalicvowelsigngujarati",
  category="mn",
  description="GUJARATI VOWEL SIGN VOCALIC RR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AC4,
 },
 [0x0AC5]={
  adobename="ecandravowelsigngujarati",
  category="mn",
  description="GUJARATI VOWEL SIGN CANDRA E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AC5,
 },
 [0x0AC7]={
  adobename="evowelsigngujarati",
  category="mn",
  description="GUJARATI VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AC7,
 },
 [0x0AC8]={
  adobename="aivowelsigngujarati",
  category="mn",
  description="GUJARATI VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AC8,
 },
 [0x0AC9]={
  adobename="ocandravowelsigngujarati",
  category="mc",
  description="GUJARATI VOWEL SIGN CANDRA O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0AC9,
 },
 [0x0ACB]={
  adobename="ovowelsigngujarati",
  category="mc",
  description="GUJARATI VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0ACB,
 },
 [0x0ACC]={
  adobename="auvowelsigngujarati",
  category="mc",
  description="GUJARATI VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0ACC,
 },
 [0x0ACD]={
  adobename="viramagujarati",
  category="mn",
  description="GUJARATI SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0ACD,
 },
 [0x0AD0]={
  adobename="omgujarati",
  category="lo",
  description="GUJARATI OM",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AD0,
 },
 [0x0AE0]={
  adobename="rrvocalicgujarati",
  category="lo",
  description="GUJARATI LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AE0,
 },
 [0x0AE1]={
  category="lo",
  description="GUJARATI LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AE1,
 },
 [0x0AE2]={
  category="mn",
  description="GUJARATI VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AE2,
 },
 [0x0AE3]={
  category="mn",
  description="GUJARATI VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0AE3,
 },
 [0x0AE6]={
  adobename="zerogujarati",
  category="nd",
  description="GUJARATI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AE6,
 },
 [0x0AE7]={
  adobename="onegujarati",
  category="nd",
  description="GUJARATI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AE7,
 },
 [0x0AE8]={
  adobename="twogujarati",
  category="nd",
  description="GUJARATI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AE8,
 },
 [0x0AE9]={
  adobename="threegujarati",
  category="nd",
  description="GUJARATI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AE9,
 },
 [0x0AEA]={
  adobename="fourgujarati",
  category="nd",
  description="GUJARATI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AEA,
 },
 [0x0AEB]={
  adobename="fivegujarati",
  category="nd",
  description="GUJARATI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AEB,
 },
 [0x0AEC]={
  adobename="sixgujarati",
  category="nd",
  description="GUJARATI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AEC,
 },
 [0x0AED]={
  adobename="sevengujarati",
  category="nd",
  description="GUJARATI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AED,
 },
 [0x0AEE]={
  adobename="eightgujarati",
  category="nd",
  description="GUJARATI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AEE,
 },
 [0x0AEF]={
  adobename="ninegujarati",
  category="nd",
  description="GUJARATI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0AEF,
 },
 [0x0AF0]={
  category="po",
  description="GUJARATI ABBREVIATION SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0AF0,
 },
 [0x0AF1]={
  category="sc",
  description="GUJARATI RUPEE SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x0AF1,
 },
 [0x0B01]={
  category="mn",
  description="ORIYA SIGN CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B01,
 },
 [0x0B02]={
  category="mc",
  description="ORIYA SIGN ANUSVARA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0B02,
 },
 [0x0B03]={
  category="mc",
  description="ORIYA SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0B03,
 },
 [0x0B05]={
  category="lo",
  description="ORIYA LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B05,
 },
 [0x0B06]={
  category="lo",
  description="ORIYA LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B06,
 },
 [0x0B07]={
  category="lo",
  description="ORIYA LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B07,
 },
 [0x0B08]={
  category="lo",
  description="ORIYA LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B08,
 },
 [0x0B09]={
  category="lo",
  description="ORIYA LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B09,
 },
 [0x0B0A]={
  category="lo",
  description="ORIYA LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B0A,
 },
 [0x0B0B]={
  category="lo",
  description="ORIYA LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B0B,
 },
 [0x0B0C]={
  category="lo",
  description="ORIYA LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B0C,
 },
 [0x0B0F]={
  category="lo",
  description="ORIYA LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B0F,
 },
 [0x0B10]={
  category="lo",
  description="ORIYA LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B10,
 },
 [0x0B13]={
  category="lo",
  description="ORIYA LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B13,
 },
 [0x0B14]={
  category="lo",
  description="ORIYA LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B14,
 },
 [0x0B15]={
  category="lo",
  description="ORIYA LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B15,
 },
 [0x0B16]={
  category="lo",
  description="ORIYA LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B16,
 },
 [0x0B17]={
  category="lo",
  description="ORIYA LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B17,
 },
 [0x0B18]={
  category="lo",
  description="ORIYA LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B18,
 },
 [0x0B19]={
  category="lo",
  description="ORIYA LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B19,
 },
 [0x0B1A]={
  category="lo",
  description="ORIYA LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B1A,
 },
 [0x0B1B]={
  category="lo",
  description="ORIYA LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B1B,
 },
 [0x0B1C]={
  category="lo",
  description="ORIYA LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B1C,
 },
 [0x0B1D]={
  category="lo",
  description="ORIYA LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B1D,
 },
 [0x0B1E]={
  category="lo",
  description="ORIYA LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B1E,
 },
 [0x0B1F]={
  category="lo",
  description="ORIYA LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B1F,
 },
 [0x0B20]={
  category="lo",
  description="ORIYA LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B20,
 },
 [0x0B21]={
  category="lo",
  description="ORIYA LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B21,
 },
 [0x0B22]={
  category="lo",
  description="ORIYA LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B22,
 },
 [0x0B23]={
  category="lo",
  description="ORIYA LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B23,
 },
 [0x0B24]={
  category="lo",
  description="ORIYA LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B24,
 },
 [0x0B25]={
  category="lo",
  description="ORIYA LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B25,
 },
 [0x0B26]={
  category="lo",
  description="ORIYA LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B26,
 },
 [0x0B27]={
  category="lo",
  description="ORIYA LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B27,
 },
 [0x0B28]={
  category="lo",
  description="ORIYA LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B28,
 },
 [0x0B2A]={
  category="lo",
  description="ORIYA LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B2A,
 },
 [0x0B2B]={
  category="lo",
  description="ORIYA LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B2B,
 },
 [0x0B2C]={
  category="lo",
  description="ORIYA LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B2C,
 },
 [0x0B2D]={
  category="lo",
  description="ORIYA LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B2D,
 },
 [0x0B2E]={
  category="lo",
  description="ORIYA LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B2E,
 },
 [0x0B2F]={
  category="lo",
  description="ORIYA LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B2F,
 },
 [0x0B30]={
  category="lo",
  description="ORIYA LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B30,
 },
 [0x0B32]={
  category="lo",
  description="ORIYA LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B32,
 },
 [0x0B33]={
  category="lo",
  description="ORIYA LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B33,
 },
 [0x0B35]={
  category="lo",
  description="ORIYA LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B35,
 },
 [0x0B36]={
  category="lo",
  description="ORIYA LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B36,
 },
 [0x0B37]={
  category="lo",
  description="ORIYA LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B37,
 },
 [0x0B38]={
  category="lo",
  description="ORIYA LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B38,
 },
 [0x0B39]={
  category="lo",
  description="ORIYA LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B39,
 },
 [0x0B3C]={
  category="mn",
  description="ORIYA SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B3C,
 },
 [0x0B3D]={
  category="lo",
  description="ORIYA SIGN AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B3D,
 },
 [0x0B3E]={
  category="mc",
  description="ORIYA VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0B3E,
 },
 [0x0B3F]={
  category="mn",
  description="ORIYA VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B3F,
 },
 [0x0B40]={
  category="mc",
  description="ORIYA VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0B40,
 },
 [0x0B41]={
  category="mn",
  description="ORIYA VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B41,
 },
 [0x0B42]={
  category="mn",
  description="ORIYA VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B42,
 },
 [0x0B43]={
  category="mn",
  description="ORIYA VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B43,
 },
 [0x0B44]={
  category="mn",
  description="ORIYA VOWEL SIGN VOCALIC RR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B44,
 },
 [0x0B47]={
  category="mc",
  description="ORIYA VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0B47,
 },
 [0x0B48]={
  category="mc",
  description="ORIYA VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0B47, 0x0B56 },
  unicodeslot=0x0B48,
 },
 [0x0B4B]={
  category="mc",
  description="ORIYA VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0B47, 0x0B3E },
  unicodeslot=0x0B4B,
 },
 [0x0B4C]={
  category="mc",
  description="ORIYA VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0B47, 0x0B57 },
  unicodeslot=0x0B4C,
 },
 [0x0B4D]={
  category="mn",
  description="ORIYA SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B4D,
 },
 [0x0B56]={
  category="mn",
  description="ORIYA AI LENGTH MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B56,
 },
 [0x0B57]={
  category="mc",
  description="ORIYA AU LENGTH MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0B57,
 },
 [0x0B5C]={
  category="lo",
  description="ORIYA LETTER RRA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0B21, 0x0B3C },
  unicodeslot=0x0B5C,
 },
 [0x0B5D]={
  category="lo",
  description="ORIYA LETTER RHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0B22, 0x0B3C },
  unicodeslot=0x0B5D,
 },
 [0x0B5F]={
  category="lo",
  description="ORIYA LETTER YYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B5F,
 },
 [0x0B60]={
  category="lo",
  description="ORIYA LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B60,
 },
 [0x0B61]={
  category="lo",
  description="ORIYA LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B61,
 },
 [0x0B62]={
  category="mn",
  description="ORIYA VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B62,
 },
 [0x0B63]={
  category="mn",
  description="ORIYA VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B63,
 },
 [0x0B66]={
  category="nd",
  description="ORIYA DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B66,
 },
 [0x0B67]={
  category="nd",
  description="ORIYA DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B67,
 },
 [0x0B68]={
  category="nd",
  description="ORIYA DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B68,
 },
 [0x0B69]={
  category="nd",
  description="ORIYA DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B69,
 },
 [0x0B6A]={
  category="nd",
  description="ORIYA DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B6A,
 },
 [0x0B6B]={
  category="nd",
  description="ORIYA DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B6B,
 },
 [0x0B6C]={
  category="nd",
  description="ORIYA DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B6C,
 },
 [0x0B6D]={
  category="nd",
  description="ORIYA DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B6D,
 },
 [0x0B6E]={
  category="nd",
  description="ORIYA DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B6E,
 },
 [0x0B6F]={
  category="nd",
  description="ORIYA DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0B6F,
 },
 [0x0B70]={
  category="so",
  description="ORIYA ISSHAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B70,
 },
 [0x0B71]={
  category="lo",
  description="ORIYA LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B71,
 },
 [0x0B72]={
  category="no",
  description="ORIYA FRACTION ONE QUARTER",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B72,
 },
 [0x0B73]={
  category="no",
  description="ORIYA FRACTION ONE HALF",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B73,
 },
 [0x0B74]={
  category="no",
  description="ORIYA FRACTION THREE QUARTERS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B74,
 },
 [0x0B75]={
  category="no",
  description="ORIYA FRACTION ONE SIXTEENTH",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B75,
 },
 [0x0B76]={
  category="no",
  description="ORIYA FRACTION ONE EIGHTH",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B76,
 },
 [0x0B77]={
  category="no",
  description="ORIYA FRACTION THREE SIXTEENTHS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B77,
 },
 [0x0B82]={
  category="mn",
  description="TAMIL SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0B82,
 },
 [0x0B83]={
  category="lo",
  description="TAMIL SIGN VISARGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B83,
 },
 [0x0B85]={
  category="lo",
  description="TAMIL LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B85,
 },
 [0x0B86]={
  category="lo",
  description="TAMIL LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B86,
 },
 [0x0B87]={
  category="lo",
  description="TAMIL LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B87,
 },
 [0x0B88]={
  category="lo",
  description="TAMIL LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B88,
 },
 [0x0B89]={
  category="lo",
  description="TAMIL LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B89,
 },
 [0x0B8A]={
  category="lo",
  description="TAMIL LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B8A,
 },
 [0x0B8E]={
  category="lo",
  description="TAMIL LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B8E,
 },
 [0x0B8F]={
  category="lo",
  description="TAMIL LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B8F,
 },
 [0x0B90]={
  category="lo",
  description="TAMIL LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B90,
 },
 [0x0B92]={
  category="lo",
  description="TAMIL LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B92,
 },
 [0x0B93]={
  category="lo",
  description="TAMIL LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B93,
 },
 [0x0B94]={
  category="lo",
  description="TAMIL LETTER AU",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0B92, 0x0BD7 },
  unicodeslot=0x0B94,
 },
 [0x0B95]={
  category="lo",
  description="TAMIL LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B95,
 },
 [0x0B99]={
  category="lo",
  description="TAMIL LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B99,
 },
 [0x0B9A]={
  category="lo",
  description="TAMIL LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B9A,
 },
 [0x0B9C]={
  category="lo",
  description="TAMIL LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B9C,
 },
 [0x0B9E]={
  category="lo",
  description="TAMIL LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B9E,
 },
 [0x0B9F]={
  category="lo",
  description="TAMIL LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0B9F,
 },
 [0x0BA3]={
  category="lo",
  description="TAMIL LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BA3,
 },
 [0x0BA4]={
  category="lo",
  description="TAMIL LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BA4,
 },
 [0x0BA8]={
  category="lo",
  description="TAMIL LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BA8,
 },
 [0x0BA9]={
  category="lo",
  description="TAMIL LETTER NNNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BA9,
 },
 [0x0BAA]={
  category="lo",
  description="TAMIL LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BAA,
 },
 [0x0BAE]={
  category="lo",
  description="TAMIL LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BAE,
 },
 [0x0BAF]={
  category="lo",
  description="TAMIL LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BAF,
 },
 [0x0BB0]={
  category="lo",
  description="TAMIL LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB0,
 },
 [0x0BB1]={
  category="lo",
  description="TAMIL LETTER RRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB1,
 },
 [0x0BB2]={
  category="lo",
  description="TAMIL LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB2,
 },
 [0x0BB3]={
  category="lo",
  description="TAMIL LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB3,
 },
 [0x0BB4]={
  category="lo",
  description="TAMIL LETTER LLLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB4,
 },
 [0x0BB5]={
  category="lo",
  description="TAMIL LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB5,
 },
 [0x0BB6]={
  category="lo",
  description="TAMIL LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB6,
 },
 [0x0BB7]={
  category="lo",
  description="TAMIL LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB7,
 },
 [0x0BB8]={
  category="lo",
  description="TAMIL LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB8,
 },
 [0x0BB9]={
  category="lo",
  description="TAMIL LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BB9,
 },
 [0x0BBE]={
  category="mc",
  description="TAMIL VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0BBE,
 },
 [0x0BBF]={
  category="mc",
  description="TAMIL VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0BBF,
 },
 [0x0BC0]={
  category="mn",
  description="TAMIL VOWEL SIGN II",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0BC0,
 },
 [0x0BC1]={
  category="mc",
  description="TAMIL VOWEL SIGN U",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0BC1,
 },
 [0x0BC2]={
  category="mc",
  description="TAMIL VOWEL SIGN UU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0BC2,
 },
 [0x0BC6]={
  category="mc",
  description="TAMIL VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0BC6,
 },
 [0x0BC7]={
  category="mc",
  description="TAMIL VOWEL SIGN EE",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0BC7,
 },
 [0x0BC8]={
  category="mc",
  description="TAMIL VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0BC8,
 },
 [0x0BCA]={
  category="mc",
  description="TAMIL VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0BC6, 0x0BBE },
  unicodeslot=0x0BCA,
 },
 [0x0BCB]={
  category="mc",
  description="TAMIL VOWEL SIGN OO",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0BC7, 0x0BBE },
  unicodeslot=0x0BCB,
 },
 [0x0BCC]={
  category="mc",
  description="TAMIL VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0BC6, 0x0BD7 },
  unicodeslot=0x0BCC,
 },
 [0x0BCD]={
  category="mn",
  description="TAMIL SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0BCD,
 },
 [0x0BD0]={
  category="lo",
  description="TAMIL OM",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BD0,
 },
 [0x0BD7]={
  category="mc",
  description="TAMIL AU LENGTH MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0BD7,
 },
 [0x0BE6]={
  category="nd",
  description="TAMIL DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BE6,
 },
 [0x0BE7]={
  category="nd",
  description="TAMIL DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BE7,
 },
 [0x0BE8]={
  category="nd",
  description="TAMIL DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BE8,
 },
 [0x0BE9]={
  category="nd",
  description="TAMIL DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BE9,
 },
 [0x0BEA]={
  category="nd",
  description="TAMIL DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BEA,
 },
 [0x0BEB]={
  category="nd",
  description="TAMIL DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BEB,
 },
 [0x0BEC]={
  category="nd",
  description="TAMIL DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BEC,
 },
 [0x0BED]={
  category="nd",
  description="TAMIL DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BED,
 },
 [0x0BEE]={
  category="nd",
  description="TAMIL DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BEE,
 },
 [0x0BEF]={
  category="nd",
  description="TAMIL DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0BEF,
 },
 [0x0BF0]={
  category="no",
  description="TAMIL NUMBER TEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BF0,
 },
 [0x0BF1]={
  category="no",
  description="TAMIL NUMBER ONE HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BF1,
 },
 [0x0BF2]={
  category="no",
  description="TAMIL NUMBER ONE THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x0BF2,
 },
 [0x0BF3]={
  category="so",
  description="TAMIL DAY SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x0BF3,
 },
 [0x0BF4]={
  category="so",
  description="TAMIL MONTH SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x0BF4,
 },
 [0x0BF5]={
  category="so",
  description="TAMIL YEAR SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x0BF5,
 },
 [0x0BF6]={
  category="so",
  description="TAMIL DEBIT SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x0BF6,
 },
 [0x0BF7]={
  category="so",
  description="TAMIL CREDIT SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x0BF7,
 },
 [0x0BF8]={
  category="so",
  description="TAMIL AS ABOVE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x0BF8,
 },
 [0x0BF9]={
  category="sc",
  description="TAMIL RUPEE SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x0BF9,
 },
 [0x0BFA]={
  category="so",
  description="TAMIL NUMBER SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x0BFA,
 },
 [0x0C01]={
  category="mc",
  description="TELUGU SIGN CANDRABINDU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C01,
 },
 [0x0C02]={
  category="mc",
  description="TELUGU SIGN ANUSVARA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C02,
 },
 [0x0C03]={
  category="mc",
  description="TELUGU SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C03,
 },
 [0x0C05]={
  category="lo",
  description="TELUGU LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C05,
 },
 [0x0C06]={
  category="lo",
  description="TELUGU LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C06,
 },
 [0x0C07]={
  category="lo",
  description="TELUGU LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C07,
 },
 [0x0C08]={
  category="lo",
  description="TELUGU LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C08,
 },
 [0x0C09]={
  category="lo",
  description="TELUGU LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C09,
 },
 [0x0C0A]={
  category="lo",
  description="TELUGU LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C0A,
 },
 [0x0C0B]={
  category="lo",
  description="TELUGU LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C0B,
 },
 [0x0C0C]={
  category="lo",
  description="TELUGU LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C0C,
 },
 [0x0C0E]={
  category="lo",
  description="TELUGU LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C0E,
 },
 [0x0C0F]={
  category="lo",
  description="TELUGU LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C0F,
 },
 [0x0C10]={
  category="lo",
  description="TELUGU LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C10,
 },
 [0x0C12]={
  category="lo",
  description="TELUGU LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C12,
 },
 [0x0C13]={
  category="lo",
  description="TELUGU LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C13,
 },
 [0x0C14]={
  category="lo",
  description="TELUGU LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C14,
 },
 [0x0C15]={
  category="lo",
  description="TELUGU LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C15,
 },
 [0x0C16]={
  category="lo",
  description="TELUGU LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C16,
 },
 [0x0C17]={
  category="lo",
  description="TELUGU LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C17,
 },
 [0x0C18]={
  category="lo",
  description="TELUGU LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C18,
 },
 [0x0C19]={
  category="lo",
  description="TELUGU LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C19,
 },
 [0x0C1A]={
  category="lo",
  description="TELUGU LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C1A,
 },
 [0x0C1B]={
  category="lo",
  description="TELUGU LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C1B,
 },
 [0x0C1C]={
  category="lo",
  description="TELUGU LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C1C,
 },
 [0x0C1D]={
  category="lo",
  description="TELUGU LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C1D,
 },
 [0x0C1E]={
  category="lo",
  description="TELUGU LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C1E,
 },
 [0x0C1F]={
  category="lo",
  description="TELUGU LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C1F,
 },
 [0x0C20]={
  category="lo",
  description="TELUGU LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C20,
 },
 [0x0C21]={
  category="lo",
  description="TELUGU LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C21,
 },
 [0x0C22]={
  category="lo",
  description="TELUGU LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C22,
 },
 [0x0C23]={
  category="lo",
  description="TELUGU LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C23,
 },
 [0x0C24]={
  category="lo",
  description="TELUGU LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C24,
 },
 [0x0C25]={
  category="lo",
  description="TELUGU LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C25,
 },
 [0x0C26]={
  category="lo",
  description="TELUGU LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C26,
 },
 [0x0C27]={
  category="lo",
  description="TELUGU LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C27,
 },
 [0x0C28]={
  category="lo",
  description="TELUGU LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C28,
 },
 [0x0C2A]={
  category="lo",
  description="TELUGU LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C2A,
 },
 [0x0C2B]={
  category="lo",
  description="TELUGU LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C2B,
 },
 [0x0C2C]={
  category="lo",
  description="TELUGU LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C2C,
 },
 [0x0C2D]={
  category="lo",
  description="TELUGU LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C2D,
 },
 [0x0C2E]={
  category="lo",
  description="TELUGU LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C2E,
 },
 [0x0C2F]={
  category="lo",
  description="TELUGU LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C2F,
 },
 [0x0C30]={
  category="lo",
  description="TELUGU LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C30,
 },
 [0x0C31]={
  category="lo",
  description="TELUGU LETTER RRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C31,
 },
 [0x0C32]={
  category="lo",
  description="TELUGU LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C32,
 },
 [0x0C33]={
  category="lo",
  description="TELUGU LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C33,
 },
 [0x0C35]={
  category="lo",
  description="TELUGU LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C35,
 },
 [0x0C36]={
  category="lo",
  description="TELUGU LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C36,
 },
 [0x0C37]={
  category="lo",
  description="TELUGU LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C37,
 },
 [0x0C38]={
  category="lo",
  description="TELUGU LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C38,
 },
 [0x0C39]={
  category="lo",
  description="TELUGU LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C39,
 },
 [0x0C3D]={
  category="lo",
  description="TELUGU SIGN AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C3D,
 },
 [0x0C3E]={
  category="mn",
  description="TELUGU VOWEL SIGN AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C3E,
 },
 [0x0C3F]={
  category="mn",
  description="TELUGU VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C3F,
 },
 [0x0C40]={
  category="mn",
  description="TELUGU VOWEL SIGN II",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C40,
 },
 [0x0C41]={
  category="mc",
  description="TELUGU VOWEL SIGN U",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C41,
 },
 [0x0C42]={
  category="mc",
  description="TELUGU VOWEL SIGN UU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C42,
 },
 [0x0C43]={
  category="mc",
  description="TELUGU VOWEL SIGN VOCALIC R",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C43,
 },
 [0x0C44]={
  category="mc",
  description="TELUGU VOWEL SIGN VOCALIC RR",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C44,
 },
 [0x0C46]={
  category="mn",
  description="TELUGU VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C46,
 },
 [0x0C47]={
  category="mn",
  description="TELUGU VOWEL SIGN EE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C47,
 },
 [0x0C48]={
  category="mn",
  description="TELUGU VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0C46, 0x0C56 },
  unicodeslot=0x0C48,
 },
 [0x0C4A]={
  category="mn",
  description="TELUGU VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C4A,
 },
 [0x0C4B]={
  category="mn",
  description="TELUGU VOWEL SIGN OO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C4B,
 },
 [0x0C4C]={
  category="mn",
  description="TELUGU VOWEL SIGN AU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C4C,
 },
 [0x0C4D]={
  category="mn",
  description="TELUGU SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C4D,
 },
 [0x0C55]={
  category="mn",
  description="TELUGU LENGTH MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C55,
 },
 [0x0C56]={
  category="mn",
  description="TELUGU AI LENGTH MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C56,
 },
 [0x0C58]={
  category="lo",
  description="TELUGU LETTER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C58,
 },
 [0x0C59]={
  category="lo",
  description="TELUGU LETTER DZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C59,
 },
 [0x0C60]={
  category="lo",
  description="TELUGU LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C60,
 },
 [0x0C61]={
  category="lo",
  description="TELUGU LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C61,
 },
 [0x0C62]={
  category="mn",
  description="TELUGU VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C62,
 },
 [0x0C63]={
  category="mn",
  description="TELUGU VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0C63,
 },
 [0x0C66]={
  category="nd",
  description="TELUGU DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C66,
 },
 [0x0C67]={
  category="nd",
  description="TELUGU DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C67,
 },
 [0x0C68]={
  category="nd",
  description="TELUGU DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C68,
 },
 [0x0C69]={
  category="nd",
  description="TELUGU DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C69,
 },
 [0x0C6A]={
  category="nd",
  description="TELUGU DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C6A,
 },
 [0x0C6B]={
  category="nd",
  description="TELUGU DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C6B,
 },
 [0x0C6C]={
  category="nd",
  description="TELUGU DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C6C,
 },
 [0x0C6D]={
  category="nd",
  description="TELUGU DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C6D,
 },
 [0x0C6E]={
  category="nd",
  description="TELUGU DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C6E,
 },
 [0x0C6F]={
  category="nd",
  description="TELUGU DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0C6F,
 },
 [0x0C78]={
  category="no",
  description="TELUGU FRACTION DIGIT ZERO FOR ODD POWERS OF FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x0C78,
 },
 [0x0C79]={
  category="no",
  description="TELUGU FRACTION DIGIT ONE FOR ODD POWERS OF FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x0C79,
 },
 [0x0C7A]={
  category="no",
  description="TELUGU FRACTION DIGIT TWO FOR ODD POWERS OF FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x0C7A,
 },
 [0x0C7B]={
  category="no",
  description="TELUGU FRACTION DIGIT THREE FOR ODD POWERS OF FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x0C7B,
 },
 [0x0C7C]={
  category="no",
  description="TELUGU FRACTION DIGIT ONE FOR EVEN POWERS OF FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x0C7C,
 },
 [0x0C7D]={
  category="no",
  description="TELUGU FRACTION DIGIT TWO FOR EVEN POWERS OF FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x0C7D,
 },
 [0x0C7E]={
  category="no",
  description="TELUGU FRACTION DIGIT THREE FOR EVEN POWERS OF FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x0C7E,
 },
 [0x0C7F]={
  category="so",
  description="TELUGU SIGN TUUMU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C7F,
 },
 [0x0C82]={
  category="mc",
  description="KANNADA SIGN ANUSVARA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C82,
 },
 [0x0C83]={
  category="mc",
  description="KANNADA SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0C83,
 },
 [0x0C85]={
  category="lo",
  description="KANNADA LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C85,
 },
 [0x0C86]={
  category="lo",
  description="KANNADA LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C86,
 },
 [0x0C87]={
  category="lo",
  description="KANNADA LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C87,
 },
 [0x0C88]={
  category="lo",
  description="KANNADA LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C88,
 },
 [0x0C89]={
  category="lo",
  description="KANNADA LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C89,
 },
 [0x0C8A]={
  category="lo",
  description="KANNADA LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C8A,
 },
 [0x0C8B]={
  category="lo",
  description="KANNADA LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C8B,
 },
 [0x0C8C]={
  category="lo",
  description="KANNADA LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C8C,
 },
 [0x0C8E]={
  category="lo",
  description="KANNADA LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C8E,
 },
 [0x0C8F]={
  category="lo",
  description="KANNADA LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C8F,
 },
 [0x0C90]={
  category="lo",
  description="KANNADA LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C90,
 },
 [0x0C92]={
  category="lo",
  description="KANNADA LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C92,
 },
 [0x0C93]={
  category="lo",
  description="KANNADA LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C93,
 },
 [0x0C94]={
  category="lo",
  description="KANNADA LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C94,
 },
 [0x0C95]={
  category="lo",
  description="KANNADA LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C95,
 },
 [0x0C96]={
  category="lo",
  description="KANNADA LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C96,
 },
 [0x0C97]={
  category="lo",
  description="KANNADA LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C97,
 },
 [0x0C98]={
  category="lo",
  description="KANNADA LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C98,
 },
 [0x0C99]={
  category="lo",
  description="KANNADA LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C99,
 },
 [0x0C9A]={
  category="lo",
  description="KANNADA LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C9A,
 },
 [0x0C9B]={
  category="lo",
  description="KANNADA LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C9B,
 },
 [0x0C9C]={
  category="lo",
  description="KANNADA LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C9C,
 },
 [0x0C9D]={
  category="lo",
  description="KANNADA LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C9D,
 },
 [0x0C9E]={
  category="lo",
  description="KANNADA LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C9E,
 },
 [0x0C9F]={
  category="lo",
  description="KANNADA LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0C9F,
 },
 [0x0CA0]={
  category="lo",
  description="KANNADA LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA0,
 },
 [0x0CA1]={
  category="lo",
  description="KANNADA LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA1,
 },
 [0x0CA2]={
  category="lo",
  description="KANNADA LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA2,
 },
 [0x0CA3]={
  category="lo",
  description="KANNADA LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA3,
 },
 [0x0CA4]={
  category="lo",
  description="KANNADA LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA4,
 },
 [0x0CA5]={
  category="lo",
  description="KANNADA LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA5,
 },
 [0x0CA6]={
  category="lo",
  description="KANNADA LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA6,
 },
 [0x0CA7]={
  category="lo",
  description="KANNADA LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA7,
 },
 [0x0CA8]={
  category="lo",
  description="KANNADA LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CA8,
 },
 [0x0CAA]={
  category="lo",
  description="KANNADA LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CAA,
 },
 [0x0CAB]={
  category="lo",
  description="KANNADA LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CAB,
 },
 [0x0CAC]={
  category="lo",
  description="KANNADA LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CAC,
 },
 [0x0CAD]={
  category="lo",
  description="KANNADA LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CAD,
 },
 [0x0CAE]={
  category="lo",
  description="KANNADA LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CAE,
 },
 [0x0CAF]={
  category="lo",
  description="KANNADA LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CAF,
 },
 [0x0CB0]={
  category="lo",
  description="KANNADA LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB0,
 },
 [0x0CB1]={
  category="lo",
  description="KANNADA LETTER RRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB1,
 },
 [0x0CB2]={
  category="lo",
  description="KANNADA LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB2,
 },
 [0x0CB3]={
  category="lo",
  description="KANNADA LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB3,
 },
 [0x0CB5]={
  category="lo",
  description="KANNADA LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB5,
 },
 [0x0CB6]={
  category="lo",
  description="KANNADA LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB6,
 },
 [0x0CB7]={
  category="lo",
  description="KANNADA LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB7,
 },
 [0x0CB8]={
  category="lo",
  description="KANNADA LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB8,
 },
 [0x0CB9]={
  category="lo",
  description="KANNADA LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CB9,
 },
 [0x0CBC]={
  category="mn",
  description="KANNADA SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0CBC,
 },
 [0x0CBD]={
  category="lo",
  description="KANNADA SIGN AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CBD,
 },
 [0x0CBE]={
  category="mc",
  description="KANNADA VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CBE,
 },
 [0x0CBF]={
  category="mn",
  description="KANNADA VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CBF,
 },
 [0x0CC0]={
  category="mc",
  description="KANNADA VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0CBF, 0x0CD5 },
  unicodeslot=0x0CC0,
 },
 [0x0CC1]={
  category="mc",
  description="KANNADA VOWEL SIGN U",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CC1,
 },
 [0x0CC2]={
  category="mc",
  description="KANNADA VOWEL SIGN UU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CC2,
 },
 [0x0CC3]={
  category="mc",
  description="KANNADA VOWEL SIGN VOCALIC R",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CC3,
 },
 [0x0CC4]={
  category="mc",
  description="KANNADA VOWEL SIGN VOCALIC RR",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CC4,
 },
 [0x0CC6]={
  category="mn",
  description="KANNADA VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CC6,
 },
 [0x0CC7]={
  category="mc",
  description="KANNADA VOWEL SIGN EE",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0CC6, 0x0CD5 },
  unicodeslot=0x0CC7,
 },
 [0x0CC8]={
  category="mc",
  description="KANNADA VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0CC6, 0x0CD6 },
  unicodeslot=0x0CC8,
 },
 [0x0CCA]={
  category="mc",
  description="KANNADA VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0CC6, 0x0CC2 },
  unicodeslot=0x0CCA,
 },
 [0x0CCB]={
  category="mc",
  description="KANNADA VOWEL SIGN OO",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0CCA, 0x0CD5 },
  unicodeslot=0x0CCB,
 },
 [0x0CCC]={
  category="mn",
  description="KANNADA VOWEL SIGN AU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0CCC,
 },
 [0x0CCD]={
  category="mn",
  description="KANNADA SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0CCD,
 },
 [0x0CD5]={
  category="mc",
  description="KANNADA LENGTH MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CD5,
 },
 [0x0CD6]={
  category="mc",
  description="KANNADA AI LENGTH MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0CD6,
 },
 [0x0CDE]={
  category="lo",
  description="KANNADA LETTER FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CDE,
 },
 [0x0CE0]={
  category="lo",
  description="KANNADA LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CE0,
 },
 [0x0CE1]={
  category="lo",
  description="KANNADA LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CE1,
 },
 [0x0CE2]={
  category="mn",
  description="KANNADA VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0CE2,
 },
 [0x0CE3]={
  category="mn",
  description="KANNADA VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0CE3,
 },
 [0x0CE6]={
  category="nd",
  description="KANNADA DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CE6,
 },
 [0x0CE7]={
  category="nd",
  description="KANNADA DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CE7,
 },
 [0x0CE8]={
  category="nd",
  description="KANNADA DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CE8,
 },
 [0x0CE9]={
  category="nd",
  description="KANNADA DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CE9,
 },
 [0x0CEA]={
  category="nd",
  description="KANNADA DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CEA,
 },
 [0x0CEB]={
  category="nd",
  description="KANNADA DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CEB,
 },
 [0x0CEC]={
  category="nd",
  description="KANNADA DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CEC,
 },
 [0x0CED]={
  category="nd",
  description="KANNADA DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CED,
 },
 [0x0CEE]={
  category="nd",
  description="KANNADA DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CEE,
 },
 [0x0CEF]={
  category="nd",
  description="KANNADA DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0CEF,
 },
 [0x0CF1]={
  category="so",
  description="KANNADA SIGN JIHVAMULIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CF1,
 },
 [0x0CF2]={
  category="so",
  description="KANNADA SIGN UPADHMANIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0CF2,
 },
 [0x0D02]={
  category="mc",
  description="MALAYALAM SIGN ANUSVARA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D02,
 },
 [0x0D03]={
  category="mc",
  description="MALAYALAM SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D03,
 },
 [0x0D05]={
  category="lo",
  description="MALAYALAM LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D05,
 },
 [0x0D06]={
  category="lo",
  description="MALAYALAM LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D06,
 },
 [0x0D07]={
  category="lo",
  description="MALAYALAM LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D07,
 },
 [0x0D08]={
  category="lo",
  description="MALAYALAM LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D08,
 },
 [0x0D09]={
  category="lo",
  description="MALAYALAM LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D09,
 },
 [0x0D0A]={
  category="lo",
  description="MALAYALAM LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D0A,
 },
 [0x0D0B]={
  category="lo",
  description="MALAYALAM LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D0B,
 },
 [0x0D0C]={
  category="lo",
  description="MALAYALAM LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D0C,
 },
 [0x0D0E]={
  category="lo",
  description="MALAYALAM LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D0E,
 },
 [0x0D0F]={
  category="lo",
  description="MALAYALAM LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D0F,
 },
 [0x0D10]={
  category="lo",
  description="MALAYALAM LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D10,
 },
 [0x0D12]={
  category="lo",
  description="MALAYALAM LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D12,
 },
 [0x0D13]={
  category="lo",
  description="MALAYALAM LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D13,
 },
 [0x0D14]={
  category="lo",
  description="MALAYALAM LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D14,
 },
 [0x0D15]={
  category="lo",
  description="MALAYALAM LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D15,
 },
 [0x0D16]={
  category="lo",
  description="MALAYALAM LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D16,
 },
 [0x0D17]={
  category="lo",
  description="MALAYALAM LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D17,
 },
 [0x0D18]={
  category="lo",
  description="MALAYALAM LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D18,
 },
 [0x0D19]={
  category="lo",
  description="MALAYALAM LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D19,
 },
 [0x0D1A]={
  category="lo",
  description="MALAYALAM LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D1A,
 },
 [0x0D1B]={
  category="lo",
  description="MALAYALAM LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D1B,
 },
 [0x0D1C]={
  category="lo",
  description="MALAYALAM LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D1C,
 },
 [0x0D1D]={
  category="lo",
  description="MALAYALAM LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D1D,
 },
 [0x0D1E]={
  category="lo",
  description="MALAYALAM LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D1E,
 },
 [0x0D1F]={
  category="lo",
  description="MALAYALAM LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D1F,
 },
 [0x0D20]={
  category="lo",
  description="MALAYALAM LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D20,
 },
 [0x0D21]={
  category="lo",
  description="MALAYALAM LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D21,
 },
 [0x0D22]={
  category="lo",
  description="MALAYALAM LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D22,
 },
 [0x0D23]={
  category="lo",
  description="MALAYALAM LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D23,
 },
 [0x0D24]={
  category="lo",
  description="MALAYALAM LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D24,
 },
 [0x0D25]={
  category="lo",
  description="MALAYALAM LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D25,
 },
 [0x0D26]={
  category="lo",
  description="MALAYALAM LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D26,
 },
 [0x0D27]={
  category="lo",
  description="MALAYALAM LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D27,
 },
 [0x0D28]={
  category="lo",
  description="MALAYALAM LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D28,
 },
 [0x0D29]={
  category="lo",
  description="MALAYALAM LETTER NNNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D29,
 },
 [0x0D2A]={
  category="lo",
  description="MALAYALAM LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D2A,
 },
 [0x0D2B]={
  category="lo",
  description="MALAYALAM LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D2B,
 },
 [0x0D2C]={
  category="lo",
  description="MALAYALAM LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D2C,
 },
 [0x0D2D]={
  category="lo",
  description="MALAYALAM LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D2D,
 },
 [0x0D2E]={
  category="lo",
  description="MALAYALAM LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D2E,
 },
 [0x0D2F]={
  category="lo",
  description="MALAYALAM LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D2F,
 },
 [0x0D30]={
  category="lo",
  description="MALAYALAM LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D30,
 },
 [0x0D31]={
  category="lo",
  description="MALAYALAM LETTER RRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D31,
 },
 [0x0D32]={
  category="lo",
  description="MALAYALAM LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D32,
 },
 [0x0D33]={
  category="lo",
  description="MALAYALAM LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D33,
 },
 [0x0D34]={
  category="lo",
  description="MALAYALAM LETTER LLLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D34,
 },
 [0x0D35]={
  category="lo",
  description="MALAYALAM LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D35,
 },
 [0x0D36]={
  category="lo",
  description="MALAYALAM LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D36,
 },
 [0x0D37]={
  category="lo",
  description="MALAYALAM LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D37,
 },
 [0x0D38]={
  category="lo",
  description="MALAYALAM LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D38,
 },
 [0x0D39]={
  category="lo",
  description="MALAYALAM LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D39,
 },
 [0x0D3A]={
  category="lo",
  description="MALAYALAM LETTER TTTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D3A,
 },
 [0x0D3D]={
  category="lo",
  description="MALAYALAM SIGN AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D3D,
 },
 [0x0D3E]={
  category="mc",
  description="MALAYALAM VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D3E,
 },
 [0x0D3F]={
  category="mc",
  description="MALAYALAM VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D3F,
 },
 [0x0D40]={
  category="mc",
  description="MALAYALAM VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D40,
 },
 [0x0D41]={
  category="mn",
  description="MALAYALAM VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0D41,
 },
 [0x0D42]={
  category="mn",
  description="MALAYALAM VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0D42,
 },
 [0x0D43]={
  category="mn",
  description="MALAYALAM VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0D43,
 },
 [0x0D44]={
  category="mn",
  description="MALAYALAM VOWEL SIGN VOCALIC RR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0D44,
 },
 [0x0D46]={
  category="mc",
  description="MALAYALAM VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D46,
 },
 [0x0D47]={
  category="mc",
  description="MALAYALAM VOWEL SIGN EE",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D47,
 },
 [0x0D48]={
  category="mc",
  description="MALAYALAM VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D48,
 },
 [0x0D4A]={
  category="mc",
  description="MALAYALAM VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0D46, 0x0D3E },
  unicodeslot=0x0D4A,
 },
 [0x0D4B]={
  category="mc",
  description="MALAYALAM VOWEL SIGN OO",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0D47, 0x0D3E },
  unicodeslot=0x0D4B,
 },
 [0x0D4C]={
  category="mc",
  description="MALAYALAM VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0D46, 0x0D57 },
  unicodeslot=0x0D4C,
 },
 [0x0D4D]={
  category="mn",
  description="MALAYALAM SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0D4D,
 },
 [0x0D4E]={
  category="lo",
  description="MALAYALAM LETTER DOT REPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D4E,
 },
 [0x0D57]={
  category="mc",
  description="MALAYALAM AU LENGTH MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D57,
 },
 [0x0D60]={
  category="lo",
  description="MALAYALAM LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D60,
 },
 [0x0D61]={
  category="lo",
  description="MALAYALAM LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D61,
 },
 [0x0D62]={
  category="mn",
  description="MALAYALAM VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0D62,
 },
 [0x0D63]={
  category="mn",
  description="MALAYALAM VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0D63,
 },
 [0x0D66]={
  category="nd",
  description="MALAYALAM DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D66,
 },
 [0x0D67]={
  category="nd",
  description="MALAYALAM DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D67,
 },
 [0x0D68]={
  category="nd",
  description="MALAYALAM DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D68,
 },
 [0x0D69]={
  category="nd",
  description="MALAYALAM DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D69,
 },
 [0x0D6A]={
  category="nd",
  description="MALAYALAM DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D6A,
 },
 [0x0D6B]={
  category="nd",
  description="MALAYALAM DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D6B,
 },
 [0x0D6C]={
  category="nd",
  description="MALAYALAM DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D6C,
 },
 [0x0D6D]={
  category="nd",
  description="MALAYALAM DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D6D,
 },
 [0x0D6E]={
  category="nd",
  description="MALAYALAM DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D6E,
 },
 [0x0D6F]={
  category="nd",
  description="MALAYALAM DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0D6F,
 },
 [0x0D70]={
  category="no",
  description="MALAYALAM NUMBER TEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D70,
 },
 [0x0D71]={
  category="no",
  description="MALAYALAM NUMBER ONE HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D71,
 },
 [0x0D72]={
  category="no",
  description="MALAYALAM NUMBER ONE THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D72,
 },
 [0x0D73]={
  category="no",
  description="MALAYALAM FRACTION ONE QUARTER",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D73,
 },
 [0x0D74]={
  category="no",
  description="MALAYALAM FRACTION ONE HALF",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D74,
 },
 [0x0D75]={
  category="no",
  description="MALAYALAM FRACTION THREE QUARTERS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D75,
 },
 [0x0D79]={
  category="so",
  description="MALAYALAM DATE MARK",
  direction="l",
  linebreak="po",
  unicodeslot=0x0D79,
 },
 [0x0D7A]={
  category="lo",
  description="MALAYALAM LETTER CHILLU NN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D7A,
 },
 [0x0D7B]={
  category="lo",
  description="MALAYALAM LETTER CHILLU N",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D7B,
 },
 [0x0D7C]={
  category="lo",
  description="MALAYALAM LETTER CHILLU RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D7C,
 },
 [0x0D7D]={
  category="lo",
  description="MALAYALAM LETTER CHILLU L",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D7D,
 },
 [0x0D7E]={
  category="lo",
  description="MALAYALAM LETTER CHILLU LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D7E,
 },
 [0x0D7F]={
  category="lo",
  description="MALAYALAM LETTER CHILLU K",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D7F,
 },
 [0x0D82]={
  category="mc",
  description="SINHALA SIGN ANUSVARAYA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D82,
 },
 [0x0D83]={
  category="mc",
  description="SINHALA SIGN VISARGAYA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0D83,
 },
 [0x0D85]={
  category="lo",
  description="SINHALA LETTER AYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D85,
 },
 [0x0D86]={
  category="lo",
  description="SINHALA LETTER AAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D86,
 },
 [0x0D87]={
  category="lo",
  description="SINHALA LETTER AEYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D87,
 },
 [0x0D88]={
  category="lo",
  description="SINHALA LETTER AEEYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D88,
 },
 [0x0D89]={
  category="lo",
  description="SINHALA LETTER IYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D89,
 },
 [0x0D8A]={
  category="lo",
  description="SINHALA LETTER IIYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D8A,
 },
 [0x0D8B]={
  category="lo",
  description="SINHALA LETTER UYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D8B,
 },
 [0x0D8C]={
  category="lo",
  description="SINHALA LETTER UUYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D8C,
 },
 [0x0D8D]={
  category="lo",
  description="SINHALA LETTER IRUYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D8D,
 },
 [0x0D8E]={
  category="lo",
  description="SINHALA LETTER IRUUYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D8E,
 },
 [0x0D8F]={
  category="lo",
  description="SINHALA LETTER ILUYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D8F,
 },
 [0x0D90]={
  category="lo",
  description="SINHALA LETTER ILUUYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D90,
 },
 [0x0D91]={
  category="lo",
  description="SINHALA LETTER EYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D91,
 },
 [0x0D92]={
  category="lo",
  description="SINHALA LETTER EEYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D92,
 },
 [0x0D93]={
  category="lo",
  description="SINHALA LETTER AIYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D93,
 },
 [0x0D94]={
  category="lo",
  description="SINHALA LETTER OYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D94,
 },
 [0x0D95]={
  category="lo",
  description="SINHALA LETTER OOYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D95,
 },
 [0x0D96]={
  category="lo",
  description="SINHALA LETTER AUYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D96,
 },
 [0x0D9A]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA KAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D9A,
 },
 [0x0D9B]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA KAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D9B,
 },
 [0x0D9C]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA GAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D9C,
 },
 [0x0D9D]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA GAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D9D,
 },
 [0x0D9E]={
  category="lo",
  description="SINHALA LETTER KANTAJA NAASIKYAYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D9E,
 },
 [0x0D9F]={
  category="lo",
  description="SINHALA LETTER SANYAKA GAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0D9F,
 },
 [0x0DA0]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA CAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA0,
 },
 [0x0DA1]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA CAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA1,
 },
 [0x0DA2]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA JAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA2,
 },
 [0x0DA3]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA JAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA3,
 },
 [0x0DA4]={
  category="lo",
  description="SINHALA LETTER TAALUJA NAASIKYAYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA4,
 },
 [0x0DA5]={
  category="lo",
  description="SINHALA LETTER TAALUJA SANYOOGA NAAKSIKYAYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA5,
 },
 [0x0DA6]={
  category="lo",
  description="SINHALA LETTER SANYAKA JAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA6,
 },
 [0x0DA7]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA TTAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA7,
 },
 [0x0DA8]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA TTAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA8,
 },
 [0x0DA9]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA DDAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DA9,
 },
 [0x0DAA]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA DDAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DAA,
 },
 [0x0DAB]={
  category="lo",
  description="SINHALA LETTER MUURDHAJA NAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DAB,
 },
 [0x0DAC]={
  category="lo",
  description="SINHALA LETTER SANYAKA DDAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DAC,
 },
 [0x0DAD]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA TAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DAD,
 },
 [0x0DAE]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA TAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DAE,
 },
 [0x0DAF]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA DAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DAF,
 },
 [0x0DB0]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA DAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB0,
 },
 [0x0DB1]={
  category="lo",
  description="SINHALA LETTER DANTAJA NAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB1,
 },
 [0x0DB3]={
  category="lo",
  description="SINHALA LETTER SANYAKA DAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB3,
 },
 [0x0DB4]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA PAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB4,
 },
 [0x0DB5]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA PAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB5,
 },
 [0x0DB6]={
  category="lo",
  description="SINHALA LETTER ALPAPRAANA BAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB6,
 },
 [0x0DB7]={
  category="lo",
  description="SINHALA LETTER MAHAAPRAANA BAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB7,
 },
 [0x0DB8]={
  category="lo",
  description="SINHALA LETTER MAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB8,
 },
 [0x0DB9]={
  category="lo",
  description="SINHALA LETTER AMBA BAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DB9,
 },
 [0x0DBA]={
  category="lo",
  description="SINHALA LETTER YAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DBA,
 },
 [0x0DBB]={
  category="lo",
  description="SINHALA LETTER RAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DBB,
 },
 [0x0DBD]={
  category="lo",
  description="SINHALA LETTER DANTAJA LAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DBD,
 },
 [0x0DC0]={
  category="lo",
  description="SINHALA LETTER VAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DC0,
 },
 [0x0DC1]={
  category="lo",
  description="SINHALA LETTER TAALUJA SAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DC1,
 },
 [0x0DC2]={
  category="lo",
  description="SINHALA LETTER MUURDHAJA SAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DC2,
 },
 [0x0DC3]={
  category="lo",
  description="SINHALA LETTER DANTAJA SAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DC3,
 },
 [0x0DC4]={
  category="lo",
  description="SINHALA LETTER HAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DC4,
 },
 [0x0DC5]={
  category="lo",
  description="SINHALA LETTER MUURDHAJA LAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DC5,
 },
 [0x0DC6]={
  category="lo",
  description="SINHALA LETTER FAYANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DC6,
 },
 [0x0DCA]={
  category="mn",
  description="SINHALA SIGN AL-LAKUNA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0DCA,
 },
 [0x0DCF]={
  category="mc",
  description="SINHALA VOWEL SIGN AELA-PILLA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DCF,
 },
 [0x0DD0]={
  category="mc",
  description="SINHALA VOWEL SIGN KETTI AEDA-PILLA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DD0,
 },
 [0x0DD1]={
  category="mc",
  description="SINHALA VOWEL SIGN DIGA AEDA-PILLA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DD1,
 },
 [0x0DD2]={
  category="mn",
  description="SINHALA VOWEL SIGN KETTI IS-PILLA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0DD2,
 },
 [0x0DD3]={
  category="mn",
  description="SINHALA VOWEL SIGN DIGA IS-PILLA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0DD3,
 },
 [0x0DD4]={
  category="mn",
  description="SINHALA VOWEL SIGN KETTI PAA-PILLA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0DD4,
 },
 [0x0DD6]={
  category="mn",
  description="SINHALA VOWEL SIGN DIGA PAA-PILLA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0DD6,
 },
 [0x0DD8]={
  category="mc",
  description="SINHALA VOWEL SIGN GAETTA-PILLA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DD8,
 },
 [0x0DD9]={
  category="mc",
  description="SINHALA VOWEL SIGN KOMBUVA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DD9,
 },
 [0x0DDA]={
  category="mc",
  description="SINHALA VOWEL SIGN DIGA KOMBUVA",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0DD9, 0x0DCA },
  unicodeslot=0x0DDA,
 },
 [0x0DDB]={
  category="mc",
  description="SINHALA VOWEL SIGN KOMBU DEKA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DDB,
 },
 [0x0DDC]={
  category="mc",
  description="SINHALA VOWEL SIGN KOMBUVA HAA AELA-PILLA",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0DD9, 0x0DCF },
  unicodeslot=0x0DDC,
 },
 [0x0DDD]={
  category="mc",
  description="SINHALA VOWEL SIGN KOMBUVA HAA DIGA AELA-PILLA",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0DDC, 0x0DCA },
  unicodeslot=0x0DDD,
 },
 [0x0DDE]={
  category="mc",
  description="SINHALA VOWEL SIGN KOMBUVA HAA GAYANUKITTA",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x0DD9, 0x0DDF },
  unicodeslot=0x0DDE,
 },
 [0x0DDF]={
  category="mc",
  description="SINHALA VOWEL SIGN GAYANUKITTA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DDF,
 },
 [0x0DF2]={
  category="mc",
  description="SINHALA VOWEL SIGN DIGA GAETTA-PILLA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DF2,
 },
 [0x0DF3]={
  category="mc",
  description="SINHALA VOWEL SIGN DIGA GAYANUKITTA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0DF3,
 },
 [0x0DF4]={
  category="po",
  description="SINHALA PUNCTUATION KUNDDALIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0DF4,
 },
 [0x0E01]={
  adobename="kokaithai",
  category="lo",
  description="THAI CHARACTER KO KAI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E01,
 },
 [0x0E02]={
  adobename="khokhaithai",
  category="lo",
  description="THAI CHARACTER KHO KHAI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E02,
 },
 [0x0E03]={
  adobename="khokhuatthai",
  category="lo",
  description="THAI CHARACTER KHO KHUAT",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E03,
 },
 [0x0E04]={
  adobename="khokhwaithai",
  category="lo",
  description="THAI CHARACTER KHO KHWAI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E04,
 },
 [0x0E05]={
  adobename="khokhonthai",
  category="lo",
  description="THAI CHARACTER KHO KHON",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E05,
 },
 [0x0E06]={
  adobename="khorakhangthai",
  category="lo",
  description="THAI CHARACTER KHO RAKHANG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E06,
 },
 [0x0E07]={
  adobename="ngonguthai",
  category="lo",
  description="THAI CHARACTER NGO NGU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E07,
 },
 [0x0E08]={
  adobename="chochanthai",
  category="lo",
  description="THAI CHARACTER CHO CHAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E08,
 },
 [0x0E09]={
  adobename="chochingthai",
  category="lo",
  description="THAI CHARACTER CHO CHING",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E09,
 },
 [0x0E0A]={
  adobename="chochangthai",
  category="lo",
  description="THAI CHARACTER CHO CHANG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E0A,
 },
 [0x0E0B]={
  adobename="sosothai",
  category="lo",
  description="THAI CHARACTER SO SO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E0B,
 },
 [0x0E0C]={
  adobename="chochoethai",
  category="lo",
  description="THAI CHARACTER CHO CHOE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E0C,
 },
 [0x0E0D]={
  adobename="yoyingthai",
  category="lo",
  description="THAI CHARACTER YO YING",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E0D,
 },
 [0x0E0E]={
  adobename="dochadathai",
  category="lo",
  description="THAI CHARACTER DO CHADA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E0E,
 },
 [0x0E0F]={
  adobename="topatakthai",
  category="lo",
  description="THAI CHARACTER TO PATAK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E0F,
 },
 [0x0E10]={
  adobename="thothanthai",
  category="lo",
  description="THAI CHARACTER THO THAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E10,
 },
 [0x0E11]={
  adobename="thonangmonthothai",
  category="lo",
  description="THAI CHARACTER THO NANGMONTHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E11,
 },
 [0x0E12]={
  adobename="thophuthaothai",
  category="lo",
  description="THAI CHARACTER THO PHUTHAO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E12,
 },
 [0x0E13]={
  adobename="nonenthai",
  category="lo",
  description="THAI CHARACTER NO NEN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E13,
 },
 [0x0E14]={
  adobename="dodekthai",
  category="lo",
  description="THAI CHARACTER DO DEK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E14,
 },
 [0x0E15]={
  adobename="totaothai",
  category="lo",
  description="THAI CHARACTER TO TAO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E15,
 },
 [0x0E16]={
  adobename="thothungthai",
  category="lo",
  description="THAI CHARACTER THO THUNG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E16,
 },
 [0x0E17]={
  adobename="thothahanthai",
  category="lo",
  description="THAI CHARACTER THO THAHAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E17,
 },
 [0x0E18]={
  adobename="thothongthai",
  category="lo",
  description="THAI CHARACTER THO THONG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E18,
 },
 [0x0E19]={
  adobename="nonuthai",
  category="lo",
  description="THAI CHARACTER NO NU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E19,
 },
 [0x0E1A]={
  adobename="bobaimaithai",
  category="lo",
  description="THAI CHARACTER BO BAIMAI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E1A,
 },
 [0x0E1B]={
  adobename="poplathai",
  category="lo",
  description="THAI CHARACTER PO PLA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E1B,
 },
 [0x0E1C]={
  adobename="phophungthai",
  category="lo",
  description="THAI CHARACTER PHO PHUNG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E1C,
 },
 [0x0E1D]={
  adobename="fofathai",
  category="lo",
  description="THAI CHARACTER FO FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E1D,
 },
 [0x0E1E]={
  adobename="phophanthai",
  category="lo",
  description="THAI CHARACTER PHO PHAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E1E,
 },
 [0x0E1F]={
  adobename="fofanthai",
  category="lo",
  description="THAI CHARACTER FO FAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E1F,
 },
 [0x0E20]={
  adobename="phosamphaothai",
  category="lo",
  description="THAI CHARACTER PHO SAMPHAO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E20,
 },
 [0x0E21]={
  adobename="momathai",
  category="lo",
  description="THAI CHARACTER MO MA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E21,
 },
 [0x0E22]={
  adobename="yoyakthai",
  category="lo",
  description="THAI CHARACTER YO YAK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E22,
 },
 [0x0E23]={
  adobename="roruathai",
  category="lo",
  description="THAI CHARACTER RO RUA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E23,
 },
 [0x0E24]={
  adobename="ruthai",
  category="lo",
  description="THAI CHARACTER RU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E24,
 },
 [0x0E25]={
  adobename="lolingthai",
  category="lo",
  description="THAI CHARACTER LO LING",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E25,
 },
 [0x0E26]={
  adobename="luthai",
  category="lo",
  description="THAI CHARACTER LU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E26,
 },
 [0x0E27]={
  adobename="wowaenthai",
  category="lo",
  description="THAI CHARACTER WO WAEN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E27,
 },
 [0x0E28]={
  adobename="sosalathai",
  category="lo",
  description="THAI CHARACTER SO SALA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E28,
 },
 [0x0E29]={
  adobename="sorusithai",
  category="lo",
  description="THAI CHARACTER SO RUSI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E29,
 },
 [0x0E2A]={
  adobename="sosuathai",
  category="lo",
  description="THAI CHARACTER SO SUA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E2A,
 },
 [0x0E2B]={
  adobename="hohipthai",
  category="lo",
  description="THAI CHARACTER HO HIP",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E2B,
 },
 [0x0E2C]={
  adobename="lochulathai",
  category="lo",
  description="THAI CHARACTER LO CHULA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E2C,
 },
 [0x0E2D]={
  adobename="oangthai",
  category="lo",
  description="THAI CHARACTER O ANG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E2D,
 },
 [0x0E2E]={
  adobename="honokhukthai",
  category="lo",
  description="THAI CHARACTER HO NOKHUK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E2E,
 },
 [0x0E2F]={
  adobename="paiyannoithai",
  category="lo",
  description="THAI CHARACTER PAIYANNOI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E2F,
 },
 [0x0E30]={
  adobename="saraathai",
  category="lo",
  description="THAI CHARACTER SARA A",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E30,
 },
 [0x0E31]={
  adobename="maihanakatthai",
  category="mn",
  description="THAI CHARACTER MAI HAN-AKAT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E31,
 },
 [0x0E32]={
  adobename="saraaathai",
  category="lo",
  description="THAI CHARACTER SARA AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E32,
 },
 [0x0E33]={
  adobename="saraamthai",
  category="lo",
  description="THAI CHARACTER SARA AM",
  direction="l",
  linebreak="sa",
  specials={ "compat", 0x0E4D, 0x0E32 },
  unicodeslot=0x0E33,
 },
 [0x0E34]={
  adobename="saraithai",
  category="mn",
  description="THAI CHARACTER SARA I",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E34,
 },
 [0x0E35]={
  adobename="saraiithai",
  category="mn",
  description="THAI CHARACTER SARA II",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E35,
 },
 [0x0E36]={
  adobename="sarauethai",
  category="mn",
  description="THAI CHARACTER SARA UE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E36,
 },
 [0x0E37]={
  adobename="saraueethai",
  category="mn",
  description="THAI CHARACTER SARA UEE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E37,
 },
 [0x0E38]={
  adobename="sarauthai",
  category="mn",
  description="THAI CHARACTER SARA U",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E38,
 },
 [0x0E39]={
  adobename="sarauuthai",
  category="mn",
  description="THAI CHARACTER SARA UU",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E39,
 },
 [0x0E3A]={
  adobename="phinthuthai",
  category="mn",
  description="THAI CHARACTER PHINTHU",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E3A,
 },
 [0x0E3F]={
  adobename="bahtthai",
  category="sc",
  description="THAI CURRENCY SYMBOL BAHT",
  direction="et",
  linebreak="pr",
  unicodeslot=0x0E3F,
 },
 [0x0E40]={
  adobename="saraethai",
  category="lo",
  description="THAI CHARACTER SARA E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E40,
 },
 [0x0E41]={
  adobename="saraaethai",
  category="lo",
  description="THAI CHARACTER SARA AE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E41,
 },
 [0x0E42]={
  adobename="saraothai",
  category="lo",
  description="THAI CHARACTER SARA O",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E42,
 },
 [0x0E43]={
  adobename="saraaimaimuanthai",
  category="lo",
  description="THAI CHARACTER SARA AI MAIMUAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E43,
 },
 [0x0E44]={
  adobename="saraaimaimalaithai",
  category="lo",
  description="THAI CHARACTER SARA AI MAIMALAI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E44,
 },
 [0x0E45]={
  adobename="lakkhangyaothai",
  category="lo",
  description="THAI CHARACTER LAKKHANGYAO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E45,
 },
 [0x0E46]={
  adobename="maiyamokthai",
  category="lm",
  description="THAI CHARACTER MAIYAMOK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E46,
 },
 [0x0E47]={
  adobename="maitaikhuthai",
  category="mn",
  description="THAI CHARACTER MAITAIKHU",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E47,
 },
 [0x0E48]={
  adobename="maiekthai",
  category="mn",
  description="THAI CHARACTER MAI EK",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E48,
 },
 [0x0E49]={
  adobename="maithothai",
  category="mn",
  description="THAI CHARACTER MAI THO",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E49,
 },
 [0x0E4A]={
  adobename="maitrithai",
  category="mn",
  description="THAI CHARACTER MAI TRI",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E4A,
 },
 [0x0E4B]={
  adobename="maichattawathai",
  category="mn",
  description="THAI CHARACTER MAI CHATTAWA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E4B,
 },
 [0x0E4C]={
  adobename="thanthakhatthai",
  category="mn",
  description="THAI CHARACTER THANTHAKHAT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E4C,
 },
 [0x0E4D]={
  adobename="nikhahitthai",
  category="mn",
  description="THAI CHARACTER NIKHAHIT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E4D,
 },
 [0x0E4E]={
  adobename="yamakkanthai",
  category="mn",
  description="THAI CHARACTER YAMAKKAN",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0E4E,
 },
 [0x0E4F]={
  adobename="fongmanthai",
  category="po",
  description="THAI CHARACTER FONGMAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0E4F,
 },
 [0x0E50]={
  adobename="zerothai",
  category="nd",
  description="THAI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E50,
 },
 [0x0E51]={
  adobename="onethai",
  category="nd",
  description="THAI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E51,
 },
 [0x0E52]={
  adobename="twothai",
  category="nd",
  description="THAI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E52,
 },
 [0x0E53]={
  adobename="threethai",
  category="nd",
  description="THAI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E53,
 },
 [0x0E54]={
  adobename="fourthai",
  category="nd",
  description="THAI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E54,
 },
 [0x0E55]={
  adobename="fivethai",
  category="nd",
  description="THAI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E55,
 },
 [0x0E56]={
  adobename="sixthai",
  category="nd",
  description="THAI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E56,
 },
 [0x0E57]={
  adobename="seventhai",
  category="nd",
  description="THAI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E57,
 },
 [0x0E58]={
  adobename="eightthai",
  category="nd",
  description="THAI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E58,
 },
 [0x0E59]={
  adobename="ninethai",
  category="nd",
  description="THAI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0E59,
 },
 [0x0E5A]={
  adobename="angkhankhuthai",
  category="po",
  description="THAI CHARACTER ANGKHANKHU",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0E5A,
 },
 [0x0E5B]={
  adobename="khomutthai",
  category="po",
  description="THAI CHARACTER KHOMUT",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0E5B,
 },
 [0x0E81]={
  category="lo",
  description="LAO LETTER KO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E81,
 },
 [0x0E82]={
  category="lo",
  description="LAO LETTER KHO SUNG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E82,
 },
 [0x0E84]={
  category="lo",
  description="LAO LETTER KHO TAM",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E84,
 },
 [0x0E87]={
  category="lo",
  description="LAO LETTER NGO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E87,
 },
 [0x0E88]={
  category="lo",
  description="LAO LETTER CO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E88,
 },
 [0x0E8A]={
  category="lo",
  description="LAO LETTER SO TAM",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E8A,
 },
 [0x0E8D]={
  category="lo",
  description="LAO LETTER NYO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E8D,
 },
 [0x0E94]={
  category="lo",
  description="LAO LETTER DO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E94,
 },
 [0x0E95]={
  category="lo",
  description="LAO LETTER TO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E95,
 },
 [0x0E96]={
  category="lo",
  description="LAO LETTER THO SUNG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E96,
 },
 [0x0E97]={
  category="lo",
  description="LAO LETTER THO TAM",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E97,
 },
 [0x0E99]={
  category="lo",
  description="LAO LETTER NO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E99,
 },
 [0x0E9A]={
  category="lo",
  description="LAO LETTER BO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E9A,
 },
 [0x0E9B]={
  category="lo",
  description="LAO LETTER PO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E9B,
 },
 [0x0E9C]={
  category="lo",
  description="LAO LETTER PHO SUNG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E9C,
 },
 [0x0E9D]={
  category="lo",
  description="LAO LETTER FO TAM",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E9D,
 },
 [0x0E9E]={
  category="lo",
  description="LAO LETTER PHO TAM",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E9E,
 },
 [0x0E9F]={
  category="lo",
  description="LAO LETTER FO SUNG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0E9F,
 },
 [0x0EA1]={
  category="lo",
  description="LAO LETTER MO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EA1,
 },
 [0x0EA2]={
  category="lo",
  description="LAO LETTER YO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EA2,
 },
 [0x0EA3]={
  category="lo",
  description="LAO LETTER LO LING",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EA3,
 },
 [0x0EA5]={
  category="lo",
  description="LAO LETTER LO LOOT",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EA5,
 },
 [0x0EA7]={
  category="lo",
  description="LAO LETTER WO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EA7,
 },
 [0x0EAA]={
  category="lo",
  description="LAO LETTER SO SUNG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EAA,
 },
 [0x0EAB]={
  category="lo",
  description="LAO LETTER HO SUNG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EAB,
 },
 [0x0EAD]={
  category="lo",
  description="LAO LETTER O",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EAD,
 },
 [0x0EAE]={
  category="lo",
  description="LAO LETTER HO TAM",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EAE,
 },
 [0x0EAF]={
  category="lo",
  description="LAO ELLIPSIS",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EAF,
 },
 [0x0EB0]={
  category="lo",
  description="LAO VOWEL SIGN A",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EB0,
 },
 [0x0EB1]={
  category="mn",
  description="LAO VOWEL SIGN MAI KAN",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EB1,
 },
 [0x0EB2]={
  category="lo",
  description="LAO VOWEL SIGN AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EB2,
 },
 [0x0EB3]={
  category="lo",
  description="LAO VOWEL SIGN AM",
  direction="l",
  linebreak="sa",
  specials={ "compat", 0x0ECD, 0x0EB2 },
  unicodeslot=0x0EB3,
 },
 [0x0EB4]={
  category="mn",
  description="LAO VOWEL SIGN I",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EB4,
 },
 [0x0EB5]={
  category="mn",
  description="LAO VOWEL SIGN II",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EB5,
 },
 [0x0EB6]={
  category="mn",
  description="LAO VOWEL SIGN Y",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EB6,
 },
 [0x0EB7]={
  category="mn",
  description="LAO VOWEL SIGN YY",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EB7,
 },
 [0x0EB8]={
  category="mn",
  description="LAO VOWEL SIGN U",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EB8,
 },
 [0x0EB9]={
  category="mn",
  description="LAO VOWEL SIGN UU",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EB9,
 },
 [0x0EBB]={
  category="mn",
  description="LAO VOWEL SIGN MAI KON",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EBB,
 },
 [0x0EBC]={
  category="mn",
  description="LAO SEMIVOWEL SIGN LO",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EBC,
 },
 [0x0EBD]={
  category="lo",
  description="LAO SEMIVOWEL SIGN NYO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EBD,
 },
 [0x0EC0]={
  category="lo",
  description="LAO VOWEL SIGN E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EC0,
 },
 [0x0EC1]={
  category="lo",
  description="LAO VOWEL SIGN EI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EC1,
 },
 [0x0EC2]={
  category="lo",
  description="LAO VOWEL SIGN O",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EC2,
 },
 [0x0EC3]={
  category="lo",
  description="LAO VOWEL SIGN AY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EC3,
 },
 [0x0EC4]={
  category="lo",
  description="LAO VOWEL SIGN AI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EC4,
 },
 [0x0EC6]={
  category="lm",
  description="LAO KO LA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EC6,
 },
 [0x0EC8]={
  category="mn",
  description="LAO TONE MAI EK",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EC8,
 },
 [0x0EC9]={
  category="mn",
  description="LAO TONE MAI THO",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0EC9,
 },
 [0x0ECA]={
  category="mn",
  description="LAO TONE MAI TI",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0ECA,
 },
 [0x0ECB]={
  category="mn",
  description="LAO TONE MAI CATAWA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0ECB,
 },
 [0x0ECC]={
  category="mn",
  description="LAO CANCELLATION MARK",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0ECC,
 },
 [0x0ECD]={
  category="mn",
  description="LAO NIGGAHITA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x0ECD,
 },
 [0x0ED0]={
  category="nd",
  description="LAO DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED0,
 },
 [0x0ED1]={
  category="nd",
  description="LAO DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED1,
 },
 [0x0ED2]={
  category="nd",
  description="LAO DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED2,
 },
 [0x0ED3]={
  category="nd",
  description="LAO DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED3,
 },
 [0x0ED4]={
  category="nd",
  description="LAO DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED4,
 },
 [0x0ED5]={
  category="nd",
  description="LAO DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED5,
 },
 [0x0ED6]={
  category="nd",
  description="LAO DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED6,
 },
 [0x0ED7]={
  category="nd",
  description="LAO DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED7,
 },
 [0x0ED8]={
  category="nd",
  description="LAO DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED8,
 },
 [0x0ED9]={
  category="nd",
  description="LAO DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0ED9,
 },
 [0x0EDC]={
  category="lo",
  description="LAO HO NO",
  direction="l",
  linebreak="sa",
  specials={ "compat", 0x0EAB, 0x0E99 },
  unicodeslot=0x0EDC,
 },
 [0x0EDD]={
  category="lo",
  description="LAO HO MO",
  direction="l",
  linebreak="sa",
  specials={ "compat", 0x0EAB, 0x0EA1 },
  unicodeslot=0x0EDD,
 },
 [0x0EDE]={
  category="lo",
  description="LAO LETTER KHMU GO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EDE,
 },
 [0x0EDF]={
  category="lo",
  description="LAO LETTER KHMU NYO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x0EDF,
 },
 [0x0F00]={
  category="lo",
  description="TIBETAN SYLLABLE OM",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F00,
 },
 [0x0F01]={
  category="so",
  description="TIBETAN MARK GTER YIG MGO TRUNCATED A",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0F01,
 },
 [0x0F02]={
  category="so",
  description="TIBETAN MARK GTER YIG MGO -UM RNAM BCAD MA",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0F02,
 },
 [0x0F03]={
  category="so",
  description="TIBETAN MARK GTER YIG MGO -UM GTER TSHEG MA",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0F03,
 },
 [0x0F04]={
  category="po",
  description="TIBETAN MARK INITIAL YIG MGO MDUN MA",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0F04,
 },
 [0x0F05]={
  category="po",
  description="TIBETAN MARK CLOSING YIG MGO SGAB MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F05,
 },
 [0x0F06]={
  category="po",
  description="TIBETAN MARK CARET YIG MGO PHUR SHAD MA",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0F06,
 },
 [0x0F07]={
  category="po",
  description="TIBETAN MARK YIG MGO TSHEG SHAD MA",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0F07,
 },
 [0x0F08]={
  category="po",
  description="TIBETAN MARK SBRUL SHAD",
  direction="l",
  linebreak="gl",
  unicodeslot=0x0F08,
 },
 [0x0F09]={
  category="po",
  description="TIBETAN MARK BSKUR YIG MGO",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0F09,
 },
 [0x0F0A]={
  category="po",
  description="TIBETAN MARK BKA- SHOG YIG MGO",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0F0A,
 },
 [0x0F0B]={
  category="po",
  description="TIBETAN MARK INTERSYLLABIC TSHEG",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0F0B,
 },
 [0x0F0C]={
  category="po",
  description="TIBETAN MARK DELIMITER TSHEG BSTAR",
  direction="l",
  linebreak="gl",
  specials={ "nobreak", 0x0F0B },
  unicodeslot=0x0F0C,
 },
 [0x0F0D]={
  category="po",
  description="TIBETAN MARK SHAD",
  direction="l",
  linebreak="ex",
  unicodeslot=0x0F0D,
 },
 [0x0F0E]={
  category="po",
  description="TIBETAN MARK NYIS SHAD",
  direction="l",
  linebreak="ex",
  unicodeslot=0x0F0E,
 },
 [0x0F0F]={
  category="po",
  description="TIBETAN MARK TSHEG SHAD",
  direction="l",
  linebreak="ex",
  unicodeslot=0x0F0F,
 },
 [0x0F10]={
  category="po",
  description="TIBETAN MARK NYIS TSHEG SHAD",
  direction="l",
  linebreak="ex",
  unicodeslot=0x0F10,
 },
 [0x0F11]={
  category="po",
  description="TIBETAN MARK RIN CHEN SPUNGS SHAD",
  direction="l",
  linebreak="ex",
  unicodeslot=0x0F11,
 },
 [0x0F12]={
  category="po",
  description="TIBETAN MARK RGYA GRAM SHAD",
  direction="l",
  linebreak="gl",
  unicodeslot=0x0F12,
 },
 [0x0F13]={
  category="so",
  description="TIBETAN MARK CARET -DZUD RTAGS ME LONG CAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F13,
 },
 [0x0F14]={
  category="so",
  description="TIBETAN MARK GTER TSHEG",
  direction="l",
  linebreak="ex",
  unicodeslot=0x0F14,
 },
 [0x0F15]={
  category="so",
  description="TIBETAN LOGOTYPE SIGN CHAD RTAGS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F15,
 },
 [0x0F16]={
  category="so",
  description="TIBETAN LOGOTYPE SIGN LHAG RTAGS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F16,
 },
 [0x0F17]={
  category="so",
  description="TIBETAN ASTROLOGICAL SIGN SGRA GCAN -CHAR RTAGS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F17,
 },
 [0x0F18]={
  category="mn",
  description="TIBETAN ASTROLOGICAL SIGN -KHYUD PA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F18,
 },
 [0x0F19]={
  category="mn",
  description="TIBETAN ASTROLOGICAL SIGN SDONG TSHUGS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F19,
 },
 [0x0F1A]={
  category="so",
  description="TIBETAN SIGN RDEL DKAR GCIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F1A,
 },
 [0x0F1B]={
  category="so",
  description="TIBETAN SIGN RDEL DKAR GNYIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F1B,
 },
 [0x0F1C]={
  category="so",
  description="TIBETAN SIGN RDEL DKAR GSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F1C,
 },
 [0x0F1D]={
  category="so",
  description="TIBETAN SIGN RDEL NAG GCIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F1D,
 },
 [0x0F1E]={
  category="so",
  description="TIBETAN SIGN RDEL NAG GNYIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F1E,
 },
 [0x0F1F]={
  category="so",
  description="TIBETAN SIGN RDEL DKAR RDEL NAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F1F,
 },
 [0x0F20]={
  category="nd",
  description="TIBETAN DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F20,
 },
 [0x0F21]={
  category="nd",
  description="TIBETAN DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F21,
 },
 [0x0F22]={
  category="nd",
  description="TIBETAN DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F22,
 },
 [0x0F23]={
  category="nd",
  description="TIBETAN DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F23,
 },
 [0x0F24]={
  category="nd",
  description="TIBETAN DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F24,
 },
 [0x0F25]={
  category="nd",
  description="TIBETAN DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F25,
 },
 [0x0F26]={
  category="nd",
  description="TIBETAN DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F26,
 },
 [0x0F27]={
  category="nd",
  description="TIBETAN DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F27,
 },
 [0x0F28]={
  category="nd",
  description="TIBETAN DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F28,
 },
 [0x0F29]={
  category="nd",
  description="TIBETAN DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x0F29,
 },
 [0x0F2A]={
  category="no",
  description="TIBETAN DIGIT HALF ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F2A,
 },
 [0x0F2B]={
  category="no",
  description="TIBETAN DIGIT HALF TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F2B,
 },
 [0x0F2C]={
  category="no",
  description="TIBETAN DIGIT HALF THREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F2C,
 },
 [0x0F2D]={
  category="no",
  description="TIBETAN DIGIT HALF FOUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F2D,
 },
 [0x0F2E]={
  category="no",
  description="TIBETAN DIGIT HALF FIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F2E,
 },
 [0x0F2F]={
  category="no",
  description="TIBETAN DIGIT HALF SIX",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F2F,
 },
 [0x0F30]={
  category="no",
  description="TIBETAN DIGIT HALF SEVEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F30,
 },
 [0x0F31]={
  category="no",
  description="TIBETAN DIGIT HALF EIGHT",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F31,
 },
 [0x0F32]={
  category="no",
  description="TIBETAN DIGIT HALF NINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F32,
 },
 [0x0F33]={
  category="no",
  description="TIBETAN DIGIT HALF ZERO",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F33,
 },
 [0x0F34]={
  category="so",
  description="TIBETAN MARK BSDUS RTAGS",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0F34,
 },
 [0x0F35]={
  category="mn",
  description="TIBETAN MARK NGAS BZUNG NYI ZLA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F35,
 },
 [0x0F36]={
  category="so",
  description="TIBETAN MARK CARET -DZUD RTAGS BZHI MIG CAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F36,
 },
 [0x0F37]={
  category="mn",
  description="TIBETAN MARK NGAS BZUNG SGOR RTAGS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F37,
 },
 [0x0F38]={
  category="so",
  description="TIBETAN MARK CHE MGO",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F38,
 },
 [0x0F39]={
  category="mn",
  description="TIBETAN MARK TSA -PHRU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F39,
 },
 [0x0F3A]={
  category="ps",
  description="TIBETAN MARK GUG RTAGS GYON",
  direction="on",
  linebreak="op",
  mirror=0x0F3B,
  unicodeslot=0x0F3A,
 },
 [0x0F3B]={
  category="pe",
  description="TIBETAN MARK GUG RTAGS GYAS",
  direction="on",
  linebreak="cl",
  mirror=0x0F3A,
  unicodeslot=0x0F3B,
 },
 [0x0F3C]={
  category="ps",
  description="TIBETAN MARK ANG KHANG GYON",
  direction="on",
  linebreak="op",
  mirror=0x0F3D,
  unicodeslot=0x0F3C,
 },
 [0x0F3D]={
  category="pe",
  description="TIBETAN MARK ANG KHANG GYAS",
  direction="on",
  linebreak="cl",
  mirror=0x0F3C,
  unicodeslot=0x0F3D,
 },
 [0x0F3E]={
  category="mc",
  description="TIBETAN SIGN YAR TSHES",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0F3E,
 },
 [0x0F3F]={
  category="mc",
  description="TIBETAN SIGN MAR TSHES",
  direction="l",
  linebreak="cm",
  unicodeslot=0x0F3F,
 },
 [0x0F40]={
  category="lo",
  description="TIBETAN LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F40,
 },
 [0x0F41]={
  category="lo",
  description="TIBETAN LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F41,
 },
 [0x0F42]={
  category="lo",
  description="TIBETAN LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F42,
 },
 [0x0F43]={
  category="lo",
  description="TIBETAN LETTER GHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0F42, 0x0FB7 },
  unicodeslot=0x0F43,
 },
 [0x0F44]={
  category="lo",
  description="TIBETAN LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F44,
 },
 [0x0F45]={
  category="lo",
  description="TIBETAN LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F45,
 },
 [0x0F46]={
  category="lo",
  description="TIBETAN LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F46,
 },
 [0x0F47]={
  category="lo",
  description="TIBETAN LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F47,
 },
 [0x0F49]={
  category="lo",
  description="TIBETAN LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F49,
 },
 [0x0F4A]={
  category="lo",
  description="TIBETAN LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F4A,
 },
 [0x0F4B]={
  category="lo",
  description="TIBETAN LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F4B,
 },
 [0x0F4C]={
  category="lo",
  description="TIBETAN LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F4C,
 },
 [0x0F4D]={
  category="lo",
  description="TIBETAN LETTER DDHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0F4C, 0x0FB7 },
  unicodeslot=0x0F4D,
 },
 [0x0F4E]={
  category="lo",
  description="TIBETAN LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F4E,
 },
 [0x0F4F]={
  category="lo",
  description="TIBETAN LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F4F,
 },
 [0x0F50]={
  category="lo",
  description="TIBETAN LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F50,
 },
 [0x0F51]={
  category="lo",
  description="TIBETAN LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F51,
 },
 [0x0F52]={
  category="lo",
  description="TIBETAN LETTER DHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0F51, 0x0FB7 },
  unicodeslot=0x0F52,
 },
 [0x0F53]={
  category="lo",
  description="TIBETAN LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F53,
 },
 [0x0F54]={
  category="lo",
  description="TIBETAN LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F54,
 },
 [0x0F55]={
  category="lo",
  description="TIBETAN LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F55,
 },
 [0x0F56]={
  category="lo",
  description="TIBETAN LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F56,
 },
 [0x0F57]={
  category="lo",
  description="TIBETAN LETTER BHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0F56, 0x0FB7 },
  unicodeslot=0x0F57,
 },
 [0x0F58]={
  category="lo",
  description="TIBETAN LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F58,
 },
 [0x0F59]={
  category="lo",
  description="TIBETAN LETTER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F59,
 },
 [0x0F5A]={
  category="lo",
  description="TIBETAN LETTER TSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F5A,
 },
 [0x0F5B]={
  category="lo",
  description="TIBETAN LETTER DZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F5B,
 },
 [0x0F5C]={
  category="lo",
  description="TIBETAN LETTER DZHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0F5B, 0x0FB7 },
  unicodeslot=0x0F5C,
 },
 [0x0F5D]={
  category="lo",
  description="TIBETAN LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F5D,
 },
 [0x0F5E]={
  category="lo",
  description="TIBETAN LETTER ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F5E,
 },
 [0x0F5F]={
  category="lo",
  description="TIBETAN LETTER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F5F,
 },
 [0x0F60]={
  category="lo",
  description="TIBETAN LETTER -A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F60,
 },
 [0x0F61]={
  category="lo",
  description="TIBETAN LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F61,
 },
 [0x0F62]={
  category="lo",
  description="TIBETAN LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F62,
 },
 [0x0F63]={
  category="lo",
  description="TIBETAN LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F63,
 },
 [0x0F64]={
  category="lo",
  description="TIBETAN LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F64,
 },
 [0x0F65]={
  category="lo",
  description="TIBETAN LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F65,
 },
 [0x0F66]={
  category="lo",
  description="TIBETAN LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F66,
 },
 [0x0F67]={
  category="lo",
  description="TIBETAN LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F67,
 },
 [0x0F68]={
  category="lo",
  description="TIBETAN LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F68,
 },
 [0x0F69]={
  category="lo",
  description="TIBETAN LETTER KSSA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x0F40, 0x0FB5 },
  unicodeslot=0x0F69,
 },
 [0x0F6A]={
  category="lo",
  description="TIBETAN LETTER FIXED-FORM RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F6A,
 },
 [0x0F6B]={
  category="lo",
  description="TIBETAN LETTER KKA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F6B,
 },
 [0x0F6C]={
  category="lo",
  description="TIBETAN LETTER RRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F6C,
 },
 [0x0F71]={
  category="mn",
  description="TIBETAN VOWEL SIGN AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F71,
 },
 [0x0F72]={
  category="mn",
  description="TIBETAN VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F72,
 },
 [0x0F73]={
  category="mn",
  description="TIBETAN VOWEL SIGN II",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0F71, 0x0F72 },
  unicodeslot=0x0F73,
 },
 [0x0F74]={
  category="mn",
  description="TIBETAN VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F74,
 },
 [0x0F75]={
  category="mn",
  description="TIBETAN VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0F71, 0x0F74 },
  unicodeslot=0x0F75,
 },
 [0x0F76]={
  category="mn",
  description="TIBETAN VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0FB2, 0x0F80 },
  unicodeslot=0x0F76,
 },
 [0x0F77]={
  category="mn",
  description="TIBETAN VOWEL SIGN VOCALIC RR",
  direction="nsm",
  linebreak="cm",
  specials={ "compat", 0x0FB2, 0x0F81 },
  unicodeslot=0x0F77,
 },
 [0x0F78]={
  category="mn",
  description="TIBETAN VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0FB3, 0x0F80 },
  unicodeslot=0x0F78,
 },
 [0x0F79]={
  category="mn",
  description="TIBETAN VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  specials={ "compat", 0x0FB3, 0x0F81 },
  unicodeslot=0x0F79,
 },
 [0x0F7A]={
  category="mn",
  description="TIBETAN VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F7A,
 },
 [0x0F7B]={
  category="mn",
  description="TIBETAN VOWEL SIGN EE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F7B,
 },
 [0x0F7C]={
  category="mn",
  description="TIBETAN VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F7C,
 },
 [0x0F7D]={
  category="mn",
  description="TIBETAN VOWEL SIGN OO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F7D,
 },
 [0x0F7E]={
  category="mn",
  description="TIBETAN SIGN RJES SU NGA RO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F7E,
 },
 [0x0F7F]={
  category="mc",
  description="TIBETAN SIGN RNAM BCAD",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0F7F,
 },
 [0x0F80]={
  category="mn",
  description="TIBETAN VOWEL SIGN REVERSED I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F80,
 },
 [0x0F81]={
  category="mn",
  description="TIBETAN VOWEL SIGN REVERSED II",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0F71, 0x0F80 },
  unicodeslot=0x0F81,
 },
 [0x0F82]={
  category="mn",
  description="TIBETAN SIGN NYI ZLA NAA DA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F82,
 },
 [0x0F83]={
  category="mn",
  description="TIBETAN SIGN SNA LDAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F83,
 },
 [0x0F84]={
  category="mn",
  description="TIBETAN MARK HALANTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F84,
 },
 [0x0F85]={
  category="po",
  description="TIBETAN MARK PALUTA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0F85,
 },
 [0x0F86]={
  category="mn",
  description="TIBETAN SIGN LCI RTAGS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F86,
 },
 [0x0F87]={
  category="mn",
  description="TIBETAN SIGN YANG RTAGS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F87,
 },
 [0x0F88]={
  category="lo",
  description="TIBETAN SIGN LCE TSA CAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F88,
 },
 [0x0F89]={
  category="lo",
  description="TIBETAN SIGN MCHU CAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F89,
 },
 [0x0F8A]={
  category="lo",
  description="TIBETAN SIGN GRU CAN RGYINGS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F8A,
 },
 [0x0F8B]={
  category="lo",
  description="TIBETAN SIGN GRU MED RGYINGS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F8B,
 },
 [0x0F8C]={
  category="lo",
  description="TIBETAN SIGN INVERTED MCHU CAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0F8C,
 },
 [0x0F8D]={
  category="mn",
  description="TIBETAN SUBJOINED SIGN LCE TSA CAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F8D,
 },
 [0x0F8E]={
  category="mn",
  description="TIBETAN SUBJOINED SIGN MCHU CAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F8E,
 },
 [0x0F8F]={
  category="mn",
  description="TIBETAN SUBJOINED SIGN INVERTED MCHU CAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F8F,
 },
 [0x0F90]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER KA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F90,
 },
 [0x0F91]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER KHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F91,
 },
 [0x0F92]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER GA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F92,
 },
 [0x0F93]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER GHA",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0F92, 0x0FB7 },
  unicodeslot=0x0F93,
 },
 [0x0F94]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER NGA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F94,
 },
 [0x0F95]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER CA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F95,
 },
 [0x0F96]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER CHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F96,
 },
 [0x0F97]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER JA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F97,
 },
 [0x0F99]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER NYA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F99,
 },
 [0x0F9A]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER TTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F9A,
 },
 [0x0F9B]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER TTHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F9B,
 },
 [0x0F9C]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER DDA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F9C,
 },
 [0x0F9D]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER DDHA",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0F9C, 0x0FB7 },
  unicodeslot=0x0F9D,
 },
 [0x0F9E]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER NNA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F9E,
 },
 [0x0F9F]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER TA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0F9F,
 },
 [0x0FA0]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER THA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FA0,
 },
 [0x0FA1]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER DA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FA1,
 },
 [0x0FA2]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER DHA",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0FA1, 0x0FB7 },
  unicodeslot=0x0FA2,
 },
 [0x0FA3]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER NA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FA3,
 },
 [0x0FA4]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER PA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FA4,
 },
 [0x0FA5]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER PHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FA5,
 },
 [0x0FA6]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER BA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FA6,
 },
 [0x0FA7]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER BHA",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0FA6, 0x0FB7 },
  unicodeslot=0x0FA7,
 },
 [0x0FA8]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER MA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FA8,
 },
 [0x0FA9]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER TSA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FA9,
 },
 [0x0FAA]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER TSHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FAA,
 },
 [0x0FAB]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER DZA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FAB,
 },
 [0x0FAC]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER DZHA",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0FAB, 0x0FB7 },
  unicodeslot=0x0FAC,
 },
 [0x0FAD]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER WA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FAD,
 },
 [0x0FAE]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER ZHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FAE,
 },
 [0x0FAF]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER ZA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FAF,
 },
 [0x0FB0]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER -A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB0,
 },
 [0x0FB1]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER YA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB1,
 },
 [0x0FB2]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER RA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB2,
 },
 [0x0FB3]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER LA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB3,
 },
 [0x0FB4]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER SHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB4,
 },
 [0x0FB5]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER SSA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB5,
 },
 [0x0FB6]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER SA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB6,
 },
 [0x0FB7]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER HA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB7,
 },
 [0x0FB8]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FB8,
 },
 [0x0FB9]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER KSSA",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x0F90, 0x0FB5 },
  unicodeslot=0x0FB9,
 },
 [0x0FBA]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER FIXED-FORM WA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FBA,
 },
 [0x0FBB]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER FIXED-FORM YA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FBB,
 },
 [0x0FBC]={
  category="mn",
  description="TIBETAN SUBJOINED LETTER FIXED-FORM RA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FBC,
 },
 [0x0FBE]={
  category="so",
  description="TIBETAN KU RU KHA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0FBE,
 },
 [0x0FBF]={
  category="so",
  description="TIBETAN KU RU KHA BZHI MIG CAN",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0FBF,
 },
 [0x0FC0]={
  category="so",
  description="TIBETAN CANTILLATION SIGN HEAVY BEAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC0,
 },
 [0x0FC1]={
  category="so",
  description="TIBETAN CANTILLATION SIGN LIGHT BEAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC1,
 },
 [0x0FC2]={
  category="so",
  description="TIBETAN CANTILLATION SIGN CANG TE-U",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC2,
 },
 [0x0FC3]={
  category="so",
  description="TIBETAN CANTILLATION SIGN SBUB -CHAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC3,
 },
 [0x0FC4]={
  category="so",
  description="TIBETAN SYMBOL DRIL BU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC4,
 },
 [0x0FC5]={
  category="so",
  description="TIBETAN SYMBOL RDO RJE",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC5,
 },
 [0x0FC6]={
  category="mn",
  description="TIBETAN SYMBOL PADMA GDAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x0FC6,
 },
 [0x0FC7]={
  category="so",
  description="TIBETAN SYMBOL RDO RJE RGYA GRAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC7,
 },
 [0x0FC8]={
  category="so",
  description="TIBETAN SYMBOL PHUR PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC8,
 },
 [0x0FC9]={
  category="so",
  description="TIBETAN SYMBOL NOR BU",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FC9,
 },
 [0x0FCA]={
  category="so",
  description="TIBETAN SYMBOL NOR BU NYIS -KHYIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FCA,
 },
 [0x0FCB]={
  category="so",
  description="TIBETAN SYMBOL NOR BU GSUM -KHYIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FCB,
 },
 [0x0FCC]={
  category="so",
  description="TIBETAN SYMBOL NOR BU BZHI -KHYIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FCC,
 },
 [0x0FCE]={
  category="so",
  description="TIBETAN SIGN RDEL NAG RDEL DKAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FCE,
 },
 [0x0FCF]={
  category="so",
  description="TIBETAN SIGN RDEL NAG GSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FCF,
 },
 [0x0FD0]={
  category="po",
  description="TIBETAN MARK BSKA- SHOG GI MGO RGYAN",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0FD0,
 },
 [0x0FD1]={
  category="po",
  description="TIBETAN MARK MNYAM YIG GI MGO RGYAN",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0FD1,
 },
 [0x0FD2]={
  category="po",
  description="TIBETAN MARK NYIS TSHEG",
  direction="l",
  linebreak="ba",
  unicodeslot=0x0FD2,
 },
 [0x0FD3]={
  category="po",
  description="TIBETAN MARK INITIAL BRDA RNYING YIG MGO MDUN MA",
  direction="l",
  linebreak="bb",
  unicodeslot=0x0FD3,
 },
 [0x0FD4]={
  category="po",
  description="TIBETAN MARK CLOSING BRDA RNYING YIG MGO SGAB MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FD4,
 },
 [0x0FD5]={
  category="so",
  description="RIGHT-FACING SVASTI SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FD5,
 },
 [0x0FD6]={
  category="so",
  description="LEFT-FACING SVASTI SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FD6,
 },
 [0x0FD7]={
  category="so",
  description="RIGHT-FACING SVASTI SIGN WITH DOTS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FD7,
 },
 [0x0FD8]={
  category="so",
  description="LEFT-FACING SVASTI SIGN WITH DOTS",
  direction="l",
  linebreak="al",
  unicodeslot=0x0FD8,
 },
 [0x0FD9]={
  category="po",
  description="TIBETAN MARK LEADING MCHAN RTAGS",
  direction="l",
  linebreak="gl",
  unicodeslot=0x0FD9,
 },
 [0x0FDA]={
  category="po",
  description="TIBETAN MARK TRAILING MCHAN RTAGS",
  direction="l",
  linebreak="gl",
  unicodeslot=0x0FDA,
 },
 [0x1000]={
  category="lo",
  description="MYANMAR LETTER KA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1000,
 },
 [0x1001]={
  category="lo",
  description="MYANMAR LETTER KHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1001,
 },
 [0x1002]={
  category="lo",
  description="MYANMAR LETTER GA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1002,
 },
 [0x1003]={
  category="lo",
  description="MYANMAR LETTER GHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1003,
 },
 [0x1004]={
  category="lo",
  description="MYANMAR LETTER NGA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1004,
 },
 [0x1005]={
  category="lo",
  description="MYANMAR LETTER CA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1005,
 },
 [0x1006]={
  category="lo",
  description="MYANMAR LETTER CHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1006,
 },
 [0x1007]={
  category="lo",
  description="MYANMAR LETTER JA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1007,
 },
 [0x1008]={
  category="lo",
  description="MYANMAR LETTER JHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1008,
 },
 [0x1009]={
  category="lo",
  description="MYANMAR LETTER NYA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1009,
 },
 [0x100A]={
  category="lo",
  description="MYANMAR LETTER NNYA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x100A,
 },
 [0x100B]={
  category="lo",
  description="MYANMAR LETTER TTA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x100B,
 },
 [0x100C]={
  category="lo",
  description="MYANMAR LETTER TTHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x100C,
 },
 [0x100D]={
  category="lo",
  description="MYANMAR LETTER DDA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x100D,
 },
 [0x100E]={
  category="lo",
  description="MYANMAR LETTER DDHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x100E,
 },
 [0x100F]={
  category="lo",
  description="MYANMAR LETTER NNA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x100F,
 },
 [0x1010]={
  category="lo",
  description="MYANMAR LETTER TA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1010,
 },
 [0x1011]={
  category="lo",
  description="MYANMAR LETTER THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1011,
 },
 [0x1012]={
  category="lo",
  description="MYANMAR LETTER DA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1012,
 },
 [0x1013]={
  category="lo",
  description="MYANMAR LETTER DHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1013,
 },
 [0x1014]={
  category="lo",
  description="MYANMAR LETTER NA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1014,
 },
 [0x1015]={
  category="lo",
  description="MYANMAR LETTER PA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1015,
 },
 [0x1016]={
  category="lo",
  description="MYANMAR LETTER PHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1016,
 },
 [0x1017]={
  category="lo",
  description="MYANMAR LETTER BA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1017,
 },
 [0x1018]={
  category="lo",
  description="MYANMAR LETTER BHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1018,
 },
 [0x1019]={
  category="lo",
  description="MYANMAR LETTER MA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1019,
 },
 [0x101A]={
  category="lo",
  description="MYANMAR LETTER YA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x101A,
 },
 [0x101B]={
  category="lo",
  description="MYANMAR LETTER RA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x101B,
 },
 [0x101C]={
  category="lo",
  description="MYANMAR LETTER LA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x101C,
 },
 [0x101D]={
  category="lo",
  description="MYANMAR LETTER WA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x101D,
 },
 [0x101E]={
  category="lo",
  description="MYANMAR LETTER SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x101E,
 },
 [0x101F]={
  category="lo",
  description="MYANMAR LETTER HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x101F,
 },
 [0x1020]={
  category="lo",
  description="MYANMAR LETTER LLA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1020,
 },
 [0x1021]={
  category="lo",
  description="MYANMAR LETTER A",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1021,
 },
 [0x1022]={
  category="lo",
  description="MYANMAR LETTER SHAN A",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1022,
 },
 [0x1023]={
  category="lo",
  description="MYANMAR LETTER I",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1023,
 },
 [0x1024]={
  category="lo",
  description="MYANMAR LETTER II",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1024,
 },
 [0x1025]={
  category="lo",
  description="MYANMAR LETTER U",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1025,
 },
 [0x1026]={
  category="lo",
  description="MYANMAR LETTER UU",
  direction="l",
  linebreak="sa",
  specials={ "char", 0x1025, 0x102E },
  unicodeslot=0x1026,
 },
 [0x1027]={
  category="lo",
  description="MYANMAR LETTER E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1027,
 },
 [0x1028]={
  category="lo",
  description="MYANMAR LETTER MON E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1028,
 },
 [0x1029]={
  category="lo",
  description="MYANMAR LETTER O",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1029,
 },
 [0x102A]={
  category="lo",
  description="MYANMAR LETTER AU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x102A,
 },
 [0x102B]={
  category="mc",
  description="MYANMAR VOWEL SIGN TALL AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x102B,
 },
 [0x102C]={
  category="mc",
  description="MYANMAR VOWEL SIGN AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x102C,
 },
 [0x102D]={
  category="mn",
  description="MYANMAR VOWEL SIGN I",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x102D,
 },
 [0x102E]={
  category="mn",
  description="MYANMAR VOWEL SIGN II",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x102E,
 },
 [0x102F]={
  category="mn",
  description="MYANMAR VOWEL SIGN U",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x102F,
 },
 [0x1030]={
  category="mn",
  description="MYANMAR VOWEL SIGN UU",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1030,
 },
 [0x1031]={
  category="mc",
  description="MYANMAR VOWEL SIGN E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1031,
 },
 [0x1032]={
  category="mn",
  description="MYANMAR VOWEL SIGN AI",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1032,
 },
 [0x1033]={
  category="mn",
  description="MYANMAR VOWEL SIGN MON II",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1033,
 },
 [0x1034]={
  category="mn",
  description="MYANMAR VOWEL SIGN MON O",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1034,
 },
 [0x1035]={
  category="mn",
  description="MYANMAR VOWEL SIGN E ABOVE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1035,
 },
 [0x1036]={
  category="mn",
  description="MYANMAR SIGN ANUSVARA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1036,
 },
 [0x1037]={
  category="mn",
  description="MYANMAR SIGN DOT BELOW",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1037,
 },
 [0x1038]={
  category="mc",
  description="MYANMAR SIGN VISARGA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1038,
 },
 [0x1039]={
  category="mn",
  description="MYANMAR SIGN VIRAMA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1039,
 },
 [0x103A]={
  category="mn",
  description="MYANMAR SIGN ASAT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x103A,
 },
 [0x103B]={
  category="mc",
  description="MYANMAR CONSONANT SIGN MEDIAL YA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x103B,
 },
 [0x103C]={
  category="mc",
  description="MYANMAR CONSONANT SIGN MEDIAL RA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x103C,
 },
 [0x103D]={
  category="mn",
  description="MYANMAR CONSONANT SIGN MEDIAL WA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x103D,
 },
 [0x103E]={
  category="mn",
  description="MYANMAR CONSONANT SIGN MEDIAL HA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x103E,
 },
 [0x103F]={
  category="lo",
  description="MYANMAR LETTER GREAT SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x103F,
 },
 [0x1040]={
  category="nd",
  description="MYANMAR DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1040,
 },
 [0x1041]={
  category="nd",
  description="MYANMAR DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1041,
 },
 [0x1042]={
  category="nd",
  description="MYANMAR DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1042,
 },
 [0x1043]={
  category="nd",
  description="MYANMAR DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1043,
 },
 [0x1044]={
  category="nd",
  description="MYANMAR DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1044,
 },
 [0x1045]={
  category="nd",
  description="MYANMAR DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1045,
 },
 [0x1046]={
  category="nd",
  description="MYANMAR DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1046,
 },
 [0x1047]={
  category="nd",
  description="MYANMAR DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1047,
 },
 [0x1048]={
  category="nd",
  description="MYANMAR DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1048,
 },
 [0x1049]={
  category="nd",
  description="MYANMAR DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1049,
 },
 [0x104A]={
  category="po",
  description="MYANMAR SIGN LITTLE SECTION",
  direction="l",
  linebreak="ba",
  unicodeslot=0x104A,
 },
 [0x104B]={
  category="po",
  description="MYANMAR SIGN SECTION",
  direction="l",
  linebreak="ba",
  unicodeslot=0x104B,
 },
 [0x104C]={
  category="po",
  description="MYANMAR SYMBOL LOCATIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x104C,
 },
 [0x104D]={
  category="po",
  description="MYANMAR SYMBOL COMPLETED",
  direction="l",
  linebreak="al",
  unicodeslot=0x104D,
 },
 [0x104E]={
  category="po",
  description="MYANMAR SYMBOL AFOREMENTIONED",
  direction="l",
  linebreak="al",
  unicodeslot=0x104E,
 },
 [0x104F]={
  category="po",
  description="MYANMAR SYMBOL GENITIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x104F,
 },
 [0x1050]={
  category="lo",
  description="MYANMAR LETTER SHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1050,
 },
 [0x1051]={
  category="lo",
  description="MYANMAR LETTER SSA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1051,
 },
 [0x1052]={
  category="lo",
  description="MYANMAR LETTER VOCALIC R",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1052,
 },
 [0x1053]={
  category="lo",
  description="MYANMAR LETTER VOCALIC RR",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1053,
 },
 [0x1054]={
  category="lo",
  description="MYANMAR LETTER VOCALIC L",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1054,
 },
 [0x1055]={
  category="lo",
  description="MYANMAR LETTER VOCALIC LL",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1055,
 },
 [0x1056]={
  category="mc",
  description="MYANMAR VOWEL SIGN VOCALIC R",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1056,
 },
 [0x1057]={
  category="mc",
  description="MYANMAR VOWEL SIGN VOCALIC RR",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1057,
 },
 [0x1058]={
  category="mn",
  description="MYANMAR VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1058,
 },
 [0x1059]={
  category="mn",
  description="MYANMAR VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1059,
 },
 [0x105A]={
  category="lo",
  description="MYANMAR LETTER MON NGA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x105A,
 },
 [0x105B]={
  category="lo",
  description="MYANMAR LETTER MON JHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x105B,
 },
 [0x105C]={
  category="lo",
  description="MYANMAR LETTER MON BBA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x105C,
 },
 [0x105D]={
  category="lo",
  description="MYANMAR LETTER MON BBE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x105D,
 },
 [0x105E]={
  category="mn",
  description="MYANMAR CONSONANT SIGN MON MEDIAL NA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x105E,
 },
 [0x105F]={
  category="mn",
  description="MYANMAR CONSONANT SIGN MON MEDIAL MA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x105F,
 },
 [0x1060]={
  category="mn",
  description="MYANMAR CONSONANT SIGN MON MEDIAL LA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1060,
 },
 [0x1061]={
  category="lo",
  description="MYANMAR LETTER SGAW KAREN SHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1061,
 },
 [0x1062]={
  category="mc",
  description="MYANMAR VOWEL SIGN SGAW KAREN EU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1062,
 },
 [0x1063]={
  category="mc",
  description="MYANMAR TONE MARK SGAW KAREN HATHI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1063,
 },
 [0x1064]={
  category="mc",
  description="MYANMAR TONE MARK SGAW KAREN KE PHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1064,
 },
 [0x1065]={
  category="lo",
  description="MYANMAR LETTER WESTERN PWO KAREN THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1065,
 },
 [0x1066]={
  category="lo",
  description="MYANMAR LETTER WESTERN PWO KAREN PWA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1066,
 },
 [0x1067]={
  category="mc",
  description="MYANMAR VOWEL SIGN WESTERN PWO KAREN EU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1067,
 },
 [0x1068]={
  category="mc",
  description="MYANMAR VOWEL SIGN WESTERN PWO KAREN UE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1068,
 },
 [0x1069]={
  category="mc",
  description="MYANMAR SIGN WESTERN PWO KAREN TONE-1",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1069,
 },
 [0x106A]={
  category="mc",
  description="MYANMAR SIGN WESTERN PWO KAREN TONE-2",
  direction="l",
  linebreak="sa",
  unicodeslot=0x106A,
 },
 [0x106B]={
  category="mc",
  description="MYANMAR SIGN WESTERN PWO KAREN TONE-3",
  direction="l",
  linebreak="sa",
  unicodeslot=0x106B,
 },
 [0x106C]={
  category="mc",
  description="MYANMAR SIGN WESTERN PWO KAREN TONE-4",
  direction="l",
  linebreak="sa",
  unicodeslot=0x106C,
 },
 [0x106D]={
  category="mc",
  description="MYANMAR SIGN WESTERN PWO KAREN TONE-5",
  direction="l",
  linebreak="sa",
  unicodeslot=0x106D,
 },
 [0x106E]={
  category="lo",
  description="MYANMAR LETTER EASTERN PWO KAREN NNA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x106E,
 },
 [0x106F]={
  category="lo",
  description="MYANMAR LETTER EASTERN PWO KAREN YWA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x106F,
 },
 [0x1070]={
  category="lo",
  description="MYANMAR LETTER EASTERN PWO KAREN GHWA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1070,
 },
 [0x1071]={
  category="mn",
  description="MYANMAR VOWEL SIGN GEBA KAREN I",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1071,
 },
 [0x1072]={
  category="mn",
  description="MYANMAR VOWEL SIGN KAYAH OE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1072,
 },
 [0x1073]={
  category="mn",
  description="MYANMAR VOWEL SIGN KAYAH U",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1073,
 },
 [0x1074]={
  category="mn",
  description="MYANMAR VOWEL SIGN KAYAH EE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1074,
 },
 [0x1075]={
  category="lo",
  description="MYANMAR LETTER SHAN KA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1075,
 },
 [0x1076]={
  category="lo",
  description="MYANMAR LETTER SHAN KHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1076,
 },
 [0x1077]={
  category="lo",
  description="MYANMAR LETTER SHAN GA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1077,
 },
 [0x1078]={
  category="lo",
  description="MYANMAR LETTER SHAN CA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1078,
 },
 [0x1079]={
  category="lo",
  description="MYANMAR LETTER SHAN ZA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1079,
 },
 [0x107A]={
  category="lo",
  description="MYANMAR LETTER SHAN NYA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x107A,
 },
 [0x107B]={
  category="lo",
  description="MYANMAR LETTER SHAN DA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x107B,
 },
 [0x107C]={
  category="lo",
  description="MYANMAR LETTER SHAN NA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x107C,
 },
 [0x107D]={
  category="lo",
  description="MYANMAR LETTER SHAN PHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x107D,
 },
 [0x107E]={
  category="lo",
  description="MYANMAR LETTER SHAN FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x107E,
 },
 [0x107F]={
  category="lo",
  description="MYANMAR LETTER SHAN BA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x107F,
 },
 [0x1080]={
  category="lo",
  description="MYANMAR LETTER SHAN THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1080,
 },
 [0x1081]={
  category="lo",
  description="MYANMAR LETTER SHAN HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1081,
 },
 [0x1082]={
  category="mn",
  description="MYANMAR CONSONANT SIGN SHAN MEDIAL WA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1082,
 },
 [0x1083]={
  category="mc",
  description="MYANMAR VOWEL SIGN SHAN AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1083,
 },
 [0x1084]={
  category="mc",
  description="MYANMAR VOWEL SIGN SHAN E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1084,
 },
 [0x1085]={
  category="mn",
  description="MYANMAR VOWEL SIGN SHAN E ABOVE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1085,
 },
 [0x1086]={
  category="mn",
  description="MYANMAR VOWEL SIGN SHAN FINAL Y",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1086,
 },
 [0x1087]={
  category="mc",
  description="MYANMAR SIGN SHAN TONE-2",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1087,
 },
 [0x1088]={
  category="mc",
  description="MYANMAR SIGN SHAN TONE-3",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1088,
 },
 [0x1089]={
  category="mc",
  description="MYANMAR SIGN SHAN TONE-5",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1089,
 },
 [0x108A]={
  category="mc",
  description="MYANMAR SIGN SHAN TONE-6",
  direction="l",
  linebreak="sa",
  unicodeslot=0x108A,
 },
 [0x108B]={
  category="mc",
  description="MYANMAR SIGN SHAN COUNCIL TONE-2",
  direction="l",
  linebreak="sa",
  unicodeslot=0x108B,
 },
 [0x108C]={
  category="mc",
  description="MYANMAR SIGN SHAN COUNCIL TONE-3",
  direction="l",
  linebreak="sa",
  unicodeslot=0x108C,
 },
 [0x108D]={
  category="mn",
  description="MYANMAR SIGN SHAN COUNCIL EMPHATIC TONE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x108D,
 },
 [0x108E]={
  category="lo",
  description="MYANMAR LETTER RUMAI PALAUNG FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x108E,
 },
 [0x108F]={
  category="mc",
  description="MYANMAR SIGN RUMAI PALAUNG TONE-5",
  direction="l",
  linebreak="sa",
  unicodeslot=0x108F,
 },
 [0x1090]={
  category="nd",
  description="MYANMAR SHAN DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1090,
 },
 [0x1091]={
  category="nd",
  description="MYANMAR SHAN DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1091,
 },
 [0x1092]={
  category="nd",
  description="MYANMAR SHAN DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1092,
 },
 [0x1093]={
  category="nd",
  description="MYANMAR SHAN DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1093,
 },
 [0x1094]={
  category="nd",
  description="MYANMAR SHAN DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1094,
 },
 [0x1095]={
  category="nd",
  description="MYANMAR SHAN DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1095,
 },
 [0x1096]={
  category="nd",
  description="MYANMAR SHAN DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1096,
 },
 [0x1097]={
  category="nd",
  description="MYANMAR SHAN DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1097,
 },
 [0x1098]={
  category="nd",
  description="MYANMAR SHAN DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1098,
 },
 [0x1099]={
  category="nd",
  description="MYANMAR SHAN DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1099,
 },
 [0x109A]={
  category="mc",
  description="MYANMAR SIGN KHAMTI TONE-1",
  direction="l",
  linebreak="sa",
  unicodeslot=0x109A,
 },
 [0x109B]={
  category="mc",
  description="MYANMAR SIGN KHAMTI TONE-3",
  direction="l",
  linebreak="sa",
  unicodeslot=0x109B,
 },
 [0x109C]={
  category="mc",
  description="MYANMAR VOWEL SIGN AITON A",
  direction="l",
  linebreak="sa",
  unicodeslot=0x109C,
 },
 [0x109D]={
  category="mn",
  description="MYANMAR VOWEL SIGN AITON AI",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x109D,
 },
 [0x109E]={
  category="so",
  description="MYANMAR SYMBOL SHAN ONE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x109E,
 },
 [0x109F]={
  category="so",
  description="MYANMAR SYMBOL SHAN EXCLAMATION",
  direction="l",
  linebreak="sa",
  unicodeslot=0x109F,
 },
 [0x10A0]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER AN",
  direction="l",
  lccode=0x2D00,
  linebreak="al",
  unicodeslot=0x10A0,
 },
 [0x10A1]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER BAN",
  direction="l",
  lccode=0x2D01,
  linebreak="al",
  unicodeslot=0x10A1,
 },
 [0x10A2]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER GAN",
  direction="l",
  lccode=0x2D02,
  linebreak="al",
  unicodeslot=0x10A2,
 },
 [0x10A3]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER DON",
  direction="l",
  lccode=0x2D03,
  linebreak="al",
  unicodeslot=0x10A3,
 },
 [0x10A4]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER EN",
  direction="l",
  lccode=0x2D04,
  linebreak="al",
  unicodeslot=0x10A4,
 },
 [0x10A5]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER VIN",
  direction="l",
  lccode=0x2D05,
  linebreak="al",
  unicodeslot=0x10A5,
 },
 [0x10A6]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER ZEN",
  direction="l",
  lccode=0x2D06,
  linebreak="al",
  unicodeslot=0x10A6,
 },
 [0x10A7]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER TAN",
  direction="l",
  lccode=0x2D07,
  linebreak="al",
  unicodeslot=0x10A7,
 },
 [0x10A8]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER IN",
  direction="l",
  lccode=0x2D08,
  linebreak="al",
  unicodeslot=0x10A8,
 },
 [0x10A9]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER KAN",
  direction="l",
  lccode=0x2D09,
  linebreak="al",
  unicodeslot=0x10A9,
 },
 [0x10AA]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER LAS",
  direction="l",
  lccode=0x2D0A,
  linebreak="al",
  unicodeslot=0x10AA,
 },
 [0x10AB]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER MAN",
  direction="l",
  lccode=0x2D0B,
  linebreak="al",
  unicodeslot=0x10AB,
 },
 [0x10AC]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER NAR",
  direction="l",
  lccode=0x2D0C,
  linebreak="al",
  unicodeslot=0x10AC,
 },
 [0x10AD]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER ON",
  direction="l",
  lccode=0x2D0D,
  linebreak="al",
  unicodeslot=0x10AD,
 },
 [0x10AE]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER PAR",
  direction="l",
  lccode=0x2D0E,
  linebreak="al",
  unicodeslot=0x10AE,
 },
 [0x10AF]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER ZHAR",
  direction="l",
  lccode=0x2D0F,
  linebreak="al",
  unicodeslot=0x10AF,
 },
 [0x10B0]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER RAE",
  direction="l",
  lccode=0x2D10,
  linebreak="al",
  unicodeslot=0x10B0,
 },
 [0x10B1]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER SAN",
  direction="l",
  lccode=0x2D11,
  linebreak="al",
  unicodeslot=0x10B1,
 },
 [0x10B2]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER TAR",
  direction="l",
  lccode=0x2D12,
  linebreak="al",
  unicodeslot=0x10B2,
 },
 [0x10B3]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER UN",
  direction="l",
  lccode=0x2D13,
  linebreak="al",
  unicodeslot=0x10B3,
 },
 [0x10B4]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER PHAR",
  direction="l",
  lccode=0x2D14,
  linebreak="al",
  unicodeslot=0x10B4,
 },
 [0x10B5]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER KHAR",
  direction="l",
  lccode=0x2D15,
  linebreak="al",
  unicodeslot=0x10B5,
 },
 [0x10B6]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER GHAN",
  direction="l",
  lccode=0x2D16,
  linebreak="al",
  unicodeslot=0x10B6,
 },
 [0x10B7]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER QAR",
  direction="l",
  lccode=0x2D17,
  linebreak="al",
  unicodeslot=0x10B7,
 },
 [0x10B8]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER SHIN",
  direction="l",
  lccode=0x2D18,
  linebreak="al",
  unicodeslot=0x10B8,
 },
 [0x10B9]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER CHIN",
  direction="l",
  lccode=0x2D19,
  linebreak="al",
  unicodeslot=0x10B9,
 },
 [0x10BA]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER CAN",
  direction="l",
  lccode=0x2D1A,
  linebreak="al",
  unicodeslot=0x10BA,
 },
 [0x10BB]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER JIL",
  direction="l",
  lccode=0x2D1B,
  linebreak="al",
  unicodeslot=0x10BB,
 },
 [0x10BC]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER CIL",
  direction="l",
  lccode=0x2D1C,
  linebreak="al",
  unicodeslot=0x10BC,
 },
 [0x10BD]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER CHAR",
  direction="l",
  lccode=0x2D1D,
  linebreak="al",
  unicodeslot=0x10BD,
 },
 [0x10BE]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER XAN",
  direction="l",
  lccode=0x2D1E,
  linebreak="al",
  unicodeslot=0x10BE,
 },
 [0x10BF]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER JHAN",
  direction="l",
  lccode=0x2D1F,
  linebreak="al",
  unicodeslot=0x10BF,
 },
 [0x10C0]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER HAE",
  direction="l",
  lccode=0x2D20,
  linebreak="al",
  unicodeslot=0x10C0,
 },
 [0x10C1]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER HE",
  direction="l",
  lccode=0x2D21,
  linebreak="al",
  unicodeslot=0x10C1,
 },
 [0x10C2]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER HIE",
  direction="l",
  lccode=0x2D22,
  linebreak="al",
  unicodeslot=0x10C2,
 },
 [0x10C3]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER WE",
  direction="l",
  lccode=0x2D23,
  linebreak="al",
  unicodeslot=0x10C3,
 },
 [0x10C4]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER HAR",
  direction="l",
  lccode=0x2D24,
  linebreak="al",
  unicodeslot=0x10C4,
 },
 [0x10C5]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER HOE",
  direction="l",
  lccode=0x2D25,
  linebreak="al",
  unicodeslot=0x10C5,
 },
 [0x10C7]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER YN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10C7,
 },
 [0x10CD]={
  category="lu",
  description="GEORGIAN CAPITAL LETTER AEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10CD,
 },
 [0x10D0]={
  category="lo",
  description="GEORGIAN LETTER AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D0,
 },
 [0x10D1]={
  category="lo",
  description="GEORGIAN LETTER BAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D1,
 },
 [0x10D2]={
  category="lo",
  description="GEORGIAN LETTER GAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D2,
 },
 [0x10D3]={
  category="lo",
  description="GEORGIAN LETTER DON",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D3,
 },
 [0x10D4]={
  category="lo",
  description="GEORGIAN LETTER EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D4,
 },
 [0x10D5]={
  category="lo",
  description="GEORGIAN LETTER VIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D5,
 },
 [0x10D6]={
  category="lo",
  description="GEORGIAN LETTER ZEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D6,
 },
 [0x10D7]={
  category="lo",
  description="GEORGIAN LETTER TAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D7,
 },
 [0x10D8]={
  category="lo",
  description="GEORGIAN LETTER IN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D8,
 },
 [0x10D9]={
  category="lo",
  description="GEORGIAN LETTER KAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10D9,
 },
 [0x10DA]={
  category="lo",
  description="GEORGIAN LETTER LAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x10DA,
 },
 [0x10DB]={
  category="lo",
  description="GEORGIAN LETTER MAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10DB,
 },
 [0x10DC]={
  category="lo",
  description="GEORGIAN LETTER NAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10DC,
 },
 [0x10DD]={
  category="lo",
  description="GEORGIAN LETTER ON",
  direction="l",
  linebreak="al",
  unicodeslot=0x10DD,
 },
 [0x10DE]={
  category="lo",
  description="GEORGIAN LETTER PAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10DE,
 },
 [0x10DF]={
  category="lo",
  description="GEORGIAN LETTER ZHAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10DF,
 },
 [0x10E0]={
  category="lo",
  description="GEORGIAN LETTER RAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E0,
 },
 [0x10E1]={
  category="lo",
  description="GEORGIAN LETTER SAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E1,
 },
 [0x10E2]={
  category="lo",
  description="GEORGIAN LETTER TAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E2,
 },
 [0x10E3]={
  category="lo",
  description="GEORGIAN LETTER UN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E3,
 },
 [0x10E4]={
  category="lo",
  description="GEORGIAN LETTER PHAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E4,
 },
 [0x10E5]={
  category="lo",
  description="GEORGIAN LETTER KHAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E5,
 },
 [0x10E6]={
  category="lo",
  description="GEORGIAN LETTER GHAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E6,
 },
 [0x10E7]={
  category="lo",
  description="GEORGIAN LETTER QAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E7,
 },
 [0x10E8]={
  category="lo",
  description="GEORGIAN LETTER SHIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E8,
 },
 [0x10E9]={
  category="lo",
  description="GEORGIAN LETTER CHIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10E9,
 },
 [0x10EA]={
  category="lo",
  description="GEORGIAN LETTER CAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10EA,
 },
 [0x10EB]={
  category="lo",
  description="GEORGIAN LETTER JIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10EB,
 },
 [0x10EC]={
  category="lo",
  description="GEORGIAN LETTER CIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10EC,
 },
 [0x10ED]={
  category="lo",
  description="GEORGIAN LETTER CHAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10ED,
 },
 [0x10EE]={
  category="lo",
  description="GEORGIAN LETTER XAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10EE,
 },
 [0x10EF]={
  category="lo",
  description="GEORGIAN LETTER JHAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10EF,
 },
 [0x10F0]={
  category="lo",
  description="GEORGIAN LETTER HAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F0,
 },
 [0x10F1]={
  category="lo",
  description="GEORGIAN LETTER HE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F1,
 },
 [0x10F2]={
  category="lo",
  description="GEORGIAN LETTER HIE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F2,
 },
 [0x10F3]={
  category="lo",
  description="GEORGIAN LETTER WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F3,
 },
 [0x10F4]={
  category="lo",
  description="GEORGIAN LETTER HAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F4,
 },
 [0x10F5]={
  category="lo",
  description="GEORGIAN LETTER HOE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F5,
 },
 [0x10F6]={
  category="lo",
  description="GEORGIAN LETTER FI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F6,
 },
 [0x10F7]={
  category="lo",
  description="GEORGIAN LETTER YN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F7,
 },
 [0x10F8]={
  category="lo",
  description="GEORGIAN LETTER ELIFI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F8,
 },
 [0x10F9]={
  category="lo",
  description="GEORGIAN LETTER TURNED GAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10F9,
 },
 [0x10FA]={
  category="lo",
  description="GEORGIAN LETTER AIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10FA,
 },
 [0x10FB]={
  category="po",
  description="GEORGIAN PARAGRAPH SEPARATOR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10FB,
 },
 [0x10FC]={
  category="lm",
  description="MODIFIER LETTER GEORGIAN NAR",
  direction="l",
  linebreak="al",
  specials={ "super", 0x10DC },
  unicodeslot=0x10FC,
 },
 [0x10FD]={
  category="lo",
  description="GEORGIAN LETTER AEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10FD,
 },
 [0x10FE]={
  category="lo",
  description="GEORGIAN LETTER HARD SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10FE,
 },
 [0x10FF]={
  category="lo",
  description="GEORGIAN LETTER LABIAL SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10FF,
 },
 [0x1100]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1100,
 },
 [0x1101]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGKIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1101,
 },
 [0x1102]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG NIEUN",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1102,
 },
 [0x1103]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1103,
 },
 [0x1104]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGTIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1104,
 },
 [0x1105]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1105,
 },
 [0x1106]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG MIEUM",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1106,
 },
 [0x1107]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1107,
 },
 [0x1108]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGPIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1108,
 },
 [0x1109]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1109,
 },
 [0x110A]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x110A,
 },
 [0x110B]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG",
  direction="l",
  linebreak="jl",
  unicodeslot=0x110B,
 },
 [0x110C]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x110C,
 },
 [0x110D]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGCIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x110D,
 },
 [0x110E]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CHIEUCH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x110E,
 },
 [0x110F]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG KHIEUKH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x110F,
 },
 [0x1110]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG THIEUTH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1110,
 },
 [0x1111]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PHIEUPH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1111,
 },
 [0x1112]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1112,
 },
 [0x1113]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG NIEUN-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1113,
 },
 [0x1114]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGNIEUN",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1114,
 },
 [0x1115]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG NIEUN-TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1115,
 },
 [0x1116]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG NIEUN-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1116,
 },
 [0x1117]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG TIKEUT-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1117,
 },
 [0x1118]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-NIEUN",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1118,
 },
 [0x1119]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGRIEUL",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1119,
 },
 [0x111A]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x111A,
 },
 [0x111B]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG KAPYEOUNRIEUL",
  direction="l",
  linebreak="jl",
  unicodeslot=0x111B,
 },
 [0x111C]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG MIEUM-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x111C,
 },
 [0x111D]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG KAPYEOUNMIEUM",
  direction="l",
  linebreak="jl",
  unicodeslot=0x111D,
 },
 [0x111E]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x111E,
 },
 [0x111F]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-NIEUN",
  direction="l",
  linebreak="jl",
  unicodeslot=0x111F,
 },
 [0x1120]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1120,
 },
 [0x1121]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-SIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1121,
 },
 [0x1122]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-SIOS-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1122,
 },
 [0x1123]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-SIOS-TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1123,
 },
 [0x1124]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-SIOS-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1124,
 },
 [0x1125]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-SSANGSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1125,
 },
 [0x1126]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-SIOS-CIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1126,
 },
 [0x1127]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-CIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1127,
 },
 [0x1128]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-CHIEUCH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1128,
 },
 [0x1129]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-THIEUTH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1129,
 },
 [0x112A]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-PHIEUPH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x112A,
 },
 [0x112B]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG KAPYEOUNPIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x112B,
 },
 [0x112C]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG KAPYEOUNSSANGPIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x112C,
 },
 [0x112D]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x112D,
 },
 [0x112E]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-NIEUN",
  direction="l",
  linebreak="jl",
  unicodeslot=0x112E,
 },
 [0x112F]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0x112F,
 },
 [0x1130]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-RIEUL",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1130,
 },
 [0x1131]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-MIEUM",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1131,
 },
 [0x1132]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1132,
 },
 [0x1133]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-PIEUP-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1133,
 },
 [0x1134]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-SSANGSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1134,
 },
 [0x1135]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-IEUNG",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1135,
 },
 [0x1136]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-CIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1136,
 },
 [0x1137]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-CHIEUCH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1137,
 },
 [0x1138]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-KHIEUKH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1138,
 },
 [0x1139]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-THIEUTH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1139,
 },
 [0x113A]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-PHIEUPH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x113A,
 },
 [0x113B]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SIOS-HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x113B,
 },
 [0x113C]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CHITUEUMSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x113C,
 },
 [0x113D]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CHITUEUMSSANGSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x113D,
 },
 [0x113E]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CEONGCHIEUMSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x113E,
 },
 [0x113F]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CEONGCHIEUMSSANGSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x113F,
 },
 [0x1140]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PANSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1140,
 },
 [0x1141]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1141,
 },
 [0x1142]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1142,
 },
 [0x1143]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-MIEUM",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1143,
 },
 [0x1144]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1144,
 },
 [0x1145]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-SIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1145,
 },
 [0x1146]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-PANSIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1146,
 },
 [0x1147]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGIEUNG",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1147,
 },
 [0x1148]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-CIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1148,
 },
 [0x1149]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-CHIEUCH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1149,
 },
 [0x114A]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-THIEUTH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x114A,
 },
 [0x114B]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-PHIEUPH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x114B,
 },
 [0x114C]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG YESIEUNG",
  direction="l",
  linebreak="jl",
  unicodeslot=0x114C,
 },
 [0x114D]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CIEUC-IEUNG",
  direction="l",
  linebreak="jl",
  unicodeslot=0x114D,
 },
 [0x114E]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CHITUEUMCIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x114E,
 },
 [0x114F]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CHITUEUMSSANGCIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x114F,
 },
 [0x1150]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CEONGCHIEUMCIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1150,
 },
 [0x1151]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CEONGCHIEUMSSANGCIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1151,
 },
 [0x1152]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CHIEUCH-KHIEUKH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1152,
 },
 [0x1153]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CHIEUCH-HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1153,
 },
 [0x1154]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CHITUEUMCHIEUCH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1154,
 },
 [0x1155]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG CEONGCHIEUMCHIEUCH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1155,
 },
 [0x1156]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PHIEUPH-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1156,
 },
 [0x1157]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG KAPYEOUNPHIEUPH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1157,
 },
 [0x1158]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGHIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1158,
 },
 [0x1159]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG YEORINHIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x1159,
 },
 [0x115A]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG KIYEOK-TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0x115A,
 },
 [0x115B]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG NIEUN-SIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0x115B,
 },
 [0x115C]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG NIEUN-CIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0x115C,
 },
 [0x115D]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG NIEUN-HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0x115D,
 },
 [0x115E]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG TIKEUT-RIEUL",
  direction="l",
  linebreak="jl",
  unicodeslot=0x115E,
 },
 [0x115F]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG FILLER",
  direction="l",
  linebreak="jl",
  unicodeslot=0x115F,
 },
 [0x1160]={
  category="lo",
  description="HANGUL JUNGSEONG FILLER",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1160,
 },
 [0x1161]={
  category="lo",
  description="HANGUL JUNGSEONG A",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1161,
 },
 [0x1162]={
  category="lo",
  description="HANGUL JUNGSEONG AE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1162,
 },
 [0x1163]={
  category="lo",
  description="HANGUL JUNGSEONG YA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1163,
 },
 [0x1164]={
  category="lo",
  description="HANGUL JUNGSEONG YAE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1164,
 },
 [0x1165]={
  category="lo",
  description="HANGUL JUNGSEONG EO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1165,
 },
 [0x1166]={
  category="lo",
  description="HANGUL JUNGSEONG E",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1166,
 },
 [0x1167]={
  category="lo",
  description="HANGUL JUNGSEONG YEO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1167,
 },
 [0x1168]={
  category="lo",
  description="HANGUL JUNGSEONG YE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1168,
 },
 [0x1169]={
  category="lo",
  description="HANGUL JUNGSEONG O",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1169,
 },
 [0x116A]={
  category="lo",
  description="HANGUL JUNGSEONG WA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x116A,
 },
 [0x116B]={
  category="lo",
  description="HANGUL JUNGSEONG WAE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x116B,
 },
 [0x116C]={
  category="lo",
  description="HANGUL JUNGSEONG OE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x116C,
 },
 [0x116D]={
  category="lo",
  description="HANGUL JUNGSEONG YO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x116D,
 },
 [0x116E]={
  category="lo",
  description="HANGUL JUNGSEONG U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x116E,
 },
 [0x116F]={
  category="lo",
  description="HANGUL JUNGSEONG WEO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x116F,
 },
 [0x1170]={
  category="lo",
  description="HANGUL JUNGSEONG WE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1170,
 },
 [0x1171]={
  category="lo",
  description="HANGUL JUNGSEONG WI",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1171,
 },
 [0x1172]={
  category="lo",
  description="HANGUL JUNGSEONG YU",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1172,
 },
 [0x1173]={
  category="lo",
  description="HANGUL JUNGSEONG EU",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1173,
 },
 [0x1174]={
  category="lo",
  description="HANGUL JUNGSEONG YI",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1174,
 },
 [0x1175]={
  category="lo",
  description="HANGUL JUNGSEONG I",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1175,
 },
 [0x1176]={
  category="lo",
  description="HANGUL JUNGSEONG A-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1176,
 },
 [0x1177]={
  category="lo",
  description="HANGUL JUNGSEONG A-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1177,
 },
 [0x1178]={
  category="lo",
  description="HANGUL JUNGSEONG YA-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1178,
 },
 [0x1179]={
  category="lo",
  description="HANGUL JUNGSEONG YA-YO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1179,
 },
 [0x117A]={
  category="lo",
  description="HANGUL JUNGSEONG EO-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0x117A,
 },
 [0x117B]={
  category="lo",
  description="HANGUL JUNGSEONG EO-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x117B,
 },
 [0x117C]={
  category="lo",
  description="HANGUL JUNGSEONG EO-EU",
  direction="l",
  linebreak="jv",
  unicodeslot=0x117C,
 },
 [0x117D]={
  category="lo",
  description="HANGUL JUNGSEONG YEO-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0x117D,
 },
 [0x117E]={
  category="lo",
  description="HANGUL JUNGSEONG YEO-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x117E,
 },
 [0x117F]={
  category="lo",
  description="HANGUL JUNGSEONG O-EO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x117F,
 },
 [0x1180]={
  category="lo",
  description="HANGUL JUNGSEONG O-E",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1180,
 },
 [0x1181]={
  category="lo",
  description="HANGUL JUNGSEONG O-YE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1181,
 },
 [0x1182]={
  category="lo",
  description="HANGUL JUNGSEONG O-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1182,
 },
 [0x1183]={
  category="lo",
  description="HANGUL JUNGSEONG O-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1183,
 },
 [0x1184]={
  category="lo",
  description="HANGUL JUNGSEONG YO-YA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1184,
 },
 [0x1185]={
  category="lo",
  description="HANGUL JUNGSEONG YO-YAE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1185,
 },
 [0x1186]={
  category="lo",
  description="HANGUL JUNGSEONG YO-YEO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1186,
 },
 [0x1187]={
  category="lo",
  description="HANGUL JUNGSEONG YO-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1187,
 },
 [0x1188]={
  category="lo",
  description="HANGUL JUNGSEONG YO-I",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1188,
 },
 [0x1189]={
  category="lo",
  description="HANGUL JUNGSEONG U-A",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1189,
 },
 [0x118A]={
  category="lo",
  description="HANGUL JUNGSEONG U-AE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x118A,
 },
 [0x118B]={
  category="lo",
  description="HANGUL JUNGSEONG U-EO-EU",
  direction="l",
  linebreak="jv",
  unicodeslot=0x118B,
 },
 [0x118C]={
  category="lo",
  description="HANGUL JUNGSEONG U-YE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x118C,
 },
 [0x118D]={
  category="lo",
  description="HANGUL JUNGSEONG U-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x118D,
 },
 [0x118E]={
  category="lo",
  description="HANGUL JUNGSEONG YU-A",
  direction="l",
  linebreak="jv",
  unicodeslot=0x118E,
 },
 [0x118F]={
  category="lo",
  description="HANGUL JUNGSEONG YU-EO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x118F,
 },
 [0x1190]={
  category="lo",
  description="HANGUL JUNGSEONG YU-E",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1190,
 },
 [0x1191]={
  category="lo",
  description="HANGUL JUNGSEONG YU-YEO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1191,
 },
 [0x1192]={
  category="lo",
  description="HANGUL JUNGSEONG YU-YE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1192,
 },
 [0x1193]={
  category="lo",
  description="HANGUL JUNGSEONG YU-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1193,
 },
 [0x1194]={
  category="lo",
  description="HANGUL JUNGSEONG YU-I",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1194,
 },
 [0x1195]={
  category="lo",
  description="HANGUL JUNGSEONG EU-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1195,
 },
 [0x1196]={
  category="lo",
  description="HANGUL JUNGSEONG EU-EU",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1196,
 },
 [0x1197]={
  category="lo",
  description="HANGUL JUNGSEONG YI-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1197,
 },
 [0x1198]={
  category="lo",
  description="HANGUL JUNGSEONG I-A",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1198,
 },
 [0x1199]={
  category="lo",
  description="HANGUL JUNGSEONG I-YA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x1199,
 },
 [0x119A]={
  category="lo",
  description="HANGUL JUNGSEONG I-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0x119A,
 },
 [0x119B]={
  category="lo",
  description="HANGUL JUNGSEONG I-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x119B,
 },
 [0x119C]={
  category="lo",
  description="HANGUL JUNGSEONG I-EU",
  direction="l",
  linebreak="jv",
  unicodeslot=0x119C,
 },
 [0x119D]={
  category="lo",
  description="HANGUL JUNGSEONG I-ARAEA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x119D,
 },
 [0x119E]={
  category="lo",
  description="HANGUL JUNGSEONG ARAEA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x119E,
 },
 [0x119F]={
  category="lo",
  description="HANGUL JUNGSEONG ARAEA-EO",
  direction="l",
  linebreak="jv",
  unicodeslot=0x119F,
 },
 [0x11A0]={
  category="lo",
  description="HANGUL JUNGSEONG ARAEA-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x11A0,
 },
 [0x11A1]={
  category="lo",
  description="HANGUL JUNGSEONG ARAEA-I",
  direction="l",
  linebreak="jv",
  unicodeslot=0x11A1,
 },
 [0x11A2]={
  category="lo",
  description="HANGUL JUNGSEONG SSANGARAEA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x11A2,
 },
 [0x11A3]={
  category="lo",
  description="HANGUL JUNGSEONG A-EU",
  direction="l",
  linebreak="jv",
  unicodeslot=0x11A3,
 },
 [0x11A4]={
  category="lo",
  description="HANGUL JUNGSEONG YA-U",
  direction="l",
  linebreak="jv",
  unicodeslot=0x11A4,
 },
 [0x11A5]={
  category="lo",
  description="HANGUL JUNGSEONG YEO-YA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x11A5,
 },
 [0x11A6]={
  category="lo",
  description="HANGUL JUNGSEONG O-YA",
  direction="l",
  linebreak="jv",
  unicodeslot=0x11A6,
 },
 [0x11A7]={
  category="lo",
  description="HANGUL JUNGSEONG O-YAE",
  direction="l",
  linebreak="jv",
  unicodeslot=0x11A7,
 },
 [0x11A8]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11A8,
 },
 [0x11A9]={
  category="lo",
  description="HANGUL JONGSEONG SSANGKIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11A9,
 },
 [0x11AA]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11AA,
 },
 [0x11AB]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11AB,
 },
 [0x11AC]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-CIEUC",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11AC,
 },
 [0x11AD]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11AD,
 },
 [0x11AE]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11AE,
 },
 [0x11AF]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11AF,
 },
 [0x11B0]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B0,
 },
 [0x11B1]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-MIEUM",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B1,
 },
 [0x11B2]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B2,
 },
 [0x11B3]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B3,
 },
 [0x11B4]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-THIEUTH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B4,
 },
 [0x11B5]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-PHIEUPH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B5,
 },
 [0x11B6]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B6,
 },
 [0x11B7]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B7,
 },
 [0x11B8]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B8,
 },
 [0x11B9]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11B9,
 },
 [0x11BA]={
  category="lo",
  description="HANGUL JONGSEONG SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11BA,
 },
 [0x11BB]={
  category="lo",
  description="HANGUL JONGSEONG SSANGSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11BB,
 },
 [0x11BC]={
  category="lo",
  description="HANGUL JONGSEONG IEUNG",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11BC,
 },
 [0x11BD]={
  category="lo",
  description="HANGUL JONGSEONG CIEUC",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11BD,
 },
 [0x11BE]={
  category="lo",
  description="HANGUL JONGSEONG CHIEUCH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11BE,
 },
 [0x11BF]={
  category="lo",
  description="HANGUL JONGSEONG KHIEUKH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11BF,
 },
 [0x11C0]={
  category="lo",
  description="HANGUL JONGSEONG THIEUTH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C0,
 },
 [0x11C1]={
  category="lo",
  description="HANGUL JONGSEONG PHIEUPH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C1,
 },
 [0x11C2]={
  category="lo",
  description="HANGUL JONGSEONG HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C2,
 },
 [0x11C3]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK-RIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C3,
 },
 [0x11C4]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK-SIOS-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C4,
 },
 [0x11C5]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C5,
 },
 [0x11C6]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-TIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C6,
 },
 [0x11C7]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C7,
 },
 [0x11C8]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-PANSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C8,
 },
 [0x11C9]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-THIEUTH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11C9,
 },
 [0x11CA]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11CA,
 },
 [0x11CB]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT-RIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11CB,
 },
 [0x11CC]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-KIYEOK-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11CC,
 },
 [0x11CD]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-NIEUN",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11CD,
 },
 [0x11CE]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-TIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11CE,
 },
 [0x11CF]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-TIKEUT-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11CF,
 },
 [0x11D0]={
  category="lo",
  description="HANGUL JONGSEONG SSANGRIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D0,
 },
 [0x11D1]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-MIEUM-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D1,
 },
 [0x11D2]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-MIEUM-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D2,
 },
 [0x11D3]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-PIEUP-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D3,
 },
 [0x11D4]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-PIEUP-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D4,
 },
 [0x11D5]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-KAPYEOUNPIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D5,
 },
 [0x11D6]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-SSANGSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D6,
 },
 [0x11D7]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-PANSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D7,
 },
 [0x11D8]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-KHIEUKH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D8,
 },
 [0x11D9]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-YEORINHIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11D9,
 },
 [0x11DA]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11DA,
 },
 [0x11DB]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-RIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11DB,
 },
 [0x11DC]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11DC,
 },
 [0x11DD]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11DD,
 },
 [0x11DE]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-SSANGSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11DE,
 },
 [0x11DF]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-PANSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11DF,
 },
 [0x11E0]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-CHIEUCH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E0,
 },
 [0x11E1]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E1,
 },
 [0x11E2]={
  category="lo",
  description="HANGUL JONGSEONG KAPYEOUNMIEUM",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E2,
 },
 [0x11E3]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-RIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E3,
 },
 [0x11E4]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-PHIEUPH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E4,
 },
 [0x11E5]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E5,
 },
 [0x11E6]={
  category="lo",
  description="HANGUL JONGSEONG KAPYEOUNPIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E6,
 },
 [0x11E7]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E7,
 },
 [0x11E8]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-TIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E8,
 },
 [0x11E9]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-RIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11E9,
 },
 [0x11EA]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11EA,
 },
 [0x11EB]={
  category="lo",
  description="HANGUL JONGSEONG PANSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11EB,
 },
 [0x11EC]={
  category="lo",
  description="HANGUL JONGSEONG IEUNG-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11EC,
 },
 [0x11ED]={
  category="lo",
  description="HANGUL JONGSEONG IEUNG-SSANGKIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11ED,
 },
 [0x11EE]={
  category="lo",
  description="HANGUL JONGSEONG SSANGIEUNG",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11EE,
 },
 [0x11EF]={
  category="lo",
  description="HANGUL JONGSEONG IEUNG-KHIEUKH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11EF,
 },
 [0x11F0]={
  category="lo",
  description="HANGUL JONGSEONG YESIEUNG",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F0,
 },
 [0x11F1]={
  category="lo",
  description="HANGUL JONGSEONG YESIEUNG-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F1,
 },
 [0x11F2]={
  category="lo",
  description="HANGUL JONGSEONG YESIEUNG-PANSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F2,
 },
 [0x11F3]={
  category="lo",
  description="HANGUL JONGSEONG PHIEUPH-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F3,
 },
 [0x11F4]={
  category="lo",
  description="HANGUL JONGSEONG KAPYEOUNPHIEUPH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F4,
 },
 [0x11F5]={
  category="lo",
  description="HANGUL JONGSEONG HIEUH-NIEUN",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F5,
 },
 [0x11F6]={
  category="lo",
  description="HANGUL JONGSEONG HIEUH-RIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F6,
 },
 [0x11F7]={
  category="lo",
  description="HANGUL JONGSEONG HIEUH-MIEUM",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F7,
 },
 [0x11F8]={
  category="lo",
  description="HANGUL JONGSEONG HIEUH-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F8,
 },
 [0x11F9]={
  category="lo",
  description="HANGUL JONGSEONG YEORINHIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11F9,
 },
 [0x11FA]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK-NIEUN",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11FA,
 },
 [0x11FB]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11FB,
 },
 [0x11FC]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK-CHIEUCH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11FC,
 },
 [0x11FD]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK-KHIEUKH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11FD,
 },
 [0x11FE]={
  category="lo",
  description="HANGUL JONGSEONG KIYEOK-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11FE,
 },
 [0x11FF]={
  category="lo",
  description="HANGUL JONGSEONG SSANGNIEUN",
  direction="l",
  linebreak="jt",
  unicodeslot=0x11FF,
 },
 [0x1200]={
  category="lo",
  description="ETHIOPIC SYLLABLE HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1200,
 },
 [0x1201]={
  category="lo",
  description="ETHIOPIC SYLLABLE HU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1201,
 },
 [0x1202]={
  category="lo",
  description="ETHIOPIC SYLLABLE HI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1202,
 },
 [0x1203]={
  category="lo",
  description="ETHIOPIC SYLLABLE HAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1203,
 },
 [0x1204]={
  category="lo",
  description="ETHIOPIC SYLLABLE HEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1204,
 },
 [0x1205]={
  category="lo",
  description="ETHIOPIC SYLLABLE HE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1205,
 },
 [0x1206]={
  category="lo",
  description="ETHIOPIC SYLLABLE HO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1206,
 },
 [0x1207]={
  category="lo",
  description="ETHIOPIC SYLLABLE HOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1207,
 },
 [0x1208]={
  category="lo",
  description="ETHIOPIC SYLLABLE LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1208,
 },
 [0x1209]={
  category="lo",
  description="ETHIOPIC SYLLABLE LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1209,
 },
 [0x120A]={
  category="lo",
  description="ETHIOPIC SYLLABLE LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A,
 },
 [0x120B]={
  category="lo",
  description="ETHIOPIC SYLLABLE LAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B,
 },
 [0x120C]={
  category="lo",
  description="ETHIOPIC SYLLABLE LEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C,
 },
 [0x120D]={
  category="lo",
  description="ETHIOPIC SYLLABLE LE",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D,
 },
 [0x120E]={
  category="lo",
  description="ETHIOPIC SYLLABLE LO",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E,
 },
 [0x120F]={
  category="lo",
  description="ETHIOPIC SYLLABLE LWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F,
 },
 [0x1210]={
  category="lo",
  description="ETHIOPIC SYLLABLE HHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1210,
 },
 [0x1211]={
  category="lo",
  description="ETHIOPIC SYLLABLE HHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1211,
 },
 [0x1212]={
  category="lo",
  description="ETHIOPIC SYLLABLE HHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1212,
 },
 [0x1213]={
  category="lo",
  description="ETHIOPIC SYLLABLE HHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1213,
 },
 [0x1214]={
  category="lo",
  description="ETHIOPIC SYLLABLE HHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1214,
 },
 [0x1215]={
  category="lo",
  description="ETHIOPIC SYLLABLE HHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1215,
 },
 [0x1216]={
  category="lo",
  description="ETHIOPIC SYLLABLE HHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1216,
 },
 [0x1217]={
  category="lo",
  description="ETHIOPIC SYLLABLE HHWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1217,
 },
 [0x1218]={
  category="lo",
  description="ETHIOPIC SYLLABLE MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1218,
 },
 [0x1219]={
  category="lo",
  description="ETHIOPIC SYLLABLE MU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1219,
 },
 [0x121A]={
  category="lo",
  description="ETHIOPIC SYLLABLE MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A,
 },
 [0x121B]={
  category="lo",
  description="ETHIOPIC SYLLABLE MAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B,
 },
 [0x121C]={
  category="lo",
  description="ETHIOPIC SYLLABLE MEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C,
 },
 [0x121D]={
  category="lo",
  description="ETHIOPIC SYLLABLE ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D,
 },
 [0x121E]={
  category="lo",
  description="ETHIOPIC SYLLABLE MO",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E,
 },
 [0x121F]={
  category="lo",
  description="ETHIOPIC SYLLABLE MWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F,
 },
 [0x1220]={
  category="lo",
  description="ETHIOPIC SYLLABLE SZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1220,
 },
 [0x1221]={
  category="lo",
  description="ETHIOPIC SYLLABLE SZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1221,
 },
 [0x1222]={
  category="lo",
  description="ETHIOPIC SYLLABLE SZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1222,
 },
 [0x1223]={
  category="lo",
  description="ETHIOPIC SYLLABLE SZAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1223,
 },
 [0x1224]={
  category="lo",
  description="ETHIOPIC SYLLABLE SZEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1224,
 },
 [0x1225]={
  category="lo",
  description="ETHIOPIC SYLLABLE SZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1225,
 },
 [0x1226]={
  category="lo",
  description="ETHIOPIC SYLLABLE SZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1226,
 },
 [0x1227]={
  category="lo",
  description="ETHIOPIC SYLLABLE SZWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1227,
 },
 [0x1228]={
  category="lo",
  description="ETHIOPIC SYLLABLE RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1228,
 },
 [0x1229]={
  category="lo",
  description="ETHIOPIC SYLLABLE RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1229,
 },
 [0x122A]={
  category="lo",
  description="ETHIOPIC SYLLABLE RI",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A,
 },
 [0x122B]={
  category="lo",
  description="ETHIOPIC SYLLABLE RAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B,
 },
 [0x122C]={
  category="lo",
  description="ETHIOPIC SYLLABLE REE",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C,
 },
 [0x122D]={
  category="lo",
  description="ETHIOPIC SYLLABLE RE",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D,
 },
 [0x122E]={
  category="lo",
  description="ETHIOPIC SYLLABLE RO",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E,
 },
 [0x122F]={
  category="lo",
  description="ETHIOPIC SYLLABLE RWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F,
 },
 [0x1230]={
  category="lo",
  description="ETHIOPIC SYLLABLE SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1230,
 },
 [0x1231]={
  category="lo",
  description="ETHIOPIC SYLLABLE SU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1231,
 },
 [0x1232]={
  category="lo",
  description="ETHIOPIC SYLLABLE SI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1232,
 },
 [0x1233]={
  category="lo",
  description="ETHIOPIC SYLLABLE SAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1233,
 },
 [0x1234]={
  category="lo",
  description="ETHIOPIC SYLLABLE SEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1234,
 },
 [0x1235]={
  category="lo",
  description="ETHIOPIC SYLLABLE SE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1235,
 },
 [0x1236]={
  category="lo",
  description="ETHIOPIC SYLLABLE SO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1236,
 },
 [0x1237]={
  category="lo",
  description="ETHIOPIC SYLLABLE SWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1237,
 },
 [0x1238]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1238,
 },
 [0x1239]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1239,
 },
 [0x123A]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x123A,
 },
 [0x123B]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x123B,
 },
 [0x123C]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x123C,
 },
 [0x123D]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x123D,
 },
 [0x123E]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x123E,
 },
 [0x123F]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x123F,
 },
 [0x1240]={
  category="lo",
  description="ETHIOPIC SYLLABLE QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1240,
 },
 [0x1241]={
  category="lo",
  description="ETHIOPIC SYLLABLE QU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1241,
 },
 [0x1242]={
  category="lo",
  description="ETHIOPIC SYLLABLE QI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1242,
 },
 [0x1243]={
  category="lo",
  description="ETHIOPIC SYLLABLE QAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1243,
 },
 [0x1244]={
  category="lo",
  description="ETHIOPIC SYLLABLE QEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1244,
 },
 [0x1245]={
  category="lo",
  description="ETHIOPIC SYLLABLE QE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1245,
 },
 [0x1246]={
  category="lo",
  description="ETHIOPIC SYLLABLE QO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1246,
 },
 [0x1247]={
  category="lo",
  description="ETHIOPIC SYLLABLE QOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1247,
 },
 [0x1248]={
  category="lo",
  description="ETHIOPIC SYLLABLE QWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1248,
 },
 [0x124A]={
  category="lo",
  description="ETHIOPIC SYLLABLE QWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x124A,
 },
 [0x124B]={
  category="lo",
  description="ETHIOPIC SYLLABLE QWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x124B,
 },
 [0x124C]={
  category="lo",
  description="ETHIOPIC SYLLABLE QWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x124C,
 },
 [0x124D]={
  category="lo",
  description="ETHIOPIC SYLLABLE QWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x124D,
 },
 [0x1250]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1250,
 },
 [0x1251]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1251,
 },
 [0x1252]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1252,
 },
 [0x1253]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1253,
 },
 [0x1254]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1254,
 },
 [0x1255]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1255,
 },
 [0x1256]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1256,
 },
 [0x1258]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1258,
 },
 [0x125A]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x125A,
 },
 [0x125B]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x125B,
 },
 [0x125C]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x125C,
 },
 [0x125D]={
  category="lo",
  description="ETHIOPIC SYLLABLE QHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x125D,
 },
 [0x1260]={
  category="lo",
  description="ETHIOPIC SYLLABLE BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1260,
 },
 [0x1261]={
  category="lo",
  description="ETHIOPIC SYLLABLE BU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1261,
 },
 [0x1262]={
  category="lo",
  description="ETHIOPIC SYLLABLE BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1262,
 },
 [0x1263]={
  category="lo",
  description="ETHIOPIC SYLLABLE BAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1263,
 },
 [0x1264]={
  category="lo",
  description="ETHIOPIC SYLLABLE BEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1264,
 },
 [0x1265]={
  category="lo",
  description="ETHIOPIC SYLLABLE BE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1265,
 },
 [0x1266]={
  category="lo",
  description="ETHIOPIC SYLLABLE BO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1266,
 },
 [0x1267]={
  category="lo",
  description="ETHIOPIC SYLLABLE BWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1267,
 },
 [0x1268]={
  category="lo",
  description="ETHIOPIC SYLLABLE VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1268,
 },
 [0x1269]={
  category="lo",
  description="ETHIOPIC SYLLABLE VU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1269,
 },
 [0x126A]={
  category="lo",
  description="ETHIOPIC SYLLABLE VI",
  direction="l",
  linebreak="al",
  unicodeslot=0x126A,
 },
 [0x126B]={
  category="lo",
  description="ETHIOPIC SYLLABLE VAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x126B,
 },
 [0x126C]={
  category="lo",
  description="ETHIOPIC SYLLABLE VEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x126C,
 },
 [0x126D]={
  category="lo",
  description="ETHIOPIC SYLLABLE VE",
  direction="l",
  linebreak="al",
  unicodeslot=0x126D,
 },
 [0x126E]={
  category="lo",
  description="ETHIOPIC SYLLABLE VO",
  direction="l",
  linebreak="al",
  unicodeslot=0x126E,
 },
 [0x126F]={
  category="lo",
  description="ETHIOPIC SYLLABLE VWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x126F,
 },
 [0x1270]={
  category="lo",
  description="ETHIOPIC SYLLABLE TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1270,
 },
 [0x1271]={
  category="lo",
  description="ETHIOPIC SYLLABLE TU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1271,
 },
 [0x1272]={
  category="lo",
  description="ETHIOPIC SYLLABLE TI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1272,
 },
 [0x1273]={
  category="lo",
  description="ETHIOPIC SYLLABLE TAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1273,
 },
 [0x1274]={
  category="lo",
  description="ETHIOPIC SYLLABLE TEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1274,
 },
 [0x1275]={
  category="lo",
  description="ETHIOPIC SYLLABLE TE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1275,
 },
 [0x1276]={
  category="lo",
  description="ETHIOPIC SYLLABLE TO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1276,
 },
 [0x1277]={
  category="lo",
  description="ETHIOPIC SYLLABLE TWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1277,
 },
 [0x1278]={
  category="lo",
  description="ETHIOPIC SYLLABLE CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1278,
 },
 [0x1279]={
  category="lo",
  description="ETHIOPIC SYLLABLE CU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1279,
 },
 [0x127A]={
  category="lo",
  description="ETHIOPIC SYLLABLE CI",
  direction="l",
  linebreak="al",
  unicodeslot=0x127A,
 },
 [0x127B]={
  category="lo",
  description="ETHIOPIC SYLLABLE CAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x127B,
 },
 [0x127C]={
  category="lo",
  description="ETHIOPIC SYLLABLE CEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x127C,
 },
 [0x127D]={
  category="lo",
  description="ETHIOPIC SYLLABLE CE",
  direction="l",
  linebreak="al",
  unicodeslot=0x127D,
 },
 [0x127E]={
  category="lo",
  description="ETHIOPIC SYLLABLE CO",
  direction="l",
  linebreak="al",
  unicodeslot=0x127E,
 },
 [0x127F]={
  category="lo",
  description="ETHIOPIC SYLLABLE CWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x127F,
 },
 [0x1280]={
  category="lo",
  description="ETHIOPIC SYLLABLE XA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1280,
 },
 [0x1281]={
  category="lo",
  description="ETHIOPIC SYLLABLE XU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1281,
 },
 [0x1282]={
  category="lo",
  description="ETHIOPIC SYLLABLE XI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1282,
 },
 [0x1283]={
  category="lo",
  description="ETHIOPIC SYLLABLE XAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1283,
 },
 [0x1284]={
  category="lo",
  description="ETHIOPIC SYLLABLE XEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1284,
 },
 [0x1285]={
  category="lo",
  description="ETHIOPIC SYLLABLE XE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1285,
 },
 [0x1286]={
  category="lo",
  description="ETHIOPIC SYLLABLE XO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1286,
 },
 [0x1287]={
  category="lo",
  description="ETHIOPIC SYLLABLE XOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1287,
 },
 [0x1288]={
  category="lo",
  description="ETHIOPIC SYLLABLE XWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1288,
 },
 [0x128A]={
  category="lo",
  description="ETHIOPIC SYLLABLE XWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x128A,
 },
 [0x128B]={
  category="lo",
  description="ETHIOPIC SYLLABLE XWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x128B,
 },
 [0x128C]={
  category="lo",
  description="ETHIOPIC SYLLABLE XWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x128C,
 },
 [0x128D]={
  category="lo",
  description="ETHIOPIC SYLLABLE XWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x128D,
 },
 [0x1290]={
  category="lo",
  description="ETHIOPIC SYLLABLE NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1290,
 },
 [0x1291]={
  category="lo",
  description="ETHIOPIC SYLLABLE NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1291,
 },
 [0x1292]={
  category="lo",
  description="ETHIOPIC SYLLABLE NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1292,
 },
 [0x1293]={
  category="lo",
  description="ETHIOPIC SYLLABLE NAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1293,
 },
 [0x1294]={
  category="lo",
  description="ETHIOPIC SYLLABLE NEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1294,
 },
 [0x1295]={
  category="lo",
  description="ETHIOPIC SYLLABLE NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1295,
 },
 [0x1296]={
  category="lo",
  description="ETHIOPIC SYLLABLE NO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1296,
 },
 [0x1297]={
  category="lo",
  description="ETHIOPIC SYLLABLE NWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1297,
 },
 [0x1298]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1298,
 },
 [0x1299]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1299,
 },
 [0x129A]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x129A,
 },
 [0x129B]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x129B,
 },
 [0x129C]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x129C,
 },
 [0x129D]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYE",
  direction="l",
  linebreak="al",
  unicodeslot=0x129D,
 },
 [0x129E]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYO",
  direction="l",
  linebreak="al",
  unicodeslot=0x129E,
 },
 [0x129F]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x129F,
 },
 [0x12A0]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A0,
 },
 [0x12A1]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A1,
 },
 [0x12A2]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL I",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A2,
 },
 [0x12A3]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A3,
 },
 [0x12A4]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A4,
 },
 [0x12A5]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL E",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A5,
 },
 [0x12A6]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL O",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A6,
 },
 [0x12A7]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A7,
 },
 [0x12A8]={
  category="lo",
  description="ETHIOPIC SYLLABLE KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A8,
 },
 [0x12A9]={
  category="lo",
  description="ETHIOPIC SYLLABLE KU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12A9,
 },
 [0x12AA]={
  category="lo",
  description="ETHIOPIC SYLLABLE KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12AA,
 },
 [0x12AB]={
  category="lo",
  description="ETHIOPIC SYLLABLE KAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12AB,
 },
 [0x12AC]={
  category="lo",
  description="ETHIOPIC SYLLABLE KEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12AC,
 },
 [0x12AD]={
  category="lo",
  description="ETHIOPIC SYLLABLE KE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12AD,
 },
 [0x12AE]={
  category="lo",
  description="ETHIOPIC SYLLABLE KO",
  direction="l",
  linebreak="al",
  unicodeslot=0x12AE,
 },
 [0x12AF]={
  category="lo",
  description="ETHIOPIC SYLLABLE KOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12AF,
 },
 [0x12B0]={
  category="lo",
  description="ETHIOPIC SYLLABLE KWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12B0,
 },
 [0x12B2]={
  category="lo",
  description="ETHIOPIC SYLLABLE KWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12B2,
 },
 [0x12B3]={
  category="lo",
  description="ETHIOPIC SYLLABLE KWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12B3,
 },
 [0x12B4]={
  category="lo",
  description="ETHIOPIC SYLLABLE KWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12B4,
 },
 [0x12B5]={
  category="lo",
  description="ETHIOPIC SYLLABLE KWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12B5,
 },
 [0x12B8]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12B8,
 },
 [0x12B9]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12B9,
 },
 [0x12BA]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12BA,
 },
 [0x12BB]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12BB,
 },
 [0x12BC]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12BC,
 },
 [0x12BD]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12BD,
 },
 [0x12BE]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXO",
  direction="l",
  linebreak="al",
  unicodeslot=0x12BE,
 },
 [0x12C0]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12C0,
 },
 [0x12C2]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12C2,
 },
 [0x12C3]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12C3,
 },
 [0x12C4]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12C4,
 },
 [0x12C5]={
  category="lo",
  description="ETHIOPIC SYLLABLE KXWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12C5,
 },
 [0x12C8]={
  category="lo",
  description="ETHIOPIC SYLLABLE WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12C8,
 },
 [0x12C9]={
  category="lo",
  description="ETHIOPIC SYLLABLE WU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12C9,
 },
 [0x12CA]={
  category="lo",
  description="ETHIOPIC SYLLABLE WI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12CA,
 },
 [0x12CB]={
  category="lo",
  description="ETHIOPIC SYLLABLE WAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12CB,
 },
 [0x12CC]={
  category="lo",
  description="ETHIOPIC SYLLABLE WEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12CC,
 },
 [0x12CD]={
  category="lo",
  description="ETHIOPIC SYLLABLE WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12CD,
 },
 [0x12CE]={
  category="lo",
  description="ETHIOPIC SYLLABLE WO",
  direction="l",
  linebreak="al",
  unicodeslot=0x12CE,
 },
 [0x12CF]={
  category="lo",
  description="ETHIOPIC SYLLABLE WOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12CF,
 },
 [0x12D0]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHARYNGEAL A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D0,
 },
 [0x12D1]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHARYNGEAL U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D1,
 },
 [0x12D2]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHARYNGEAL I",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D2,
 },
 [0x12D3]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHARYNGEAL AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D3,
 },
 [0x12D4]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHARYNGEAL EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D4,
 },
 [0x12D5]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHARYNGEAL E",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D5,
 },
 [0x12D6]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHARYNGEAL O",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D6,
 },
 [0x12D8]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D8,
 },
 [0x12D9]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12D9,
 },
 [0x12DA]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12DA,
 },
 [0x12DB]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12DB,
 },
 [0x12DC]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12DC,
 },
 [0x12DD]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12DD,
 },
 [0x12DE]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x12DE,
 },
 [0x12DF]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12DF,
 },
 [0x12E0]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E0,
 },
 [0x12E1]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E1,
 },
 [0x12E2]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E2,
 },
 [0x12E3]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E3,
 },
 [0x12E4]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E4,
 },
 [0x12E5]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E5,
 },
 [0x12E6]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E6,
 },
 [0x12E7]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZHWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E7,
 },
 [0x12E8]={
  category="lo",
  description="ETHIOPIC SYLLABLE YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E8,
 },
 [0x12E9]={
  category="lo",
  description="ETHIOPIC SYLLABLE YU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12E9,
 },
 [0x12EA]={
  category="lo",
  description="ETHIOPIC SYLLABLE YI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12EA,
 },
 [0x12EB]={
  category="lo",
  description="ETHIOPIC SYLLABLE YAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12EB,
 },
 [0x12EC]={
  category="lo",
  description="ETHIOPIC SYLLABLE YEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12EC,
 },
 [0x12ED]={
  category="lo",
  description="ETHIOPIC SYLLABLE YE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12ED,
 },
 [0x12EE]={
  category="lo",
  description="ETHIOPIC SYLLABLE YO",
  direction="l",
  linebreak="al",
  unicodeslot=0x12EE,
 },
 [0x12EF]={
  category="lo",
  description="ETHIOPIC SYLLABLE YOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12EF,
 },
 [0x12F0]={
  category="lo",
  description="ETHIOPIC SYLLABLE DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F0,
 },
 [0x12F1]={
  category="lo",
  description="ETHIOPIC SYLLABLE DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F1,
 },
 [0x12F2]={
  category="lo",
  description="ETHIOPIC SYLLABLE DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F2,
 },
 [0x12F3]={
  category="lo",
  description="ETHIOPIC SYLLABLE DAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F3,
 },
 [0x12F4]={
  category="lo",
  description="ETHIOPIC SYLLABLE DEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F4,
 },
 [0x12F5]={
  category="lo",
  description="ETHIOPIC SYLLABLE DE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F5,
 },
 [0x12F6]={
  category="lo",
  description="ETHIOPIC SYLLABLE DO",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F6,
 },
 [0x12F7]={
  category="lo",
  description="ETHIOPIC SYLLABLE DWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F7,
 },
 [0x12F8]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F8,
 },
 [0x12F9]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12F9,
 },
 [0x12FA]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12FA,
 },
 [0x12FB]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12FB,
 },
 [0x12FC]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12FC,
 },
 [0x12FD]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12FD,
 },
 [0x12FE]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDO",
  direction="l",
  linebreak="al",
  unicodeslot=0x12FE,
 },
 [0x12FF]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12FF,
 },
 [0x1300]={
  category="lo",
  description="ETHIOPIC SYLLABLE JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1300,
 },
 [0x1301]={
  category="lo",
  description="ETHIOPIC SYLLABLE JU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1301,
 },
 [0x1302]={
  category="lo",
  description="ETHIOPIC SYLLABLE JI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1302,
 },
 [0x1303]={
  category="lo",
  description="ETHIOPIC SYLLABLE JAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1303,
 },
 [0x1304]={
  category="lo",
  description="ETHIOPIC SYLLABLE JEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1304,
 },
 [0x1305]={
  category="lo",
  description="ETHIOPIC SYLLABLE JE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1305,
 },
 [0x1306]={
  category="lo",
  description="ETHIOPIC SYLLABLE JO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1306,
 },
 [0x1307]={
  category="lo",
  description="ETHIOPIC SYLLABLE JWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1307,
 },
 [0x1308]={
  category="lo",
  description="ETHIOPIC SYLLABLE GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1308,
 },
 [0x1309]={
  category="lo",
  description="ETHIOPIC SYLLABLE GU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1309,
 },
 [0x130A]={
  category="lo",
  description="ETHIOPIC SYLLABLE GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A,
 },
 [0x130B]={
  category="lo",
  description="ETHIOPIC SYLLABLE GAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B,
 },
 [0x130C]={
  category="lo",
  description="ETHIOPIC SYLLABLE GEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C,
 },
 [0x130D]={
  category="lo",
  description="ETHIOPIC SYLLABLE GE",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D,
 },
 [0x130E]={
  category="lo",
  description="ETHIOPIC SYLLABLE GO",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E,
 },
 [0x130F]={
  category="lo",
  description="ETHIOPIC SYLLABLE GOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F,
 },
 [0x1310]={
  category="lo",
  description="ETHIOPIC SYLLABLE GWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1310,
 },
 [0x1312]={
  category="lo",
  description="ETHIOPIC SYLLABLE GWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1312,
 },
 [0x1313]={
  category="lo",
  description="ETHIOPIC SYLLABLE GWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1313,
 },
 [0x1314]={
  category="lo",
  description="ETHIOPIC SYLLABLE GWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1314,
 },
 [0x1315]={
  category="lo",
  description="ETHIOPIC SYLLABLE GWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1315,
 },
 [0x1318]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1318,
 },
 [0x1319]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1319,
 },
 [0x131A]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A,
 },
 [0x131B]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B,
 },
 [0x131C]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C,
 },
 [0x131D]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGE",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D,
 },
 [0x131E]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGO",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E,
 },
 [0x131F]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F,
 },
 [0x1320]={
  category="lo",
  description="ETHIOPIC SYLLABLE THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1320,
 },
 [0x1321]={
  category="lo",
  description="ETHIOPIC SYLLABLE THU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1321,
 },
 [0x1322]={
  category="lo",
  description="ETHIOPIC SYLLABLE THI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1322,
 },
 [0x1323]={
  category="lo",
  description="ETHIOPIC SYLLABLE THAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1323,
 },
 [0x1324]={
  category="lo",
  description="ETHIOPIC SYLLABLE THEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1324,
 },
 [0x1325]={
  category="lo",
  description="ETHIOPIC SYLLABLE THE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1325,
 },
 [0x1326]={
  category="lo",
  description="ETHIOPIC SYLLABLE THO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1326,
 },
 [0x1327]={
  category="lo",
  description="ETHIOPIC SYLLABLE THWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1327,
 },
 [0x1328]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1328,
 },
 [0x1329]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1329,
 },
 [0x132A]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A,
 },
 [0x132B]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B,
 },
 [0x132C]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C,
 },
 [0x132D]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D,
 },
 [0x132E]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E,
 },
 [0x132F]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F,
 },
 [0x1330]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1330,
 },
 [0x1331]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1331,
 },
 [0x1332]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1332,
 },
 [0x1333]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1333,
 },
 [0x1334]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1334,
 },
 [0x1335]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1335,
 },
 [0x1336]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1336,
 },
 [0x1337]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1337,
 },
 [0x1338]={
  category="lo",
  description="ETHIOPIC SYLLABLE TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1338,
 },
 [0x1339]={
  category="lo",
  description="ETHIOPIC SYLLABLE TSU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1339,
 },
 [0x133A]={
  category="lo",
  description="ETHIOPIC SYLLABLE TSI",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A,
 },
 [0x133B]={
  category="lo",
  description="ETHIOPIC SYLLABLE TSAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B,
 },
 [0x133C]={
  category="lo",
  description="ETHIOPIC SYLLABLE TSEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C,
 },
 [0x133D]={
  category="lo",
  description="ETHIOPIC SYLLABLE TSE",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D,
 },
 [0x133E]={
  category="lo",
  description="ETHIOPIC SYLLABLE TSO",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E,
 },
 [0x133F]={
  category="lo",
  description="ETHIOPIC SYLLABLE TSWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F,
 },
 [0x1340]={
  category="lo",
  description="ETHIOPIC SYLLABLE TZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1340,
 },
 [0x1341]={
  category="lo",
  description="ETHIOPIC SYLLABLE TZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1341,
 },
 [0x1342]={
  category="lo",
  description="ETHIOPIC SYLLABLE TZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1342,
 },
 [0x1343]={
  category="lo",
  description="ETHIOPIC SYLLABLE TZAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1343,
 },
 [0x1344]={
  category="lo",
  description="ETHIOPIC SYLLABLE TZEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1344,
 },
 [0x1345]={
  category="lo",
  description="ETHIOPIC SYLLABLE TZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1345,
 },
 [0x1346]={
  category="lo",
  description="ETHIOPIC SYLLABLE TZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1346,
 },
 [0x1347]={
  category="lo",
  description="ETHIOPIC SYLLABLE TZOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1347,
 },
 [0x1348]={
  category="lo",
  description="ETHIOPIC SYLLABLE FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1348,
 },
 [0x1349]={
  category="lo",
  description="ETHIOPIC SYLLABLE FU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1349,
 },
 [0x134A]={
  category="lo",
  description="ETHIOPIC SYLLABLE FI",
  direction="l",
  linebreak="al",
  unicodeslot=0x134A,
 },
 [0x134B]={
  category="lo",
  description="ETHIOPIC SYLLABLE FAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x134B,
 },
 [0x134C]={
  category="lo",
  description="ETHIOPIC SYLLABLE FEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x134C,
 },
 [0x134D]={
  category="lo",
  description="ETHIOPIC SYLLABLE FE",
  direction="l",
  linebreak="al",
  unicodeslot=0x134D,
 },
 [0x134E]={
  category="lo",
  description="ETHIOPIC SYLLABLE FO",
  direction="l",
  linebreak="al",
  unicodeslot=0x134E,
 },
 [0x134F]={
  category="lo",
  description="ETHIOPIC SYLLABLE FWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x134F,
 },
 [0x1350]={
  category="lo",
  description="ETHIOPIC SYLLABLE PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1350,
 },
 [0x1351]={
  category="lo",
  description="ETHIOPIC SYLLABLE PU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1351,
 },
 [0x1352]={
  category="lo",
  description="ETHIOPIC SYLLABLE PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1352,
 },
 [0x1353]={
  category="lo",
  description="ETHIOPIC SYLLABLE PAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1353,
 },
 [0x1354]={
  category="lo",
  description="ETHIOPIC SYLLABLE PEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1354,
 },
 [0x1355]={
  category="lo",
  description="ETHIOPIC SYLLABLE PE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1355,
 },
 [0x1356]={
  category="lo",
  description="ETHIOPIC SYLLABLE PO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1356,
 },
 [0x1357]={
  category="lo",
  description="ETHIOPIC SYLLABLE PWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1357,
 },
 [0x1358]={
  category="lo",
  description="ETHIOPIC SYLLABLE RYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1358,
 },
 [0x1359]={
  category="lo",
  description="ETHIOPIC SYLLABLE MYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1359,
 },
 [0x135A]={
  category="lo",
  description="ETHIOPIC SYLLABLE FYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x135A,
 },
 [0x135D]={
  category="mn",
  description="ETHIOPIC COMBINING GEMINATION AND VOWEL LENGTH MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x135D,
 },
 [0x135E]={
  category="mn",
  description="ETHIOPIC COMBINING VOWEL LENGTH MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x135E,
 },
 [0x135F]={
  category="mn",
  description="ETHIOPIC COMBINING GEMINATION MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x135F,
 },
 [0x1360]={
  category="so",
  description="ETHIOPIC SECTION MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1360,
 },
 [0x1361]={
  category="po",
  description="ETHIOPIC WORDSPACE",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1361,
 },
 [0x1362]={
  category="po",
  description="ETHIOPIC FULL STOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1362,
 },
 [0x1363]={
  category="po",
  description="ETHIOPIC COMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1363,
 },
 [0x1364]={
  category="po",
  description="ETHIOPIC SEMICOLON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1364,
 },
 [0x1365]={
  category="po",
  description="ETHIOPIC COLON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1365,
 },
 [0x1366]={
  category="po",
  description="ETHIOPIC PREFACE COLON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1366,
 },
 [0x1367]={
  category="po",
  description="ETHIOPIC QUESTION MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1367,
 },
 [0x1368]={
  category="po",
  description="ETHIOPIC PARAGRAPH SEPARATOR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1368,
 },
 [0x1369]={
  category="no",
  description="ETHIOPIC DIGIT ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1369,
 },
 [0x136A]={
  category="no",
  description="ETHIOPIC DIGIT TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x136A,
 },
 [0x136B]={
  category="no",
  description="ETHIOPIC DIGIT THREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x136B,
 },
 [0x136C]={
  category="no",
  description="ETHIOPIC DIGIT FOUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x136C,
 },
 [0x136D]={
  category="no",
  description="ETHIOPIC DIGIT FIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x136D,
 },
 [0x136E]={
  category="no",
  description="ETHIOPIC DIGIT SIX",
  direction="l",
  linebreak="al",
  unicodeslot=0x136E,
 },
 [0x136F]={
  category="no",
  description="ETHIOPIC DIGIT SEVEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x136F,
 },
 [0x1370]={
  category="no",
  description="ETHIOPIC DIGIT EIGHT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1370,
 },
 [0x1371]={
  category="no",
  description="ETHIOPIC DIGIT NINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1371,
 },
 [0x1372]={
  category="no",
  description="ETHIOPIC NUMBER TEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1372,
 },
 [0x1373]={
  category="no",
  description="ETHIOPIC NUMBER TWENTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1373,
 },
 [0x1374]={
  category="no",
  description="ETHIOPIC NUMBER THIRTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1374,
 },
 [0x1375]={
  category="no",
  description="ETHIOPIC NUMBER FORTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1375,
 },
 [0x1376]={
  category="no",
  description="ETHIOPIC NUMBER FIFTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1376,
 },
 [0x1377]={
  category="no",
  description="ETHIOPIC NUMBER SIXTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1377,
 },
 [0x1378]={
  category="no",
  description="ETHIOPIC NUMBER SEVENTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1378,
 },
 [0x1379]={
  category="no",
  description="ETHIOPIC NUMBER EIGHTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1379,
 },
 [0x137A]={
  category="no",
  description="ETHIOPIC NUMBER NINETY",
  direction="l",
  linebreak="al",
  unicodeslot=0x137A,
 },
 [0x137B]={
  category="no",
  description="ETHIOPIC NUMBER HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x137B,
 },
 [0x137C]={
  category="no",
  description="ETHIOPIC NUMBER TEN THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x137C,
 },
 [0x1380]={
  category="lo",
  description="ETHIOPIC SYLLABLE SEBATBEIT MWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1380,
 },
 [0x1381]={
  category="lo",
  description="ETHIOPIC SYLLABLE MWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1381,
 },
 [0x1382]={
  category="lo",
  description="ETHIOPIC SYLLABLE MWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1382,
 },
 [0x1383]={
  category="lo",
  description="ETHIOPIC SYLLABLE MWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1383,
 },
 [0x1384]={
  category="lo",
  description="ETHIOPIC SYLLABLE SEBATBEIT BWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1384,
 },
 [0x1385]={
  category="lo",
  description="ETHIOPIC SYLLABLE BWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1385,
 },
 [0x1386]={
  category="lo",
  description="ETHIOPIC SYLLABLE BWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1386,
 },
 [0x1387]={
  category="lo",
  description="ETHIOPIC SYLLABLE BWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1387,
 },
 [0x1388]={
  category="lo",
  description="ETHIOPIC SYLLABLE SEBATBEIT FWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1388,
 },
 [0x1389]={
  category="lo",
  description="ETHIOPIC SYLLABLE FWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1389,
 },
 [0x138A]={
  category="lo",
  description="ETHIOPIC SYLLABLE FWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x138A,
 },
 [0x138B]={
  category="lo",
  description="ETHIOPIC SYLLABLE FWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x138B,
 },
 [0x138C]={
  category="lo",
  description="ETHIOPIC SYLLABLE SEBATBEIT PWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x138C,
 },
 [0x138D]={
  category="lo",
  description="ETHIOPIC SYLLABLE PWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x138D,
 },
 [0x138E]={
  category="lo",
  description="ETHIOPIC SYLLABLE PWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x138E,
 },
 [0x138F]={
  category="lo",
  description="ETHIOPIC SYLLABLE PWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x138F,
 },
 [0x1390]={
  category="so",
  description="ETHIOPIC TONAL MARK YIZET",
  direction="on",
  linebreak="al",
  unicodeslot=0x1390,
 },
 [0x1391]={
  category="so",
  description="ETHIOPIC TONAL MARK DERET",
  direction="on",
  linebreak="al",
  unicodeslot=0x1391,
 },
 [0x1392]={
  category="so",
  description="ETHIOPIC TONAL MARK RIKRIK",
  direction="on",
  linebreak="al",
  unicodeslot=0x1392,
 },
 [0x1393]={
  category="so",
  description="ETHIOPIC TONAL MARK SHORT RIKRIK",
  direction="on",
  linebreak="al",
  unicodeslot=0x1393,
 },
 [0x1394]={
  category="so",
  description="ETHIOPIC TONAL MARK DIFAT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1394,
 },
 [0x1395]={
  category="so",
  description="ETHIOPIC TONAL MARK KENAT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1395,
 },
 [0x1396]={
  category="so",
  description="ETHIOPIC TONAL MARK CHIRET",
  direction="on",
  linebreak="al",
  unicodeslot=0x1396,
 },
 [0x1397]={
  category="so",
  description="ETHIOPIC TONAL MARK HIDET",
  direction="on",
  linebreak="al",
  unicodeslot=0x1397,
 },
 [0x1398]={
  category="so",
  description="ETHIOPIC TONAL MARK DERET-HIDET",
  direction="on",
  linebreak="al",
  unicodeslot=0x1398,
 },
 [0x1399]={
  category="so",
  description="ETHIOPIC TONAL MARK KURT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1399,
 },
 [0x13A0]={
  category="lo",
  description="CHEROKEE LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A0,
 },
 [0x13A1]={
  category="lo",
  description="CHEROKEE LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A1,
 },
 [0x13A2]={
  category="lo",
  description="CHEROKEE LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A2,
 },
 [0x13A3]={
  category="lo",
  description="CHEROKEE LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A3,
 },
 [0x13A4]={
  category="lo",
  description="CHEROKEE LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A4,
 },
 [0x13A5]={
  category="lo",
  description="CHEROKEE LETTER V",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A5,
 },
 [0x13A6]={
  category="lo",
  description="CHEROKEE LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A6,
 },
 [0x13A7]={
  category="lo",
  description="CHEROKEE LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A7,
 },
 [0x13A8]={
  category="lo",
  description="CHEROKEE LETTER GE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A8,
 },
 [0x13A9]={
  category="lo",
  description="CHEROKEE LETTER GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13A9,
 },
 [0x13AA]={
  category="lo",
  description="CHEROKEE LETTER GO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13AA,
 },
 [0x13AB]={
  category="lo",
  description="CHEROKEE LETTER GU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13AB,
 },
 [0x13AC]={
  category="lo",
  description="CHEROKEE LETTER GV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13AC,
 },
 [0x13AD]={
  category="lo",
  description="CHEROKEE LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13AD,
 },
 [0x13AE]={
  category="lo",
  description="CHEROKEE LETTER HE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13AE,
 },
 [0x13AF]={
  category="lo",
  description="CHEROKEE LETTER HI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13AF,
 },
 [0x13B0]={
  category="lo",
  description="CHEROKEE LETTER HO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B0,
 },
 [0x13B1]={
  category="lo",
  description="CHEROKEE LETTER HU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B1,
 },
 [0x13B2]={
  category="lo",
  description="CHEROKEE LETTER HV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B2,
 },
 [0x13B3]={
  category="lo",
  description="CHEROKEE LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B3,
 },
 [0x13B4]={
  category="lo",
  description="CHEROKEE LETTER LE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B4,
 },
 [0x13B5]={
  category="lo",
  description="CHEROKEE LETTER LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B5,
 },
 [0x13B6]={
  category="lo",
  description="CHEROKEE LETTER LO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B6,
 },
 [0x13B7]={
  category="lo",
  description="CHEROKEE LETTER LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B7,
 },
 [0x13B8]={
  category="lo",
  description="CHEROKEE LETTER LV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B8,
 },
 [0x13B9]={
  category="lo",
  description="CHEROKEE LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13B9,
 },
 [0x13BA]={
  category="lo",
  description="CHEROKEE LETTER ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x13BA,
 },
 [0x13BB]={
  category="lo",
  description="CHEROKEE LETTER MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13BB,
 },
 [0x13BC]={
  category="lo",
  description="CHEROKEE LETTER MO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13BC,
 },
 [0x13BD]={
  category="lo",
  description="CHEROKEE LETTER MU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13BD,
 },
 [0x13BE]={
  category="lo",
  description="CHEROKEE LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13BE,
 },
 [0x13BF]={
  category="lo",
  description="CHEROKEE LETTER HNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13BF,
 },
 [0x13C0]={
  category="lo",
  description="CHEROKEE LETTER NAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C0,
 },
 [0x13C1]={
  category="lo",
  description="CHEROKEE LETTER NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C1,
 },
 [0x13C2]={
  category="lo",
  description="CHEROKEE LETTER NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C2,
 },
 [0x13C3]={
  category="lo",
  description="CHEROKEE LETTER NO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C3,
 },
 [0x13C4]={
  category="lo",
  description="CHEROKEE LETTER NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C4,
 },
 [0x13C5]={
  category="lo",
  description="CHEROKEE LETTER NV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C5,
 },
 [0x13C6]={
  category="lo",
  description="CHEROKEE LETTER QUA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C6,
 },
 [0x13C7]={
  category="lo",
  description="CHEROKEE LETTER QUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C7,
 },
 [0x13C8]={
  category="lo",
  description="CHEROKEE LETTER QUI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C8,
 },
 [0x13C9]={
  category="lo",
  description="CHEROKEE LETTER QUO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13C9,
 },
 [0x13CA]={
  category="lo",
  description="CHEROKEE LETTER QUU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13CA,
 },
 [0x13CB]={
  category="lo",
  description="CHEROKEE LETTER QUV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13CB,
 },
 [0x13CC]={
  category="lo",
  description="CHEROKEE LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13CC,
 },
 [0x13CD]={
  category="lo",
  description="CHEROKEE LETTER S",
  direction="l",
  linebreak="al",
  unicodeslot=0x13CD,
 },
 [0x13CE]={
  category="lo",
  description="CHEROKEE LETTER SE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13CE,
 },
 [0x13CF]={
  category="lo",
  description="CHEROKEE LETTER SI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13CF,
 },
 [0x13D0]={
  category="lo",
  description="CHEROKEE LETTER SO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D0,
 },
 [0x13D1]={
  category="lo",
  description="CHEROKEE LETTER SU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D1,
 },
 [0x13D2]={
  category="lo",
  description="CHEROKEE LETTER SV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D2,
 },
 [0x13D3]={
  category="lo",
  description="CHEROKEE LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D3,
 },
 [0x13D4]={
  category="lo",
  description="CHEROKEE LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D4,
 },
 [0x13D5]={
  category="lo",
  description="CHEROKEE LETTER DE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D5,
 },
 [0x13D6]={
  category="lo",
  description="CHEROKEE LETTER TE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D6,
 },
 [0x13D7]={
  category="lo",
  description="CHEROKEE LETTER DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D7,
 },
 [0x13D8]={
  category="lo",
  description="CHEROKEE LETTER TI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D8,
 },
 [0x13D9]={
  category="lo",
  description="CHEROKEE LETTER DO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13D9,
 },
 [0x13DA]={
  category="lo",
  description="CHEROKEE LETTER DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13DA,
 },
 [0x13DB]={
  category="lo",
  description="CHEROKEE LETTER DV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13DB,
 },
 [0x13DC]={
  category="lo",
  description="CHEROKEE LETTER DLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13DC,
 },
 [0x13DD]={
  category="lo",
  description="CHEROKEE LETTER TLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13DD,
 },
 [0x13DE]={
  category="lo",
  description="CHEROKEE LETTER TLE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13DE,
 },
 [0x13DF]={
  category="lo",
  description="CHEROKEE LETTER TLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13DF,
 },
 [0x13E0]={
  category="lo",
  description="CHEROKEE LETTER TLO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E0,
 },
 [0x13E1]={
  category="lo",
  description="CHEROKEE LETTER TLU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E1,
 },
 [0x13E2]={
  category="lo",
  description="CHEROKEE LETTER TLV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E2,
 },
 [0x13E3]={
  category="lo",
  description="CHEROKEE LETTER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E3,
 },
 [0x13E4]={
  category="lo",
  description="CHEROKEE LETTER TSE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E4,
 },
 [0x13E5]={
  category="lo",
  description="CHEROKEE LETTER TSI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E5,
 },
 [0x13E6]={
  category="lo",
  description="CHEROKEE LETTER TSO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E6,
 },
 [0x13E7]={
  category="lo",
  description="CHEROKEE LETTER TSU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E7,
 },
 [0x13E8]={
  category="lo",
  description="CHEROKEE LETTER TSV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E8,
 },
 [0x13E9]={
  category="lo",
  description="CHEROKEE LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13E9,
 },
 [0x13EA]={
  category="lo",
  description="CHEROKEE LETTER WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13EA,
 },
 [0x13EB]={
  category="lo",
  description="CHEROKEE LETTER WI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13EB,
 },
 [0x13EC]={
  category="lo",
  description="CHEROKEE LETTER WO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13EC,
 },
 [0x13ED]={
  category="lo",
  description="CHEROKEE LETTER WU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13ED,
 },
 [0x13EE]={
  category="lo",
  description="CHEROKEE LETTER WV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13EE,
 },
 [0x13EF]={
  category="lo",
  description="CHEROKEE LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x13EF,
 },
 [0x13F0]={
  category="lo",
  description="CHEROKEE LETTER YE",
  direction="l",
  linebreak="al",
  unicodeslot=0x13F0,
 },
 [0x13F1]={
  category="lo",
  description="CHEROKEE LETTER YI",
  direction="l",
  linebreak="al",
  unicodeslot=0x13F1,
 },
 [0x13F2]={
  category="lo",
  description="CHEROKEE LETTER YO",
  direction="l",
  linebreak="al",
  unicodeslot=0x13F2,
 },
 [0x13F3]={
  category="lo",
  description="CHEROKEE LETTER YU",
  direction="l",
  linebreak="al",
  unicodeslot=0x13F3,
 },
 [0x13F4]={
  category="lo",
  description="CHEROKEE LETTER YV",
  direction="l",
  linebreak="al",
  unicodeslot=0x13F4,
 },
 [0x1400]={
  category="pd",
  description="CANADIAN SYLLABICS HYPHEN",
  direction="on",
  linebreak="ba",
  unicodeslot=0x1400,
 },
 [0x1401]={
  category="lo",
  description="CANADIAN SYLLABICS E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1401,
 },
 [0x1402]={
  category="lo",
  description="CANADIAN SYLLABICS AAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1402,
 },
 [0x1403]={
  category="lo",
  description="CANADIAN SYLLABICS I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1403,
 },
 [0x1404]={
  category="lo",
  description="CANADIAN SYLLABICS II",
  direction="l",
  linebreak="al",
  unicodeslot=0x1404,
 },
 [0x1405]={
  category="lo",
  description="CANADIAN SYLLABICS O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1405,
 },
 [0x1406]={
  category="lo",
  description="CANADIAN SYLLABICS OO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1406,
 },
 [0x1407]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE OO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1407,
 },
 [0x1408]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1408,
 },
 [0x1409]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1409,
 },
 [0x140A]={
  category="lo",
  description="CANADIAN SYLLABICS A",
  direction="l",
  linebreak="al",
  unicodeslot=0x140A,
 },
 [0x140B]={
  category="lo",
  description="CANADIAN SYLLABICS AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x140B,
 },
 [0x140C]={
  category="lo",
  description="CANADIAN SYLLABICS WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x140C,
 },
 [0x140D]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x140D,
 },
 [0x140E]={
  category="lo",
  description="CANADIAN SYLLABICS WI",
  direction="l",
  linebreak="al",
  unicodeslot=0x140E,
 },
 [0x140F]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE WI",
  direction="l",
  linebreak="al",
  unicodeslot=0x140F,
 },
 [0x1410]={
  category="lo",
  description="CANADIAN SYLLABICS WII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1410,
 },
 [0x1411]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE WII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1411,
 },
 [0x1412]={
  category="lo",
  description="CANADIAN SYLLABICS WO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1412,
 },
 [0x1413]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE WO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1413,
 },
 [0x1414]={
  category="lo",
  description="CANADIAN SYLLABICS WOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1414,
 },
 [0x1415]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE WOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1415,
 },
 [0x1416]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI WOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1416,
 },
 [0x1417]={
  category="lo",
  description="CANADIAN SYLLABICS WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1417,
 },
 [0x1418]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1418,
 },
 [0x1419]={
  category="lo",
  description="CANADIAN SYLLABICS WAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1419,
 },
 [0x141A]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE WAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x141A,
 },
 [0x141B]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI WAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x141B,
 },
 [0x141C]={
  category="lo",
  description="CANADIAN SYLLABICS AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x141C,
 },
 [0x141D]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE W",
  direction="l",
  linebreak="al",
  unicodeslot=0x141D,
 },
 [0x141E]={
  category="lo",
  description="CANADIAN SYLLABICS GLOTTAL STOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x141E,
 },
 [0x141F]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL ACUTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x141F,
 },
 [0x1420]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL GRAVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1420,
 },
 [0x1421]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL BOTTOM HALF RING",
  direction="l",
  linebreak="al",
  unicodeslot=0x1421,
 },
 [0x1422]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL TOP HALF RING",
  direction="l",
  linebreak="al",
  unicodeslot=0x1422,
 },
 [0x1423]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL RIGHT HALF RING",
  direction="l",
  linebreak="al",
  unicodeslot=0x1423,
 },
 [0x1424]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL RING",
  direction="l",
  linebreak="al",
  unicodeslot=0x1424,
 },
 [0x1425]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL DOUBLE ACUTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1425,
 },
 [0x1426]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL DOUBLE SHORT VERTICAL STROKES",
  direction="l",
  linebreak="al",
  unicodeslot=0x1426,
 },
 [0x1427]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL MIDDLE DOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1427,
 },
 [0x1428]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL SHORT HORIZONTAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1428,
 },
 [0x1429]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL PLUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1429,
 },
 [0x142A]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL DOWN TACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x142A,
 },
 [0x142B]={
  category="lo",
  description="CANADIAN SYLLABICS EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x142B,
 },
 [0x142C]={
  category="lo",
  description="CANADIAN SYLLABICS IN",
  direction="l",
  linebreak="al",
  unicodeslot=0x142C,
 },
 [0x142D]={
  category="lo",
  description="CANADIAN SYLLABICS ON",
  direction="l",
  linebreak="al",
  unicodeslot=0x142D,
 },
 [0x142E]={
  category="lo",
  description="CANADIAN SYLLABICS AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x142E,
 },
 [0x142F]={
  category="lo",
  description="CANADIAN SYLLABICS PE",
  direction="l",
  linebreak="al",
  unicodeslot=0x142F,
 },
 [0x1430]={
  category="lo",
  description="CANADIAN SYLLABICS PAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1430,
 },
 [0x1431]={
  category="lo",
  description="CANADIAN SYLLABICS PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1431,
 },
 [0x1432]={
  category="lo",
  description="CANADIAN SYLLABICS PII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1432,
 },
 [0x1433]={
  category="lo",
  description="CANADIAN SYLLABICS PO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1433,
 },
 [0x1434]={
  category="lo",
  description="CANADIAN SYLLABICS POO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1434,
 },
 [0x1435]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE POO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1435,
 },
 [0x1436]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER HEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1436,
 },
 [0x1437]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER HI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1437,
 },
 [0x1438]={
  category="lo",
  description="CANADIAN SYLLABICS PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1438,
 },
 [0x1439]={
  category="lo",
  description="CANADIAN SYLLABICS PAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1439,
 },
 [0x143A]={
  category="lo",
  description="CANADIAN SYLLABICS PWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x143A,
 },
 [0x143B]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE PWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x143B,
 },
 [0x143C]={
  category="lo",
  description="CANADIAN SYLLABICS PWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x143C,
 },
 [0x143D]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE PWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x143D,
 },
 [0x143E]={
  category="lo",
  description="CANADIAN SYLLABICS PWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x143E,
 },
 [0x143F]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE PWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x143F,
 },
 [0x1440]={
  category="lo",
  description="CANADIAN SYLLABICS PWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1440,
 },
 [0x1441]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE PWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1441,
 },
 [0x1442]={
  category="lo",
  description="CANADIAN SYLLABICS PWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1442,
 },
 [0x1443]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE PWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1443,
 },
 [0x1444]={
  category="lo",
  description="CANADIAN SYLLABICS PWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1444,
 },
 [0x1445]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE PWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1445,
 },
 [0x1446]={
  category="lo",
  description="CANADIAN SYLLABICS PWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1446,
 },
 [0x1447]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE PWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1447,
 },
 [0x1448]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE PWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1448,
 },
 [0x1449]={
  category="lo",
  description="CANADIAN SYLLABICS P",
  direction="l",
  linebreak="al",
  unicodeslot=0x1449,
 },
 [0x144A]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE P",
  direction="l",
  linebreak="al",
  unicodeslot=0x144A,
 },
 [0x144B]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER H",
  direction="l",
  linebreak="al",
  unicodeslot=0x144B,
 },
 [0x144C]={
  category="lo",
  description="CANADIAN SYLLABICS TE",
  direction="l",
  linebreak="al",
  unicodeslot=0x144C,
 },
 [0x144D]={
  category="lo",
  description="CANADIAN SYLLABICS TAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x144D,
 },
 [0x144E]={
  category="lo",
  description="CANADIAN SYLLABICS TI",
  direction="l",
  linebreak="al",
  unicodeslot=0x144E,
 },
 [0x144F]={
  category="lo",
  description="CANADIAN SYLLABICS TII",
  direction="l",
  linebreak="al",
  unicodeslot=0x144F,
 },
 [0x1450]={
  category="lo",
  description="CANADIAN SYLLABICS TO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1450,
 },
 [0x1451]={
  category="lo",
  description="CANADIAN SYLLABICS TOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1451,
 },
 [0x1452]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE TOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1452,
 },
 [0x1453]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1453,
 },
 [0x1454]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1454,
 },
 [0x1455]={
  category="lo",
  description="CANADIAN SYLLABICS TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1455,
 },
 [0x1456]={
  category="lo",
  description="CANADIAN SYLLABICS TAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1456,
 },
 [0x1457]={
  category="lo",
  description="CANADIAN SYLLABICS TWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1457,
 },
 [0x1458]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE TWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1458,
 },
 [0x1459]={
  category="lo",
  description="CANADIAN SYLLABICS TWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1459,
 },
 [0x145A]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE TWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x145A,
 },
 [0x145B]={
  category="lo",
  description="CANADIAN SYLLABICS TWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x145B,
 },
 [0x145C]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE TWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x145C,
 },
 [0x145D]={
  category="lo",
  description="CANADIAN SYLLABICS TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x145D,
 },
 [0x145E]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x145E,
 },
 [0x145F]={
  category="lo",
  description="CANADIAN SYLLABICS TWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x145F,
 },
 [0x1460]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE TWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1460,
 },
 [0x1461]={
  category="lo",
  description="CANADIAN SYLLABICS TWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1461,
 },
 [0x1462]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE TWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1462,
 },
 [0x1463]={
  category="lo",
  description="CANADIAN SYLLABICS TWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1463,
 },
 [0x1464]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE TWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1464,
 },
 [0x1465]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI TWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1465,
 },
 [0x1466]={
  category="lo",
  description="CANADIAN SYLLABICS T",
  direction="l",
  linebreak="al",
  unicodeslot=0x1466,
 },
 [0x1467]={
  category="lo",
  description="CANADIAN SYLLABICS TTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1467,
 },
 [0x1468]={
  category="lo",
  description="CANADIAN SYLLABICS TTI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1468,
 },
 [0x1469]={
  category="lo",
  description="CANADIAN SYLLABICS TTO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1469,
 },
 [0x146A]={
  category="lo",
  description="CANADIAN SYLLABICS TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x146A,
 },
 [0x146B]={
  category="lo",
  description="CANADIAN SYLLABICS KE",
  direction="l",
  linebreak="al",
  unicodeslot=0x146B,
 },
 [0x146C]={
  category="lo",
  description="CANADIAN SYLLABICS KAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x146C,
 },
 [0x146D]={
  category="lo",
  description="CANADIAN SYLLABICS KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x146D,
 },
 [0x146E]={
  category="lo",
  description="CANADIAN SYLLABICS KII",
  direction="l",
  linebreak="al",
  unicodeslot=0x146E,
 },
 [0x146F]={
  category="lo",
  description="CANADIAN SYLLABICS KO",
  direction="l",
  linebreak="al",
  unicodeslot=0x146F,
 },
 [0x1470]={
  category="lo",
  description="CANADIAN SYLLABICS KOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1470,
 },
 [0x1471]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE KOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1471,
 },
 [0x1472]={
  category="lo",
  description="CANADIAN SYLLABICS KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1472,
 },
 [0x1473]={
  category="lo",
  description="CANADIAN SYLLABICS KAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1473,
 },
 [0x1474]={
  category="lo",
  description="CANADIAN SYLLABICS KWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1474,
 },
 [0x1475]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE KWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1475,
 },
 [0x1476]={
  category="lo",
  description="CANADIAN SYLLABICS KWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1476,
 },
 [0x1477]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE KWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1477,
 },
 [0x1478]={
  category="lo",
  description="CANADIAN SYLLABICS KWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1478,
 },
 [0x1479]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE KWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1479,
 },
 [0x147A]={
  category="lo",
  description="CANADIAN SYLLABICS KWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x147A,
 },
 [0x147B]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE KWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x147B,
 },
 [0x147C]={
  category="lo",
  description="CANADIAN SYLLABICS KWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x147C,
 },
 [0x147D]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE KWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x147D,
 },
 [0x147E]={
  category="lo",
  description="CANADIAN SYLLABICS KWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x147E,
 },
 [0x147F]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE KWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x147F,
 },
 [0x1480]={
  category="lo",
  description="CANADIAN SYLLABICS KWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1480,
 },
 [0x1481]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE KWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1481,
 },
 [0x1482]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI KWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1482,
 },
 [0x1483]={
  category="lo",
  description="CANADIAN SYLLABICS K",
  direction="l",
  linebreak="al",
  unicodeslot=0x1483,
 },
 [0x1484]={
  category="lo",
  description="CANADIAN SYLLABICS KW",
  direction="l",
  linebreak="al",
  unicodeslot=0x1484,
 },
 [0x1485]={
  category="lo",
  description="CANADIAN SYLLABICS SOUTH-SLAVEY KEH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1485,
 },
 [0x1486]={
  category="lo",
  description="CANADIAN SYLLABICS SOUTH-SLAVEY KIH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1486,
 },
 [0x1487]={
  category="lo",
  description="CANADIAN SYLLABICS SOUTH-SLAVEY KOH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1487,
 },
 [0x1488]={
  category="lo",
  description="CANADIAN SYLLABICS SOUTH-SLAVEY KAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1488,
 },
 [0x1489]={
  category="lo",
  description="CANADIAN SYLLABICS CE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1489,
 },
 [0x148A]={
  category="lo",
  description="CANADIAN SYLLABICS CAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x148A,
 },
 [0x148B]={
  category="lo",
  description="CANADIAN SYLLABICS CI",
  direction="l",
  linebreak="al",
  unicodeslot=0x148B,
 },
 [0x148C]={
  category="lo",
  description="CANADIAN SYLLABICS CII",
  direction="l",
  linebreak="al",
  unicodeslot=0x148C,
 },
 [0x148D]={
  category="lo",
  description="CANADIAN SYLLABICS CO",
  direction="l",
  linebreak="al",
  unicodeslot=0x148D,
 },
 [0x148E]={
  category="lo",
  description="CANADIAN SYLLABICS COO",
  direction="l",
  linebreak="al",
  unicodeslot=0x148E,
 },
 [0x148F]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE COO",
  direction="l",
  linebreak="al",
  unicodeslot=0x148F,
 },
 [0x1490]={
  category="lo",
  description="CANADIAN SYLLABICS CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1490,
 },
 [0x1491]={
  category="lo",
  description="CANADIAN SYLLABICS CAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1491,
 },
 [0x1492]={
  category="lo",
  description="CANADIAN SYLLABICS CWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1492,
 },
 [0x1493]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE CWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1493,
 },
 [0x1494]={
  category="lo",
  description="CANADIAN SYLLABICS CWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1494,
 },
 [0x1495]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE CWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1495,
 },
 [0x1496]={
  category="lo",
  description="CANADIAN SYLLABICS CWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1496,
 },
 [0x1497]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE CWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1497,
 },
 [0x1498]={
  category="lo",
  description="CANADIAN SYLLABICS CWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1498,
 },
 [0x1499]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE CWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1499,
 },
 [0x149A]={
  category="lo",
  description="CANADIAN SYLLABICS CWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x149A,
 },
 [0x149B]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE CWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x149B,
 },
 [0x149C]={
  category="lo",
  description="CANADIAN SYLLABICS CWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x149C,
 },
 [0x149D]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE CWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x149D,
 },
 [0x149E]={
  category="lo",
  description="CANADIAN SYLLABICS CWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x149E,
 },
 [0x149F]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE CWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x149F,
 },
 [0x14A0]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI CWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A0,
 },
 [0x14A1]={
  category="lo",
  description="CANADIAN SYLLABICS C",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A1,
 },
 [0x14A2]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI TH",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A2,
 },
 [0x14A3]={
  category="lo",
  description="CANADIAN SYLLABICS ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A3,
 },
 [0x14A4]={
  category="lo",
  description="CANADIAN SYLLABICS MAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A4,
 },
 [0x14A5]={
  category="lo",
  description="CANADIAN SYLLABICS MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A5,
 },
 [0x14A6]={
  category="lo",
  description="CANADIAN SYLLABICS MII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A6,
 },
 [0x14A7]={
  category="lo",
  description="CANADIAN SYLLABICS MO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A7,
 },
 [0x14A8]={
  category="lo",
  description="CANADIAN SYLLABICS MOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A8,
 },
 [0x14A9]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE MOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14A9,
 },
 [0x14AA]={
  category="lo",
  description="CANADIAN SYLLABICS MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14AA,
 },
 [0x14AB]={
  category="lo",
  description="CANADIAN SYLLABICS MAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14AB,
 },
 [0x14AC]={
  category="lo",
  description="CANADIAN SYLLABICS MWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14AC,
 },
 [0x14AD]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE MWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14AD,
 },
 [0x14AE]={
  category="lo",
  description="CANADIAN SYLLABICS MWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14AE,
 },
 [0x14AF]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE MWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14AF,
 },
 [0x14B0]={
  category="lo",
  description="CANADIAN SYLLABICS MWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B0,
 },
 [0x14B1]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE MWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B1,
 },
 [0x14B2]={
  category="lo",
  description="CANADIAN SYLLABICS MWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B2,
 },
 [0x14B3]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE MWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B3,
 },
 [0x14B4]={
  category="lo",
  description="CANADIAN SYLLABICS MWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B4,
 },
 [0x14B5]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE MWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B5,
 },
 [0x14B6]={
  category="lo",
  description="CANADIAN SYLLABICS MWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B6,
 },
 [0x14B7]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE MWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B7,
 },
 [0x14B8]={
  category="lo",
  description="CANADIAN SYLLABICS MWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B8,
 },
 [0x14B9]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE MWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14B9,
 },
 [0x14BA]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI MWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14BA,
 },
 [0x14BB]={
  category="lo",
  description="CANADIAN SYLLABICS M",
  direction="l",
  linebreak="al",
  unicodeslot=0x14BB,
 },
 [0x14BC]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE M",
  direction="l",
  linebreak="al",
  unicodeslot=0x14BC,
 },
 [0x14BD]={
  category="lo",
  description="CANADIAN SYLLABICS MH",
  direction="l",
  linebreak="al",
  unicodeslot=0x14BD,
 },
 [0x14BE]={
  category="lo",
  description="CANADIAN SYLLABICS ATHAPASCAN M",
  direction="l",
  linebreak="al",
  unicodeslot=0x14BE,
 },
 [0x14BF]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI M",
  direction="l",
  linebreak="al",
  unicodeslot=0x14BF,
 },
 [0x14C0]={
  category="lo",
  description="CANADIAN SYLLABICS NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C0,
 },
 [0x14C1]={
  category="lo",
  description="CANADIAN SYLLABICS NAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C1,
 },
 [0x14C2]={
  category="lo",
  description="CANADIAN SYLLABICS NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C2,
 },
 [0x14C3]={
  category="lo",
  description="CANADIAN SYLLABICS NII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C3,
 },
 [0x14C4]={
  category="lo",
  description="CANADIAN SYLLABICS NO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C4,
 },
 [0x14C5]={
  category="lo",
  description="CANADIAN SYLLABICS NOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C5,
 },
 [0x14C6]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE NOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C6,
 },
 [0x14C7]={
  category="lo",
  description="CANADIAN SYLLABICS NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C7,
 },
 [0x14C8]={
  category="lo",
  description="CANADIAN SYLLABICS NAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C8,
 },
 [0x14C9]={
  category="lo",
  description="CANADIAN SYLLABICS NWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14C9,
 },
 [0x14CA]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE NWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14CA,
 },
 [0x14CB]={
  category="lo",
  description="CANADIAN SYLLABICS NWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14CB,
 },
 [0x14CC]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE NWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14CC,
 },
 [0x14CD]={
  category="lo",
  description="CANADIAN SYLLABICS NWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14CD,
 },
 [0x14CE]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE NWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14CE,
 },
 [0x14CF]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI NWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14CF,
 },
 [0x14D0]={
  category="lo",
  description="CANADIAN SYLLABICS N",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D0,
 },
 [0x14D1]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER NG",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D1,
 },
 [0x14D2]={
  category="lo",
  description="CANADIAN SYLLABICS NH",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D2,
 },
 [0x14D3]={
  category="lo",
  description="CANADIAN SYLLABICS LE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D3,
 },
 [0x14D4]={
  category="lo",
  description="CANADIAN SYLLABICS LAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D4,
 },
 [0x14D5]={
  category="lo",
  description="CANADIAN SYLLABICS LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D5,
 },
 [0x14D6]={
  category="lo",
  description="CANADIAN SYLLABICS LII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D6,
 },
 [0x14D7]={
  category="lo",
  description="CANADIAN SYLLABICS LO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D7,
 },
 [0x14D8]={
  category="lo",
  description="CANADIAN SYLLABICS LOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D8,
 },
 [0x14D9]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE LOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14D9,
 },
 [0x14DA]={
  category="lo",
  description="CANADIAN SYLLABICS LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14DA,
 },
 [0x14DB]={
  category="lo",
  description="CANADIAN SYLLABICS LAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14DB,
 },
 [0x14DC]={
  category="lo",
  description="CANADIAN SYLLABICS LWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14DC,
 },
 [0x14DD]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14DD,
 },
 [0x14DE]={
  category="lo",
  description="CANADIAN SYLLABICS LWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14DE,
 },
 [0x14DF]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14DF,
 },
 [0x14E0]={
  category="lo",
  description="CANADIAN SYLLABICS LWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E0,
 },
 [0x14E1]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E1,
 },
 [0x14E2]={
  category="lo",
  description="CANADIAN SYLLABICS LWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E2,
 },
 [0x14E3]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E3,
 },
 [0x14E4]={
  category="lo",
  description="CANADIAN SYLLABICS LWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E4,
 },
 [0x14E5]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E5,
 },
 [0x14E6]={
  category="lo",
  description="CANADIAN SYLLABICS LWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E6,
 },
 [0x14E7]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E7,
 },
 [0x14E8]={
  category="lo",
  description="CANADIAN SYLLABICS LWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E8,
 },
 [0x14E9]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14E9,
 },
 [0x14EA]={
  category="lo",
  description="CANADIAN SYLLABICS L",
  direction="l",
  linebreak="al",
  unicodeslot=0x14EA,
 },
 [0x14EB]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE L",
  direction="l",
  linebreak="al",
  unicodeslot=0x14EB,
 },
 [0x14EC]={
  category="lo",
  description="CANADIAN SYLLABICS MEDIAL L",
  direction="l",
  linebreak="al",
  unicodeslot=0x14EC,
 },
 [0x14ED]={
  category="lo",
  description="CANADIAN SYLLABICS SE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14ED,
 },
 [0x14EE]={
  category="lo",
  description="CANADIAN SYLLABICS SAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14EE,
 },
 [0x14EF]={
  category="lo",
  description="CANADIAN SYLLABICS SI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14EF,
 },
 [0x14F0]={
  category="lo",
  description="CANADIAN SYLLABICS SII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F0,
 },
 [0x14F1]={
  category="lo",
  description="CANADIAN SYLLABICS SO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F1,
 },
 [0x14F2]={
  category="lo",
  description="CANADIAN SYLLABICS SOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F2,
 },
 [0x14F3]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE SOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F3,
 },
 [0x14F4]={
  category="lo",
  description="CANADIAN SYLLABICS SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F4,
 },
 [0x14F5]={
  category="lo",
  description="CANADIAN SYLLABICS SAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F5,
 },
 [0x14F6]={
  category="lo",
  description="CANADIAN SYLLABICS SWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F6,
 },
 [0x14F7]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F7,
 },
 [0x14F8]={
  category="lo",
  description="CANADIAN SYLLABICS SWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F8,
 },
 [0x14F9]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x14F9,
 },
 [0x14FA]={
  category="lo",
  description="CANADIAN SYLLABICS SWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14FA,
 },
 [0x14FB]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x14FB,
 },
 [0x14FC]={
  category="lo",
  description="CANADIAN SYLLABICS SWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14FC,
 },
 [0x14FD]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14FD,
 },
 [0x14FE]={
  category="lo",
  description="CANADIAN SYLLABICS SWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14FE,
 },
 [0x14FF]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x14FF,
 },
 [0x1500]={
  category="lo",
  description="CANADIAN SYLLABICS SWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1500,
 },
 [0x1501]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1501,
 },
 [0x1502]={
  category="lo",
  description="CANADIAN SYLLABICS SWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1502,
 },
 [0x1503]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1503,
 },
 [0x1504]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI SWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1504,
 },
 [0x1505]={
  category="lo",
  description="CANADIAN SYLLABICS S",
  direction="l",
  linebreak="al",
  unicodeslot=0x1505,
 },
 [0x1506]={
  category="lo",
  description="CANADIAN SYLLABICS ATHAPASCAN S",
  direction="l",
  linebreak="al",
  unicodeslot=0x1506,
 },
 [0x1507]={
  category="lo",
  description="CANADIAN SYLLABICS SW",
  direction="l",
  linebreak="al",
  unicodeslot=0x1507,
 },
 [0x1508]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT S",
  direction="l",
  linebreak="al",
  unicodeslot=0x1508,
 },
 [0x1509]={
  category="lo",
  description="CANADIAN SYLLABICS MOOSE-CREE SK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1509,
 },
 [0x150A]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI SKW",
  direction="l",
  linebreak="al",
  unicodeslot=0x150A,
 },
 [0x150B]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI S-W",
  direction="l",
  linebreak="al",
  unicodeslot=0x150B,
 },
 [0x150C]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI SPWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x150C,
 },
 [0x150D]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI STWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x150D,
 },
 [0x150E]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI SKWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x150E,
 },
 [0x150F]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI SCWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x150F,
 },
 [0x1510]={
  category="lo",
  description="CANADIAN SYLLABICS SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1510,
 },
 [0x1511]={
  category="lo",
  description="CANADIAN SYLLABICS SHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1511,
 },
 [0x1512]={
  category="lo",
  description="CANADIAN SYLLABICS SHII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1512,
 },
 [0x1513]={
  category="lo",
  description="CANADIAN SYLLABICS SHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1513,
 },
 [0x1514]={
  category="lo",
  description="CANADIAN SYLLABICS SHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1514,
 },
 [0x1515]={
  category="lo",
  description="CANADIAN SYLLABICS SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1515,
 },
 [0x1516]={
  category="lo",
  description="CANADIAN SYLLABICS SHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1516,
 },
 [0x1517]={
  category="lo",
  description="CANADIAN SYLLABICS SHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1517,
 },
 [0x1518]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1518,
 },
 [0x1519]={
  category="lo",
  description="CANADIAN SYLLABICS SHWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1519,
 },
 [0x151A]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SHWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x151A,
 },
 [0x151B]={
  category="lo",
  description="CANADIAN SYLLABICS SHWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x151B,
 },
 [0x151C]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SHWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x151C,
 },
 [0x151D]={
  category="lo",
  description="CANADIAN SYLLABICS SHWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x151D,
 },
 [0x151E]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SHWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x151E,
 },
 [0x151F]={
  category="lo",
  description="CANADIAN SYLLABICS SHWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x151F,
 },
 [0x1520]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SHWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1520,
 },
 [0x1521]={
  category="lo",
  description="CANADIAN SYLLABICS SHWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1521,
 },
 [0x1522]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SHWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1522,
 },
 [0x1523]={
  category="lo",
  description="CANADIAN SYLLABICS SHWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1523,
 },
 [0x1524]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE SHWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1524,
 },
 [0x1525]={
  category="lo",
  description="CANADIAN SYLLABICS SH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1525,
 },
 [0x1526]={
  category="lo",
  description="CANADIAN SYLLABICS YE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1526,
 },
 [0x1527]={
  category="lo",
  description="CANADIAN SYLLABICS YAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1527,
 },
 [0x1528]={
  category="lo",
  description="CANADIAN SYLLABICS YI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1528,
 },
 [0x1529]={
  category="lo",
  description="CANADIAN SYLLABICS YII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1529,
 },
 [0x152A]={
  category="lo",
  description="CANADIAN SYLLABICS YO",
  direction="l",
  linebreak="al",
  unicodeslot=0x152A,
 },
 [0x152B]={
  category="lo",
  description="CANADIAN SYLLABICS YOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x152B,
 },
 [0x152C]={
  category="lo",
  description="CANADIAN SYLLABICS Y-CREE YOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x152C,
 },
 [0x152D]={
  category="lo",
  description="CANADIAN SYLLABICS YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x152D,
 },
 [0x152E]={
  category="lo",
  description="CANADIAN SYLLABICS YAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x152E,
 },
 [0x152F]={
  category="lo",
  description="CANADIAN SYLLABICS YWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x152F,
 },
 [0x1530]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE YWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1530,
 },
 [0x1531]={
  category="lo",
  description="CANADIAN SYLLABICS YWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1531,
 },
 [0x1532]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE YWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1532,
 },
 [0x1533]={
  category="lo",
  description="CANADIAN SYLLABICS YWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1533,
 },
 [0x1534]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE YWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1534,
 },
 [0x1535]={
  category="lo",
  description="CANADIAN SYLLABICS YWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1535,
 },
 [0x1536]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE YWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1536,
 },
 [0x1537]={
  category="lo",
  description="CANADIAN SYLLABICS YWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1537,
 },
 [0x1538]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE YWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1538,
 },
 [0x1539]={
  category="lo",
  description="CANADIAN SYLLABICS YWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1539,
 },
 [0x153A]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE YWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x153A,
 },
 [0x153B]={
  category="lo",
  description="CANADIAN SYLLABICS YWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x153B,
 },
 [0x153C]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE YWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x153C,
 },
 [0x153D]={
  category="lo",
  description="CANADIAN SYLLABICS NASKAPI YWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x153D,
 },
 [0x153E]={
  category="lo",
  description="CANADIAN SYLLABICS Y",
  direction="l",
  linebreak="al",
  unicodeslot=0x153E,
 },
 [0x153F]={
  category="lo",
  description="CANADIAN SYLLABICS BIBLE-CREE Y",
  direction="l",
  linebreak="al",
  unicodeslot=0x153F,
 },
 [0x1540]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE Y",
  direction="l",
  linebreak="al",
  unicodeslot=0x1540,
 },
 [0x1541]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI YI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1541,
 },
 [0x1542]={
  category="lo",
  description="CANADIAN SYLLABICS RE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1542,
 },
 [0x1543]={
  category="lo",
  description="CANADIAN SYLLABICS R-CREE RE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1543,
 },
 [0x1544]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1544,
 },
 [0x1545]={
  category="lo",
  description="CANADIAN SYLLABICS RAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1545,
 },
 [0x1546]={
  category="lo",
  description="CANADIAN SYLLABICS RI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1546,
 },
 [0x1547]={
  category="lo",
  description="CANADIAN SYLLABICS RII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1547,
 },
 [0x1548]={
  category="lo",
  description="CANADIAN SYLLABICS RO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1548,
 },
 [0x1549]={
  category="lo",
  description="CANADIAN SYLLABICS ROO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1549,
 },
 [0x154A]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LO",
  direction="l",
  linebreak="al",
  unicodeslot=0x154A,
 },
 [0x154B]={
  category="lo",
  description="CANADIAN SYLLABICS RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x154B,
 },
 [0x154C]={
  category="lo",
  description="CANADIAN SYLLABICS RAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x154C,
 },
 [0x154D]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x154D,
 },
 [0x154E]={
  category="lo",
  description="CANADIAN SYLLABICS RWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x154E,
 },
 [0x154F]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE RWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x154F,
 },
 [0x1550]={
  category="lo",
  description="CANADIAN SYLLABICS R",
  direction="l",
  linebreak="al",
  unicodeslot=0x1550,
 },
 [0x1551]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE R",
  direction="l",
  linebreak="al",
  unicodeslot=0x1551,
 },
 [0x1552]={
  category="lo",
  description="CANADIAN SYLLABICS MEDIAL R",
  direction="l",
  linebreak="al",
  unicodeslot=0x1552,
 },
 [0x1553]={
  category="lo",
  description="CANADIAN SYLLABICS FE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1553,
 },
 [0x1554]={
  category="lo",
  description="CANADIAN SYLLABICS FAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1554,
 },
 [0x1555]={
  category="lo",
  description="CANADIAN SYLLABICS FI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1555,
 },
 [0x1556]={
  category="lo",
  description="CANADIAN SYLLABICS FII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1556,
 },
 [0x1557]={
  category="lo",
  description="CANADIAN SYLLABICS FO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1557,
 },
 [0x1558]={
  category="lo",
  description="CANADIAN SYLLABICS FOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1558,
 },
 [0x1559]={
  category="lo",
  description="CANADIAN SYLLABICS FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1559,
 },
 [0x155A]={
  category="lo",
  description="CANADIAN SYLLABICS FAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x155A,
 },
 [0x155B]={
  category="lo",
  description="CANADIAN SYLLABICS FWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x155B,
 },
 [0x155C]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE FWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x155C,
 },
 [0x155D]={
  category="lo",
  description="CANADIAN SYLLABICS F",
  direction="l",
  linebreak="al",
  unicodeslot=0x155D,
 },
 [0x155E]={
  category="lo",
  description="CANADIAN SYLLABICS THE",
  direction="l",
  linebreak="al",
  unicodeslot=0x155E,
 },
 [0x155F]={
  category="lo",
  description="CANADIAN SYLLABICS N-CREE THE",
  direction="l",
  linebreak="al",
  unicodeslot=0x155F,
 },
 [0x1560]={
  category="lo",
  description="CANADIAN SYLLABICS THI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1560,
 },
 [0x1561]={
  category="lo",
  description="CANADIAN SYLLABICS N-CREE THI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1561,
 },
 [0x1562]={
  category="lo",
  description="CANADIAN SYLLABICS THII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1562,
 },
 [0x1563]={
  category="lo",
  description="CANADIAN SYLLABICS N-CREE THII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1563,
 },
 [0x1564]={
  category="lo",
  description="CANADIAN SYLLABICS THO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1564,
 },
 [0x1565]={
  category="lo",
  description="CANADIAN SYLLABICS THOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1565,
 },
 [0x1566]={
  category="lo",
  description="CANADIAN SYLLABICS THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1566,
 },
 [0x1567]={
  category="lo",
  description="CANADIAN SYLLABICS THAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1567,
 },
 [0x1568]={
  category="lo",
  description="CANADIAN SYLLABICS THWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1568,
 },
 [0x1569]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE THWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1569,
 },
 [0x156A]={
  category="lo",
  description="CANADIAN SYLLABICS TH",
  direction="l",
  linebreak="al",
  unicodeslot=0x156A,
 },
 [0x156B]={
  category="lo",
  description="CANADIAN SYLLABICS TTHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x156B,
 },
 [0x156C]={
  category="lo",
  description="CANADIAN SYLLABICS TTHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x156C,
 },
 [0x156D]={
  category="lo",
  description="CANADIAN SYLLABICS TTHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x156D,
 },
 [0x156E]={
  category="lo",
  description="CANADIAN SYLLABICS TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x156E,
 },
 [0x156F]={
  category="lo",
  description="CANADIAN SYLLABICS TTH",
  direction="l",
  linebreak="al",
  unicodeslot=0x156F,
 },
 [0x1570]={
  category="lo",
  description="CANADIAN SYLLABICS TYE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1570,
 },
 [0x1571]={
  category="lo",
  description="CANADIAN SYLLABICS TYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1571,
 },
 [0x1572]={
  category="lo",
  description="CANADIAN SYLLABICS TYO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1572,
 },
 [0x1573]={
  category="lo",
  description="CANADIAN SYLLABICS TYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1573,
 },
 [0x1574]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVIK HE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1574,
 },
 [0x1575]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVIK HI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1575,
 },
 [0x1576]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVIK HII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1576,
 },
 [0x1577]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVIK HO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1577,
 },
 [0x1578]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVIK HOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1578,
 },
 [0x1579]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVIK HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1579,
 },
 [0x157A]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVIK HAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x157A,
 },
 [0x157B]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVIK H",
  direction="l",
  linebreak="al",
  unicodeslot=0x157B,
 },
 [0x157C]={
  category="lo",
  description="CANADIAN SYLLABICS NUNAVUT H",
  direction="l",
  linebreak="al",
  unicodeslot=0x157C,
 },
 [0x157D]={
  category="lo",
  description="CANADIAN SYLLABICS HK",
  direction="l",
  linebreak="al",
  unicodeslot=0x157D,
 },
 [0x157E]={
  category="lo",
  description="CANADIAN SYLLABICS QAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x157E,
 },
 [0x157F]={
  category="lo",
  description="CANADIAN SYLLABICS QI",
  direction="l",
  linebreak="al",
  unicodeslot=0x157F,
 },
 [0x1580]={
  category="lo",
  description="CANADIAN SYLLABICS QII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1580,
 },
 [0x1581]={
  category="lo",
  description="CANADIAN SYLLABICS QO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1581,
 },
 [0x1582]={
  category="lo",
  description="CANADIAN SYLLABICS QOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1582,
 },
 [0x1583]={
  category="lo",
  description="CANADIAN SYLLABICS QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1583,
 },
 [0x1584]={
  category="lo",
  description="CANADIAN SYLLABICS QAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1584,
 },
 [0x1585]={
  category="lo",
  description="CANADIAN SYLLABICS Q",
  direction="l",
  linebreak="al",
  unicodeslot=0x1585,
 },
 [0x1586]={
  category="lo",
  description="CANADIAN SYLLABICS TLHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1586,
 },
 [0x1587]={
  category="lo",
  description="CANADIAN SYLLABICS TLHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1587,
 },
 [0x1588]={
  category="lo",
  description="CANADIAN SYLLABICS TLHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1588,
 },
 [0x1589]={
  category="lo",
  description="CANADIAN SYLLABICS TLHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1589,
 },
 [0x158A]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE RE",
  direction="l",
  linebreak="al",
  unicodeslot=0x158A,
 },
 [0x158B]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE RI",
  direction="l",
  linebreak="al",
  unicodeslot=0x158B,
 },
 [0x158C]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE RO",
  direction="l",
  linebreak="al",
  unicodeslot=0x158C,
 },
 [0x158D]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x158D,
 },
 [0x158E]={
  category="lo",
  description="CANADIAN SYLLABICS NGAAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x158E,
 },
 [0x158F]={
  category="lo",
  description="CANADIAN SYLLABICS NGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x158F,
 },
 [0x1590]={
  category="lo",
  description="CANADIAN SYLLABICS NGII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1590,
 },
 [0x1591]={
  category="lo",
  description="CANADIAN SYLLABICS NGO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1591,
 },
 [0x1592]={
  category="lo",
  description="CANADIAN SYLLABICS NGOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1592,
 },
 [0x1593]={
  category="lo",
  description="CANADIAN SYLLABICS NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1593,
 },
 [0x1594]={
  category="lo",
  description="CANADIAN SYLLABICS NGAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1594,
 },
 [0x1595]={
  category="lo",
  description="CANADIAN SYLLABICS NG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1595,
 },
 [0x1596]={
  category="lo",
  description="CANADIAN SYLLABICS NNG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1596,
 },
 [0x1597]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1597,
 },
 [0x1598]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI SHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1598,
 },
 [0x1599]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI SHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1599,
 },
 [0x159A]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x159A,
 },
 [0x159B]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THE",
  direction="l",
  linebreak="al",
  unicodeslot=0x159B,
 },
 [0x159C]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THI",
  direction="l",
  linebreak="al",
  unicodeslot=0x159C,
 },
 [0x159D]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THO",
  direction="l",
  linebreak="al",
  unicodeslot=0x159D,
 },
 [0x159E]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x159E,
 },
 [0x159F]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE TH",
  direction="l",
  linebreak="al",
  unicodeslot=0x159F,
 },
 [0x15A0]={
  category="lo",
  description="CANADIAN SYLLABICS LHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A0,
 },
 [0x15A1]={
  category="lo",
  description="CANADIAN SYLLABICS LHII",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A1,
 },
 [0x15A2]={
  category="lo",
  description="CANADIAN SYLLABICS LHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A2,
 },
 [0x15A3]={
  category="lo",
  description="CANADIAN SYLLABICS LHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A3,
 },
 [0x15A4]={
  category="lo",
  description="CANADIAN SYLLABICS LHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A4,
 },
 [0x15A5]={
  category="lo",
  description="CANADIAN SYLLABICS LHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A5,
 },
 [0x15A6]={
  category="lo",
  description="CANADIAN SYLLABICS LH",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A6,
 },
 [0x15A7]={
  category="lo",
  description="CANADIAN SYLLABICS TH-CREE THE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A7,
 },
 [0x15A8]={
  category="lo",
  description="CANADIAN SYLLABICS TH-CREE THI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A8,
 },
 [0x15A9]={
  category="lo",
  description="CANADIAN SYLLABICS TH-CREE THII",
  direction="l",
  linebreak="al",
  unicodeslot=0x15A9,
 },
 [0x15AA]={
  category="lo",
  description="CANADIAN SYLLABICS TH-CREE THO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15AA,
 },
 [0x15AB]={
  category="lo",
  description="CANADIAN SYLLABICS TH-CREE THOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15AB,
 },
 [0x15AC]={
  category="lo",
  description="CANADIAN SYLLABICS TH-CREE THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15AC,
 },
 [0x15AD]={
  category="lo",
  description="CANADIAN SYLLABICS TH-CREE THAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15AD,
 },
 [0x15AE]={
  category="lo",
  description="CANADIAN SYLLABICS TH-CREE TH",
  direction="l",
  linebreak="al",
  unicodeslot=0x15AE,
 },
 [0x15AF]={
  category="lo",
  description="CANADIAN SYLLABICS AIVILIK B",
  direction="l",
  linebreak="al",
  unicodeslot=0x15AF,
 },
 [0x15B0]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT E",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B0,
 },
 [0x15B1]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT I",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B1,
 },
 [0x15B2]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT O",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B2,
 },
 [0x15B3]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT A",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B3,
 },
 [0x15B4]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B4,
 },
 [0x15B5]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT WI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B5,
 },
 [0x15B6]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT WO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B6,
 },
 [0x15B7]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B7,
 },
 [0x15B8]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B8,
 },
 [0x15B9]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15B9,
 },
 [0x15BA]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT NO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15BA,
 },
 [0x15BB]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15BB,
 },
 [0x15BC]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT KE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15BC,
 },
 [0x15BD]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15BD,
 },
 [0x15BE]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT KO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15BE,
 },
 [0x15BF]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15BF,
 },
 [0x15C0]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI HE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C0,
 },
 [0x15C1]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI HI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C1,
 },
 [0x15C2]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI HO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C2,
 },
 [0x15C3]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C3,
 },
 [0x15C4]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C4,
 },
 [0x15C5]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C5,
 },
 [0x15C6]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C6,
 },
 [0x15C7]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C7,
 },
 [0x15C8]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C8,
 },
 [0x15C9]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15C9,
 },
 [0x15CA]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15CA,
 },
 [0x15CB]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER RO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15CB,
 },
 [0x15CC]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER RE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15CC,
 },
 [0x15CD]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER REE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15CD,
 },
 [0x15CE]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER RI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15CE,
 },
 [0x15CF]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15CF,
 },
 [0x15D0]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER WU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D0,
 },
 [0x15D1]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER WO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D1,
 },
 [0x15D2]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D2,
 },
 [0x15D3]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER WEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D3,
 },
 [0x15D4]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER WI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D4,
 },
 [0x15D5]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D5,
 },
 [0x15D6]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER HWU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D6,
 },
 [0x15D7]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER HWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D7,
 },
 [0x15D8]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER HWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D8,
 },
 [0x15D9]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER HWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15D9,
 },
 [0x15DA]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER HWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15DA,
 },
 [0x15DB]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER HWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15DB,
 },
 [0x15DC]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER THU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15DC,
 },
 [0x15DD]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER THO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15DD,
 },
 [0x15DE]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER THE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15DE,
 },
 [0x15DF]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER THEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15DF,
 },
 [0x15E0]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER THI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E0,
 },
 [0x15E1]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E1,
 },
 [0x15E2]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E2,
 },
 [0x15E3]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E3,
 },
 [0x15E4]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E4,
 },
 [0x15E5]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E5,
 },
 [0x15E6]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E6,
 },
 [0x15E7]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E7,
 },
 [0x15E8]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER PU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E8,
 },
 [0x15E9]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER PO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15E9,
 },
 [0x15EA]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER PE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15EA,
 },
 [0x15EB]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER PEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15EB,
 },
 [0x15EC]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15EC,
 },
 [0x15ED]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15ED,
 },
 [0x15EE]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER P",
  direction="l",
  linebreak="al",
  unicodeslot=0x15EE,
 },
 [0x15EF]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15EF,
 },
 [0x15F0]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F0,
 },
 [0x15F1]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F1,
 },
 [0x15F2]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F2,
 },
 [0x15F3]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F3,
 },
 [0x15F4]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F4,
 },
 [0x15F5]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F5,
 },
 [0x15F6]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F6,
 },
 [0x15F7]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F7,
 },
 [0x15F8]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F8,
 },
 [0x15F9]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15F9,
 },
 [0x15FA]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x15FA,
 },
 [0x15FB]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KKU",
  direction="l",
  linebreak="al",
  unicodeslot=0x15FB,
 },
 [0x15FC]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KKO",
  direction="l",
  linebreak="al",
  unicodeslot=0x15FC,
 },
 [0x15FD]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15FD,
 },
 [0x15FE]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KKEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x15FE,
 },
 [0x15FF]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KKI",
  direction="l",
  linebreak="al",
  unicodeslot=0x15FF,
 },
 [0x1600]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KKA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1600,
 },
 [0x1601]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER KK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1601,
 },
 [0x1602]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1602,
 },
 [0x1603]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER NO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1603,
 },
 [0x1604]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1604,
 },
 [0x1605]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER NEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1605,
 },
 [0x1606]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1606,
 },
 [0x1607]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1607,
 },
 [0x1608]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER MU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1608,
 },
 [0x1609]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER MO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1609,
 },
 [0x160A]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x160A,
 },
 [0x160B]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER MEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x160B,
 },
 [0x160C]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x160C,
 },
 [0x160D]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x160D,
 },
 [0x160E]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER YU",
  direction="l",
  linebreak="al",
  unicodeslot=0x160E,
 },
 [0x160F]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER YO",
  direction="l",
  linebreak="al",
  unicodeslot=0x160F,
 },
 [0x1610]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER YE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1610,
 },
 [0x1611]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER YEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1611,
 },
 [0x1612]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER YI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1612,
 },
 [0x1613]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1613,
 },
 [0x1614]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1614,
 },
 [0x1615]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI JU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1615,
 },
 [0x1616]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1616,
 },
 [0x1617]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1617,
 },
 [0x1618]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1618,
 },
 [0x1619]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1619,
 },
 [0x161A]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI JI",
  direction="l",
  linebreak="al",
  unicodeslot=0x161A,
 },
 [0x161B]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x161B,
 },
 [0x161C]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JJU",
  direction="l",
  linebreak="al",
  unicodeslot=0x161C,
 },
 [0x161D]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JJO",
  direction="l",
  linebreak="al",
  unicodeslot=0x161D,
 },
 [0x161E]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JJE",
  direction="l",
  linebreak="al",
  unicodeslot=0x161E,
 },
 [0x161F]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JJEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x161F,
 },
 [0x1620]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JJI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1620,
 },
 [0x1621]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JJA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1621,
 },
 [0x1622]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1622,
 },
 [0x1623]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1623,
 },
 [0x1624]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1624,
 },
 [0x1625]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1625,
 },
 [0x1626]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1626,
 },
 [0x1627]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1627,
 },
 [0x1628]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DLU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1628,
 },
 [0x1629]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DLO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1629,
 },
 [0x162A]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DLE",
  direction="l",
  linebreak="al",
  unicodeslot=0x162A,
 },
 [0x162B]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DLEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x162B,
 },
 [0x162C]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x162C,
 },
 [0x162D]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x162D,
 },
 [0x162E]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x162E,
 },
 [0x162F]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x162F,
 },
 [0x1630]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1630,
 },
 [0x1631]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1631,
 },
 [0x1632]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1632,
 },
 [0x1633]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER LHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1633,
 },
 [0x1634]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1634,
 },
 [0x1635]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1635,
 },
 [0x1636]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1636,
 },
 [0x1637]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1637,
 },
 [0x1638]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1638,
 },
 [0x1639]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1639,
 },
 [0x163A]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLU",
  direction="l",
  linebreak="al",
  unicodeslot=0x163A,
 },
 [0x163B]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLO",
  direction="l",
  linebreak="al",
  unicodeslot=0x163B,
 },
 [0x163C]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLE",
  direction="l",
  linebreak="al",
  unicodeslot=0x163C,
 },
 [0x163D]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x163D,
 },
 [0x163E]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x163E,
 },
 [0x163F]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x163F,
 },
 [0x1640]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER ZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1640,
 },
 [0x1641]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER ZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1641,
 },
 [0x1642]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER ZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1642,
 },
 [0x1643]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER ZEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1643,
 },
 [0x1644]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER ZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1644,
 },
 [0x1645]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1645,
 },
 [0x1646]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER Z",
  direction="l",
  linebreak="al",
  unicodeslot=0x1646,
 },
 [0x1647]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER INITIAL Z",
  direction="l",
  linebreak="al",
  unicodeslot=0x1647,
 },
 [0x1648]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1648,
 },
 [0x1649]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1649,
 },
 [0x164A]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x164A,
 },
 [0x164B]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DZEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x164B,
 },
 [0x164C]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x164C,
 },
 [0x164D]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x164D,
 },
 [0x164E]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SU",
  direction="l",
  linebreak="al",
  unicodeslot=0x164E,
 },
 [0x164F]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SO",
  direction="l",
  linebreak="al",
  unicodeslot=0x164F,
 },
 [0x1650]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1650,
 },
 [0x1651]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1651,
 },
 [0x1652]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1652,
 },
 [0x1653]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1653,
 },
 [0x1654]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1654,
 },
 [0x1655]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1655,
 },
 [0x1656]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1656,
 },
 [0x1657]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1657,
 },
 [0x1658]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1658,
 },
 [0x1659]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1659,
 },
 [0x165A]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER SH",
  direction="l",
  linebreak="al",
  unicodeslot=0x165A,
 },
 [0x165B]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TSU",
  direction="l",
  linebreak="al",
  unicodeslot=0x165B,
 },
 [0x165C]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TSO",
  direction="l",
  linebreak="al",
  unicodeslot=0x165C,
 },
 [0x165D]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TSE",
  direction="l",
  linebreak="al",
  unicodeslot=0x165D,
 },
 [0x165E]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TSEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x165E,
 },
 [0x165F]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TSI",
  direction="l",
  linebreak="al",
  unicodeslot=0x165F,
 },
 [0x1660]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1660,
 },
 [0x1661]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER CHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1661,
 },
 [0x1662]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER CHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1662,
 },
 [0x1663]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER CHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1663,
 },
 [0x1664]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER CHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1664,
 },
 [0x1665]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER CHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1665,
 },
 [0x1666]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1666,
 },
 [0x1667]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTSU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1667,
 },
 [0x1668]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTSO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1668,
 },
 [0x1669]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTSE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1669,
 },
 [0x166A]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTSEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x166A,
 },
 [0x166B]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTSI",
  direction="l",
  linebreak="al",
  unicodeslot=0x166B,
 },
 [0x166C]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER TTSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x166C,
 },
 [0x166D]={
  category="po",
  description="CANADIAN SYLLABICS CHI SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x166D,
 },
 [0x166E]={
  category="po",
  description="CANADIAN SYLLABICS FULL STOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x166E,
 },
 [0x166F]={
  category="lo",
  description="CANADIAN SYLLABICS QAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x166F,
 },
 [0x1670]={
  category="lo",
  description="CANADIAN SYLLABICS NGAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1670,
 },
 [0x1671]={
  category="lo",
  description="CANADIAN SYLLABICS NNGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1671,
 },
 [0x1672]={
  category="lo",
  description="CANADIAN SYLLABICS NNGII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1672,
 },
 [0x1673]={
  category="lo",
  description="CANADIAN SYLLABICS NNGO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1673,
 },
 [0x1674]={
  category="lo",
  description="CANADIAN SYLLABICS NNGOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1674,
 },
 [0x1675]={
  category="lo",
  description="CANADIAN SYLLABICS NNGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1675,
 },
 [0x1676]={
  category="lo",
  description="CANADIAN SYLLABICS NNGAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1676,
 },
 [0x1677]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1677,
 },
 [0x1678]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1678,
 },
 [0x1679]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1679,
 },
 [0x167A]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x167A,
 },
 [0x167B]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x167B,
 },
 [0x167C]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x167C,
 },
 [0x167D]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE THWAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x167D,
 },
 [0x167E]={
  category="lo",
  description="CANADIAN SYLLABICS WOODS-CREE FINAL TH",
  direction="l",
  linebreak="al",
  unicodeslot=0x167E,
 },
 [0x167F]={
  category="lo",
  description="CANADIAN SYLLABICS BLACKFOOT W",
  direction="l",
  linebreak="al",
  unicodeslot=0x167F,
 },
 [0x1680]={
  category="zs",
  description="OGHAM SPACE MARK",
  direction="ws",
  linebreak="ba",
  unicodeslot=0x1680,
 },
 [0x1681]={
  category="lo",
  description="OGHAM LETTER BEITH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1681,
 },
 [0x1682]={
  category="lo",
  description="OGHAM LETTER LUIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1682,
 },
 [0x1683]={
  category="lo",
  description="OGHAM LETTER FEARN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1683,
 },
 [0x1684]={
  category="lo",
  description="OGHAM LETTER SAIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1684,
 },
 [0x1685]={
  category="lo",
  description="OGHAM LETTER NION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1685,
 },
 [0x1686]={
  category="lo",
  description="OGHAM LETTER UATH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1686,
 },
 [0x1687]={
  category="lo",
  description="OGHAM LETTER DAIR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1687,
 },
 [0x1688]={
  category="lo",
  description="OGHAM LETTER TINNE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1688,
 },
 [0x1689]={
  category="lo",
  description="OGHAM LETTER COLL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1689,
 },
 [0x168A]={
  category="lo",
  description="OGHAM LETTER CEIRT",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A,
 },
 [0x168B]={
  category="lo",
  description="OGHAM LETTER MUIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B,
 },
 [0x168C]={
  category="lo",
  description="OGHAM LETTER GORT",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C,
 },
 [0x168D]={
  category="lo",
  description="OGHAM LETTER NGEADAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D,
 },
 [0x168E]={
  category="lo",
  description="OGHAM LETTER STRAIF",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E,
 },
 [0x168F]={
  category="lo",
  description="OGHAM LETTER RUIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F,
 },
 [0x1690]={
  category="lo",
  description="OGHAM LETTER AILM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1690,
 },
 [0x1691]={
  category="lo",
  description="OGHAM LETTER ONN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1691,
 },
 [0x1692]={
  category="lo",
  description="OGHAM LETTER UR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1692,
 },
 [0x1693]={
  category="lo",
  description="OGHAM LETTER EADHADH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1693,
 },
 [0x1694]={
  category="lo",
  description="OGHAM LETTER IODHADH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1694,
 },
 [0x1695]={
  category="lo",
  description="OGHAM LETTER EABHADH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1695,
 },
 [0x1696]={
  category="lo",
  description="OGHAM LETTER OR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1696,
 },
 [0x1697]={
  category="lo",
  description="OGHAM LETTER UILLEANN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1697,
 },
 [0x1698]={
  category="lo",
  description="OGHAM LETTER IFIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1698,
 },
 [0x1699]={
  category="lo",
  description="OGHAM LETTER EAMHANCHOLL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1699,
 },
 [0x169A]={
  category="lo",
  description="OGHAM LETTER PEITH",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A,
 },
 [0x169B]={
  category="ps",
  description="OGHAM FEATHER MARK",
  direction="on",
  linebreak="op",
  mirror=0x169C,
  unicodeslot=0x169B,
 },
 [0x169C]={
  category="pe",
  description="OGHAM REVERSED FEATHER MARK",
  direction="on",
  linebreak="cl",
  mirror=0x169B,
  unicodeslot=0x169C,
 },
 [0x16A0]={
  category="lo",
  description="RUNIC LETTER FEHU FEOH FE F",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A0,
 },
 [0x16A1]={
  category="lo",
  description="RUNIC LETTER V",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A1,
 },
 [0x16A2]={
  category="lo",
  description="RUNIC LETTER URUZ UR U",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A2,
 },
 [0x16A3]={
  category="lo",
  description="RUNIC LETTER YR",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A3,
 },
 [0x16A4]={
  category="lo",
  description="RUNIC LETTER Y",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A4,
 },
 [0x16A5]={
  category="lo",
  description="RUNIC LETTER W",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A5,
 },
 [0x16A6]={
  category="lo",
  description="RUNIC LETTER THURISAZ THURS THORN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A6,
 },
 [0x16A7]={
  category="lo",
  description="RUNIC LETTER ETH",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A7,
 },
 [0x16A8]={
  category="lo",
  description="RUNIC LETTER ANSUZ A",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A8,
 },
 [0x16A9]={
  category="lo",
  description="RUNIC LETTER OS O",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A9,
 },
 [0x16AA]={
  category="lo",
  description="RUNIC LETTER AC A",
  direction="l",
  linebreak="al",
  unicodeslot=0x16AA,
 },
 [0x16AB]={
  category="lo",
  description="RUNIC LETTER AESC",
  direction="l",
  linebreak="al",
  unicodeslot=0x16AB,
 },
 [0x16AC]={
  category="lo",
  description="RUNIC LETTER LONG-BRANCH-OSS O",
  direction="l",
  linebreak="al",
  unicodeslot=0x16AC,
 },
 [0x16AD]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-OSS O",
  direction="l",
  linebreak="al",
  unicodeslot=0x16AD,
 },
 [0x16AE]={
  category="lo",
  description="RUNIC LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x16AE,
 },
 [0x16AF]={
  category="lo",
  description="RUNIC LETTER OE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16AF,
 },
 [0x16B0]={
  category="lo",
  description="RUNIC LETTER ON",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B0,
 },
 [0x16B1]={
  category="lo",
  description="RUNIC LETTER RAIDO RAD REID R",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B1,
 },
 [0x16B2]={
  category="lo",
  description="RUNIC LETTER KAUNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B2,
 },
 [0x16B3]={
  category="lo",
  description="RUNIC LETTER CEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B3,
 },
 [0x16B4]={
  category="lo",
  description="RUNIC LETTER KAUN K",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B4,
 },
 [0x16B5]={
  category="lo",
  description="RUNIC LETTER G",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B5,
 },
 [0x16B6]={
  category="lo",
  description="RUNIC LETTER ENG",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B6,
 },
 [0x16B7]={
  category="lo",
  description="RUNIC LETTER GEBO GYFU G",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B7,
 },
 [0x16B8]={
  category="lo",
  description="RUNIC LETTER GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B8,
 },
 [0x16B9]={
  category="lo",
  description="RUNIC LETTER WUNJO WYNN W",
  direction="l",
  linebreak="al",
  unicodeslot=0x16B9,
 },
 [0x16BA]={
  category="lo",
  description="RUNIC LETTER HAGLAZ H",
  direction="l",
  linebreak="al",
  unicodeslot=0x16BA,
 },
 [0x16BB]={
  category="lo",
  description="RUNIC LETTER HAEGL H",
  direction="l",
  linebreak="al",
  unicodeslot=0x16BB,
 },
 [0x16BC]={
  category="lo",
  description="RUNIC LETTER LONG-BRANCH-HAGALL H",
  direction="l",
  linebreak="al",
  unicodeslot=0x16BC,
 },
 [0x16BD]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-HAGALL H",
  direction="l",
  linebreak="al",
  unicodeslot=0x16BD,
 },
 [0x16BE]={
  category="lo",
  description="RUNIC LETTER NAUDIZ NYD NAUD N",
  direction="l",
  linebreak="al",
  unicodeslot=0x16BE,
 },
 [0x16BF]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-NAUD N",
  direction="l",
  linebreak="al",
  unicodeslot=0x16BF,
 },
 [0x16C0]={
  category="lo",
  description="RUNIC LETTER DOTTED-N",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C0,
 },
 [0x16C1]={
  category="lo",
  description="RUNIC LETTER ISAZ IS ISS I",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C1,
 },
 [0x16C2]={
  category="lo",
  description="RUNIC LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C2,
 },
 [0x16C3]={
  category="lo",
  description="RUNIC LETTER JERAN J",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C3,
 },
 [0x16C4]={
  category="lo",
  description="RUNIC LETTER GER",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C4,
 },
 [0x16C5]={
  category="lo",
  description="RUNIC LETTER LONG-BRANCH-AR AE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C5,
 },
 [0x16C6]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-AR A",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C6,
 },
 [0x16C7]={
  category="lo",
  description="RUNIC LETTER IWAZ EOH",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C7,
 },
 [0x16C8]={
  category="lo",
  description="RUNIC LETTER PERTHO PEORTH P",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C8,
 },
 [0x16C9]={
  category="lo",
  description="RUNIC LETTER ALGIZ EOLHX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16C9,
 },
 [0x16CA]={
  category="lo",
  description="RUNIC LETTER SOWILO S",
  direction="l",
  linebreak="al",
  unicodeslot=0x16CA,
 },
 [0x16CB]={
  category="lo",
  description="RUNIC LETTER SIGEL LONG-BRANCH-SOL S",
  direction="l",
  linebreak="al",
  unicodeslot=0x16CB,
 },
 [0x16CC]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-SOL S",
  direction="l",
  linebreak="al",
  unicodeslot=0x16CC,
 },
 [0x16CD]={
  category="lo",
  description="RUNIC LETTER C",
  direction="l",
  linebreak="al",
  unicodeslot=0x16CD,
 },
 [0x16CE]={
  category="lo",
  description="RUNIC LETTER Z",
  direction="l",
  linebreak="al",
  unicodeslot=0x16CE,
 },
 [0x16CF]={
  category="lo",
  description="RUNIC LETTER TIWAZ TIR TYR T",
  direction="l",
  linebreak="al",
  unicodeslot=0x16CF,
 },
 [0x16D0]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-TYR T",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D0,
 },
 [0x16D1]={
  category="lo",
  description="RUNIC LETTER D",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D1,
 },
 [0x16D2]={
  category="lo",
  description="RUNIC LETTER BERKANAN BEORC BJARKAN B",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D2,
 },
 [0x16D3]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-BJARKAN B",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D3,
 },
 [0x16D4]={
  category="lo",
  description="RUNIC LETTER DOTTED-P",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D4,
 },
 [0x16D5]={
  category="lo",
  description="RUNIC LETTER OPEN-P",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D5,
 },
 [0x16D6]={
  category="lo",
  description="RUNIC LETTER EHWAZ EH E",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D6,
 },
 [0x16D7]={
  category="lo",
  description="RUNIC LETTER MANNAZ MAN M",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D7,
 },
 [0x16D8]={
  category="lo",
  description="RUNIC LETTER LONG-BRANCH-MADR M",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D8,
 },
 [0x16D9]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-MADR M",
  direction="l",
  linebreak="al",
  unicodeslot=0x16D9,
 },
 [0x16DA]={
  category="lo",
  description="RUNIC LETTER LAUKAZ LAGU LOGR L",
  direction="l",
  linebreak="al",
  unicodeslot=0x16DA,
 },
 [0x16DB]={
  category="lo",
  description="RUNIC LETTER DOTTED-L",
  direction="l",
  linebreak="al",
  unicodeslot=0x16DB,
 },
 [0x16DC]={
  category="lo",
  description="RUNIC LETTER INGWAZ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16DC,
 },
 [0x16DD]={
  category="lo",
  description="RUNIC LETTER ING",
  direction="l",
  linebreak="al",
  unicodeslot=0x16DD,
 },
 [0x16DE]={
  category="lo",
  description="RUNIC LETTER DAGAZ DAEG D",
  direction="l",
  linebreak="al",
  unicodeslot=0x16DE,
 },
 [0x16DF]={
  category="lo",
  description="RUNIC LETTER OTHALAN ETHEL O",
  direction="l",
  linebreak="al",
  unicodeslot=0x16DF,
 },
 [0x16E0]={
  category="lo",
  description="RUNIC LETTER EAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E0,
 },
 [0x16E1]={
  category="lo",
  description="RUNIC LETTER IOR",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E1,
 },
 [0x16E2]={
  category="lo",
  description="RUNIC LETTER CWEORTH",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E2,
 },
 [0x16E3]={
  category="lo",
  description="RUNIC LETTER CALC",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E3,
 },
 [0x16E4]={
  category="lo",
  description="RUNIC LETTER CEALC",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E4,
 },
 [0x16E5]={
  category="lo",
  description="RUNIC LETTER STAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E5,
 },
 [0x16E6]={
  category="lo",
  description="RUNIC LETTER LONG-BRANCH-YR",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E6,
 },
 [0x16E7]={
  category="lo",
  description="RUNIC LETTER SHORT-TWIG-YR",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E7,
 },
 [0x16E8]={
  category="lo",
  description="RUNIC LETTER ICELANDIC-YR",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E8,
 },
 [0x16E9]={
  category="lo",
  description="RUNIC LETTER Q",
  direction="l",
  linebreak="al",
  unicodeslot=0x16E9,
 },
 [0x16EA]={
  category="lo",
  description="RUNIC LETTER X",
  direction="l",
  linebreak="al",
  unicodeslot=0x16EA,
 },
 [0x16EB]={
  category="po",
  description="RUNIC SINGLE PUNCTUATION",
  direction="l",
  linebreak="ba",
  unicodeslot=0x16EB,
 },
 [0x16EC]={
  category="po",
  description="RUNIC MULTIPLE PUNCTUATION",
  direction="l",
  linebreak="ba",
  unicodeslot=0x16EC,
 },
 [0x16ED]={
  category="po",
  description="RUNIC CROSS PUNCTUATION",
  direction="l",
  linebreak="ba",
  unicodeslot=0x16ED,
 },
 [0x16EE]={
  category="nl",
  description="RUNIC ARLAUG SYMBOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x16EE,
 },
 [0x16EF]={
  category="nl",
  description="RUNIC TVIMADUR SYMBOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x16EF,
 },
 [0x16F0]={
  category="nl",
  description="RUNIC BELGTHOR SYMBOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F0,
 },
 [0x1700]={
  category="lo",
  description="TAGALOG LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1700,
 },
 [0x1701]={
  category="lo",
  description="TAGALOG LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1701,
 },
 [0x1702]={
  category="lo",
  description="TAGALOG LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1702,
 },
 [0x1703]={
  category="lo",
  description="TAGALOG LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1703,
 },
 [0x1704]={
  category="lo",
  description="TAGALOG LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1704,
 },
 [0x1705]={
  category="lo",
  description="TAGALOG LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1705,
 },
 [0x1706]={
  category="lo",
  description="TAGALOG LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1706,
 },
 [0x1707]={
  category="lo",
  description="TAGALOG LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1707,
 },
 [0x1708]={
  category="lo",
  description="TAGALOG LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1708,
 },
 [0x1709]={
  category="lo",
  description="TAGALOG LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1709,
 },
 [0x170A]={
  category="lo",
  description="TAGALOG LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x170A,
 },
 [0x170B]={
  category="lo",
  description="TAGALOG LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x170B,
 },
 [0x170C]={
  category="lo",
  description="TAGALOG LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x170C,
 },
 [0x170E]={
  category="lo",
  description="TAGALOG LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x170E,
 },
 [0x170F]={
  category="lo",
  description="TAGALOG LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x170F,
 },
 [0x1710]={
  category="lo",
  description="TAGALOG LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1710,
 },
 [0x1711]={
  category="lo",
  description="TAGALOG LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1711,
 },
 [0x1712]={
  category="mn",
  description="TAGALOG VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1712,
 },
 [0x1713]={
  category="mn",
  description="TAGALOG VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1713,
 },
 [0x1714]={
  category="mn",
  description="TAGALOG SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1714,
 },
 [0x1720]={
  category="lo",
  description="HANUNOO LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1720,
 },
 [0x1721]={
  category="lo",
  description="HANUNOO LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1721,
 },
 [0x1722]={
  category="lo",
  description="HANUNOO LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1722,
 },
 [0x1723]={
  category="lo",
  description="HANUNOO LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1723,
 },
 [0x1724]={
  category="lo",
  description="HANUNOO LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1724,
 },
 [0x1725]={
  category="lo",
  description="HANUNOO LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1725,
 },
 [0x1726]={
  category="lo",
  description="HANUNOO LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1726,
 },
 [0x1727]={
  category="lo",
  description="HANUNOO LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1727,
 },
 [0x1728]={
  category="lo",
  description="HANUNOO LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1728,
 },
 [0x1729]={
  category="lo",
  description="HANUNOO LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1729,
 },
 [0x172A]={
  category="lo",
  description="HANUNOO LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x172A,
 },
 [0x172B]={
  category="lo",
  description="HANUNOO LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x172B,
 },
 [0x172C]={
  category="lo",
  description="HANUNOO LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x172C,
 },
 [0x172D]={
  category="lo",
  description="HANUNOO LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x172D,
 },
 [0x172E]={
  category="lo",
  description="HANUNOO LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x172E,
 },
 [0x172F]={
  category="lo",
  description="HANUNOO LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x172F,
 },
 [0x1730]={
  category="lo",
  description="HANUNOO LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1730,
 },
 [0x1731]={
  category="lo",
  description="HANUNOO LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1731,
 },
 [0x1732]={
  category="mn",
  description="HANUNOO VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1732,
 },
 [0x1733]={
  category="mn",
  description="HANUNOO VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1733,
 },
 [0x1734]={
  category="mn",
  description="HANUNOO SIGN PAMUDPOD",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1734,
 },
 [0x1735]={
  category="po",
  description="PHILIPPINE SINGLE PUNCTUATION",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1735,
 },
 [0x1736]={
  category="po",
  description="PHILIPPINE DOUBLE PUNCTUATION",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1736,
 },
 [0x1740]={
  category="lo",
  description="BUHID LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1740,
 },
 [0x1741]={
  category="lo",
  description="BUHID LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1741,
 },
 [0x1742]={
  category="lo",
  description="BUHID LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1742,
 },
 [0x1743]={
  category="lo",
  description="BUHID LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1743,
 },
 [0x1744]={
  category="lo",
  description="BUHID LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1744,
 },
 [0x1745]={
  category="lo",
  description="BUHID LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1745,
 },
 [0x1746]={
  category="lo",
  description="BUHID LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1746,
 },
 [0x1747]={
  category="lo",
  description="BUHID LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1747,
 },
 [0x1748]={
  category="lo",
  description="BUHID LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1748,
 },
 [0x1749]={
  category="lo",
  description="BUHID LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1749,
 },
 [0x174A]={
  category="lo",
  description="BUHID LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x174A,
 },
 [0x174B]={
  category="lo",
  description="BUHID LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x174B,
 },
 [0x174C]={
  category="lo",
  description="BUHID LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x174C,
 },
 [0x174D]={
  category="lo",
  description="BUHID LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x174D,
 },
 [0x174E]={
  category="lo",
  description="BUHID LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x174E,
 },
 [0x174F]={
  category="lo",
  description="BUHID LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x174F,
 },
 [0x1750]={
  category="lo",
  description="BUHID LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1750,
 },
 [0x1751]={
  category="lo",
  description="BUHID LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1751,
 },
 [0x1752]={
  category="mn",
  description="BUHID VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1752,
 },
 [0x1753]={
  category="mn",
  description="BUHID VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1753,
 },
 [0x1760]={
  category="lo",
  description="TAGBANWA LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1760,
 },
 [0x1761]={
  category="lo",
  description="TAGBANWA LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1761,
 },
 [0x1762]={
  category="lo",
  description="TAGBANWA LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1762,
 },
 [0x1763]={
  category="lo",
  description="TAGBANWA LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1763,
 },
 [0x1764]={
  category="lo",
  description="TAGBANWA LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1764,
 },
 [0x1765]={
  category="lo",
  description="TAGBANWA LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1765,
 },
 [0x1766]={
  category="lo",
  description="TAGBANWA LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1766,
 },
 [0x1767]={
  category="lo",
  description="TAGBANWA LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1767,
 },
 [0x1768]={
  category="lo",
  description="TAGBANWA LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1768,
 },
 [0x1769]={
  category="lo",
  description="TAGBANWA LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1769,
 },
 [0x176A]={
  category="lo",
  description="TAGBANWA LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x176A,
 },
 [0x176B]={
  category="lo",
  description="TAGBANWA LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x176B,
 },
 [0x176C]={
  category="lo",
  description="TAGBANWA LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x176C,
 },
 [0x176E]={
  category="lo",
  description="TAGBANWA LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x176E,
 },
 [0x176F]={
  category="lo",
  description="TAGBANWA LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x176F,
 },
 [0x1770]={
  category="lo",
  description="TAGBANWA LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1770,
 },
 [0x1772]={
  category="mn",
  description="TAGBANWA VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1772,
 },
 [0x1773]={
  category="mn",
  description="TAGBANWA VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1773,
 },
 [0x1780]={
  category="lo",
  description="KHMER LETTER KA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1780,
 },
 [0x1781]={
  category="lo",
  description="KHMER LETTER KHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1781,
 },
 [0x1782]={
  category="lo",
  description="KHMER LETTER KO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1782,
 },
 [0x1783]={
  category="lo",
  description="KHMER LETTER KHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1783,
 },
 [0x1784]={
  category="lo",
  description="KHMER LETTER NGO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1784,
 },
 [0x1785]={
  category="lo",
  description="KHMER LETTER CA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1785,
 },
 [0x1786]={
  category="lo",
  description="KHMER LETTER CHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1786,
 },
 [0x1787]={
  category="lo",
  description="KHMER LETTER CO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1787,
 },
 [0x1788]={
  category="lo",
  description="KHMER LETTER CHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1788,
 },
 [0x1789]={
  category="lo",
  description="KHMER LETTER NYO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1789,
 },
 [0x178A]={
  category="lo",
  description="KHMER LETTER DA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x178A,
 },
 [0x178B]={
  category="lo",
  description="KHMER LETTER TTHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x178B,
 },
 [0x178C]={
  category="lo",
  description="KHMER LETTER DO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x178C,
 },
 [0x178D]={
  category="lo",
  description="KHMER LETTER TTHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x178D,
 },
 [0x178E]={
  category="lo",
  description="KHMER LETTER NNO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x178E,
 },
 [0x178F]={
  category="lo",
  description="KHMER LETTER TA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x178F,
 },
 [0x1790]={
  category="lo",
  description="KHMER LETTER THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1790,
 },
 [0x1791]={
  category="lo",
  description="KHMER LETTER TO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1791,
 },
 [0x1792]={
  category="lo",
  description="KHMER LETTER THO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1792,
 },
 [0x1793]={
  category="lo",
  description="KHMER LETTER NO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1793,
 },
 [0x1794]={
  category="lo",
  description="KHMER LETTER BA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1794,
 },
 [0x1795]={
  category="lo",
  description="KHMER LETTER PHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1795,
 },
 [0x1796]={
  category="lo",
  description="KHMER LETTER PO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1796,
 },
 [0x1797]={
  category="lo",
  description="KHMER LETTER PHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1797,
 },
 [0x1798]={
  category="lo",
  description="KHMER LETTER MO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1798,
 },
 [0x1799]={
  category="lo",
  description="KHMER LETTER YO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1799,
 },
 [0x179A]={
  category="lo",
  description="KHMER LETTER RO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x179A,
 },
 [0x179B]={
  category="lo",
  description="KHMER LETTER LO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x179B,
 },
 [0x179C]={
  category="lo",
  description="KHMER LETTER VO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x179C,
 },
 [0x179D]={
  category="lo",
  description="KHMER LETTER SHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x179D,
 },
 [0x179E]={
  category="lo",
  description="KHMER LETTER SSO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x179E,
 },
 [0x179F]={
  category="lo",
  description="KHMER LETTER SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x179F,
 },
 [0x17A0]={
  category="lo",
  description="KHMER LETTER HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A0,
 },
 [0x17A1]={
  category="lo",
  description="KHMER LETTER LA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A1,
 },
 [0x17A2]={
  category="lo",
  description="KHMER LETTER QA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A2,
 },
 [0x17A3]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QAQ",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A3,
 },
 [0x17A4]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QAA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A4,
 },
 [0x17A5]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A5,
 },
 [0x17A6]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QII",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A6,
 },
 [0x17A7]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A7,
 },
 [0x17A8]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QUK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A8,
 },
 [0x17A9]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QUU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17A9,
 },
 [0x17AA]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QUUV",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17AA,
 },
 [0x17AB]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL RY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17AB,
 },
 [0x17AC]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL RYY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17AC,
 },
 [0x17AD]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL LY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17AD,
 },
 [0x17AE]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL LYY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17AE,
 },
 [0x17AF]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17AF,
 },
 [0x17B0]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QAI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17B0,
 },
 [0x17B1]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QOO TYPE ONE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17B1,
 },
 [0x17B2]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QOO TYPE TWO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17B2,
 },
 [0x17B3]={
  category="lo",
  description="KHMER INDEPENDENT VOWEL QAU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17B3,
 },
 [0x17B4]={
  category="cf",
  description="KHMER VOWEL INHERENT AQ",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17B4,
 },
 [0x17B5]={
  category="cf",
  description="KHMER VOWEL INHERENT AA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17B5,
 },
 [0x17B6]={
  category="mc",
  description="KHMER VOWEL SIGN AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17B6,
 },
 [0x17B7]={
  category="mn",
  description="KHMER VOWEL SIGN I",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17B7,
 },
 [0x17B8]={
  category="mn",
  description="KHMER VOWEL SIGN II",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17B8,
 },
 [0x17B9]={
  category="mn",
  description="KHMER VOWEL SIGN Y",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17B9,
 },
 [0x17BA]={
  category="mn",
  description="KHMER VOWEL SIGN YY",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17BA,
 },
 [0x17BB]={
  category="mn",
  description="KHMER VOWEL SIGN U",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17BB,
 },
 [0x17BC]={
  category="mn",
  description="KHMER VOWEL SIGN UU",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17BC,
 },
 [0x17BD]={
  category="mn",
  description="KHMER VOWEL SIGN UA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17BD,
 },
 [0x17BE]={
  category="mc",
  description="KHMER VOWEL SIGN OE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17BE,
 },
 [0x17BF]={
  category="mc",
  description="KHMER VOWEL SIGN YA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17BF,
 },
 [0x17C0]={
  category="mc",
  description="KHMER VOWEL SIGN IE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17C0,
 },
 [0x17C1]={
  category="mc",
  description="KHMER VOWEL SIGN E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17C1,
 },
 [0x17C2]={
  category="mc",
  description="KHMER VOWEL SIGN AE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17C2,
 },
 [0x17C3]={
  category="mc",
  description="KHMER VOWEL SIGN AI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17C3,
 },
 [0x17C4]={
  category="mc",
  description="KHMER VOWEL SIGN OO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17C4,
 },
 [0x17C5]={
  category="mc",
  description="KHMER VOWEL SIGN AU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17C5,
 },
 [0x17C6]={
  category="mn",
  description="KHMER SIGN NIKAHIT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17C6,
 },
 [0x17C7]={
  category="mc",
  description="KHMER SIGN REAHMUK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17C7,
 },
 [0x17C8]={
  category="mc",
  description="KHMER SIGN YUUKALEAPINTU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17C8,
 },
 [0x17C9]={
  category="mn",
  description="KHMER SIGN MUUSIKATOAN",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17C9,
 },
 [0x17CA]={
  category="mn",
  description="KHMER SIGN TRIISAP",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17CA,
 },
 [0x17CB]={
  category="mn",
  description="KHMER SIGN BANTOC",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17CB,
 },
 [0x17CC]={
  category="mn",
  description="KHMER SIGN ROBAT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17CC,
 },
 [0x17CD]={
  category="mn",
  description="KHMER SIGN TOANDAKHIAT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17CD,
 },
 [0x17CE]={
  category="mn",
  description="KHMER SIGN KAKABAT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17CE,
 },
 [0x17CF]={
  category="mn",
  description="KHMER SIGN AHSDA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17CF,
 },
 [0x17D0]={
  category="mn",
  description="KHMER SIGN SAMYOK SANNYA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17D0,
 },
 [0x17D1]={
  category="mn",
  description="KHMER SIGN VIRIAM",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17D1,
 },
 [0x17D2]={
  category="mn",
  description="KHMER SIGN COENG",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17D2,
 },
 [0x17D3]={
  category="mn",
  description="KHMER SIGN BATHAMASAT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17D3,
 },
 [0x17D4]={
  category="po",
  description="KHMER SIGN KHAN",
  direction="l",
  linebreak="ba",
  unicodeslot=0x17D4,
 },
 [0x17D5]={
  category="po",
  description="KHMER SIGN BARIYOOSAN",
  direction="l",
  linebreak="ba",
  unicodeslot=0x17D5,
 },
 [0x17D6]={
  category="po",
  description="KHMER SIGN CAMNUC PII KUUH",
  direction="l",
  linebreak="ns",
  unicodeslot=0x17D6,
 },
 [0x17D7]={
  category="lm",
  description="KHMER SIGN LEK TOO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17D7,
 },
 [0x17D8]={
  category="po",
  description="KHMER SIGN BEYYAL",
  direction="l",
  linebreak="ba",
  unicodeslot=0x17D8,
 },
 [0x17D9]={
  category="po",
  description="KHMER SIGN PHNAEK MUAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x17D9,
 },
 [0x17DA]={
  category="po",
  description="KHMER SIGN KOOMUUT",
  direction="l",
  linebreak="ba",
  unicodeslot=0x17DA,
 },
 [0x17DB]={
  category="sc",
  description="KHMER CURRENCY SYMBOL RIEL",
  direction="et",
  linebreak="pr",
  unicodeslot=0x17DB,
 },
 [0x17DC]={
  category="lo",
  description="KHMER SIGN AVAKRAHASANYA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x17DC,
 },
 [0x17DD]={
  category="mn",
  description="KHMER SIGN ATTHACAN",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x17DD,
 },
 [0x17E0]={
  category="nd",
  description="KHMER DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E0,
 },
 [0x17E1]={
  category="nd",
  description="KHMER DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E1,
 },
 [0x17E2]={
  category="nd",
  description="KHMER DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E2,
 },
 [0x17E3]={
  category="nd",
  description="KHMER DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E3,
 },
 [0x17E4]={
  category="nd",
  description="KHMER DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E4,
 },
 [0x17E5]={
  category="nd",
  description="KHMER DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E5,
 },
 [0x17E6]={
  category="nd",
  description="KHMER DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E6,
 },
 [0x17E7]={
  category="nd",
  description="KHMER DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E7,
 },
 [0x17E8]={
  category="nd",
  description="KHMER DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E8,
 },
 [0x17E9]={
  category="nd",
  description="KHMER DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x17E9,
 },
 [0x17F0]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK SON",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F0,
 },
 [0x17F1]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK MUOY",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F1,
 },
 [0x17F2]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK PII",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F2,
 },
 [0x17F3]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK BEI",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F3,
 },
 [0x17F4]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK BUON",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F4,
 },
 [0x17F5]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK PRAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F5,
 },
 [0x17F6]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK PRAM-MUOY",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F6,
 },
 [0x17F7]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK PRAM-PII",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F7,
 },
 [0x17F8]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK PRAM-BEI",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F8,
 },
 [0x17F9]={
  category="no",
  description="KHMER SYMBOL LEK ATTAK PRAM-BUON",
  direction="on",
  linebreak="al",
  unicodeslot=0x17F9,
 },
 [0x1800]={
  category="po",
  description="MONGOLIAN BIRGA",
  direction="on",
  linebreak="al",
  unicodeslot=0x1800,
 },
 [0x1801]={
  category="po",
  description="MONGOLIAN ELLIPSIS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1801,
 },
 [0x1802]={
  category="po",
  description="MONGOLIAN COMMA",
  direction="on",
  linebreak="ex",
  unicodeslot=0x1802,
 },
 [0x1803]={
  category="po",
  description="MONGOLIAN FULL STOP",
  direction="on",
  linebreak="ex",
  unicodeslot=0x1803,
 },
 [0x1804]={
  category="po",
  description="MONGOLIAN COLON",
  direction="on",
  linebreak="ba",
  unicodeslot=0x1804,
 },
 [0x1805]={
  category="po",
  description="MONGOLIAN FOUR DOTS",
  direction="on",
  linebreak="ba",
  unicodeslot=0x1805,
 },
 [0x1806]={
  category="pd",
  description="MONGOLIAN TODO SOFT HYPHEN",
  direction="on",
  linebreak="bb",
  unicodeslot=0x1806,
 },
 [0x1807]={
  category="po",
  description="MONGOLIAN SIBE SYLLABLE BOUNDARY MARKER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1807,
 },
 [0x1808]={
  category="po",
  description="MONGOLIAN MANCHU COMMA",
  direction="on",
  linebreak="ex",
  unicodeslot=0x1808,
 },
 [0x1809]={
  category="po",
  description="MONGOLIAN MANCHU FULL STOP",
  direction="on",
  linebreak="ex",
  unicodeslot=0x1809,
 },
 [0x180A]={
  category="po",
  description="MONGOLIAN NIRUGU",
  direction="on",
  linebreak="al",
  unicodeslot=0x180A,
 },
 [0x180B]={
  category="mn",
  description="MONGOLIAN FREE VARIATION SELECTOR ONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x180B,
 },
 [0x180C]={
  category="mn",
  description="MONGOLIAN FREE VARIATION SELECTOR TWO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x180C,
 },
 [0x180D]={
  category="mn",
  description="MONGOLIAN FREE VARIATION SELECTOR THREE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x180D,
 },
 [0x180E]={
  category="zs",
  description="MONGOLIAN VOWEL SEPARATOR",
  direction="ws",
  linebreak="gl",
  unicodeslot=0x180E,
 },
 [0x1810]={
  category="nd",
  description="MONGOLIAN DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1810,
 },
 [0x1811]={
  category="nd",
  description="MONGOLIAN DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1811,
 },
 [0x1812]={
  category="nd",
  description="MONGOLIAN DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1812,
 },
 [0x1813]={
  category="nd",
  description="MONGOLIAN DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1813,
 },
 [0x1814]={
  category="nd",
  description="MONGOLIAN DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1814,
 },
 [0x1815]={
  category="nd",
  description="MONGOLIAN DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1815,
 },
 [0x1816]={
  category="nd",
  description="MONGOLIAN DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1816,
 },
 [0x1817]={
  category="nd",
  description="MONGOLIAN DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1817,
 },
 [0x1818]={
  category="nd",
  description="MONGOLIAN DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1818,
 },
 [0x1819]={
  category="nd",
  description="MONGOLIAN DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1819,
 },
 [0x1820]={
  category="lo",
  description="MONGOLIAN LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1820,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
  },
 },
 [0x1821]={
  category="lo",
  description="MONGOLIAN LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1821,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1822]={
  category="lo",
  description="MONGOLIAN LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1822,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1823]={
  category="lo",
  description="MONGOLIAN LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1823,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1824]={
  category="lo",
  description="MONGOLIAN LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1824,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1825]={
  category="lo",
  description="MONGOLIAN LETTER OE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1825,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
  },
 },
 [0x1826]={
  category="lo",
  description="MONGOLIAN LETTER UE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1826,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
  },
 },
 [0x1827]={
  category="lo",
  description="MONGOLIAN LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1827,
 },
 [0x1828]={
  category="lo",
  description="MONGOLIAN LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1828,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
   [0x180D]="separate form",
  },
 },
 [0x1829]={
  category="lo",
  description="MONGOLIAN LETTER ANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1829,
 },
 [0x182A]={
  category="lo",
  description="MONGOLIAN LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x182A,
  variants={
   [0x180B]="alternative form",
  },
 },
 [0x182B]={
  category="lo",
  description="MONGOLIAN LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x182B,
 },
 [0x182C]={
  category="lo",
  description="MONGOLIAN LETTER QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x182C,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
   [0x180D]="fourth form",
  },
 },
 [0x182D]={
  category="lo",
  description="MONGOLIAN LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x182D,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
   [0x180D]="feminine form",
  },
 },
 [0x182E]={
  category="lo",
  description="MONGOLIAN LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x182E,
 },
 [0x182F]={
  category="lo",
  description="MONGOLIAN LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x182F,
 },
 [0x1830]={
  category="lo",
  description="MONGOLIAN LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1830,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
  },
 },
 [0x1831]={
  category="lo",
  description="MONGOLIAN LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1831,
 },
 [0x1832]={
  category="lo",
  description="MONGOLIAN LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1832,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1833]={
  category="lo",
  description="MONGOLIAN LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1833,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1834]={
  category="lo",
  description="MONGOLIAN LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1834,
 },
 [0x1835]={
  category="lo",
  description="MONGOLIAN LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1835,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1836]={
  category="lo",
  description="MONGOLIAN LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1836,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
  },
 },
 [0x1837]={
  category="lo",
  description="MONGOLIAN LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1837,
 },
 [0x1838]={
  category="lo",
  description="MONGOLIAN LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1838,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1839]={
  category="lo",
  description="MONGOLIAN LETTER FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1839,
 },
 [0x183A]={
  category="lo",
  description="MONGOLIAN LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x183A,
 },
 [0x183B]={
  category="lo",
  description="MONGOLIAN LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x183B,
 },
 [0x183C]={
  category="lo",
  description="MONGOLIAN LETTER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x183C,
 },
 [0x183D]={
  category="lo",
  description="MONGOLIAN LETTER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x183D,
 },
 [0x183E]={
  category="lo",
  description="MONGOLIAN LETTER HAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x183E,
 },
 [0x183F]={
  category="lo",
  description="MONGOLIAN LETTER ZRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x183F,
 },
 [0x1840]={
  category="lo",
  description="MONGOLIAN LETTER LHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1840,
 },
 [0x1841]={
  category="lo",
  description="MONGOLIAN LETTER ZHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1841,
 },
 [0x1842]={
  category="lo",
  description="MONGOLIAN LETTER CHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1842,
 },
 [0x1843]={
  category="lm",
  description="MONGOLIAN LETTER TODO LONG VOWEL SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1843,
 },
 [0x1844]={
  category="lo",
  description="MONGOLIAN LETTER TODO E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1844,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1845]={
  category="lo",
  description="MONGOLIAN LETTER TODO I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1845,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1846]={
  category="lo",
  description="MONGOLIAN LETTER TODO O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1846,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1847]={
  category="lo",
  description="MONGOLIAN LETTER TODO U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1847,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
  },
 },
 [0x1848]={
  category="lo",
  description="MONGOLIAN LETTER TODO OE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1848,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1849]={
  category="lo",
  description="MONGOLIAN LETTER TODO UE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1849,
  variants={
   [0x180B]="second form",
  },
 },
 [0x184A]={
  category="lo",
  description="MONGOLIAN LETTER TODO ANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x184A,
 },
 [0x184B]={
  category="lo",
  description="MONGOLIAN LETTER TODO BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x184B,
 },
 [0x184C]={
  category="lo",
  description="MONGOLIAN LETTER TODO PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x184C,
 },
 [0x184D]={
  category="lo",
  description="MONGOLIAN LETTER TODO QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x184D,
  variants={
   [0x180B]="feminine form",
  },
 },
 [0x184E]={
  category="lo",
  description="MONGOLIAN LETTER TODO GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x184E,
  variants={
   [0x180B]="second form",
  },
 },
 [0x184F]={
  category="lo",
  description="MONGOLIAN LETTER TODO MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x184F,
 },
 [0x1850]={
  category="lo",
  description="MONGOLIAN LETTER TODO TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1850,
 },
 [0x1851]={
  category="lo",
  description="MONGOLIAN LETTER TODO DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1851,
 },
 [0x1852]={
  category="lo",
  description="MONGOLIAN LETTER TODO CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1852,
 },
 [0x1853]={
  category="lo",
  description="MONGOLIAN LETTER TODO JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1853,
 },
 [0x1854]={
  category="lo",
  description="MONGOLIAN LETTER TODO TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1854,
 },
 [0x1855]={
  category="lo",
  description="MONGOLIAN LETTER TODO YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1855,
 },
 [0x1856]={
  category="lo",
  description="MONGOLIAN LETTER TODO WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1856,
 },
 [0x1857]={
  category="lo",
  description="MONGOLIAN LETTER TODO KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1857,
 },
 [0x1858]={
  category="lo",
  description="MONGOLIAN LETTER TODO GAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1858,
 },
 [0x1859]={
  category="lo",
  description="MONGOLIAN LETTER TODO HAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1859,
 },
 [0x185A]={
  category="lo",
  description="MONGOLIAN LETTER TODO JIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x185A,
 },
 [0x185B]={
  category="lo",
  description="MONGOLIAN LETTER TODO NIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x185B,
 },
 [0x185C]={
  category="lo",
  description="MONGOLIAN LETTER TODO DZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x185C,
 },
 [0x185D]={
  category="lo",
  description="MONGOLIAN LETTER SIBE E",
  direction="l",
  linebreak="al",
  unicodeslot=0x185D,
  variants={
   [0x180B]="second form",
  },
 },
 [0x185E]={
  category="lo",
  description="MONGOLIAN LETTER SIBE I",
  direction="l",
  linebreak="al",
  unicodeslot=0x185E,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
  },
 },
 [0x185F]={
  category="lo",
  description="MONGOLIAN LETTER SIBE IY",
  direction="l",
  linebreak="al",
  unicodeslot=0x185F,
 },
 [0x1860]={
  category="lo",
  description="MONGOLIAN LETTER SIBE UE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1860,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1861]={
  category="lo",
  description="MONGOLIAN LETTER SIBE U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1861,
 },
 [0x1862]={
  category="lo",
  description="MONGOLIAN LETTER SIBE ANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1862,
 },
 [0x1863]={
  category="lo",
  description="MONGOLIAN LETTER SIBE KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1863,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1864]={
  category="lo",
  description="MONGOLIAN LETTER SIBE GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1864,
 },
 [0x1865]={
  category="lo",
  description="MONGOLIAN LETTER SIBE HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1865,
 },
 [0x1866]={
  category="lo",
  description="MONGOLIAN LETTER SIBE PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1866,
 },
 [0x1867]={
  category="lo",
  description="MONGOLIAN LETTER SIBE SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1867,
 },
 [0x1868]={
  category="lo",
  description="MONGOLIAN LETTER SIBE TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1868,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
  },
 },
 [0x1869]={
  category="lo",
  description="MONGOLIAN LETTER SIBE DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1869,
  variants={
   [0x180B]="second form",
  },
 },
 [0x186A]={
  category="lo",
  description="MONGOLIAN LETTER SIBE JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x186A,
 },
 [0x186B]={
  category="lo",
  description="MONGOLIAN LETTER SIBE FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x186B,
 },
 [0x186C]={
  category="lo",
  description="MONGOLIAN LETTER SIBE GAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x186C,
 },
 [0x186D]={
  category="lo",
  description="MONGOLIAN LETTER SIBE HAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x186D,
 },
 [0x186E]={
  category="lo",
  description="MONGOLIAN LETTER SIBE TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x186E,
 },
 [0x186F]={
  category="lo",
  description="MONGOLIAN LETTER SIBE ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x186F,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1870]={
  category="lo",
  description="MONGOLIAN LETTER SIBE RAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1870,
 },
 [0x1871]={
  category="lo",
  description="MONGOLIAN LETTER SIBE CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1871,
 },
 [0x1872]={
  category="lo",
  description="MONGOLIAN LETTER SIBE ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1872,
 },
 [0x1873]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1873,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
   [0x180D]="fourth form",
  },
 },
 [0x1874]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1874,
  variants={
   [0x180B]="second form",
   [0x180C]="feminine first medial form",
   [0x180D]="feminine second medial form",
  },
 },
 [0x1875]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1875,
 },
 [0x1876]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1876,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1877]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1877,
 },
 [0x1880]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI ANUSVARA ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1880,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1881]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI VISARGA ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1881,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1882]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI DAMARU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1882,
 },
 [0x1883]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI UBADAMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1883,
 },
 [0x1884]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI INVERTED UBADAMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1884,
 },
 [0x1885]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI BALUDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1885,
 },
 [0x1886]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI THREE BALUDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1886,
 },
 [0x1887]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1887,
  variants={
   [0x180B]="second form",
   [0x180C]="third form",
   [0x180D]="fourth form",
  },
 },
 [0x1888]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1888,
  variants={
   [0x180B]="second form",
  },
 },
 [0x1889]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1889,
 },
 [0x188A]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x188A,
  variants={
   [0x180B]="second form",
  },
 },
 [0x188B]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x188B,
 },
 [0x188C]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x188C,
 },
 [0x188D]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x188D,
 },
 [0x188E]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x188E,
 },
 [0x188F]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x188F,
 },
 [0x1890]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1890,
 },
 [0x1891]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1891,
 },
 [0x1892]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1892,
 },
 [0x1893]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1893,
 },
 [0x1894]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1894,
 },
 [0x1895]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1895,
 },
 [0x1896]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1896,
 },
 [0x1897]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI AH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1897,
 },
 [0x1898]={
  category="lo",
  description="MONGOLIAN LETTER TODO ALI GALI TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1898,
 },
 [0x1899]={
  category="lo",
  description="MONGOLIAN LETTER TODO ALI GALI ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1899,
 },
 [0x189A]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x189A,
 },
 [0x189B]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x189B,
 },
 [0x189C]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x189C,
 },
 [0x189D]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x189D,
 },
 [0x189E]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x189E,
 },
 [0x189F]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x189F,
 },
 [0x18A0]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A0,
 },
 [0x18A1]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A1,
 },
 [0x18A2]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A2,
 },
 [0x18A3]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI CYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A3,
 },
 [0x18A4]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A4,
 },
 [0x18A5]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A5,
 },
 [0x18A6]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI HALF U",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A6,
 },
 [0x18A7]={
  category="lo",
  description="MONGOLIAN LETTER ALI GALI HALF YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A7,
 },
 [0x18A8]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18A8,
 },
 [0x18A9]={
  category="mn",
  description="MONGOLIAN LETTER ALI GALI DAGALGA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x18A9,
 },
 [0x18AA]={
  category="lo",
  description="MONGOLIAN LETTER MANCHU ALI GALI LHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18AA,
 },
 [0x18B0]={
  category="lo",
  description="CANADIAN SYLLABICS OY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B0,
 },
 [0x18B1]={
  category="lo",
  description="CANADIAN SYLLABICS AY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B1,
 },
 [0x18B2]={
  category="lo",
  description="CANADIAN SYLLABICS AAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B2,
 },
 [0x18B3]={
  category="lo",
  description="CANADIAN SYLLABICS WAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B3,
 },
 [0x18B4]={
  category="lo",
  description="CANADIAN SYLLABICS POY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B4,
 },
 [0x18B5]={
  category="lo",
  description="CANADIAN SYLLABICS PAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B5,
 },
 [0x18B6]={
  category="lo",
  description="CANADIAN SYLLABICS PWOY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B6,
 },
 [0x18B7]={
  category="lo",
  description="CANADIAN SYLLABICS TAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B7,
 },
 [0x18B8]={
  category="lo",
  description="CANADIAN SYLLABICS KAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B8,
 },
 [0x18B9]={
  category="lo",
  description="CANADIAN SYLLABICS KWAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18B9,
 },
 [0x18BA]={
  category="lo",
  description="CANADIAN SYLLABICS MAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18BA,
 },
 [0x18BB]={
  category="lo",
  description="CANADIAN SYLLABICS NOY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18BB,
 },
 [0x18BC]={
  category="lo",
  description="CANADIAN SYLLABICS NAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18BC,
 },
 [0x18BD]={
  category="lo",
  description="CANADIAN SYLLABICS LAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18BD,
 },
 [0x18BE]={
  category="lo",
  description="CANADIAN SYLLABICS SOY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18BE,
 },
 [0x18BF]={
  category="lo",
  description="CANADIAN SYLLABICS SAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18BF,
 },
 [0x18C0]={
  category="lo",
  description="CANADIAN SYLLABICS SHOY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C0,
 },
 [0x18C1]={
  category="lo",
  description="CANADIAN SYLLABICS SHAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C1,
 },
 [0x18C2]={
  category="lo",
  description="CANADIAN SYLLABICS SHWOY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C2,
 },
 [0x18C3]={
  category="lo",
  description="CANADIAN SYLLABICS YOY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C3,
 },
 [0x18C4]={
  category="lo",
  description="CANADIAN SYLLABICS YAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C4,
 },
 [0x18C5]={
  category="lo",
  description="CANADIAN SYLLABICS RAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C5,
 },
 [0x18C6]={
  category="lo",
  description="CANADIAN SYLLABICS NWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C6,
 },
 [0x18C7]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY NWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C7,
 },
 [0x18C8]={
  category="lo",
  description="CANADIAN SYLLABICS NWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C8,
 },
 [0x18C9]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY NWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x18C9,
 },
 [0x18CA]={
  category="lo",
  description="CANADIAN SYLLABICS NWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18CA,
 },
 [0x18CB]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY NWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18CB,
 },
 [0x18CC]={
  category="lo",
  description="CANADIAN SYLLABICS NWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18CC,
 },
 [0x18CD]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY NWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18CD,
 },
 [0x18CE]={
  category="lo",
  description="CANADIAN SYLLABICS RWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x18CE,
 },
 [0x18CF]={
  category="lo",
  description="CANADIAN SYLLABICS RWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x18CF,
 },
 [0x18D0]={
  category="lo",
  description="CANADIAN SYLLABICS RWII",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D0,
 },
 [0x18D1]={
  category="lo",
  description="CANADIAN SYLLABICS RWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D1,
 },
 [0x18D2]={
  category="lo",
  description="CANADIAN SYLLABICS RWOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D2,
 },
 [0x18D3]={
  category="lo",
  description="CANADIAN SYLLABICS RWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D3,
 },
 [0x18D4]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY P",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D4,
 },
 [0x18D5]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY T",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D5,
 },
 [0x18D6]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY K",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D6,
 },
 [0x18D7]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY C",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D7,
 },
 [0x18D8]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY M",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D8,
 },
 [0x18D9]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY N",
  direction="l",
  linebreak="al",
  unicodeslot=0x18D9,
 },
 [0x18DA]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY S",
  direction="l",
  linebreak="al",
  unicodeslot=0x18DA,
 },
 [0x18DB]={
  category="lo",
  description="CANADIAN SYLLABICS OJIBWAY SH",
  direction="l",
  linebreak="al",
  unicodeslot=0x18DB,
 },
 [0x18DC]={
  category="lo",
  description="CANADIAN SYLLABICS EASTERN W",
  direction="l",
  linebreak="al",
  unicodeslot=0x18DC,
 },
 [0x18DD]={
  category="lo",
  description="CANADIAN SYLLABICS WESTERN W",
  direction="l",
  linebreak="al",
  unicodeslot=0x18DD,
 },
 [0x18DE]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL SMALL RING",
  direction="l",
  linebreak="al",
  unicodeslot=0x18DE,
 },
 [0x18DF]={
  category="lo",
  description="CANADIAN SYLLABICS FINAL RAISED DOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x18DF,
 },
 [0x18E0]={
  category="lo",
  description="CANADIAN SYLLABICS R-CREE RWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E0,
 },
 [0x18E1]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E1,
 },
 [0x18E2]={
  category="lo",
  description="CANADIAN SYLLABICS WEST-CREE LAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E2,
 },
 [0x18E3]={
  category="lo",
  description="CANADIAN SYLLABICS THWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E3,
 },
 [0x18E4]={
  category="lo",
  description="CANADIAN SYLLABICS THWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E4,
 },
 [0x18E5]={
  category="lo",
  description="CANADIAN SYLLABICS TTHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E5,
 },
 [0x18E6]={
  category="lo",
  description="CANADIAN SYLLABICS TTHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E6,
 },
 [0x18E7]={
  category="lo",
  description="CANADIAN SYLLABICS TTHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E7,
 },
 [0x18E8]={
  category="lo",
  description="CANADIAN SYLLABICS TLHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E8,
 },
 [0x18E9]={
  category="lo",
  description="CANADIAN SYLLABICS TLHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18E9,
 },
 [0x18EA]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI SHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x18EA,
 },
 [0x18EB]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI SHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18EB,
 },
 [0x18EC]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI HOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x18EC,
 },
 [0x18ED]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GWU",
  direction="l",
  linebreak="al",
  unicodeslot=0x18ED,
 },
 [0x18EE]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DENE GEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x18EE,
 },
 [0x18EF]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18EF,
 },
 [0x18F0]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER GWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18F0,
 },
 [0x18F1]={
  category="lo",
  description="CANADIAN SYLLABICS SAYISI JUU",
  direction="l",
  linebreak="al",
  unicodeslot=0x18F1,
 },
 [0x18F2]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER JWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x18F2,
 },
 [0x18F3]={
  category="lo",
  description="CANADIAN SYLLABICS BEAVER DENE L",
  direction="l",
  linebreak="al",
  unicodeslot=0x18F3,
 },
 [0x18F4]={
  category="lo",
  description="CANADIAN SYLLABICS BEAVER DENE R",
  direction="l",
  linebreak="al",
  unicodeslot=0x18F4,
 },
 [0x18F5]={
  category="lo",
  description="CANADIAN SYLLABICS CARRIER DENTAL S",
  direction="l",
  linebreak="al",
  unicodeslot=0x18F5,
 },
 [0x1900]={
  category="lo",
  description="LIMBU VOWEL-CARRIER LETTER",
  direction="l",
  linebreak="al",
  unicodeslot=0x1900,
 },
 [0x1901]={
  category="lo",
  description="LIMBU LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1901,
 },
 [0x1902]={
  category="lo",
  description="LIMBU LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1902,
 },
 [0x1903]={
  category="lo",
  description="LIMBU LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1903,
 },
 [0x1904]={
  category="lo",
  description="LIMBU LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1904,
 },
 [0x1905]={
  category="lo",
  description="LIMBU LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1905,
 },
 [0x1906]={
  category="lo",
  description="LIMBU LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1906,
 },
 [0x1907]={
  category="lo",
  description="LIMBU LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1907,
 },
 [0x1908]={
  category="lo",
  description="LIMBU LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1908,
 },
 [0x1909]={
  category="lo",
  description="LIMBU LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1909,
 },
 [0x190A]={
  category="lo",
  description="LIMBU LETTER YAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x190A,
 },
 [0x190B]={
  category="lo",
  description="LIMBU LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x190B,
 },
 [0x190C]={
  category="lo",
  description="LIMBU LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x190C,
 },
 [0x190D]={
  category="lo",
  description="LIMBU LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x190D,
 },
 [0x190E]={
  category="lo",
  description="LIMBU LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x190E,
 },
 [0x190F]={
  category="lo",
  description="LIMBU LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x190F,
 },
 [0x1910]={
  category="lo",
  description="LIMBU LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1910,
 },
 [0x1911]={
  category="lo",
  description="LIMBU LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1911,
 },
 [0x1912]={
  category="lo",
  description="LIMBU LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1912,
 },
 [0x1913]={
  category="lo",
  description="LIMBU LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1913,
 },
 [0x1914]={
  category="lo",
  description="LIMBU LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1914,
 },
 [0x1915]={
  category="lo",
  description="LIMBU LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1915,
 },
 [0x1916]={
  category="lo",
  description="LIMBU LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1916,
 },
 [0x1917]={
  category="lo",
  description="LIMBU LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1917,
 },
 [0x1918]={
  category="lo",
  description="LIMBU LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1918,
 },
 [0x1919]={
  category="lo",
  description="LIMBU LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1919,
 },
 [0x191A]={
  category="lo",
  description="LIMBU LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x191A,
 },
 [0x191B]={
  category="lo",
  description="LIMBU LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x191B,
 },
 [0x191C]={
  category="lo",
  description="LIMBU LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x191C,
 },
 [0x1920]={
  category="mn",
  description="LIMBU VOWEL SIGN A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1920,
 },
 [0x1921]={
  category="mn",
  description="LIMBU VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1921,
 },
 [0x1922]={
  category="mn",
  description="LIMBU VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1922,
 },
 [0x1923]={
  category="mc",
  description="LIMBU VOWEL SIGN EE",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1923,
 },
 [0x1924]={
  category="mc",
  description="LIMBU VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1924,
 },
 [0x1925]={
  category="mc",
  description="LIMBU VOWEL SIGN OO",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1925,
 },
 [0x1926]={
  category="mc",
  description="LIMBU VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1926,
 },
 [0x1927]={
  category="mn",
  description="LIMBU VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1927,
 },
 [0x1928]={
  category="mn",
  description="LIMBU VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1928,
 },
 [0x1929]={
  category="mc",
  description="LIMBU SUBJOINED LETTER YA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1929,
 },
 [0x192A]={
  category="mc",
  description="LIMBU SUBJOINED LETTER RA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x192A,
 },
 [0x192B]={
  category="mc",
  description="LIMBU SUBJOINED LETTER WA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x192B,
 },
 [0x1930]={
  category="mc",
  description="LIMBU SMALL LETTER KA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1930,
 },
 [0x1931]={
  category="mc",
  description="LIMBU SMALL LETTER NGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1931,
 },
 [0x1932]={
  category="mn",
  description="LIMBU SMALL LETTER ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1932,
 },
 [0x1933]={
  category="mc",
  description="LIMBU SMALL LETTER TA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1933,
 },
 [0x1934]={
  category="mc",
  description="LIMBU SMALL LETTER NA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1934,
 },
 [0x1935]={
  category="mc",
  description="LIMBU SMALL LETTER PA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1935,
 },
 [0x1936]={
  category="mc",
  description="LIMBU SMALL LETTER MA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1936,
 },
 [0x1937]={
  category="mc",
  description="LIMBU SMALL LETTER RA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1937,
 },
 [0x1938]={
  category="mc",
  description="LIMBU SMALL LETTER LA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1938,
 },
 [0x1939]={
  category="mn",
  description="LIMBU SIGN MUKPHRENG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1939,
 },
 [0x193A]={
  category="mn",
  description="LIMBU SIGN KEMPHRENG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x193A,
 },
 [0x193B]={
  category="mn",
  description="LIMBU SIGN SA-I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x193B,
 },
 [0x1940]={
  category="so",
  description="LIMBU SIGN LOO",
  direction="on",
  linebreak="al",
  unicodeslot=0x1940,
 },
 [0x1944]={
  category="po",
  description="LIMBU EXCLAMATION MARK",
  direction="on",
  linebreak="ex",
  unicodeslot=0x1944,
 },
 [0x1945]={
  category="po",
  description="LIMBU QUESTION MARK",
  direction="on",
  linebreak="ex",
  unicodeslot=0x1945,
 },
 [0x1946]={
  category="nd",
  description="LIMBU DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1946,
 },
 [0x1947]={
  category="nd",
  description="LIMBU DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1947,
 },
 [0x1948]={
  category="nd",
  description="LIMBU DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1948,
 },
 [0x1949]={
  category="nd",
  description="LIMBU DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1949,
 },
 [0x194A]={
  category="nd",
  description="LIMBU DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x194A,
 },
 [0x194B]={
  category="nd",
  description="LIMBU DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x194B,
 },
 [0x194C]={
  category="nd",
  description="LIMBU DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x194C,
 },
 [0x194D]={
  category="nd",
  description="LIMBU DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x194D,
 },
 [0x194E]={
  category="nd",
  description="LIMBU DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x194E,
 },
 [0x194F]={
  category="nd",
  description="LIMBU DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x194F,
 },
 [0x1950]={
  category="lo",
  description="TAI LE LETTER KA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1950,
 },
 [0x1951]={
  category="lo",
  description="TAI LE LETTER XA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1951,
 },
 [0x1952]={
  category="lo",
  description="TAI LE LETTER NGA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1952,
 },
 [0x1953]={
  category="lo",
  description="TAI LE LETTER TSA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1953,
 },
 [0x1954]={
  category="lo",
  description="TAI LE LETTER SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1954,
 },
 [0x1955]={
  category="lo",
  description="TAI LE LETTER YA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1955,
 },
 [0x1956]={
  category="lo",
  description="TAI LE LETTER TA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1956,
 },
 [0x1957]={
  category="lo",
  description="TAI LE LETTER THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1957,
 },
 [0x1958]={
  category="lo",
  description="TAI LE LETTER LA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1958,
 },
 [0x1959]={
  category="lo",
  description="TAI LE LETTER PA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1959,
 },
 [0x195A]={
  category="lo",
  description="TAI LE LETTER PHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x195A,
 },
 [0x195B]={
  category="lo",
  description="TAI LE LETTER MA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x195B,
 },
 [0x195C]={
  category="lo",
  description="TAI LE LETTER FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x195C,
 },
 [0x195D]={
  category="lo",
  description="TAI LE LETTER VA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x195D,
 },
 [0x195E]={
  category="lo",
  description="TAI LE LETTER HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x195E,
 },
 [0x195F]={
  category="lo",
  description="TAI LE LETTER QA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x195F,
 },
 [0x1960]={
  category="lo",
  description="TAI LE LETTER KHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1960,
 },
 [0x1961]={
  category="lo",
  description="TAI LE LETTER TSHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1961,
 },
 [0x1962]={
  category="lo",
  description="TAI LE LETTER NA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1962,
 },
 [0x1963]={
  category="lo",
  description="TAI LE LETTER A",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1963,
 },
 [0x1964]={
  category="lo",
  description="TAI LE LETTER I",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1964,
 },
 [0x1965]={
  category="lo",
  description="TAI LE LETTER EE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1965,
 },
 [0x1966]={
  category="lo",
  description="TAI LE LETTER EH",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1966,
 },
 [0x1967]={
  category="lo",
  description="TAI LE LETTER U",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1967,
 },
 [0x1968]={
  category="lo",
  description="TAI LE LETTER OO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1968,
 },
 [0x1969]={
  category="lo",
  description="TAI LE LETTER O",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1969,
 },
 [0x196A]={
  category="lo",
  description="TAI LE LETTER UE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x196A,
 },
 [0x196B]={
  category="lo",
  description="TAI LE LETTER E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x196B,
 },
 [0x196C]={
  category="lo",
  description="TAI LE LETTER AUE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x196C,
 },
 [0x196D]={
  category="lo",
  description="TAI LE LETTER AI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x196D,
 },
 [0x1970]={
  category="lo",
  description="TAI LE LETTER TONE-0x0002",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1970,
 },
 [0x1971]={
  category="lo",
  description="TAI LE LETTER TONE-0x0003",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1971,
 },
 [0x1972]={
  category="lo",
  description="TAI LE LETTER TONE-0x0004",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1972,
 },
 [0x1973]={
  category="lo",
  description="TAI LE LETTER TONE-0x0005",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1973,
 },
 [0x1974]={
  category="lo",
  description="TAI LE LETTER TONE-0x0006",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1974,
 },
 [0x1980]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH QA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1980,
 },
 [0x1981]={
  category="lo",
  description="NEW TAI LUE LETTER LOW QA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1981,
 },
 [0x1982]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH KA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1982,
 },
 [0x1983]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH XA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1983,
 },
 [0x1984]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH NGA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1984,
 },
 [0x1985]={
  category="lo",
  description="NEW TAI LUE LETTER LOW KA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1985,
 },
 [0x1986]={
  category="lo",
  description="NEW TAI LUE LETTER LOW XA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1986,
 },
 [0x1987]={
  category="lo",
  description="NEW TAI LUE LETTER LOW NGA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1987,
 },
 [0x1988]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH TSA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1988,
 },
 [0x1989]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1989,
 },
 [0x198A]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH YA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x198A,
 },
 [0x198B]={
  category="lo",
  description="NEW TAI LUE LETTER LOW TSA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x198B,
 },
 [0x198C]={
  category="lo",
  description="NEW TAI LUE LETTER LOW SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x198C,
 },
 [0x198D]={
  category="lo",
  description="NEW TAI LUE LETTER LOW YA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x198D,
 },
 [0x198E]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH TA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x198E,
 },
 [0x198F]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x198F,
 },
 [0x1990]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH NA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1990,
 },
 [0x1991]={
  category="lo",
  description="NEW TAI LUE LETTER LOW TA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1991,
 },
 [0x1992]={
  category="lo",
  description="NEW TAI LUE LETTER LOW THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1992,
 },
 [0x1993]={
  category="lo",
  description="NEW TAI LUE LETTER LOW NA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1993,
 },
 [0x1994]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH PA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1994,
 },
 [0x1995]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH PHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1995,
 },
 [0x1996]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH MA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1996,
 },
 [0x1997]={
  category="lo",
  description="NEW TAI LUE LETTER LOW PA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1997,
 },
 [0x1998]={
  category="lo",
  description="NEW TAI LUE LETTER LOW PHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1998,
 },
 [0x1999]={
  category="lo",
  description="NEW TAI LUE LETTER LOW MA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1999,
 },
 [0x199A]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x199A,
 },
 [0x199B]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH VA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x199B,
 },
 [0x199C]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH LA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x199C,
 },
 [0x199D]={
  category="lo",
  description="NEW TAI LUE LETTER LOW FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x199D,
 },
 [0x199E]={
  category="lo",
  description="NEW TAI LUE LETTER LOW VA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x199E,
 },
 [0x199F]={
  category="lo",
  description="NEW TAI LUE LETTER LOW LA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x199F,
 },
 [0x19A0]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A0,
 },
 [0x19A1]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH DA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A1,
 },
 [0x19A2]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH BA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A2,
 },
 [0x19A3]={
  category="lo",
  description="NEW TAI LUE LETTER LOW HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A3,
 },
 [0x19A4]={
  category="lo",
  description="NEW TAI LUE LETTER LOW DA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A4,
 },
 [0x19A5]={
  category="lo",
  description="NEW TAI LUE LETTER LOW BA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A5,
 },
 [0x19A6]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH KVA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A6,
 },
 [0x19A7]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH XVA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A7,
 },
 [0x19A8]={
  category="lo",
  description="NEW TAI LUE LETTER LOW KVA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A8,
 },
 [0x19A9]={
  category="lo",
  description="NEW TAI LUE LETTER LOW XVA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19A9,
 },
 [0x19AA]={
  category="lo",
  description="NEW TAI LUE LETTER HIGH SUA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19AA,
 },
 [0x19AB]={
  category="lo",
  description="NEW TAI LUE LETTER LOW SUA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19AB,
 },
 [0x19B0]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN VOWEL SHORTENER",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B0,
 },
 [0x19B1]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B1,
 },
 [0x19B2]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN II",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B2,
 },
 [0x19B3]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN U",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B3,
 },
 [0x19B4]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN UU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B4,
 },
 [0x19B5]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B5,
 },
 [0x19B6]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN AE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B6,
 },
 [0x19B7]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN O",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B7,
 },
 [0x19B8]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN OA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B8,
 },
 [0x19B9]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN UE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19B9,
 },
 [0x19BA]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN AY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19BA,
 },
 [0x19BB]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN AAY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19BB,
 },
 [0x19BC]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN UY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19BC,
 },
 [0x19BD]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN OY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19BD,
 },
 [0x19BE]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN OAY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19BE,
 },
 [0x19BF]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN UEY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19BF,
 },
 [0x19C0]={
  category="mc",
  description="NEW TAI LUE VOWEL SIGN IY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C0,
 },
 [0x19C1]={
  category="lo",
  description="NEW TAI LUE LETTER FINAL V",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C1,
 },
 [0x19C2]={
  category="lo",
  description="NEW TAI LUE LETTER FINAL NG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C2,
 },
 [0x19C3]={
  category="lo",
  description="NEW TAI LUE LETTER FINAL N",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C3,
 },
 [0x19C4]={
  category="lo",
  description="NEW TAI LUE LETTER FINAL M",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C4,
 },
 [0x19C5]={
  category="lo",
  description="NEW TAI LUE LETTER FINAL K",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C5,
 },
 [0x19C6]={
  category="lo",
  description="NEW TAI LUE LETTER FINAL D",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C6,
 },
 [0x19C7]={
  category="lo",
  description="NEW TAI LUE LETTER FINAL B",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C7,
 },
 [0x19C8]={
  category="mc",
  description="NEW TAI LUE TONE MARK-0x0001",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C8,
 },
 [0x19C9]={
  category="mc",
  description="NEW TAI LUE TONE MARK-0x0002",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19C9,
 },
 [0x19D0]={
  category="nd",
  description="NEW TAI LUE DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D0,
 },
 [0x19D1]={
  category="nd",
  description="NEW TAI LUE DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D1,
 },
 [0x19D2]={
  category="nd",
  description="NEW TAI LUE DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D2,
 },
 [0x19D3]={
  category="nd",
  description="NEW TAI LUE DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D3,
 },
 [0x19D4]={
  category="nd",
  description="NEW TAI LUE DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D4,
 },
 [0x19D5]={
  category="nd",
  description="NEW TAI LUE DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D5,
 },
 [0x19D6]={
  category="nd",
  description="NEW TAI LUE DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D6,
 },
 [0x19D7]={
  category="nd",
  description="NEW TAI LUE DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D7,
 },
 [0x19D8]={
  category="nd",
  description="NEW TAI LUE DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D8,
 },
 [0x19D9]={
  category="nd",
  description="NEW TAI LUE DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x19D9,
 },
 [0x19DA]={
  category="no",
  description="NEW TAI LUE THAM DIGIT ONE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x19DA,
 },
 [0x19DE]={
  category="po",
  description="NEW TAI LUE SIGN LAE",
  direction="on",
  linebreak="sa",
  unicodeslot=0x19DE,
 },
 [0x19DF]={
  category="po",
  description="NEW TAI LUE SIGN LAEV",
  direction="on",
  linebreak="sa",
  unicodeslot=0x19DF,
 },
 [0x19E0]={
  category="so",
  description="KHMER SYMBOL PATHAMASAT",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E0,
 },
 [0x19E1]={
  category="so",
  description="KHMER SYMBOL MUOY KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E1,
 },
 [0x19E2]={
  category="so",
  description="KHMER SYMBOL PII KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E2,
 },
 [0x19E3]={
  category="so",
  description="KHMER SYMBOL BEI KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E3,
 },
 [0x19E4]={
  category="so",
  description="KHMER SYMBOL BUON KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E4,
 },
 [0x19E5]={
  category="so",
  description="KHMER SYMBOL PRAM KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E5,
 },
 [0x19E6]={
  category="so",
  description="KHMER SYMBOL PRAM-MUOY KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E6,
 },
 [0x19E7]={
  category="so",
  description="KHMER SYMBOL PRAM-PII KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E7,
 },
 [0x19E8]={
  category="so",
  description="KHMER SYMBOL PRAM-BEI KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E8,
 },
 [0x19E9]={
  category="so",
  description="KHMER SYMBOL PRAM-BUON KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19E9,
 },
 [0x19EA]={
  category="so",
  description="KHMER SYMBOL DAP KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19EA,
 },
 [0x19EB]={
  category="so",
  description="KHMER SYMBOL DAP-MUOY KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19EB,
 },
 [0x19EC]={
  category="so",
  description="KHMER SYMBOL DAP-PII KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19EC,
 },
 [0x19ED]={
  category="so",
  description="KHMER SYMBOL DAP-BEI KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19ED,
 },
 [0x19EE]={
  category="so",
  description="KHMER SYMBOL DAP-BUON KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19EE,
 },
 [0x19EF]={
  category="so",
  description="KHMER SYMBOL DAP-PRAM KOET",
  direction="on",
  linebreak="al",
  unicodeslot=0x19EF,
 },
 [0x19F0]={
  category="so",
  description="KHMER SYMBOL TUTEYASAT",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F0,
 },
 [0x19F1]={
  category="so",
  description="KHMER SYMBOL MUOY ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F1,
 },
 [0x19F2]={
  category="so",
  description="KHMER SYMBOL PII ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F2,
 },
 [0x19F3]={
  category="so",
  description="KHMER SYMBOL BEI ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F3,
 },
 [0x19F4]={
  category="so",
  description="KHMER SYMBOL BUON ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F4,
 },
 [0x19F5]={
  category="so",
  description="KHMER SYMBOL PRAM ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F5,
 },
 [0x19F6]={
  category="so",
  description="KHMER SYMBOL PRAM-MUOY ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F6,
 },
 [0x19F7]={
  category="so",
  description="KHMER SYMBOL PRAM-PII ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F7,
 },
 [0x19F8]={
  category="so",
  description="KHMER SYMBOL PRAM-BEI ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F8,
 },
 [0x19F9]={
  category="so",
  description="KHMER SYMBOL PRAM-BUON ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19F9,
 },
 [0x19FA]={
  category="so",
  description="KHMER SYMBOL DAP ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19FA,
 },
 [0x19FB]={
  category="so",
  description="KHMER SYMBOL DAP-MUOY ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19FB,
 },
 [0x19FC]={
  category="so",
  description="KHMER SYMBOL DAP-PII ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19FC,
 },
 [0x19FD]={
  category="so",
  description="KHMER SYMBOL DAP-BEI ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19FD,
 },
 [0x19FE]={
  category="so",
  description="KHMER SYMBOL DAP-BUON ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19FE,
 },
 [0x19FF]={
  category="so",
  description="KHMER SYMBOL DAP-PRAM ROC",
  direction="on",
  linebreak="al",
  unicodeslot=0x19FF,
 },
 [0x1A00]={
  category="lo",
  description="BUGINESE LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A00,
 },
 [0x1A01]={
  category="lo",
  description="BUGINESE LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A01,
 },
 [0x1A02]={
  category="lo",
  description="BUGINESE LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A02,
 },
 [0x1A03]={
  category="lo",
  description="BUGINESE LETTER NGKA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A03,
 },
 [0x1A04]={
  category="lo",
  description="BUGINESE LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A04,
 },
 [0x1A05]={
  category="lo",
  description="BUGINESE LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A05,
 },
 [0x1A06]={
  category="lo",
  description="BUGINESE LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A06,
 },
 [0x1A07]={
  category="lo",
  description="BUGINESE LETTER MPA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A07,
 },
 [0x1A08]={
  category="lo",
  description="BUGINESE LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A08,
 },
 [0x1A09]={
  category="lo",
  description="BUGINESE LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A09,
 },
 [0x1A0A]={
  category="lo",
  description="BUGINESE LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A0A,
 },
 [0x1A0B]={
  category="lo",
  description="BUGINESE LETTER NRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A0B,
 },
 [0x1A0C]={
  category="lo",
  description="BUGINESE LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A0C,
 },
 [0x1A0D]={
  category="lo",
  description="BUGINESE LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A0D,
 },
 [0x1A0E]={
  category="lo",
  description="BUGINESE LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A0E,
 },
 [0x1A0F]={
  category="lo",
  description="BUGINESE LETTER NYCA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A0F,
 },
 [0x1A10]={
  category="lo",
  description="BUGINESE LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A10,
 },
 [0x1A11]={
  category="lo",
  description="BUGINESE LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A11,
 },
 [0x1A12]={
  category="lo",
  description="BUGINESE LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A12,
 },
 [0x1A13]={
  category="lo",
  description="BUGINESE LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A13,
 },
 [0x1A14]={
  category="lo",
  description="BUGINESE LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A14,
 },
 [0x1A15]={
  category="lo",
  description="BUGINESE LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A15,
 },
 [0x1A16]={
  category="lo",
  description="BUGINESE LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A16,
 },
 [0x1A17]={
  category="mn",
  description="BUGINESE VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1A17,
 },
 [0x1A18]={
  category="mn",
  description="BUGINESE VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1A18,
 },
 [0x1A19]={
  category="mc",
  description="BUGINESE VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1A19,
 },
 [0x1A1A]={
  category="mc",
  description="BUGINESE VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1A1A,
 },
 [0x1A1B]={
  category="mc",
  description="BUGINESE VOWEL SIGN AE",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1A1B,
 },
 [0x1A1E]={
  category="po",
  description="BUGINESE PALLAWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A1E,
 },
 [0x1A1F]={
  category="po",
  description="BUGINESE END OF SECTION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1A1F,
 },
 [0x1A20]={
  category="lo",
  description="TAI THAM LETTER HIGH KA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A20,
 },
 [0x1A21]={
  category="lo",
  description="TAI THAM LETTER HIGH KHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A21,
 },
 [0x1A22]={
  category="lo",
  description="TAI THAM LETTER HIGH KXA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A22,
 },
 [0x1A23]={
  category="lo",
  description="TAI THAM LETTER LOW KA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A23,
 },
 [0x1A24]={
  category="lo",
  description="TAI THAM LETTER LOW KXA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A24,
 },
 [0x1A25]={
  category="lo",
  description="TAI THAM LETTER LOW KHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A25,
 },
 [0x1A26]={
  category="lo",
  description="TAI THAM LETTER NGA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A26,
 },
 [0x1A27]={
  category="lo",
  description="TAI THAM LETTER HIGH CA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A27,
 },
 [0x1A28]={
  category="lo",
  description="TAI THAM LETTER HIGH CHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A28,
 },
 [0x1A29]={
  category="lo",
  description="TAI THAM LETTER LOW CA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A29,
 },
 [0x1A2A]={
  category="lo",
  description="TAI THAM LETTER LOW SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A2A,
 },
 [0x1A2B]={
  category="lo",
  description="TAI THAM LETTER LOW CHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A2B,
 },
 [0x1A2C]={
  category="lo",
  description="TAI THAM LETTER NYA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A2C,
 },
 [0x1A2D]={
  category="lo",
  description="TAI THAM LETTER RATA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A2D,
 },
 [0x1A2E]={
  category="lo",
  description="TAI THAM LETTER HIGH RATHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A2E,
 },
 [0x1A2F]={
  category="lo",
  description="TAI THAM LETTER DA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A2F,
 },
 [0x1A30]={
  category="lo",
  description="TAI THAM LETTER LOW RATHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A30,
 },
 [0x1A31]={
  category="lo",
  description="TAI THAM LETTER RANA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A31,
 },
 [0x1A32]={
  category="lo",
  description="TAI THAM LETTER HIGH TA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A32,
 },
 [0x1A33]={
  category="lo",
  description="TAI THAM LETTER HIGH THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A33,
 },
 [0x1A34]={
  category="lo",
  description="TAI THAM LETTER LOW TA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A34,
 },
 [0x1A35]={
  category="lo",
  description="TAI THAM LETTER LOW THA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A35,
 },
 [0x1A36]={
  category="lo",
  description="TAI THAM LETTER NA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A36,
 },
 [0x1A37]={
  category="lo",
  description="TAI THAM LETTER BA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A37,
 },
 [0x1A38]={
  category="lo",
  description="TAI THAM LETTER HIGH PA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A38,
 },
 [0x1A39]={
  category="lo",
  description="TAI THAM LETTER HIGH PHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A39,
 },
 [0x1A3A]={
  category="lo",
  description="TAI THAM LETTER HIGH FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A3A,
 },
 [0x1A3B]={
  category="lo",
  description="TAI THAM LETTER LOW PA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A3B,
 },
 [0x1A3C]={
  category="lo",
  description="TAI THAM LETTER LOW FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A3C,
 },
 [0x1A3D]={
  category="lo",
  description="TAI THAM LETTER LOW PHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A3D,
 },
 [0x1A3E]={
  category="lo",
  description="TAI THAM LETTER MA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A3E,
 },
 [0x1A3F]={
  category="lo",
  description="TAI THAM LETTER LOW YA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A3F,
 },
 [0x1A40]={
  category="lo",
  description="TAI THAM LETTER HIGH YA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A40,
 },
 [0x1A41]={
  category="lo",
  description="TAI THAM LETTER RA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A41,
 },
 [0x1A42]={
  category="lo",
  description="TAI THAM LETTER RUE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A42,
 },
 [0x1A43]={
  category="lo",
  description="TAI THAM LETTER LA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A43,
 },
 [0x1A44]={
  category="lo",
  description="TAI THAM LETTER LUE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A44,
 },
 [0x1A45]={
  category="lo",
  description="TAI THAM LETTER WA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A45,
 },
 [0x1A46]={
  category="lo",
  description="TAI THAM LETTER HIGH SHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A46,
 },
 [0x1A47]={
  category="lo",
  description="TAI THAM LETTER HIGH SSA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A47,
 },
 [0x1A48]={
  category="lo",
  description="TAI THAM LETTER HIGH SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A48,
 },
 [0x1A49]={
  category="lo",
  description="TAI THAM LETTER HIGH HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A49,
 },
 [0x1A4A]={
  category="lo",
  description="TAI THAM LETTER LLA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A4A,
 },
 [0x1A4B]={
  category="lo",
  description="TAI THAM LETTER A",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A4B,
 },
 [0x1A4C]={
  category="lo",
  description="TAI THAM LETTER LOW HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A4C,
 },
 [0x1A4D]={
  category="lo",
  description="TAI THAM LETTER I",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A4D,
 },
 [0x1A4E]={
  category="lo",
  description="TAI THAM LETTER II",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A4E,
 },
 [0x1A4F]={
  category="lo",
  description="TAI THAM LETTER U",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A4F,
 },
 [0x1A50]={
  category="lo",
  description="TAI THAM LETTER UU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A50,
 },
 [0x1A51]={
  category="lo",
  description="TAI THAM LETTER EE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A51,
 },
 [0x1A52]={
  category="lo",
  description="TAI THAM LETTER OO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A52,
 },
 [0x1A53]={
  category="lo",
  description="TAI THAM LETTER LAE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A53,
 },
 [0x1A54]={
  category="lo",
  description="TAI THAM LETTER GREAT SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A54,
 },
 [0x1A55]={
  category="mc",
  description="TAI THAM CONSONANT SIGN MEDIAL RA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A55,
 },
 [0x1A56]={
  category="mn",
  description="TAI THAM CONSONANT SIGN MEDIAL LA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A56,
 },
 [0x1A57]={
  category="mc",
  description="TAI THAM CONSONANT SIGN LA TANG LAI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A57,
 },
 [0x1A58]={
  category="mn",
  description="TAI THAM SIGN MAI KANG LAI",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A58,
 },
 [0x1A59]={
  category="mn",
  description="TAI THAM CONSONANT SIGN FINAL NGA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A59,
 },
 [0x1A5A]={
  category="mn",
  description="TAI THAM CONSONANT SIGN LOW PA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A5A,
 },
 [0x1A5B]={
  category="mn",
  description="TAI THAM CONSONANT SIGN HIGH RATHA OR LOW PA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A5B,
 },
 [0x1A5C]={
  category="mn",
  description="TAI THAM CONSONANT SIGN MA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A5C,
 },
 [0x1A5D]={
  category="mn",
  description="TAI THAM CONSONANT SIGN BA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A5D,
 },
 [0x1A5E]={
  category="mn",
  description="TAI THAM CONSONANT SIGN SA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A5E,
 },
 [0x1A60]={
  category="mn",
  description="TAI THAM SIGN SAKOT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A60,
 },
 [0x1A61]={
  category="mc",
  description="TAI THAM VOWEL SIGN A",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A61,
 },
 [0x1A62]={
  category="mn",
  description="TAI THAM VOWEL SIGN MAI SAT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A62,
 },
 [0x1A63]={
  category="mc",
  description="TAI THAM VOWEL SIGN AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A63,
 },
 [0x1A64]={
  category="mc",
  description="TAI THAM VOWEL SIGN TALL AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A64,
 },
 [0x1A65]={
  category="mn",
  description="TAI THAM VOWEL SIGN I",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A65,
 },
 [0x1A66]={
  category="mn",
  description="TAI THAM VOWEL SIGN II",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A66,
 },
 [0x1A67]={
  category="mn",
  description="TAI THAM VOWEL SIGN UE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A67,
 },
 [0x1A68]={
  category="mn",
  description="TAI THAM VOWEL SIGN UUE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A68,
 },
 [0x1A69]={
  category="mn",
  description="TAI THAM VOWEL SIGN U",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A69,
 },
 [0x1A6A]={
  category="mn",
  description="TAI THAM VOWEL SIGN UU",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A6A,
 },
 [0x1A6B]={
  category="mn",
  description="TAI THAM VOWEL SIGN O",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A6B,
 },
 [0x1A6C]={
  category="mn",
  description="TAI THAM VOWEL SIGN OA BELOW",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A6C,
 },
 [0x1A6D]={
  category="mc",
  description="TAI THAM VOWEL SIGN OY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A6D,
 },
 [0x1A6E]={
  category="mc",
  description="TAI THAM VOWEL SIGN E",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A6E,
 },
 [0x1A6F]={
  category="mc",
  description="TAI THAM VOWEL SIGN AE",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A6F,
 },
 [0x1A70]={
  category="mc",
  description="TAI THAM VOWEL SIGN OO",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A70,
 },
 [0x1A71]={
  category="mc",
  description="TAI THAM VOWEL SIGN AI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A71,
 },
 [0x1A72]={
  category="mc",
  description="TAI THAM VOWEL SIGN THAM AI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1A72,
 },
 [0x1A73]={
  category="mn",
  description="TAI THAM VOWEL SIGN OA ABOVE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A73,
 },
 [0x1A74]={
  category="mn",
  description="TAI THAM SIGN MAI KANG",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A74,
 },
 [0x1A75]={
  category="mn",
  description="TAI THAM SIGN TONE-1",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A75,
 },
 [0x1A76]={
  category="mn",
  description="TAI THAM SIGN TONE-2",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A76,
 },
 [0x1A77]={
  category="mn",
  description="TAI THAM SIGN KHUEN TONE-3",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A77,
 },
 [0x1A78]={
  category="mn",
  description="TAI THAM SIGN KHUEN TONE-4",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A78,
 },
 [0x1A79]={
  category="mn",
  description="TAI THAM SIGN KHUEN TONE-5",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A79,
 },
 [0x1A7A]={
  category="mn",
  description="TAI THAM SIGN RA HAAM",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A7A,
 },
 [0x1A7B]={
  category="mn",
  description="TAI THAM SIGN MAI SAM",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A7B,
 },
 [0x1A7C]={
  category="mn",
  description="TAI THAM SIGN KHUEN-LUE KARAN",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0x1A7C,
 },
 [0x1A7F]={
  category="mn",
  description="TAI THAM COMBINING CRYPTOGRAMMIC DOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1A7F,
 },
 [0x1A80]={
  category="nd",
  description="TAI THAM HORA DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A80,
 },
 [0x1A81]={
  category="nd",
  description="TAI THAM HORA DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A81,
 },
 [0x1A82]={
  category="nd",
  description="TAI THAM HORA DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A82,
 },
 [0x1A83]={
  category="nd",
  description="TAI THAM HORA DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A83,
 },
 [0x1A84]={
  category="nd",
  description="TAI THAM HORA DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A84,
 },
 [0x1A85]={
  category="nd",
  description="TAI THAM HORA DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A85,
 },
 [0x1A86]={
  category="nd",
  description="TAI THAM HORA DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A86,
 },
 [0x1A87]={
  category="nd",
  description="TAI THAM HORA DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A87,
 },
 [0x1A88]={
  category="nd",
  description="TAI THAM HORA DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A88,
 },
 [0x1A89]={
  category="nd",
  description="TAI THAM HORA DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A89,
 },
 [0x1A90]={
  category="nd",
  description="TAI THAM THAM DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A90,
 },
 [0x1A91]={
  category="nd",
  description="TAI THAM THAM DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A91,
 },
 [0x1A92]={
  category="nd",
  description="TAI THAM THAM DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A92,
 },
 [0x1A93]={
  category="nd",
  description="TAI THAM THAM DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A93,
 },
 [0x1A94]={
  category="nd",
  description="TAI THAM THAM DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A94,
 },
 [0x1A95]={
  category="nd",
  description="TAI THAM THAM DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A95,
 },
 [0x1A96]={
  category="nd",
  description="TAI THAM THAM DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A96,
 },
 [0x1A97]={
  category="nd",
  description="TAI THAM THAM DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A97,
 },
 [0x1A98]={
  category="nd",
  description="TAI THAM THAM DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A98,
 },
 [0x1A99]={
  category="nd",
  description="TAI THAM THAM DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1A99,
 },
 [0x1AA0]={
  category="po",
  description="TAI THAM SIGN WIANG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA0,
 },
 [0x1AA1]={
  category="po",
  description="TAI THAM SIGN WIANGWAAK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA1,
 },
 [0x1AA2]={
  category="po",
  description="TAI THAM SIGN SAWAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA2,
 },
 [0x1AA3]={
  category="po",
  description="TAI THAM SIGN KEOW",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA3,
 },
 [0x1AA4]={
  category="po",
  description="TAI THAM SIGN HOY",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA4,
 },
 [0x1AA5]={
  category="po",
  description="TAI THAM SIGN DOKMAI",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA5,
 },
 [0x1AA6]={
  category="po",
  description="TAI THAM SIGN REVERSED ROTATED RANA",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA6,
 },
 [0x1AA7]={
  category="lm",
  description="TAI THAM SIGN MAI YAMOK",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA7,
 },
 [0x1AA8]={
  category="po",
  description="TAI THAM SIGN KAAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA8,
 },
 [0x1AA9]={
  category="po",
  description="TAI THAM SIGN KAANKUU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AA9,
 },
 [0x1AAA]={
  category="po",
  description="TAI THAM SIGN SATKAAN",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AAA,
 },
 [0x1AAB]={
  category="po",
  description="TAI THAM SIGN SATKAANKUU",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AAB,
 },
 [0x1AAC]={
  category="po",
  description="TAI THAM SIGN HANG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AAC,
 },
 [0x1AAD]={
  category="po",
  description="TAI THAM SIGN CAANG",
  direction="l",
  linebreak="sa",
  unicodeslot=0x1AAD,
 },
 [0x1B00]={
  category="mn",
  description="BALINESE SIGN ULU RICEM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B00,
 },
 [0x1B01]={
  category="mn",
  description="BALINESE SIGN ULU CANDRA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B01,
 },
 [0x1B02]={
  category="mn",
  description="BALINESE SIGN CECEK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B02,
 },
 [0x1B03]={
  category="mn",
  description="BALINESE SIGN SURANG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B03,
 },
 [0x1B04]={
  category="mc",
  description="BALINESE SIGN BISAH",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1B04,
 },
 [0x1B05]={
  category="lo",
  description="BALINESE LETTER AKARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B05,
 },
 [0x1B06]={
  category="lo",
  description="BALINESE LETTER AKARA TEDUNG",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1B05, 0x1B35 },
  unicodeslot=0x1B06,
 },
 [0x1B07]={
  category="lo",
  description="BALINESE LETTER IKARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B07,
 },
 [0x1B08]={
  category="lo",
  description="BALINESE LETTER IKARA TEDUNG",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1B07, 0x1B35 },
  unicodeslot=0x1B08,
 },
 [0x1B09]={
  category="lo",
  description="BALINESE LETTER UKARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B09,
 },
 [0x1B0A]={
  category="lo",
  description="BALINESE LETTER UKARA TEDUNG",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1B09, 0x1B35 },
  unicodeslot=0x1B0A,
 },
 [0x1B0B]={
  category="lo",
  description="BALINESE LETTER RA REPA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B0B,
 },
 [0x1B0C]={
  category="lo",
  description="BALINESE LETTER RA REPA TEDUNG",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1B0B, 0x1B35 },
  unicodeslot=0x1B0C,
 },
 [0x1B0D]={
  category="lo",
  description="BALINESE LETTER LA LENGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B0D,
 },
 [0x1B0E]={
  category="lo",
  description="BALINESE LETTER LA LENGA TEDUNG",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1B0D, 0x1B35 },
  unicodeslot=0x1B0E,
 },
 [0x1B0F]={
  category="lo",
  description="BALINESE LETTER EKARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B0F,
 },
 [0x1B10]={
  category="lo",
  description="BALINESE LETTER AIKARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B10,
 },
 [0x1B11]={
  category="lo",
  description="BALINESE LETTER OKARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B11,
 },
 [0x1B12]={
  category="lo",
  description="BALINESE LETTER OKARA TEDUNG",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1B11, 0x1B35 },
  unicodeslot=0x1B12,
 },
 [0x1B13]={
  category="lo",
  description="BALINESE LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B13,
 },
 [0x1B14]={
  category="lo",
  description="BALINESE LETTER KA MAHAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B14,
 },
 [0x1B15]={
  category="lo",
  description="BALINESE LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B15,
 },
 [0x1B16]={
  category="lo",
  description="BALINESE LETTER GA GORA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B16,
 },
 [0x1B17]={
  category="lo",
  description="BALINESE LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B17,
 },
 [0x1B18]={
  category="lo",
  description="BALINESE LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B18,
 },
 [0x1B19]={
  category="lo",
  description="BALINESE LETTER CA LACA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B19,
 },
 [0x1B1A]={
  category="lo",
  description="BALINESE LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B1A,
 },
 [0x1B1B]={
  category="lo",
  description="BALINESE LETTER JA JERA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B1B,
 },
 [0x1B1C]={
  category="lo",
  description="BALINESE LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B1C,
 },
 [0x1B1D]={
  category="lo",
  description="BALINESE LETTER TA LATIK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B1D,
 },
 [0x1B1E]={
  category="lo",
  description="BALINESE LETTER TA MURDA MAHAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B1E,
 },
 [0x1B1F]={
  category="lo",
  description="BALINESE LETTER DA MURDA ALPAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B1F,
 },
 [0x1B20]={
  category="lo",
  description="BALINESE LETTER DA MURDA MAHAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B20,
 },
 [0x1B21]={
  category="lo",
  description="BALINESE LETTER NA RAMBAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B21,
 },
 [0x1B22]={
  category="lo",
  description="BALINESE LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B22,
 },
 [0x1B23]={
  category="lo",
  description="BALINESE LETTER TA TAWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B23,
 },
 [0x1B24]={
  category="lo",
  description="BALINESE LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B24,
 },
 [0x1B25]={
  category="lo",
  description="BALINESE LETTER DA MADU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B25,
 },
 [0x1B26]={
  category="lo",
  description="BALINESE LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B26,
 },
 [0x1B27]={
  category="lo",
  description="BALINESE LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B27,
 },
 [0x1B28]={
  category="lo",
  description="BALINESE LETTER PA KAPAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B28,
 },
 [0x1B29]={
  category="lo",
  description="BALINESE LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B29,
 },
 [0x1B2A]={
  category="lo",
  description="BALINESE LETTER BA KEMBANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B2A,
 },
 [0x1B2B]={
  category="lo",
  description="BALINESE LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B2B,
 },
 [0x1B2C]={
  category="lo",
  description="BALINESE LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B2C,
 },
 [0x1B2D]={
  category="lo",
  description="BALINESE LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B2D,
 },
 [0x1B2E]={
  category="lo",
  description="BALINESE LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B2E,
 },
 [0x1B2F]={
  category="lo",
  description="BALINESE LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B2F,
 },
 [0x1B30]={
  category="lo",
  description="BALINESE LETTER SA SAGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B30,
 },
 [0x1B31]={
  category="lo",
  description="BALINESE LETTER SA SAPA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B31,
 },
 [0x1B32]={
  category="lo",
  description="BALINESE LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B32,
 },
 [0x1B33]={
  category="lo",
  description="BALINESE LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B33,
 },
 [0x1B34]={
  category="mn",
  description="BALINESE SIGN REREKAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B34,
 },
 [0x1B35]={
  category="mc",
  description="BALINESE VOWEL SIGN TEDUNG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1B35,
 },
 [0x1B36]={
  category="mn",
  description="BALINESE VOWEL SIGN ULU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B36,
 },
 [0x1B37]={
  category="mn",
  description="BALINESE VOWEL SIGN ULU SARI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B37,
 },
 [0x1B38]={
  category="mn",
  description="BALINESE VOWEL SIGN SUKU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B38,
 },
 [0x1B39]={
  category="mn",
  description="BALINESE VOWEL SIGN SUKU ILUT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B39,
 },
 [0x1B3A]={
  category="mn",
  description="BALINESE VOWEL SIGN RA REPA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B3A,
 },
 [0x1B3B]={
  category="mc",
  description="BALINESE VOWEL SIGN RA REPA TEDUNG",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x1B3A, 0x1B35 },
  unicodeslot=0x1B3B,
 },
 [0x1B3C]={
  category="mn",
  description="BALINESE VOWEL SIGN LA LENGA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B3C,
 },
 [0x1B3D]={
  category="mc",
  description="BALINESE VOWEL SIGN LA LENGA TEDUNG",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x1B3C, 0x1B35 },
  unicodeslot=0x1B3D,
 },
 [0x1B3E]={
  category="mc",
  description="BALINESE VOWEL SIGN TALING",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1B3E,
 },
 [0x1B3F]={
  category="mc",
  description="BALINESE VOWEL SIGN TALING REPA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1B3F,
 },
 [0x1B40]={
  category="mc",
  description="BALINESE VOWEL SIGN TALING TEDUNG",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x1B3E, 0x1B35 },
  unicodeslot=0x1B40,
 },
 [0x1B41]={
  category="mc",
  description="BALINESE VOWEL SIGN TALING REPA TEDUNG",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x1B3F, 0x1B35 },
  unicodeslot=0x1B41,
 },
 [0x1B42]={
  category="mn",
  description="BALINESE VOWEL SIGN PEPET",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B42,
 },
 [0x1B43]={
  category="mc",
  description="BALINESE VOWEL SIGN PEPET TEDUNG",
  direction="l",
  linebreak="cm",
  specials={ "char", 0x1B42, 0x1B35 },
  unicodeslot=0x1B43,
 },
 [0x1B44]={
  category="mc",
  description="BALINESE ADEG ADEG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1B44,
 },
 [0x1B45]={
  category="lo",
  description="BALINESE LETTER KAF SASAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B45,
 },
 [0x1B46]={
  category="lo",
  description="BALINESE LETTER KHOT SASAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B46,
 },
 [0x1B47]={
  category="lo",
  description="BALINESE LETTER TZIR SASAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B47,
 },
 [0x1B48]={
  category="lo",
  description="BALINESE LETTER EF SASAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B48,
 },
 [0x1B49]={
  category="lo",
  description="BALINESE LETTER VE SASAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B49,
 },
 [0x1B4A]={
  category="lo",
  description="BALINESE LETTER ZAL SASAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B4A,
 },
 [0x1B4B]={
  category="lo",
  description="BALINESE LETTER ASYURA SASAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B4B,
 },
 [0x1B50]={
  category="nd",
  description="BALINESE DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B50,
 },
 [0x1B51]={
  category="nd",
  description="BALINESE DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B51,
 },
 [0x1B52]={
  category="nd",
  description="BALINESE DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B52,
 },
 [0x1B53]={
  category="nd",
  description="BALINESE DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B53,
 },
 [0x1B54]={
  category="nd",
  description="BALINESE DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B54,
 },
 [0x1B55]={
  category="nd",
  description="BALINESE DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B55,
 },
 [0x1B56]={
  category="nd",
  description="BALINESE DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B56,
 },
 [0x1B57]={
  category="nd",
  description="BALINESE DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B57,
 },
 [0x1B58]={
  category="nd",
  description="BALINESE DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B58,
 },
 [0x1B59]={
  category="nd",
  description="BALINESE DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1B59,
 },
 [0x1B5A]={
  category="po",
  description="BALINESE PANTI",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1B5A,
 },
 [0x1B5B]={
  category="po",
  description="BALINESE PAMADA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1B5B,
 },
 [0x1B5C]={
  category="po",
  description="BALINESE WINDU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B5C,
 },
 [0x1B5D]={
  category="po",
  description="BALINESE CARIK PAMUNGKAH",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1B5D,
 },
 [0x1B5E]={
  category="po",
  description="BALINESE CARIK SIKI",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1B5E,
 },
 [0x1B5F]={
  category="po",
  description="BALINESE CARIK PAREREN",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1B5F,
 },
 [0x1B60]={
  category="po",
  description="BALINESE PAMENENG",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1B60,
 },
 [0x1B61]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DONG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B61,
 },
 [0x1B62]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DENG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B62,
 },
 [0x1B63]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DUNG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B63,
 },
 [0x1B64]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B64,
 },
 [0x1B65]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DANG SURANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B65,
 },
 [0x1B66]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DING",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B66,
 },
 [0x1B67]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DAENG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B67,
 },
 [0x1B68]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DEUNG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B68,
 },
 [0x1B69]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DAING",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B69,
 },
 [0x1B6A]={
  category="so",
  description="BALINESE MUSICAL SYMBOL DANG GEDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B6A,
 },
 [0x1B6B]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING TEGEH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B6B,
 },
 [0x1B6C]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING ENDEP",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B6C,
 },
 [0x1B6D]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING KEMPUL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B6D,
 },
 [0x1B6E]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING KEMPLI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B6E,
 },
 [0x1B6F]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING JEGOGAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B6F,
 },
 [0x1B70]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING KEMPUL WITH JEGOGAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B70,
 },
 [0x1B71]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING KEMPLI WITH JEGOGAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B71,
 },
 [0x1B72]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING BENDE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B72,
 },
 [0x1B73]={
  category="mn",
  description="BALINESE MUSICAL SYMBOL COMBINING GONG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B73,
 },
 [0x1B74]={
  category="so",
  description="BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B74,
 },
 [0x1B75]={
  category="so",
  description="BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B75,
 },
 [0x1B76]={
  category="so",
  description="BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TUK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B76,
 },
 [0x1B77]={
  category="so",
  description="BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B77,
 },
 [0x1B78]={
  category="so",
  description="BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B78,
 },
 [0x1B79]={
  category="so",
  description="BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PUNG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B79,
 },
 [0x1B7A]={
  category="so",
  description="BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B7A,
 },
 [0x1B7B]={
  category="so",
  description="BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLUK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B7B,
 },
 [0x1B7C]={
  category="so",
  description="BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PING",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B7C,
 },
 [0x1B80]={
  category="mn",
  description="SUNDANESE SIGN PANYECEK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B80,
 },
 [0x1B81]={
  category="mn",
  description="SUNDANESE SIGN PANGLAYAR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1B81,
 },
 [0x1B82]={
  category="mc",
  description="SUNDANESE SIGN PANGWISAD",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1B82,
 },
 [0x1B83]={
  category="lo",
  description="SUNDANESE LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B83,
 },
 [0x1B84]={
  category="lo",
  description="SUNDANESE LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B84,
 },
 [0x1B85]={
  category="lo",
  description="SUNDANESE LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B85,
 },
 [0x1B86]={
  category="lo",
  description="SUNDANESE LETTER AE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B86,
 },
 [0x1B87]={
  category="lo",
  description="SUNDANESE LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B87,
 },
 [0x1B88]={
  category="lo",
  description="SUNDANESE LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B88,
 },
 [0x1B89]={
  category="lo",
  description="SUNDANESE LETTER EU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B89,
 },
 [0x1B8A]={
  category="lo",
  description="SUNDANESE LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B8A,
 },
 [0x1B8B]={
  category="lo",
  description="SUNDANESE LETTER QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B8B,
 },
 [0x1B8C]={
  category="lo",
  description="SUNDANESE LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B8C,
 },
 [0x1B8D]={
  category="lo",
  description="SUNDANESE LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B8D,
 },
 [0x1B8E]={
  category="lo",
  description="SUNDANESE LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B8E,
 },
 [0x1B8F]={
  category="lo",
  description="SUNDANESE LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B8F,
 },
 [0x1B90]={
  category="lo",
  description="SUNDANESE LETTER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B90,
 },
 [0x1B91]={
  category="lo",
  description="SUNDANESE LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B91,
 },
 [0x1B92]={
  category="lo",
  description="SUNDANESE LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B92,
 },
 [0x1B93]={
  category="lo",
  description="SUNDANESE LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B93,
 },
 [0x1B94]={
  category="lo",
  description="SUNDANESE LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B94,
 },
 [0x1B95]={
  category="lo",
  description="SUNDANESE LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B95,
 },
 [0x1B96]={
  category="lo",
  description="SUNDANESE LETTER FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B96,
 },
 [0x1B97]={
  category="lo",
  description="SUNDANESE LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B97,
 },
 [0x1B98]={
  category="lo",
  description="SUNDANESE LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B98,
 },
 [0x1B99]={
  category="lo",
  description="SUNDANESE LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B99,
 },
 [0x1B9A]={
  category="lo",
  description="SUNDANESE LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B9A,
 },
 [0x1B9B]={
  category="lo",
  description="SUNDANESE LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B9B,
 },
 [0x1B9C]={
  category="lo",
  description="SUNDANESE LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B9C,
 },
 [0x1B9D]={
  category="lo",
  description="SUNDANESE LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B9D,
 },
 [0x1B9E]={
  category="lo",
  description="SUNDANESE LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B9E,
 },
 [0x1B9F]={
  category="lo",
  description="SUNDANESE LETTER XA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1B9F,
 },
 [0x1BA0]={
  category="lo",
  description="SUNDANESE LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BA0,
 },
 [0x1BA1]={
  category="mc",
  description="SUNDANESE CONSONANT SIGN PAMINGKAL",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BA1,
 },
 [0x1BA2]={
  category="mn",
  description="SUNDANESE CONSONANT SIGN PANYAKRA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BA2,
 },
 [0x1BA3]={
  category="mn",
  description="SUNDANESE CONSONANT SIGN PANYIKU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BA3,
 },
 [0x1BA4]={
  category="mn",
  description="SUNDANESE VOWEL SIGN PANGHULU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BA4,
 },
 [0x1BA5]={
  category="mn",
  description="SUNDANESE VOWEL SIGN PANYUKU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BA5,
 },
 [0x1BA6]={
  category="mc",
  description="SUNDANESE VOWEL SIGN PANAELAENG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BA6,
 },
 [0x1BA7]={
  category="mc",
  description="SUNDANESE VOWEL SIGN PANOLONG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BA7,
 },
 [0x1BA8]={
  category="mn",
  description="SUNDANESE VOWEL SIGN PAMEPET",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BA8,
 },
 [0x1BA9]={
  category="mn",
  description="SUNDANESE VOWEL SIGN PANEULEUNG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BA9,
 },
 [0x1BAA]={
  category="mc",
  description="SUNDANESE SIGN PAMAAEH",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BAA,
 },
 [0x1BAB]={
  category="mn",
  description="SUNDANESE SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BAB,
 },
 [0x1BAC]={
  category="mc",
  description="SUNDANESE CONSONANT SIGN PASANGAN MA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BAC,
 },
 [0x1BAD]={
  category="mc",
  description="SUNDANESE CONSONANT SIGN PASANGAN WA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BAD,
 },
 [0x1BAE]={
  category="lo",
  description="SUNDANESE LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BAE,
 },
 [0x1BAF]={
  category="lo",
  description="SUNDANESE LETTER SYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BAF,
 },
 [0x1BB0]={
  category="nd",
  description="SUNDANESE DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB0,
 },
 [0x1BB1]={
  category="nd",
  description="SUNDANESE DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB1,
 },
 [0x1BB2]={
  category="nd",
  description="SUNDANESE DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB2,
 },
 [0x1BB3]={
  category="nd",
  description="SUNDANESE DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB3,
 },
 [0x1BB4]={
  category="nd",
  description="SUNDANESE DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB4,
 },
 [0x1BB5]={
  category="nd",
  description="SUNDANESE DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB5,
 },
 [0x1BB6]={
  category="nd",
  description="SUNDANESE DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB6,
 },
 [0x1BB7]={
  category="nd",
  description="SUNDANESE DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB7,
 },
 [0x1BB8]={
  category="nd",
  description="SUNDANESE DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB8,
 },
 [0x1BB9]={
  category="nd",
  description="SUNDANESE DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1BB9,
 },
 [0x1BBA]={
  category="lo",
  description="SUNDANESE AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BBA,
 },
 [0x1BBB]={
  category="lo",
  description="SUNDANESE LETTER REU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BBB,
 },
 [0x1BBC]={
  category="lo",
  description="SUNDANESE LETTER LEU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BBC,
 },
 [0x1BBD]={
  category="lo",
  description="SUNDANESE LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BBD,
 },
 [0x1BBE]={
  category="lo",
  description="SUNDANESE LETTER FINAL K",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BBE,
 },
 [0x1BBF]={
  category="lo",
  description="SUNDANESE LETTER FINAL M",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BBF,
 },
 [0x1BC0]={
  category="lo",
  description="BATAK LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC0,
 },
 [0x1BC1]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC1,
 },
 [0x1BC2]={
  category="lo",
  description="BATAK LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC2,
 },
 [0x1BC3]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC3,
 },
 [0x1BC4]={
  category="lo",
  description="BATAK LETTER MANDAILING HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC4,
 },
 [0x1BC5]={
  category="lo",
  description="BATAK LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC5,
 },
 [0x1BC6]={
  category="lo",
  description="BATAK LETTER KARO BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC6,
 },
 [0x1BC7]={
  category="lo",
  description="BATAK LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC7,
 },
 [0x1BC8]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC8,
 },
 [0x1BC9]={
  category="lo",
  description="BATAK LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BC9,
 },
 [0x1BCA]={
  category="lo",
  description="BATAK LETTER MANDAILING NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BCA,
 },
 [0x1BCB]={
  category="lo",
  description="BATAK LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BCB,
 },
 [0x1BCC]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BCC,
 },
 [0x1BCD]={
  category="lo",
  description="BATAK LETTER PAKPAK WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BCD,
 },
 [0x1BCE]={
  category="lo",
  description="BATAK LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BCE,
 },
 [0x1BCF]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BCF,
 },
 [0x1BD0]={
  category="lo",
  description="BATAK LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD0,
 },
 [0x1BD1]={
  category="lo",
  description="BATAK LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD1,
 },
 [0x1BD2]={
  category="lo",
  description="BATAK LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD2,
 },
 [0x1BD3]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD3,
 },
 [0x1BD4]={
  category="lo",
  description="BATAK LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD4,
 },
 [0x1BD5]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD5,
 },
 [0x1BD6]={
  category="lo",
  description="BATAK LETTER SOUTHERN TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD6,
 },
 [0x1BD7]={
  category="lo",
  description="BATAK LETTER NORTHERN TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD7,
 },
 [0x1BD8]={
  category="lo",
  description="BATAK LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD8,
 },
 [0x1BD9]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BD9,
 },
 [0x1BDA]={
  category="lo",
  description="BATAK LETTER MANDAILING SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BDA,
 },
 [0x1BDB]={
  category="lo",
  description="BATAK LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BDB,
 },
 [0x1BDC]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BDC,
 },
 [0x1BDD]={
  category="lo",
  description="BATAK LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BDD,
 },
 [0x1BDE]={
  category="lo",
  description="BATAK LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BDE,
 },
 [0x1BDF]={
  category="lo",
  description="BATAK LETTER SIMALUNGUN LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BDF,
 },
 [0x1BE0]={
  category="lo",
  description="BATAK LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BE0,
 },
 [0x1BE1]={
  category="lo",
  description="BATAK LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BE1,
 },
 [0x1BE2]={
  category="lo",
  description="BATAK LETTER NDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BE2,
 },
 [0x1BE3]={
  category="lo",
  description="BATAK LETTER MBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BE3,
 },
 [0x1BE4]={
  category="lo",
  description="BATAK LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BE4,
 },
 [0x1BE5]={
  category="lo",
  description="BATAK LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BE5,
 },
 [0x1BE6]={
  category="mn",
  description="BATAK SIGN TOMPI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BE6,
 },
 [0x1BE7]={
  category="mc",
  description="BATAK VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BE7,
 },
 [0x1BE8]={
  category="mn",
  description="BATAK VOWEL SIGN PAKPAK E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BE8,
 },
 [0x1BE9]={
  category="mn",
  description="BATAK VOWEL SIGN EE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BE9,
 },
 [0x1BEA]={
  category="mc",
  description="BATAK VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BEA,
 },
 [0x1BEB]={
  category="mc",
  description="BATAK VOWEL SIGN KARO I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BEB,
 },
 [0x1BEC]={
  category="mc",
  description="BATAK VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BEC,
 },
 [0x1BED]={
  category="mn",
  description="BATAK VOWEL SIGN KARO O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BED,
 },
 [0x1BEE]={
  category="mc",
  description="BATAK VOWEL SIGN U",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BEE,
 },
 [0x1BEF]={
  category="mn",
  description="BATAK VOWEL SIGN U FOR SIMALUNGUN SA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BEF,
 },
 [0x1BF0]={
  category="mn",
  description="BATAK CONSONANT SIGN NG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BF0,
 },
 [0x1BF1]={
  category="mn",
  description="BATAK CONSONANT SIGN H",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1BF1,
 },
 [0x1BF2]={
  category="mc",
  description="BATAK PANGOLAT",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BF2,
 },
 [0x1BF3]={
  category="mc",
  description="BATAK PANONGONAN",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1BF3,
 },
 [0x1BFC]={
  category="po",
  description="BATAK SYMBOL BINDU NA METEK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BFC,
 },
 [0x1BFD]={
  category="po",
  description="BATAK SYMBOL BINDU PINARBORAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BFD,
 },
 [0x1BFE]={
  category="po",
  description="BATAK SYMBOL BINDU JUDUL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BFE,
 },
 [0x1BFF]={
  category="po",
  description="BATAK SYMBOL BINDU PANGOLAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1BFF,
 },
 [0x1C00]={
  category="lo",
  description="LEPCHA LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C00,
 },
 [0x1C01]={
  category="lo",
  description="LEPCHA LETTER KLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C01,
 },
 [0x1C02]={
  category="lo",
  description="LEPCHA LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C02,
 },
 [0x1C03]={
  category="lo",
  description="LEPCHA LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C03,
 },
 [0x1C04]={
  category="lo",
  description="LEPCHA LETTER GLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C04,
 },
 [0x1C05]={
  category="lo",
  description="LEPCHA LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C05,
 },
 [0x1C06]={
  category="lo",
  description="LEPCHA LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C06,
 },
 [0x1C07]={
  category="lo",
  description="LEPCHA LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C07,
 },
 [0x1C08]={
  category="lo",
  description="LEPCHA LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C08,
 },
 [0x1C09]={
  category="lo",
  description="LEPCHA LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C09,
 },
 [0x1C0A]={
  category="lo",
  description="LEPCHA LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C0A,
 },
 [0x1C0B]={
  category="lo",
  description="LEPCHA LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C0B,
 },
 [0x1C0C]={
  category="lo",
  description="LEPCHA LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C0C,
 },
 [0x1C0D]={
  category="lo",
  description="LEPCHA LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C0D,
 },
 [0x1C0E]={
  category="lo",
  description="LEPCHA LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C0E,
 },
 [0x1C0F]={
  category="lo",
  description="LEPCHA LETTER PLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C0F,
 },
 [0x1C10]={
  category="lo",
  description="LEPCHA LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C10,
 },
 [0x1C11]={
  category="lo",
  description="LEPCHA LETTER FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C11,
 },
 [0x1C12]={
  category="lo",
  description="LEPCHA LETTER FLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C12,
 },
 [0x1C13]={
  category="lo",
  description="LEPCHA LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C13,
 },
 [0x1C14]={
  category="lo",
  description="LEPCHA LETTER BLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C14,
 },
 [0x1C15]={
  category="lo",
  description="LEPCHA LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C15,
 },
 [0x1C16]={
  category="lo",
  description="LEPCHA LETTER MLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C16,
 },
 [0x1C17]={
  category="lo",
  description="LEPCHA LETTER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C17,
 },
 [0x1C18]={
  category="lo",
  description="LEPCHA LETTER TSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C18,
 },
 [0x1C19]={
  category="lo",
  description="LEPCHA LETTER DZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C19,
 },
 [0x1C1A]={
  category="lo",
  description="LEPCHA LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C1A,
 },
 [0x1C1B]={
  category="lo",
  description="LEPCHA LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C1B,
 },
 [0x1C1C]={
  category="lo",
  description="LEPCHA LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C1C,
 },
 [0x1C1D]={
  category="lo",
  description="LEPCHA LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C1D,
 },
 [0x1C1E]={
  category="lo",
  description="LEPCHA LETTER HLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C1E,
 },
 [0x1C1F]={
  category="lo",
  description="LEPCHA LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C1F,
 },
 [0x1C20]={
  category="lo",
  description="LEPCHA LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C20,
 },
 [0x1C21]={
  category="lo",
  description="LEPCHA LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C21,
 },
 [0x1C22]={
  category="lo",
  description="LEPCHA LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C22,
 },
 [0x1C23]={
  category="lo",
  description="LEPCHA LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C23,
 },
 [0x1C24]={
  category="mc",
  description="LEPCHA SUBJOINED LETTER YA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C24,
 },
 [0x1C25]={
  category="mc",
  description="LEPCHA SUBJOINED LETTER RA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C25,
 },
 [0x1C26]={
  category="mc",
  description="LEPCHA VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C26,
 },
 [0x1C27]={
  category="mc",
  description="LEPCHA VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C27,
 },
 [0x1C28]={
  category="mc",
  description="LEPCHA VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C28,
 },
 [0x1C29]={
  category="mc",
  description="LEPCHA VOWEL SIGN OO",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C29,
 },
 [0x1C2A]={
  category="mc",
  description="LEPCHA VOWEL SIGN U",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C2A,
 },
 [0x1C2B]={
  category="mc",
  description="LEPCHA VOWEL SIGN UU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C2B,
 },
 [0x1C2C]={
  category="mn",
  description="LEPCHA VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C2C,
 },
 [0x1C2D]={
  category="mn",
  description="LEPCHA CONSONANT SIGN K",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C2D,
 },
 [0x1C2E]={
  category="mn",
  description="LEPCHA CONSONANT SIGN M",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C2E,
 },
 [0x1C2F]={
  category="mn",
  description="LEPCHA CONSONANT SIGN L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C2F,
 },
 [0x1C30]={
  category="mn",
  description="LEPCHA CONSONANT SIGN N",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C30,
 },
 [0x1C31]={
  category="mn",
  description="LEPCHA CONSONANT SIGN P",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C31,
 },
 [0x1C32]={
  category="mn",
  description="LEPCHA CONSONANT SIGN R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C32,
 },
 [0x1C33]={
  category="mn",
  description="LEPCHA CONSONANT SIGN T",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C33,
 },
 [0x1C34]={
  category="mc",
  description="LEPCHA CONSONANT SIGN NYIN-DO",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C34,
 },
 [0x1C35]={
  category="mc",
  description="LEPCHA CONSONANT SIGN KANG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1C35,
 },
 [0x1C36]={
  category="mn",
  description="LEPCHA SIGN RAN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C36,
 },
 [0x1C37]={
  category="mn",
  description="LEPCHA SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1C37,
 },
 [0x1C3B]={
  category="po",
  description="LEPCHA PUNCTUATION TA-ROL",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1C3B,
 },
 [0x1C3C]={
  category="po",
  description="LEPCHA PUNCTUATION NYET THYOOM TA-ROL",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1C3C,
 },
 [0x1C3D]={
  category="po",
  description="LEPCHA PUNCTUATION CER-WA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1C3D,
 },
 [0x1C3E]={
  category="po",
  description="LEPCHA PUNCTUATION TSHOOK CER-WA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1C3E,
 },
 [0x1C3F]={
  category="po",
  description="LEPCHA PUNCTUATION TSHOOK",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1C3F,
 },
 [0x1C40]={
  category="nd",
  description="LEPCHA DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C40,
 },
 [0x1C41]={
  category="nd",
  description="LEPCHA DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C41,
 },
 [0x1C42]={
  category="nd",
  description="LEPCHA DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C42,
 },
 [0x1C43]={
  category="nd",
  description="LEPCHA DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C43,
 },
 [0x1C44]={
  category="nd",
  description="LEPCHA DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C44,
 },
 [0x1C45]={
  category="nd",
  description="LEPCHA DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C45,
 },
 [0x1C46]={
  category="nd",
  description="LEPCHA DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C46,
 },
 [0x1C47]={
  category="nd",
  description="LEPCHA DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C47,
 },
 [0x1C48]={
  category="nd",
  description="LEPCHA DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C48,
 },
 [0x1C49]={
  category="nd",
  description="LEPCHA DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C49,
 },
 [0x1C4D]={
  category="lo",
  description="LEPCHA LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C4D,
 },
 [0x1C4E]={
  category="lo",
  description="LEPCHA LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C4E,
 },
 [0x1C4F]={
  category="lo",
  description="LEPCHA LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C4F,
 },
 [0x1C50]={
  category="nd",
  description="OL CHIKI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C50,
 },
 [0x1C51]={
  category="nd",
  description="OL CHIKI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C51,
 },
 [0x1C52]={
  category="nd",
  description="OL CHIKI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C52,
 },
 [0x1C53]={
  category="nd",
  description="OL CHIKI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C53,
 },
 [0x1C54]={
  category="nd",
  description="OL CHIKI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C54,
 },
 [0x1C55]={
  category="nd",
  description="OL CHIKI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C55,
 },
 [0x1C56]={
  category="nd",
  description="OL CHIKI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C56,
 },
 [0x1C57]={
  category="nd",
  description="OL CHIKI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C57,
 },
 [0x1C58]={
  category="nd",
  description="OL CHIKI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C58,
 },
 [0x1C59]={
  category="nd",
  description="OL CHIKI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1C59,
 },
 [0x1C5A]={
  category="lo",
  description="OL CHIKI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C5A,
 },
 [0x1C5B]={
  category="lo",
  description="OL CHIKI LETTER AT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C5B,
 },
 [0x1C5C]={
  category="lo",
  description="OL CHIKI LETTER AG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C5C,
 },
 [0x1C5D]={
  category="lo",
  description="OL CHIKI LETTER ANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C5D,
 },
 [0x1C5E]={
  category="lo",
  description="OL CHIKI LETTER AL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C5E,
 },
 [0x1C5F]={
  category="lo",
  description="OL CHIKI LETTER LAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C5F,
 },
 [0x1C60]={
  category="lo",
  description="OL CHIKI LETTER AAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C60,
 },
 [0x1C61]={
  category="lo",
  description="OL CHIKI LETTER AAJ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C61,
 },
 [0x1C62]={
  category="lo",
  description="OL CHIKI LETTER AAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C62,
 },
 [0x1C63]={
  category="lo",
  description="OL CHIKI LETTER AAW",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C63,
 },
 [0x1C64]={
  category="lo",
  description="OL CHIKI LETTER LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C64,
 },
 [0x1C65]={
  category="lo",
  description="OL CHIKI LETTER IS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C65,
 },
 [0x1C66]={
  category="lo",
  description="OL CHIKI LETTER IH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C66,
 },
 [0x1C67]={
  category="lo",
  description="OL CHIKI LETTER INY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C67,
 },
 [0x1C68]={
  category="lo",
  description="OL CHIKI LETTER IR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C68,
 },
 [0x1C69]={
  category="lo",
  description="OL CHIKI LETTER LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C69,
 },
 [0x1C6A]={
  category="lo",
  description="OL CHIKI LETTER UC",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C6A,
 },
 [0x1C6B]={
  category="lo",
  description="OL CHIKI LETTER UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C6B,
 },
 [0x1C6C]={
  category="lo",
  description="OL CHIKI LETTER UNN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C6C,
 },
 [0x1C6D]={
  category="lo",
  description="OL CHIKI LETTER UY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C6D,
 },
 [0x1C6E]={
  category="lo",
  description="OL CHIKI LETTER LE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C6E,
 },
 [0x1C6F]={
  category="lo",
  description="OL CHIKI LETTER EP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C6F,
 },
 [0x1C70]={
  category="lo",
  description="OL CHIKI LETTER EDD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C70,
 },
 [0x1C71]={
  category="lo",
  description="OL CHIKI LETTER EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C71,
 },
 [0x1C72]={
  category="lo",
  description="OL CHIKI LETTER ERR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C72,
 },
 [0x1C73]={
  category="lo",
  description="OL CHIKI LETTER LO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C73,
 },
 [0x1C74]={
  category="lo",
  description="OL CHIKI LETTER OTT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C74,
 },
 [0x1C75]={
  category="lo",
  description="OL CHIKI LETTER OB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C75,
 },
 [0x1C76]={
  category="lo",
  description="OL CHIKI LETTER OV",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C76,
 },
 [0x1C77]={
  category="lo",
  description="OL CHIKI LETTER OH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C77,
 },
 [0x1C78]={
  category="lm",
  description="OL CHIKI MU TTUDDAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C78,
 },
 [0x1C79]={
  category="lm",
  description="OL CHIKI GAAHLAA TTUDDAAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C79,
 },
 [0x1C7A]={
  category="lm",
  description="OL CHIKI MU-GAAHLAA TTUDDAAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C7A,
 },
 [0x1C7B]={
  category="lm",
  description="OL CHIKI RELAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C7B,
 },
 [0x1C7C]={
  category="lm",
  description="OL CHIKI PHAARKAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C7C,
 },
 [0x1C7D]={
  category="lm",
  description="OL CHIKI AHAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1C7D,
 },
 [0x1C7E]={
  category="po",
  description="OL CHIKI PUNCTUATION MUCAAD",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1C7E,
 },
 [0x1C7F]={
  category="po",
  description="OL CHIKI PUNCTUATION DOUBLE MUCAAD",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1C7F,
 },
 [0x1CC0]={
  category="po",
  description="SUNDANESE PUNCTUATION BINDU SURYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CC0,
 },
 [0x1CC1]={
  category="po",
  description="SUNDANESE PUNCTUATION BINDU PANGLONG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CC1,
 },
 [0x1CC2]={
  category="po",
  description="SUNDANESE PUNCTUATION BINDU PURNAMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CC2,
 },
 [0x1CC3]={
  category="po",
  description="SUNDANESE PUNCTUATION BINDU CAKRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CC3,
 },
 [0x1CC4]={
  category="po",
  description="SUNDANESE PUNCTUATION BINDU LEU SATANGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CC4,
 },
 [0x1CC5]={
  category="po",
  description="SUNDANESE PUNCTUATION BINDU KA SATANGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CC5,
 },
 [0x1CC6]={
  category="po",
  description="SUNDANESE PUNCTUATION BINDU DA SATANGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CC6,
 },
 [0x1CC7]={
  category="po",
  description="SUNDANESE PUNCTUATION BINDU BA SATANGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CC7,
 },
 [0x1CD0]={
  category="mn",
  description="VEDIC TONE KARSHANA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD0,
 },
 [0x1CD1]={
  category="mn",
  description="VEDIC TONE SHARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD1,
 },
 [0x1CD2]={
  category="mn",
  description="VEDIC TONE PRENKHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD2,
 },
 [0x1CD3]={
  category="po",
  description="VEDIC SIGN NIHSHVASA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CD3,
 },
 [0x1CD4]={
  category="mn",
  description="VEDIC SIGN YAJURVEDIC MIDLINE SVARITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD4,
 },
 [0x1CD5]={
  category="mn",
  description="VEDIC TONE YAJURVEDIC AGGRAVATED INDEPENDENT SVARITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD5,
 },
 [0x1CD6]={
  category="mn",
  description="VEDIC TONE YAJURVEDIC INDEPENDENT SVARITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD6,
 },
 [0x1CD7]={
  category="mn",
  description="VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD7,
 },
 [0x1CD8]={
  category="mn",
  description="VEDIC TONE CANDRA BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD8,
 },
 [0x1CD9]={
  category="mn",
  description="VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA SCHROEDER",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CD9,
 },
 [0x1CDA]={
  category="mn",
  description="VEDIC TONE DOUBLE SVARITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CDA,
 },
 [0x1CDB]={
  category="mn",
  description="VEDIC TONE TRIPLE SVARITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CDB,
 },
 [0x1CDC]={
  category="mn",
  description="VEDIC TONE KATHAKA ANUDATTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CDC,
 },
 [0x1CDD]={
  category="mn",
  description="VEDIC TONE DOT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CDD,
 },
 [0x1CDE]={
  category="mn",
  description="VEDIC TONE TWO DOTS BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CDE,
 },
 [0x1CDF]={
  category="mn",
  description="VEDIC TONE THREE DOTS BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CDF,
 },
 [0x1CE0]={
  category="mn",
  description="VEDIC TONE RIGVEDIC KASHMIRI INDEPENDENT SVARITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CE0,
 },
 [0x1CE1]={
  category="mc",
  description="VEDIC TONE ATHARVAVEDIC INDEPENDENT SVARITA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1CE1,
 },
 [0x1CE2]={
  category="mn",
  description="VEDIC SIGN VISARGA SVARITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CE2,
 },
 [0x1CE3]={
  category="mn",
  description="VEDIC SIGN VISARGA UDATTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CE3,
 },
 [0x1CE4]={
  category="mn",
  description="VEDIC SIGN REVERSED VISARGA UDATTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CE4,
 },
 [0x1CE5]={
  category="mn",
  description="VEDIC SIGN VISARGA ANUDATTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CE5,
 },
 [0x1CE6]={
  category="mn",
  description="VEDIC SIGN REVERSED VISARGA ANUDATTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CE6,
 },
 [0x1CE7]={
  category="mn",
  description="VEDIC SIGN VISARGA UDATTA WITH TAIL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CE7,
 },
 [0x1CE8]={
  category="mn",
  description="VEDIC SIGN VISARGA ANUDATTA WITH TAIL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CE8,
 },
 [0x1CE9]={
  category="lo",
  description="VEDIC SIGN ANUSVARA ANTARGOMUKHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CE9,
 },
 [0x1CEA]={
  category="lo",
  description="VEDIC SIGN ANUSVARA BAHIRGOMUKHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CEA,
 },
 [0x1CEB]={
  category="lo",
  description="VEDIC SIGN ANUSVARA VAMAGOMUKHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CEB,
 },
 [0x1CEC]={
  category="lo",
  description="VEDIC SIGN ANUSVARA VAMAGOMUKHA WITH TAIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CEC,
 },
 [0x1CED]={
  category="mn",
  description="VEDIC SIGN TIRYAK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CED,
 },
 [0x1CEE]={
  category="lo",
  description="VEDIC SIGN HEXIFORM LONG ANUSVARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CEE,
 },
 [0x1CEF]={
  category="lo",
  description="VEDIC SIGN LONG ANUSVARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CEF,
 },
 [0x1CF0]={
  category="lo",
  description="VEDIC SIGN RTHANG LONG ANUSVARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CF0,
 },
 [0x1CF1]={
  category="lo",
  description="VEDIC SIGN ANUSVARA UBHAYATO MUKHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CF1,
 },
 [0x1CF2]={
  category="mc",
  description="VEDIC SIGN ARDHAVISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1CF2,
 },
 [0x1CF3]={
  category="mc",
  description="VEDIC SIGN ROTATED ARDHAVISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1CF3,
 },
 [0x1CF4]={
  category="mn",
  description="VEDIC TONE CANDRA ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1CF4,
 },
 [0x1CF5]={
  category="lo",
  description="VEDIC SIGN JIHVAMULIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CF5,
 },
 [0x1CF6]={
  category="lo",
  description="VEDIC SIGN UPADHMANIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1CF6,
 },
 [0x1D00]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D00,
 },
 [0x1D01]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL AE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D01,
 },
 [0x1D02]={
  category="ll",
  description="LATIN SMALL LETTER TURNED AE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D02,
 },
 [0x1D03]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL BARRED B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D03,
 },
 [0x1D04]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL C",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D04,
 },
 [0x1D05]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL D",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D05,
 },
 [0x1D06]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL ETH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D06,
 },
 [0x1D07]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D07,
 },
 [0x1D08]={
  category="ll",
  description="LATIN SMALL LETTER TURNED OPEN E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D08,
 },
 [0x1D09]={
  category="ll",
  description="LATIN SMALL LETTER TURNED I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D09,
 },
 [0x1D0A]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL J",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A,
 },
 [0x1D0B]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL K",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B,
 },
 [0x1D0C]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL L WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C,
 },
 [0x1D0D]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL M",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D,
 },
 [0x1D0E]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL REVERSED N",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E,
 },
 [0x1D0F]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0F,
 },
 [0x1D10]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL OPEN O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D10,
 },
 [0x1D11]={
  category="ll",
  description="LATIN SMALL LETTER SIDEWAYS O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D11,
 },
 [0x1D12]={
  category="ll",
  description="LATIN SMALL LETTER SIDEWAYS OPEN O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D12,
 },
 [0x1D13]={
  category="ll",
  description="LATIN SMALL LETTER SIDEWAYS O WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D13,
 },
 [0x1D14]={
  category="ll",
  description="LATIN SMALL LETTER TURNED OE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D14,
 },
 [0x1D15]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL OU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D15,
 },
 [0x1D16]={
  category="ll",
  description="LATIN SMALL LETTER TOP HALF O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D16,
 },
 [0x1D17]={
  category="ll",
  description="LATIN SMALL LETTER BOTTOM HALF O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D17,
 },
 [0x1D18]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL P",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D18,
 },
 [0x1D19]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL REVERSED R",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D19,
 },
 [0x1D1A]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL TURNED R",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A,
 },
 [0x1D1B]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL T",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B,
 },
 [0x1D1C]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C,
 },
 [0x1D1D]={
  category="ll",
  description="LATIN SMALL LETTER SIDEWAYS U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D,
 },
 [0x1D1E]={
  category="ll",
  description="LATIN SMALL LETTER SIDEWAYS DIAERESIZED U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1E,
 },
 [0x1D1F]={
  category="ll",
  description="LATIN SMALL LETTER SIDEWAYS TURNED M",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1F,
 },
 [0x1D20]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL V",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D20,
 },
 [0x1D21]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL W",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D21,
 },
 [0x1D22]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL Z",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D22,
 },
 [0x1D23]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL EZH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D23,
 },
 [0x1D24]={
  category="ll",
  description="LATIN LETTER VOICED LARYNGEAL SPIRANT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D24,
 },
 [0x1D25]={
  category="ll",
  description="LATIN LETTER AIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D25,
 },
 [0x1D26]={
  category="ll",
  description="GREEK LETTER SMALL CAPITAL GAMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D26,
 },
 [0x1D27]={
  category="ll",
  description="GREEK LETTER SMALL CAPITAL LAMDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D27,
 },
 [0x1D28]={
  category="ll",
  description="GREEK LETTER SMALL CAPITAL PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D28,
 },
 [0x1D29]={
  category="ll",
  description="GREEK LETTER SMALL CAPITAL RHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D29,
 },
 [0x1D2A]={
  category="ll",
  description="GREEK LETTER SMALL CAPITAL PSI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D2A,
 },
 [0x1D2B]={
  category="ll",
  description="CYRILLIC LETTER SMALL CAPITAL EL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D2B,
 },
 [0x1D2C]={
  category="lm",
  description="MODIFIER LETTER CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0041 },
  unicodeslot=0x1D2C,
 },
 [0x1D2D]={
  category="lm",
  description="MODIFIER LETTER CAPITAL AE",
  direction="l",
  linebreak="al",
  specials={ "super", 0x00C6 },
  unicodeslot=0x1D2D,
 },
 [0x1D2E]={
  category="lm",
  description="MODIFIER LETTER CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0042 },
  unicodeslot=0x1D2E,
 },
 [0x1D2F]={
  category="lm",
  description="MODIFIER LETTER CAPITAL BARRED B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D2F,
 },
 [0x1D30]={
  category="lm",
  description="MODIFIER LETTER CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0044 },
  unicodeslot=0x1D30,
 },
 [0x1D31]={
  category="lm",
  description="MODIFIER LETTER CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0045 },
  unicodeslot=0x1D31,
 },
 [0x1D32]={
  category="lm",
  description="MODIFIER LETTER CAPITAL REVERSED E",
  direction="l",
  linebreak="al",
  specials={ "super", 0x018E },
  unicodeslot=0x1D32,
 },
 [0x1D33]={
  category="lm",
  description="MODIFIER LETTER CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0047 },
  unicodeslot=0x1D33,
 },
 [0x1D34]={
  category="lm",
  description="MODIFIER LETTER CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0048 },
  unicodeslot=0x1D34,
 },
 [0x1D35]={
  category="lm",
  description="MODIFIER LETTER CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0049 },
  unicodeslot=0x1D35,
 },
 [0x1D36]={
  category="lm",
  description="MODIFIER LETTER CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "super", 0x004A },
  unicodeslot=0x1D36,
 },
 [0x1D37]={
  category="lm",
  description="MODIFIER LETTER CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "super", 0x004B },
  unicodeslot=0x1D37,
 },
 [0x1D38]={
  category="lm",
  description="MODIFIER LETTER CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "super", 0x004C },
  unicodeslot=0x1D38,
 },
 [0x1D39]={
  category="lm",
  description="MODIFIER LETTER CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "super", 0x004D },
  unicodeslot=0x1D39,
 },
 [0x1D3A]={
  category="lm",
  description="MODIFIER LETTER CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "super", 0x004E },
  unicodeslot=0x1D3A,
 },
 [0x1D3B]={
  category="lm",
  description="MODIFIER LETTER CAPITAL REVERSED N",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D3B,
 },
 [0x1D3C]={
  category="lm",
  description="MODIFIER LETTER CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "super", 0x004F },
  unicodeslot=0x1D3C,
 },
 [0x1D3D]={
  category="lm",
  description="MODIFIER LETTER CAPITAL OU",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0222 },
  unicodeslot=0x1D3D,
 },
 [0x1D3E]={
  category="lm",
  description="MODIFIER LETTER CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0050 },
  unicodeslot=0x1D3E,
 },
 [0x1D3F]={
  category="lm",
  description="MODIFIER LETTER CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0052 },
  unicodeslot=0x1D3F,
 },
 [0x1D40]={
  category="lm",
  description="MODIFIER LETTER CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0054 },
  unicodeslot=0x1D40,
 },
 [0x1D41]={
  category="lm",
  description="MODIFIER LETTER CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0055 },
  unicodeslot=0x1D41,
 },
 [0x1D42]={
  category="lm",
  description="MODIFIER LETTER CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0057 },
  unicodeslot=0x1D42,
 },
 [0x1D43]={
  category="lm",
  description="MODIFIER LETTER SMALL A",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0061 },
  unicodeslot=0x1D43,
 },
 [0x1D44]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED A",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0250 },
  unicodeslot=0x1D44,
 },
 [0x1D45]={
  category="lm",
  description="MODIFIER LETTER SMALL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0251 },
  unicodeslot=0x1D45,
 },
 [0x1D46]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED AE",
  direction="l",
  linebreak="al",
  specials={ "super", 0x1D02 },
  unicodeslot=0x1D46,
 },
 [0x1D47]={
  category="lm",
  description="MODIFIER LETTER SMALL B",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0062 },
  unicodeslot=0x1D47,
 },
 [0x1D48]={
  category="lm",
  description="MODIFIER LETTER SMALL D",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0064 },
  unicodeslot=0x1D48,
 },
 [0x1D49]={
  category="lm",
  description="MODIFIER LETTER SMALL E",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0065 },
  unicodeslot=0x1D49,
 },
 [0x1D4A]={
  category="lm",
  description="MODIFIER LETTER SMALL SCHWA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0259 },
  unicodeslot=0x1D4A,
 },
 [0x1D4B]={
  category="lm",
  description="MODIFIER LETTER SMALL OPEN E",
  direction="l",
  linebreak="al",
  specials={ "super", 0x025B },
  unicodeslot=0x1D4B,
 },
 [0x1D4C]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED OPEN E",
  direction="l",
  linebreak="al",
  specials={ "super", 0x025C },
  unicodeslot=0x1D4C,
 },
 [0x1D4D]={
  category="lm",
  description="MODIFIER LETTER SMALL G",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0067 },
  unicodeslot=0x1D4D,
 },
 [0x1D4E]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D4E,
 },
 [0x1D4F]={
  category="lm",
  description="MODIFIER LETTER SMALL K",
  direction="l",
  linebreak="al",
  specials={ "super", 0x006B },
  unicodeslot=0x1D4F,
 },
 [0x1D50]={
  category="lm",
  description="MODIFIER LETTER SMALL M",
  direction="l",
  linebreak="al",
  specials={ "super", 0x006D },
  unicodeslot=0x1D50,
 },
 [0x1D51]={
  category="lm",
  description="MODIFIER LETTER SMALL ENG",
  direction="l",
  linebreak="al",
  specials={ "super", 0x014B },
  unicodeslot=0x1D51,
 },
 [0x1D52]={
  category="lm",
  description="MODIFIER LETTER SMALL O",
  direction="l",
  linebreak="al",
  specials={ "super", 0x006F },
  unicodeslot=0x1D52,
 },
 [0x1D53]={
  category="lm",
  description="MODIFIER LETTER SMALL OPEN O",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0254 },
  unicodeslot=0x1D53,
 },
 [0x1D54]={
  category="lm",
  description="MODIFIER LETTER SMALL TOP HALF O",
  direction="l",
  linebreak="al",
  specials={ "super", 0x1D16 },
  unicodeslot=0x1D54,
 },
 [0x1D55]={
  category="lm",
  description="MODIFIER LETTER SMALL BOTTOM HALF O",
  direction="l",
  linebreak="al",
  specials={ "super", 0x1D17 },
  unicodeslot=0x1D55,
 },
 [0x1D56]={
  category="lm",
  description="MODIFIER LETTER SMALL P",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0070 },
  unicodeslot=0x1D56,
 },
 [0x1D57]={
  category="lm",
  description="MODIFIER LETTER SMALL T",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0074 },
  unicodeslot=0x1D57,
 },
 [0x1D58]={
  category="lm",
  description="MODIFIER LETTER SMALL U",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0075 },
  unicodeslot=0x1D58,
 },
 [0x1D59]={
  category="lm",
  description="MODIFIER LETTER SMALL SIDEWAYS U",
  direction="l",
  linebreak="al",
  specials={ "super", 0x1D1D },
  unicodeslot=0x1D59,
 },
 [0x1D5A]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED M",
  direction="l",
  linebreak="al",
  specials={ "super", 0x026F },
  unicodeslot=0x1D5A,
 },
 [0x1D5B]={
  category="lm",
  description="MODIFIER LETTER SMALL V",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0076 },
  unicodeslot=0x1D5B,
 },
 [0x1D5C]={
  category="lm",
  description="MODIFIER LETTER SMALL AIN",
  direction="l",
  linebreak="al",
  specials={ "super", 0x1D25 },
  unicodeslot=0x1D5C,
 },
 [0x1D5D]={
  category="lm",
  description="MODIFIER LETTER SMALL BETA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x03B2 },
  unicodeslot=0x1D5D,
 },
 [0x1D5E]={
  category="lm",
  description="MODIFIER LETTER SMALL GREEK GAMMA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x03B3 },
  unicodeslot=0x1D5E,
 },
 [0x1D5F]={
  category="lm",
  description="MODIFIER LETTER SMALL DELTA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x03B4 },
  unicodeslot=0x1D5F,
 },
 [0x1D60]={
  category="lm",
  description="MODIFIER LETTER SMALL GREEK PHI",
  direction="l",
  linebreak="al",
  specials={ "super", 0x03C6 },
  unicodeslot=0x1D60,
 },
 [0x1D61]={
  category="lm",
  description="MODIFIER LETTER SMALL CHI",
  direction="l",
  linebreak="al",
  specials={ "super", 0x03C7 },
  unicodeslot=0x1D61,
 },
 [0x1D62]={
  category="ll",
  description="LATIN SUBSCRIPT SMALL LETTER I",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0069 },
  unicodeslot=0x1D62,
 },
 [0x1D63]={
  category="ll",
  description="LATIN SUBSCRIPT SMALL LETTER R",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0072 },
  unicodeslot=0x1D63,
 },
 [0x1D64]={
  category="ll",
  description="LATIN SUBSCRIPT SMALL LETTER U",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0075 },
  unicodeslot=0x1D64,
 },
 [0x1D65]={
  category="ll",
  description="LATIN SUBSCRIPT SMALL LETTER V",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0076 },
  unicodeslot=0x1D65,
 },
 [0x1D66]={
  category="ll",
  description="GREEK SUBSCRIPT SMALL LETTER BETA",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x03B2 },
  unicodeslot=0x1D66,
 },
 [0x1D67]={
  category="ll",
  description="GREEK SUBSCRIPT SMALL LETTER GAMMA",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x03B3 },
  unicodeslot=0x1D67,
 },
 [0x1D68]={
  category="ll",
  description="GREEK SUBSCRIPT SMALL LETTER RHO",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x03C1 },
  unicodeslot=0x1D68,
 },
 [0x1D69]={
  category="ll",
  description="GREEK SUBSCRIPT SMALL LETTER PHI",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x03C6 },
  unicodeslot=0x1D69,
 },
 [0x1D6A]={
  category="ll",
  description="GREEK SUBSCRIPT SMALL LETTER CHI",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x03C7 },
  unicodeslot=0x1D6A,
 },
 [0x1D6B]={
  category="ll",
  description="LATIN SMALL LETTER UE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D6B,
 },
 [0x1D6C]={
  category="ll",
  description="LATIN SMALL LETTER B WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0062,
  unicodeslot=0x1D6C,
 },
 [0x1D6D]={
  category="ll",
  description="LATIN SMALL LETTER D WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  unicodeslot=0x1D6D,
 },
 [0x1D6E]={
  category="ll",
  description="LATIN SMALL LETTER F WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0066,
  unicodeslot=0x1D6E,
 },
 [0x1D6F]={
  category="ll",
  description="LATIN SMALL LETTER M WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x006D,
  unicodeslot=0x1D6F,
 },
 [0x1D70]={
  category="ll",
  description="LATIN SMALL LETTER N WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  unicodeslot=0x1D70,
 },
 [0x1D71]={
  category="ll",
  description="LATIN SMALL LETTER P WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0070,
  unicodeslot=0x1D71,
 },
 [0x1D72]={
  category="ll",
  description="LATIN SMALL LETTER R WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  unicodeslot=0x1D72,
 },
 [0x1D73]={
  category="ll",
  description="LATIN SMALL LETTER R WITH FISHHOOK AND MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  unicodeslot=0x1D73,
 },
 [0x1D74]={
  category="ll",
  description="LATIN SMALL LETTER S WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  unicodeslot=0x1D74,
 },
 [0x1D75]={
  category="ll",
  description="LATIN SMALL LETTER T WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  unicodeslot=0x1D75,
 },
 [0x1D76]={
  category="ll",
  description="LATIN SMALL LETTER Z WITH MIDDLE TILDE",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  unicodeslot=0x1D76,
 },
 [0x1D77]={
  category="ll",
  description="LATIN SMALL LETTER TURNED G",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D77,
 },
 [0x1D78]={
  category="lm",
  description="MODIFIER LETTER CYRILLIC EN",
  direction="l",
  linebreak="al",
  specials={ "super", 0x043D },
  unicodeslot=0x1D78,
 },
 [0x1D79]={
  category="ll",
  description="LATIN SMALL LETTER INSULAR G",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D79,
 },
 [0x1D7A]={
  category="ll",
  description="LATIN SMALL LETTER TH WITH STRIKETHROUGH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D7A,
 },
 [0x1D7B]={
  category="ll",
  description="LATIN SMALL CAPITAL LETTER I WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D7B,
 },
 [0x1D7C]={
  category="ll",
  description="LATIN SMALL LETTER IOTA WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0269,
  unicodeslot=0x1D7C,
 },
 [0x1D7D]={
  category="ll",
  description="LATIN SMALL LETTER P WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0070,
  uccode=0x2C63,
  unicodeslot=0x1D7D,
 },
 [0x1D7E]={
  category="ll",
  description="LATIN SMALL CAPITAL LETTER U WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D7E,
 },
 [0x1D7F]={
  category="ll",
  description="LATIN SMALL LETTER UPSILON WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x028A,
  unicodeslot=0x1D7F,
 },
 [0x1D80]={
  category="ll",
  description="LATIN SMALL LETTER B WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0062,
  unicodeslot=0x1D80,
 },
 [0x1D81]={
  category="ll",
  description="LATIN SMALL LETTER D WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  unicodeslot=0x1D81,
 },
 [0x1D82]={
  category="ll",
  description="LATIN SMALL LETTER F WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0066,
  unicodeslot=0x1D82,
 },
 [0x1D83]={
  category="ll",
  description="LATIN SMALL LETTER G WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  unicodeslot=0x1D83,
 },
 [0x1D84]={
  category="ll",
  description="LATIN SMALL LETTER K WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006B,
  unicodeslot=0x1D84,
 },
 [0x1D85]={
  category="ll",
  description="LATIN SMALL LETTER L WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  unicodeslot=0x1D85,
 },
 [0x1D86]={
  category="ll",
  description="LATIN SMALL LETTER M WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006D,
  unicodeslot=0x1D86,
 },
 [0x1D87]={
  category="ll",
  description="LATIN SMALL LETTER N WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  unicodeslot=0x1D87,
 },
 [0x1D88]={
  category="ll",
  description="LATIN SMALL LETTER P WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0070,
  unicodeslot=0x1D88,
 },
 [0x1D89]={
  category="ll",
  description="LATIN SMALL LETTER R WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  unicodeslot=0x1D89,
 },
 [0x1D8A]={
  category="ll",
  description="LATIN SMALL LETTER S WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  unicodeslot=0x1D8A,
 },
 [0x1D8B]={
  category="ll",
  description="LATIN SMALL LETTER ESH WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0283,
  unicodeslot=0x1D8B,
 },
 [0x1D8C]={
  category="ll",
  description="LATIN SMALL LETTER V WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0076,
  unicodeslot=0x1D8C,
 },
 [0x1D8D]={
  category="ll",
  description="LATIN SMALL LETTER X WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0078,
  unicodeslot=0x1D8D,
 },
 [0x1D8E]={
  category="ll",
  description="LATIN SMALL LETTER Z WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  unicodeslot=0x1D8E,
 },
 [0x1D8F]={
  category="ll",
  description="LATIN SMALL LETTER A WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  unicodeslot=0x1D8F,
 },
 [0x1D90]={
  category="ll",
  description="LATIN SMALL LETTER ALPHA WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0251,
  unicodeslot=0x1D90,
 },
 [0x1D91]={
  category="ll",
  description="LATIN SMALL LETTER D WITH HOOK AND TAIL",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  unicodeslot=0x1D91,
 },
 [0x1D92]={
  category="ll",
  description="LATIN SMALL LETTER E WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  unicodeslot=0x1D92,
 },
 [0x1D93]={
  category="ll",
  description="LATIN SMALL LETTER OPEN E WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D93,
 },
 [0x1D94]={
  category="ll",
  description="LATIN SMALL LETTER REVERSED OPEN E WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D94,
 },
 [0x1D95]={
  category="ll",
  description="LATIN SMALL LETTER SCHWA WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0259,
  unicodeslot=0x1D95,
 },
 [0x1D96]={
  category="ll",
  description="LATIN SMALL LETTER I WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  unicodeslot=0x1D96,
 },
 [0x1D97]={
  category="ll",
  description="LATIN SMALL LETTER OPEN O WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D97,
 },
 [0x1D98]={
  category="ll",
  description="LATIN SMALL LETTER ESH WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0283,
  unicodeslot=0x1D98,
 },
 [0x1D99]={
  category="ll",
  description="LATIN SMALL LETTER U WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  unicodeslot=0x1D99,
 },
 [0x1D9A]={
  category="ll",
  description="LATIN SMALL LETTER EZH WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  shcode=0x0292,
  unicodeslot=0x1D9A,
 },
 [0x1D9B]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED ALPHA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0252 },
  unicodeslot=0x1D9B,
 },
 [0x1D9C]={
  category="lm",
  description="MODIFIER LETTER SMALL C",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0063 },
  unicodeslot=0x1D9C,
 },
 [0x1D9D]={
  category="lm",
  description="MODIFIER LETTER SMALL C WITH CURL",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0255 },
  unicodeslot=0x1D9D,
 },
 [0x1D9E]={
  category="lm",
  description="MODIFIER LETTER SMALL ETH",
  direction="l",
  linebreak="al",
  specials={ "super", 0x00F0 },
  unicodeslot=0x1D9E,
 },
 [0x1D9F]={
  category="lm",
  description="MODIFIER LETTER SMALL REVERSED OPEN E",
  direction="l",
  linebreak="al",
  specials={ "super", 0x025C },
  unicodeslot=0x1D9F,
 },
 [0x1DA0]={
  category="lm",
  description="MODIFIER LETTER SMALL F",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0066 },
  unicodeslot=0x1DA0,
 },
 [0x1DA1]={
  category="lm",
  description="MODIFIER LETTER SMALL DOTLESS J WITH STROKE",
  direction="l",
  linebreak="al",
  specials={ "super", 0x025F },
  unicodeslot=0x1DA1,
 },
 [0x1DA2]={
  category="lm",
  description="MODIFIER LETTER SMALL SCRIPT G",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0261 },
  unicodeslot=0x1DA2,
 },
 [0x1DA3]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED H",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0265 },
  unicodeslot=0x1DA3,
 },
 [0x1DA4]={
  category="lm",
  description="MODIFIER LETTER SMALL I WITH STROKE",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0268 },
  unicodeslot=0x1DA4,
 },
 [0x1DA5]={
  category="lm",
  description="MODIFIER LETTER SMALL IOTA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0269 },
  unicodeslot=0x1DA5,
 },
 [0x1DA6]={
  category="lm",
  description="MODIFIER LETTER SMALL CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "super", 0x026A },
  unicodeslot=0x1DA6,
 },
 [0x1DA7]={
  category="lm",
  description="MODIFIER LETTER SMALL CAPITAL I WITH STROKE",
  direction="l",
  linebreak="al",
  specials={ "super", 0x1D7B },
  unicodeslot=0x1DA7,
 },
 [0x1DA8]={
  category="lm",
  description="MODIFIER LETTER SMALL J WITH CROSSED-TAIL",
  direction="l",
  linebreak="al",
  specials={ "super", 0x029D },
  unicodeslot=0x1DA8,
 },
 [0x1DA9]={
  category="lm",
  description="MODIFIER LETTER SMALL L WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x026D },
  unicodeslot=0x1DA9,
 },
 [0x1DAA]={
  category="lm",
  description="MODIFIER LETTER SMALL L WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x1D85 },
  unicodeslot=0x1DAA,
 },
 [0x1DAB]={
  category="lm",
  description="MODIFIER LETTER SMALL CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "super", 0x029F },
  unicodeslot=0x1DAB,
 },
 [0x1DAC]={
  category="lm",
  description="MODIFIER LETTER SMALL M WITH HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0271 },
  unicodeslot=0x1DAC,
 },
 [0x1DAD]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED M WITH LONG LEG",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0270 },
  unicodeslot=0x1DAD,
 },
 [0x1DAE]={
  category="lm",
  description="MODIFIER LETTER SMALL N WITH LEFT HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0272 },
  unicodeslot=0x1DAE,
 },
 [0x1DAF]={
  category="lm",
  description="MODIFIER LETTER SMALL N WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0273 },
  unicodeslot=0x1DAF,
 },
 [0x1DB0]={
  category="lm",
  description="MODIFIER LETTER SMALL CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0274 },
  unicodeslot=0x1DB0,
 },
 [0x1DB1]={
  category="lm",
  description="MODIFIER LETTER SMALL BARRED O",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0275 },
  unicodeslot=0x1DB1,
 },
 [0x1DB2]={
  category="lm",
  description="MODIFIER LETTER SMALL PHI",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0278 },
  unicodeslot=0x1DB2,
 },
 [0x1DB3]={
  category="lm",
  description="MODIFIER LETTER SMALL S WITH HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0282 },
  unicodeslot=0x1DB3,
 },
 [0x1DB4]={
  category="lm",
  description="MODIFIER LETTER SMALL ESH",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0283 },
  unicodeslot=0x1DB4,
 },
 [0x1DB5]={
  category="lm",
  description="MODIFIER LETTER SMALL T WITH PALATAL HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x01AB },
  unicodeslot=0x1DB5,
 },
 [0x1DB6]={
  category="lm",
  description="MODIFIER LETTER SMALL U BAR",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0289 },
  unicodeslot=0x1DB6,
 },
 [0x1DB7]={
  category="lm",
  description="MODIFIER LETTER SMALL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "super", 0x028A },
  unicodeslot=0x1DB7,
 },
 [0x1DB8]={
  category="lm",
  description="MODIFIER LETTER SMALL CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "super", 0x1D1C },
  unicodeslot=0x1DB8,
 },
 [0x1DB9]={
  category="lm",
  description="MODIFIER LETTER SMALL V WITH HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x028B },
  unicodeslot=0x1DB9,
 },
 [0x1DBA]={
  category="lm",
  description="MODIFIER LETTER SMALL TURNED V",
  direction="l",
  linebreak="al",
  specials={ "super", 0x028C },
  unicodeslot=0x1DBA,
 },
 [0x1DBB]={
  category="lm",
  description="MODIFIER LETTER SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "super", 0x007A },
  unicodeslot=0x1DBB,
 },
 [0x1DBC]={
  category="lm",
  description="MODIFIER LETTER SMALL Z WITH RETROFLEX HOOK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0290 },
  unicodeslot=0x1DBC,
 },
 [0x1DBD]={
  category="lm",
  description="MODIFIER LETTER SMALL Z WITH CURL",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0291 },
  unicodeslot=0x1DBD,
 },
 [0x1DBE]={
  category="lm",
  description="MODIFIER LETTER SMALL EZH",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0292 },
  unicodeslot=0x1DBE,
 },
 [0x1DBF]={
  category="lm",
  description="MODIFIER LETTER SMALL THETA",
  direction="l",
  linebreak="al",
  specials={ "super", 0x03B8 },
  unicodeslot=0x1DBF,
 },
 [0x1DC0]={
  category="mn",
  description="COMBINING DOTTED GRAVE ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC0,
 },
 [0x1DC1]={
  category="mn",
  description="COMBINING DOTTED ACUTE ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC1,
 },
 [0x1DC2]={
  category="mn",
  description="COMBINING SNAKE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC2,
 },
 [0x1DC3]={
  category="mn",
  description="COMBINING SUSPENSION MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC3,
 },
 [0x1DC4]={
  category="mn",
  description="COMBINING MACRON-ACUTE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC4,
 },
 [0x1DC5]={
  category="mn",
  description="COMBINING GRAVE-MACRON",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC5,
 },
 [0x1DC6]={
  category="mn",
  description="COMBINING MACRON-GRAVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC6,
 },
 [0x1DC7]={
  category="mn",
  description="COMBINING ACUTE-MACRON",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC7,
 },
 [0x1DC8]={
  category="mn",
  description="COMBINING GRAVE-ACUTE-GRAVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC8,
 },
 [0x1DC9]={
  category="mn",
  description="COMBINING ACUTE-GRAVE-ACUTE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DC9,
 },
 [0x1DCA]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER R BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DCA,
 },
 [0x1DCB]={
  category="mn",
  description="COMBINING BREVE-MACRON",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DCB,
 },
 [0x1DCC]={
  category="mn",
  description="COMBINING MACRON-BREVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DCC,
 },
 [0x1DCD]={
  category="mn",
  description="COMBINING DOUBLE CIRCUMFLEX ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DCD,
 },
 [0x1DCE]={
  category="mn",
  description="COMBINING OGONEK ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DCE,
 },
 [0x1DCF]={
  category="mn",
  description="COMBINING ZIGZAG BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DCF,
 },
 [0x1DD0]={
  category="mn",
  description="COMBINING IS BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD0,
 },
 [0x1DD1]={
  category="mn",
  description="COMBINING UR ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD1,
 },
 [0x1DD2]={
  category="mn",
  description="COMBINING US ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD2,
 },
 [0x1DD3]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER FLATTENED OPEN A ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD3,
 },
 [0x1DD4]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER AE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD4,
 },
 [0x1DD5]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER AO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD5,
 },
 [0x1DD6]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER AV",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD6,
 },
 [0x1DD7]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER C CEDILLA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD7,
 },
 [0x1DD8]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER INSULAR D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD8,
 },
 [0x1DD9]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER ETH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DD9,
 },
 [0x1DDA]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER G",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DDA,
 },
 [0x1DDB]={
  category="mn",
  description="COMBINING LATIN LETTER SMALL CAPITAL G",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DDB,
 },
 [0x1DDC]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER K",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DDC,
 },
 [0x1DDD]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DDD,
 },
 [0x1DDE]={
  category="mn",
  description="COMBINING LATIN LETTER SMALL CAPITAL L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DDE,
 },
 [0x1DDF]={
  category="mn",
  description="COMBINING LATIN LETTER SMALL CAPITAL M",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DDF,
 },
 [0x1DE0]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER N",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DE0,
 },
 [0x1DE1]={
  category="mn",
  description="COMBINING LATIN LETTER SMALL CAPITAL N",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DE1,
 },
 [0x1DE2]={
  category="mn",
  description="COMBINING LATIN LETTER SMALL CAPITAL R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DE2,
 },
 [0x1DE3]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER R ROTUNDA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DE3,
 },
 [0x1DE4]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER S",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DE4,
 },
 [0x1DE5]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER LONG S",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DE5,
 },
 [0x1DE6]={
  category="mn",
  description="COMBINING LATIN SMALL LETTER Z",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DE6,
 },
 [0x1DFC]={
  category="mn",
  description="COMBINING DOUBLE INVERTED BREVE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DFC,
 },
 [0x1DFD]={
  category="mn",
  description="COMBINING ALMOST EQUAL TO BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DFD,
 },
 [0x1DFE]={
  category="mn",
  description="COMBINING LEFT ARROWHEAD ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DFE,
 },
 [0x1DFF]={
  category="mn",
  description="COMBINING RIGHT ARROWHEAD AND DOWN ARROWHEAD BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1DFF,
 },
 [0x1E00]={
  adobename="Aringbelow",
  category="lu",
  description="LATIN CAPITAL LETTER A WITH RING BELOW",
  direction="l",
  lccode=0x1E01,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0325 },
  unicodeslot=0x1E00,
 },
 [0x1E01]={
  adobename="aringbelow",
  category="ll",
  description="LATIN SMALL LETTER A WITH RING BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0325 },
  uccode=0x1E00,
  unicodeslot=0x1E01,
 },
 [0x1E02]={
  adobename="Bdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER B WITH DOT ABOVE",
  direction="l",
  lccode=0x1E03,
  linebreak="al",
  shcode=0x0042,
  specials={ "char", 0x0042, 0x0307 },
  unicodeslot=0x1E02,
 },
 [0x1E03]={
  adobename="bdotaccent",
  category="ll",
  description="LATIN SMALL LETTER B WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0062,
  specials={ "char", 0x0062, 0x0307 },
  uccode=0x1E02,
  unicodeslot=0x1E03,
 },
 [0x1E04]={
  adobename="Bdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER B WITH DOT BELOW",
  direction="l",
  lccode=0x1E05,
  linebreak="al",
  shcode=0x0042,
  specials={ "char", 0x0042, 0x0323 },
  unicodeslot=0x1E04,
 },
 [0x1E05]={
  adobename="bdotbelow",
  category="ll",
  description="LATIN SMALL LETTER B WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0062,
  specials={ "char", 0x0062, 0x0323 },
  uccode=0x1E04,
  unicodeslot=0x1E05,
 },
 [0x1E06]={
  adobename="Blinebelow",
  category="lu",
  description="LATIN CAPITAL LETTER B WITH LINE BELOW",
  direction="l",
  lccode=0x1E07,
  linebreak="al",
  shcode=0x0042,
  specials={ "char", 0x0042, 0x0331 },
  unicodeslot=0x1E06,
 },
 [0x1E07]={
  adobename="blinebelow",
  category="ll",
  description="LATIN SMALL LETTER B WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0062,
  specials={ "char", 0x0062, 0x0331 },
  uccode=0x1E06,
  unicodeslot=0x1E07,
 },
 [0x1E08]={
  adobename="Ccedillaacute",
  category="lu",
  description="LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE",
  direction="l",
  lccode=0x1E09,
  linebreak="al",
  shcode=0x0043,
  specials={ "char", 0x00C7, 0x0301 },
  unicodeslot=0x1E08,
 },
 [0x1E09]={
  adobename="ccedillaacute",
  category="ll",
  description="LATIN SMALL LETTER C WITH CEDILLA AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0063,
  specials={ "char", 0x00E7, 0x0301 },
  uccode=0x1E08,
  unicodeslot=0x1E09,
 },
 [0x1E0A]={
  adobename="Ddotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER D WITH DOT ABOVE",
  direction="l",
  lccode=0x1E0B,
  linebreak="al",
  shcode=0x0044,
  specials={ "char", 0x0044, 0x0307 },
  unicodeslot=0x1E0A,
 },
 [0x1E0B]={
  adobename="ddotaccent",
  category="ll",
  description="LATIN SMALL LETTER D WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  specials={ "char", 0x0064, 0x0307 },
  uccode=0x1E0A,
  unicodeslot=0x1E0B,
 },
 [0x1E0C]={
  adobename="Ddotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER D WITH DOT BELOW",
  direction="l",
  lccode=0x1E0D,
  linebreak="al",
  shcode=0x0044,
  specials={ "char", 0x0044, 0x0323 },
  unicodeslot=0x1E0C,
 },
 [0x1E0D]={
  adobename="ddotbelow",
  category="ll",
  description="LATIN SMALL LETTER D WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  specials={ "char", 0x0064, 0x0323 },
  uccode=0x1E0C,
  unicodeslot=0x1E0D,
 },
 [0x1E0E]={
  adobename="Dlinebelow",
  category="lu",
  description="LATIN CAPITAL LETTER D WITH LINE BELOW",
  direction="l",
  lccode=0x1E0F,
  linebreak="al",
  shcode=0x0044,
  specials={ "char", 0x0044, 0x0331 },
  unicodeslot=0x1E0E,
 },
 [0x1E0F]={
  adobename="dlinebelow",
  category="ll",
  description="LATIN SMALL LETTER D WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  specials={ "char", 0x0064, 0x0331 },
  uccode=0x1E0E,
  unicodeslot=0x1E0F,
 },
 [0x1E10]={
  adobename="Dcedilla",
  category="lu",
  description="LATIN CAPITAL LETTER D WITH CEDILLA",
  direction="l",
  lccode=0x1E11,
  linebreak="al",
  shcode=0x0044,
  specials={ "char", 0x0044, 0x0327 },
  unicodeslot=0x1E10,
 },
 [0x1E11]={
  adobename="dcedilla",
  category="ll",
  description="LATIN SMALL LETTER D WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  specials={ "char", 0x0064, 0x0327 },
  uccode=0x1E10,
  unicodeslot=0x1E11,
 },
 [0x1E12]={
  adobename="Dcircumflexbelow",
  category="lu",
  description="LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW",
  direction="l",
  lccode=0x1E13,
  linebreak="al",
  shcode=0x0044,
  specials={ "char", 0x0044, 0x032D },
  unicodeslot=0x1E12,
 },
 [0x1E13]={
  adobename="dcircumflexbelow",
  category="ll",
  description="LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0064,
  specials={ "char", 0x0064, 0x032D },
  uccode=0x1E12,
  unicodeslot=0x1E13,
 },
 [0x1E14]={
  adobename="Emacrongrave",
  category="lu",
  description="LATIN CAPITAL LETTER E WITH MACRON AND GRAVE",
  direction="l",
  lccode=0x1E15,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0112, 0x0300 },
  unicodeslot=0x1E14,
 },
 [0x1E15]={
  adobename="emacrongrave",
  category="ll",
  description="LATIN SMALL LETTER E WITH MACRON AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0113, 0x0300 },
  uccode=0x1E14,
  unicodeslot=0x1E15,
 },
 [0x1E16]={
  adobename="Emacronacute",
  category="lu",
  description="LATIN CAPITAL LETTER E WITH MACRON AND ACUTE",
  direction="l",
  lccode=0x1E17,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0112, 0x0301 },
  unicodeslot=0x1E16,
 },
 [0x1E17]={
  adobename="emacronacute",
  category="ll",
  description="LATIN SMALL LETTER E WITH MACRON AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0113, 0x0301 },
  uccode=0x1E16,
  unicodeslot=0x1E17,
 },
 [0x1E18]={
  adobename="Ecircumflexbelow",
  category="lu",
  description="LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW",
  direction="l",
  lccode=0x1E19,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x032D },
  unicodeslot=0x1E18,
 },
 [0x1E19]={
  adobename="ecircumflexbelow",
  category="ll",
  description="LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x032D },
  uccode=0x1E18,
  unicodeslot=0x1E19,
 },
 [0x1E1A]={
  adobename="Etildebelow",
  category="lu",
  description="LATIN CAPITAL LETTER E WITH TILDE BELOW",
  direction="l",
  lccode=0x1E1B,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0330 },
  unicodeslot=0x1E1A,
 },
 [0x1E1B]={
  adobename="etildebelow",
  category="ll",
  description="LATIN SMALL LETTER E WITH TILDE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0330 },
  uccode=0x1E1A,
  unicodeslot=0x1E1B,
 },
 [0x1E1C]={
  adobename="Ecedillabreve",
  category="lu",
  description="LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE",
  direction="l",
  lccode=0x1E1D,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0228, 0x0306 },
  unicodeslot=0x1E1C,
 },
 [0x1E1D]={
  adobename="ecedillabreve",
  category="ll",
  description="LATIN SMALL LETTER E WITH CEDILLA AND BREVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0229, 0x0306 },
  uccode=0x1E1C,
  unicodeslot=0x1E1D,
 },
 [0x1E1E]={
  adobename="Fdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER F WITH DOT ABOVE",
  direction="l",
  lccode=0x1E1F,
  linebreak="al",
  shcode=0x0046,
  specials={ "char", 0x0046, 0x0307 },
  unicodeslot=0x1E1E,
 },
 [0x1E1F]={
  adobename="fdotaccent",
  category="ll",
  description="LATIN SMALL LETTER F WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0066,
  specials={ "char", 0x0066, 0x0307 },
  uccode=0x1E1E,
  unicodeslot=0x1E1F,
 },
 [0x1E20]={
  adobename="Gmacron",
  category="lu",
  description="LATIN CAPITAL LETTER G WITH MACRON",
  direction="l",
  lccode=0x1E21,
  linebreak="al",
  shcode=0x0047,
  specials={ "char", 0x0047, 0x0304 },
  unicodeslot=0x1E20,
 },
 [0x1E21]={
  adobename="gmacron",
  category="ll",
  description="LATIN SMALL LETTER G WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0067,
  specials={ "char", 0x0067, 0x0304 },
  uccode=0x1E20,
  unicodeslot=0x1E21,
 },
 [0x1E22]={
  adobename="Hdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER H WITH DOT ABOVE",
  direction="l",
  lccode=0x1E23,
  linebreak="al",
  shcode=0x0048,
  specials={ "char", 0x0048, 0x0307 },
  unicodeslot=0x1E22,
 },
 [0x1E23]={
  adobename="hdotaccent",
  category="ll",
  description="LATIN SMALL LETTER H WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  specials={ "char", 0x0068, 0x0307 },
  uccode=0x1E22,
  unicodeslot=0x1E23,
 },
 [0x1E24]={
  adobename="Hdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER H WITH DOT BELOW",
  direction="l",
  lccode=0x1E25,
  linebreak="al",
  shcode=0x0048,
  specials={ "char", 0x0048, 0x0323 },
  unicodeslot=0x1E24,
 },
 [0x1E25]={
  adobename="hdotbelow",
  category="ll",
  description="LATIN SMALL LETTER H WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  specials={ "char", 0x0068, 0x0323 },
  uccode=0x1E24,
  unicodeslot=0x1E25,
 },
 [0x1E26]={
  adobename="Hdieresis",
  category="lu",
  description="LATIN CAPITAL LETTER H WITH DIAERESIS",
  direction="l",
  lccode=0x1E27,
  linebreak="al",
  shcode=0x0048,
  specials={ "char", 0x0048, 0x0308 },
  unicodeslot=0x1E26,
 },
 [0x1E27]={
  adobename="hdieresis",
  category="ll",
  description="LATIN SMALL LETTER H WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  specials={ "char", 0x0068, 0x0308 },
  uccode=0x1E26,
  unicodeslot=0x1E27,
 },
 [0x1E28]={
  adobename="Hcedilla",
  category="lu",
  description="LATIN CAPITAL LETTER H WITH CEDILLA",
  direction="l",
  lccode=0x1E29,
  linebreak="al",
  shcode=0x0048,
  specials={ "char", 0x0048, 0x0327 },
  unicodeslot=0x1E28,
 },
 [0x1E29]={
  adobename="hcedilla",
  category="ll",
  description="LATIN SMALL LETTER H WITH CEDILLA",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  specials={ "char", 0x0068, 0x0327 },
  uccode=0x1E28,
  unicodeslot=0x1E29,
 },
 [0x1E2A]={
  adobename="Hbrevebelow",
  category="lu",
  description="LATIN CAPITAL LETTER H WITH BREVE BELOW",
  direction="l",
  lccode=0x1E2B,
  linebreak="al",
  shcode=0x0048,
  specials={ "char", 0x0048, 0x032E },
  unicodeslot=0x1E2A,
 },
 [0x1E2B]={
  adobename="hbrevebelow",
  category="ll",
  description="LATIN SMALL LETTER H WITH BREVE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  specials={ "char", 0x0068, 0x032E },
  uccode=0x1E2A,
  unicodeslot=0x1E2B,
 },
 [0x1E2C]={
  adobename="Itildebelow",
  category="lu",
  description="LATIN CAPITAL LETTER I WITH TILDE BELOW",
  direction="l",
  lccode=0x1E2D,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0330 },
  unicodeslot=0x1E2C,
 },
 [0x1E2D]={
  adobename="itildebelow",
  category="ll",
  description="LATIN SMALL LETTER I WITH TILDE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0330 },
  uccode=0x1E2C,
  unicodeslot=0x1E2D,
 },
 [0x1E2E]={
  adobename="Idieresisacute",
  category="lu",
  description="LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE",
  direction="l",
  lccode=0x1E2F,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x00CF, 0x0301 },
  unicodeslot=0x1E2E,
 },
 [0x1E2F]={
  adobename="idieresisacute",
  category="ll",
  description="LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x00EF, 0x0301 },
  uccode=0x1E2E,
  unicodeslot=0x1E2F,
 },
 [0x1E30]={
  adobename="Kacute",
  category="lu",
  description="LATIN CAPITAL LETTER K WITH ACUTE",
  direction="l",
  lccode=0x1E31,
  linebreak="al",
  shcode=0x004B,
  specials={ "char", 0x004B, 0x0301 },
  unicodeslot=0x1E30,
 },
 [0x1E31]={
  adobename="kacute",
  category="ll",
  description="LATIN SMALL LETTER K WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006B,
  specials={ "char", 0x006B, 0x0301 },
  uccode=0x1E30,
  unicodeslot=0x1E31,
 },
 [0x1E32]={
  adobename="Kdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER K WITH DOT BELOW",
  direction="l",
  lccode=0x1E33,
  linebreak="al",
  shcode=0x004B,
  specials={ "char", 0x004B, 0x0323 },
  unicodeslot=0x1E32,
 },
 [0x1E33]={
  adobename="kdotbelow",
  category="ll",
  description="LATIN SMALL LETTER K WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006B,
  specials={ "char", 0x006B, 0x0323 },
  uccode=0x1E32,
  unicodeslot=0x1E33,
 },
 [0x1E34]={
  adobename="Klinebelow",
  category="lu",
  description="LATIN CAPITAL LETTER K WITH LINE BELOW",
  direction="l",
  lccode=0x1E35,
  linebreak="al",
  shcode=0x004B,
  specials={ "char", 0x004B, 0x0331 },
  unicodeslot=0x1E34,
 },
 [0x1E35]={
  adobename="klinebelow",
  category="ll",
  description="LATIN SMALL LETTER K WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006B,
  specials={ "char", 0x006B, 0x0331 },
  uccode=0x1E34,
  unicodeslot=0x1E35,
 },
 [0x1E36]={
  adobename="Ldotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER L WITH DOT BELOW",
  direction="l",
  lccode=0x1E37,
  linebreak="al",
  shcode=0x004C,
  specials={ "char", 0x004C, 0x0323 },
  unicodeslot=0x1E36,
 },
 [0x1E37]={
  adobename="ldotbelow",
  category="ll",
  description="LATIN SMALL LETTER L WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  specials={ "char", 0x006C, 0x0323 },
  uccode=0x1E36,
  unicodeslot=0x1E37,
 },
 [0x1E38]={
  adobename="Ldotbelowmacron",
  category="lu",
  description="LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON",
  direction="l",
  lccode=0x1E39,
  linebreak="al",
  shcode=0x004C,
  specials={ "char", 0x1E36, 0x0304 },
  unicodeslot=0x1E38,
 },
 [0x1E39]={
  adobename="ldotbelowmacron",
  category="ll",
  description="LATIN SMALL LETTER L WITH DOT BELOW AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  specials={ "char", 0x1E37, 0x0304 },
  uccode=0x1E38,
  unicodeslot=0x1E39,
 },
 [0x1E3A]={
  adobename="Llinebelow",
  category="lu",
  description="LATIN CAPITAL LETTER L WITH LINE BELOW",
  direction="l",
  lccode=0x1E3B,
  linebreak="al",
  shcode=0x004C,
  specials={ "char", 0x004C, 0x0331 },
  unicodeslot=0x1E3A,
 },
 [0x1E3B]={
  adobename="llinebelow",
  category="ll",
  description="LATIN SMALL LETTER L WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  specials={ "char", 0x006C, 0x0331 },
  uccode=0x1E3A,
  unicodeslot=0x1E3B,
 },
 [0x1E3C]={
  adobename="Lcircumflexbelow",
  category="lu",
  description="LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW",
  direction="l",
  lccode=0x1E3D,
  linebreak="al",
  shcode=0x004C,
  specials={ "char", 0x004C, 0x032D },
  unicodeslot=0x1E3C,
 },
 [0x1E3D]={
  adobename="lcircumflexbelow",
  category="ll",
  description="LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  specials={ "char", 0x006C, 0x032D },
  uccode=0x1E3C,
  unicodeslot=0x1E3D,
 },
 [0x1E3E]={
  adobename="Macute",
  category="lu",
  description="LATIN CAPITAL LETTER M WITH ACUTE",
  direction="l",
  lccode=0x1E3F,
  linebreak="al",
  shcode=0x004D,
  specials={ "char", 0x004D, 0x0301 },
  unicodeslot=0x1E3E,
 },
 [0x1E3F]={
  adobename="macute",
  category="ll",
  description="LATIN SMALL LETTER M WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006D,
  specials={ "char", 0x006D, 0x0301 },
  uccode=0x1E3E,
  unicodeslot=0x1E3F,
 },
 [0x1E40]={
  adobename="Mdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER M WITH DOT ABOVE",
  direction="l",
  lccode=0x1E41,
  linebreak="al",
  shcode=0x004D,
  specials={ "char", 0x004D, 0x0307 },
  unicodeslot=0x1E40,
 },
 [0x1E41]={
  adobename="mdotaccent",
  category="ll",
  description="LATIN SMALL LETTER M WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x006D,
  specials={ "char", 0x006D, 0x0307 },
  uccode=0x1E40,
  unicodeslot=0x1E41,
 },
 [0x1E42]={
  adobename="Mdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER M WITH DOT BELOW",
  direction="l",
  lccode=0x1E43,
  linebreak="al",
  shcode=0x004D,
  specials={ "char", 0x004D, 0x0323 },
  unicodeslot=0x1E42,
 },
 [0x1E43]={
  adobename="mdotbelow",
  category="ll",
  description="LATIN SMALL LETTER M WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006D,
  specials={ "char", 0x006D, 0x0323 },
  uccode=0x1E42,
  unicodeslot=0x1E43,
 },
 [0x1E44]={
  adobename="Ndotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER N WITH DOT ABOVE",
  direction="l",
  lccode=0x1E45,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x0307 },
  unicodeslot=0x1E44,
 },
 [0x1E45]={
  adobename="ndotaccent",
  category="ll",
  description="LATIN SMALL LETTER N WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x0307 },
  uccode=0x1E44,
  unicodeslot=0x1E45,
 },
 [0x1E46]={
  adobename="Ndotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER N WITH DOT BELOW",
  direction="l",
  lccode=0x1E47,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x0323 },
  unicodeslot=0x1E46,
 },
 [0x1E47]={
  adobename="ndotbelow",
  category="ll",
  description="LATIN SMALL LETTER N WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x0323 },
  uccode=0x1E46,
  unicodeslot=0x1E47,
 },
 [0x1E48]={
  adobename="Nlinebelow",
  category="lu",
  description="LATIN CAPITAL LETTER N WITH LINE BELOW",
  direction="l",
  lccode=0x1E49,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x0331 },
  unicodeslot=0x1E48,
 },
 [0x1E49]={
  adobename="nlinebelow",
  category="ll",
  description="LATIN SMALL LETTER N WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x0331 },
  uccode=0x1E48,
  unicodeslot=0x1E49,
 },
 [0x1E4A]={
  adobename="Ncircumflexbelow",
  category="lu",
  description="LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW",
  direction="l",
  lccode=0x1E4B,
  linebreak="al",
  shcode=0x004E,
  specials={ "char", 0x004E, 0x032D },
  unicodeslot=0x1E4A,
 },
 [0x1E4B]={
  adobename="ncircumflexbelow",
  category="ll",
  description="LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006E,
  specials={ "char", 0x006E, 0x032D },
  uccode=0x1E4A,
  unicodeslot=0x1E4B,
 },
 [0x1E4C]={
  adobename="Otildeacute",
  category="lu",
  description="LATIN CAPITAL LETTER O WITH TILDE AND ACUTE",
  direction="l",
  lccode=0x1E4D,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D5, 0x0301 },
  unicodeslot=0x1E4C,
 },
 [0x1E4D]={
  adobename="otildeacute",
  category="ll",
  description="LATIN SMALL LETTER O WITH TILDE AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F5, 0x0301 },
  uccode=0x1E4C,
  unicodeslot=0x1E4D,
 },
 [0x1E4E]={
  adobename="Otildedieresis",
  category="lu",
  description="LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS",
  direction="l",
  lccode=0x1E4F,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D5, 0x0308 },
  unicodeslot=0x1E4E,
 },
 [0x1E4F]={
  adobename="otildedieresis",
  category="ll",
  description="LATIN SMALL LETTER O WITH TILDE AND DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F5, 0x0308 },
  uccode=0x1E4E,
  unicodeslot=0x1E4F,
 },
 [0x1E50]={
  adobename="Omacrongrave",
  category="lu",
  description="LATIN CAPITAL LETTER O WITH MACRON AND GRAVE",
  direction="l",
  lccode=0x1E51,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x014C, 0x0300 },
  unicodeslot=0x1E50,
 },
 [0x1E51]={
  adobename="omacrongrave",
  category="ll",
  description="LATIN SMALL LETTER O WITH MACRON AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x014D, 0x0300 },
  uccode=0x1E50,
  unicodeslot=0x1E51,
 },
 [0x1E52]={
  adobename="Omacronacute",
  category="lu",
  description="LATIN CAPITAL LETTER O WITH MACRON AND ACUTE",
  direction="l",
  lccode=0x1E53,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x014C, 0x0301 },
  unicodeslot=0x1E52,
 },
 [0x1E53]={
  adobename="omacronacute",
  category="ll",
  description="LATIN SMALL LETTER O WITH MACRON AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x014D, 0x0301 },
  uccode=0x1E52,
  unicodeslot=0x1E53,
 },
 [0x1E54]={
  adobename="Pacute",
  category="lu",
  description="LATIN CAPITAL LETTER P WITH ACUTE",
  direction="l",
  lccode=0x1E55,
  linebreak="al",
  shcode=0x0050,
  specials={ "char", 0x0050, 0x0301 },
  unicodeslot=0x1E54,
 },
 [0x1E55]={
  adobename="pacute",
  category="ll",
  description="LATIN SMALL LETTER P WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0070,
  specials={ "char", 0x0070, 0x0301 },
  uccode=0x1E54,
  unicodeslot=0x1E55,
 },
 [0x1E56]={
  adobename="Pdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER P WITH DOT ABOVE",
  direction="l",
  lccode=0x1E57,
  linebreak="al",
  shcode=0x0050,
  specials={ "char", 0x0050, 0x0307 },
  unicodeslot=0x1E56,
 },
 [0x1E57]={
  adobename="pdotaccent",
  category="ll",
  description="LATIN SMALL LETTER P WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0070,
  specials={ "char", 0x0070, 0x0307 },
  uccode=0x1E56,
  unicodeslot=0x1E57,
 },
 [0x1E58]={
  adobename="Rdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER R WITH DOT ABOVE",
  direction="l",
  lccode=0x1E59,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x0052, 0x0307 },
  unicodeslot=0x1E58,
 },
 [0x1E59]={
  adobename="rdotaccent",
  category="ll",
  description="LATIN SMALL LETTER R WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x0072, 0x0307 },
  uccode=0x1E58,
  unicodeslot=0x1E59,
 },
 [0x1E5A]={
  adobename="Rdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER R WITH DOT BELOW",
  direction="l",
  lccode=0x1E5B,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x0052, 0x0323 },
  unicodeslot=0x1E5A,
 },
 [0x1E5B]={
  adobename="rdotbelow",
  category="ll",
  description="LATIN SMALL LETTER R WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x0072, 0x0323 },
  uccode=0x1E5A,
  unicodeslot=0x1E5B,
 },
 [0x1E5C]={
  adobename="Rdotbelowmacron",
  category="lu",
  description="LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON",
  direction="l",
  lccode=0x1E5D,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x1E5A, 0x0304 },
  unicodeslot=0x1E5C,
 },
 [0x1E5D]={
  adobename="rdotbelowmacron",
  category="ll",
  description="LATIN SMALL LETTER R WITH DOT BELOW AND MACRON",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x1E5B, 0x0304 },
  uccode=0x1E5C,
  unicodeslot=0x1E5D,
 },
 [0x1E5E]={
  adobename="Rlinebelow",
  category="lu",
  description="LATIN CAPITAL LETTER R WITH LINE BELOW",
  direction="l",
  lccode=0x1E5F,
  linebreak="al",
  shcode=0x0052,
  specials={ "char", 0x0052, 0x0331 },
  unicodeslot=0x1E5E,
 },
 [0x1E5F]={
  adobename="rlinebelow",
  category="ll",
  description="LATIN SMALL LETTER R WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0072,
  specials={ "char", 0x0072, 0x0331 },
  uccode=0x1E5E,
  unicodeslot=0x1E5F,
 },
 [0x1E60]={
  adobename="Sdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER S WITH DOT ABOVE",
  direction="l",
  lccode=0x1E61,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x0053, 0x0307 },
  unicodeslot=0x1E60,
 },
 [0x1E61]={
  adobename="sdotaccent",
  category="ll",
  description="LATIN SMALL LETTER S WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x0073, 0x0307 },
  uccode=0x1E60,
  unicodeslot=0x1E61,
 },
 [0x1E62]={
  adobename="Sdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER S WITH DOT BELOW",
  direction="l",
  lccode=0x1E63,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x0053, 0x0323 },
  unicodeslot=0x1E62,
 },
 [0x1E63]={
  adobename="sdotbelow",
  category="ll",
  description="LATIN SMALL LETTER S WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x0073, 0x0323 },
  uccode=0x1E62,
  unicodeslot=0x1E63,
 },
 [0x1E64]={
  adobename="Sacutedotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE",
  direction="l",
  lccode=0x1E65,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x015A, 0x0307 },
  unicodeslot=0x1E64,
 },
 [0x1E65]={
  adobename="sacutedotaccent",
  category="ll",
  description="LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x015B, 0x0307 },
  uccode=0x1E64,
  unicodeslot=0x1E65,
 },
 [0x1E66]={
  adobename="Scarondotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE",
  direction="l",
  lccode=0x1E67,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x0160, 0x0307 },
  unicodeslot=0x1E66,
 },
 [0x1E67]={
  adobename="scarondotaccent",
  category="ll",
  description="LATIN SMALL LETTER S WITH CARON AND DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x0161, 0x0307 },
  uccode=0x1E66,
  unicodeslot=0x1E67,
 },
 [0x1E68]={
  adobename="Sdotbelowdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE",
  direction="l",
  lccode=0x1E69,
  linebreak="al",
  shcode=0x0053,
  specials={ "char", 0x1E62, 0x0307 },
  unicodeslot=0x1E68,
 },
 [0x1E69]={
  adobename="sdotbelowdotaccent",
  category="ll",
  description="LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0073,
  specials={ "char", 0x1E63, 0x0307 },
  uccode=0x1E68,
  unicodeslot=0x1E69,
 },
 [0x1E6A]={
  adobename="Tdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER T WITH DOT ABOVE",
  direction="l",
  lccode=0x1E6B,
  linebreak="al",
  shcode=0x0054,
  specials={ "char", 0x0054, 0x0307 },
  unicodeslot=0x1E6A,
 },
 [0x1E6B]={
  adobename="tdotaccent",
  category="ll",
  description="LATIN SMALL LETTER T WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  specials={ "char", 0x0074, 0x0307 },
  uccode=0x1E6A,
  unicodeslot=0x1E6B,
 },
 [0x1E6C]={
  adobename="Tdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER T WITH DOT BELOW",
  direction="l",
  lccode=0x1E6D,
  linebreak="al",
  shcode=0x0054,
  specials={ "char", 0x0054, 0x0323 },
  unicodeslot=0x1E6C,
 },
 [0x1E6D]={
  adobename="tdotbelow",
  category="ll",
  description="LATIN SMALL LETTER T WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  specials={ "char", 0x0074, 0x0323 },
  uccode=0x1E6C,
  unicodeslot=0x1E6D,
 },
 [0x1E6E]={
  adobename="Tlinebelow",
  category="lu",
  description="LATIN CAPITAL LETTER T WITH LINE BELOW",
  direction="l",
  lccode=0x1E6F,
  linebreak="al",
  shcode=0x0054,
  specials={ "char", 0x0054, 0x0331 },
  unicodeslot=0x1E6E,
 },
 [0x1E6F]={
  adobename="tlinebelow",
  category="ll",
  description="LATIN SMALL LETTER T WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  specials={ "char", 0x0074, 0x0331 },
  uccode=0x1E6E,
  unicodeslot=0x1E6F,
 },
 [0x1E70]={
  adobename="Tcircumflexbelow",
  category="lu",
  description="LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW",
  direction="l",
  lccode=0x1E71,
  linebreak="al",
  shcode=0x0054,
  specials={ "char", 0x0054, 0x032D },
  unicodeslot=0x1E70,
 },
 [0x1E71]={
  adobename="tcircumflexbelow",
  category="ll",
  description="LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  specials={ "char", 0x0074, 0x032D },
  uccode=0x1E70,
  unicodeslot=0x1E71,
 },
 [0x1E72]={
  adobename="Udieresisbelow",
  category="lu",
  description="LATIN CAPITAL LETTER U WITH DIAERESIS BELOW",
  direction="l",
  lccode=0x1E73,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0324 },
  unicodeslot=0x1E72,
 },
 [0x1E73]={
  adobename="udieresisbelow",
  category="ll",
  description="LATIN SMALL LETTER U WITH DIAERESIS BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0324 },
  uccode=0x1E72,
  unicodeslot=0x1E73,
 },
 [0x1E74]={
  adobename="Utildebelow",
  category="lu",
  description="LATIN CAPITAL LETTER U WITH TILDE BELOW",
  direction="l",
  lccode=0x1E75,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0330 },
  unicodeslot=0x1E74,
 },
 [0x1E75]={
  adobename="utildebelow",
  category="ll",
  description="LATIN SMALL LETTER U WITH TILDE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0330 },
  uccode=0x1E74,
  unicodeslot=0x1E75,
 },
 [0x1E76]={
  adobename="Ucircumflexbelow",
  category="lu",
  description="LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW",
  direction="l",
  lccode=0x1E77,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x032D },
  unicodeslot=0x1E76,
 },
 [0x1E77]={
  adobename="ucircumflexbelow",
  category="ll",
  description="LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x032D },
  uccode=0x1E76,
  unicodeslot=0x1E77,
 },
 [0x1E78]={
  adobename="Utildeacute",
  category="lu",
  description="LATIN CAPITAL LETTER U WITH TILDE AND ACUTE",
  direction="l",
  lccode=0x1E79,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0168, 0x0301 },
  unicodeslot=0x1E78,
 },
 [0x1E79]={
  adobename="utildeacute",
  category="ll",
  description="LATIN SMALL LETTER U WITH TILDE AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0169, 0x0301 },
  uccode=0x1E78,
  unicodeslot=0x1E79,
 },
 [0x1E7A]={
  adobename="Umacrondieresis",
  category="lu",
  description="LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS",
  direction="l",
  lccode=0x1E7B,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x016A, 0x0308 },
  unicodeslot=0x1E7A,
 },
 [0x1E7B]={
  adobename="umacrondieresis",
  category="ll",
  description="LATIN SMALL LETTER U WITH MACRON AND DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x016B, 0x0308 },
  uccode=0x1E7A,
  unicodeslot=0x1E7B,
 },
 [0x1E7C]={
  adobename="Vtilde",
  category="lu",
  description="LATIN CAPITAL LETTER V WITH TILDE",
  direction="l",
  lccode=0x1E7D,
  linebreak="al",
  shcode=0x0056,
  specials={ "char", 0x0056, 0x0303 },
  unicodeslot=0x1E7C,
 },
 [0x1E7D]={
  adobename="vtilde",
  category="ll",
  description="LATIN SMALL LETTER V WITH TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0076,
  specials={ "char", 0x0076, 0x0303 },
  uccode=0x1E7C,
  unicodeslot=0x1E7D,
 },
 [0x1E7E]={
  adobename="Vdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER V WITH DOT BELOW",
  direction="l",
  lccode=0x1E7F,
  linebreak="al",
  shcode=0x0056,
  specials={ "char", 0x0056, 0x0323 },
  unicodeslot=0x1E7E,
 },
 [0x1E7F]={
  adobename="vdotbelow",
  category="ll",
  description="LATIN SMALL LETTER V WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0076,
  specials={ "char", 0x0076, 0x0323 },
  uccode=0x1E7E,
  unicodeslot=0x1E7F,
 },
 [0x1E80]={
  adobename="Wgrave",
  category="lu",
  description="LATIN CAPITAL LETTER W WITH GRAVE",
  direction="l",
  lccode=0x1E81,
  linebreak="al",
  shcode=0x0057,
  specials={ "char", 0x0057, 0x0300 },
  unicodeslot=0x1E80,
 },
 [0x1E81]={
  adobename="wgrave",
  category="ll",
  description="LATIN SMALL LETTER W WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0077,
  specials={ "char", 0x0077, 0x0300 },
  uccode=0x1E80,
  unicodeslot=0x1E81,
 },
 [0x1E82]={
  adobename="Wacute",
  category="lu",
  description="LATIN CAPITAL LETTER W WITH ACUTE",
  direction="l",
  lccode=0x1E83,
  linebreak="al",
  shcode=0x0057,
  specials={ "char", 0x0057, 0x0301 },
  unicodeslot=0x1E82,
 },
 [0x1E83]={
  adobename="wacute",
  category="ll",
  description="LATIN SMALL LETTER W WITH ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0077,
  specials={ "char", 0x0077, 0x0301 },
  uccode=0x1E82,
  unicodeslot=0x1E83,
 },
 [0x1E84]={
  adobename="Wdieresis",
  category="lu",
  description="LATIN CAPITAL LETTER W WITH DIAERESIS",
  direction="l",
  lccode=0x1E85,
  linebreak="al",
  shcode=0x0057,
  specials={ "char", 0x0057, 0x0308 },
  unicodeslot=0x1E84,
 },
 [0x1E85]={
  adobename="wdieresis",
  category="ll",
  description="LATIN SMALL LETTER W WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0077,
  specials={ "char", 0x0077, 0x0308 },
  uccode=0x1E84,
  unicodeslot=0x1E85,
 },
 [0x1E86]={
  adobename="Wdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER W WITH DOT ABOVE",
  direction="l",
  lccode=0x1E87,
  linebreak="al",
  shcode=0x0057,
  specials={ "char", 0x0057, 0x0307 },
  unicodeslot=0x1E86,
 },
 [0x1E87]={
  adobename="wdotaccent",
  category="ll",
  description="LATIN SMALL LETTER W WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0077,
  specials={ "char", 0x0077, 0x0307 },
  uccode=0x1E86,
  unicodeslot=0x1E87,
 },
 [0x1E88]={
  adobename="Wdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER W WITH DOT BELOW",
  direction="l",
  lccode=0x1E89,
  linebreak="al",
  shcode=0x0057,
  specials={ "char", 0x0057, 0x0323 },
  unicodeslot=0x1E88,
 },
 [0x1E89]={
  adobename="wdotbelow",
  category="ll",
  description="LATIN SMALL LETTER W WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0077,
  specials={ "char", 0x0077, 0x0323 },
  uccode=0x1E88,
  unicodeslot=0x1E89,
 },
 [0x1E8A]={
  adobename="Xdotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER X WITH DOT ABOVE",
  direction="l",
  lccode=0x1E8B,
  linebreak="al",
  shcode=0x0058,
  specials={ "char", 0x0058, 0x0307 },
  unicodeslot=0x1E8A,
 },
 [0x1E8B]={
  adobename="xdotaccent",
  category="ll",
  description="LATIN SMALL LETTER X WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0078,
  specials={ "char", 0x0078, 0x0307 },
  uccode=0x1E8A,
  unicodeslot=0x1E8B,
 },
 [0x1E8C]={
  adobename="Xdieresis",
  category="lu",
  description="LATIN CAPITAL LETTER X WITH DIAERESIS",
  direction="l",
  lccode=0x1E8D,
  linebreak="al",
  shcode=0x0058,
  specials={ "char", 0x0058, 0x0308 },
  unicodeslot=0x1E8C,
 },
 [0x1E8D]={
  adobename="xdieresis",
  category="ll",
  description="LATIN SMALL LETTER X WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0078,
  specials={ "char", 0x0078, 0x0308 },
  uccode=0x1E8C,
  unicodeslot=0x1E8D,
 },
 [0x1E8E]={
  adobename="Ydotaccent",
  category="lu",
  description="LATIN CAPITAL LETTER Y WITH DOT ABOVE",
  direction="l",
  lccode=0x1E8F,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0307 },
  unicodeslot=0x1E8E,
 },
 [0x1E8F]={
  adobename="ydotaccent",
  category="ll",
  description="LATIN SMALL LETTER Y WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0307 },
  uccode=0x1E8E,
  unicodeslot=0x1E8F,
 },
 [0x1E90]={
  adobename="Zcircumflex",
  category="lu",
  description="LATIN CAPITAL LETTER Z WITH CIRCUMFLEX",
  direction="l",
  lccode=0x1E91,
  linebreak="al",
  shcode=0x005A,
  specials={ "char", 0x005A, 0x0302 },
  unicodeslot=0x1E90,
 },
 [0x1E91]={
  adobename="zcircumflex",
  category="ll",
  description="LATIN SMALL LETTER Z WITH CIRCUMFLEX",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  specials={ "char", 0x007A, 0x0302 },
  uccode=0x1E90,
  unicodeslot=0x1E91,
 },
 [0x1E92]={
  adobename="Zdotbelow",
  category="lu",
  description="LATIN CAPITAL LETTER Z WITH DOT BELOW",
  direction="l",
  lccode=0x1E93,
  linebreak="al",
  shcode=0x005A,
  specials={ "char", 0x005A, 0x0323 },
  unicodeslot=0x1E92,
 },
 [0x1E93]={
  adobename="zdotbelow",
  category="ll",
  description="LATIN SMALL LETTER Z WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  specials={ "char", 0x007A, 0x0323 },
  uccode=0x1E92,
  unicodeslot=0x1E93,
 },
 [0x1E94]={
  adobename="Zlinebelow",
  category="lu",
  description="LATIN CAPITAL LETTER Z WITH LINE BELOW",
  direction="l",
  lccode=0x1E95,
  linebreak="al",
  shcode=0x005A,
  specials={ "char", 0x005A, 0x0331 },
  unicodeslot=0x1E94,
 },
 [0x1E95]={
  adobename="zlinebelow",
  category="ll",
  description="LATIN SMALL LETTER Z WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  specials={ "char", 0x007A, 0x0331 },
  uccode=0x1E94,
  unicodeslot=0x1E95,
 },
 [0x1E96]={
  adobename="hlinebelow",
  category="ll",
  description="LATIN SMALL LETTER H WITH LINE BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  specials={ "char", 0x0068, 0x0331 },
  unicodeslot=0x1E96,
 },
 [0x1E97]={
  adobename="tdieresis",
  category="ll",
  description="LATIN SMALL LETTER T WITH DIAERESIS",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  specials={ "char", 0x0074, 0x0308 },
  unicodeslot=0x1E97,
 },
 [0x1E98]={
  adobename="wring",
  category="ll",
  description="LATIN SMALL LETTER W WITH RING ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0077,
  specials={ "char", 0x0077, 0x030A },
  unicodeslot=0x1E98,
 },
 [0x1E99]={
  adobename="yring",
  category="ll",
  description="LATIN SMALL LETTER Y WITH RING ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x030A },
  unicodeslot=0x1E99,
 },
 [0x1E9A]={
  adobename="arighthalfring",
  category="ll",
  description="LATIN SMALL LETTER A WITH RIGHT HALF RING",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "compat", 0x0061, 0x02BE },
  unicodeslot=0x1E9A,
 },
 [0x1E9B]={
  adobename="slongdotaccent",
  category="ll",
  description="LATIN SMALL LETTER LONG S WITH DOT ABOVE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x017F, 0x0307 },
  uccode=0x1E60,
  unicodeslot=0x1E9B,
 },
 [0x1E9C]={
  category="ll",
  description="LATIN SMALL LETTER LONG S WITH DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1E9C,
 },
 [0x1E9D]={
  category="ll",
  description="LATIN SMALL LETTER LONG S WITH HIGH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1E9D,
 },
 [0x1E9E]={
  category="lu",
  description="LATIN CAPITAL LETTER SHARP S",
  direction="l",
  linebreak="al",
  unicodeslot=0x1E9E,
 },
 [0x1E9F]={
  category="ll",
  description="LATIN SMALL LETTER DELTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1E9F,
 },
 [0x1EA0]={
  adobename="Adotbelow",
  category="lu",
  contextname="Adotbelow",
  description="LATIN CAPITAL LETTER A WITH DOT BELOW",
  direction="l",
  lccode=0x1EA1,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0323 },
  unicodeslot=0x1EA0,
 },
 [0x1EA1]={
  adobename="adotbelow",
  category="ll",
  contextname="adotbelow",
  description="LATIN SMALL LETTER A WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0323 },
  uccode=0x1EA0,
  unicodeslot=0x1EA1,
 },
 [0x1EA2]={
  adobename="Ahookabove",
  category="lu",
  contextname="Ahook",
  description="LATIN CAPITAL LETTER A WITH HOOK ABOVE",
  direction="l",
  lccode=0x1EA3,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0041, 0x0309 },
  unicodeslot=0x1EA2,
 },
 [0x1EA3]={
  adobename="ahookabove",
  category="ll",
  contextname="ahook",
  description="LATIN SMALL LETTER A WITH HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0061, 0x0309 },
  uccode=0x1EA2,
  unicodeslot=0x1EA3,
 },
 [0x1EA4]={
  adobename="Acircumflexacute",
  category="lu",
  contextname="Acircumflexacute",
  description="LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE",
  direction="l",
  lccode=0x1EA5,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x00C2, 0x0301 },
  unicodeslot=0x1EA4,
 },
 [0x1EA5]={
  adobename="acircumflexacute",
  category="ll",
  contextname="acircumflexacute",
  description="LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x00E2, 0x0301 },
  uccode=0x1EA4,
  unicodeslot=0x1EA5,
 },
 [0x1EA6]={
  adobename="Acircumflexgrave",
  category="lu",
  contextname="Acircumflexgrave",
  description="LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE",
  direction="l",
  lccode=0x1EA7,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x00C2, 0x0300 },
  unicodeslot=0x1EA6,
 },
 [0x1EA7]={
  adobename="acircumflexgrave",
  category="ll",
  contextname="acircumflexgrave",
  description="LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x00E2, 0x0300 },
  uccode=0x1EA6,
  unicodeslot=0x1EA7,
 },
 [0x1EA8]={
  adobename="Acircumflexhookabove",
  category="lu",
  contextname="Acircumflexhook",
  description="LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE",
  direction="l",
  lccode=0x1EA9,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x00C2, 0x0309 },
  unicodeslot=0x1EA8,
 },
 [0x1EA9]={
  adobename="acircumflexhookabove",
  category="ll",
  contextname="acircumflexhook",
  description="LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x00E2, 0x0309 },
  uccode=0x1EA8,
  unicodeslot=0x1EA9,
 },
 [0x1EAA]={
  adobename="Acircumflextilde",
  category="lu",
  contextname="Acircumflextilde",
  description="LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE",
  direction="l",
  lccode=0x1EAB,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x00C2, 0x0303 },
  unicodeslot=0x1EAA,
 },
 [0x1EAB]={
  adobename="acircumflextilde",
  category="ll",
  contextname="acircumflextilde",
  description="LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x00E2, 0x0303 },
  uccode=0x1EAA,
  unicodeslot=0x1EAB,
 },
 [0x1EAC]={
  adobename="Acircumflexdotbelow",
  category="lu",
  contextname="Acircumflexdotbelow",
  description="LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW",
  direction="l",
  lccode=0x1EAD,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x1EA0, 0x0302 },
  unicodeslot=0x1EAC,
 },
 [0x1EAD]={
  adobename="acircumflexdotbelow",
  category="ll",
  contextname="acircumflexdotbelow",
  description="LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x1EA1, 0x0302 },
  uccode=0x1EAC,
  unicodeslot=0x1EAD,
 },
 [0x1EAE]={
  adobename="Abreveacute",
  category="lu",
  contextname="Abreveacute",
  description="LATIN CAPITAL LETTER A WITH BREVE AND ACUTE",
  direction="l",
  lccode=0x1EAF,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0102, 0x0301 },
  unicodeslot=0x1EAE,
 },
 [0x1EAF]={
  adobename="abreveacute",
  category="ll",
  contextname="abreveacute",
  description="LATIN SMALL LETTER A WITH BREVE AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0103, 0x0301 },
  uccode=0x1EAE,
  unicodeslot=0x1EAF,
 },
 [0x1EB0]={
  adobename="Abrevegrave",
  category="lu",
  contextname="Abrevegrave",
  description="LATIN CAPITAL LETTER A WITH BREVE AND GRAVE",
  direction="l",
  lccode=0x1EB1,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0102, 0x0300 },
  unicodeslot=0x1EB0,
 },
 [0x1EB1]={
  adobename="abrevegrave",
  category="ll",
  contextname="abrevegrave",
  description="LATIN SMALL LETTER A WITH BREVE AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0103, 0x0300 },
  uccode=0x1EB0,
  unicodeslot=0x1EB1,
 },
 [0x1EB2]={
  adobename="Abrevehookabove",
  category="lu",
  contextname="Abrevehook",
  description="LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE",
  direction="l",
  lccode=0x1EB3,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0102, 0x0309 },
  unicodeslot=0x1EB2,
 },
 [0x1EB3]={
  adobename="abrevehookabove",
  category="ll",
  contextname="abrevehook",
  description="LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0103, 0x0309 },
  uccode=0x1EB2,
  unicodeslot=0x1EB3,
 },
 [0x1EB4]={
  adobename="Abrevetilde",
  category="lu",
  contextname="Abrevetilde",
  description="LATIN CAPITAL LETTER A WITH BREVE AND TILDE",
  direction="l",
  lccode=0x1EB5,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x0102, 0x0303 },
  unicodeslot=0x1EB4,
 },
 [0x1EB5]={
  adobename="abrevetilde",
  category="ll",
  contextname="abrevetilde",
  description="LATIN SMALL LETTER A WITH BREVE AND TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x0103, 0x0303 },
  uccode=0x1EB4,
  unicodeslot=0x1EB5,
 },
 [0x1EB6]={
  adobename="Abrevedotbelow",
  category="lu",
  contextname="Abrevedotbelow",
  description="LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW",
  direction="l",
  lccode=0x1EB7,
  linebreak="al",
  shcode=0x0041,
  specials={ "char", 0x1EA0, 0x0306 },
  unicodeslot=0x1EB6,
 },
 [0x1EB7]={
  adobename="abrevedotbelow",
  category="ll",
  contextname="abrevedotbelow",
  description="LATIN SMALL LETTER A WITH BREVE AND DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  specials={ "char", 0x1EA1, 0x0306 },
  uccode=0x1EB6,
  unicodeslot=0x1EB7,
 },
 [0x1EB8]={
  adobename="Edotbelow",
  category="lu",
  contextname="Edotbelow",
  description="LATIN CAPITAL LETTER E WITH DOT BELOW",
  direction="l",
  lccode=0x1EB9,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0323 },
  unicodeslot=0x1EB8,
 },
 [0x1EB9]={
  adobename="edotbelow",
  category="ll",
  contextname="edotbelow",
  description="LATIN SMALL LETTER E WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0323 },
  uccode=0x1EB8,
  unicodeslot=0x1EB9,
 },
 [0x1EBA]={
  adobename="Ehookabove",
  category="lu",
  contextname="Ehook",
  description="LATIN CAPITAL LETTER E WITH HOOK ABOVE",
  direction="l",
  lccode=0x1EBB,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0309 },
  unicodeslot=0x1EBA,
 },
 [0x1EBB]={
  adobename="ehookabove",
  category="ll",
  contextname="ehook",
  description="LATIN SMALL LETTER E WITH HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0309 },
  uccode=0x1EBA,
  unicodeslot=0x1EBB,
 },
 [0x1EBC]={
  adobename="Etilde",
  category="lu",
  contextname="Etilde",
  description="LATIN CAPITAL LETTER E WITH TILDE",
  direction="l",
  lccode=0x1EBD,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x0045, 0x0303 },
  unicodeslot=0x1EBC,
 },
 [0x1EBD]={
  adobename="etilde",
  category="ll",
  contextname="etilde",
  description="LATIN SMALL LETTER E WITH TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x0065, 0x0303 },
  uccode=0x1EBC,
  unicodeslot=0x1EBD,
 },
 [0x1EBE]={
  adobename="Ecircumflexacute",
  category="lu",
  contextname="Ecircumflexacute",
  description="LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE",
  direction="l",
  lccode=0x1EBF,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x00CA, 0x0301 },
  unicodeslot=0x1EBE,
 },
 [0x1EBF]={
  adobename="ecircumflexacute",
  category="ll",
  contextname="ecircumflexacute",
  description="LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x00EA, 0x0301 },
  uccode=0x1EBE,
  unicodeslot=0x1EBF,
 },
 [0x1EC0]={
  adobename="Ecircumflexgrave",
  category="lu",
  contextname="Ecircumflexgrave",
  description="LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE",
  direction="l",
  lccode=0x1EC1,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x00CA, 0x0300 },
  unicodeslot=0x1EC0,
 },
 [0x1EC1]={
  adobename="ecircumflexgrave",
  category="ll",
  contextname="ecircumflexgrave",
  description="LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x00EA, 0x0300 },
  uccode=0x1EC0,
  unicodeslot=0x1EC1,
 },
 [0x1EC2]={
  adobename="Ecircumflexhookabove",
  category="lu",
  contextname="Ecircumflexhook",
  description="LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE",
  direction="l",
  lccode=0x1EC3,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x00CA, 0x0309 },
  unicodeslot=0x1EC2,
 },
 [0x1EC3]={
  adobename="ecircumflexhookabove",
  category="ll",
  contextname="ecircumflexhook",
  description="LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x00EA, 0x0309 },
  uccode=0x1EC2,
  unicodeslot=0x1EC3,
 },
 [0x1EC4]={
  adobename="Ecircumflextilde",
  category="lu",
  contextname="Ecircumflextilde",
  description="LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE",
  direction="l",
  lccode=0x1EC5,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x00CA, 0x0303 },
  unicodeslot=0x1EC4,
 },
 [0x1EC5]={
  adobename="ecircumflextilde",
  category="ll",
  contextname="ecircumflextilde",
  description="LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x00EA, 0x0303 },
  uccode=0x1EC4,
  unicodeslot=0x1EC5,
 },
 [0x1EC6]={
  adobename="Ecircumflexdotbelow",
  category="lu",
  contextname="Ecircumflexdotbelow",
  description="LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW",
  direction="l",
  lccode=0x1EC7,
  linebreak="al",
  shcode=0x0045,
  specials={ "char", 0x1EB8, 0x0302 },
  unicodeslot=0x1EC6,
 },
 [0x1EC7]={
  adobename="ecircumflexdotbelow",
  category="ll",
  contextname="ecircumflexdotbelow",
  description="LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0065,
  specials={ "char", 0x1EB9, 0x0302 },
  uccode=0x1EC6,
  unicodeslot=0x1EC7,
 },
 [0x1EC8]={
  adobename="Ihookabove",
  category="lu",
  contextname="Ihook",
  description="LATIN CAPITAL LETTER I WITH HOOK ABOVE",
  direction="l",
  lccode=0x1EC9,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0309 },
  unicodeslot=0x1EC8,
 },
 [0x1EC9]={
  adobename="ihookabove",
  category="ll",
  contextname="ihook",
  description="LATIN SMALL LETTER I WITH HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0309 },
  uccode=0x1EC8,
  unicodeslot=0x1EC9,
 },
 [0x1ECA]={
  adobename="Idotbelow",
  category="lu",
  contextname="Idotbelow",
  description="LATIN CAPITAL LETTER I WITH DOT BELOW",
  direction="l",
  lccode=0x1ECB,
  linebreak="al",
  shcode=0x0049,
  specials={ "char", 0x0049, 0x0323 },
  unicodeslot=0x1ECA,
 },
 [0x1ECB]={
  adobename="idotbelow",
  category="ll",
  contextname="idotbelow",
  description="LATIN SMALL LETTER I WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0069,
  specials={ "char", 0x0069, 0x0323 },
  uccode=0x1ECA,
  unicodeslot=0x1ECB,
 },
 [0x1ECC]={
  adobename="Odotbelow",
  category="lu",
  contextname="Odotbelow",
  description="LATIN CAPITAL LETTER O WITH DOT BELOW",
  direction="l",
  lccode=0x1ECD,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0323 },
  unicodeslot=0x1ECC,
 },
 [0x1ECD]={
  adobename="odotbelow",
  category="ll",
  contextname="odotbelow",
  description="LATIN SMALL LETTER O WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0323 },
  uccode=0x1ECC,
  unicodeslot=0x1ECD,
 },
 [0x1ECE]={
  adobename="Ohookabove",
  category="lu",
  contextname="Ohook",
  description="LATIN CAPITAL LETTER O WITH HOOK ABOVE",
  direction="l",
  lccode=0x1ECF,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x004F, 0x0309 },
  unicodeslot=0x1ECE,
 },
 [0x1ECF]={
  adobename="ohookabove",
  category="ll",
  contextname="ohook",
  description="LATIN SMALL LETTER O WITH HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x006F, 0x0309 },
  uccode=0x1ECE,
  unicodeslot=0x1ECF,
 },
 [0x1ED0]={
  adobename="Ocircumflexacute",
  category="lu",
  contextname="Ocircumflexacute",
  description="LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE",
  direction="l",
  lccode=0x1ED1,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D4, 0x0301 },
  unicodeslot=0x1ED0,
 },
 [0x1ED1]={
  adobename="ocircumflexacute",
  category="ll",
  contextname="ocircumflexacute",
  description="LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F4, 0x0301 },
  uccode=0x1ED0,
  unicodeslot=0x1ED1,
 },
 [0x1ED2]={
  adobename="Ocircumflexgrave",
  category="lu",
  contextname="Ocircumflexgrave",
  description="LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE",
  direction="l",
  lccode=0x1ED3,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D4, 0x0300 },
  unicodeslot=0x1ED2,
 },
 [0x1ED3]={
  adobename="ocircumflexgrave",
  category="ll",
  contextname="ocircumflexgrave",
  description="LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F4, 0x0300 },
  uccode=0x1ED2,
  unicodeslot=0x1ED3,
 },
 [0x1ED4]={
  adobename="Ocircumflexhookabove",
  category="lu",
  contextname="Ocircumflexhook",
  description="LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE",
  direction="l",
  lccode=0x1ED5,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D4, 0x0309 },
  unicodeslot=0x1ED4,
 },
 [0x1ED5]={
  adobename="ocircumflexhookabove",
  category="ll",
  contextname="ocircumflexhook",
  description="LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F4, 0x0309 },
  uccode=0x1ED4,
  unicodeslot=0x1ED5,
 },
 [0x1ED6]={
  adobename="Ocircumflextilde",
  category="lu",
  contextname="Ocircumflextilde",
  description="LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE",
  direction="l",
  lccode=0x1ED7,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x00D4, 0x0303 },
  unicodeslot=0x1ED6,
 },
 [0x1ED7]={
  adobename="ocircumflextilde",
  category="ll",
  contextname="ocircumflextilde",
  description="LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x00F4, 0x0303 },
  uccode=0x1ED6,
  unicodeslot=0x1ED7,
 },
 [0x1ED8]={
  adobename="Ocircumflexdotbelow",
  category="lu",
  contextname="Ocircumflexdotbelow",
  description="LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW",
  direction="l",
  lccode=0x1ED9,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x1ECC, 0x0302 },
  unicodeslot=0x1ED8,
 },
 [0x1ED9]={
  adobename="ocircumflexdotbelow",
  category="ll",
  contextname="ocircumflexdotbelow",
  description="LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x1ECD, 0x0302 },
  uccode=0x1ED8,
  unicodeslot=0x1ED9,
 },
 [0x1EDA]={
  adobename="Ohornacute",
  category="lu",
  contextname="Ohornacute",
  description="LATIN CAPITAL LETTER O WITH HORN AND ACUTE",
  direction="l",
  lccode=0x1EDB,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x01A0, 0x0301 },
  unicodeslot=0x1EDA,
 },
 [0x1EDB]={
  adobename="ohornacute",
  category="ll",
  contextname="ohornacute",
  description="LATIN SMALL LETTER O WITH HORN AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x01A1, 0x0301 },
  uccode=0x1EDA,
  unicodeslot=0x1EDB,
 },
 [0x1EDC]={
  adobename="Ohorngrave",
  category="lu",
  contextname="Ohorngrave",
  description="LATIN CAPITAL LETTER O WITH HORN AND GRAVE",
  direction="l",
  lccode=0x1EDD,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x01A0, 0x0300 },
  unicodeslot=0x1EDC,
 },
 [0x1EDD]={
  adobename="ohorngrave",
  category="ll",
  contextname="ohorngrave",
  description="LATIN SMALL LETTER O WITH HORN AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x01A1, 0x0300 },
  uccode=0x1EDC,
  unicodeslot=0x1EDD,
 },
 [0x1EDE]={
  adobename="Ohornhookabove",
  category="lu",
  contextname="Ohornhook",
  description="LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE",
  direction="l",
  lccode=0x1EDF,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x01A0, 0x0309 },
  unicodeslot=0x1EDE,
 },
 [0x1EDF]={
  adobename="ohornhookabove",
  category="ll",
  contextname="ohornhook",
  description="LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x01A1, 0x0309 },
  uccode=0x1EDE,
  unicodeslot=0x1EDF,
 },
 [0x1EE0]={
  adobename="Ohorntilde",
  category="lu",
  contextname="Ohorntilde",
  description="LATIN CAPITAL LETTER O WITH HORN AND TILDE",
  direction="l",
  lccode=0x1EE1,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x01A0, 0x0303 },
  unicodeslot=0x1EE0,
 },
 [0x1EE1]={
  adobename="ohorntilde",
  category="ll",
  contextname="ohorntilde",
  description="LATIN SMALL LETTER O WITH HORN AND TILDE",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x01A1, 0x0303 },
  uccode=0x1EE0,
  unicodeslot=0x1EE1,
 },
 [0x1EE2]={
  adobename="Ohorndotbelow",
  category="lu",
  contextname="Ohorndotbelow",
  description="LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW",
  direction="l",
  lccode=0x1EE3,
  linebreak="al",
  shcode=0x004F,
  specials={ "char", 0x01A0, 0x0323 },
  unicodeslot=0x1EE2,
 },
 [0x1EE3]={
  adobename="ohorndotbelow",
  category="ll",
  contextname="ohorndotbelow",
  description="LATIN SMALL LETTER O WITH HORN AND DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x006F,
  specials={ "char", 0x01A1, 0x0323 },
  uccode=0x1EE2,
  unicodeslot=0x1EE3,
 },
 [0x1EE4]={
  adobename="Udotbelow",
  category="lu",
  contextname="Udotbelow",
  description="LATIN CAPITAL LETTER U WITH DOT BELOW",
  direction="l",
  lccode=0x1EE5,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0323 },
  unicodeslot=0x1EE4,
 },
 [0x1EE5]={
  adobename="udotbelow",
  category="ll",
  contextname="udotbelow",
  description="LATIN SMALL LETTER U WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0323 },
  uccode=0x1EE4,
  unicodeslot=0x1EE5,
 },
 [0x1EE6]={
  adobename="Uhookabove",
  category="lu",
  contextname="Uhook",
  description="LATIN CAPITAL LETTER U WITH HOOK ABOVE",
  direction="l",
  lccode=0x1EE7,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x0055, 0x0309 },
  unicodeslot=0x1EE6,
 },
 [0x1EE7]={
  adobename="uhookabove",
  category="ll",
  contextname="uhook",
  description="LATIN SMALL LETTER U WITH HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x0075, 0x0309 },
  uccode=0x1EE6,
  unicodeslot=0x1EE7,
 },
 [0x1EE8]={
  adobename="Uhornacute",
  category="lu",
  contextname="Uhornacute",
  description="LATIN CAPITAL LETTER U WITH HORN AND ACUTE",
  direction="l",
  lccode=0x1EE9,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x01AF, 0x0301 },
  unicodeslot=0x1EE8,
 },
 [0x1EE9]={
  adobename="uhornacute",
  category="ll",
  contextname="uhornacute",
  description="LATIN SMALL LETTER U WITH HORN AND ACUTE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x01B0, 0x0301 },
  uccode=0x1EE8,
  unicodeslot=0x1EE9,
 },
 [0x1EEA]={
  adobename="Uhorngrave",
  category="lu",
  contextname="Uhorngrave",
  description="LATIN CAPITAL LETTER U WITH HORN AND GRAVE",
  direction="l",
  lccode=0x1EEB,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x01AF, 0x0300 },
  unicodeslot=0x1EEA,
 },
 [0x1EEB]={
  adobename="uhorngrave",
  category="ll",
  contextname="uhorngrave",
  description="LATIN SMALL LETTER U WITH HORN AND GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x01B0, 0x0300 },
  uccode=0x1EEA,
  unicodeslot=0x1EEB,
 },
 [0x1EEC]={
  adobename="Uhornhookabove",
  category="lu",
  contextname="Uhornhook",
  description="LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE",
  direction="l",
  lccode=0x1EED,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x01AF, 0x0309 },
  unicodeslot=0x1EEC,
 },
 [0x1EED]={
  adobename="uhornhookabove",
  category="ll",
  contextname="uhornhook",
  description="LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x01B0, 0x0309 },
  uccode=0x1EEC,
  unicodeslot=0x1EED,
 },
 [0x1EEE]={
  adobename="Uhorntilde",
  category="lu",
  contextname="Uhorntilde",
  description="LATIN CAPITAL LETTER U WITH HORN AND TILDE",
  direction="l",
  lccode=0x1EEF,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x01AF, 0x0303 },
  unicodeslot=0x1EEE,
 },
 [0x1EEF]={
  adobename="uhorntilde",
  category="ll",
  contextname="uhorntilde",
  description="LATIN SMALL LETTER U WITH HORN AND TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x01B0, 0x0303 },
  uccode=0x1EEE,
  unicodeslot=0x1EEF,
 },
 [0x1EF0]={
  adobename="Uhorndotbelow",
  category="lu",
  contextname="Uhorndotbelow",
  description="LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW",
  direction="l",
  lccode=0x1EF1,
  linebreak="al",
  shcode=0x0055,
  specials={ "char", 0x01AF, 0x0323 },
  unicodeslot=0x1EF0,
 },
 [0x1EF1]={
  adobename="uhorndotbelow",
  category="ll",
  contextname="uhorndotbelow",
  description="LATIN SMALL LETTER U WITH HORN AND DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0075,
  specials={ "char", 0x01B0, 0x0323 },
  uccode=0x1EF0,
  unicodeslot=0x1EF1,
 },
 [0x1EF2]={
  adobename="Ygrave",
  category="lu",
  contextname="Ygrave",
  description="LATIN CAPITAL LETTER Y WITH GRAVE",
  direction="l",
  lccode=0x1EF3,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0300 },
  unicodeslot=0x1EF2,
 },
 [0x1EF3]={
  adobename="ygrave",
  category="ll",
  contextname="ygrave",
  description="LATIN SMALL LETTER Y WITH GRAVE",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0300 },
  uccode=0x1EF2,
  unicodeslot=0x1EF3,
 },
 [0x1EF4]={
  adobename="Ydotbelow",
  category="lu",
  contextname="Ydotbelow",
  description="LATIN CAPITAL LETTER Y WITH DOT BELOW",
  direction="l",
  lccode=0x1EF5,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0323 },
  unicodeslot=0x1EF4,
 },
 [0x1EF5]={
  adobename="ydotbelow",
  category="ll",
  contextname="ydotbelow",
  description="LATIN SMALL LETTER Y WITH DOT BELOW",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0323 },
  uccode=0x1EF4,
  unicodeslot=0x1EF5,
 },
 [0x1EF6]={
  adobename="Yhookabove",
  category="lu",
  contextname="Yhook",
  description="LATIN CAPITAL LETTER Y WITH HOOK ABOVE",
  direction="l",
  lccode=0x1EF7,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0309 },
  unicodeslot=0x1EF6,
 },
 [0x1EF7]={
  adobename="yhookabove",
  category="ll",
  contextname="yhook",
  description="LATIN SMALL LETTER Y WITH HOOK ABOVE",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0309 },
  uccode=0x1EF6,
  unicodeslot=0x1EF7,
 },
 [0x1EF8]={
  adobename="Ytilde",
  category="lu",
  contextname="Ytilde",
  description="LATIN CAPITAL LETTER Y WITH TILDE",
  direction="l",
  lccode=0x1EF9,
  linebreak="al",
  shcode=0x0059,
  specials={ "char", 0x0059, 0x0303 },
  unicodeslot=0x1EF8,
 },
 [0x1EF9]={
  adobename="ytilde",
  category="ll",
  contextname="ytilde",
  description="LATIN SMALL LETTER Y WITH TILDE",
  direction="l",
  linebreak="al",
  shcode=0x0079,
  specials={ "char", 0x0079, 0x0303 },
  uccode=0x1EF8,
  unicodeslot=0x1EF9,
 },
 [0x1EFA]={
  category="lu",
  description="LATIN CAPITAL LETTER MIDDLE-WELSH LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1EFA,
 },
 [0x1EFB]={
  category="ll",
  description="LATIN SMALL LETTER MIDDLE-WELSH LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1EFB,
 },
 [0x1EFC]={
  category="lu",
  description="LATIN CAPITAL LETTER MIDDLE-WELSH V",
  direction="l",
  linebreak="al",
  unicodeslot=0x1EFC,
 },
 [0x1EFD]={
  category="ll",
  description="LATIN SMALL LETTER MIDDLE-WELSH V",
  direction="l",
  linebreak="al",
  unicodeslot=0x1EFD,
 },
 [0x1EFE]={
  category="lu",
  description="LATIN CAPITAL LETTER Y WITH LOOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1EFE,
 },
 [0x1EFF]={
  category="ll",
  description="LATIN SMALL LETTER Y WITH LOOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1EFF,
 },
 [0x1F00]={
  category="ll",
  contextname="greekalphapsili",
  description="GREEK SMALL LETTER ALPHA WITH PSILI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03B1, 0x0313 },
  uccode=0x1F08,
  unicodeslot=0x1F00,
 },
 [0x1F01]={
  category="ll",
  contextname="greekalphadasia",
  description="GREEK SMALL LETTER ALPHA WITH DASIA",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03B1, 0x0314 },
  uccode=0x1F09,
  unicodeslot=0x1F01,
 },
 [0x1F02]={
  category="ll",
  contextname="greekalphapsilivaria",
  description="GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F00, 0x0300 },
  uccode=0x1F0A,
  unicodeslot=0x1F02,
 },
 [0x1F03]={
  category="ll",
  contextname="greekalphadasiavaria",
  description="GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F01, 0x0300 },
  uccode=0x1F0B,
  unicodeslot=0x1F03,
 },
 [0x1F04]={
  category="ll",
  contextname="greekalphapsilitonos",
  description="GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F00, 0x0301 },
  uccode=0x1F0C,
  unicodeslot=0x1F04,
 },
 [0x1F05]={
  category="ll",
  contextname="greekalphadasiatonos",
  description="GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F01, 0x0301 },
  uccode=0x1F0D,
  unicodeslot=0x1F05,
 },
 [0x1F06]={
  category="ll",
  contextname="greekalphapsiliperispomeni",
  description="GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F00, 0x0342 },
  uccode=0x1F0E,
  unicodeslot=0x1F06,
 },
 [0x1F07]={
  category="ll",
  contextname="greekalphadasiaperispomeni",
  description="GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F01, 0x0342 },
  uccode=0x1F0F,
  unicodeslot=0x1F07,
 },
 [0x1F08]={
  category="lu",
  contextname="greekAlphapsili",
  description="GREEK CAPITAL LETTER ALPHA WITH PSILI",
  direction="l",
  lccode=0x1F00,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x0391, 0x0313 },
  unicodeslot=0x1F08,
 },
 [0x1F09]={
  category="lu",
  contextname="greekAlphadasia",
  description="GREEK CAPITAL LETTER ALPHA WITH DASIA",
  direction="l",
  lccode=0x1F01,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x0391, 0x0314 },
  unicodeslot=0x1F09,
 },
 [0x1F0A]={
  category="lu",
  contextname="greekAlphapsilivaria",
  description="GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA",
  direction="l",
  lccode=0x1F02,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F08, 0x0300 },
  unicodeslot=0x1F0A,
 },
 [0x1F0B]={
  category="lu",
  contextname="greekAlphadasiavaria",
  description="GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA",
  direction="l",
  lccode=0x1F03,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F09, 0x0300 },
  unicodeslot=0x1F0B,
 },
 [0x1F0C]={
  category="lu",
  contextname="greekAlphapsilitonos",
  description="GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA",
  direction="l",
  lccode=0x1F04,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F08, 0x0301 },
  unicodeslot=0x1F0C,
 },
 [0x1F0D]={
  category="lu",
  contextname="greekAlphadasiatonos",
  description="GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA",
  direction="l",
  lccode=0x1F05,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F09, 0x0301 },
  unicodeslot=0x1F0D,
 },
 [0x1F0E]={
  category="lu",
  contextname="greekAlphapsiliperispomeni",
  description="GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI",
  direction="l",
  lccode=0x1F06,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F08, 0x0342 },
  unicodeslot=0x1F0E,
 },
 [0x1F0F]={
  category="lu",
  contextname="greekAlphadasiaperispomeni",
  description="GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI",
  direction="l",
  lccode=0x1F07,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F09, 0x0342 },
  unicodeslot=0x1F0F,
 },
 [0x1F10]={
  category="ll",
  contextname="greekepsilonpsili",
  description="GREEK SMALL LETTER EPSILON WITH PSILI",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x03B5, 0x0313 },
  uccode=0x1F18,
  unicodeslot=0x1F10,
 },
 [0x1F11]={
  category="ll",
  contextname="greekepsilondasia",
  description="GREEK SMALL LETTER EPSILON WITH DASIA",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x03B5, 0x0314 },
  uccode=0x1F19,
  unicodeslot=0x1F11,
 },
 [0x1F12]={
  category="ll",
  contextname="greekepsilonpsilivaria",
  description="GREEK SMALL LETTER EPSILON WITH PSILI AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x1F10, 0x0300 },
  uccode=0x1F1A,
  unicodeslot=0x1F12,
 },
 [0x1F13]={
  category="ll",
  contextname="greekepsilondasiavaria",
  description="GREEK SMALL LETTER EPSILON WITH DASIA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x1F11, 0x0300 },
  uccode=0x1F1B,
  unicodeslot=0x1F13,
 },
 [0x1F14]={
  category="ll",
  contextname="greekepsilonpsilitonos",
  description="GREEK SMALL LETTER EPSILON WITH PSILI AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x1F10, 0x0301 },
  uccode=0x1F1C,
  unicodeslot=0x1F14,
 },
 [0x1F15]={
  category="ll",
  contextname="greekepsilondasiatonos",
  description="GREEK SMALL LETTER EPSILON WITH DASIA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x1F11, 0x0301 },
  uccode=0x1F1D,
  unicodeslot=0x1F15,
 },
 [0x1F18]={
  category="lu",
  contextname="greekEpsilonpsili",
  description="GREEK CAPITAL LETTER EPSILON WITH PSILI",
  direction="l",
  lccode=0x1F10,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x0395, 0x0313 },
  unicodeslot=0x1F18,
 },
 [0x1F19]={
  category="lu",
  contextname="greekEpsilondasia",
  description="GREEK CAPITAL LETTER EPSILON WITH DASIA",
  direction="l",
  lccode=0x1F11,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x0395, 0x0314 },
  unicodeslot=0x1F19,
 },
 [0x1F1A]={
  category="lu",
  contextname="greekEpsilonpsilivaria",
  description="GREEK CAPITAL LETTER EPSILON WITH PSILI AND VARIA",
  direction="l",
  lccode=0x1F12,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x1F18, 0x0300 },
  unicodeslot=0x1F1A,
 },
 [0x1F1B]={
  category="lu",
  contextname="greekEpsilondasiavaria",
  description="GREEK CAPITAL LETTER EPSILON WITH DASIA AND VARIA",
  direction="l",
  lccode=0x1F13,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x1F19, 0x0300 },
  unicodeslot=0x1F1B,
 },
 [0x1F1C]={
  category="lu",
  contextname="greekEpsilonpsilitonos",
  description="GREEK CAPITAL LETTER EPSILON WITH PSILI AND OXIA",
  direction="l",
  lccode=0x1F14,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x1F18, 0x0301 },
  unicodeslot=0x1F1C,
 },
 [0x1F1D]={
  category="lu",
  contextname="greekEpsilondasiatonos",
  description="GREEK CAPITAL LETTER EPSILON WITH DASIA AND OXIA",
  direction="l",
  lccode=0x1F15,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x1F19, 0x0301 },
  unicodeslot=0x1F1D,
 },
 [0x1F20]={
  category="ll",
  contextname="greeketapsili",
  description="GREEK SMALL LETTER ETA WITH PSILI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x03B7, 0x0313 },
  uccode=0x1F28,
  unicodeslot=0x1F20,
 },
 [0x1F21]={
  category="ll",
  contextname="greeketadasia",
  description="GREEK SMALL LETTER ETA WITH DASIA",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x03B7, 0x0314 },
  uccode=0x1F29,
  unicodeslot=0x1F21,
 },
 [0x1F22]={
  category="ll",
  contextname="greeketapsilivaria",
  description="GREEK SMALL LETTER ETA WITH PSILI AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F20, 0x0300 },
  uccode=0x1F2A,
  unicodeslot=0x1F22,
 },
 [0x1F23]={
  category="ll",
  contextname="greeketadasiavaria",
  description="GREEK SMALL LETTER ETA WITH DASIA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F21, 0x0300 },
  uccode=0x1F2B,
  unicodeslot=0x1F23,
 },
 [0x1F24]={
  category="ll",
  contextname="greeketapsilitonos",
  description="GREEK SMALL LETTER ETA WITH PSILI AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F20, 0x0301 },
  uccode=0x1F2C,
  unicodeslot=0x1F24,
 },
 [0x1F25]={
  category="ll",
  contextname="greeketadasiatonos",
  description="GREEK SMALL LETTER ETA WITH DASIA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F21, 0x0301 },
  uccode=0x1F2D,
  unicodeslot=0x1F25,
 },
 [0x1F26]={
  category="ll",
  contextname="greeketapsiliperispomeni",
  description="GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F20, 0x0342 },
  uccode=0x1F2E,
  unicodeslot=0x1F26,
 },
 [0x1F27]={
  category="ll",
  contextname="greeketadasiaperispomeni",
  description="GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F21, 0x0342 },
  uccode=0x1F2F,
  unicodeslot=0x1F27,
 },
 [0x1F28]={
  category="lu",
  contextname="greekEtapsili",
  description="GREEK CAPITAL LETTER ETA WITH PSILI",
  direction="l",
  lccode=0x1F20,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x0397, 0x0313 },
  unicodeslot=0x1F28,
 },
 [0x1F29]={
  category="lu",
  contextname="greekEtadasia",
  description="GREEK CAPITAL LETTER ETA WITH DASIA",
  direction="l",
  lccode=0x1F21,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x0397, 0x0314 },
  unicodeslot=0x1F29,
 },
 [0x1F2A]={
  category="lu",
  contextname="greekEtapsilivaria",
  description="GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA",
  direction="l",
  lccode=0x1F22,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F28, 0x0300 },
  unicodeslot=0x1F2A,
 },
 [0x1F2B]={
  category="lu",
  contextname="greekEtadasiavaria",
  description="GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA",
  direction="l",
  lccode=0x1F23,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F29, 0x0300 },
  unicodeslot=0x1F2B,
 },
 [0x1F2C]={
  category="lu",
  contextname="greekEtapsilitonos",
  description="GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA",
  direction="l",
  lccode=0x1F24,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F28, 0x0301 },
  unicodeslot=0x1F2C,
 },
 [0x1F2D]={
  category="lu",
  contextname="greekEtadasiatonos",
  description="GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA",
  direction="l",
  lccode=0x1F25,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F29, 0x0301 },
  unicodeslot=0x1F2D,
 },
 [0x1F2E]={
  category="lu",
  contextname="greekEtapsiliperispomeni",
  description="GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI",
  direction="l",
  lccode=0x1F26,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F28, 0x0342 },
  unicodeslot=0x1F2E,
 },
 [0x1F2F]={
  category="lu",
  contextname="greekEtadasiaperispomeni",
  description="GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI",
  direction="l",
  lccode=0x1F27,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F29, 0x0342 },
  unicodeslot=0x1F2F,
 },
 [0x1F30]={
  category="ll",
  contextname="greekiotapsili",
  description="GREEK SMALL LETTER IOTA WITH PSILI",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03B9, 0x0313 },
  uccode=0x1F38,
  unicodeslot=0x1F30,
 },
 [0x1F31]={
  category="ll",
  contextname="greekiotadasia",
  description="GREEK SMALL LETTER IOTA WITH DASIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03B9, 0x0314 },
  uccode=0x1F39,
  unicodeslot=0x1F31,
 },
 [0x1F32]={
  category="ll",
  contextname="greekiotapsilivaria",
  description="GREEK SMALL LETTER IOTA WITH PSILI AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x1F30, 0x0300 },
  uccode=0x1F3A,
  unicodeslot=0x1F32,
 },
 [0x1F33]={
  category="ll",
  contextname="greekiotadasiavaria",
  description="GREEK SMALL LETTER IOTA WITH DASIA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x1F31, 0x0300 },
  uccode=0x1F3B,
  unicodeslot=0x1F33,
 },
 [0x1F34]={
  category="ll",
  contextname="greekiotapsilitonos",
  description="GREEK SMALL LETTER IOTA WITH PSILI AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x1F30, 0x0301 },
  uccode=0x1F3C,
  unicodeslot=0x1F34,
 },
 [0x1F35]={
  category="ll",
  contextname="greekiotadasiatonos",
  description="GREEK SMALL LETTER IOTA WITH DASIA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x1F31, 0x0301 },
  uccode=0x1F3D,
  unicodeslot=0x1F35,
 },
 [0x1F36]={
  category="ll",
  contextname="greekiotapsiliperispomeni",
  description="GREEK SMALL LETTER IOTA WITH PSILI AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x1F30, 0x0342 },
  uccode=0x1F3E,
  unicodeslot=0x1F36,
 },
 [0x1F37]={
  category="ll",
  contextname="greekiotadasiaperispomeni",
  description="GREEK SMALL LETTER IOTA WITH DASIA AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x1F31, 0x0342 },
  uccode=0x1F3F,
  unicodeslot=0x1F37,
 },
 [0x1F38]={
  category="lu",
  contextname="greekIotapsili",
  description="GREEK CAPITAL LETTER IOTA WITH PSILI",
  direction="l",
  lccode=0x1F30,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x0399, 0x0313 },
  unicodeslot=0x1F38,
 },
 [0x1F39]={
  category="lu",
  contextname="greekIotadasia",
  description="GREEK CAPITAL LETTER IOTA WITH DASIA",
  direction="l",
  lccode=0x1F31,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x0399, 0x0314 },
  unicodeslot=0x1F39,
 },
 [0x1F3A]={
  category="lu",
  contextname="greekIotapsilivaria",
  description="GREEK CAPITAL LETTER IOTA WITH PSILI AND VARIA",
  direction="l",
  lccode=0x1F32,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x1F38, 0x0300 },
  unicodeslot=0x1F3A,
 },
 [0x1F3B]={
  category="lu",
  contextname="greekIotadasiavaria",
  description="GREEK CAPITAL LETTER IOTA WITH DASIA AND VARIA",
  direction="l",
  lccode=0x1F33,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x1F39, 0x0300 },
  unicodeslot=0x1F3B,
 },
 [0x1F3C]={
  category="lu",
  contextname="greekIotapsilitonos",
  description="GREEK CAPITAL LETTER IOTA WITH PSILI AND OXIA",
  direction="l",
  lccode=0x1F34,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x1F38, 0x0301 },
  unicodeslot=0x1F3C,
 },
 [0x1F3D]={
  category="lu",
  contextname="greekIotadasiatonos",
  description="GREEK CAPITAL LETTER IOTA WITH DASIA AND OXIA",
  direction="l",
  lccode=0x1F35,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x1F39, 0x0301 },
  unicodeslot=0x1F3D,
 },
 [0x1F3E]={
  category="lu",
  contextname="greekIotapsiliperispomeni",
  description="GREEK CAPITAL LETTER IOTA WITH PSILI AND PERISPOMENI",
  direction="l",
  lccode=0x1F36,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x1F38, 0x0342 },
  unicodeslot=0x1F3E,
 },
 [0x1F3F]={
  category="lu",
  contextname="greekIotadasiaperispomeni",
  description="GREEK CAPITAL LETTER IOTA WITH DASIA AND PERISPOMENI",
  direction="l",
  lccode=0x1F37,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x1F39, 0x0342 },
  unicodeslot=0x1F3F,
 },
 [0x1F40]={
  category="ll",
  contextname="greekomicronpsili",
  description="GREEK SMALL LETTER OMICRON WITH PSILI",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x03BF, 0x0313 },
  uccode=0x1F48,
  unicodeslot=0x1F40,
 },
 [0x1F41]={
  category="ll",
  contextname="greekomicrondasia",
  description="GREEK SMALL LETTER OMICRON WITH DASIA",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x03BF, 0x0314 },
  uccode=0x1F49,
  unicodeslot=0x1F41,
 },
 [0x1F42]={
  category="ll",
  contextname="greekomicronpsilivaria",
  description="GREEK SMALL LETTER OMICRON WITH PSILI AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x1F40, 0x0300 },
  uccode=0x1F4A,
  unicodeslot=0x1F42,
 },
 [0x1F43]={
  category="ll",
  contextname="greekomicrondasiavaria",
  description="GREEK SMALL LETTER OMICRON WITH DASIA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x1F41, 0x0300 },
  uccode=0x1F4B,
  unicodeslot=0x1F43,
 },
 [0x1F44]={
  category="ll",
  contextname="greekomicronpsilitonos",
  description="GREEK SMALL LETTER OMICRON WITH PSILI AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x1F40, 0x0301 },
  uccode=0x1F4C,
  unicodeslot=0x1F44,
 },
 [0x1F45]={
  category="ll",
  contextname="greekomicrondasiatonos",
  description="GREEK SMALL LETTER OMICRON WITH DASIA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x1F41, 0x0301 },
  uccode=0x1F4D,
  unicodeslot=0x1F45,
 },
 [0x1F48]={
  category="lu",
  contextname="greekOmicronpsili",
  description="GREEK CAPITAL LETTER OMICRON WITH PSILI",
  direction="l",
  lccode=0x1F40,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x039F, 0x0313 },
  unicodeslot=0x1F48,
 },
 [0x1F49]={
  category="lu",
  contextname="greekOmicrondasia",
  description="GREEK CAPITAL LETTER OMICRON WITH DASIA",
  direction="l",
  lccode=0x1F41,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x039F, 0x0314 },
  unicodeslot=0x1F49,
 },
 [0x1F4A]={
  category="lu",
  contextname="greekOmicronpsilivaria",
  description="GREEK CAPITAL LETTER OMICRON WITH PSILI AND VARIA",
  direction="l",
  lccode=0x1F42,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x1F48, 0x0300 },
  unicodeslot=0x1F4A,
 },
 [0x1F4B]={
  category="lu",
  contextname="greekOmicrondasiavaria",
  description="GREEK CAPITAL LETTER OMICRON WITH DASIA AND VARIA",
  direction="l",
  lccode=0x1F43,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x1F49, 0x0300 },
  unicodeslot=0x1F4B,
 },
 [0x1F4C]={
  category="lu",
  contextname="greekOmicronpsilitonos",
  description="GREEK CAPITAL LETTER OMICRON WITH PSILI AND OXIA",
  direction="l",
  lccode=0x1F44,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x1F48, 0x0301 },
  unicodeslot=0x1F4C,
 },
 [0x1F4D]={
  category="lu",
  contextname="greekOmicrondasiatonos",
  description="GREEK CAPITAL LETTER OMICRON WITH DASIA AND OXIA",
  direction="l",
  lccode=0x1F45,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x1F49, 0x0301 },
  unicodeslot=0x1F4D,
 },
 [0x1F50]={
  category="ll",
  contextname="greekupsilonpsili",
  description="GREEK SMALL LETTER UPSILON WITH PSILI",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03C5, 0x0313 },
  unicodeslot=0x1F50,
 },
 [0x1F51]={
  category="ll",
  contextname="greekupsilondasia",
  description="GREEK SMALL LETTER UPSILON WITH DASIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03C5, 0x0314 },
  uccode=0x1F59,
  unicodeslot=0x1F51,
 },
 [0x1F52]={
  category="ll",
  contextname="greekupsilonpsilivaria",
  description="GREEK SMALL LETTER UPSILON WITH PSILI AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x1F50, 0x0300 },
  unicodeslot=0x1F52,
 },
 [0x1F53]={
  category="ll",
  contextname="greekupsilondasiavaria",
  description="GREEK SMALL LETTER UPSILON WITH DASIA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x1F51, 0x0300 },
  uccode=0x1F5B,
  unicodeslot=0x1F53,
 },
 [0x1F54]={
  category="ll",
  contextname="greekupsilonpsilitonos",
  description="GREEK SMALL LETTER UPSILON WITH PSILI AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x1F50, 0x0301 },
  unicodeslot=0x1F54,
 },
 [0x1F55]={
  category="ll",
  contextname="greekupsilondasiatonos",
  description="GREEK SMALL LETTER UPSILON WITH DASIA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x1F51, 0x0301 },
  uccode=0x1F5D,
  unicodeslot=0x1F55,
 },
 [0x1F56]={
  category="ll",
  contextname="greekupsilonpsiliperispomeni",
  description="GREEK SMALL LETTER UPSILON WITH PSILI AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x1F50, 0x0342 },
  unicodeslot=0x1F56,
 },
 [0x1F57]={
  category="ll",
  contextname="greekupsilondasiaperispomeni",
  description="GREEK SMALL LETTER UPSILON WITH DASIA AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x1F51, 0x0342 },
  uccode=0x1F5F,
  unicodeslot=0x1F57,
 },
 [0x1F59]={
  category="lu",
  contextname="greekUpsilondasia",
  description="GREEK CAPITAL LETTER UPSILON WITH DASIA",
  direction="l",
  lccode=0x1F51,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x03A5, 0x0314 },
  unicodeslot=0x1F59,
 },
 [0x1F5B]={
  category="lu",
  contextname="greekUpsilondasiavaria",
  description="GREEK CAPITAL LETTER UPSILON WITH DASIA AND VARIA",
  direction="l",
  lccode=0x1F53,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x1F59, 0x0300 },
  unicodeslot=0x1F5B,
 },
 [0x1F5D]={
  category="lu",
  contextname="greekUpsilondasiatonos",
  description="GREEK CAPITAL LETTER UPSILON WITH DASIA AND OXIA",
  direction="l",
  lccode=0x1F55,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x1F59, 0x0301 },
  unicodeslot=0x1F5D,
 },
 [0x1F5F]={
  category="lu",
  contextname="greekUpsilondasiaperispomeni",
  description="GREEK CAPITAL LETTER UPSILON WITH DASIA AND PERISPOMENI",
  direction="l",
  lccode=0x1F57,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x1F59, 0x0342 },
  unicodeslot=0x1F5F,
 },
 [0x1F60]={
  category="ll",
  contextname="greekomegapsili",
  description="GREEK SMALL LETTER OMEGA WITH PSILI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x03C9, 0x0313 },
  uccode=0x1F68,
  unicodeslot=0x1F60,
 },
 [0x1F61]={
  category="ll",
  contextname="greekomegadasia",
  description="GREEK SMALL LETTER OMEGA WITH DASIA",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x03C9, 0x0314 },
  uccode=0x1F69,
  unicodeslot=0x1F61,
 },
 [0x1F62]={
  category="ll",
  contextname="greekomegapsilivaria",
  description="GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F60, 0x0300 },
  uccode=0x1F6A,
  unicodeslot=0x1F62,
 },
 [0x1F63]={
  category="ll",
  contextname="greekomegadasiavaria",
  description="GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F61, 0x0300 },
  uccode=0x1F6B,
  unicodeslot=0x1F63,
 },
 [0x1F64]={
  category="ll",
  contextname="greekomegapsilitonos",
  description="GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F60, 0x0301 },
  uccode=0x1F6C,
  unicodeslot=0x1F64,
 },
 [0x1F65]={
  category="ll",
  contextname="greekomegadasiatonos",
  description="GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F61, 0x0301 },
  uccode=0x1F6D,
  unicodeslot=0x1F65,
 },
 [0x1F66]={
  category="ll",
  contextname="greekomegapsiliperispomeni",
  description="GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F60, 0x0342 },
  uccode=0x1F6E,
  unicodeslot=0x1F66,
 },
 [0x1F67]={
  category="ll",
  contextname="greekomegadasiaperispomeni",
  description="GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F61, 0x0342 },
  uccode=0x1F6F,
  unicodeslot=0x1F67,
 },
 [0x1F68]={
  category="lu",
  contextname="greekOmegapsili",
  description="GREEK CAPITAL LETTER OMEGA WITH PSILI",
  direction="l",
  lccode=0x1F60,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x03A9, 0x0313 },
  unicodeslot=0x1F68,
 },
 [0x1F69]={
  category="lu",
  contextname="greekOmegadasia",
  description="GREEK CAPITAL LETTER OMEGA WITH DASIA",
  direction="l",
  lccode=0x1F61,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x03A9, 0x0314 },
  unicodeslot=0x1F69,
 },
 [0x1F6A]={
  category="lu",
  contextname="greekOmegapsilivaria",
  description="GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA",
  direction="l",
  lccode=0x1F62,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F68, 0x0300 },
  unicodeslot=0x1F6A,
 },
 [0x1F6B]={
  category="lu",
  contextname="greekOmegadasiavaria",
  description="GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA",
  direction="l",
  lccode=0x1F63,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F69, 0x0300 },
  unicodeslot=0x1F6B,
 },
 [0x1F6C]={
  category="lu",
  contextname="greekOmegapsilitonos",
  description="GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA",
  direction="l",
  lccode=0x1F64,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F68, 0x0301 },
  unicodeslot=0x1F6C,
 },
 [0x1F6D]={
  category="lu",
  contextname="greekOmegadasiatonos",
  description="GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA",
  direction="l",
  lccode=0x1F65,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F69, 0x0301 },
  unicodeslot=0x1F6D,
 },
 [0x1F6E]={
  category="lu",
  contextname="greekOmegapsiliperispomeni",
  description="GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI",
  direction="l",
  lccode=0x1F66,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F68, 0x0342 },
  unicodeslot=0x1F6E,
 },
 [0x1F6F]={
  category="lu",
  contextname="greekOmegadasiaperispomeni",
  description="GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI",
  direction="l",
  lccode=0x1F67,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F69, 0x0342 },
  unicodeslot=0x1F6F,
 },
 [0x1F70]={
  category="ll",
  contextname="greekalphavaria",
  description="GREEK SMALL LETTER ALPHA WITH VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03B1, 0x0300 },
  uccode=0x1FBA,
  unicodeslot=0x1F70,
 },
 [0x1F71]={
  category="ll",
  contextname="greekalphaoxia",
  description="GREEK SMALL LETTER ALPHA WITH OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03AC },
  uccode=0x1FBB,
  unicodeslot=0x1F71,
 },
 [0x1F72]={
  category="ll",
  contextname="greekepsilonvaria",
  description="GREEK SMALL LETTER EPSILON WITH VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x03B5, 0x0300 },
  uccode=0x1FC8,
  unicodeslot=0x1F72,
 },
 [0x1F73]={
  category="ll",
  contextname="greekepsilonoxia",
  description="GREEK SMALL LETTER EPSILON WITH OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B5,
  specials={ "char", 0x03AD },
  uccode=0x1FC9,
  unicodeslot=0x1F73,
 },
 [0x1F74]={
  category="ll",
  contextname="greeketavaria",
  description="GREEK SMALL LETTER ETA WITH VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x03B7, 0x0300 },
  uccode=0x1FCA,
  unicodeslot=0x1F74,
 },
 [0x1F75]={
  category="ll",
  contextname="greeketaoxia",
  description="GREEK SMALL LETTER ETA WITH OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x03AE },
  uccode=0x1FCB,
  unicodeslot=0x1F75,
 },
 [0x1F76]={
  category="ll",
  contextname="greekiotavaria",
  description="GREEK SMALL LETTER IOTA WITH VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03B9, 0x0300 },
  uccode=0x1FDA,
  unicodeslot=0x1F76,
 },
 [0x1F77]={
  category="ll",
  contextname="greekiotaoxia",
  description="GREEK SMALL LETTER IOTA WITH OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03AF },
  uccode=0x1FDB,
  unicodeslot=0x1F77,
 },
 [0x1F78]={
  category="ll",
  contextname="greekomicronvaria",
  description="GREEK SMALL LETTER OMICRON WITH VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x03BF, 0x0300 },
  uccode=0x1FF8,
  unicodeslot=0x1F78,
 },
 [0x1F79]={
  category="ll",
  contextname="greekomicronoxia",
  description="GREEK SMALL LETTER OMICRON WITH OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03BF,
  specials={ "char", 0x03CC },
  uccode=0x1FF9,
  unicodeslot=0x1F79,
 },
 [0x1F7A]={
  category="ll",
  contextname="greekupsilonvaria",
  description="GREEK SMALL LETTER UPSILON WITH VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03C5, 0x0300 },
  uccode=0x1FEA,
  unicodeslot=0x1F7A,
 },
 [0x1F7B]={
  category="ll",
  contextname="greekupsilonoxia",
  description="GREEK SMALL LETTER UPSILON WITH OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03CD },
  uccode=0x1FEB,
  unicodeslot=0x1F7B,
 },
 [0x1F7C]={
  category="ll",
  contextname="greekomegavaria",
  description="GREEK SMALL LETTER OMEGA WITH VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x03C9, 0x0300 },
  uccode=0x1FFA,
  unicodeslot=0x1F7C,
 },
 [0x1F7D]={
  category="ll",
  contextname="greekomegaoxia",
  description="GREEK SMALL LETTER OMEGA WITH OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x03CE },
  uccode=0x1FFB,
  unicodeslot=0x1F7D,
 },
 [0x1F80]={
  category="ll",
  contextname="greekalphaiotasubpsili",
  description="GREEK SMALL LETTER ALPHA WITH PSILI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F00, 0x0345 },
  uccode=0x1F88,
  unicodeslot=0x1F80,
 },
 [0x1F81]={
  category="ll",
  contextname="greekalphaiotasubdasia",
  description="GREEK SMALL LETTER ALPHA WITH DASIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F01, 0x0345 },
  uccode=0x1F89,
  unicodeslot=0x1F81,
 },
 [0x1F82]={
  category="ll",
  contextname="greekalphaiotasubpsilivaria",
  description="GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F02, 0x0345 },
  uccode=0x1F8A,
  unicodeslot=0x1F82,
 },
 [0x1F83]={
  category="ll",
  contextname="greekalphaiotasubdasiavaria",
  description="GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F03, 0x0345 },
  uccode=0x1F8B,
  unicodeslot=0x1F83,
 },
 [0x1F84]={
  category="ll",
  contextname="greekalphaiotasubpsilitonos",
  description="GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F04, 0x0345 },
  uccode=0x1F8C,
  unicodeslot=0x1F84,
 },
 [0x1F85]={
  category="ll",
  contextname="greekalphaiotasubdasiatonos",
  description="GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F05, 0x0345 },
  uccode=0x1F8D,
  unicodeslot=0x1F85,
 },
 [0x1F86]={
  category="ll",
  contextname="greekalphaiotasubpsiliperispomeni",
  description="GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F06, 0x0345 },
  uccode=0x1F8E,
  unicodeslot=0x1F86,
 },
 [0x1F87]={
  category="ll",
  contextname="greekalphaiotasubdasiaperispomeni",
  description="GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F07, 0x0345 },
  uccode=0x1F8F,
  unicodeslot=0x1F87,
 },
 [0x1F88]={
  category="lt",
  contextname="greekAlphaiotasubpsili",
  description="GREEK CAPITAL LETTER ALPHA WITH PSILI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F80,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F08, 0x0345 },
  unicodeslot=0x1F88,
 },
 [0x1F89]={
  category="lt",
  contextname="greekAlphaiotasubdasia",
  description="GREEK CAPITAL LETTER ALPHA WITH DASIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F81,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F09, 0x0345 },
  unicodeslot=0x1F89,
 },
 [0x1F8A]={
  category="lt",
  contextname="greekAlphaiotasubpsilivaria",
  description="GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F82,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F0A, 0x0345 },
  unicodeslot=0x1F8A,
 },
 [0x1F8B]={
  category="lt",
  contextname="greekAlphaiotasubdasiavaria",
  description="GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F83,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F0B, 0x0345 },
  unicodeslot=0x1F8B,
 },
 [0x1F8C]={
  category="lt",
  contextname="greekAlphaiotasubpsilitonos",
  description="GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F84,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F0C, 0x0345 },
  unicodeslot=0x1F8C,
 },
 [0x1F8D]={
  category="lt",
  contextname="greekAlphaiotasubdasiatonos",
  description="GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F85,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F0D, 0x0345 },
  unicodeslot=0x1F8D,
 },
 [0x1F8E]={
  category="lt",
  contextname="greekAlphaiotasubpsiliperispomeni",
  description="GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F86,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F0E, 0x0345 },
  unicodeslot=0x1F8E,
 },
 [0x1F8F]={
  category="lt",
  contextname="greekAlphaiotasubdasiaperispomeni",
  description="GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F87,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x1F0F, 0x0345 },
  unicodeslot=0x1F8F,
 },
 [0x1F90]={
  category="ll",
  contextname="greeketaiotasubpsili",
  description="GREEK SMALL LETTER ETA WITH PSILI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F20, 0x0345 },
  uccode=0x1F98,
  unicodeslot=0x1F90,
 },
 [0x1F91]={
  category="ll",
  contextname="greeketaiotasubdasia",
  description="GREEK SMALL LETTER ETA WITH DASIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F21, 0x0345 },
  uccode=0x1F99,
  unicodeslot=0x1F91,
 },
 [0x1F92]={
  category="ll",
  contextname="greeketaiotasubpsilivaria",
  description="GREEK SMALL LETTER ETA WITH PSILI AND VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F22, 0x0345 },
  uccode=0x1F9A,
  unicodeslot=0x1F92,
 },
 [0x1F93]={
  category="ll",
  contextname="greeketaiotasubdasiavaria",
  description="GREEK SMALL LETTER ETA WITH DASIA AND VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F23, 0x0345 },
  uccode=0x1F9B,
  unicodeslot=0x1F93,
 },
 [0x1F94]={
  category="ll",
  contextname="greeketaiotasubpsilitonos",
  description="GREEK SMALL LETTER ETA WITH PSILI AND OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F24, 0x0345 },
  uccode=0x1F9C,
  unicodeslot=0x1F94,
 },
 [0x1F95]={
  category="ll",
  contextname="greeketaiotasubdasiatonos",
  description="GREEK SMALL LETTER ETA WITH DASIA AND OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F25, 0x0345 },
  uccode=0x1F9D,
  unicodeslot=0x1F95,
 },
 [0x1F96]={
  category="ll",
  contextname="greeketaiotasubpsiliperispomeni",
  description="GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F26, 0x0345 },
  uccode=0x1F9E,
  unicodeslot=0x1F96,
 },
 [0x1F97]={
  category="ll",
  contextname="greeketaiotasubdasiaperispomeni",
  description="GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F27, 0x0345 },
  uccode=0x1F9F,
  unicodeslot=0x1F97,
 },
 [0x1F98]={
  category="lt",
  contextname="greekEtaiotasubpsili",
  description="GREEK CAPITAL LETTER ETA WITH PSILI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F90,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F28, 0x0345 },
  unicodeslot=0x1F98,
 },
 [0x1F99]={
  category="lt",
  contextname="greekEtaiotasubdasia",
  description="GREEK CAPITAL LETTER ETA WITH DASIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F91,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F29, 0x0345 },
  unicodeslot=0x1F99,
 },
 [0x1F9A]={
  category="lt",
  contextname="greekEtaiotasubpsilivaria",
  description="GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F92,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F2A, 0x0345 },
  unicodeslot=0x1F9A,
 },
 [0x1F9B]={
  category="lt",
  contextname="greekEtaiotasubdasiavaria",
  description="GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F93,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F2B, 0x0345 },
  unicodeslot=0x1F9B,
 },
 [0x1F9C]={
  category="lt",
  contextname="greekEtaiotasubpsilitonos",
  description="GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F94,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F2C, 0x0345 },
  unicodeslot=0x1F9C,
 },
 [0x1F9D]={
  category="lt",
  contextname="greekEtaiotasubdasiatonos",
  description="GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F95,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F2D, 0x0345 },
  unicodeslot=0x1F9D,
 },
 [0x1F9E]={
  category="lt",
  contextname="greekEtaiotasubpsiliperispomeni",
  description="GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F96,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F2E, 0x0345 },
  unicodeslot=0x1F9E,
 },
 [0x1F9F]={
  category="lt",
  contextname="greekEtaiotasubdasiaperispomeni",
  description="GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1F97,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x1F2F, 0x0345 },
  unicodeslot=0x1F9F,
 },
 [0x1FA0]={
  category="ll",
  contextname="greekomegaiotasubpsili",
  description="GREEK SMALL LETTER OMEGA WITH PSILI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F60, 0x0345 },
  uccode=0x1FA8,
  unicodeslot=0x1FA0,
 },
 [0x1FA1]={
  category="ll",
  contextname="greekomegaiotasubdasia",
  description="GREEK SMALL LETTER OMEGA WITH DASIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F61, 0x0345 },
  uccode=0x1FA9,
  unicodeslot=0x1FA1,
 },
 [0x1FA2]={
  category="ll",
  contextname="greekomegaiotasubpsilivaria",
  description="GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F62, 0x0345 },
  uccode=0x1FAA,
  unicodeslot=0x1FA2,
 },
 [0x1FA3]={
  category="ll",
  contextname="greekomegaiotasubdasiavaria",
  description="GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F63, 0x0345 },
  uccode=0x1FAB,
  unicodeslot=0x1FA3,
 },
 [0x1FA4]={
  category="ll",
  contextname="greekomegaiotasubpsilitonos",
  description="GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F64, 0x0345 },
  uccode=0x1FAC,
  unicodeslot=0x1FA4,
 },
 [0x1FA5]={
  category="ll",
  contextname="greekomegaiotasubdasiatonos",
  description="GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F65, 0x0345 },
  uccode=0x1FAD,
  unicodeslot=0x1FA5,
 },
 [0x1FA6]={
  category="ll",
  contextname="greekomegaiotasubpsiliperispomeni",
  description="GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F66, 0x0345 },
  uccode=0x1FAE,
  unicodeslot=0x1FA6,
 },
 [0x1FA7]={
  category="ll",
  contextname="greekomegaiotasubdasiaperispomeni",
  description="GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F67, 0x0345 },
  uccode=0x1FAF,
  unicodeslot=0x1FA7,
 },
 [0x1FA8]={
  category="lt",
  contextname="greekOmegaiotasubpsili",
  description="GREEK CAPITAL LETTER OMEGA WITH PSILI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FA0,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F68, 0x0345 },
  unicodeslot=0x1FA8,
 },
 [0x1FA9]={
  category="lt",
  contextname="greekOmegaiotasubdasia",
  description="GREEK CAPITAL LETTER OMEGA WITH DASIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FA1,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F69, 0x0345 },
  unicodeslot=0x1FA9,
 },
 [0x1FAA]={
  category="lt",
  contextname="greekOmegaiotasubpsilivaria",
  description="GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FA2,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F6A, 0x0345 },
  unicodeslot=0x1FAA,
 },
 [0x1FAB]={
  category="lt",
  contextname="greekOmegaiotasubdasiavaria",
  description="GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FA3,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F6B, 0x0345 },
  unicodeslot=0x1FAB,
 },
 [0x1FAC]={
  category="lt",
  contextname="greekOmegaiotasubpsilitonos",
  description="GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FA4,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F6C, 0x0345 },
  unicodeslot=0x1FAC,
 },
 [0x1FAD]={
  category="lt",
  contextname="greekOmegaiotasubdasiatonos",
  description="GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FA5,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F6D, 0x0345 },
  unicodeslot=0x1FAD,
 },
 [0x1FAE]={
  category="lt",
  contextname="greekOmegaiotasubpsiliperispomeni",
  description="GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FA6,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F6E, 0x0345 },
  unicodeslot=0x1FAE,
 },
 [0x1FAF]={
  category="lt",
  contextname="greekOmegaiotasubdasiaperispomeni",
  description="GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FA7,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x1F6F, 0x0345 },
  unicodeslot=0x1FAF,
 },
 [0x1FB0]={
  category="ll",
  contextname="greekalphavrachy",
  description="GREEK SMALL LETTER ALPHA WITH VRACHY",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03B1, 0x0306 },
  uccode=0x1FB8,
  unicodeslot=0x1FB0,
 },
 [0x1FB1]={
  category="ll",
  contextname="greekalphamacron",
  description="GREEK SMALL LETTER ALPHA WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03B1, 0x0304 },
  uccode=0x1FB9,
  unicodeslot=0x1FB1,
 },
 [0x1FB2]={
  category="ll",
  contextname="greekalphaiotasubvaria",
  description="GREEK SMALL LETTER ALPHA WITH VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1F70, 0x0345 },
  unicodeslot=0x1FB2,
 },
 [0x1FB3]={
  category="ll",
  contextname="greekalphaiotasub",
  description="GREEK SMALL LETTER ALPHA WITH YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03B1, 0x0345 },
  uccode=0x1FBC,
  unicodeslot=0x1FB3,
 },
 [0x1FB4]={
  category="ll",
  contextname="greekalphaiotasubtonos",
  description="GREEK SMALL LETTER ALPHA WITH OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03AC, 0x0345 },
  unicodeslot=0x1FB4,
 },
 [0x1FB6]={
  category="ll",
  contextname="greekalphaperispomeni",
  description="GREEK SMALL LETTER ALPHA WITH PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x03B1, 0x0342 },
  unicodeslot=0x1FB6,
 },
 [0x1FB7]={
  category="ll",
  contextname="greekalphaiotasubperispomeni",
  description="GREEK SMALL LETTER ALPHA WITH PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B1,
  specials={ "char", 0x1FB6, 0x0345 },
  unicodeslot=0x1FB7,
 },
 [0x1FB8]={
  category="lu",
  contextname="greekAlphavrachy",
  description="GREEK CAPITAL LETTER ALPHA WITH VRACHY",
  direction="l",
  lccode=0x1FB0,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x0391, 0x0306 },
  unicodeslot=0x1FB8,
 },
 [0x1FB9]={
  category="lu",
  contextname="greekAlphamacron",
  description="GREEK CAPITAL LETTER ALPHA WITH MACRON",
  direction="l",
  lccode=0x1FB1,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x0391, 0x0304 },
  unicodeslot=0x1FB9,
 },
 [0x1FBA]={
  category="lu",
  contextname="greekAlphavaria",
  description="GREEK CAPITAL LETTER ALPHA WITH VARIA",
  direction="l",
  lccode=0x1F70,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x0391, 0x0300 },
  unicodeslot=0x1FBA,
 },
 [0x1FBB]={
  category="lu",
  contextname="greekAlphatonos",
  description="GREEK CAPITAL LETTER ALPHA WITH OXIA",
  direction="l",
  lccode=0x1F71,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x0386 },
  unicodeslot=0x1FBB,
 },
 [0x1FBC]={
  category="lt",
  contextname="greekAlphaiotasub",
  description="GREEK CAPITAL LETTER ALPHA WITH PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FB3,
  linebreak="al",
  shcode=0x0391,
  specials={ "char", 0x0391, 0x0345 },
  unicodeslot=0x1FBC,
 },
 [0x1FBD]={
  category="sk",
  contextname="greekCoronis",
  description="GREEK KORONIS",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0020, 0x0313 },
  unicodeslot=0x1FBD,
 },
 [0x1FBE]={
  category="ll",
  contextname="greekprosgegrammeni",
  description="GREEK PROSGEGRAMMENI",
  direction="l",
  linebreak="al",
  specials={ "char", 0x03B9 },
  uccode=0x0399,
  unicodeslot=0x1FBE,
 },
 [0x1FBF]={
  category="sk",
  contextname="greekpsili",
  description="GREEK PSILI",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0020, 0x0313 },
  unicodeslot=0x1FBF,
 },
 [0x1FC0]={
  category="sk",
  contextname="greekperispomeni",
  description="GREEK PERISPOMENI",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0020, 0x0342 },
  unicodeslot=0x1FC0,
 },
 [0x1FC1]={
  category="sk",
  contextname="greekdialytikaperispomeni",
  description="GREEK DIALYTIKA AND PERISPOMENI",
  direction="on",
  linebreak="al",
  specials={ "char", 0x00A8, 0x0342 },
  unicodeslot=0x1FC1,
 },
 [0x1FC2]={
  category="ll",
  contextname="greeketaiotasubvaria",
  description="GREEK SMALL LETTER ETA WITH VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1F74, 0x0345 },
  unicodeslot=0x1FC2,
 },
 [0x1FC3]={
  category="ll",
  contextname="greeketaiotasub",
  description="GREEK SMALL LETTER ETA WITH YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x03B7, 0x0345 },
  uccode=0x1FCC,
  unicodeslot=0x1FC3,
 },
 [0x1FC4]={
  category="ll",
  contextname="greeketaiotasubtonos",
  description="GREEK SMALL LETTER ETA WITH OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x03AE, 0x0345 },
  unicodeslot=0x1FC4,
 },
 [0x1FC6]={
  category="ll",
  contextname="greeketaperispomeni",
  description="GREEK SMALL LETTER ETA WITH PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x03B7, 0x0342 },
  unicodeslot=0x1FC6,
 },
 [0x1FC7]={
  category="ll",
  contextname="greeketaiotasubperispomeni",
  description="GREEK SMALL LETTER ETA WITH PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B7,
  specials={ "char", 0x1FC6, 0x0345 },
  unicodeslot=0x1FC7,
 },
 [0x1FC8]={
  category="lu",
  contextname="greekEpsilonvaria",
  description="GREEK CAPITAL LETTER EPSILON WITH VARIA",
  direction="l",
  lccode=0x1F72,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x0395, 0x0300 },
  unicodeslot=0x1FC8,
 },
 [0x1FC9]={
  category="lu",
  contextname="greekEpsilontonos",
  description="GREEK CAPITAL LETTER EPSILON WITH OXIA",
  direction="l",
  lccode=0x1F73,
  linebreak="al",
  shcode=0x0395,
  specials={ "char", 0x0388 },
  unicodeslot=0x1FC9,
 },
 [0x1FCA]={
  category="lu",
  contextname="greekEtavaria",
  description="GREEK CAPITAL LETTER ETA WITH VARIA",
  direction="l",
  lccode=0x1F74,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x0397, 0x0300 },
  unicodeslot=0x1FCA,
 },
 [0x1FCB]={
  category="lu",
  contextname="greekEtatonos",
  description="GREEK CAPITAL LETTER ETA WITH OXIA",
  direction="l",
  lccode=0x1F75,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x0389 },
  unicodeslot=0x1FCB,
 },
 [0x1FCC]={
  category="lt",
  contextname="greekEtaiotasub",
  description="GREEK CAPITAL LETTER ETA WITH PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FC3,
  linebreak="al",
  shcode=0x0397,
  specials={ "char", 0x0397, 0x0345 },
  unicodeslot=0x1FCC,
 },
 [0x1FCD]={
  category="sk",
  contextname="greekpsilivaria",
  description="GREEK PSILI AND VARIA",
  direction="on",
  linebreak="al",
  specials={ "char", 0x1FBF, 0x0300 },
  unicodeslot=0x1FCD,
 },
 [0x1FCE]={
  category="sk",
  contextname="greekpsilitonos",
  description="GREEK PSILI AND OXIA",
  direction="on",
  linebreak="al",
  specials={ "char", 0x1FBF, 0x0301 },
  unicodeslot=0x1FCE,
 },
 [0x1FCF]={
  category="sk",
  contextname="greekpsiliperispomeni",
  description="GREEK PSILI AND PERISPOMENI",
  direction="on",
  linebreak="al",
  specials={ "char", 0x1FBF, 0x0342 },
  unicodeslot=0x1FCF,
 },
 [0x1FD0]={
  category="ll",
  contextname="greekiotavrachy",
  description="GREEK SMALL LETTER IOTA WITH VRACHY",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03B9, 0x0306 },
  uccode=0x1FD8,
  unicodeslot=0x1FD0,
 },
 [0x1FD1]={
  category="ll",
  contextname="greekiotamacron",
  description="GREEK SMALL LETTER IOTA WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03B9, 0x0304 },
  uccode=0x1FD9,
  unicodeslot=0x1FD1,
 },
 [0x1FD2]={
  category="ll",
  contextname="greekiotadialytikavaria",
  description="GREEK SMALL LETTER IOTA WITH DIALYTIKA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03CA, 0x0300 },
  unicodeslot=0x1FD2,
 },
 [0x1FD3]={
  category="ll",
  contextname="greekiotadialytikatonos",
  description="GREEK SMALL LETTER IOTA WITH DIALYTIKA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x0390 },
  unicodeslot=0x1FD3,
 },
 [0x1FD6]={
  category="ll",
  contextname="greekiotaperispomeni",
  description="GREEK SMALL LETTER IOTA WITH PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03B9, 0x0342 },
  unicodeslot=0x1FD6,
 },
 [0x1FD7]={
  category="ll",
  contextname="greekiotadialytikaperispomeni",
  description="GREEK SMALL LETTER IOTA WITH DIALYTIKA AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03B9,
  specials={ "char", 0x03CA, 0x0342 },
  unicodeslot=0x1FD7,
 },
 [0x1FD8]={
  category="lu",
  contextname="greekIotavrachy",
  description="GREEK CAPITAL LETTER IOTA WITH VRACHY",
  direction="l",
  lccode=0x1FD0,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x0399, 0x0306 },
  unicodeslot=0x1FD8,
 },
 [0x1FD9]={
  category="lu",
  contextname="greekIotamacron",
  description="GREEK CAPITAL LETTER IOTA WITH MACRON",
  direction="l",
  lccode=0x1FD1,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x0399, 0x0304 },
  unicodeslot=0x1FD9,
 },
 [0x1FDA]={
  category="lu",
  contextname="greekIotavaria",
  description="GREEK CAPITAL LETTER IOTA WITH VARIA",
  direction="l",
  lccode=0x1F76,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x0399, 0x0300 },
  unicodeslot=0x1FDA,
 },
 [0x1FDB]={
  category="lu",
  contextname="greekIotatonos",
  description="GREEK CAPITAL LETTER IOTA WITH OXIA",
  direction="l",
  lccode=0x1F77,
  linebreak="al",
  shcode=0x0399,
  specials={ "char", 0x038A },
  unicodeslot=0x1FDB,
 },
 [0x1FDD]={
  category="sk",
  contextname="greekdasiavaria",
  description="GREEK DASIA AND VARIA",
  direction="on",
  linebreak="al",
  specials={ "char", 0x1FFE, 0x0300 },
  unicodeslot=0x1FDD,
 },
 [0x1FDE]={
  category="sk",
  contextname="greekdasiatonos",
  description="GREEK DASIA AND OXIA",
  direction="on",
  linebreak="al",
  specials={ "char", 0x1FFE, 0x0301 },
  unicodeslot=0x1FDE,
 },
 [0x1FDF]={
  category="sk",
  contextname="greekdasiaperispomeni",
  description="GREEK DASIA AND PERISPOMENI",
  direction="on",
  linebreak="al",
  specials={ "char", 0x1FFE, 0x0342 },
  unicodeslot=0x1FDF,
 },
 [0x1FE0]={
  category="ll",
  contextname="greekupsilonvrachy",
  description="GREEK SMALL LETTER UPSILON WITH VRACHY",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03C5, 0x0306 },
  uccode=0x1FE8,
  unicodeslot=0x1FE0,
 },
 [0x1FE1]={
  category="ll",
  contextname="greekupsilonmacron",
  description="GREEK SMALL LETTER UPSILON WITH MACRON",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03C5, 0x0304 },
  uccode=0x1FE9,
  unicodeslot=0x1FE1,
 },
 [0x1FE2]={
  category="ll",
  contextname="greekupsilondialytikavaria",
  description="GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND VARIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03CB, 0x0300 },
  unicodeslot=0x1FE2,
 },
 [0x1FE3]={
  category="ll",
  contextname="greekupsilondialytikatonos",
  description="GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND OXIA",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03B0 },
  unicodeslot=0x1FE3,
 },
 [0x1FE4]={
  category="ll",
  contextname="greekrhopsili",
  description="GREEK SMALL LETTER RHO WITH PSILI",
  direction="l",
  linebreak="al",
  shcode=0x03C1,
  specials={ "char", 0x03C1, 0x0313 },
  unicodeslot=0x1FE4,
 },
 [0x1FE5]={
  category="ll",
  contextname="greekrhodasia",
  description="GREEK SMALL LETTER RHO WITH DASIA",
  direction="l",
  linebreak="al",
  shcode=0x03C1,
  specials={ "char", 0x03C1, 0x0314 },
  uccode=0x1FEC,
  unicodeslot=0x1FE5,
 },
 [0x1FE6]={
  category="ll",
  contextname="greekupsilonperispomeni",
  description="GREEK SMALL LETTER UPSILON WITH PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03C5, 0x0342 },
  unicodeslot=0x1FE6,
 },
 [0x1FE7]={
  category="ll",
  contextname="greekupsilondialytikaperispomeni",
  description="GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C5,
  specials={ "char", 0x03CB, 0x0342 },
  unicodeslot=0x1FE7,
 },
 [0x1FE8]={
  category="lu",
  contextname="greekUpsilonvrachy",
  description="GREEK CAPITAL LETTER UPSILON WITH VRACHY",
  direction="l",
  lccode=0x1FE0,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x03A5, 0x0306 },
  unicodeslot=0x1FE8,
 },
 [0x1FE9]={
  category="lu",
  contextname="greekUpsilonmacron",
  description="GREEK CAPITAL LETTER UPSILON WITH MACRON",
  direction="l",
  lccode=0x1FE1,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x03A5, 0x0304 },
  unicodeslot=0x1FE9,
 },
 [0x1FEA]={
  category="lu",
  contextname="greekUpsilonvaria",
  description="GREEK CAPITAL LETTER UPSILON WITH VARIA",
  direction="l",
  lccode=0x1F7A,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x03A5, 0x0300 },
  unicodeslot=0x1FEA,
 },
 [0x1FEB]={
  category="lu",
  contextname="greekUpsilontonos",
  description="GREEK CAPITAL LETTER UPSILON WITH OXIA",
  direction="l",
  lccode=0x1F7B,
  linebreak="al",
  shcode=0x03A5,
  specials={ "char", 0x038E },
  unicodeslot=0x1FEB,
 },
 [0x1FEC]={
  category="lu",
  contextname="greekRhodasia",
  description="GREEK CAPITAL LETTER RHO WITH DASIA",
  direction="l",
  lccode=0x1FE5,
  linebreak="al",
  shcode=0x03A1,
  specials={ "char", 0x03A1, 0x0314 },
  unicodeslot=0x1FEC,
 },
 [0x1FED]={
  category="sk",
  contextname="greekdialytikavaria",
  description="GREEK DIALYTIKA AND VARIA",
  direction="on",
  linebreak="al",
  specials={ "char", 0x00A8, 0x0300 },
  unicodeslot=0x1FED,
 },
 [0x1FEE]={
  category="sk",
  contextname="greekdialytikatonos",
  description="GREEK DIALYTIKA AND OXIA",
  direction="on",
  linebreak="al",
  specials={ "char", 0x0385 },
  unicodeslot=0x1FEE,
 },
 [0x1FEF]={
  category="sk",
  contextname="greekvaria",
  description="GREEK VARIA",
  direction="on",
  linebreak="al",
  specials={ "char", 0x0060 },
  unicodeslot=0x1FEF,
 },
 [0x1FF2]={
  category="ll",
  contextname="greekomegaiotasubvaria",
  description="GREEK SMALL LETTER OMEGA WITH VARIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1F7C, 0x0345 },
  unicodeslot=0x1FF2,
 },
 [0x1FF3]={
  category="ll",
  contextname="greekomegaiotasub",
  description="GREEK SMALL LETTER OMEGA WITH YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x03C9, 0x0345 },
  uccode=0x1FFC,
  unicodeslot=0x1FF3,
 },
 [0x1FF4]={
  category="ll",
  contextname="greekomegaiotasubtonos",
  description="GREEK SMALL LETTER OMEGA WITH OXIA AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x03CE, 0x0345 },
  unicodeslot=0x1FF4,
 },
 [0x1FF6]={
  category="ll",
  contextname="greekomegaperispomeni",
  description="GREEK SMALL LETTER OMEGA WITH PERISPOMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x03C9, 0x0342 },
  unicodeslot=0x1FF6,
 },
 [0x1FF7]={
  category="ll",
  contextname="greekomegaiotasubperispomeni",
  description="GREEK SMALL LETTER OMEGA WITH PERISPOMENI AND YPOGEGRAMMENI",
  direction="l",
  linebreak="al",
  shcode=0x03C9,
  specials={ "char", 0x1FF6, 0x0345 },
  unicodeslot=0x1FF7,
 },
 [0x1FF8]={
  category="lu",
  contextname="greekOmicronvaria",
  description="GREEK CAPITAL LETTER OMICRON WITH VARIA",
  direction="l",
  lccode=0x1F78,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x039F, 0x0300 },
  unicodeslot=0x1FF8,
 },
 [0x1FF9]={
  category="lu",
  contextname="greekOmicrontonos",
  description="GREEK CAPITAL LETTER OMICRON WITH OXIA",
  direction="l",
  lccode=0x1F79,
  linebreak="al",
  shcode=0x039F,
  specials={ "char", 0x038C },
  unicodeslot=0x1FF9,
 },
 [0x1FFA]={
  category="lu",
  contextname="greekOmegavaria",
  description="GREEK CAPITAL LETTER OMEGA WITH VARIA",
  direction="l",
  lccode=0x1F7C,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x03A9, 0x0300 },
  unicodeslot=0x1FFA,
 },
 [0x1FFB]={
  category="lu",
  contextname="greekOmegatonos",
  description="GREEK CAPITAL LETTER OMEGA WITH OXIA",
  direction="l",
  lccode=0x1F7D,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x038F },
  unicodeslot=0x1FFB,
 },
 [0x1FFC]={
  category="lt",
  contextname="greekOmegaiotasub",
  description="GREEK CAPITAL LETTER OMEGA WITH PROSGEGRAMMENI",
  direction="l",
  lccode=0x1FF3,
  linebreak="al",
  shcode=0x03A9,
  specials={ "char", 0x03A9, 0x0345 },
  unicodeslot=0x1FFC,
 },
 [0x1FFD]={
  category="sk",
  contextname="greekoxia",
  description="GREEK OXIA",
  direction="on",
  linebreak="bb",
  specials={ "char", 0x00B4 },
  unicodeslot=0x1FFD,
 },
 [0x1FFE]={
  category="sk",
  contextname="greekdasia",
  description="GREEK DASIA",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0020, 0x0314 },
  unicodeslot=0x1FFE,
 },
 [0x2000]={
  category="zs",
  description="EN QUAD",
  direction="ws",
  linebreak="ba",
  specials={ "char", 0x2002 },
  unicodeslot=0x2000,
 },
 [0x2001]={
  category="zs",
  description="EM QUAD",
  direction="ws",
  linebreak="ba",
  specials={ "char", 0x2003 },
  unicodeslot=0x2001,
 },
 [0x2002]={
  adobename="enspace",
  category="zs",
  contextname="enspace",
  description="EN SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x2002,
 },
 [0x2003]={
  category="zs",
  contextname="emspace",
  description="EM SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x2003,
 },
 [0x2004]={
  category="zs",
  contextname="threeperemspace",
  description="THREE-PER-EM SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x2004,
 },
 [0x2005]={
  category="zs",
  contextname="fourperemspace",
  description="FOUR-PER-EM SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x2005,
 },
 [0x2006]={
  category="zs",
  contextname="sixperemspace",
  description="SIX-PER-EM SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x2006,
 },
 [0x2007]={
  category="zs",
  contextname="figurespace",
  description="FIGURE SPACE",
  direction="ws",
  linebreak="gl",
  specials={ "nobreak", 0x0020 },
  unicodeslot=0x2007,
 },
 [0x2008]={
  category="zs",
  contextname="punctuationspace",
  description="PUNCTUATION SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x2008,
 },
 [0x2009]={
  category="zs",
  contextname="breakablethinspace",
  description="THIN SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x2009,
 },
 [0x200A]={
  category="zs",
  contextname="hairspace",
  description="HAIR SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x200A,
 },
 [0x200B]={
  adobename="zerowidthspace",
  category="cf",
  contextname="zerowidthspace",
  description="ZERO WIDTH SPACE",
  direction="bn",
  linebreak="zw",
  unicodeslot=0x200B,
 },
 [0x200C]={
  adobename="zerowidthnonjoiner",
  arabic="u",
  category="cf",
  contextname="zwnj",
  description="ZERO WIDTH NON-JOINER",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x200C,
 },
 [0x200D]={
  adobename="afii301",
  arabic="c",
  category="cf",
  contextname="zwj",
  description="ZERO WIDTH JOINER",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x200D,
 },
 [0x200E]={
  adobename="afii299",
  category="cf",
  description="LEFT-TO-RIGHT MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x200E,
 },
 [0x200F]={
  adobename="afii300",
  category="cf",
  description="RIGHT-TO-LEFT MARK",
  direction="r",
  linebreak="cm",
  unicodeslot=0x200F,
 },
 [0x2010]={
  adobename="hyphentwo",
  category="pd",
  cjkwd="a",
  description="HYPHEN",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2010,
 },
 [0x2011]={
  category="pd",
  description="NON-BREAKING HYPHEN",
  direction="on",
  linebreak="gl",
  specials={ "nobreak", 0x2010 },
  unicodeslot=0x2011,
 },
 [0x2012]={
  adobename="figuredash",
  category="pd",
  contextname="textminus",
  description="FIGURE DASH",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2012,
 },
 [0x2013]={
  adobename="endash",
  category="pd",
  cjkwd="a",
  contextname="endash",
  description="EN DASH",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2013,
 },
 [0x2014]={
  adobename="emdash",
  category="pd",
  cjkwd="a",
  contextname="emdash",
  description="EM DASH",
  direction="on",
  linebreak="b2",
  unicodeslot=0x2014,
 },
 [0x2015]={
  adobename="horizontalbar",
  category="pd",
  cjkwd="a",
  contextname="texthorizontalbar",
  description="HORIZONTAL BAR",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2015,
 },
 [0x2016]={
  adobename="dblverticalbar",
  category="po",
  cjkwd="a",
  description="DOUBLE VERTICAL LINE",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="delimiter",
    name="Vert",
   },
   {
    class="nothing",
    name="Arrowvert",
   },
   {
    class="open",
    name="lVert",
   },
   {
    class="close",
    name="rVert",
   },
  },
  unicodeslot=0x2016,
 },
 [0x2017]={
  adobename="underscoredbl",
  category="po",
  description="DOUBLE LOW LINE",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0020, 0x0333 },
  unicodeslot=0x2017,
 },
 [0x2018]={
  adobename="quoteleft",
  category="pi",
  cjkwd="a",
  contextname="quoteleft",
  description="LEFT SINGLE QUOTATION MARK",
  direction="on",
  linebreak="qu",
  unicodeslot=0x2018,
 },
 [0x2019]={
  adobename="quoteright",
  category="pf",
  cjkwd="a",
  contextname="quoteright",
  description="RIGHT SINGLE QUOTATION MARK",
  direction="on",
  linebreak="qu",
  unicodeslot=0x2019,
 },
 [0x201A]={
  adobename="quotesinglbase",
  category="ps",
  contextname="quotesinglebase",
  description="SINGLE LOW-0x0009 QUOTATION MARK",
  direction="on",
  linebreak="op",
  unicodeslot=0x201A,
 },
 [0x201B]={
  adobename="quotereversed",
  category="pi",
  description="SINGLE HIGH-REVERSED-0x0009 QUOTATION MARK",
  direction="on",
  linebreak="qu",
  unicodeslot=0x201B,
 },
 [0x201C]={
  adobename="quotedblleft",
  category="pi",
  cjkwd="a",
  contextname="quotedblleft",
  description="LEFT DOUBLE QUOTATION MARK",
  direction="on",
  linebreak="qu",
  unicodeslot=0x201C,
 },
 [0x201D]={
  adobename="quotedblright",
  category="pf",
  cjkwd="a",
  contextname="quotedblright",
  description="RIGHT DOUBLE QUOTATION MARK",
  direction="on",
  linebreak="qu",
  unicodeslot=0x201D,
 },
 [0x201E]={
  adobename="quotedblbase",
  category="ps",
  contextname="quotedblbase",
  description="DOUBLE LOW-0x0009 QUOTATION MARK",
  direction="on",
  linebreak="op",
  unicodeslot=0x201E,
 },
 [0x201F]={
  category="pi",
  description="DOUBLE HIGH-REVERSED-0x0009 QUOTATION MARK",
  direction="on",
  linebreak="qu",
  unicodeslot=0x201F,
 },
 [0x2020]={
  adobename="dagger",
  category="po",
  cjkwd="a",
  contextname="textdag",
  description="DAGGER",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="binary",
    name="dagger",
   },
   {
    class="box",
    name="dag",
   },
  },
  unicodeslot=0x2020,
 },
 [0x2021]={
  adobename="daggerdbl",
  category="po",
  cjkwd="a",
  contextname="textddag",
  description="DOUBLE DAGGER",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="binary",
    name="ddagger",
   },
   {
    class="box",
    name="ddag",
   },
  },
  unicodeslot=0x2021,
 },
 [0x2022]={
  adobename="bullet",
  category="po",
  cjkwd="a",
  contextname="textbullet",
  description="BULLET",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="bullet",
  unicodeslot=0x2022,
 },
 [0x2023]={
  category="po",
  description="TRIANGULAR BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2023,
 },
 [0x2024]={
  adobename="onedotenleader",
  category="po",
  cjkwd="a",
  description="ONE DOT LEADER",
  direction="on",
  linebreak="in",
  specials={ "compat", 0x002E },
  unicodeslot=0x2024,
 },
 [0x2025]={
  adobename="twodotleader",
  category="po",
  cjkwd="a",
  description="TWO DOT LEADER",
  direction="on",
  linebreak="in",
  specials={ "compat", 0x002E, 0x002E },
  unicodeslot=0x2025,
 },
 [0x2026]={
  adobename="ellipsis",
  category="po",
  cjkwd="a",
  contextname="textellipsis",
  description="HORIZONTAL ELLIPSIS",
  direction="on",
  linebreak="in",
  mathspec={
   {
    class="inner",
    name="ldots",
   },
   {
    class="inner",
    name="dots",
   },
  },
  specials={ "compat", 0x002E, 0x002E, 0x002E },
  unicodeslot=0x2026,
 },
 [0x2027]={
  category="po",
  cjkwd="a",
  description="HYPHENATION POINT",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2027,
 },
 [0x2028]={
  category="zl",
  description="LINE SEPARATOR",
  direction="ws",
  linebreak="bk",
  unicodeslot=0x2028,
 },
 [0x2029]={
  category="zp",
  description="PARAGRAPH SEPARATOR",
  direction="b",
  linebreak="bk",
  unicodeslot=0x2029,
 },
 [0x202A]={
  category="cf",
  description="LEFT-TO-RIGHT EMBEDDING",
  direction="lre",
  linebreak="cm",
  unicodeslot=0x202A,
 },
 [0x202B]={
  category="cf",
  description="RIGHT-TO-LEFT EMBEDDING",
  direction="rle",
  linebreak="cm",
  unicodeslot=0x202B,
 },
 [0x202C]={
  adobename="afii61573",
  category="cf",
  description="POP DIRECTIONAL FORMATTING",
  direction="pdf",
  linebreak="cm",
  unicodeslot=0x202C,
 },
 [0x202D]={
  adobename="afii61574",
  category="cf",
  description="LEFT-TO-RIGHT OVERRIDE",
  direction="lro",
  linebreak="cm",
  unicodeslot=0x202D,
 },
 [0x202E]={
  adobename="afii61575",
  category="cf",
  description="RIGHT-TO-LEFT OVERRIDE",
  direction="rlo",
  linebreak="cm",
  unicodeslot=0x202E,
 },
 [0x202F]={
  category="zs",
  contextname="narrownobreakspace",
  description="NARROW NO-BREAK SPACE",
  direction="cs",
  linebreak="gl",
  specials={ "nobreak", 0x0020 },
  unicodeslot=0x202F,
 },
 [0x2030]={
  adobename="perthousand",
  category="po",
  cjkwd="a",
  contextname="perthousand",
  description="PER MILLE SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x2030,
 },
 [0x2031]={
  category="po",
  description="PER TEN THOUSAND SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x2031,
 },
 [0x2032]={
  adobename="minute",
  category="po",
  cjkwd="a",
  description="PRIME",
  direction="et",
  linebreak="po",
  mathclass="nothing",
  mathname="prime",
  unicodeslot=0x2032,
 },
 [0x2033]={
  adobename="second",
  category="po",
  cjkwd="a",
  description="DOUBLE PRIME",
  direction="et",
  linebreak="po",
  mathclass="nothing",
  mathname="doubleprime",
  specials={ "compat", 0x2032, 0x2032 },
  unicodeslot=0x2033,
 },
 [0x2034]={
  category="po",
  description="TRIPLE PRIME",
  direction="et",
  linebreak="po",
  mathclass="nothing",
  mathname="tripleprime",
  specials={ "compat", 0x2032, 0x2032, 0x2032 },
  unicodeslot=0x2034,
 },
 [0x2035]={
  adobename="primereversed",
  category="po",
  cjkwd="a",
  description="REVERSED PRIME",
  direction="on",
  linebreak="po",
  unicodeslot=0x2035,
 },
 [0x2036]={
  category="po",
  description="REVERSED DOUBLE PRIME",
  direction="on",
  linebreak="po",
  specials={ "compat", 0x2035, 0x2035 },
  unicodeslot=0x2036,
 },
 [0x2037]={
  category="po",
  description="REVERSED TRIPLE PRIME",
  direction="on",
  linebreak="po",
  specials={ "compat", 0x2035, 0x2035, 0x2035 },
  unicodeslot=0x2037,
 },
 [0x2038]={
  category="po",
  description="CARET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2038,
 },
 [0x2039]={
  adobename="guilsinglleft",
  category="pi",
  contextname="guilsingleleft",
  description="SINGLE LEFT-POINTING ANGLE QUOTATION MARK",
  direction="on",
  linebreak="qu",
  mirror=0x203A,
  textclass="open",
  unicodeslot=0x2039,
 },
 [0x203A]={
  adobename="guilsinglright",
  category="pf",
  contextname="guilsingleright",
  description="SINGLE RIGHT-POINTING ANGLE QUOTATION MARK",
  direction="on",
  linebreak="qu",
  mirror=0x2039,
  textclass="close",
  unicodeslot=0x203A,
 },
 [0x203B]={
  adobename="referencemark",
  category="po",
  cjkwd="a",
  description="REFERENCE MARK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x203B,
 },
 [0x203C]={
  adobename="exclamdbl",
  category="po",
  description="DOUBLE EXCLAMATION MARK",
  direction="on",
  linebreak="ns",
  specials={ "compat", 0x0021, 0x0021 },
  unicodeslot=0x203C,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x203D]={
  category="po",
  description="INTERROBANG",
  direction="on",
  linebreak="ns",
  unicodeslot=0x203D,
 },
 [0x203E]={
  adobename="overline",
  category="po",
  cjkwd="a",
  comment=[[mathspec={ { class="topaccent", name="overbar" }, { class="botaccent", name="underbar" } }"]],
  description="OVERLINE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  mathfiller="barfill",
  mathspec={
   {
    class="under",
    name="underbar",
   },
   {
    class="over",
    name="overbar",
   },
  },
  mathstretch="h",
  specials={ "compat", 0x0020, 0x0305 },
  unicodeslot=0x203E,
 },
 [0x203F]={
  category="pc",
  description="UNDERTIE",
  direction="on",
  linebreak="al",
  unicodeslot=0x203F,
 },
 [0x2040]={
  category="pc",
  description="CHARACTER TIE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2040,
 },
 [0x2041]={
  category="po",
  description="CARET INSERTION POINT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2041,
 },
 [0x2042]={
  adobename="asterism",
  category="po",
  description="ASTERISM",
  direction="on",
  linebreak="al",
  unicodeslot=0x2042,
 },
 [0x2043]={
  category="po",
  description="HYPHEN BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2043,
 },
 [0x2044]={
  adobename="fraction",
  category="sm",
  contextname="textfraction",
  description="FRACTION SLASH",
  direction="cs",
  linebreak="is",
  mathspec={
   {
    class="ordinary",
    name="slash",
   },
   {
    class="close",
    name="solidus",
   },
  },
  unicodeslot=0x2044,
 },
 [0x2045]={
  category="ps",
  description="LEFT SQUARE BRACKET WITH QUILL",
  direction="on",
  linebreak="op",
  mirror=0x2046,
  unicodeslot=0x2045,
 },
 [0x2046]={
  category="pe",
  description="RIGHT SQUARE BRACKET WITH QUILL",
  direction="on",
  linebreak="cl",
  mirror=0x2045,
  unicodeslot=0x2046,
 },
 [0x2047]={
  category="po",
  description="DOUBLE QUESTION MARK",
  direction="on",
  linebreak="ns",
  specials={ "compat", 0x003F, 0x003F },
  unicodeslot=0x2047,
 },
 [0x2048]={
  category="po",
  description="QUESTION EXCLAMATION MARK",
  direction="on",
  linebreak="ns",
  specials={ "compat", 0x003F, 0x0021 },
  unicodeslot=0x2048,
 },
 [0x2049]={
  category="po",
  description="EXCLAMATION QUESTION MARK",
  direction="on",
  linebreak="ns",
  specials={ "compat", 0x0021, 0x003F },
  unicodeslot=0x2049,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x204A]={
  category="po",
  description="TIRONIAN SIGN ET",
  direction="on",
  linebreak="al",
  unicodeslot=0x204A,
 },
 [0x204B]={
  category="po",
  description="REVERSED PILCROW SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x204B,
 },
 [0x204C]={
  category="po",
  description="BLACK LEFTWARDS BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x204C,
 },
 [0x204D]={
  category="po",
  description="BLACK RIGHTWARDS BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x204D,
 },
 [0x204E]={
  category="po",
  description="LOW ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x204E,
 },
 [0x204F]={
  category="po",
  description="REVERSED SEMICOLON",
  direction="on",
  linebreak="al",
  unicodeslot=0x204F,
 },
 [0x2050]={
  category="po",
  description="CLOSE UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x2050,
 },
 [0x2051]={
  category="po",
  description="TWO ASTERISKS ALIGNED VERTICALLY",
  direction="on",
  linebreak="al",
  unicodeslot=0x2051,
 },
 [0x2052]={
  category="sm",
  description="COMMERCIAL MINUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2052,
 },
 [0x2053]={
  category="po",
  description="SWUNG DASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2053,
 },
 [0x2054]={
  category="pc",
  description="INVERTED UNDERTIE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2054,
 },
 [0x2055]={
  category="po",
  description="FLOWER PUNCTUATION MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2055,
 },
 [0x2056]={
  category="po",
  description="THREE DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2056,
 },
 [0x2057]={
  category="po",
  description="QUADRUPLE PRIME",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x2032, 0x2032, 0x2032, 0x2032 },
  unicodeslot=0x2057,
 },
 [0x2058]={
  category="po",
  description="FOUR DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2058,
 },
 [0x2059]={
  category="po",
  description="FIVE DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2059,
 },
 [0x205A]={
  category="po",
  description="TWO DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x205A,
 },
 [0x205B]={
  category="po",
  description="FOUR DOT MARK",
  direction="on",
  linebreak="ba",
  unicodeslot=0x205B,
 },
 [0x205C]={
  category="po",
  description="DOTTED CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x205C,
 },
 [0x205D]={
  category="po",
  description="TRICOLON",
  direction="on",
  linebreak="ba",
  unicodeslot=0x205D,
 },
 [0x205E]={
  category="po",
  description="VERTICAL FOUR DOTS",
  direction="on",
  linebreak="ba",
  unicodeslot=0x205E,
 },
 [0x205F]={
  category="zs",
  contextname="medspace",
  description="MEDIUM MATHEMATICAL SPACE",
  direction="ws",
  linebreak="ba",
  specials={ "compat", 0x0020 },
  unicodeslot=0x205F,
 },
 [0x2060]={
  category="cf",
  description="WORD JOINER",
  direction="bn",
  linebreak="wj",
  unicodeslot=0x2060,
 },
 [0x2061]={
  category="cf",
  comment="maybe: nulloperator",
  contextname="relax",
  description="FUNCTION APPLICATION",
  direction="bn",
  linebreak="al",
  unicodeslot=0x2061,
 },
 [0x2062]={
  category="cf",
  description="INVISIBLE TIMES",
  direction="bn",
  linebreak="al",
  unicodeslot=0x2062,
 },
 [0x2063]={
  category="cf",
  description="INVISIBLE SEPARATOR",
  direction="bn",
  linebreak="al",
  unicodeslot=0x2063,
 },
 [0x2064]={
  category="cf",
  description="INVISIBLE PLUS",
  direction="bn",
  linebreak="al",
  unicodeslot=0x2064,
 },
 [0x206A]={
  category="cf",
  description="INHIBIT SYMMETRIC SWAPPING",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x206A,
 },
 [0x206B]={
  category="cf",
  description="ACTIVATE SYMMETRIC SWAPPING",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x206B,
 },
 [0x206C]={
  category="cf",
  description="INHIBIT ARABIC FORM SHAPING",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x206C,
 },
 [0x206D]={
  category="cf",
  description="ACTIVATE ARABIC FORM SHAPING",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x206D,
 },
 [0x206E]={
  category="cf",
  description="NATIONAL DIGIT SHAPES",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x206E,
 },
 [0x206F]={
  category="cf",
  description="NOMINAL DIGIT SHAPES",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x206F,
 },
 [0x2070]={
  adobename="zerosuperior",
  category="no",
  description="SUPERSCRIPT ZERO",
  direction="en",
  linebreak="al",
  specials={ "super", 0x0030 },
  unicodeslot=0x2070,
 },
 [0x2071]={
  category="ll",
  description="SUPERSCRIPT LATIN SMALL LETTER I",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0069 },
  unicodeslot=0x2071,
 },
 [0x2074]={
  adobename="foursuperior",
  category="no",
  cjkwd="a",
  description="SUPERSCRIPT FOUR",
  direction="en",
  linebreak="ai",
  specials={ "super", 0x0034 },
  unicodeslot=0x2074,
 },
 [0x2075]={
  adobename="fivesuperior",
  category="no",
  description="SUPERSCRIPT FIVE",
  direction="en",
  linebreak="al",
  specials={ "super", 0x0035 },
  unicodeslot=0x2075,
 },
 [0x2076]={
  adobename="sixsuperior",
  category="no",
  description="SUPERSCRIPT SIX",
  direction="en",
  linebreak="al",
  specials={ "super", 0x0036 },
  unicodeslot=0x2076,
 },
 [0x2077]={
  adobename="sevensuperior",
  category="no",
  description="SUPERSCRIPT SEVEN",
  direction="en",
  linebreak="al",
  specials={ "super", 0x0037 },
  unicodeslot=0x2077,
 },
 [0x2078]={
  adobename="eightsuperior",
  category="no",
  description="SUPERSCRIPT EIGHT",
  direction="en",
  linebreak="al",
  specials={ "super", 0x0038 },
  unicodeslot=0x2078,
 },
 [0x2079]={
  adobename="ninesuperior",
  category="no",
  description="SUPERSCRIPT NINE",
  direction="en",
  linebreak="al",
  specials={ "super", 0x0039 },
  unicodeslot=0x2079,
 },
 [0x207A]={
  adobename="plussuperior",
  category="sm",
  description="SUPERSCRIPT PLUS SIGN",
  direction="es",
  linebreak="al",
  mathclass="binary",
  mathname="positivesign",
  specials={ "super", 0x002B },
  unicodeslot=0x207A,
 },
 [0x207B]={
  category="sm",
  description="SUPERSCRIPT MINUS",
  direction="es",
  linebreak="al",
  mathclass="binary",
  mathname="negativesign",
  specials={ "super", 0x2212 },
  unicodeslot=0x207B,
 },
 [0x207C]={
  adobename="equalsuperior",
  category="sm",
  description="SUPERSCRIPT EQUALS SIGN",
  direction="on",
  linebreak="al",
  specials={ "super", 0x003D },
  unicodeslot=0x207C,
 },
 [0x207D]={
  adobename="parenleftsuperior",
  category="ps",
  description="SUPERSCRIPT LEFT PARENTHESIS",
  direction="on",
  linebreak="op",
  mirror=0x207E,
  textclass="open",
  specials={ "super", 0x0028 },
  unicodeslot=0x207D,
 },
 [0x207E]={
  adobename="parenrightsuperior",
  category="pe",
  description="SUPERSCRIPT RIGHT PARENTHESIS",
  direction="on",
  linebreak="cl",
  mirror=0x207D,
  textclass="close",
  specials={ "super", 0x0029 },
  unicodeslot=0x207E,
 },
 [0x207F]={
  adobename="nsuperior",
  category="ll",
  cjkwd="a",
  description="SUPERSCRIPT LATIN SMALL LETTER N",
  direction="l",
  linebreak="ai",
  specials={ "super", 0x006E },
  unicodeslot=0x207F,
 },
 [0x2080]={
  adobename="zeroinferior",
  category="no",
  description="SUBSCRIPT ZERO",
  direction="en",
  linebreak="al",
  specials={ "sub", 0x0030 },
  unicodeslot=0x2080,
 },
 [0x2081]={
  adobename="oneinferior",
  category="no",
  cjkwd="a",
  description="SUBSCRIPT ONE",
  direction="en",
  linebreak="ai",
  specials={ "sub", 0x0031 },
  unicodeslot=0x2081,
 },
 [0x2082]={
  adobename="twoinferior",
  category="no",
  cjkwd="a",
  description="SUBSCRIPT TWO",
  direction="en",
  linebreak="ai",
  specials={ "sub", 0x0032 },
  unicodeslot=0x2082,
 },
 [0x2083]={
  adobename="threeinferior",
  category="no",
  cjkwd="a",
  description="SUBSCRIPT THREE",
  direction="en",
  linebreak="ai",
  specials={ "sub", 0x0033 },
  unicodeslot=0x2083,
 },
 [0x2084]={
  adobename="fourinferior",
  category="no",
  cjkwd="a",
  description="SUBSCRIPT FOUR",
  direction="en",
  linebreak="ai",
  specials={ "sub", 0x0034 },
  unicodeslot=0x2084,
 },
 [0x2085]={
  adobename="fiveinferior",
  category="no",
  description="SUBSCRIPT FIVE",
  direction="en",
  linebreak="al",
  specials={ "sub", 0x0035 },
  unicodeslot=0x2085,
 },
 [0x2086]={
  adobename="sixinferior",
  category="no",
  description="SUBSCRIPT SIX",
  direction="en",
  linebreak="al",
  specials={ "sub", 0x0036 },
  unicodeslot=0x2086,
 },
 [0x2087]={
  adobename="seveninferior",
  category="no",
  description="SUBSCRIPT SEVEN",
  direction="en",
  linebreak="al",
  specials={ "sub", 0x0037 },
  unicodeslot=0x2087,
 },
 [0x2088]={
  adobename="eightinferior",
  category="no",
  description="SUBSCRIPT EIGHT",
  direction="en",
  linebreak="al",
  specials={ "sub", 0x0038 },
  unicodeslot=0x2088,
 },
 [0x2089]={
  adobename="nineinferior",
  category="no",
  description="SUBSCRIPT NINE",
  direction="en",
  linebreak="al",
  specials={ "sub", 0x0039 },
  unicodeslot=0x2089,
 },
 [0x208A]={
  category="sm",
  description="SUBSCRIPT PLUS SIGN",
  direction="es",
  linebreak="al",
  specials={ "sub", 0x002B },
  unicodeslot=0x208A,
 },
 [0x208B]={
  category="sm",
  description="SUBSCRIPT MINUS",
  direction="es",
  linebreak="al",
  specials={ "sub", 0x2212 },
  unicodeslot=0x208B,
 },
 [0x208C]={
  category="sm",
  description="SUBSCRIPT EQUALS SIGN",
  direction="on",
  linebreak="al",
  specials={ "sub", 0x003D },
  unicodeslot=0x208C,
 },
 [0x208D]={
  adobename="parenleftinferior",
  category="ps",
  description="SUBSCRIPT LEFT PARENTHESIS",
  direction="on",
  linebreak="op",
  mirror=0x208E,
  textclass="open",
  specials={ "sub", 0x0028 },
  unicodeslot=0x208D,
 },
 [0x208E]={
  adobename="parenrightinferior",
  category="pe",
  description="SUBSCRIPT RIGHT PARENTHESIS",
  direction="on",
  linebreak="cl",
  mirror=0x208D,
  textclass="close",
  specials={ "sub", 0x0029 },
  unicodeslot=0x208E,
 },
 [0x2090]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER A",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0061 },
  unicodeslot=0x2090,
 },
 [0x2091]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER E",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0065 },
  unicodeslot=0x2091,
 },
 [0x2092]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER O",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x006F },
  unicodeslot=0x2092,
 },
 [0x2093]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER X",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0078 },
  unicodeslot=0x2093,
 },
 [0x2094]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER SCHWA",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0259 },
  unicodeslot=0x2094,
 },
 [0x2095]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER H",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0068 },
  unicodeslot=0x2095,
 },
 [0x2096]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER K",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x006B },
  unicodeslot=0x2096,
 },
 [0x2097]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER L",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x006C },
  unicodeslot=0x2097,
 },
 [0x2098]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER M",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x006D },
  unicodeslot=0x2098,
 },
 [0x2099]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER N",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x006E },
  unicodeslot=0x2099,
 },
 [0x209A]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER P",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0070 },
  unicodeslot=0x209A,
 },
 [0x209B]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER S",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0073 },
  unicodeslot=0x209B,
 },
 [0x209C]={
  category="lm",
  description="LATIN SUBSCRIPT SMALL LETTER T",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x0074 },
  unicodeslot=0x209C,
 },
 [0x20A0]={
  category="sc",
  description="EURO-CURRENCY SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20A0,
 },
 [0x20A1]={
  adobename="colonsign",
  category="sc",
  description="COLON SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20A1,
 },
 [0x20A2]={
  adobename="cruzeiro",
  category="sc",
  description="CRUZEIRO SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20A2,
 },
 [0x20A3]={
  adobename="franc",
  category="sc",
  description="FRENCH FRANC SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20A3,
 },
 [0x20A4]={
  adobename="lira",
  category="sc",
  description="LIRA SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20A4,
 },
 [0x20A5]={
  category="sc",
  description="MILL SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20A5,
 },
 [0x20A6]={
  category="sc",
  description="NAIRA SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20A6,
 },
 [0x20A7]={
  adobename="peseta",
  category="sc",
  description="PESETA SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x20A7,
 },
 [0x20A8]={
  category="sc",
  description="RUPEE SIGN",
  direction="et",
  linebreak="pr",
  specials={ "compat", 0x0052, 0x0073 },
  unicodeslot=0x20A8,
 },
 [0x20A9]={
  adobename="won",
  category="sc",
  cjkwd="h",
  description="WON SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20A9,
 },
 [0x20AA]={
  adobename="sheqelhebrew",
  category="sc",
  description="NEW SHEQEL SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20AA,
 },
 [0x20AB]={
  adobename="dong",
  category="sc",
  contextname="textdong",
  description="DONG SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20AB,
 },
 [0x20AC]={
  adobename="euro",
  category="sc",
  cjkwd="a",
  contextname="texteuro",
  description="EURO SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20AC,
 },
 [0x20AD]={
  category="sc",
  description="KIP SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20AD,
 },
 [0x20AE]={
  category="sc",
  description="TUGRIK SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20AE,
 },
 [0x20AF]={
  category="sc",
  description="DRACHMA SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20AF,
 },
 [0x20B0]={
  category="sc",
  description="GERMAN PENNY SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B0,
 },
 [0x20B1]={
  category="sc",
  description="PESO SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B1,
 },
 [0x20B2]={
  category="sc",
  description="GUARANI SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B2,
 },
 [0x20B3]={
  category="sc",
  description="AUSTRAL SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B3,
 },
 [0x20B4]={
  category="sc",
  description="HRYVNIA SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B4,
 },
 [0x20B5]={
  category="sc",
  description="CEDI SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B5,
 },
 [0x20B6]={
  category="sc",
  description="LIVRE TOURNOIS SIGN",
  direction="et",
  linebreak="po",
  unicodeslot=0x20B6,
 },
 [0x20B7]={
  category="sc",
  description="SPESMILO SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B7,
 },
 [0x20B8]={
  category="sc",
  description="TENGE SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B8,
 },
 [0x20B9]={
  category="sc",
  description="INDIAN RUPEE SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20B9,
 },
 [0x20BA]={
  category="sc",
  description="TURKISH LIRA SIGN",
  direction="et",
  linebreak="pr",
  unicodeslot=0x20BA,
 },
 [0x20D0]={
  category="mn",
  description="COMBINING LEFT HARPOON ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D0,
 },
 [0x20D1]={
  category="mn",
  description="COMBINING RIGHT HARPOON ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D1,
 },
 [0x20D2]={
  category="mn",
  description="COMBINING LONG VERTICAL LINE OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D2,
 },
 [0x20D3]={
  category="mn",
  description="COMBINING SHORT VERTICAL LINE OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D3,
 },
 [0x20D4]={
  category="mn",
  description="COMBINING ANTICLOCKWISE ARROW ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D4,
 },
 [0x20D5]={
  category="mn",
  description="COMBINING CLOCKWISE ARROW ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D5,
 },
 [0x20D6]={
  category="mn",
  description="COMBINING LEFT ARROW ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D6,
 },
 [0x20D7]={
  category="mn",
  description="COMBINING RIGHT ARROW ABOVE",
  direction="nsm",
  linebreak="cm",
  mathclass="topaccent",
  mathname="vec",
  unicodeslot=0x20D7,
 },
 [0x20D8]={
  category="mn",
  description="COMBINING RING OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D8,
 },
 [0x20D9]={
  category="mn",
  description="COMBINING CLOCKWISE RING OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20D9,
 },
 [0x20DA]={
  category="mn",
  description="COMBINING ANTICLOCKWISE RING OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20DA,
 },
 [0x20DB]={
  category="mn",
  description="COMBINING THREE DOTS ABOVE",
  direction="nsm",
  linebreak="cm",
  mathclass="topaccent",
  mathname="dddot",
  unicodeslot=0x20DB,
 },
 [0x20DC]={
  category="mn",
  description="COMBINING FOUR DOTS ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20DC,
 },
 [0x20DD]={
  category="me",
  description="COMBINING ENCLOSING CIRCLE",
  direction="nsm",
  linebreak="cm",
  mathspec={
   {
    class="default",
    name="bigcircle",
   },
   {
    class="binary",
    name="bigcircle",
   },
  },
  unicodeslot=0x20DD,
 },
 [0x20DE]={
  category="me",
  description="COMBINING ENCLOSING SQUARE",
  direction="nsm",
  linebreak="cm",
  mathclass="default",
  mathname="bigsquare",
  unicodeslot=0x20DE,
 },
 [0x20DF]={
  category="me",
  description="COMBINING ENCLOSING DIAMOND",
  direction="nsm",
  linebreak="cm",
  mathclass="default",
  mathname="bigdiamond",
  unicodeslot=0x20DF,
 },
 [0x20E0]={
  category="me",
  description="COMBINING ENCLOSING CIRCLE BACKSLASH",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E0,
 },
 [0x20E1]={
  category="mn",
  description="COMBINING LEFT RIGHT ARROW ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E1,
 },
 [0x20E2]={
  category="me",
  description="COMBINING ENCLOSING SCREEN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E2,
 },
 [0x20E3]={
  category="me",
  description="COMBINING ENCLOSING KEYCAP",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E3,
 },
 [0x20E4]={
  category="me",
  description="COMBINING ENCLOSING UPWARD POINTING TRIANGLE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E4,
 },
 [0x20E5]={
  category="mn",
  description="COMBINING REVERSE SOLIDUS OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E5,
 },
 [0x20E6]={
  category="mn",
  description="COMBINING DOUBLE VERTICAL STROKE OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E6,
 },
 [0x20E7]={
  category="mn",
  description="COMBINING ANNUITY SYMBOL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E7,
 },
 [0x20E8]={
  category="mn",
  description="COMBINING TRIPLE UNDERDOT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20E8,
 },
 [0x20E9]={
  category="mn",
  description="COMBINING WIDE BRIDGE ABOVE",
  direction="nsm",
  linebreak="cm",
  mathclass="topaccent",
  unicodeslot=0x20E9,
 },
 [0x20EA]={
  category="mn",
  description="COMBINING LEFTWARDS ARROW OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20EA,
 },
 [0x20EB]={
  category="mn",
  description="COMBINING LONG DOUBLE SOLIDUS OVERLAY",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20EB,
 },
 [0x20EC]={
  category="mn",
  description="COMBINING RIGHTWARDS HARPOON WITH BARB DOWNWARDS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20EC,
 },
 [0x20ED]={
  category="mn",
  description="COMBINING LEFTWARDS HARPOON WITH BARB DOWNWARDS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20ED,
 },
 [0x20EE]={
  category="mn",
  description="COMBINING LEFT ARROW BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20EE,
 },
 [0x20EF]={
  category="mn",
  description="COMBINING RIGHT ARROW BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20EF,
 },
 [0x20F0]={
  category="mn",
  description="COMBINING ASTERISK ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x20F0,
 },
 [0x2100]={
  category="so",
  description="ACCOUNT OF",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0061, 0x002F, 0x0063 },
  unicodeslot=0x2100,
 },
 [0x2101]={
  category="so",
  description="ADDRESSED TO THE SUBJECT",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0061, 0x002F, 0x0073 },
  unicodeslot=0x2101,
 },
 [0x2102]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL C",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="complexes",
  specials={ "font", 0x0043 },
  unicodeslot=0x2102,
 },
 [0x2103]={
  adobename="centigrade",
  category="so",
  cjkwd="a",
  contextname="textcelsius",
  description="DEGREE CELSIUS",
  direction="on",
  linebreak="po",
  specials={ "compat", 0x00B0, 0x0043 },
  unicodeslot=0x2103,
 },
 [0x2104]={
  category="so",
  description="CENTRE LINE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2104,
 },
 [0x2105]={
  adobename="careof",
  category="so",
  cjkwd="a",
  description="CARE OF",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0063, 0x002F, 0x006F },
  unicodeslot=0x2105,
 },
 [0x2106]={
  category="so",
  description="CADA UNA",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0063, 0x002F, 0x0075 },
  unicodeslot=0x2106,
 },
 [0x2107]={
  category="lu",
  description="EULER CONSTANT",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="Eulerconst",
  specials={ "compat", 0x0190 },
  unicodeslot=0x2107,
 },
 [0x2108]={
  category="so",
  description="SCRUPLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2108,
 },
 [0x2109]={
  adobename="fahrenheit",
  category="so",
  cjkwd="a",
  description="DEGREE FAHRENHEIT",
  direction="on",
  linebreak="po",
  specials={ "compat", 0x00B0, 0x0046 },
  unicodeslot=0x2109,
 },
 [0x210A]={
  category="ll",
  description="SCRIPT SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x210A,
 },
 [0x210B]={
  category="lu",
  description="SCRIPT CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x210B,
 },
 [0x210C]={
  category="lu",
  description="BLACK-LETTER CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x210C,
 },
 [0x210D]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x210D,
 },
 [0x210E]={
  category="ll",
  description="PLANCK CONSTANT",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="Plankconst",
  specials={ "font", 0x0068 },
  unicodeslot=0x210E,
 },
 [0x210F]={
  category="ll",
  description="PLANCK CONSTANT OVER TWO PI",
  direction="l",
  linebreak="al",
  mathspec={
   {
    class="variable",
    name="hslash",
   },
   {
    class="ordinary",
    name="hbar",
   },
  },
  specials={ "font", 0x0127 },
  unicodeslot=0x210F,
 },
 [0x2110]={
  category="lu",
  description="SCRIPT CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x2110,
 },
 [0x2111]={
  adobename="Ifraktur",
  category="lu",
  description="BLACK-LETTER CAPITAL I",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="Im",
  specials={ "font", 0x0049 },
  unicodeslot=0x2111,
 },
 [0x2112]={
  category="lu",
  description="SCRIPT CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x2112,
 },
 [0x2113]={
  adobename="lsquare",
  category="ll",
  cjkwd="a",
  description="SCRIPT SMALL L",
  direction="l",
  linebreak="ai",
  mathclass="default",
  mathname="ell",
  specials={ "font", 0x006C },
  unicodeslot=0x2113,
 },
 [0x2114]={
  category="so",
  description="L B BAR SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2114,
 },
 [0x2115]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL N",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="naturalnumbers",
  specials={ "font", 0x004E },
  unicodeslot=0x2115,
 },
 [0x2116]={
  adobename="numero",
  category="so",
  cjkwd="a",
  contextname="textnumero",
  description="NUMERO SIGN",
  direction="on",
  linebreak="pr",
  specials={ "compat", 0x004E, 0x006F },
  unicodeslot=0x2116,
 },
 [0x2117]={
  category="so",
  contextname="textcircledP",
  description="SOUND RECORDING COPYRIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2117,
 },
 [0x2118]={
  adobename="weierstrass",
  category="so",
  description="SCRIPT CAPITAL P",
  direction="on",
  linebreak="al",
  mathclass="default",
  mathname="wp",
  unicodeslot=0x2118,
 },
 [0x2119]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL P",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="primes",
  specials={ "font", 0x0050 },
  unicodeslot=0x2119,
 },
 [0x211A]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL Q",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="rationals",
  specials={ "font", 0x0051 },
  unicodeslot=0x211A,
 },
 [0x211B]={
  category="lu",
  description="SCRIPT CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x211B,
 },
 [0x211C]={
  adobename="Rfraktur",
  category="lu",
  description="BLACK-LETTER CAPITAL R",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="Re",
  specials={ "font", 0x0052 },
  unicodeslot=0x211C,
 },
 [0x211D]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL R",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="reals",
  specials={ "font", 0x0052 },
  unicodeslot=0x211D,
 },
 [0x211E]={
  adobename="prescription",
  category="so",
  description="PRESCRIPTION TAKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x211E,
 },
 [0x211F]={
  category="so",
  description="RESPONSE",
  direction="on",
  linebreak="al",
  unicodeslot=0x211F,
 },
 [0x2120]={
  category="so",
  description="SERVICE MARK",
  direction="on",
  linebreak="al",
  specials={ "super", 0x0053, 0x004D },
  unicodeslot=0x2120,
 },
 [0x2121]={
  adobename="telephone",
  category="so",
  cjkwd="a",
  description="TELEPHONE SIGN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0054, 0x0045, 0x004C },
  unicodeslot=0x2121,
 },
 [0x2122]={
  adobename="trademark",
  category="so",
  cjkwd="a",
  contextname="trademark",
  description="TRADE MARK SIGN",
  direction="on",
  linebreak="ai",
  specials={ "super", 0x0054, 0x004D },
  unicodeslot=0x2122,
 },
 [0x2123]={
  category="so",
  description="VERSICLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2123,
 },
 [0x2124]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL Z",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="integers",
  specials={ "font", 0x005A },
  unicodeslot=0x2124,
 },
 [0x2125]={
  category="so",
  contextname="textounce",
  description="OUNCE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2125,
 },
 [0x2126]={
  adobename="Omega",
  category="lu",
  cjkwd="a",
  contextname="textohm",
  description="OHM SIGN",
  direction="l",
  lccode=0x03C9,
  linebreak="al",
  mathclass="variable",
  mathname="ohm",
  specials={ "char", 0x03A9 },
  unicodeslot=0x2126,
 },
 [0x2127]={
  category="so",
  contextname="textmho",
  description="INVERTED OHM SIGN",
  direction="on",
  linebreak="al",
  mathclass="variable",
  mathname="mho",
  unicodeslot=0x2127,
 },
 [0x2128]={
  category="lu",
  description="BLACK-LETTER CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x2128,
 },
 [0x2129]={
  category="so",
  description="TURNED GREEK SMALL LETTER IOTA",
  direction="on",
  linebreak="al",
  mathclass="variable",
  mathname="turnediota",
  unicodeslot=0x2129,
 },
 [0x212A]={
  category="lu",
  contextname="textkelvin",
  description="KELVIN SIGN",
  direction="l",
  lccode=0x006B,
  linebreak="al",
  specials={ "char", 0x004B },
  unicodeslot=0x212A,
 },
 [0x212B]={
  adobename="angstrom",
  category="lu",
  cjkwd="a",
  contextname="textAngstrom",
  description="ANGSTROM SIGN",
  direction="l",
  lccode=0x00E5,
  linebreak="ai",
  mathclass="variable",
  mathname="Angstrom",
  specials={ "char", 0x00C5 },
  unicodeslot=0x212B,
 },
 [0x212C]={
  category="lu",
  description="SCRIPT CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x212C,
 },
 [0x212D]={
  category="lu",
  description="BLACK-LETTER CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x212D,
 },
 [0x212E]={
  adobename="estimated",
  category="so",
  description="ESTIMATED SYMBOL",
  direction="et",
  linebreak="al",
  unicodeslot=0x212E,
 },
 [0x212F]={
  category="ll",
  description="SCRIPT SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x212F,
 },
 [0x2130]={
  category="lu",
  description="SCRIPT CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x2130,
 },
 [0x2131]={
  category="lu",
  description="SCRIPT CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x2131,
 },
 [0x2132]={
  category="lu",
  description="TURNED CAPITAL F",
  direction="l",
  lccode=0x214E,
  linebreak="al",
  mathclass="ordinary",
  mathname="Finv",
  unicodeslot=0x2132,
 },
 [0x2133]={
  category="lu",
  description="SCRIPT CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x2133,
 },
 [0x2134]={
  category="ll",
  description="SCRIPT SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x2134,
 },
 [0x2135]={
  adobename="aleph",
  category="lo",
  description="ALEF SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="aleph",
  specials={ "compat", 0x05D0 },
  unicodeslot=0x2135,
 },
 [0x2136]={
  category="lo",
  description="BET SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="beth",
  specials={ "compat", 0x05D1 },
  unicodeslot=0x2136,
 },
 [0x2137]={
  category="lo",
  description="GIMEL SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="gimel",
  specials={ "compat", 0x05D2 },
  unicodeslot=0x2137,
 },
 [0x2138]={
  category="lo",
  description="DALET SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="daleth",
  specials={ "compat", 0x05D3 },
  unicodeslot=0x2138,
 },
 [0x2139]={
  category="ll",
  description="INFORMATION SOURCE",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x2139,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x213A]={
  category="so",
  description="ROTATED CAPITAL Q",
  direction="on",
  linebreak="al",
  unicodeslot=0x213A,
 },
 [0x213B]={
  category="so",
  description="FACSIMILE SIGN",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x0046, 0x0041, 0x0058 },
  unicodeslot=0x213B,
 },
 [0x213C]={
  category="ll",
  description="DOUBLE-STRUCK SMALL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C0 },
  unicodeslot=0x213C,
 },
 [0x213D]={
  category="ll",
  description="DOUBLE-STRUCK SMALL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B3 },
  unicodeslot=0x213D,
 },
 [0x213E]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0393 },
  unicodeslot=0x213E,
 },
 [0x213F]={
  category="lu",
  description="DOUBLE-STRUCK CAPITAL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A0 },
  unicodeslot=0x213F,
 },
 [0x2140]={
  category="sm",
  description="DOUBLE-STRUCK N-ARY SUMMATION",
  direction="on",
  linebreak="al",
  specials={ "font", 0x2211 },
  unicodeslot=0x2140,
 },
 [0x2141]={
  category="sm",
  description="TURNED SANS-SERIF CAPITAL G",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="Game",
  unicodeslot=0x2141,
 },
 [0x2142]={
  category="sm",
  comment="mathname=sansLturned",
  description="TURNED SANS-SERIF CAPITAL L",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  unicodeslot=0x2142,
 },
 [0x2143]={
  category="sm",
  comment="mathname=sansLmirrored",
  description="REVERSED SANS-SERIF CAPITAL L",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  unicodeslot=0x2143,
 },
 [0x2144]={
  category="sm",
  comment="mathname=Yup",
  description="TURNED SANS-SERIF CAPITAL Y",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  unicodeslot=0x2144,
 },
 [0x2145]={
  category="lu",
  description="DOUBLE-STRUCK ITALIC CAPITAL D",
  direction="l",
  linebreak="al",
  mathclass="nothing",
  mathname="differentialD",
  specials={ "font", 0x0044 },
  unicodeslot=0x2145,
 },
 [0x2146]={
  category="ll",
  description="DOUBLE-STRUCK ITALIC SMALL D",
  direction="l",
  linebreak="al",
  mathclass="nothing",
  mathname="differentiald",
  specials={ "font", 0x0064 },
  unicodeslot=0x2146,
 },
 [0x2147]={
  category="ll",
  description="DOUBLE-STRUCK ITALIC SMALL E",
  direction="l",
  linebreak="al",
  mathclass="nothing",
  mathname="exponentiale",
  specials={ "font", 0x0065 },
  unicodeslot=0x2147,
 },
 [0x2148]={
  category="ll",
  description="DOUBLE-STRUCK ITALIC SMALL I",
  direction="l",
  linebreak="al",
  mathclass="nothing",
  mathname="imaginaryi",
  specials={ "font", 0x0069 },
  unicodeslot=0x2148,
 },
 [0x2149]={
  category="ll",
  description="DOUBLE-STRUCK ITALIC SMALL J",
  direction="l",
  linebreak="al",
  mathclass="nothing",
  mathname="imaginaryj",
  specials={ "font", 0x006A },
  unicodeslot=0x2149,
 },
 [0x214A]={
  category="so",
  description="PROPERTY LINE",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="PropertyLine",
  unicodeslot=0x214A,
 },
 [0x214B]={
  category="sm",
  description="TURNED AMPERSAND",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="upand",
  unicodeslot=0x214B,
 },
 [0x214C]={
  category="so",
  description="PER SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x214C,
 },
 [0x214D]={
  category="so",
  description="AKTIESELSKAB",
  direction="on",
  linebreak="al",
  unicodeslot=0x214D,
 },
 [0x214E]={
  category="ll",
  description="TURNED SMALL F",
  direction="l",
  linebreak="al",
  uccode=0x2132,
  unicodeslot=0x214E,
 },
 [0x214F]={
  category="so",
  description="SYMBOL FOR SAMARITAN SOURCE",
  direction="l",
  linebreak="al",
  unicodeslot=0x214F,
 },
 [0x2150]={
  category="no",
  description="VULGAR FRACTION ONE SEVENTH",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0031, 0x2044, 0x0037 },
  unicodeslot=0x2150,
 },
 [0x2151]={
  category="no",
  description="VULGAR FRACTION ONE NINTH",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0031, 0x2044, 0x0039 },
  unicodeslot=0x2151,
 },
 [0x2152]={
  category="no",
  description="VULGAR FRACTION ONE TENTH",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0031, 0x2044, 0x0031, 0x0030 },
  unicodeslot=0x2152,
 },
 [0x2153]={
  adobename="onethird",
  category="no",
  cjkwd="a",
  contextname="onethird",
  description="VULGAR FRACTION ONE THIRD",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0031, 0x2044, 0x0033 },
  unicodeslot=0x2153,
 },
 [0x2154]={
  adobename="twothirds",
  category="no",
  cjkwd="a",
  contextname="twothirds",
  description="VULGAR FRACTION TWO THIRDS",
  direction="on",
  linebreak="ai",
  specials={ "fraction", 0x0032, 0x2044, 0x0033 },
  unicodeslot=0x2154,
 },
 [0x2155]={
  category="no",
  contextname="onefifth",
  description="VULGAR FRACTION ONE FIFTH",
  direction="on",
  linebreak="ai",
  specials={ "fraction", 0x0031, 0x2044, 0x0035 },
  unicodeslot=0x2155,
 },
 [0x2156]={
  category="no",
  contextname="twofifths",
  description="VULGAR FRACTION TWO FIFTHS",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0032, 0x2044, 0x0035 },
  unicodeslot=0x2156,
 },
 [0x2157]={
  category="no",
  contextname="threefifths",
  description="VULGAR FRACTION THREE FIFTHS",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0033, 0x2044, 0x0035 },
  unicodeslot=0x2157,
 },
 [0x2158]={
  category="no",
  contextname="fourfifths",
  description="VULGAR FRACTION FOUR FIFTHS",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0034, 0x2044, 0x0035 },
  unicodeslot=0x2158,
 },
 [0x2159]={
  category="no",
  contextname="onesixth",
  description="VULGAR FRACTION ONE SIXTH",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0031, 0x2044, 0x0036 },
  unicodeslot=0x2159,
 },
 [0x215A]={
  category="no",
  contextname="fivesixths",
  description="VULGAR FRACTION FIVE SIXTHS",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0035, 0x2044, 0x0036 },
  unicodeslot=0x215A,
 },
 [0x215B]={
  adobename="oneeighth",
  category="no",
  cjkwd="a",
  contextname="oneeighth",
  description="VULGAR FRACTION ONE EIGHTH",
  direction="on",
  linebreak="ai",
  specials={ "fraction", 0x0031, 0x2044, 0x0038 },
  unicodeslot=0x215B,
 },
 [0x215C]={
  adobename="threeeighths",
  category="no",
  cjkwd="a",
  contextname="threeeighths",
  description="VULGAR FRACTION THREE EIGHTHS",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0033, 0x2044, 0x0038 },
  unicodeslot=0x215C,
 },
 [0x215D]={
  adobename="fiveeighths",
  category="no",
  cjkwd="a",
  contextname="fiveeighths",
  description="VULGAR FRACTION FIVE EIGHTHS",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0035, 0x2044, 0x0038 },
  unicodeslot=0x215D,
 },
 [0x215E]={
  adobename="seveneighths",
  category="no",
  cjkwd="a",
  contextname="seveneighths",
  description="VULGAR FRACTION SEVEN EIGHTHS",
  direction="on",
  linebreak="ai",
  specials={ "fraction", 0x0037, 0x2044, 0x0038 },
  unicodeslot=0x215E,
 },
 [0x215F]={
  category="no",
  description="FRACTION NUMERATOR ONE",
  direction="on",
  linebreak="al",
  specials={ "fraction", 0x0031, 0x2044 },
  unicodeslot=0x215F,
 },
 [0x2160]={
  adobename="Oneroman",
  category="nl",
  cjkwd="a",
  contextname="romanI",
  description="ROMAN NUMERAL ONE",
  direction="l",
  lccode=0x2170,
  linebreak="ai",
  specials={ "compat", 0x0049 },
  unicodeslot=0x2160,
 },
 [0x2161]={
  adobename="Tworoman",
  category="nl",
  cjkwd="a",
  contextname="romanII",
  description="ROMAN NUMERAL TWO",
  direction="l",
  lccode=0x2171,
  linebreak="ai",
  specials={ "compat", 0x0049, 0x0049 },
  unicodeslot=0x2161,
 },
 [0x2162]={
  adobename="Threeroman",
  category="nl",
  cjkwd="a",
  contextname="romanIII",
  description="ROMAN NUMERAL THREE",
  direction="l",
  lccode=0x2172,
  linebreak="ai",
  specials={ "compat", 0x0049, 0x0049, 0x0049 },
  unicodeslot=0x2162,
 },
 [0x2163]={
  adobename="Fourroman",
  category="nl",
  cjkwd="a",
  contextname="romanIV",
  description="ROMAN NUMERAL FOUR",
  direction="l",
  lccode=0x2173,
  linebreak="ai",
  specials={ "compat", 0x0049, 0x0056 },
  unicodeslot=0x2163,
 },
 [0x2164]={
  adobename="Fiveroman",
  category="nl",
  cjkwd="a",
  contextname="romanV",
  description="ROMAN NUMERAL FIVE",
  direction="l",
  lccode=0x2174,
  linebreak="ai",
  specials={ "compat", 0x0056 },
  unicodeslot=0x2164,
 },
 [0x2165]={
  adobename="Sixroman",
  category="nl",
  cjkwd="a",
  contextname="romanVI",
  description="ROMAN NUMERAL SIX",
  direction="l",
  lccode=0x2175,
  linebreak="ai",
  specials={ "compat", 0x0056, 0x0049 },
  unicodeslot=0x2165,
 },
 [0x2166]={
  adobename="Sevenroman",
  category="nl",
  cjkwd="a",
  contextname="romanVII",
  description="ROMAN NUMERAL SEVEN",
  direction="l",
  lccode=0x2176,
  linebreak="ai",
  specials={ "compat", 0x0056, 0x0049, 0x0049 },
  unicodeslot=0x2166,
 },
 [0x2167]={
  adobename="Eightroman",
  category="nl",
  cjkwd="a",
  contextname="romanVIII",
  description="ROMAN NUMERAL EIGHT",
  direction="l",
  lccode=0x2177,
  linebreak="ai",
  specials={ "compat", 0x0056, 0x0049, 0x0049, 0x0049 },
  unicodeslot=0x2167,
 },
 [0x2168]={
  adobename="Nineroman",
  category="nl",
  cjkwd="a",
  contextname="romanIX",
  description="ROMAN NUMERAL NINE",
  direction="l",
  lccode=0x2178,
  linebreak="ai",
  specials={ "compat", 0x0049, 0x0058 },
  unicodeslot=0x2168,
 },
 [0x2169]={
  adobename="Tenroman",
  category="nl",
  cjkwd="a",
  contextname="romanX",
  description="ROMAN NUMERAL TEN",
  direction="l",
  lccode=0x2179,
  linebreak="ai",
  specials={ "compat", 0x0058 },
  unicodeslot=0x2169,
 },
 [0x216A]={
  adobename="Elevenroman",
  category="nl",
  cjkwd="a",
  contextname="romanXI",
  description="ROMAN NUMERAL ELEVEN",
  direction="l",
  lccode=0x217A,
  linebreak="ai",
  specials={ "compat", 0x0058, 0x0049 },
  unicodeslot=0x216A,
 },
 [0x216B]={
  adobename="Twelveroman",
  category="nl",
  cjkwd="a",
  contextname="romanXII",
  description="ROMAN NUMERAL TWELVE",
  direction="l",
  lccode=0x217B,
  linebreak="ai",
  specials={ "compat", 0x0058, 0x0049, 0x0049 },
  unicodeslot=0x216B,
 },
 [0x216C]={
  category="nl",
  contextname="romanL",
  description="ROMAN NUMERAL FIFTY",
  direction="l",
  lccode=0x217C,
  linebreak="al",
  specials={ "compat", 0x004C },
  unicodeslot=0x216C,
 },
 [0x216D]={
  category="nl",
  contextname="romanC",
  description="ROMAN NUMERAL ONE HUNDRED",
  direction="l",
  lccode=0x217D,
  linebreak="al",
  specials={ "compat", 0x0043 },
  unicodeslot=0x216D,
 },
 [0x216E]={
  category="nl",
  contextname="romanD",
  description="ROMAN NUMERAL FIVE HUNDRED",
  direction="l",
  lccode=0x217E,
  linebreak="al",
  specials={ "compat", 0x0044 },
  unicodeslot=0x216E,
 },
 [0x216F]={
  category="nl",
  contextname="romanM",
  description="ROMAN NUMERAL ONE THOUSAND",
  direction="l",
  lccode=0x217F,
  linebreak="al",
  specials={ "compat", 0x004D },
  unicodeslot=0x216F,
 },
 [0x2170]={
  adobename="oneroman",
  category="nl",
  cjkwd="a",
  contextname="romani",
  description="SMALL ROMAN NUMERAL ONE",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0069 },
  uccode=0x2160,
  unicodeslot=0x2170,
 },
 [0x2171]={
  adobename="tworoman",
  category="nl",
  cjkwd="a",
  contextname="romanii",
  description="SMALL ROMAN NUMERAL TWO",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0069, 0x0069 },
  uccode=0x2161,
  unicodeslot=0x2171,
 },
 [0x2172]={
  adobename="threeroman",
  category="nl",
  cjkwd="a",
  contextname="romaniii",
  description="SMALL ROMAN NUMERAL THREE",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0069, 0x0069, 0x0069 },
  uccode=0x2162,
  unicodeslot=0x2172,
 },
 [0x2173]={
  adobename="fourroman",
  category="nl",
  cjkwd="a",
  contextname="romaniv",
  description="SMALL ROMAN NUMERAL FOUR",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0069, 0x0076 },
  uccode=0x2163,
  unicodeslot=0x2173,
 },
 [0x2174]={
  adobename="fiveroman",
  category="nl",
  cjkwd="a",
  contextname="romanv",
  description="SMALL ROMAN NUMERAL FIVE",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0076 },
  uccode=0x2164,
  unicodeslot=0x2174,
 },
 [0x2175]={
  adobename="sixroman",
  category="nl",
  cjkwd="a",
  contextname="romanvi",
  description="SMALL ROMAN NUMERAL SIX",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0076, 0x0069 },
  uccode=0x2165,
  unicodeslot=0x2175,
 },
 [0x2176]={
  adobename="sevenroman",
  category="nl",
  cjkwd="a",
  contextname="romanvii",
  description="SMALL ROMAN NUMERAL SEVEN",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0076, 0x0069, 0x0069 },
  uccode=0x2166,
  unicodeslot=0x2176,
 },
 [0x2177]={
  adobename="eightroman",
  category="nl",
  cjkwd="a",
  contextname="romanviii",
  description="SMALL ROMAN NUMERAL EIGHT",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0076, 0x0069, 0x0069, 0x0069 },
  uccode=0x2167,
  unicodeslot=0x2177,
 },
 [0x2178]={
  adobename="nineroman",
  category="nl",
  cjkwd="a",
  contextname="romanix",
  description="SMALL ROMAN NUMERAL NINE",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0069, 0x0078 },
  uccode=0x2168,
  unicodeslot=0x2178,
 },
 [0x2179]={
  adobename="tenroman",
  category="nl",
  cjkwd="a",
  contextname="romanx",
  description="SMALL ROMAN NUMERAL TEN",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0078 },
  uccode=0x2169,
  unicodeslot=0x2179,
 },
 [0x217A]={
  adobename="elevenroman",
  category="nl",
  contextname="romanxi",
  description="SMALL ROMAN NUMERAL ELEVEN",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0078, 0x0069 },
  uccode=0x216A,
  unicodeslot=0x217A,
 },
 [0x217B]={
  adobename="twelveroman",
  category="nl",
  contextname="romanxii",
  description="SMALL ROMAN NUMERAL TWELVE",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0078, 0x0069, 0x0069 },
  uccode=0x216B,
  unicodeslot=0x217B,
 },
 [0x217C]={
  category="nl",
  contextname="romanl",
  description="SMALL ROMAN NUMERAL FIFTY",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x006C },
  uccode=0x216C,
  unicodeslot=0x217C,
 },
 [0x217D]={
  category="nl",
  contextname="romanc",
  description="SMALL ROMAN NUMERAL ONE HUNDRED",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0063 },
  uccode=0x216D,
  unicodeslot=0x217D,
 },
 [0x217E]={
  category="nl",
  contextname="romand",
  description="SMALL ROMAN NUMERAL FIVE HUNDRED",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0064 },
  uccode=0x216E,
  unicodeslot=0x217E,
 },
 [0x217F]={
  category="nl",
  contextname="romanm",
  description="SMALL ROMAN NUMERAL ONE THOUSAND",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x006D },
  uccode=0x216F,
  unicodeslot=0x217F,
 },
 [0x2180]={
  category="nl",
  description="ROMAN NUMERAL ONE THOUSAND C D",
  direction="l",
  linebreak="al",
  unicodeslot=0x2180,
 },
 [0x2181]={
  category="nl",
  description="ROMAN NUMERAL FIVE THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x2181,
 },
 [0x2182]={
  category="nl",
  description="ROMAN NUMERAL TEN THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x2182,
 },
 [0x2183]={
  category="lu",
  description="ROMAN NUMERAL REVERSED ONE HUNDRED",
  direction="l",
  lccode=0x2184,
  linebreak="al",
  unicodeslot=0x2183,
 },
 [0x2184]={
  category="ll",
  description="LATIN SMALL LETTER REVERSED C",
  direction="l",
  linebreak="al",
  uccode=0x2183,
  unicodeslot=0x2184,
 },
 [0x2185]={
  category="nl",
  description="ROMAN NUMERAL SIX LATE FORM",
  direction="l",
  linebreak="al",
  unicodeslot=0x2185,
 },
 [0x2186]={
  category="nl",
  description="ROMAN NUMERAL FIFTY EARLY FORM",
  direction="l",
  linebreak="al",
  unicodeslot=0x2186,
 },
 [0x2187]={
  category="nl",
  description="ROMAN NUMERAL FIFTY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x2187,
 },
 [0x2188]={
  category="nl",
  description="ROMAN NUMERAL ONE HUNDRED THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x2188,
 },
 [0x2189]={
  category="no",
  cjkwd="a",
  description="VULGAR FRACTION ZERO THIRDS",
  direction="on",
  linebreak="ai",
  specials={ "fraction", 0x0030, 0x2044, 0x0033 },
  unicodeslot=0x2189,
 },
 [0x2190]={
  adobename="arrowleft",
  category="sm",
  cjkwd="a",
  description="LEFTWARDS ARROW",
  direction="on",
  linebreak="ai",
  mathextensible="l",
  mathfiller="leftarrowfill",
  mathspec={
   {
    class="relation",
    name="leftarrow",
   },
   {
    class="relation",
    name="gets",
   },
   {
    class="under",
    name="underleftarrow",
   },
   {
    class="over",
    name="overleftarrow",
   },
  },
  mathstretch="h",
  unicodeslot=0x2190,
 },
 [0x2191]={
  adobename="arrowup",
  category="sm",
  cjkwd="a",
  description="UPWARDS ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathextensible="u",
  mathname="uparrow",
  unicodeslot=0x2191,
 },
 [0x2192]={
  adobename="arrowright",
  category="sm",
  cjkwd="a",
  description="RIGHTWARDS ARROW",
  direction="on",
  linebreak="ai",
  mathextensible="r",
  mathfiller="rightarrowfill",
  mathspec={
   {
    class="relation",
    name="rightarrow",
   },
   {
    class="relation",
    name="to",
   },
   {
    class="under",
    name="underrightarrow",
   },
   {
    class="over",
    name="overrightarrow",
   },
  },
  mathstretch="h",
  unicodeslot=0x2192,
 },
 [0x2193]={
  adobename="arrowdown",
  category="sm",
  cjkwd="a",
  description="DOWNWARDS ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathextensible="d",
  mathname="downarrow",
  unicodeslot=0x2193,
 },
 [0x2194]={
  adobename="arrowboth",
  category="sm",
  cjkwd="a",
  description="LEFT RIGHT ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathextensible="h",
  mathname="leftrightarrow",
  unicodeslot=0x2194,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2195]={
  adobename="arrowupdn",
  category="so",
  cjkwd="a",
  description="UP DOWN ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathextensible="v",
  mathname="updownarrow",
  unicodeslot=0x2195,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2196]={
  adobename="arrowupleft",
  category="so",
  cjkwd="a",
  description="NORTH WEST ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="nwarrow",
  unicodeslot=0x2196,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2197]={
  adobename="arrowupright",
  category="so",
  cjkwd="a",
  description="NORTH EAST ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="nearrow",
  unicodeslot=0x2197,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2198]={
  adobename="arrowdownright",
  category="so",
  cjkwd="a",
  description="SOUTH EAST ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="searrow",
  unicodeslot=0x2198,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2199]={
  adobename="arrowdownleft",
  category="so",
  cjkwd="a",
  description="SOUTH WEST ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="swarrow",
  unicodeslot=0x2199,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x219A]={
  category="sm",
  description="LEFTWARDS ARROW WITH STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="nleftarrow",
  specials={ "char", 0x2190, 0x0338 },
  unicodeslot=0x219A,
 },
 [0x219B]={
  category="sm",
  description="RIGHTWARDS ARROW WITH STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="nrightarrow",
  specials={ "char", 0x2192, 0x0338 },
  unicodeslot=0x219B,
 },
 [0x219C]={
  category="so",
  description="LEFTWARDS WAVE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="leftwavearrow",
  unicodeslot=0x219C,
 },
 [0x219D]={
  category="so",
  description="RIGHTWARDS WAVE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="rightwavearrow",
  unicodeslot=0x219D,
 },
 [0x219E]={
  category="so",
  description="LEFTWARDS TWO HEADED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathfiller="twoheadleftarrowfill",
  mathname="twoheadleftarrow",
  unicodeslot=0x219E,
 },
 [0x219F]={
  category="so",
  description="UPWARDS TWO HEADED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="u",
  mathname="twoheaduparrow",
  unicodeslot=0x219F,
 },
 [0x21A0]={
  category="sm",
  description="RIGHTWARDS TWO HEADED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathfiller="twoheadrightarrowfill",
  mathname="twoheadrightarrow",
  unicodeslot=0x21A0,
 },
 [0x21A1]={
  category="so",
  description="DOWNWARDS TWO HEADED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="d",
  mathname="twoheaddownarrow",
  unicodeslot=0x21A1,
 },
 [0x21A2]={
  category="so",
  description="LEFTWARDS ARROW WITH TAIL",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="leftarrowtail",
  unicodeslot=0x21A2,
 },
 [0x21A3]={
  category="sm",
  description="RIGHTWARDS ARROW WITH TAIL",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="rightarrowtail",
  unicodeslot=0x21A3,
 },
 [0x21A4]={
  category="so",
  description="LEFTWARDS ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="mapsfrom",
  unicodeslot=0x21A4,
 },
 [0x21A5]={
  category="so",
  description="UPWARDS ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="u",
  mathname="mapsup",
  unicodeslot=0x21A5,
 },
 [0x21A6]={
  category="sm",
  description="RIGHTWARDS ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathfiller="mapstofill",
  mathname="mapsto",
  unicodeslot=0x21A6,
 },
 [0x21A7]={
  category="so",
  description="DOWNWARDS ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="d",
  mathname="mapsdown",
  unicodeslot=0x21A7,
 },
 [0x21A8]={
  adobename="arrowupdownbase",
  category="so",
  description="UP DOWN ARROW WITH BASE",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathextensible="v",
  mathname="updownarrowbar",
  unicodeslot=0x21A8,
 },
 [0x21A9]={
  category="so",
  description="LEFTWARDS ARROW WITH HOOK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathfiller="hookleftarrowfill",
  mathname="hookleftarrow",
  unicodeslot=0x21A9,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x21AA]={
  category="so",
  description="RIGHTWARDS ARROW WITH HOOK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathfiller="hookrightarrowfill",
  mathname="hookrightarrow",
  unicodeslot=0x21AA,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x21AB]={
  category="so",
  description="LEFTWARDS ARROW WITH LOOP",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="looparrowleft",
  unicodeslot=0x21AB,
 },
 [0x21AC]={
  category="so",
  description="RIGHTWARDS ARROW WITH LOOP",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="looparrowright",
  unicodeslot=0x21AC,
 },
 [0x21AD]={
  category="so",
  description="LEFT RIGHT WAVE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathname="leftrightsquigarrow",
  unicodeslot=0x21AD,
 },
 [0x21AE]={
  category="sm",
  description="LEFT RIGHT ARROW WITH STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathname="nleftrightarrow",
  specials={ "char", 0x2194, 0x0338 },
  unicodeslot=0x21AE,
 },
 [0x21AF]={
  category="so",
  description="DOWNWARDS ZIGZAG ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="d",
  mathname="downzigzagarrow",
  unicodeslot=0x21AF,
 },
 [0x21B0]={
  category="so",
  description="UPWARDS ARROW WITH TIP LEFTWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="m",
  mathname="Lsh",
  unicodeslot=0x21B0,
 },
 [0x21B1]={
  category="so",
  description="UPWARDS ARROW WITH TIP RIGHTWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="m",
  mathname="Rsh",
  unicodeslot=0x21B1,
 },
 [0x21B2]={
  category="so",
  description="DOWNWARDS ARROW WITH TIP LEFTWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="m",
  mathname="Ldsh",
  unicodeslot=0x21B2,
 },
 [0x21B3]={
  category="so",
  description="DOWNWARDS ARROW WITH TIP RIGHTWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="m",
  mathname="Rdsh",
  unicodeslot=0x21B3,
 },
 [0x21B4]={
  category="so",
  description="RIGHTWARDS ARROW WITH CORNER DOWNWARDS",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathextensible="m",
  mathname="linefeed",
  unicodeslot=0x21B4,
 },
 [0x21B5]={
  adobename="carriagereturn",
  category="so",
  contextname="carriagereturn",
  description="DOWNWARDS ARROW WITH CORNER LEFTWARDS",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathextensible="m",
  mathname="carriagereturn",
  unicodeslot=0x21B5,
 },
 [0x21B6]={
  category="so",
  description="ANTICLOCKWISE TOP SEMICIRCLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="curvearrowleft",
  unicodeslot=0x21B6,
 },
 [0x21B7]={
  category="so",
  description="CLOCKWISE TOP SEMICIRCLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="curvearrowright",
  unicodeslot=0x21B7,
 },
 [0x21B8]={
  category="so",
  cjkwd="a",
  description="NORTH WEST ARROW TO LONG BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="barovernorthwestarrow",
  unicodeslot=0x21B8,
 },
 [0x21B9]={
  category="so",
  cjkwd="a",
  description="LEFTWARDS ARROW TO BAR OVER RIGHTWARDS ARROW TO BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathname="barleftarrowrightarrowbar",
  unicodeslot=0x21B9,
 },
 [0x21BA]={
  category="so",
  description="ANTICLOCKWISE OPEN CIRCLE ARROW",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="circlearrowright",
   },
   {
    class="relation",
    name="acwopencirclearrow",
   },
  },
  unicodeslot=0x21BA,
 },
 [0x21BB]={
  category="so",
  description="CLOCKWISE OPEN CIRCLE ARROW",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="circlearrowleft",
   },
   {
    class="relation",
    name="cwopencirclearrow",
   },
  },
  unicodeslot=0x21BB,
 },
 [0x21BC]={
  adobename="harpoonleftbarbup",
  category="so",
  description="LEFTWARDS HARPOON WITH BARB UPWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathfiller="leftharpoonupfill",
  mathname="leftharpoonup",
  unicodeslot=0x21BC,
 },
 [0x21BD]={
  category="so",
  description="LEFTWARDS HARPOON WITH BARB DOWNWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathfiller="leftharpoondownfill",
  mathname="leftharpoondown",
  unicodeslot=0x21BD,
 },
 [0x21BE]={
  category="so",
  description="UPWARDS HARPOON WITH BARB RIGHTWARDS",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="upharpoonright",
   },
   {
    class="relation",
    name="restriction",
   },
  },
  unicodeslot=0x21BE,
 },
 [0x21BF]={
  category="so",
  description="UPWARDS HARPOON WITH BARB LEFTWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="upharpoonleft",
  unicodeslot=0x21BF,
 },
 [0x21C0]={
  adobename="harpoonrightbarbup",
  category="so",
  description="RIGHTWARDS HARPOON WITH BARB UPWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathfiller="rightharpoonupfill",
  mathname="rightharpoonup",
  unicodeslot=0x21C0,
 },
 [0x21C1]={
  category="so",
  description="RIGHTWARDS HARPOON WITH BARB DOWNWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathfiller="rightharpoondownfill",
  mathname="rightharpoondown",
  unicodeslot=0x21C1,
 },
 [0x21C2]={
  category="so",
  description="DOWNWARDS HARPOON WITH BARB RIGHTWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="downharpoonright",
  unicodeslot=0x21C2,
 },
 [0x21C3]={
  category="so",
  description="DOWNWARDS HARPOON WITH BARB LEFTWARDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="downharpoonleft",
  unicodeslot=0x21C3,
 },
 [0x21C4]={
  adobename="arrowrightoverleft",
  category="so",
  description="RIGHTWARDS ARROW OVER LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathfiller="rightoverleftarrowfill",
  mathname="rightleftarrows",
  unicodeslot=0x21C4,
 },
 [0x21C5]={
  adobename="arrowupleftofdown",
  category="so",
  description="UPWARDS ARROW LEFTWARDS OF DOWNWARDS ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="m",
  mathname="updownarrows",
  unicodeslot=0x21C5,
 },
 [0x21C6]={
  adobename="arrowleftoverright",
  category="so",
  description="LEFTWARDS ARROW OVER RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathfiller="lefgtoverrightarrowfill",
  mathname="leftrightarrows",
  unicodeslot=0x21C6,
 },
 [0x21C7]={
  category="so",
  description="LEFTWARDS PAIRED ARROWS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="leftleftarrows",
  unicodeslot=0x21C7,
 },
 [0x21C8]={
  category="so",
  description="UPWARDS PAIRED ARROWS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="u",
  mathname="upuparrows",
  unicodeslot=0x21C8,
 },
 [0x21C9]={
  category="so",
  description="RIGHTWARDS PAIRED ARROWS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="rightrightarrows",
  unicodeslot=0x21C9,
 },
 [0x21CA]={
  category="so",
  description="DOWNWARDS PAIRED ARROWS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="d",
  mathname="downdownarrows",
  unicodeslot=0x21CA,
 },
 [0x21CB]={
  category="so",
  description="LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathfiller="leftrightharpoonsfill",
  mathname="leftrightharpoons",
  unicodeslot=0x21CB,
 },
 [0x21CC]={
  category="so",
  description="RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathfiller="rightleftharpoonsfill",
  mathname="rightleftharpoons",
  unicodeslot=0x21CC,
 },
 [0x21CD]={
  adobename="arrowleftdblstroke",
  category="so",
  description="LEFTWARDS DOUBLE ARROW WITH STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="nLeftarrow",
  specials={ "char", 0x21D0, 0x0338 },
  unicodeslot=0x21CD,
 },
 [0x21CE]={
  category="sm",
  description="LEFT RIGHT DOUBLE ARROW WITH STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathname="nLeftrightarrow",
  specials={ "char", 0x21D4, 0x0338 },
  unicodeslot=0x21CE,
 },
 [0x21CF]={
  adobename="arrowrightdblstroke",
  category="sm",
  description="RIGHTWARDS DOUBLE ARROW WITH STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="nRightarrow",
  specials={ "char", 0x21D2, 0x0338 },
  unicodeslot=0x21CF,
 },
 [0x21D0]={
  adobename="arrowleftdbl",
  category="so",
  description="LEFTWARDS DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="Leftarrow",
  unicodeslot=0x21D0,
 },
 [0x21D1]={
  adobename="arrowdblup",
  category="so",
  description="UPWARDS DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="u",
  mathname="Uparrow",
  unicodeslot=0x21D1,
 },
 [0x21D2]={
  adobename="dblarrowright",
  category="sm",
  cjkwd="a",
  description="RIGHTWARDS DOUBLE ARROW",
  direction="on",
  linebreak="ai",
  mathextensible="r",
  mathspec={
   {
    class="relation",
    name="Rightarrow",
   },
   {
    class="relation",
    name="imply",
   },
  },
  unicodeslot=0x21D2,
 },
 [0x21D3]={
  adobename="arrowdbldown",
  category="so",
  description="DOWNWARDS DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="d",
  mathname="Downarrow",
  unicodeslot=0x21D3,
 },
 [0x21D4]={
  adobename="dblarrowleft",
  category="sm",
  cjkwd="a",
  description="LEFT RIGHT DOUBLE ARROW",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathextensible="h",
  mathname="Leftrightarrow",
  unicodeslot=0x21D4,
 },
 [0x21D5]={
  category="so",
  description="UP DOWN DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="v",
  mathname="Updownarrow",
  unicodeslot=0x21D5,
 },
 [0x21D6]={
  category="so",
  description="NORTH WEST DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Nwarrow",
  unicodeslot=0x21D6,
 },
 [0x21D7]={
  category="so",
  description="NORTH EAST DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Nearrow",
  unicodeslot=0x21D7,
 },
 [0x21D8]={
  category="so",
  description="SOUTH EAST DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Searrow",
  unicodeslot=0x21D8,
 },
 [0x21D9]={
  category="so",
  description="SOUTH WEST DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Swarrow",
  unicodeslot=0x21D9,
 },
 [0x21DA]={
  category="so",
  description="LEFTWARDS TRIPLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="Lleftarrow",
  unicodeslot=0x21DA,
 },
 [0x21DB]={
  category="so",
  description="RIGHTWARDS TRIPLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="Rrightarrow",
  unicodeslot=0x21DB,
 },
 [0x21DC]={
  category="so",
  description="LEFTWARDS SQUIGGLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="leftsquigarrow",
  unicodeslot=0x21DC,
 },
 [0x21DD]={
  category="so",
  description="RIGHTWARDS SQUIGGLE ARROW",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="rightsquigarrow",
   },
   {
    class="relation",
    name="leadsto",
   },
  },
  unicodeslot=0x21DD,
 },
 [0x21DE]={
  adobename="pageup",
  category="so",
  description="UPWARDS ARROW WITH DOUBLE STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="u",
  mathname="nHuparrow",
  unicodeslot=0x21DE,
 },
 [0x21DF]={
  adobename="pagedown",
  category="so",
  description="DOWNWARDS ARROW WITH DOUBLE STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="d",
  mathname="nHdownarrow",
  unicodeslot=0x21DF,
 },
 [0x21E0]={
  adobename="arrowdashleft",
  category="so",
  description="LEFTWARDS DASHED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="leftdasharrow",
  unicodeslot=0x21E0,
 },
 [0x21E1]={
  adobename="arrowdashup",
  category="so",
  description="UPWARDS DASHED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="u",
  mathname="updasharrow",
  unicodeslot=0x21E1,
 },
 [0x21E2]={
  adobename="arrowdashright",
  category="so",
  description="RIGHTWARDS DASHED ARROW",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="rightdasharrow",
   },
   {
    class="relation",
    name="dasharrow",
   },
  },
  unicodeslot=0x21E2,
 },
 [0x21E3]={
  adobename="arrowdashdown",
  category="so",
  description="DOWNWARDS DASHED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="d",
  mathname="downdasharrow",
  unicodeslot=0x21E3,
 },
 [0x21E4]={
  adobename="arrowtableft",
  category="so",
  description="LEFTWARDS ARROW TO BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="barleftarrow",
  unicodeslot=0x21E4,
 },
 [0x21E5]={
  adobename="arrowtabright",
  category="so",
  description="RIGHTWARDS ARROW TO BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="rightarrowbar",
  unicodeslot=0x21E5,
 },
 [0x21E6]={
  adobename="arrowleftwhite",
  category="so",
  description="LEFTWARDS WHITE ARROW",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathextensible="l",
  mathname="leftwhitearrow",
  unicodeslot=0x21E6,
 },
 [0x21E7]={
  adobename="arrowupwhite",
  category="so",
  cjkwd="a",
  description="UPWARDS WHITE ARROW",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathextensible="u",
  mathname="upwhitearrow",
  unicodeslot=0x21E7,
 },
 [0x21E8]={
  adobename="arrowrightwhite",
  category="so",
  description="RIGHTWARDS WHITE ARROW",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathextensible="r",
  mathname="rightwhitearrow",
  unicodeslot=0x21E8,
 },
 [0x21E9]={
  adobename="arrowdownwhite",
  category="so",
  description="DOWNWARDS WHITE ARROW",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathextensible="d",
  mathname="downwhitearrow",
  unicodeslot=0x21E9,
 },
 [0x21EA]={
  adobename="capslock",
  category="so",
  description="UPWARDS WHITE ARROW FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x21EA,
 },
 [0x21EB]={
  category="so",
  description="UPWARDS WHITE ARROW ON PEDESTAL",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathextensible="u",
  mathname="whitearrowupfrombar",
  unicodeslot=0x21EB,
 },
 [0x21EC]={
  category="so",
  description="UPWARDS WHITE ARROW ON PEDESTAL WITH HORIZONTAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x21EC,
 },
 [0x21ED]={
  category="so",
  description="UPWARDS WHITE ARROW ON PEDESTAL WITH VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x21ED,
 },
 [0x21EE]={
  category="so",
  description="UPWARDS WHITE DOUBLE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x21EE,
 },
 [0x21EF]={
  category="so",
  description="UPWARDS WHITE DOUBLE ARROW ON PEDESTAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x21EF,
 },
 [0x21F0]={
  category="so",
  description="RIGHTWARDS WHITE ARROW FROM WALL",
  direction="on",
  linebreak="al",
  unicodeslot=0x21F0,
 },
 [0x21F1]={
  category="so",
  description="NORTH WEST ARROW TO CORNER",
  direction="on",
  linebreak="al",
  unicodeslot=0x21F1,
 },
 [0x21F2]={
  category="so",
  description="SOUTH EAST ARROW TO CORNER",
  direction="on",
  linebreak="al",
  unicodeslot=0x21F2,
 },
 [0x21F3]={
  category="so",
  description="UP DOWN WHITE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x21F3,
 },
 [0x21F4]={
  category="sm",
  description="RIGHT ARROW WITH SMALL CIRCLE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="circleonrightarrow",
  unicodeslot=0x21F4,
 },
 [0x21F5]={
  category="sm",
  description="DOWNWARDS ARROW LEFTWARDS OF UPWARDS ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="m",
  mathname="downuparrows",
  unicodeslot=0x21F5,
 },
 [0x21F6]={
  category="sm",
  description="THREE RIGHTWARDS ARROWS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="rightthreearrows",
  unicodeslot=0x21F6,
 },
 [0x21F7]={
  category="sm",
  description="LEFTWARDS ARROW WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="nvleftarrow",
  unicodeslot=0x21F7,
 },
 [0x21F8]={
  category="sm",
  description="RIGHTWARDS ARROW WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="nvrightarrow",
  unicodeslot=0x21F8,
 },
 [0x21F9]={
  category="sm",
  description="LEFT RIGHT ARROW WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathname="nvleftrightarrow",
  unicodeslot=0x21F9,
 },
 [0x21FA]={
  category="sm",
  description="LEFTWARDS ARROW WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="nVleftarrow",
  unicodeslot=0x21FA,
 },
 [0x21FB]={
  category="sm",
  description="RIGHTWARDS ARROW WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="nVrightarrow",
  unicodeslot=0x21FB,
 },
 [0x21FC]={
  category="sm",
  description="LEFT RIGHT ARROW WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathname="nVleftrightarrow",
  unicodeslot=0x21FC,
 },
 [0x21FD]={
  category="sm",
  description="LEFTWARDS OPEN-HEADED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="leftarrowtriangle",
  unicodeslot=0x21FD,
 },
 [0x21FE]={
  category="sm",
  description="RIGHTWARDS OPEN-HEADED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="rightarrowtriangle",
  unicodeslot=0x21FE,
 },
 [0x21FF]={
  category="sm",
  description="LEFT RIGHT OPEN-HEADED ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathname="leftrightarrowtriangle",
  unicodeslot=0x21FF,
 },
 [0x2200]={
  adobename="universal",
  category="sm",
  cjkwd="a",
  description="FOR ALL",
  direction="on",
  linebreak="ai",
  mathclass="ordinary",
  mathname="forall",
  unicodeslot=0x2200,
 },
 [0x2201]={
  category="sm",
  description="COMPLEMENT",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="complement",
  unicodeslot=0x2201,
 },
 [0x2202]={
  adobename="partialdiff",
  category="sm",
  cjkwd="a",
  description="PARTIAL DIFFERENTIAL",
  direction="on",
  linebreak="ai",
  mathclass="default",
  mathname="partial",
  unicodeslot=0x2202,
 },
 [0x2203]={
  adobename="thereexists",
  category="sm",
  cjkwd="a",
  description="THERE EXISTS",
  direction="on",
  linebreak="ai",
  mathclass="ordinary",
  mathname="exists",
  unicodeslot=0x2203,
 },
 [0x2204]={
  category="sm",
  description="THERE DOES NOT EXIST",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="nexists",
  specials={ "char", 0x2203, 0x0338 },
  unicodeslot=0x2204,
 },
 [0x2205]={
  adobename="emptyset",
  category="sm",
  description="EMPTY SET",
  direction="on",
  linebreak="al",
  mathclass="default",
  mathname="emptyset",
  unicodeslot=0x2205,
 },
 [0x2206]={
  adobename="increment",
  category="sm",
  description="INCREMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2206,
 },
 [0x2207]={
  adobename="nabla",
  category="sm",
  cjkwd="a",
  description="NABLA",
  direction="on",
  linebreak="ai",
  mathclass="default",
  mathname="nabla",
  unicodeslot=0x2207,
 },
 [0x2208]={
  adobename="element",
  category="sm",
  cjkwd="a",
  description="ELEMENT OF",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="in",
  mirror=0x220B,
  unicodeslot=0x2208,
 },
 [0x2209]={
  adobename="notelementof",
  category="sm",
  description="NOT AN ELEMENT OF",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="notin",
   },
   {
    class="relation",
    name="nin",
   },
  },
  mirror=0x220C,
  specials={ "char", 0x2208, 0x0338 },
  unicodeslot=0x2209,
 },
 [0x220A]={
  category="sm",
  description="SMALL ELEMENT OF",
  direction="on",
  linebreak="al",
  mirror=0x220D,
  unicodeslot=0x220A,
 },
 [0x220B]={
  adobename="suchthat",
  category="sm",
  cjkwd="a",
  description="CONTAINS AS MEMBER",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="relation",
    name="ni",
   },
   {
    class="relation",
    name="owns",
   },
  },
  mirror=0x2208,
  unicodeslot=0x220B,
 },
 [0x220C]={
  adobename="notcontains",
  category="sm",
  description="DOES NOT CONTAIN AS MEMBER",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="nni",
   },
   {
    class="relation",
    name="nowns",
   },
  },
  mirror=0x2209,
  specials={ "char", 0x220B, 0x0338 },
  unicodeslot=0x220C,
 },
 [0x220D]={
  category="sm",
  description="SMALL CONTAINS AS MEMBER",
  direction="on",
  linebreak="al",
  mirror=0x220A,
  unicodeslot=0x220D,
 },
 [0x220E]={
  category="sm",
  description="END OF PROOF",
  direction="on",
  linebreak="al",
  unicodeslot=0x220E,
 },
 [0x220F]={
  adobename="product",
  category="sm",
  cjkwd="a",
  description="N-ARY PRODUCT",
  direction="on",
  linebreak="ai",
  mathclass="limop",
  mathname="prod",
  unicodeslot=0x220F,
 },
 [0x2210]={
  category="sm",
  description="N-ARY COPRODUCT",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="coprod",
  unicodeslot=0x2210,
 },
 [0x2211]={
  adobename="summation",
  category="sm",
  cjkwd="a",
  description="N-ARY SUMMATION",
  direction="on",
  linebreak="ai",
  mathclass="limop",
  mathname="sum",
  unicodeslot=0x2211,
 },
 [0x2212]={
  adobename="minus",
  category="sm",
  description="MINUS SIGN",
  direction="es",
  linebreak="pr",
  mathspec={
   {
    class="binary",
    name="minus",
   },
   {
    class="relation",
    name="relbar",
   },
  },
  unicodeslot=0x2212,
 },
 [0x2213]={
  adobename="minusplus",
  category="sm",
  description="MINUS-OR-PLUS SIGN",
  direction="et",
  linebreak="pr",
  mathclass="binary",
  mathname="mp",
  unicodeslot=0x2213,
 },
 [0x2214]={
  category="sm",
  description="DOT PLUS",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="dotplus",
  unicodeslot=0x2214,
 },
 [0x2215]={
  adobename="divisionslash",
  category="sm",
  cjkwd="a",
  comment="mathclass=ordinary,mathname=diagup",
  description="DIVISION SLASH",
  direction="on",
  linebreak="ai",
  mirror=0x29F5,
  unicodeslot=0x2215,
 },
 [0x2216]={
  category="sm",
  comment="mathclass=ordinary,mathname=diagdown",
  description="SET MINUS",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="binary",
    name="setminus",
   },
  },
  unicodeslot=0x2216,
 },
 [0x2217]={
  adobename="asteriskmath",
  category="sm",
  description="ASTERISK OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="ast",
  unicodeslot=0x2217,
 },
 [0x2218]={
  category="sm",
  description="RING OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="circ",
  unicodeslot=0x2218,
 },
 [0x2219]={
  adobename="bulletoperator",
  category="sm",
  description="BULLET OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="bullet",
  unicodeslot=0x2219,
 },
 [0x221A]={
  adobename="radical",
  category="sm",
  cjkwd="a",
  description="SQUARE ROOT",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="root",
    name="rootradical",
   },
   {
    class="radical",
    name="surdradical",
   },
   {
    class="ordinary",
    name="surd",
   },
  },
  unicodeslot=0x221A,
 },
 [0x221B]={
  category="sm",
  description="CUBE ROOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x221B,
 },
 [0x221C]={
  category="sm",
  description="FOURTH ROOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x221C,
 },
 [0x221D]={
  adobename="proportional",
  category="sm",
  cjkwd="a",
  description="PROPORTIONAL TO",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="propto",
  unicodeslot=0x221D,
 },
 [0x221E]={
  adobename="infinity",
  category="sm",
  cjkwd="a",
  description="INFINITY",
  direction="on",
  linebreak="ai",
  mathclass="default",
  mathname="infty",
  unicodeslot=0x221E,
 },
 [0x221F]={
  adobename="rightangle",
  category="sm",
  cjkwd="a",
  description="RIGHT ANGLE",
  direction="on",
  linebreak="ai",
  mathclass="ordinary",
  mathname="rightangle",
  unicodeslot=0x221F,
 },
 [0x2220]={
  adobename="angle",
  category="sm",
  cjkwd="a",
  description="ANGLE",
  direction="on",
  linebreak="ai",
  mathclass="ordinary",
  mathname="angle",
  unicodeslot=0x2220,
 },
 [0x2221]={
  category="sm",
  description="MEASURED ANGLE",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="measuredangle",
  unicodeslot=0x2221,
 },
 [0x2222]={
  category="sm",
  description="SPHERICAL ANGLE",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="sphericalangle",
  unicodeslot=0x2222,
 },
 [0x2223]={
  adobename="divides",
  category="sm",
  cjkwd="a",
  description="DIVIDES",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="divides",
  unicodeslot=0x2223,
 },
 [0x2224]={
  category="sm",
  description="DOES NOT DIVIDE",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="binary",
    name="ndivides",
   },
   {
    class="relation",
    name="nmid",
   },
  },
  specials={ "char", 0x2223, 0x0338 },
  unicodeslot=0x2224,
 },
 [0x2225]={
  adobename="parallel",
  category="sm",
  cjkwd="a",
  description="PARALLEL TO",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="relation",
    name="parallel",
   },
  },
  unicodeslot=0x2225,
 },
 [0x2226]={
  adobename="notparallel",
  category="sm",
  description="NOT PARALLEL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nparallel",
  specials={ "char", 0x2225, 0x0338 },
  unicodeslot=0x2226,
 },
 [0x2227]={
  adobename="logicaland",
  category="sm",
  cjkwd="a",
  description="LOGICAL AND",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="binary",
    name="wedge",
   },
   {
    class="binary",
    name="land",
   },
  },
  unicodeslot=0x2227,
 },
 [0x2228]={
  adobename="logicalor",
  category="sm",
  cjkwd="a",
  description="LOGICAL OR",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="binary",
    name="vee",
   },
   {
    class="binary",
    name="lor",
   },
  },
  unicodeslot=0x2228,
 },
 [0x2229]={
  adobename="intersection",
  category="sm",
  cjkwd="a",
  description="INTERSECTION",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="cap",
  unicodeslot=0x2229,
  variants={
   [0xFE00]="with serifs",
  },
 },
 [0x222A]={
  adobename="union",
  category="sm",
  cjkwd="a",
  description="UNION",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="cup",
  unicodeslot=0x222A,
  variants={
   [0xFE00]="with serifs",
  },
 },
 [0x222B]={
  adobename="integral",
  category="sm",
  cjkwd="a",
  description="INTEGRAL",
  direction="on",
  linebreak="ai",
  mathclass="limop",
  mathspec={
   {
    class="limop",
    name="int",
   },
   {
    class="nothing",
    name="intop",
   },
  },
  unicodeslot=0x222B,
 },
 [0x222C]={
  adobename="dblintegral",
  category="sm",
  cjkwd="a",
  description="DOUBLE INTEGRAL",
  direction="on",
  linebreak="ai",
  mathclass="limop",
  mathspec={
   {
    class="limop",
    name="iint",
   },
   {
    class="nothing",
    name="iintop",
   },
  },
  specials={ "compat", 0x222B, 0x222B },
  unicodeslot=0x222C,
 },
 [0x222D]={
  category="sm",
  description="TRIPLE INTEGRAL",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathspec={
   {
    class="limop",
    name="iiint",
   },
   {
    class="nothing",
    name="iiintop",
   },
  },
  specials={ "compat", 0x222B, 0x222B, 0x222B },
  unicodeslot=0x222D,
 },
 [0x222E]={
  adobename="contourintegral",
  category="sm",
  cjkwd="a",
  description="CONTOUR INTEGRAL",
  direction="on",
  linebreak="ai",
  mathclass="limop",
  mathname="oint",
  unicodeslot=0x222E,
 },
 [0x222F]={
  category="sm",
  description="SURFACE INTEGRAL",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="oiint",
  specials={ "compat", 0x222E, 0x222E },
  unicodeslot=0x222F,
 },
 [0x2230]={
  category="sm",
  description="VOLUME INTEGRAL",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="oiiint",
  specials={ "compat", 0x222E, 0x222E, 0x222E },
  unicodeslot=0x2230,
 },
 [0x2231]={
  category="sm",
  description="CLOCKWISE INTEGRAL",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="intclockwise",
  unicodeslot=0x2231,
 },
 [0x2232]={
  category="sm",
  description="CLOCKWISE CONTOUR INTEGRAL",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="ointclockwise",
  unicodeslot=0x2232,
 },
 [0x2233]={
  category="sm",
  description="ANTICLOCKWISE CONTOUR INTEGRAL",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="ointctrclockwise",
  unicodeslot=0x2233,
 },
 [0x2234]={
  adobename="therefore",
  category="sm",
  cjkwd="a",
  description="THEREFORE",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="therefore",
  unicodeslot=0x2234,
 },
 [0x2235]={
  adobename="because",
  category="sm",
  cjkwd="a",
  description="BECAUSE",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="because",
  unicodeslot=0x2235,
 },
 [0x2236]={
  adobename="ratio",
  category="sm",
  cjkwd="a",
  description="RATIO",
  direction="on",
  linebreak="ai",
  mathclass="punctuation",
  mathname="colon",
  unicodeslot=0x2236,
 },
 [0x2237]={
  adobename="proportion",
  category="sm",
  cjkwd="a",
  description="PROPORTION",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="squaredots",
  unicodeslot=0x2237,
 },
 [0x2238]={
  category="sm",
  description="DOT MINUS",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="dotminus",
  unicodeslot=0x2238,
 },
 [0x2239]={
  category="sm",
  description="EXCESS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="minuscolon",
  unicodeslot=0x2239,
 },
 [0x223A]={
  category="sm",
  description="GEOMETRIC PROPORTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x223A,
 },
 [0x223B]={
  category="sm",
  description="HOMOTHETIC",
  direction="on",
  linebreak="al",
  unicodeslot=0x223B,
 },
 [0x223C]={
  adobename="tildeoperator",
  category="sm",
  cjkwd="a",
  description="TILDE OPERATOR",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="sim",
  mirror=0x223D,
  unicodeslot=0x223C,
 },
 [0x223D]={
  adobename="reversedtilde",
  category="sm",
  cjkwd="a",
  description="REVERSED TILDE",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="backsim",
  mirror=0x223C,
  unicodeslot=0x223D,
 },
 [0x223E]={
  category="sm",
  description="INVERTED LAZY S",
  direction="on",
  linebreak="al",
  unicodeslot=0x223E,
 },
 [0x223F]={
  category="sm",
  description="SINE WAVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x223F,
 },
 [0x2240]={
  category="sm",
  description="WREATH PRODUCT",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="wr",
  unicodeslot=0x2240,
 },
 [0x2241]={
  category="sm",
  description="NOT TILDE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsim",
  specials={ "char", 0x223C, 0x0338 },
  unicodeslot=0x2241,
 },
 [0x2242]={
  category="sm",
  description="MINUS TILDE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="eqsim",
  unicodeslot=0x2242,
 },
 [0x2243]={
  adobename="asymptoticallyequal",
  category="sm",
  description="ASYMPTOTICALLY EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="simeq",
  mirror=0x22CD,
  unicodeslot=0x2243,
 },
 [0x2244]={
  category="sm",
  description="NOT ASYMPTOTICALLY EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsimeq",
  specials={ "char", 0x2243, 0x0338 },
  unicodeslot=0x2244,
 },
 [0x2245]={
  adobename="congruent",
  category="sm",
  description="APPROXIMATELY EQUAL TO",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="approxEq",
   },
   {
    class="relation",
    name="cong",
   },
  },
  unicodeslot=0x2245,
 },
 [0x2246]={
  category="sm",
  description="APPROXIMATELY BUT NOT ACTUALLY EQUAL TO",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="napproxEq",
   },
   {
    class="relation",
    name="ncong",
   },
  },
  unicodeslot=0x2246,
 },
 [0x2247]={
  category="sm",
  description="NEITHER APPROXIMATELY NOR ACTUALLY EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="approxnEq",
  specials={ "char", 0x2245, 0x0338 },
  unicodeslot=0x2247,
 },
 [0x2248]={
  adobename="approxequal",
  category="sm",
  cjkwd="a",
  description="ALMOST EQUAL TO",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="approx",
  unicodeslot=0x2248,
 },
 [0x2249]={
  category="sm",
  description="NOT ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="napprox",
  specials={ "char", 0x2248, 0x0338 },
  unicodeslot=0x2249,
 },
 [0x224A]={
  category="sm",
  description="ALMOST EQUAL OR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="approxeq",
  unicodeslot=0x224A,
 },
 [0x224B]={
  category="sm",
  description="TRIPLE TILDE",
  direction="on",
  linebreak="al",
  unicodeslot=0x224B,
 },
 [0x224C]={
  adobename="allequal",
  category="sm",
  cjkwd="a",
  description="ALL EQUAL TO",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  unicodeslot=0x224C,
 },
 [0x224D]={
  category="sm",
  description="EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="asymp",
  unicodeslot=0x224D,
 },
 [0x224E]={
  category="sm",
  description="GEOMETRICALLY EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Bumpeq",
  unicodeslot=0x224E,
 },
 [0x224F]={
  category="sm",
  description="DIFFERENCE BETWEEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x224F,
 },
 [0x2250]={
  adobename="approaches",
  category="sm",
  description="APPROACHES THE LIMIT",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="doteq",
  unicodeslot=0x2250,
 },
 [0x2251]={
  adobename="geometricallyequal",
  category="sm",
  description="GEOMETRICALLY EQUAL TO",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="doteqdot",
   },
   {
    class="relation",
    name="Doteq",
   },
  },
  unicodeslot=0x2251,
 },
 [0x2252]={
  adobename="approxequalorimage",
  category="sm",
  cjkwd="a",
  description="APPROXIMATELY EQUAL TO OR THE IMAGE OF",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="fallingdotseq",
  mirror=0x2253,
  unicodeslot=0x2252,
 },
 [0x2253]={
  adobename="imageorapproximatelyequal",
  category="sm",
  description="IMAGE OF OR APPROXIMATELY EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="risingdotseq",
  mirror=0x2252,
  unicodeslot=0x2253,
 },
 [0x2254]={
  category="sm",
  description="COLON EQUALS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="colonequals",
  mirror=0x2255,
  unicodeslot=0x2254,
 },
 [0x2255]={
  category="sm",
  description="EQUALS COLON",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="equalscolon",
  mirror=0x2254,
  unicodeslot=0x2255,
 },
 [0x2256]={
  category="sm",
  description="RING IN EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="eqcirc",
  unicodeslot=0x2256,
 },
 [0x2257]={
  category="sm",
  description="RING EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="circeq",
  unicodeslot=0x2257,
 },
 [0x2258]={
  category="sm",
  description="CORRESPONDS TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2258,
 },
 [0x2259]={
  category="sm",
  description="ESTIMATES",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="wedgeeq",
  unicodeslot=0x2259,
 },
 [0x225A]={
  category="sm",
  description="EQUIANGULAR TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="veeeq",
  unicodeslot=0x225A,
 },
 [0x225B]={
  category="sm",
  description="STAR EQUALS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="stareq",
  unicodeslot=0x225B,
 },
 [0x225C]={
  category="sm",
  description="DELTA EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="triangleq",
  unicodeslot=0x225C,
 },
 [0x225D]={
  category="sm",
  description="EQUAL TO BY DEFINITION",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="definedeq",
  unicodeslot=0x225D,
 },
 [0x225E]={
  category="sm",
  description="MEASURED BY",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="measuredeq",
  unicodeslot=0x225E,
 },
 [0x225F]={
  category="sm",
  description="QUESTIONED EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="questionedeq",
  unicodeslot=0x225F,
 },
 [0x2260]={
  adobename="notequal",
  category="sm",
  cjkwd="a",
  description="NOT EQUAL TO",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="relation",
    name="neq",
   },
   {
    class="relation",
    name="ne",
   },
  },
  specials={ "char", 0x003D, 0x0338 },
  unicodeslot=0x2260,
 },
 [0x2261]={
  adobename="equivalence",
  category="sm",
  cjkwd="a",
  description="IDENTICAL TO",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathextensible="h",
  mathname="equiv",
  unicodeslot=0x2261,
 },
 [0x2262]={
  adobename="notidentical",
  category="sm",
  description="NOT IDENTICAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathfiller="triplerelfill",
  mathname="nequiv",
  specials={ "char", 0x2261, 0x0338 },
  unicodeslot=0x2262,
 },
 [0x2263]={
  category="sm",
  description="STRICTLY EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  unicodeslot=0x2263,
 },
 [0x2264]={
  adobename="lessequal",
  category="sm",
  cjkwd="a",
  description="LESS-THAN OR EQUAL TO",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="relation",
    name="leq",
   },
   {
    class="relation",
    name="le",
   },
  },
  mirror=0x2265,
  unicodeslot=0x2264,
 },
 [0x2265]={
  adobename="greaterequal",
  category="sm",
  cjkwd="a",
  description="GREATER-THAN OR EQUAL TO",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="relation",
    name="geq",
   },
   {
    class="relation",
    name="ge",
   },
  },
  mirror=0x2264,
  unicodeslot=0x2265,
 },
 [0x2266]={
  adobename="lessoverequal",
  category="sm",
  cjkwd="a",
  description="LESS-THAN OVER EQUAL TO",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="leqq",
  mirror=0x2267,
  unicodeslot=0x2266,
 },
 [0x2267]={
  adobename="greateroverequal",
  category="sm",
  cjkwd="a",
  description="GREATER-THAN OVER EQUAL TO",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="geqq",
  mirror=0x2266,
  unicodeslot=0x2267,
 },
 [0x2268]={
  category="sm",
  description="LESS-THAN BUT NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lneqq",
  mirror=0x2269,
  unicodeslot=0x2268,
  variants={
   [0xFE00]="with vertical stroke",
  },
 },
 [0x2269]={
  category="sm",
  description="GREATER-THAN BUT NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gneqq",
  mirror=0x2268,
  unicodeslot=0x2269,
  variants={
   [0xFE00]="with vertical stroke",
  },
 },
 [0x226A]={
  adobename="muchless",
  category="sm",
  cjkwd="a",
  description="MUCH LESS-THAN",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="ll",
  mirror=0x226B,
  unicodeslot=0x226A,
 },
 [0x226B]={
  adobename="muchgreater",
  category="sm",
  cjkwd="a",
  description="MUCH GREATER-THAN",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="gg",
  mirror=0x226A,
  unicodeslot=0x226B,
 },
 [0x226C]={
  category="sm",
  description="BETWEEN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="between",
  unicodeslot=0x226C,
 },
 [0x226D]={
  category="sm",
  description="NOT EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nasymp",
  specials={ "char", 0x224D, 0x0338 },
  unicodeslot=0x226D,
 },
 [0x226E]={
  adobename="notless",
  category="sm",
  cjkwd="a",
  description="NOT LESS-THAN",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="nless",
  mirror=0x226F,
  specials={ "char", 0x003C, 0x0338 },
  unicodeslot=0x226E,
 },
 [0x226F]={
  adobename="notgreater",
  category="sm",
  cjkwd="a",
  description="NOT GREATER-THAN",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="ngtr",
  mirror=0x226E,
  specials={ "char", 0x003E, 0x0338 },
  unicodeslot=0x226F,
 },
 [0x2270]={
  adobename="notlessnorequal",
  category="sm",
  description="NEITHER LESS-THAN NOR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nleq",
  mirror=0x2271,
  specials={ "char", 0x2264, 0x0338 },
  unicodeslot=0x2270,
 },
 [0x2271]={
  adobename="notgreaternorequal",
  category="sm",
  description="NEITHER GREATER-THAN NOR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="ngeq",
  mirror=0x2270,
  specials={ "char", 0x2265, 0x0338 },
  unicodeslot=0x2271,
 },
 [0x2272]={
  adobename="lessorequivalent",
  category="sm",
  description="LESS-THAN OR EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lesssim",
  mirror=0x2273,
  unicodeslot=0x2272,
  variants={
   [0xFE00]="following the slant of the lower leg",
  },
 },
 [0x2273]={
  adobename="greaterorequivalent",
  category="sm",
  description="GREATER-THAN OR EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gtrsim",
  mirror=0x2272,
  unicodeslot=0x2273,
  variants={
   [0xFE00]="following the slant of the lower leg",
  },
 },
 [0x2274]={
  category="sm",
  description="NEITHER LESS-THAN NOR EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nlesssim",
  mirror=0x2275,
  specials={ "char", 0x2272, 0x0338 },
  unicodeslot=0x2274,
 },
 [0x2275]={
  category="sm",
  description="NEITHER GREATER-THAN NOR EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="ngtrsim",
  mirror=0x2274,
  specials={ "char", 0x2273, 0x0338 },
  unicodeslot=0x2275,
 },
 [0x2276]={
  adobename="lessorgreater",
  category="sm",
  description="LESS-THAN OR GREATER-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lessgtr",
  mirror=0x2277,
  unicodeslot=0x2276,
 },
 [0x2277]={
  adobename="greaterorless",
  category="sm",
  description="GREATER-THAN OR LESS-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gtrless",
  mirror=0x2276,
  unicodeslot=0x2277,
 },
 [0x2278]={
  category="sm",
  description="NEITHER LESS-THAN NOR GREATER-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nlessgtr",
  mirror=0x2279,
  specials={ "char", 0x2276, 0x0338 },
  unicodeslot=0x2278,
 },
 [0x2279]={
  adobename="notgreaternorless",
  category="sm",
  description="NEITHER GREATER-THAN NOR LESS-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="ngtrless",
  mirror=0x2278,
  specials={ "char", 0x2277, 0x0338 },
  unicodeslot=0x2279,
 },
 [0x227A]={
  adobename="precedes",
  category="sm",
  description="PRECEDES",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="prec",
  mirror=0x227B,
  unicodeslot=0x227A,
 },
 [0x227B]={
  adobename="succeeds",
  category="sm",
  description="SUCCEEDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succ",
  mirror=0x227A,
  unicodeslot=0x227B,
 },
 [0x227C]={
  category="sm",
  description="PRECEDES OR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="preccurlyeq",
  mirror=0x227D,
  unicodeslot=0x227C,
 },
 [0x227D]={
  category="sm",
  description="SUCCEEDS OR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succcurlyeq",
  mirror=0x227C,
  unicodeslot=0x227D,
 },
 [0x227E]={
  category="sm",
  description="PRECEDES OR EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="precsim",
  mirror=0x227F,
  unicodeslot=0x227E,
 },
 [0x227F]={
  category="sm",
  description="SUCCEEDS OR EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succsim",
  mirror=0x227E,
  unicodeslot=0x227F,
 },
 [0x2280]={
  adobename="notprecedes",
  category="sm",
  description="DOES NOT PRECEDE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nprec",
  mirror=0x2281,
  specials={ "char", 0x227A, 0x0338 },
  unicodeslot=0x2280,
 },
 [0x2281]={
  adobename="notsucceeds",
  category="sm",
  description="DOES NOT SUCCEED",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsucc",
  mirror=0x2280,
  specials={ "char", 0x227B, 0x0338 },
  unicodeslot=0x2281,
 },
 [0x2282]={
  adobename="subset",
  category="sm",
  cjkwd="a",
  description="SUBSET OF",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="subset",
  mirror=0x2283,
  unicodeslot=0x2282,
 },
 [0x2283]={
  adobename="superset",
  category="sm",
  cjkwd="a",
  description="SUPERSET OF",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="supset",
  mirror=0x2282,
  unicodeslot=0x2283,
 },
 [0x2284]={
  adobename="notsubset",
  category="sm",
  description="NOT A SUBSET OF",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsubset",
  mirror=0x2285,
  specials={ "char", 0x2282, 0x0338 },
  unicodeslot=0x2284,
 },
 [0x2285]={
  adobename="notsuperset",
  category="sm",
  description="NOT A SUPERSET OF",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsupset",
  mirror=0x2284,
  specials={ "char", 0x2283, 0x0338 },
  unicodeslot=0x2285,
 },
 [0x2286]={
  adobename="subsetorequal",
  category="sm",
  cjkwd="a",
  description="SUBSET OF OR EQUAL TO",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="subseteq",
  mirror=0x2287,
  unicodeslot=0x2286,
 },
 [0x2287]={
  adobename="supersetorequal",
  category="sm",
  cjkwd="a",
  description="SUPERSET OF OR EQUAL TO",
  direction="on",
  linebreak="ai",
  mathclass="relation",
  mathname="supseteq",
  mirror=0x2286,
  unicodeslot=0x2287,
 },
 [0x2288]={
  category="sm",
  description="NEITHER A SUBSET OF NOR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsubseteq",
  mirror=0x2289,
  specials={ "char", 0x2286, 0x0338 },
  unicodeslot=0x2288,
 },
 [0x2289]={
  category="sm",
  description="NEITHER A SUPERSET OF NOR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsupseteq",
  mirror=0x2288,
  specials={ "char", 0x2287, 0x0338 },
  unicodeslot=0x2289,
 },
 [0x228A]={
  adobename="subsetnotequal",
  category="sm",
  description="SUBSET OF WITH NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="subsetneq",
  mirror=0x228B,
  unicodeslot=0x228A,
  variants={
   [0xFE00]="with stroke through bottom members",
  },
 },
 [0x228B]={
  adobename="supersetnotequal",
  category="sm",
  description="SUPERSET OF WITH NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="supsetneq",
  mirror=0x228A,
  unicodeslot=0x228B,
  variants={
   [0xFE00]="with stroke through bottom members",
  },
 },
 [0x228C]={
  category="sm",
  description="MULTISET",
  direction="on",
  linebreak="al",
  unicodeslot=0x228C,
 },
 [0x228D]={
  category="sm",
  description="MULTISET MULTIPLICATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x228D,
 },
 [0x228E]={
  category="sm",
  description="MULTISET UNION",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="uplus",
  unicodeslot=0x228E,
 },
 [0x228F]={
  category="sm",
  description="SQUARE IMAGE OF",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="sqsubset",
  mirror=0x2290,
  unicodeslot=0x228F,
 },
 [0x2290]={
  category="sm",
  description="SQUARE ORIGINAL OF",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="sqsupset",
  mirror=0x228F,
  unicodeslot=0x2290,
 },
 [0x2291]={
  category="sm",
  description="SQUARE IMAGE OF OR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="sqsubseteq",
  mirror=0x2292,
  unicodeslot=0x2291,
 },
 [0x2292]={
  category="sm",
  description="SQUARE ORIGINAL OF OR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="sqsupseteq",
  mirror=0x2291,
  unicodeslot=0x2292,
 },
 [0x2293]={
  category="sm",
  description="SQUARE CAP",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="sqcap",
  unicodeslot=0x2293,
  variants={
   [0xFE00]="with serifs",
  },
 },
 [0x2294]={
  category="sm",
  description="SQUARE CUP",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="sqcup",
  unicodeslot=0x2294,
  variants={
   [0xFE00]="with serifs",
  },
 },
 [0x2295]={
  adobename="pluscircle",
  category="sm",
  cjkwd="a",
  description="CIRCLED PLUS",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="oplus",
  unicodeslot=0x2295,
  variants={
   [0xFE00]="with white rim",
  },
 },
 [0x2296]={
  adobename="minuscircle",
  category="sm",
  description="CIRCLED MINUS",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="ominus",
  unicodeslot=0x2296,
 },
 [0x2297]={
  adobename="timescircle",
  category="sm",
  description="CIRCLED TIMES",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="otimes",
  unicodeslot=0x2297,
  variants={
   [0xFE00]="with white rim",
  },
 },
 [0x2298]={
  category="sm",
  description="CIRCLED DIVISION SLASH",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="oslash",
  mirror=0x29B8,
  unicodeslot=0x2298,
 },
 [0x2299]={
  adobename="circleot",
  category="sm",
  cjkwd="a",
  description="CIRCLED DOT OPERATOR",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="odot",
  unicodeslot=0x2299,
 },
 [0x229A]={
  category="sm",
  description="CIRCLED RING OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="circledcirc",
  unicodeslot=0x229A,
 },
 [0x229B]={
  category="sm",
  description="CIRCLED ASTERISK OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="circledast",
  unicodeslot=0x229B,
 },
 [0x229C]={
  category="sm",
  description="CIRCLED EQUALS",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="circledequals",
  unicodeslot=0x229C,
  variants={
   [0xFE00]="with equal sign touching the circle",
  },
 },
 [0x229D]={
  category="sm",
  description="CIRCLED DASH",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="circleddash",
  unicodeslot=0x229D,
 },
 [0x229E]={
  category="sm",
  description="SQUARED PLUS",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="boxplus",
  unicodeslot=0x229E,
 },
 [0x229F]={
  category="sm",
  description="SQUARED MINUS",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="boxminus",
  unicodeslot=0x229F,
 },
 [0x22A0]={
  category="sm",
  description="SQUARED TIMES",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="boxtimes",
  unicodeslot=0x22A0,
 },
 [0x22A1]={
  category="sm",
  description="SQUARED DOT OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="boxdot",
  unicodeslot=0x22A1,
 },
 [0x22A2]={
  category="sm",
  description="RIGHT TACK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="vdash",
  mirror=0x22A3,
  unicodeslot=0x22A2,
 },
 [0x22A3]={
  adobename="tackleft",
  category="sm",
  description="LEFT TACK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="dashv",
  mirror=0x22A2,
  unicodeslot=0x22A3,
 },
 [0x22A4]={
  adobename="tackdown",
  category="sm",
  description="DOWN TACK",
  direction="on",
  linebreak="al",
  mathclass="default",
  mathname="top",
  unicodeslot=0x22A4,
 },
 [0x22A5]={
  adobename="perpendicular",
  category="sm",
  cjkwd="a",
  description="UP TACK",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="default",
    name="bot",
   },
   {
    class="relation",
    name="perp",
   },
  },
  unicodeslot=0x22A5,
 },
 [0x22A6]={
  category="sm",
  description="ASSERTION",
  direction="on",
  linebreak="al",
  mirror=0x2ADE,
  unicodeslot=0x22A6,
 },
 [0x22A7]={
  category="sm",
  description="MODELS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="models",
  unicodeslot=0x22A7,
 },
 [0x22A8]={
  category="sm",
  description="TRUE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="vDash",
  mirror=0x2AE4,
  unicodeslot=0x22A8,
 },
 [0x22A9]={
  category="sm",
  description="FORCES",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Vdash",
  mirror=0x2AE3,
  unicodeslot=0x22A9,
 },
 [0x22AA]={
  category="sm",
  description="TRIPLE VERTICAL BAR RIGHT TURNSTILE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Vvdash",
  unicodeslot=0x22AA,
 },
 [0x22AB]={
  category="sm",
  description="DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="VDash",
  mirror=0x2AE5,
  unicodeslot=0x22AB,
 },
 [0x22AC]={
  category="sm",
  description="DOES NOT PROVE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nvdash",
  specials={ "char", 0x22A2, 0x0338 },
  unicodeslot=0x22AC,
 },
 [0x22AD]={
  category="sm",
  description="NOT TRUE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nvDash",
  specials={ "char", 0x22A8, 0x0338 },
  unicodeslot=0x22AD,
 },
 [0x22AE]={
  category="sm",
  description="DOES NOT FORCE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nVdash",
  specials={ "char", 0x22A9, 0x0338 },
  unicodeslot=0x22AE,
 },
 [0x22AF]={
  category="sm",
  description="NEGATED DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nVDash",
  specials={ "char", 0x22AB, 0x0338 },
  unicodeslot=0x22AF,
 },
 [0x22B0]={
  category="sm",
  description="PRECEDES UNDER RELATION",
  direction="on",
  linebreak="al",
  mirror=0x22B1,
  unicodeslot=0x22B0,
 },
 [0x22B1]={
  category="sm",
  description="SUCCEEDS UNDER RELATION",
  direction="on",
  linebreak="al",
  mirror=0x22B0,
  unicodeslot=0x22B1,
 },
 [0x22B2]={
  category="sm",
  comment="cramped triangleleft",
  description="NORMAL SUBGROUP OF",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mirror=0x22B3,
  unicodeslot=0x22B2,
 },
 [0x22B3]={
  category="sm",
  comment="cramped triangleright",
  description="CONTAINS AS NORMAL SUBGROUP",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mirror=0x22B2,
  unicodeslot=0x22B3,
 },
 [0x22B4]={
  category="sm",
  description="NORMAL SUBGROUP OF OR EQUAL TO",
  direction="on",
  linebreak="al",
  mirror=0x22B5,
  unicodeslot=0x22B4,
 },
 [0x22B5]={
  category="sm",
  description="CONTAINS AS NORMAL SUBGROUP OR EQUAL TO",
  direction="on",
  linebreak="al",
  mirror=0x22B4,
  unicodeslot=0x22B5,
 },
 [0x22B6]={
  category="sm",
  description="ORIGINAL OF",
  direction="on",
  linebreak="al",
  mirror=0x22B7,
  unicodeslot=0x22B6,
 },
 [0x22B7]={
  category="sm",
  description="IMAGE OF",
  direction="on",
  linebreak="al",
  mirror=0x22B6,
  unicodeslot=0x22B7,
 },
 [0x22B8]={
  category="sm",
  description="MULTIMAP",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="multimap",
  unicodeslot=0x22B8,
 },
 [0x22B9]={
  category="sm",
  description="HERMITIAN CONJUGATE MATRIX",
  direction="on",
  linebreak="al",
  unicodeslot=0x22B9,
 },
 [0x22BA]={
  category="sm",
  description="INTERCALATE",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="intercal",
  unicodeslot=0x22BA,
 },
 [0x22BB]={
  category="sm",
  description="XOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="veebar",
  unicodeslot=0x22BB,
 },
 [0x22BC]={
  category="sm",
  description="NAND",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="barwedge",
  unicodeslot=0x22BC,
 },
 [0x22BD]={
  category="sm",
  description="NOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x22BD,
 },
 [0x22BE]={
  category="sm",
  description="RIGHT ANGLE WITH ARC",
  direction="on",
  linebreak="al",
  unicodeslot=0x22BE,
 },
 [0x22BF]={
  adobename="righttriangle",
  category="sm",
  cjkwd="a",
  description="RIGHT TRIANGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x22BF,
 },
 [0x22C0]={
  category="sm",
  description="N-ARY LOGICAL AND",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigwedge",
  unicodeslot=0x22C0,
 },
 [0x22C1]={
  category="sm",
  description="N-ARY LOGICAL OR",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigvee",
  unicodeslot=0x22C1,
 },
 [0x22C2]={
  category="sm",
  description="N-ARY INTERSECTION",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigcap",
  unicodeslot=0x22C2,
 },
 [0x22C3]={
  category="sm",
  description="N-ARY UNION",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigcup",
  unicodeslot=0x22C3,
 },
 [0x22C4]={
  category="sm",
  description="DIAMOND OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="diamond",
  unicodeslot=0x22C4,
 },
 [0x22C5]={
  adobename="dotmath",
  category="sm",
  description="DOT OPERATOR",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="binary",
    name="cdot",
   },
   {
    class="punctuation",
    name="cdotp",
   },
  },
  unicodeslot=0x22C5,
 },
 [0x22C6]={
  category="sm",
  description="STAR OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="star",
  unicodeslot=0x22C6,
 },
 [0x22C7]={
  category="sm",
  description="DIVISION TIMES",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="divideontimes",
  unicodeslot=0x22C7,
 },
 [0x22C8]={
  category="sm",
  description="BOWTIE",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="bowtie",
   },
   {
    class="relation",
    name="Join",
   },
  },
  unicodeslot=0x22C8,
 },
 [0x22C9]={
  category="sm",
  description="LEFT NORMAL FACTOR SEMIDIRECT PRODUCT",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="ltimes",
  mirror=0x22CA,
  unicodeslot=0x22C9,
 },
 [0x22CA]={
  category="sm",
  description="RIGHT NORMAL FACTOR SEMIDIRECT PRODUCT",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="rtimes",
  mirror=0x22C9,
  unicodeslot=0x22CA,
 },
 [0x22CB]={
  category="sm",
  description="LEFT SEMIDIRECT PRODUCT",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="leftthreetimes",
  mirror=0x22CC,
  unicodeslot=0x22CB,
 },
 [0x22CC]={
  category="sm",
  description="RIGHT SEMIDIRECT PRODUCT",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="rightthreetimes",
  mirror=0x22CB,
  unicodeslot=0x22CC,
 },
 [0x22CD]={
  category="sm",
  description="REVERSED TILDE EQUALS",
  direction="on",
  linebreak="al",
  mirror=0x2243,
  unicodeslot=0x22CD,
 },
 [0x22CE]={
  adobename="curlyor",
  category="sm",
  description="CURLY LOGICAL OR",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="curlyvee",
  unicodeslot=0x22CE,
 },
 [0x22CF]={
  adobename="curlyand",
  category="sm",
  description="CURLY LOGICAL AND",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="curlywedge",
  unicodeslot=0x22CF,
 },
 [0x22D0]={
  category="sm",
  description="DOUBLE SUBSET",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Subset",
  mirror=0x22D1,
  unicodeslot=0x22D0,
 },
 [0x22D1]={
  category="sm",
  description="DOUBLE SUPERSET",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="Supset",
  mirror=0x22D0,
  unicodeslot=0x22D1,
 },
 [0x22D2]={
  category="sm",
  description="DOUBLE INTERSECTION",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="binary",
    name="Cap",
   },
   {
    class="binary",
    name="doublecap",
   },
  },
  unicodeslot=0x22D2,
 },
 [0x22D3]={
  category="sm",
  description="DOUBLE UNION",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="binary",
    name="Cup",
   },
   {
    class="binary",
    name="doublecup",
   },
  },
  unicodeslot=0x22D3,
 },
 [0x22D4]={
  category="sm",
  description="PITCHFORK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="pitchfork",
  unicodeslot=0x22D4,
 },
 [0x22D5]={
  category="sm",
  description="EQUAL AND PARALLEL TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x22D5,
 },
 [0x22D6]={
  category="sm",
  description="LESS-THAN WITH DOT",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="lessdot",
  mirror=0x22D7,
  unicodeslot=0x22D6,
 },
 [0x22D7]={
  category="sm",
  description="GREATER-THAN WITH DOT",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="gtrdot",
  mirror=0x22D6,
  unicodeslot=0x22D7,
 },
 [0x22D8]={
  category="sm",
  description="VERY MUCH LESS-THAN",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="lll",
   },
   {
    class="relation",
    name="llless",
   },
  },
  mirror=0x22D9,
  unicodeslot=0x22D8,
 },
 [0x22D9]={
  category="sm",
  description="VERY MUCH GREATER-THAN",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="relation",
    name="ggg",
   },
   {
    class="relation",
    name="gggtr",
   },
  },
  mirror=0x22D8,
  unicodeslot=0x22D9,
 },
 [0x22DA]={
  adobename="lessequalorgreater",
  category="sm",
  description="LESS-THAN EQUAL TO OR GREATER-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lesseqgtr",
  mirror=0x22DB,
  unicodeslot=0x22DA,
  variants={
   [0xFE00]="with slanted equal",
  },
 },
 [0x22DB]={
  adobename="greaterequalorless",
  category="sm",
  description="GREATER-THAN EQUAL TO OR LESS-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gtreqless",
  mirror=0x22DA,
  unicodeslot=0x22DB,
  variants={
   [0xFE00]="with slanted equal",
  },
 },
 [0x22DC]={
  category="sm",
  description="EQUAL TO OR LESS-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="eqless",
  mirror=0x22DD,
  unicodeslot=0x22DC,
 },
 [0x22DD]={
  category="sm",
  description="EQUAL TO OR GREATER-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="eqgtr",
  mirror=0x22DC,
  unicodeslot=0x22DD,
 },
 [0x22DE]={
  category="sm",
  description="EQUAL TO OR PRECEDES",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="curlyeqprec",
  mirror=0x22DF,
  unicodeslot=0x22DE,
 },
 [0x22DF]={
  category="sm",
  description="EQUAL TO OR SUCCEEDS",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="curlyeqsucc",
  mirror=0x22DE,
  unicodeslot=0x22DF,
 },
 [0x22E0]={
  category="sm",
  description="DOES NOT PRECEDE OR EQUAL",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="npreccurlyeq",
  mirror=0x22E1,
  specials={ "char", 0x227C, 0x0338 },
  unicodeslot=0x22E0,
 },
 [0x22E1]={
  category="sm",
  description="DOES NOT SUCCEED OR EQUAL",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsucccurlyeq",
  mirror=0x22E0,
  specials={ "char", 0x227D, 0x0338 },
  unicodeslot=0x22E1,
 },
 [0x22E2]={
  category="sm",
  description="NOT SQUARE IMAGE OF OR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsqsubseteq",
  mirror=0x22E3,
  specials={ "char", 0x2291, 0x0338 },
  unicodeslot=0x22E2,
 },
 [0x22E3]={
  category="sm",
  description="NOT SQUARE ORIGINAL OF OR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nsqsupseteq",
  mirror=0x22E2,
  specials={ "char", 0x2292, 0x0338 },
  unicodeslot=0x22E3,
 },
 [0x22E4]={
  category="sm",
  description="SQUARE IMAGE OF OR NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="sqsubsetneq",
  mirror=0x22E5,
  unicodeslot=0x22E4,
 },
 [0x22E5]={
  category="sm",
  description="SQUARE ORIGINAL OF OR NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="sqsupsetneq",
  mirror=0x22E4,
  unicodeslot=0x22E5,
 },
 [0x22E6]={
  category="sm",
  description="LESS-THAN BUT NOT EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lnsim",
  mirror=0x22E7,
  unicodeslot=0x22E6,
 },
 [0x22E7]={
  category="sm",
  description="GREATER-THAN BUT NOT EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gnsim",
  mirror=0x22E6,
  unicodeslot=0x22E7,
 },
 [0x22E8]={
  category="sm",
  description="PRECEDES BUT NOT EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="precnsim",
  mirror=0x22E9,
  unicodeslot=0x22E8,
 },
 [0x22E9]={
  category="sm",
  description="SUCCEEDS BUT NOT EQUIVALENT TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succnsim",
  mirror=0x22E8,
  unicodeslot=0x22E9,
 },
 [0x22EA]={
  category="sm",
  description="NOT NORMAL SUBGROUP OF",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="ntriangleright",
  mirror=0x22EB,
  specials={ "char", 0x22B2, 0x0338 },
  unicodeslot=0x22EA,
 },
 [0x22EB]={
  category="sm",
  description="DOES NOT CONTAIN AS NORMAL SUBGROUP",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="ntriangleleft",
  mirror=0x22EA,
  specials={ "char", 0x22B3, 0x0338 },
  unicodeslot=0x22EB,
 },
 [0x22EC]={
  category="sm",
  description="NOT NORMAL SUBGROUP OF OR EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="ntrianglelefteq",
  mirror=0x22ED,
  specials={ "char", 0x22B4, 0x0338 },
  unicodeslot=0x22EC,
 },
 [0x22ED]={
  category="sm",
  description="DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="ntrianglerighteq",
  mirror=0x22EC,
  specials={ "char", 0x22B5, 0x0338 },
  unicodeslot=0x22ED,
 },
 [0x22EE]={
  adobename="ellipsisvertical",
  category="sm",
  description="VERTICAL ELLIPSIS",
  direction="on",
  linebreak="al",
  mathclass="inner",
  mathname="vdots",
  unicodeslot=0x22EE,
 },
 [0x22EF]={
  category="sm",
  description="MIDLINE HORIZONTAL ELLIPSIS",
  direction="on",
  linebreak="al",
  mathclass="inner",
  mathname="cdots",
  unicodeslot=0x22EF,
 },
 [0x22F0]={
  category="sm",
  description="UP RIGHT DIAGONAL ELLIPSIS",
  direction="on",
  linebreak="al",
  mathclass="inner",
  mathname="udots",
  mirror=0x22F1,
  unicodeslot=0x22F0,
 },
 [0x22F1]={
  category="sm",
  description="DOWN RIGHT DIAGONAL ELLIPSIS",
  direction="on",
  linebreak="al",
  mathclass="inner",
  mathname="ddots",
  mirror=0x22F0,
  unicodeslot=0x22F1,
 },
 [0x22F2]={
  category="sm",
  description="ELEMENT OF WITH LONG HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  mirror=0x22FA,
  unicodeslot=0x22F2,
 },
 [0x22F3]={
  category="sm",
  description="ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  mirror=0x22FB,
  unicodeslot=0x22F3,
 },
 [0x22F4]={
  category="sm",
  description="SMALL ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  mirror=0x22FC,
  unicodeslot=0x22F4,
 },
 [0x22F5]={
  category="sm",
  description="ELEMENT OF WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x22F5,
 },
 [0x22F6]={
  category="sm",
  description="ELEMENT OF WITH OVERBAR",
  direction="on",
  linebreak="al",
  mirror=0x22FD,
  unicodeslot=0x22F6,
 },
 [0x22F7]={
  category="sm",
  description="SMALL ELEMENT OF WITH OVERBAR",
  direction="on",
  linebreak="al",
  mirror=0x22FE,
  unicodeslot=0x22F7,
 },
 [0x22F8]={
  category="sm",
  description="ELEMENT OF WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x22F8,
 },
 [0x22F9]={
  category="sm",
  description="ELEMENT OF WITH TWO HORIZONTAL STROKES",
  direction="on",
  linebreak="al",
  unicodeslot=0x22F9,
 },
 [0x22FA]={
  category="sm",
  description="CONTAINS WITH LONG HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  mirror=0x22F2,
  unicodeslot=0x22FA,
 },
 [0x22FB]={
  category="sm",
  description="CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  mirror=0x22F3,
  unicodeslot=0x22FB,
 },
 [0x22FC]={
  category="sm",
  description="SMALL CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  mirror=0x22F4,
  unicodeslot=0x22FC,
 },
 [0x22FD]={
  category="sm",
  description="CONTAINS WITH OVERBAR",
  direction="on",
  linebreak="al",
  mirror=0x22F6,
  unicodeslot=0x22FD,
 },
 [0x22FE]={
  category="sm",
  description="SMALL CONTAINS WITH OVERBAR",
  direction="on",
  linebreak="al",
  mirror=0x22F7,
  unicodeslot=0x22FE,
 },
 [0x22FF]={
  category="sm",
  description="Z NOTATION BAG MEMBERSHIP",
  direction="on",
  linebreak="al",
  unicodeslot=0x22FF,
 },
 [0x2300]={
  category="so",
  description="DIAMETER SIGN",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="varnothing",
  unicodeslot=0x2300,
 },
 [0x2301]={
  category="so",
  description="ELECTRIC ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2301,
 },
 [0x2302]={
  adobename="house",
  category="so",
  description="HOUSE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2302,
 },
 [0x2303]={
  adobename="control",
  category="so",
  description="UP ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x2303,
 },
 [0x2304]={
  category="so",
  description="DOWN ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x2304,
 },
 [0x2305]={
  adobename="projective",
  category="so",
  description="PROJECTIVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2305,
 },
 [0x2306]={
  category="so",
  description="PERSPECTIVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2306,
 },
 [0x2307]={
  category="so",
  description="WAVY LINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2307,
 },
 [0x2308]={
  category="sm",
  description="LEFT CEILING",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="open",
    name="lceil",
   },
   {
    class="open",
    name="lceiling",
   },
  },
  mirror=0x2309,
  unicodeslot=0x2308,
 },
 [0x2309]={
  category="sm",
  description="RIGHT CEILING",
  direction="on",
  linebreak="al",
  mathspec={
   {
    class="close",
    name="rceil",
   },
   {
    class="close",
    name="rceiling",
   },
  },
  mirror=0x2308,
  unicodeslot=0x2309,
 },
 [0x230A]={
  category="sm",
  description="LEFT FLOOR",
  direction="on",
  linebreak="al",
  mathclass="open",
  mathname="lfloor",
  mirror=0x230B,
  unicodeslot=0x230A,
 },
 [0x230B]={
  category="sm",
  description="RIGHT FLOOR",
  direction="on",
  linebreak="al",
  mathclass="close",
  mathname="rfloor",
  mirror=0x230A,
  unicodeslot=0x230B,
 },
 [0x230C]={
  category="so",
  description="BOTTOM RIGHT CROP",
  direction="on",
  linebreak="al",
  unicodeslot=0x230C,
 },
 [0x230D]={
  category="so",
  description="BOTTOM LEFT CROP",
  direction="on",
  linebreak="al",
  unicodeslot=0x230D,
 },
 [0x230E]={
  category="so",
  description="TOP RIGHT CROP",
  direction="on",
  linebreak="al",
  unicodeslot=0x230E,
 },
 [0x230F]={
  category="so",
  description="TOP LEFT CROP",
  direction="on",
  linebreak="al",
  unicodeslot=0x230F,
 },
 [0x2310]={
  adobename="revlogicalnot",
  category="so",
  description="REVERSED NOT SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2310,
 },
 [0x2311]={
  category="so",
  description="SQUARE LOZENGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2311,
 },
 [0x2312]={
  adobename="arc",
  category="so",
  cjkwd="a",
  description="ARC",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2312,
 },
 [0x2313]={
  category="so",
  description="SEGMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2313,
 },
 [0x2314]={
  category="so",
  description="SECTOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2314,
 },
 [0x2315]={
  category="so",
  description="TELEPHONE RECORDER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2315,
 },
 [0x2316]={
  category="so",
  description="POSITION INDICATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2316,
 },
 [0x2317]={
  category="so",
  description="VIEWDATA SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2317,
 },
 [0x2318]={
  adobename="propellor",
  category="so",
  description="PLACE OF INTEREST SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2318,
 },
 [0x2319]={
  category="so",
  description="TURNED NOT SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2319,
 },
 [0x231A]={
  category="so",
  description="WATCH",
  direction="on",
  linebreak="id",
  unicodeslot=0x231A,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x231B]={
  category="so",
  description="HOURGLASS",
  direction="on",
  linebreak="id",
  unicodeslot=0x231B,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x231C]={
  category="so",
  description="TOP LEFT CORNER",
  direction="on",
  linebreak="al",
  mathclass="open",
  mathname="ulcorner",
  unicodeslot=0x231C,
 },
 [0x231D]={
  category="so",
  description="TOP RIGHT CORNER",
  direction="on",
  linebreak="al",
  mathclass="close",
  mathname="urcorner",
  unicodeslot=0x231D,
 },
 [0x231E]={
  category="so",
  description="BOTTOM LEFT CORNER",
  direction="on",
  linebreak="al",
  mathclass="open",
  mathname="llcorner",
  unicodeslot=0x231E,
 },
 [0x231F]={
  category="so",
  description="BOTTOM RIGHT CORNER",
  direction="on",
  linebreak="al",
  mathclass="close",
  mathname="lrcorner",
  unicodeslot=0x231F,
 },
 [0x2320]={
  adobename="integraltp",
  category="sm",
  description="TOP HALF INTEGRAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2320,
 },
 [0x2321]={
  adobename="integralbt",
  category="sm",
  description="BOTTOM HALF INTEGRAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2321,
 },
 [0x2322]={
  category="so",
  description="FROWN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="frown",
  unicodeslot=0x2322,
 },
 [0x2323]={
  category="so",
  description="SMILE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="smile",
  unicodeslot=0x2323,
 },
 [0x2324]={
  category="so",
  description="UP ARROWHEAD BETWEEN TWO HORIZONTAL BARS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2324,
 },
 [0x2325]={
  adobename="option",
  category="so",
  description="OPTION KEY",
  direction="on",
  linebreak="al",
  unicodeslot=0x2325,
 },
 [0x2326]={
  adobename="deleteright",
  category="so",
  description="ERASE TO THE RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2326,
 },
 [0x2327]={
  adobename="clear",
  category="so",
  description="X IN A RECTANGLE BOX",
  direction="on",
  linebreak="al",
  unicodeslot=0x2327,
 },
 [0x2328]={
  category="so",
  description="KEYBOARD",
  direction="on",
  linebreak="al",
  unicodeslot=0x2328,
 },
 [0x2329]={
  adobename="angleleft",
  category="ps",
  cjkwd="w",
  description="LEFT-POINTING ANGLE BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x232A,
  specials={ "char", 0x3008 },
  unicodeslot=0x2329,
 },
 [0x232A]={
  adobename="angleright",
  category="pe",
  cjkwd="w",
  description="RIGHT-POINTING ANGLE BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2329,
  specials={ "char", 0x3009 },
  unicodeslot=0x232A,
 },
 [0x232B]={
  adobename="deleteleft",
  category="so",
  description="ERASE TO THE LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x232B,
 },
 [0x232C]={
  category="so",
  description="BENZENE RING",
  direction="on",
  linebreak="al",
  unicodeslot=0x232C,
 },
 [0x232D]={
  category="so",
  description="CYLINDRICITY",
  direction="on",
  linebreak="al",
  unicodeslot=0x232D,
 },
 [0x232E]={
  category="so",
  description="ALL AROUND-PROFILE",
  direction="on",
  linebreak="al",
  unicodeslot=0x232E,
 },
 [0x232F]={
  category="so",
  description="SYMMETRY",
  direction="on",
  linebreak="al",
  unicodeslot=0x232F,
 },
 [0x2330]={
  category="so",
  description="TOTAL RUNOUT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2330,
 },
 [0x2331]={
  category="so",
  description="DIMENSION ORIGIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2331,
 },
 [0x2332]={
  category="so",
  description="CONICAL TAPER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2332,
 },
 [0x2333]={
  category="so",
  description="SLOPE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2333,
 },
 [0x2334]={
  category="so",
  description="COUNTERBORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2334,
 },
 [0x2335]={
  category="so",
  description="COUNTERSINK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2335,
 },
 [0x2336]={
  category="so",
  description="APL FUNCTIONAL SYMBOL I-BEAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x2336,
 },
 [0x2337]={
  category="so",
  description="APL FUNCTIONAL SYMBOL SQUISH QUAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x2337,
 },
 [0x2338]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD EQUAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x2338,
 },
 [0x2339]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD DIVIDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2339,
 },
 [0x233A]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD DIAMOND",
  direction="l",
  linebreak="al",
  unicodeslot=0x233A,
 },
 [0x233B]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD JOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x233B,
 },
 [0x233C]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD CIRCLE",
  direction="l",
  linebreak="al",
  unicodeslot=0x233C,
 },
 [0x233D]={
  category="so",
  description="APL FUNCTIONAL SYMBOL CIRCLE STILE",
  direction="l",
  linebreak="al",
  unicodeslot=0x233D,
 },
 [0x233E]={
  category="so",
  description="APL FUNCTIONAL SYMBOL CIRCLE JOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x233E,
 },
 [0x233F]={
  category="so",
  description="APL FUNCTIONAL SYMBOL SLASH BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x233F,
 },
 [0x2340]={
  category="so",
  description="APL FUNCTIONAL SYMBOL BACKSLASH BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2340,
 },
 [0x2341]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD SLASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2341,
 },
 [0x2342]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD BACKSLASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2342,
 },
 [0x2343]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD LESS-THAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x2343,
 },
 [0x2344]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD GREATER-THAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x2344,
 },
 [0x2345]={
  category="so",
  description="APL FUNCTIONAL SYMBOL LEFTWARDS VANE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2345,
 },
 [0x2346]={
  category="so",
  description="APL FUNCTIONAL SYMBOL RIGHTWARDS VANE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2346,
 },
 [0x2347]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD LEFTWARDS ARROW",
  direction="l",
  linebreak="al",
  unicodeslot=0x2347,
 },
 [0x2348]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD RIGHTWARDS ARROW",
  direction="l",
  linebreak="al",
  unicodeslot=0x2348,
 },
 [0x2349]={
  category="so",
  description="APL FUNCTIONAL SYMBOL CIRCLE BACKSLASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2349,
 },
 [0x234A]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DOWN TACK UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x234A,
 },
 [0x234B]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DELTA STILE",
  direction="l",
  linebreak="al",
  unicodeslot=0x234B,
 },
 [0x234C]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD DOWN CARET",
  direction="l",
  linebreak="al",
  unicodeslot=0x234C,
 },
 [0x234D]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD DELTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x234D,
 },
 [0x234E]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DOWN TACK JOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x234E,
 },
 [0x234F]={
  category="so",
  description="APL FUNCTIONAL SYMBOL UPWARDS VANE",
  direction="l",
  linebreak="al",
  unicodeslot=0x234F,
 },
 [0x2350]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD UPWARDS ARROW",
  direction="l",
  linebreak="al",
  unicodeslot=0x2350,
 },
 [0x2351]={
  category="so",
  description="APL FUNCTIONAL SYMBOL UP TACK OVERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2351,
 },
 [0x2352]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DEL STILE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2352,
 },
 [0x2353]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD UP CARET",
  direction="l",
  linebreak="al",
  unicodeslot=0x2353,
 },
 [0x2354]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD DEL",
  direction="l",
  linebreak="al",
  unicodeslot=0x2354,
 },
 [0x2355]={
  category="so",
  description="APL FUNCTIONAL SYMBOL UP TACK JOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x2355,
 },
 [0x2356]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DOWNWARDS VANE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2356,
 },
 [0x2357]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD DOWNWARDS ARROW",
  direction="l",
  linebreak="al",
  unicodeslot=0x2357,
 },
 [0x2358]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUOTE UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2358,
 },
 [0x2359]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DELTA UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2359,
 },
 [0x235A]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DIAMOND UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x235A,
 },
 [0x235B]={
  category="so",
  description="APL FUNCTIONAL SYMBOL JOT UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x235B,
 },
 [0x235C]={
  category="so",
  description="APL FUNCTIONAL SYMBOL CIRCLE UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x235C,
 },
 [0x235D]={
  category="so",
  description="APL FUNCTIONAL SYMBOL UP SHOE JOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x235D,
 },
 [0x235E]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUOTE QUAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x235E,
 },
 [0x235F]={
  category="so",
  description="APL FUNCTIONAL SYMBOL CIRCLE STAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x235F,
 },
 [0x2360]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD COLON",
  direction="l",
  linebreak="al",
  unicodeslot=0x2360,
 },
 [0x2361]={
  category="so",
  description="APL FUNCTIONAL SYMBOL UP TACK DIAERESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2361,
 },
 [0x2362]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DEL DIAERESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2362,
 },
 [0x2363]={
  category="so",
  description="APL FUNCTIONAL SYMBOL STAR DIAERESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2363,
 },
 [0x2364]={
  category="so",
  description="APL FUNCTIONAL SYMBOL JOT DIAERESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2364,
 },
 [0x2365]={
  category="so",
  description="APL FUNCTIONAL SYMBOL CIRCLE DIAERESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2365,
 },
 [0x2366]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DOWN SHOE STILE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2366,
 },
 [0x2367]={
  category="so",
  description="APL FUNCTIONAL SYMBOL LEFT SHOE STILE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2367,
 },
 [0x2368]={
  category="so",
  description="APL FUNCTIONAL SYMBOL TILDE DIAERESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2368,
 },
 [0x2369]={
  category="so",
  description="APL FUNCTIONAL SYMBOL GREATER-THAN DIAERESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2369,
 },
 [0x236A]={
  category="so",
  description="APL FUNCTIONAL SYMBOL COMMA BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x236A,
 },
 [0x236B]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DEL TILDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x236B,
 },
 [0x236C]={
  category="so",
  description="APL FUNCTIONAL SYMBOL ZILDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x236C,
 },
 [0x236D]={
  category="so",
  description="APL FUNCTIONAL SYMBOL STILE TILDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x236D,
 },
 [0x236E]={
  category="so",
  description="APL FUNCTIONAL SYMBOL SEMICOLON UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x236E,
 },
 [0x236F]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD NOT EQUAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x236F,
 },
 [0x2370]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD QUESTION",
  direction="l",
  linebreak="al",
  unicodeslot=0x2370,
 },
 [0x2371]={
  category="so",
  description="APL FUNCTIONAL SYMBOL DOWN CARET TILDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2371,
 },
 [0x2372]={
  category="so",
  description="APL FUNCTIONAL SYMBOL UP CARET TILDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2372,
 },
 [0x2373]={
  category="so",
  description="APL FUNCTIONAL SYMBOL IOTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2373,
 },
 [0x2374]={
  category="so",
  description="APL FUNCTIONAL SYMBOL RHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2374,
 },
 [0x2375]={
  category="so",
  description="APL FUNCTIONAL SYMBOL OMEGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2375,
 },
 [0x2376]={
  category="so",
  description="APL FUNCTIONAL SYMBOL ALPHA UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2376,
 },
 [0x2377]={
  category="so",
  description="APL FUNCTIONAL SYMBOL EPSILON UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2377,
 },
 [0x2378]={
  category="so",
  description="APL FUNCTIONAL SYMBOL IOTA UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2378,
 },
 [0x2379]={
  category="so",
  description="APL FUNCTIONAL SYMBOL OMEGA UNDERBAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2379,
 },
 [0x237A]={
  category="so",
  description="APL FUNCTIONAL SYMBOL ALPHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x237A,
 },
 [0x237B]={
  category="so",
  description="NOT CHECK MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x237B,
 },
 [0x237C]={
  category="sm",
  description="RIGHT ANGLE WITH DOWNWARDS ZIGZAG ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x237C,
 },
 [0x237D]={
  category="so",
  description="SHOULDERED OPEN BOX",
  direction="on",
  linebreak="al",
  unicodeslot=0x237D,
 },
 [0x237E]={
  category="so",
  description="BELL SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x237E,
 },
 [0x237F]={
  category="so",
  description="VERTICAL LINE WITH MIDDLE DOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x237F,
 },
 [0x2380]={
  category="so",
  description="INSERTION SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2380,
 },
 [0x2381]={
  category="so",
  description="CONTINUOUS UNDERLINE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2381,
 },
 [0x2382]={
  category="so",
  description="DISCONTINUOUS UNDERLINE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2382,
 },
 [0x2383]={
  category="so",
  description="EMPHASIS SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2383,
 },
 [0x2384]={
  category="so",
  description="COMPOSITION SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2384,
 },
 [0x2385]={
  category="so",
  description="WHITE SQUARE WITH CENTRE VERTICAL LINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2385,
 },
 [0x2386]={
  category="so",
  description="ENTER SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2386,
 },
 [0x2387]={
  category="so",
  description="ALTERNATIVE KEY SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2387,
 },
 [0x2388]={
  category="so",
  description="HELM SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2388,
 },
 [0x2389]={
  category="so",
  description="CIRCLED HORIZONTAL BAR WITH NOTCH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2389,
 },
 [0x238A]={
  category="so",
  description="CIRCLED TRIANGLE DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x238A,
 },
 [0x238B]={
  category="so",
  description="BROKEN CIRCLE WITH NORTHWEST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x238B,
 },
 [0x238C]={
  category="so",
  description="UNDO SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x238C,
 },
 [0x238D]={
  category="so",
  description="MONOSTABLE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x238D,
 },
 [0x238E]={
  category="so",
  description="HYSTERESIS SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x238E,
 },
 [0x238F]={
  category="so",
  description="OPEN-CIRCUIT-OUTPUT H-TYPE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x238F,
 },
 [0x2390]={
  category="so",
  description="OPEN-CIRCUIT-OUTPUT L-TYPE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2390,
 },
 [0x2391]={
  category="so",
  description="PASSIVE-PULL-DOWN-OUTPUT SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2391,
 },
 [0x2392]={
  category="so",
  description="PASSIVE-PULL-UP-OUTPUT SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2392,
 },
 [0x2393]={
  category="so",
  description="DIRECT CURRENT SYMBOL FORM TWO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2393,
 },
 [0x2394]={
  category="so",
  description="SOFTWARE-FUNCTION SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2394,
 },
 [0x2395]={
  category="so",
  description="APL FUNCTIONAL SYMBOL QUAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x2395,
 },
 [0x2396]={
  category="so",
  description="DECIMAL SEPARATOR KEY SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2396,
 },
 [0x2397]={
  category="so",
  description="PREVIOUS PAGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2397,
 },
 [0x2398]={
  category="so",
  description="NEXT PAGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2398,
 },
 [0x2399]={
  category="so",
  description="PRINT SCREEN SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2399,
 },
 [0x239A]={
  category="so",
  description="CLEAR SCREEN SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x239A,
 },
 [0x239B]={
  category="sm",
  description="LEFT PARENTHESIS UPPER HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x239B,
 },
 [0x239C]={
  category="sm",
  description="LEFT PARENTHESIS EXTENSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x239C,
 },
 [0x239D]={
  category="sm",
  description="LEFT PARENTHESIS LOWER HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x239D,
 },
 [0x239E]={
  category="sm",
  description="RIGHT PARENTHESIS UPPER HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x239E,
 },
 [0x239F]={
  category="sm",
  description="RIGHT PARENTHESIS EXTENSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x239F,
 },
 [0x23A0]={
  category="sm",
  description="RIGHT PARENTHESIS LOWER HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A0,
 },
 [0x23A1]={
  category="sm",
  description="LEFT SQUARE BRACKET UPPER CORNER",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A1,
 },
 [0x23A2]={
  category="sm",
  description="LEFT SQUARE BRACKET EXTENSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A2,
 },
 [0x23A3]={
  category="sm",
  description="LEFT SQUARE BRACKET LOWER CORNER",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A3,
 },
 [0x23A4]={
  category="sm",
  description="RIGHT SQUARE BRACKET UPPER CORNER",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A4,
 },
 [0x23A5]={
  category="sm",
  description="RIGHT SQUARE BRACKET EXTENSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A5,
 },
 [0x23A6]={
  category="sm",
  description="RIGHT SQUARE BRACKET LOWER CORNER",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A6,
 },
 [0x23A7]={
  category="sm",
  description="LEFT CURLY BRACKET UPPER HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A7,
 },
 [0x23A8]={
  category="sm",
  description="LEFT CURLY BRACKET MIDDLE PIECE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A8,
 },
 [0x23A9]={
  category="sm",
  description="LEFT CURLY BRACKET LOWER HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x23A9,
 },
 [0x23AA]={
  category="sm",
  description="CURLY BRACKET EXTENSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x23AA,
 },
 [0x23AB]={
  category="sm",
  description="RIGHT CURLY BRACKET UPPER HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x23AB,
 },
 [0x23AC]={
  category="sm",
  description="RIGHT CURLY BRACKET MIDDLE PIECE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23AC,
 },
 [0x23AD]={
  category="sm",
  description="RIGHT CURLY BRACKET LOWER HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x23AD,
 },
 [0x23AE]={
  category="sm",
  description="INTEGRAL EXTENSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x23AE,
 },
 [0x23AF]={
  category="sm",
  description="HORIZONTAL LINE EXTENSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x23AF,
 },
 [0x23B0]={
  category="sm",
  description="UPPER LEFT OR LOWER RIGHT CURLY BRACKET SECTION",
  direction="on",
  linebreak="al",
  mathclass="open",
  mathname="lmoustache",
  unicodeslot=0x23B0,
 },
 [0x23B1]={
  category="sm",
  description="UPPER RIGHT OR LOWER LEFT CURLY BRACKET SECTION",
  direction="on",
  linebreak="al",
  mathclass="close",
  mathname="rmoustache",
  unicodeslot=0x23B1,
 },
 [0x23B2]={
  category="sm",
  description="SUMMATION TOP",
  direction="on",
  linebreak="al",
  unicodeslot=0x23B2,
 },
 [0x23B3]={
  category="sm",
  description="SUMMATION BOTTOM",
  direction="on",
  linebreak="al",
  unicodeslot=0x23B3,
 },
 [0x23B4]={
  category="so",
  description="TOP SQUARE BRACKET",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  mathname="overbracket",
  unicodeslot=0x23B4,
 },
 [0x23B5]={
  category="so",
  description="BOTTOM SQUARE BRACKET",
  direction="on",
  linebreak="al",
  mathclass="botaccent",
  mathname="underbracket",
  unicodeslot=0x23B5,
 },
 [0x23B6]={
  category="so",
  description="BOTTOM SQUARE BRACKET OVER TOP SQUARE BRACKET",
  direction="on",
  linebreak="al",
  unicodeslot=0x23B6,
 },
 [0x23B7]={
  category="so",
  description="RADICAL SYMBOL BOTTOM",
  direction="on",
  linebreak="al",
  unicodeslot=0x23B7,
 },
 [0x23B8]={
  category="so",
  description="LEFT VERTICAL BOX LINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23B8,
 },
 [0x23B9]={
  category="so",
  description="RIGHT VERTICAL BOX LINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23B9,
 },
 [0x23BA]={
  category="so",
  description="HORIZONTAL SCAN LINE-0x0001",
  direction="on",
  linebreak="al",
  unicodeslot=0x23BA,
 },
 [0x23BB]={
  category="so",
  description="HORIZONTAL SCAN LINE-0x0003",
  direction="on",
  linebreak="al",
  unicodeslot=0x23BB,
 },
 [0x23BC]={
  category="so",
  description="HORIZONTAL SCAN LINE-0x0007",
  direction="on",
  linebreak="al",
  unicodeslot=0x23BC,
 },
 [0x23BD]={
  category="so",
  description="HORIZONTAL SCAN LINE-0x0009",
  direction="on",
  linebreak="al",
  unicodeslot=0x23BD,
 },
 [0x23BE]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT VERTICAL AND TOP RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x23BE,
 },
 [0x23BF]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x23BF,
 },
 [0x23C0]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT VERTICAL WITH CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C0,
 },
 [0x23C1]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C1,
 },
 [0x23C2]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C2,
 },
 [0x23C3]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT VERTICAL WITH TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C3,
 },
 [0x23C4]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C4,
 },
 [0x23C5]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C5,
 },
 [0x23C6]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT VERTICAL AND WAVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C6,
 },
 [0x23C7]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH WAVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C7,
 },
 [0x23C8]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH WAVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C8,
 },
 [0x23C9]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x23C9,
 },
 [0x23CA]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x23CA,
 },
 [0x23CB]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT VERTICAL AND TOP LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x23CB,
 },
 [0x23CC]={
  category="so",
  description="DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x23CC,
 },
 [0x23CD]={
  category="so",
  description="SQUARE FOOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x23CD,
 },
 [0x23CE]={
  category="so",
  description="RETURN SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x23CE,
 },
 [0x23CF]={
  category="so",
  description="EJECT SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x23CF,
 },
 [0x23D0]={
  category="so",
  description="VERTICAL LINE EXTENSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D0,
 },
 [0x23D1]={
  category="so",
  description="METRICAL BREVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D1,
 },
 [0x23D2]={
  category="so",
  description="METRICAL LONG OVER SHORT",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D2,
 },
 [0x23D3]={
  category="so",
  description="METRICAL SHORT OVER LONG",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D3,
 },
 [0x23D4]={
  category="so",
  description="METRICAL LONG OVER TWO SHORTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D4,
 },
 [0x23D5]={
  category="so",
  description="METRICAL TWO SHORTS OVER LONG",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D5,
 },
 [0x23D6]={
  category="so",
  description="METRICAL TWO SHORTS JOINED",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D6,
 },
 [0x23D7]={
  category="so",
  description="METRICAL TRISEME",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D7,
 },
 [0x23D8]={
  category="so",
  description="METRICAL TETRASEME",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D8,
 },
 [0x23D9]={
  category="so",
  description="METRICAL PENTASEME",
  direction="on",
  linebreak="al",
  unicodeslot=0x23D9,
 },
 [0x23DA]={
  category="so",
  description="EARTH GROUND",
  direction="on",
  linebreak="al",
  unicodeslot=0x23DA,
 },
 [0x23DB]={
  category="so",
  description="FUSE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23DB,
 },
 [0x23DC]={
  category="sm",
  description="TOP PARENTHESIS",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  mathname="overparent",
  unicodeslot=0x23DC,
 },
 [0x23DD]={
  category="sm",
  description="BOTTOM PARENTHESIS",
  direction="on",
  linebreak="al",
  mathclass="botaccent",
  mathname="underparent",
  unicodeslot=0x23DD,
 },
 [0x23DE]={
  category="sm",
  description="TOP CURLY BRACKET",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  mathname="overbrace",
  unicodeslot=0x23DE,
 },
 [0x23DF]={
  category="sm",
  description="BOTTOM CURLY BRACKET",
  direction="on",
  linebreak="al",
  mathclass="botaccent",
  mathname="underbrace",
  unicodeslot=0x23DF,
 },
 [0x23E0]={
  category="sm",
  description="TOP TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="al",
  mathclass="topaccent",
  unicodeslot=0x23E0,
 },
 [0x23E1]={
  category="sm",
  description="BOTTOM TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="al",
  mathclass="botaccent",
  unicodeslot=0x23E1,
 },
 [0x23E2]={
  category="so",
  description="WHITE TRAPEZIUM",
  direction="on",
  linebreak="al",
  unicodeslot=0x23E2,
 },
 [0x23E3]={
  category="so",
  description="BENZENE RING WITH CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23E3,
 },
 [0x23E4]={
  category="so",
  description="STRAIGHTNESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x23E4,
 },
 [0x23E5]={
  category="so",
  description="FLATNESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x23E5,
 },
 [0x23E6]={
  category="so",
  description="AC CURRENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x23E6,
 },
 [0x23E7]={
  category="so",
  description="ELECTRICAL INTERSECTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x23E7,
 },
 [0x23E8]={
  category="so",
  description="DECIMAL EXPONENT SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x23E8,
 },
 [0x23E9]={
  category="so",
  description="BLACK RIGHT-POINTING DOUBLE TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23E9,
 },
 [0x23EA]={
  category="so",
  description="BLACK LEFT-POINTING DOUBLE TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23EA,
 },
 [0x23EB]={
  category="so",
  description="BLACK UP-POINTING DOUBLE TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23EB,
 },
 [0x23EC]={
  category="so",
  description="BLACK DOWN-POINTING DOUBLE TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x23EC,
 },
 [0x23ED]={
  category="so",
  description="BLACK RIGHT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x23ED,
 },
 [0x23EE]={
  category="so",
  description="BLACK LEFT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x23EE,
 },
 [0x23EF]={
  category="so",
  description="BLACK RIGHT-POINTING TRIANGLE WITH DOUBLE VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x23EF,
 },
 [0x23F0]={
  category="so",
  description="ALARM CLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x23F0,
 },
 [0x23F1]={
  category="so",
  description="STOPWATCH",
  direction="on",
  linebreak="id",
  unicodeslot=0x23F1,
 },
 [0x23F2]={
  category="so",
  description="TIMER CLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x23F2,
 },
 [0x23F3]={
  category="so",
  description="HOURGLASS WITH FLOWING SAND",
  direction="on",
  linebreak="id",
  unicodeslot=0x23F3,
 },
 [0x2400]={
  category="so",
  description="SYMBOL FOR NULL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2400,
 },
 [0x2401]={
  category="so",
  description="SYMBOL FOR START OF HEADING",
  direction="on",
  linebreak="al",
  unicodeslot=0x2401,
 },
 [0x2402]={
  category="so",
  description="SYMBOL FOR START OF TEXT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2402,
 },
 [0x2403]={
  category="so",
  description="SYMBOL FOR END OF TEXT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2403,
 },
 [0x2404]={
  category="so",
  description="SYMBOL FOR END OF TRANSMISSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2404,
 },
 [0x2405]={
  category="so",
  description="SYMBOL FOR ENQUIRY",
  direction="on",
  linebreak="al",
  unicodeslot=0x2405,
 },
 [0x2406]={
  category="so",
  description="SYMBOL FOR ACKNOWLEDGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2406,
 },
 [0x2407]={
  category="so",
  description="SYMBOL FOR BELL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2407,
 },
 [0x2408]={
  category="so",
  description="SYMBOL FOR BACKSPACE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2408,
 },
 [0x2409]={
  category="so",
  description="SYMBOL FOR HORIZONTAL TABULATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2409,
 },
 [0x240A]={
  category="so",
  description="SYMBOL FOR LINE FEED",
  direction="on",
  linebreak="al",
  unicodeslot=0x240A,
 },
 [0x240B]={
  category="so",
  description="SYMBOL FOR VERTICAL TABULATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x240B,
 },
 [0x240C]={
  category="so",
  description="SYMBOL FOR FORM FEED",
  direction="on",
  linebreak="al",
  unicodeslot=0x240C,
 },
 [0x240D]={
  category="so",
  description="SYMBOL FOR CARRIAGE RETURN",
  direction="on",
  linebreak="al",
  unicodeslot=0x240D,
 },
 [0x240E]={
  category="so",
  description="SYMBOL FOR SHIFT OUT",
  direction="on",
  linebreak="al",
  unicodeslot=0x240E,
 },
 [0x240F]={
  category="so",
  description="SYMBOL FOR SHIFT IN",
  direction="on",
  linebreak="al",
  unicodeslot=0x240F,
 },
 [0x2410]={
  category="so",
  description="SYMBOL FOR DATA LINK ESCAPE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2410,
 },
 [0x2411]={
  category="so",
  description="SYMBOL FOR DEVICE CONTROL ONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2411,
 },
 [0x2412]={
  category="so",
  description="SYMBOL FOR DEVICE CONTROL TWO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2412,
 },
 [0x2413]={
  category="so",
  description="SYMBOL FOR DEVICE CONTROL THREE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2413,
 },
 [0x2414]={
  category="so",
  description="SYMBOL FOR DEVICE CONTROL FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2414,
 },
 [0x2415]={
  category="so",
  description="SYMBOL FOR NEGATIVE ACKNOWLEDGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2415,
 },
 [0x2416]={
  category="so",
  description="SYMBOL FOR SYNCHRONOUS IDLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2416,
 },
 [0x2417]={
  category="so",
  description="SYMBOL FOR END OF TRANSMISSION BLOCK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2417,
 },
 [0x2418]={
  category="so",
  description="SYMBOL FOR CANCEL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2418,
 },
 [0x2419]={
  category="so",
  description="SYMBOL FOR END OF MEDIUM",
  direction="on",
  linebreak="al",
  unicodeslot=0x2419,
 },
 [0x241A]={
  category="so",
  description="SYMBOL FOR SUBSTITUTE",
  direction="on",
  linebreak="al",
  unicodeslot=0x241A,
 },
 [0x241B]={
  category="so",
  description="SYMBOL FOR ESCAPE",
  direction="on",
  linebreak="al",
  unicodeslot=0x241B,
 },
 [0x241C]={
  category="so",
  description="SYMBOL FOR FILE SEPARATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x241C,
 },
 [0x241D]={
  category="so",
  description="SYMBOL FOR GROUP SEPARATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x241D,
 },
 [0x241E]={
  category="so",
  description="SYMBOL FOR RECORD SEPARATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x241E,
 },
 [0x241F]={
  category="so",
  description="SYMBOL FOR UNIT SEPARATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x241F,
 },
 [0x2420]={
  category="so",
  description="SYMBOL FOR SPACE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2420,
 },
 [0x2421]={
  category="so",
  description="SYMBOL FOR DELETE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2421,
 },
 [0x2422]={
  category="so",
  description="BLANK SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2422,
 },
 [0x2423]={
  adobename="blank",
  category="so",
  description="OPEN BOX",
  direction="on",
  linebreak="al",
  unicodeslot=0x2423,
 },
 [0x2424]={
  category="so",
  description="SYMBOL FOR NEWLINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2424,
 },
 [0x2425]={
  category="so",
  description="SYMBOL FOR DELETE FORM TWO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2425,
 },
 [0x2426]={
  category="so",
  description="SYMBOL FOR SUBSTITUTE FORM TWO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2426,
 },
 [0x2440]={
  category="so",
  description="OCR HOOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2440,
 },
 [0x2441]={
  category="so",
  description="OCR CHAIR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2441,
 },
 [0x2442]={
  category="so",
  description="OCR FORK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2442,
 },
 [0x2443]={
  category="so",
  description="OCR INVERTED FORK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2443,
 },
 [0x2444]={
  category="so",
  description="OCR BELT BUCKLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2444,
 },
 [0x2445]={
  category="so",
  description="OCR BOW TIE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2445,
 },
 [0x2446]={
  category="so",
  description="OCR BRANCH BANK IDENTIFICATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2446,
 },
 [0x2447]={
  category="so",
  description="OCR AMOUNT OF CHECK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2447,
 },
 [0x2448]={
  category="so",
  description="OCR DASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2448,
 },
 [0x2449]={
  category="so",
  description="OCR CUSTOMER ACCOUNT NUMBER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2449,
 },
 [0x244A]={
  category="so",
  description="OCR DOUBLE BACKSLASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x244A,
 },
 [0x2460]={
  adobename="onecircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT ONE",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031 },
  unicodeslot=0x2460,
 },
 [0x2461]={
  adobename="twocircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT TWO",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0032 },
  unicodeslot=0x2461,
 },
 [0x2462]={
  adobename="threecircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT THREE",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0033 },
  unicodeslot=0x2462,
 },
 [0x2463]={
  adobename="fourcircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT FOUR",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0034 },
  unicodeslot=0x2463,
 },
 [0x2464]={
  adobename="fivecircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT FIVE",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0035 },
  unicodeslot=0x2464,
 },
 [0x2465]={
  adobename="sixcircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT SIX",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0036 },
  unicodeslot=0x2465,
 },
 [0x2466]={
  adobename="sevencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT SEVEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0037 },
  unicodeslot=0x2466,
 },
 [0x2467]={
  adobename="eightcircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT EIGHT",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0038 },
  unicodeslot=0x2467,
 },
 [0x2468]={
  adobename="ninecircle",
  category="no",
  cjkwd="a",
  description="CIRCLED DIGIT NINE",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0039 },
  unicodeslot=0x2468,
 },
 [0x2469]={
  adobename="tencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER TEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0030 },
  unicodeslot=0x2469,
 },
 [0x246A]={
  adobename="elevencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER ELEVEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0031 },
  unicodeslot=0x246A,
 },
 [0x246B]={
  adobename="twelvecircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER TWELVE",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0032 },
  unicodeslot=0x246B,
 },
 [0x246C]={
  adobename="thirteencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER THIRTEEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0033 },
  unicodeslot=0x246C,
 },
 [0x246D]={
  adobename="fourteencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER FOURTEEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0034 },
  unicodeslot=0x246D,
 },
 [0x246E]={
  adobename="fifteencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER FIFTEEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0035 },
  unicodeslot=0x246E,
 },
 [0x246F]={
  adobename="sixteencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER SIXTEEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0036 },
  unicodeslot=0x246F,
 },
 [0x2470]={
  adobename="seventeencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER SEVENTEEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0037 },
  unicodeslot=0x2470,
 },
 [0x2471]={
  adobename="eighteencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER EIGHTEEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0038 },
  unicodeslot=0x2471,
 },
 [0x2472]={
  adobename="nineteencircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER NINETEEN",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0031, 0x0039 },
  unicodeslot=0x2472,
 },
 [0x2473]={
  adobename="twentycircle",
  category="no",
  cjkwd="a",
  description="CIRCLED NUMBER TWENTY",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0032, 0x0030 },
  unicodeslot=0x2473,
 },
 [0x2474]={
  adobename="oneparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT ONE",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0029 },
  unicodeslot=0x2474,
 },
 [0x2475]={
  adobename="twoparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT TWO",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0032, 0x0029 },
  unicodeslot=0x2475,
 },
 [0x2476]={
  adobename="threeparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT THREE",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0033, 0x0029 },
  unicodeslot=0x2476,
 },
 [0x2477]={
  adobename="fourparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT FOUR",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0034, 0x0029 },
  unicodeslot=0x2477,
 },
 [0x2478]={
  adobename="fiveparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT FIVE",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0035, 0x0029 },
  unicodeslot=0x2478,
 },
 [0x2479]={
  adobename="sixparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT SIX",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0036, 0x0029 },
  unicodeslot=0x2479,
 },
 [0x247A]={
  adobename="sevenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT SEVEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0037, 0x0029 },
  unicodeslot=0x247A,
 },
 [0x247B]={
  adobename="eightparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT EIGHT",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0038, 0x0029 },
  unicodeslot=0x247B,
 },
 [0x247C]={
  adobename="nineparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED DIGIT NINE",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0039, 0x0029 },
  unicodeslot=0x247C,
 },
 [0x247D]={
  adobename="tenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER TEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0030, 0x0029 },
  unicodeslot=0x247D,
 },
 [0x247E]={
  adobename="elevenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER ELEVEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0031, 0x0029 },
  unicodeslot=0x247E,
 },
 [0x247F]={
  adobename="twelveparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER TWELVE",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0032, 0x0029 },
  unicodeslot=0x247F,
 },
 [0x2480]={
  adobename="thirteenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER THIRTEEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0033, 0x0029 },
  unicodeslot=0x2480,
 },
 [0x2481]={
  adobename="fourteenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER FOURTEEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0034, 0x0029 },
  unicodeslot=0x2481,
 },
 [0x2482]={
  adobename="fifteenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER FIFTEEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0035, 0x0029 },
  unicodeslot=0x2482,
 },
 [0x2483]={
  adobename="sixteenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER SIXTEEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0036, 0x0029 },
  unicodeslot=0x2483,
 },
 [0x2484]={
  adobename="seventeenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER SEVENTEEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0037, 0x0029 },
  unicodeslot=0x2484,
 },
 [0x2485]={
  adobename="eighteenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER EIGHTEEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0038, 0x0029 },
  unicodeslot=0x2485,
 },
 [0x2486]={
  adobename="nineteenparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER NINETEEN",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0031, 0x0039, 0x0029 },
  unicodeslot=0x2486,
 },
 [0x2487]={
  adobename="twentyparen",
  category="no",
  cjkwd="a",
  description="PARENTHESIZED NUMBER TWENTY",
  direction="on",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0032, 0x0030, 0x0029 },
  unicodeslot=0x2487,
 },
 [0x2488]={
  adobename="oneperiod",
  category="no",
  cjkwd="a",
  description="DIGIT ONE FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x002E },
  unicodeslot=0x2488,
 },
 [0x2489]={
  adobename="twoperiod",
  category="no",
  cjkwd="a",
  description="DIGIT TWO FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0032, 0x002E },
  unicodeslot=0x2489,
 },
 [0x248A]={
  adobename="threeperiod",
  category="no",
  cjkwd="a",
  description="DIGIT THREE FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0033, 0x002E },
  unicodeslot=0x248A,
 },
 [0x248B]={
  adobename="fourperiod",
  category="no",
  cjkwd="a",
  description="DIGIT FOUR FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0034, 0x002E },
  unicodeslot=0x248B,
 },
 [0x248C]={
  adobename="fiveperiod",
  category="no",
  cjkwd="a",
  description="DIGIT FIVE FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0035, 0x002E },
  unicodeslot=0x248C,
 },
 [0x248D]={
  adobename="sixperiod",
  category="no",
  cjkwd="a",
  description="DIGIT SIX FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0036, 0x002E },
  unicodeslot=0x248D,
 },
 [0x248E]={
  adobename="sevenperiod",
  category="no",
  cjkwd="a",
  description="DIGIT SEVEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0037, 0x002E },
  unicodeslot=0x248E,
 },
 [0x248F]={
  adobename="eightperiod",
  category="no",
  cjkwd="a",
  description="DIGIT EIGHT FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0038, 0x002E },
  unicodeslot=0x248F,
 },
 [0x2490]={
  adobename="nineperiod",
  category="no",
  cjkwd="a",
  description="DIGIT NINE FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0039, 0x002E },
  unicodeslot=0x2490,
 },
 [0x2491]={
  adobename="tenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER TEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0030, 0x002E },
  unicodeslot=0x2491,
 },
 [0x2492]={
  adobename="elevenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER ELEVEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0031, 0x002E },
  unicodeslot=0x2492,
 },
 [0x2493]={
  adobename="twelveperiod",
  category="no",
  cjkwd="a",
  description="NUMBER TWELVE FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0032, 0x002E },
  unicodeslot=0x2493,
 },
 [0x2494]={
  adobename="thirteenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER THIRTEEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0033, 0x002E },
  unicodeslot=0x2494,
 },
 [0x2495]={
  adobename="fourteenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER FOURTEEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0034, 0x002E },
  unicodeslot=0x2495,
 },
 [0x2496]={
  adobename="fifteenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER FIFTEEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0035, 0x002E },
  unicodeslot=0x2496,
 },
 [0x2497]={
  adobename="sixteenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER SIXTEEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0036, 0x002E },
  unicodeslot=0x2497,
 },
 [0x2498]={
  adobename="seventeenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER SEVENTEEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0037, 0x002E },
  unicodeslot=0x2498,
 },
 [0x2499]={
  adobename="eighteenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER EIGHTEEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0038, 0x002E },
  unicodeslot=0x2499,
 },
 [0x249A]={
  adobename="nineteenperiod",
  category="no",
  cjkwd="a",
  description="NUMBER NINETEEN FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x0039, 0x002E },
  unicodeslot=0x249A,
 },
 [0x249B]={
  adobename="twentyperiod",
  category="no",
  cjkwd="a",
  description="NUMBER TWENTY FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0032, 0x0030, 0x002E },
  unicodeslot=0x249B,
 },
 [0x249C]={
  adobename="aparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER A",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0061, 0x0029 },
  unicodeslot=0x249C,
 },
 [0x249D]={
  adobename="bparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER B",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0062, 0x0029 },
  unicodeslot=0x249D,
 },
 [0x249E]={
  adobename="cparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER C",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0063, 0x0029 },
  unicodeslot=0x249E,
 },
 [0x249F]={
  adobename="dparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER D",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0064, 0x0029 },
  unicodeslot=0x249F,
 },
 [0x24A0]={
  adobename="eparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER E",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0065, 0x0029 },
  unicodeslot=0x24A0,
 },
 [0x24A1]={
  adobename="fparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER F",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0066, 0x0029 },
  unicodeslot=0x24A1,
 },
 [0x24A2]={
  adobename="gparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER G",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0067, 0x0029 },
  unicodeslot=0x24A2,
 },
 [0x24A3]={
  adobename="hparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER H",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0068, 0x0029 },
  unicodeslot=0x24A3,
 },
 [0x24A4]={
  adobename="iparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER I",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0069, 0x0029 },
  unicodeslot=0x24A4,
 },
 [0x24A5]={
  adobename="jparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER J",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x006A, 0x0029 },
  unicodeslot=0x24A5,
 },
 [0x24A6]={
  adobename="kparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER K",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x006B, 0x0029 },
  unicodeslot=0x24A6,
 },
 [0x24A7]={
  adobename="lparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER L",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x006C, 0x0029 },
  unicodeslot=0x24A7,
 },
 [0x24A8]={
  adobename="mparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER M",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x006D, 0x0029 },
  unicodeslot=0x24A8,
 },
 [0x24A9]={
  adobename="nparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER N",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x006E, 0x0029 },
  unicodeslot=0x24A9,
 },
 [0x24AA]={
  adobename="oparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER O",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x006F, 0x0029 },
  unicodeslot=0x24AA,
 },
 [0x24AB]={
  adobename="pparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER P",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0070, 0x0029 },
  unicodeslot=0x24AB,
 },
 [0x24AC]={
  adobename="qparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER Q",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0071, 0x0029 },
  unicodeslot=0x24AC,
 },
 [0x24AD]={
  adobename="rparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER R",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0072, 0x0029 },
  unicodeslot=0x24AD,
 },
 [0x24AE]={
  adobename="sparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER S",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0073, 0x0029 },
  unicodeslot=0x24AE,
 },
 [0x24AF]={
  adobename="tparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER T",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0074, 0x0029 },
  unicodeslot=0x24AF,
 },
 [0x24B0]={
  adobename="uparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER U",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0075, 0x0029 },
  unicodeslot=0x24B0,
 },
 [0x24B1]={
  adobename="vparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER V",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0076, 0x0029 },
  unicodeslot=0x24B1,
 },
 [0x24B2]={
  adobename="wparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER W",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0077, 0x0029 },
  unicodeslot=0x24B2,
 },
 [0x24B3]={
  adobename="xparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER X",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0078, 0x0029 },
  unicodeslot=0x24B3,
 },
 [0x24B4]={
  adobename="yparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER Y",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0079, 0x0029 },
  unicodeslot=0x24B4,
 },
 [0x24B5]={
  adobename="zparen",
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN SMALL LETTER Z",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x007A, 0x0029 },
  unicodeslot=0x24B5,
 },
 [0x24B6]={
  adobename="Acircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER A",
  direction="l",
  lccode=0x24D0,
  linebreak="ai",
  specials={ "circle", 0x0041 },
  unicodeslot=0x24B6,
 },
 [0x24B7]={
  adobename="Bcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER B",
  direction="l",
  lccode=0x24D1,
  linebreak="ai",
  specials={ "circle", 0x0042 },
  unicodeslot=0x24B7,
 },
 [0x24B8]={
  adobename="Ccircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER C",
  direction="l",
  lccode=0x24D2,
  linebreak="ai",
  specials={ "circle", 0x0043 },
  unicodeslot=0x24B8,
 },
 [0x24B9]={
  adobename="Dcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER D",
  direction="l",
  lccode=0x24D3,
  linebreak="ai",
  specials={ "circle", 0x0044 },
  unicodeslot=0x24B9,
 },
 [0x24BA]={
  adobename="Ecircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER E",
  direction="l",
  lccode=0x24D4,
  linebreak="ai",
  specials={ "circle", 0x0045 },
  unicodeslot=0x24BA,
 },
 [0x24BB]={
  adobename="Fcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER F",
  direction="l",
  lccode=0x24D5,
  linebreak="ai",
  specials={ "circle", 0x0046 },
  unicodeslot=0x24BB,
 },
 [0x24BC]={
  adobename="Gcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER G",
  direction="l",
  lccode=0x24D6,
  linebreak="ai",
  specials={ "circle", 0x0047 },
  unicodeslot=0x24BC,
 },
 [0x24BD]={
  adobename="Hcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER H",
  direction="l",
  lccode=0x24D7,
  linebreak="ai",
  specials={ "circle", 0x0048 },
  unicodeslot=0x24BD,
 },
 [0x24BE]={
  adobename="Icircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER I",
  direction="l",
  lccode=0x24D8,
  linebreak="ai",
  specials={ "circle", 0x0049 },
  unicodeslot=0x24BE,
 },
 [0x24BF]={
  adobename="Jcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER J",
  direction="l",
  lccode=0x24D9,
  linebreak="ai",
  specials={ "circle", 0x004A },
  unicodeslot=0x24BF,
 },
 [0x24C0]={
  adobename="Kcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER K",
  direction="l",
  lccode=0x24DA,
  linebreak="ai",
  specials={ "circle", 0x004B },
  unicodeslot=0x24C0,
 },
 [0x24C1]={
  adobename="Lcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER L",
  direction="l",
  lccode=0x24DB,
  linebreak="ai",
  specials={ "circle", 0x004C },
  unicodeslot=0x24C1,
 },
 [0x24C2]={
  adobename="Mcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER M",
  direction="l",
  lccode=0x24DC,
  linebreak="ai",
  specials={ "circle", 0x004D },
  unicodeslot=0x24C2,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x24C3]={
  adobename="Ncircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER N",
  direction="l",
  lccode=0x24DD,
  linebreak="ai",
  specials={ "circle", 0x004E },
  unicodeslot=0x24C3,
 },
 [0x24C4]={
  adobename="Ocircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER O",
  direction="l",
  lccode=0x24DE,
  linebreak="ai",
  specials={ "circle", 0x004F },
  unicodeslot=0x24C4,
 },
 [0x24C5]={
  adobename="Pcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER P",
  direction="l",
  lccode=0x24DF,
  linebreak="ai",
  specials={ "circle", 0x0050 },
  unicodeslot=0x24C5,
 },
 [0x24C6]={
  adobename="Qcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER Q",
  direction="l",
  lccode=0x24E0,
  linebreak="ai",
  specials={ "circle", 0x0051 },
  unicodeslot=0x24C6,
 },
 [0x24C7]={
  adobename="Rcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER R",
  direction="l",
  lccode=0x24E1,
  linebreak="ai",
  mathclass="ordinary",
  mathname="circledR",
  specials={ "circle", 0x0052 },
  unicodeslot=0x24C7,
 },
 [0x24C8]={
  adobename="Scircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER S",
  direction="l",
  lccode=0x24E2,
  linebreak="ai",
  mathclass="ordinary",
  mathname="circledS",
  specials={ "circle", 0x0053 },
  unicodeslot=0x24C8,
 },
 [0x24C9]={
  adobename="Tcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER T",
  direction="l",
  lccode=0x24E3,
  linebreak="ai",
  specials={ "circle", 0x0054 },
  unicodeslot=0x24C9,
 },
 [0x24CA]={
  adobename="Ucircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER U",
  direction="l",
  lccode=0x24E4,
  linebreak="ai",
  specials={ "circle", 0x0055 },
  unicodeslot=0x24CA,
 },
 [0x24CB]={
  adobename="Vcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER V",
  direction="l",
  lccode=0x24E5,
  linebreak="ai",
  specials={ "circle", 0x0056 },
  unicodeslot=0x24CB,
 },
 [0x24CC]={
  adobename="Wcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER W",
  direction="l",
  lccode=0x24E6,
  linebreak="ai",
  specials={ "circle", 0x0057 },
  unicodeslot=0x24CC,
 },
 [0x24CD]={
  adobename="Xcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER X",
  direction="l",
  lccode=0x24E7,
  linebreak="ai",
  specials={ "circle", 0x0058 },
  unicodeslot=0x24CD,
 },
 [0x24CE]={
  adobename="Ycircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER Y",
  direction="l",
  lccode=0x24E8,
  linebreak="ai",
  specials={ "circle", 0x0059 },
  unicodeslot=0x24CE,
 },
 [0x24CF]={
  adobename="Zcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN CAPITAL LETTER Z",
  direction="l",
  lccode=0x24E9,
  linebreak="ai",
  specials={ "circle", 0x005A },
  unicodeslot=0x24CF,
 },
 [0x24D0]={
  adobename="acircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER A",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0061 },
  uccode=0x24B6,
  unicodeslot=0x24D0,
 },
 [0x24D1]={
  adobename="bcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER B",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0062 },
  uccode=0x24B7,
  unicodeslot=0x24D1,
 },
 [0x24D2]={
  adobename="ccircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER C",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0063 },
  uccode=0x24B8,
  unicodeslot=0x24D2,
 },
 [0x24D3]={
  adobename="dcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER D",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0064 },
  uccode=0x24B9,
  unicodeslot=0x24D3,
 },
 [0x24D4]={
  adobename="ecircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER E",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0065 },
  uccode=0x24BA,
  unicodeslot=0x24D4,
 },
 [0x24D5]={
  adobename="fcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER F",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0066 },
  uccode=0x24BB,
  unicodeslot=0x24D5,
 },
 [0x24D6]={
  adobename="gcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER G",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0067 },
  uccode=0x24BC,
  unicodeslot=0x24D6,
 },
 [0x24D7]={
  adobename="hcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER H",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0068 },
  uccode=0x24BD,
  unicodeslot=0x24D7,
 },
 [0x24D8]={
  adobename="icircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER I",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0069 },
  uccode=0x24BE,
  unicodeslot=0x24D8,
 },
 [0x24D9]={
  adobename="jcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER J",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x006A },
  uccode=0x24BF,
  unicodeslot=0x24D9,
 },
 [0x24DA]={
  adobename="kcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER K",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x006B },
  uccode=0x24C0,
  unicodeslot=0x24DA,
 },
 [0x24DB]={
  adobename="lcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER L",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x006C },
  uccode=0x24C1,
  unicodeslot=0x24DB,
 },
 [0x24DC]={
  adobename="mcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER M",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x006D },
  uccode=0x24C2,
  unicodeslot=0x24DC,
 },
 [0x24DD]={
  adobename="ncircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER N",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x006E },
  uccode=0x24C3,
  unicodeslot=0x24DD,
 },
 [0x24DE]={
  adobename="ocircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER O",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x006F },
  uccode=0x24C4,
  unicodeslot=0x24DE,
 },
 [0x24DF]={
  adobename="pcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER P",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0070 },
  uccode=0x24C5,
  unicodeslot=0x24DF,
 },
 [0x24E0]={
  adobename="qcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER Q",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0071 },
  uccode=0x24C6,
  unicodeslot=0x24E0,
 },
 [0x24E1]={
  adobename="rcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER R",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0072 },
  uccode=0x24C7,
  unicodeslot=0x24E1,
 },
 [0x24E2]={
  adobename="scircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER S",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0073 },
  uccode=0x24C8,
  unicodeslot=0x24E2,
 },
 [0x24E3]={
  adobename="tcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER T",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0074 },
  uccode=0x24C9,
  unicodeslot=0x24E3,
 },
 [0x24E4]={
  adobename="ucircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER U",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0075 },
  uccode=0x24CA,
  unicodeslot=0x24E4,
 },
 [0x24E5]={
  adobename="vcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER V",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0076 },
  uccode=0x24CB,
  unicodeslot=0x24E5,
 },
 [0x24E6]={
  adobename="wcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER W",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0077 },
  uccode=0x24CC,
  unicodeslot=0x24E6,
 },
 [0x24E7]={
  adobename="xcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER X",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0078 },
  uccode=0x24CD,
  unicodeslot=0x24E7,
 },
 [0x24E8]={
  adobename="ycircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER Y",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0079 },
  uccode=0x24CE,
  unicodeslot=0x24E8,
 },
 [0x24E9]={
  adobename="zcircle",
  category="so",
  cjkwd="a",
  description="CIRCLED LATIN SMALL LETTER Z",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x007A },
  uccode=0x24CF,
  unicodeslot=0x24E9,
 },
 [0x24EA]={
  category="no",
  description="CIRCLED DIGIT ZERO",
  direction="on",
  linebreak="ai",
  specials={ "circle", 0x0030 },
  unicodeslot=0x24EA,
 },
 [0x24EB]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER ELEVEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24EB,
 },
 [0x24EC]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER TWELVE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24EC,
 },
 [0x24ED]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER THIRTEEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24ED,
 },
 [0x24EE]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER FOURTEEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24EE,
 },
 [0x24EF]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER FIFTEEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24EF,
 },
 [0x24F0]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER SIXTEEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F0,
 },
 [0x24F1]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER SEVENTEEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F1,
 },
 [0x24F2]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER EIGHTEEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F2,
 },
 [0x24F3]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER NINETEEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F3,
 },
 [0x24F4]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED NUMBER TWENTY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F4,
 },
 [0x24F5]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT ONE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F5,
 },
 [0x24F6]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT TWO",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F6,
 },
 [0x24F7]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT THREE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F7,
 },
 [0x24F8]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT FOUR",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F8,
 },
 [0x24F9]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT FIVE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24F9,
 },
 [0x24FA]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT SIX",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24FA,
 },
 [0x24FB]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT SEVEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24FB,
 },
 [0x24FC]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT EIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24FC,
 },
 [0x24FD]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED DIGIT NINE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24FD,
 },
 [0x24FE]={
  category="no",
  cjkwd="a",
  description="DOUBLE CIRCLED NUMBER TEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x24FE,
 },
 [0x24FF]={
  category="no",
  cjkwd="a",
  description="NEGATIVE CIRCLED DIGIT ZERO",
  direction="on",
  linebreak="al",
  unicodeslot=0x24FF,
 },
 [0x2500]={
  adobename="SF100000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2500,
 },
 [0x2501]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2501,
 },
 [0x2502]={
  adobename="SF110000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT VERTICAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2502,
 },
 [0x2503]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY VERTICAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2503,
 },
 [0x2504]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT TRIPLE DASH HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2504,
 },
 [0x2505]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY TRIPLE DASH HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2505,
 },
 [0x2506]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2506,
 },
 [0x2507]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY TRIPLE DASH VERTICAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2507,
 },
 [0x2508]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT QUADRUPLE DASH HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2508,
 },
 [0x2509]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY QUADRUPLE DASH HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2509,
 },
 [0x250A]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT QUADRUPLE DASH VERTICAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x250A,
 },
 [0x250B]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY QUADRUPLE DASH VERTICAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x250B,
 },
 [0x250C]={
  adobename="SF010000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT DOWN AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x250C,
 },
 [0x250D]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN LIGHT AND RIGHT HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x250D,
 },
 [0x250E]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN HEAVY AND RIGHT LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x250E,
 },
 [0x250F]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY DOWN AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x250F,
 },
 [0x2510]={
  adobename="SF030000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT DOWN AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2510,
 },
 [0x2511]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN LIGHT AND LEFT HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2511,
 },
 [0x2512]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN HEAVY AND LEFT LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2512,
 },
 [0x2513]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY DOWN AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2513,
 },
 [0x2514]={
  adobename="SF020000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT UP AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2514,
 },
 [0x2515]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP LIGHT AND RIGHT HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2515,
 },
 [0x2516]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP HEAVY AND RIGHT LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2516,
 },
 [0x2517]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY UP AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2517,
 },
 [0x2518]={
  adobename="SF040000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT UP AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2518,
 },
 [0x2519]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP LIGHT AND LEFT HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2519,
 },
 [0x251A]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP HEAVY AND LEFT LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x251A,
 },
 [0x251B]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY UP AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x251B,
 },
 [0x251C]={
  adobename="SF080000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT VERTICAL AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x251C,
 },
 [0x251D]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL LIGHT AND RIGHT HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x251D,
 },
 [0x251E]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP HEAVY AND RIGHT DOWN LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x251E,
 },
 [0x251F]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN HEAVY AND RIGHT UP LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x251F,
 },
 [0x2520]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL HEAVY AND RIGHT LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2520,
 },
 [0x2521]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN LIGHT AND RIGHT UP HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2521,
 },
 [0x2522]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP LIGHT AND RIGHT DOWN HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2522,
 },
 [0x2523]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY VERTICAL AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2523,
 },
 [0x2524]={
  adobename="SF090000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT VERTICAL AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2524,
 },
 [0x2525]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL LIGHT AND LEFT HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2525,
 },
 [0x2526]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP HEAVY AND LEFT DOWN LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2526,
 },
 [0x2527]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN HEAVY AND LEFT UP LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2527,
 },
 [0x2528]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL HEAVY AND LEFT LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2528,
 },
 [0x2529]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN LIGHT AND LEFT UP HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2529,
 },
 [0x252A]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP LIGHT AND LEFT DOWN HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x252A,
 },
 [0x252B]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY VERTICAL AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x252B,
 },
 [0x252C]={
  adobename="SF060000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT DOWN AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x252C,
 },
 [0x252D]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LEFT HEAVY AND RIGHT DOWN LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x252D,
 },
 [0x252E]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS RIGHT HEAVY AND LEFT DOWN LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x252E,
 },
 [0x252F]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN LIGHT AND HORIZONTAL HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x252F,
 },
 [0x2530]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN HEAVY AND HORIZONTAL LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2530,
 },
 [0x2531]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS RIGHT LIGHT AND LEFT DOWN HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2531,
 },
 [0x2532]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LEFT LIGHT AND RIGHT DOWN HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2532,
 },
 [0x2533]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY DOWN AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2533,
 },
 [0x2534]={
  adobename="SF070000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT UP AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2534,
 },
 [0x2535]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LEFT HEAVY AND RIGHT UP LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2535,
 },
 [0x2536]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS RIGHT HEAVY AND LEFT UP LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2536,
 },
 [0x2537]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP LIGHT AND HORIZONTAL HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2537,
 },
 [0x2538]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP HEAVY AND HORIZONTAL LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2538,
 },
 [0x2539]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS RIGHT LIGHT AND LEFT UP HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2539,
 },
 [0x253A]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LEFT LIGHT AND RIGHT UP HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x253A,
 },
 [0x253B]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY UP AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x253B,
 },
 [0x253C]={
  adobename="SF050000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x253C,
 },
 [0x253D]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LEFT HEAVY AND RIGHT VERTICAL LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x253D,
 },
 [0x253E]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS RIGHT HEAVY AND LEFT VERTICAL LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x253E,
 },
 [0x253F]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL LIGHT AND HORIZONTAL HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x253F,
 },
 [0x2540]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP HEAVY AND DOWN HORIZONTAL LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2540,
 },
 [0x2541]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN HEAVY AND UP HORIZONTAL LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2541,
 },
 [0x2542]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL HEAVY AND HORIZONTAL LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2542,
 },
 [0x2543]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LEFT UP HEAVY AND RIGHT DOWN LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2543,
 },
 [0x2544]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS RIGHT UP HEAVY AND LEFT DOWN LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2544,
 },
 [0x2545]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LEFT DOWN HEAVY AND RIGHT UP LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2545,
 },
 [0x2546]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS RIGHT DOWN HEAVY AND LEFT UP LIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2546,
 },
 [0x2547]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN LIGHT AND UP HORIZONTAL HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2547,
 },
 [0x2548]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP LIGHT AND DOWN HORIZONTAL HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2548,
 },
 [0x2549]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS RIGHT LIGHT AND LEFT VERTICAL HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2549,
 },
 [0x254A]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LEFT LIGHT AND RIGHT VERTICAL HEAVY",
  direction="on",
  linebreak="ai",
  unicodeslot=0x254A,
 },
 [0x254B]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS HEAVY VERTICAL AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x254B,
 },
 [0x254C]={
  category="so",
  description="BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x254C,
 },
 [0x254D]={
  category="so",
  description="BOX DRAWINGS HEAVY DOUBLE DASH HORIZONTAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x254D,
 },
 [0x254E]={
  category="so",
  description="BOX DRAWINGS LIGHT DOUBLE DASH VERTICAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x254E,
 },
 [0x254F]={
  category="so",
  description="BOX DRAWINGS HEAVY DOUBLE DASH VERTICAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x254F,
 },
 [0x2550]={
  adobename="SF430000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2550,
 },
 [0x2551]={
  adobename="SF240000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE VERTICAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2551,
 },
 [0x2552]={
  adobename="SF510000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2552,
 },
 [0x2553]={
  adobename="SF520000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2553,
 },
 [0x2554]={
  adobename="SF390000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE DOWN AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2554,
 },
 [0x2555]={
  adobename="SF220000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2555,
 },
 [0x2556]={
  adobename="SF210000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2556,
 },
 [0x2557]={
  adobename="SF250000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE DOWN AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2557,
 },
 [0x2558]={
  adobename="SF500000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2558,
 },
 [0x2559]={
  adobename="SF490000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2559,
 },
 [0x255A]={
  adobename="SF380000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE UP AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x255A,
 },
 [0x255B]={
  adobename="SF280000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP SINGLE AND LEFT DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x255B,
 },
 [0x255C]={
  adobename="SF270000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP DOUBLE AND LEFT SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x255C,
 },
 [0x255D]={
  adobename="SF260000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE UP AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x255D,
 },
 [0x255E]={
  adobename="SF360000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x255E,
 },
 [0x255F]={
  adobename="SF370000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x255F,
 },
 [0x2560]={
  adobename="SF420000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE VERTICAL AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2560,
 },
 [0x2561]={
  adobename="SF190000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2561,
 },
 [0x2562]={
  adobename="SF200000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2562,
 },
 [0x2563]={
  adobename="SF230000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE VERTICAL AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2563,
 },
 [0x2564]={
  adobename="SF470000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2564,
 },
 [0x2565]={
  adobename="SF480000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2565,
 },
 [0x2566]={
  adobename="SF410000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2566,
 },
 [0x2567]={
  adobename="SF450000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2567,
 },
 [0x2568]={
  adobename="SF460000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2568,
 },
 [0x2569]={
  adobename="SF400000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE UP AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2569,
 },
 [0x256A]={
  adobename="SF540000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x256A,
 },
 [0x256B]={
  adobename="SF530000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x256B,
 },
 [0x256C]={
  adobename="SF440000",
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x256C,
 },
 [0x256D]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT ARC DOWN AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x256D,
 },
 [0x256E]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT ARC DOWN AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x256E,
 },
 [0x256F]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT ARC UP AND LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x256F,
 },
 [0x2570]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT ARC UP AND RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2570,
 },
 [0x2571]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2571,
 },
 [0x2572]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2572,
 },
 [0x2573]={
  category="so",
  cjkwd="a",
  description="BOX DRAWINGS LIGHT DIAGONAL CROSS",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2573,
 },
 [0x2574]={
  category="so",
  description="BOX DRAWINGS LIGHT LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2574,
 },
 [0x2575]={
  category="so",
  description="BOX DRAWINGS LIGHT UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x2575,
 },
 [0x2576]={
  category="so",
  description="BOX DRAWINGS LIGHT RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2576,
 },
 [0x2577]={
  category="so",
  description="BOX DRAWINGS LIGHT DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2577,
 },
 [0x2578]={
  category="so",
  description="BOX DRAWINGS HEAVY LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2578,
 },
 [0x2579]={
  category="so",
  description="BOX DRAWINGS HEAVY UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x2579,
 },
 [0x257A]={
  category="so",
  description="BOX DRAWINGS HEAVY RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x257A,
 },
 [0x257B]={
  category="so",
  description="BOX DRAWINGS HEAVY DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x257B,
 },
 [0x257C]={
  category="so",
  description="BOX DRAWINGS LIGHT LEFT AND HEAVY RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x257C,
 },
 [0x257D]={
  category="so",
  description="BOX DRAWINGS LIGHT UP AND HEAVY DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x257D,
 },
 [0x257E]={
  category="so",
  description="BOX DRAWINGS HEAVY LEFT AND LIGHT RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x257E,
 },
 [0x257F]={
  category="so",
  description="BOX DRAWINGS HEAVY UP AND LIGHT DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x257F,
 },
 [0x2580]={
  adobename="upblock",
  category="so",
  cjkwd="a",
  description="UPPER HALF BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2580,
 },
 [0x2581]={
  category="so",
  cjkwd="a",
  description="LOWER ONE EIGHTH BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2581,
 },
 [0x2582]={
  category="so",
  cjkwd="a",
  description="LOWER ONE QUARTER BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2582,
 },
 [0x2583]={
  category="so",
  cjkwd="a",
  description="LOWER THREE EIGHTHS BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2583,
 },
 [0x2584]={
  adobename="dnblock",
  category="so",
  cjkwd="a",
  description="LOWER HALF BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2584,
 },
 [0x2585]={
  category="so",
  cjkwd="a",
  description="LOWER FIVE EIGHTHS BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2585,
 },
 [0x2586]={
  category="so",
  cjkwd="a",
  description="LOWER THREE QUARTERS BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2586,
 },
 [0x2587]={
  category="so",
  cjkwd="a",
  description="LOWER SEVEN EIGHTHS BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2587,
 },
 [0x2588]={
  adobename="block",
  category="so",
  cjkwd="a",
  description="FULL BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2588,
 },
 [0x2589]={
  category="so",
  cjkwd="a",
  description="LEFT SEVEN EIGHTHS BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2589,
 },
 [0x258A]={
  category="so",
  cjkwd="a",
  description="LEFT THREE QUARTERS BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x258A,
 },
 [0x258B]={
  category="so",
  cjkwd="a",
  description="LEFT FIVE EIGHTHS BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x258B,
 },
 [0x258C]={
  adobename="lfblock",
  category="so",
  cjkwd="a",
  description="LEFT HALF BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x258C,
 },
 [0x258D]={
  category="so",
  cjkwd="a",
  description="LEFT THREE EIGHTHS BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x258D,
 },
 [0x258E]={
  category="so",
  cjkwd="a",
  description="LEFT ONE QUARTER BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x258E,
 },
 [0x258F]={
  category="so",
  cjkwd="a",
  description="LEFT ONE EIGHTH BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x258F,
 },
 [0x2590]={
  adobename="rtblock",
  category="so",
  description="RIGHT HALF BLOCK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2590,
 },
 [0x2591]={
  adobename="shadelight",
  category="so",
  description="LIGHT SHADE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2591,
 },
 [0x2592]={
  adobename="shademedium",
  category="so",
  cjkwd="a",
  description="MEDIUM SHADE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2592,
 },
 [0x2593]={
  adobename="shadedark",
  category="so",
  cjkwd="a",
  description="DARK SHADE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2593,
 },
 [0x2594]={
  category="so",
  cjkwd="a",
  description="UPPER ONE EIGHTH BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2594,
 },
 [0x2595]={
  category="so",
  cjkwd="a",
  description="RIGHT ONE EIGHTH BLOCK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2595,
 },
 [0x2596]={
  category="so",
  description="QUADRANT LOWER LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2596,
 },
 [0x2597]={
  category="so",
  description="QUADRANT LOWER RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2597,
 },
 [0x2598]={
  category="so",
  description="QUADRANT UPPER LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2598,
 },
 [0x2599]={
  category="so",
  description="QUADRANT UPPER LEFT AND LOWER LEFT AND LOWER RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2599,
 },
 [0x259A]={
  category="so",
  description="QUADRANT UPPER LEFT AND LOWER RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x259A,
 },
 [0x259B]={
  category="so",
  description="QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x259B,
 },
 [0x259C]={
  category="so",
  description="QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x259C,
 },
 [0x259D]={
  category="so",
  description="QUADRANT UPPER RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x259D,
 },
 [0x259E]={
  category="so",
  description="QUADRANT UPPER RIGHT AND LOWER LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x259E,
 },
 [0x259F]={
  category="so",
  description="QUADRANT UPPER RIGHT AND LOWER LEFT AND LOWER RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x259F,
 },
 [0x25A0]={
  adobename="filledbox",
  category="so",
  cjkwd="a",
  description="BLACK SQUARE",
  direction="on",
  linebreak="ai",
  mathclass="ordinary",
  mathname="blacksquare",
  unicodeslot=0x25A0,
 },
 [0x25A1]={
  adobename="whitesquare",
  category="so",
  cjkwd="a",
  description="WHITE SQUARE",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="ordinary",
    name="square",
   },
   {
    class="ordinary",
    name="Box",
   },
  },
  unicodeslot=0x25A1,
 },
 [0x25A2]={
  category="so",
  description="WHITE SQUARE WITH ROUNDED CORNERS",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  unicodeslot=0x25A2,
 },
 [0x25A3]={
  adobename="squarewhitewithsmallblack",
  category="so",
  cjkwd="a",
  description="WHITE SQUARE CONTAINING BLACK SMALL SQUARE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25A3,
 },
 [0x25A4]={
  adobename="squarehorizontalfill",
  category="so",
  cjkwd="a",
  description="SQUARE WITH HORIZONTAL FILL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25A4,
 },
 [0x25A5]={
  adobename="squareverticalfill",
  category="so",
  cjkwd="a",
  description="SQUARE WITH VERTICAL FILL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25A5,
 },
 [0x25A6]={
  adobename="squareorthogonalcrosshatchfill",
  category="so",
  cjkwd="a",
  description="SQUARE WITH ORTHOGONAL CROSSHATCH FILL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25A6,
 },
 [0x25A7]={
  adobename="squareupperlefttolowerrightfill",
  category="so",
  cjkwd="a",
  description="SQUARE WITH UPPER LEFT TO LOWER RIGHT FILL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25A7,
 },
 [0x25A8]={
  adobename="squareupperrighttolowerleftfill",
  category="so",
  cjkwd="a",
  description="SQUARE WITH UPPER RIGHT TO LOWER LEFT FILL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25A8,
 },
 [0x25A9]={
  adobename="squarediagonalcrosshatchfill",
  category="so",
  cjkwd="a",
  description="SQUARE WITH DIAGONAL CROSSHATCH FILL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25A9,
 },
 [0x25AA]={
  adobename="blacksmallsquare",
  category="so",
  description="BLACK SMALL SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25AA,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x25AB]={
  adobename="whitesmallsquare",
  category="so",
  description="WHITE SMALL SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25AB,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x25AC]={
  adobename="filledrect",
  category="so",
  description="BLACK RECTANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25AC,
 },
 [0x25AD]={
  category="so",
  description="WHITE RECTANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25AD,
 },
 [0x25AE]={
  category="so",
  description="BLACK VERTICAL RECTANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25AE,
 },
 [0x25AF]={
  category="so",
  description="WHITE VERTICAL RECTANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25AF,
 },
 [0x25B0]={
  category="so",
  description="BLACK PARALLELOGRAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x25B0,
 },
 [0x25B1]={
  category="so",
  description="WHITE PARALLELOGRAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x25B1,
 },
 [0x25B2]={
  adobename="triagup",
  category="so",
  cjkwd="a",
  description="BLACK UP-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="blacktriangle",
  unicodeslot=0x25B2,
 },
 [0x25B3]={
  adobename="whiteuppointingtriangle",
  category="so",
  cjkwd="a",
  description="WHITE UP-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="ordinary",
    name="triangle",
   },
   {
    class="binary",
    name="bigtriangleup",
   },
  },
  unicodeslot=0x25B3,
 },
 [0x25B4]={
  adobename="blackuppointingsmalltriangle",
  category="so",
  description="BLACK UP-POINTING SMALL TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25B4,
 },
 [0x25B5]={
  adobename="whiteuppointingsmalltriangle",
  category="so",
  description="WHITE UP-POINTING SMALL TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25B5,
 },
 [0x25B6]={
  adobename="blackrightpointingtriangle",
  category="so",
  cjkwd="a",
  description="BLACK RIGHT-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="blacktriangleright",
  unicodeslot=0x25B6,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x25B7]={
  adobename="whiterightpointingtriangle",
  category="sm",
  cjkwd="a",
  description="WHITE RIGHT-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="triangleright",
  unicodeslot=0x25B7,
 },
 [0x25B8]={
  category="so",
  description="BLACK RIGHT-POINTING SMALL TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25B8,
 },
 [0x25B9]={
  adobename="whiterightpointingsmalltriangle",
  category="so",
  description="WHITE RIGHT-POINTING SMALL TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25B9,
 },
 [0x25BA]={
  adobename="triagrt",
  category="so",
  description="BLACK RIGHT-POINTING POINTER",
  direction="on",
  linebreak="al",
  unicodeslot=0x25BA,
 },
 [0x25BB]={
  category="so",
  description="WHITE RIGHT-POINTING POINTER",
  direction="on",
  linebreak="al",
  unicodeslot=0x25BB,
 },
 [0x25BC]={
  adobename="triagdn",
  category="so",
  cjkwd="a",
  description="BLACK DOWN-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="blacktriangledown",
  unicodeslot=0x25BC,
 },
 [0x25BD]={
  adobename="whitedownpointingtriangle",
  category="so",
  cjkwd="a",
  description="WHITE DOWN-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  mathspec={
   {
    class="binary",
    name="triangledown",
   },
   {
    class="binary",
    name="bigtriangledown",
   },
  },
  unicodeslot=0x25BD,
 },
 [0x25BE]={
  category="so",
  description="BLACK DOWN-POINTING SMALL TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25BE,
 },
 [0x25BF]={
  adobename="whitedownpointingsmalltriangle",
  category="so",
  description="WHITE DOWN-POINTING SMALL TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25BF,
 },
 [0x25C0]={
  adobename="blackleftpointingtriangle",
  category="so",
  cjkwd="a",
  description="BLACK LEFT-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="blacktriangleleft",
  unicodeslot=0x25C0,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x25C1]={
  adobename="whiteleftpointingtriangle",
  category="sm",
  cjkwd="a",
  description="WHITE LEFT-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="triangleleft",
  unicodeslot=0x25C1,
 },
 [0x25C2]={
  category="so",
  description="BLACK LEFT-POINTING SMALL TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25C2,
 },
 [0x25C3]={
  adobename="whiteleftpointingsmalltriangle",
  category="so",
  description="WHITE LEFT-POINTING SMALL TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25C3,
 },
 [0x25C4]={
  adobename="triaglf",
  category="so",
  description="BLACK LEFT-POINTING POINTER",
  direction="on",
  linebreak="al",
  unicodeslot=0x25C4,
 },
 [0x25C5]={
  category="so",
  description="WHITE LEFT-POINTING POINTER",
  direction="on",
  linebreak="al",
  unicodeslot=0x25C5,
 },
 [0x25C6]={
  adobename="blackdiamond",
  category="so",
  cjkwd="a",
  description="BLACK DIAMOND",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25C6,
 },
 [0x25C7]={
  adobename="whitediamond",
  category="so",
  cjkwd="a",
  description="WHITE DIAMOND",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25C7,
 },
 [0x25C8]={
  adobename="whitediamondcontainingblacksmalldiamond",
  category="so",
  cjkwd="a",
  description="WHITE DIAMOND CONTAINING BLACK SMALL DIAMOND",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25C8,
 },
 [0x25C9]={
  adobename="fisheye",
  category="so",
  description="FISHEYE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25C9,
 },
 [0x25CA]={
  adobename="lozenge",
  category="so",
  description="LOZENGE",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="lozenge",
  unicodeslot=0x25CA,
 },
 [0x25CB]={
  adobename="whitecircle",
  category="so",
  cjkwd="a",
  description="WHITE CIRCLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25CB,
 },
 [0x25CC]={
  adobename="dottedcircle",
  category="so",
  description="DOTTED CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25CC,
 },
 [0x25CD]={
  category="so",
  description="CIRCLE WITH VERTICAL FILL",
  direction="on",
  linebreak="al",
  unicodeslot=0x25CD,
 },
 [0x25CE]={
  adobename="bullseye",
  category="so",
  cjkwd="a",
  description="BULLSEYE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25CE,
 },
 [0x25CF]={
  adobename="blackcircle",
  category="so",
  cjkwd="a",
  description="BLACK CIRCLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25CF,
 },
 [0x25D0]={
  adobename="circlewithlefthalfblack",
  category="so",
  cjkwd="a",
  description="CIRCLE WITH LEFT HALF BLACK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25D0,
 },
 [0x25D1]={
  adobename="circlewithrighthalfblack",
  category="so",
  cjkwd="a",
  description="CIRCLE WITH RIGHT HALF BLACK",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25D1,
 },
 [0x25D2]={
  category="so",
  description="CIRCLE WITH LOWER HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25D2,
 },
 [0x25D3]={
  category="so",
  description="CIRCLE WITH UPPER HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25D3,
 },
 [0x25D4]={
  category="so",
  description="CIRCLE WITH UPPER RIGHT QUADRANT BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25D4,
 },
 [0x25D5]={
  category="so",
  description="CIRCLE WITH ALL BUT UPPER LEFT QUADRANT BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25D5,
 },
 [0x25D6]={
  category="so",
  description="LEFT HALF BLACK CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25D6,
 },
 [0x25D7]={
  category="so",
  description="RIGHT HALF BLACK CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25D7,
 },
 [0x25D8]={
  adobename="invbullet",
  category="so",
  description="INVERSE BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x25D8,
 },
 [0x25D9]={
  adobename="whitecircleinverse",
  category="so",
  description="INVERSE WHITE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25D9,
 },
 [0x25DA]={
  category="so",
  description="UPPER HALF INVERSE WHITE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25DA,
 },
 [0x25DB]={
  category="so",
  description="LOWER HALF INVERSE WHITE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25DB,
 },
 [0x25DC]={
  category="so",
  description="UPPER LEFT QUADRANT CIRCULAR ARC",
  direction="on",
  linebreak="al",
  unicodeslot=0x25DC,
 },
 [0x25DD]={
  category="so",
  description="UPPER RIGHT QUADRANT CIRCULAR ARC",
  direction="on",
  linebreak="al",
  unicodeslot=0x25DD,
 },
 [0x25DE]={
  category="so",
  description="LOWER RIGHT QUADRANT CIRCULAR ARC",
  direction="on",
  linebreak="al",
  unicodeslot=0x25DE,
 },
 [0x25DF]={
  category="so",
  description="LOWER LEFT QUADRANT CIRCULAR ARC",
  direction="on",
  linebreak="al",
  unicodeslot=0x25DF,
 },
 [0x25E0]={
  category="so",
  description="UPPER HALF CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25E0,
 },
 [0x25E1]={
  category="so",
  description="LOWER HALF CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25E1,
 },
 [0x25E2]={
  adobename="blacklowerrighttriangle",
  category="so",
  cjkwd="a",
  description="BLACK LOWER RIGHT TRIANGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25E2,
 },
 [0x25E3]={
  adobename="blacklowerlefttriangle",
  category="so",
  cjkwd="a",
  description="BLACK LOWER LEFT TRIANGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25E3,
 },
 [0x25E4]={
  adobename="blackupperlefttriangle",
  category="so",
  cjkwd="a",
  description="BLACK UPPER LEFT TRIANGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25E4,
 },
 [0x25E5]={
  adobename="blackupperrighttriangle",
  category="so",
  cjkwd="a",
  description="BLACK UPPER RIGHT TRIANGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x25E5,
 },
 [0x25E6]={
  adobename="whitebullet",
  category="so",
  description="WHITE BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x25E6,
 },
 [0x25E7]={
  category="so",
  description="SQUARE WITH LEFT HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25E7,
 },
 [0x25E8]={
  category="so",
  description="SQUARE WITH RIGHT HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25E8,
 },
 [0x25E9]={
  category="so",
  description="SQUARE WITH UPPER LEFT DIAGONAL HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25E9,
 },
 [0x25EA]={
  category="so",
  description="SQUARE WITH LOWER RIGHT DIAGONAL HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25EA,
 },
 [0x25EB]={
  category="so",
  description="WHITE SQUARE WITH VERTICAL BISECTING LINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25EB,
 },
 [0x25EC]={
  category="so",
  description="WHITE UP-POINTING TRIANGLE WITH DOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25EC,
 },
 [0x25ED]={
  category="so",
  description="UP-POINTING TRIANGLE WITH LEFT HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25ED,
 },
 [0x25EE]={
  category="so",
  description="UP-POINTING TRIANGLE WITH RIGHT HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x25EE,
 },
 [0x25EF]={
  adobename="largecircle",
  category="so",
  cjkwd="a",
  description="LARGE CIRCLE",
  direction="on",
  linebreak="ai",
  mathclass="binary",
  mathname="bigcirc",
  unicodeslot=0x25EF,
 },
 [0x25F0]={
  category="so",
  description="WHITE SQUARE WITH UPPER LEFT QUADRANT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F0,
 },
 [0x25F1]={
  category="so",
  description="WHITE SQUARE WITH LOWER LEFT QUADRANT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F1,
 },
 [0x25F2]={
  category="so",
  description="WHITE SQUARE WITH LOWER RIGHT QUADRANT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F2,
 },
 [0x25F3]={
  category="so",
  description="WHITE SQUARE WITH UPPER RIGHT QUADRANT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F3,
 },
 [0x25F4]={
  category="so",
  description="WHITE CIRCLE WITH UPPER LEFT QUADRANT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F4,
 },
 [0x25F5]={
  category="so",
  description="WHITE CIRCLE WITH LOWER LEFT QUADRANT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F5,
 },
 [0x25F6]={
  category="so",
  description="WHITE CIRCLE WITH LOWER RIGHT QUADRANT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F6,
 },
 [0x25F7]={
  category="so",
  description="WHITE CIRCLE WITH UPPER RIGHT QUADRANT",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F7,
 },
 [0x25F8]={
  category="sm",
  description="UPPER LEFT TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F8,
 },
 [0x25F9]={
  category="sm",
  description="UPPER RIGHT TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25F9,
 },
 [0x25FA]={
  category="sm",
  description="LOWER LEFT TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25FA,
 },
 [0x25FB]={
  category="sm",
  description="WHITE MEDIUM SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25FB,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x25FC]={
  category="sm",
  description="BLACK MEDIUM SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25FC,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x25FD]={
  category="sm",
  description="WHITE MEDIUM SMALL SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25FD,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x25FE]={
  category="sm",
  description="BLACK MEDIUM SMALL SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25FE,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x25FF]={
  category="sm",
  description="LOWER RIGHT TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x25FF,
 },
 [0x2600]={
  category="so",
  description="BLACK SUN WITH RAYS",
  direction="on",
  linebreak="id",
  unicodeslot=0x2600,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2601]={
  category="so",
  description="CLOUD",
  direction="on",
  linebreak="id",
  unicodeslot=0x2601,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2602]={
  category="so",
  description="UMBRELLA",
  direction="on",
  linebreak="id",
  unicodeslot=0x2602,
 },
 [0x2603]={
  category="so",
  description="SNOWMAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x2603,
 },
 [0x2604]={
  category="so",
  description="COMET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2604,
 },
 [0x2605]={
  adobename="blackstar",
  category="so",
  cjkwd="a",
  description="BLACK STAR",
  direction="on",
  linebreak="ai",
  mathclass="ordinary",
  mathname="bigstar",
  unicodeslot=0x2605,
 },
 [0x2606]={
  adobename="whitestar",
  category="so",
  cjkwd="a",
  description="WHITE STAR",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2606,
 },
 [0x2607]={
  category="so",
  description="LIGHTNING",
  direction="on",
  linebreak="al",
  unicodeslot=0x2607,
 },
 [0x2608]={
  category="so",
  description="THUNDERSTORM",
  direction="on",
  linebreak="al",
  unicodeslot=0x2608,
 },
 [0x2609]={
  category="so",
  cjkwd="a",
  description="SUN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2609,
 },
 [0x260A]={
  category="so",
  description="ASCENDING NODE",
  direction="on",
  linebreak="al",
  unicodeslot=0x260A,
 },
 [0x260B]={
  category="so",
  description="DESCENDING NODE",
  direction="on",
  linebreak="al",
  unicodeslot=0x260B,
 },
 [0x260C]={
  category="so",
  description="CONJUNCTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x260C,
 },
 [0x260D]={
  category="so",
  description="OPPOSITION",
  direction="on",
  linebreak="al",
  unicodeslot=0x260D,
 },
 [0x260E]={
  adobename="telephoneblack",
  category="so",
  cjkwd="a",
  description="BLACK TELEPHONE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x260E,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x260F]={
  adobename="whitetelephone",
  category="so",
  cjkwd="a",
  description="WHITE TELEPHONE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x260F,
 },
 [0x2610]={
  category="so",
  description="BALLOT BOX",
  direction="on",
  linebreak="al",
  unicodeslot=0x2610,
 },
 [0x2611]={
  category="so",
  description="BALLOT BOX WITH CHECK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2611,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2612]={
  category="so",
  description="BALLOT BOX WITH X",
  direction="on",
  linebreak="al",
  unicodeslot=0x2612,
 },
 [0x2613]={
  category="so",
  description="SALTIRE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2613,
 },
 [0x2614]={
  category="so",
  cjkwd="a",
  description="UMBRELLA WITH RAIN DROPS",
  direction="on",
  linebreak="id",
  unicodeslot=0x2614,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2615]={
  category="so",
  cjkwd="a",
  description="HOT BEVERAGE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2615,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2616]={
  category="so",
  description="WHITE SHOGI PIECE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2616,
 },
 [0x2617]={
  category="so",
  description="BLACK SHOGI PIECE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2617,
 },
 [0x2618]={
  category="so",
  description="SHAMROCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x2618,
 },
 [0x2619]={
  category="so",
  description="REVERSED ROTATED FLORAL HEART BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2619,
 },
 [0x261A]={
  category="so",
  description="BLACK LEFT POINTING INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x261A,
 },
 [0x261B]={
  category="so",
  description="BLACK RIGHT POINTING INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x261B,
 },
 [0x261C]={
  adobename="pointingindexleftwhite",
  category="so",
  cjkwd="a",
  description="WHITE LEFT POINTING INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x261C,
 },
 [0x261D]={
  adobename="pointingindexupwhite",
  category="so",
  description="WHITE UP POINTING INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x261D,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x261E]={
  adobename="pointingindexrightwhite",
  category="so",
  cjkwd="a",
  description="WHITE RIGHT POINTING INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x261E,
 },
 [0x261F]={
  adobename="pointingindexdownwhite",
  category="so",
  description="WHITE DOWN POINTING INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x261F,
 },
 [0x2620]={
  category="so",
  description="SKULL AND CROSSBONES",
  direction="on",
  linebreak="al",
  unicodeslot=0x2620,
 },
 [0x2621]={
  category="so",
  description="CAUTION SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2621,
 },
 [0x2622]={
  category="so",
  description="RADIOACTIVE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2622,
 },
 [0x2623]={
  category="so",
  description="BIOHAZARD SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2623,
 },
 [0x2624]={
  category="so",
  description="CADUCEUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2624,
 },
 [0x2625]={
  category="so",
  description="ANKH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2625,
 },
 [0x2626]={
  category="so",
  description="ORTHODOX CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2626,
 },
 [0x2627]={
  category="so",
  description="CHI RHO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2627,
 },
 [0x2628]={
  category="so",
  description="CROSS OF LORRAINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2628,
 },
 [0x2629]={
  category="so",
  description="CROSS OF JERUSALEM",
  direction="on",
  linebreak="al",
  unicodeslot=0x2629,
 },
 [0x262A]={
  category="so",
  description="STAR AND CRESCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x262A,
 },
 [0x262B]={
  category="so",
  description="FARSI SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x262B,
 },
 [0x262C]={
  category="so",
  description="ADI SHAKTI",
  direction="on",
  linebreak="al",
  unicodeslot=0x262C,
 },
 [0x262D]={
  category="so",
  description="HAMMER AND SICKLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x262D,
 },
 [0x262E]={
  category="so",
  description="PEACE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x262E,
 },
 [0x262F]={
  adobename="yinyang",
  category="so",
  description="YIN YANG",
  direction="on",
  linebreak="al",
  unicodeslot=0x262F,
 },
 [0x2630]={
  category="so",
  description="TRIGRAM FOR HEAVEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2630,
 },
 [0x2631]={
  category="so",
  description="TRIGRAM FOR LAKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2631,
 },
 [0x2632]={
  category="so",
  description="TRIGRAM FOR FIRE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2632,
 },
 [0x2633]={
  category="so",
  description="TRIGRAM FOR THUNDER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2633,
 },
 [0x2634]={
  category="so",
  description="TRIGRAM FOR WIND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2634,
 },
 [0x2635]={
  category="so",
  description="TRIGRAM FOR WATER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2635,
 },
 [0x2636]={
  category="so",
  description="TRIGRAM FOR MOUNTAIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2636,
 },
 [0x2637]={
  category="so",
  description="TRIGRAM FOR EARTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2637,
 },
 [0x2638]={
  category="so",
  description="WHEEL OF DHARMA",
  direction="on",
  linebreak="al",
  unicodeslot=0x2638,
 },
 [0x2639]={
  category="so",
  description="WHITE FROWNING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2639,
 },
 [0x263A]={
  adobename="whitesmilingface",
  category="so",
  description="WHITE SMILING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x263A,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x263B]={
  adobename="invsmileface",
  category="so",
  description="BLACK SMILING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x263B,
 },
 [0x263C]={
  adobename="sun",
  category="so",
  description="WHITE SUN WITH RAYS",
  direction="on",
  linebreak="al",
  unicodeslot=0x263C,
 },
 [0x263D]={
  category="so",
  description="FIRST QUARTER MOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x263D,
 },
 [0x263E]={
  category="so",
  description="LAST QUARTER MOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x263E,
 },
 [0x263F]={
  category="so",
  description="MERCURY",
  direction="on",
  linebreak="al",
  unicodeslot=0x263F,
 },
 [0x2640]={
  adobename="venus",
  category="so",
  cjkwd="a",
  description="FEMALE SIGN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2640,
 },
 [0x2641]={
  adobename="earth",
  category="so",
  description="EARTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2641,
 },
 [0x2642]={
  adobename="mars",
  category="so",
  cjkwd="a",
  description="MALE SIGN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2642,
 },
 [0x2643]={
  category="so",
  description="JUPITER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2643,
 },
 [0x2644]={
  category="so",
  description="SATURN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2644,
 },
 [0x2645]={
  category="so",
  description="URANUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2645,
 },
 [0x2646]={
  category="so",
  description="NEPTUNE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2646,
 },
 [0x2647]={
  category="so",
  description="PLUTO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2647,
 },
 [0x2648]={
  category="so",
  description="ARIES",
  direction="on",
  linebreak="al",
  unicodeslot=0x2648,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2649]={
  category="so",
  description="TAURUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2649,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x264A]={
  category="so",
  description="GEMINI",
  direction="on",
  linebreak="al",
  unicodeslot=0x264A,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x264B]={
  category="so",
  description="CANCER",
  direction="on",
  linebreak="al",
  unicodeslot=0x264B,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x264C]={
  category="so",
  description="LEO",
  direction="on",
  linebreak="al",
  unicodeslot=0x264C,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x264D]={
  category="so",
  description="VIRGO",
  direction="on",
  linebreak="al",
  unicodeslot=0x264D,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x264E]={
  category="so",
  description="LIBRA",
  direction="on",
  linebreak="al",
  unicodeslot=0x264E,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x264F]={
  category="so",
  description="SCORPIUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x264F,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2650]={
  category="so",
  description="SAGITTARIUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2650,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2651]={
  category="so",
  description="CAPRICORN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2651,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2652]={
  category="so",
  description="AQUARIUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2652,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2653]={
  category="so",
  description="PISCES",
  direction="on",
  linebreak="al",
  unicodeslot=0x2653,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2654]={
  category="so",
  description="WHITE CHESS KING",
  direction="on",
  linebreak="al",
  unicodeslot=0x2654,
 },
 [0x2655]={
  category="so",
  description="WHITE CHESS QUEEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2655,
 },
 [0x2656]={
  category="so",
  description="WHITE CHESS ROOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2656,
 },
 [0x2657]={
  category="so",
  description="WHITE CHESS BISHOP",
  direction="on",
  linebreak="al",
  unicodeslot=0x2657,
 },
 [0x2658]={
  category="so",
  description="WHITE CHESS KNIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2658,
 },
 [0x2659]={
  category="so",
  description="WHITE CHESS PAWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2659,
 },
 [0x265A]={
  category="so",
  description="BLACK CHESS KING",
  direction="on",
  linebreak="al",
  unicodeslot=0x265A,
 },
 [0x265B]={
  category="so",
  description="BLACK CHESS QUEEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x265B,
 },
 [0x265C]={
  category="so",
  description="BLACK CHESS ROOK",
  direction="on",
  linebreak="al",
  unicodeslot=0x265C,
 },
 [0x265D]={
  category="so",
  description="BLACK CHESS BISHOP",
  direction="on",
  linebreak="al",
  unicodeslot=0x265D,
 },
 [0x265E]={
  category="so",
  description="BLACK CHESS KNIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x265E,
 },
 [0x265F]={
  category="so",
  description="BLACK CHESS PAWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x265F,
 },
 [0x2660]={
  adobename="spadesuitblack",
  category="so",
  cjkwd="a",
  description="BLACK SPADE SUIT",
  direction="on",
  linebreak="ai",
  mathclass="default",
  mathname="spadesuit",
  unicodeslot=0x2660,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2661]={
  adobename="heartsuitwhite",
  category="so",
  cjkwd="a",
  description="WHITE HEART SUIT",
  direction="on",
  linebreak="ai",
  mathclass="default",
  mathname="heartsuit",
  unicodeslot=0x2661,
 },
 [0x2662]={
  adobename="diamondsuitwhite",
  category="so",
  description="WHITE DIAMOND SUIT",
  direction="on",
  linebreak="al",
  mathclass="default",
  mathname="diamondsuit",
  unicodeslot=0x2662,
 },
 [0x2663]={
  adobename="clubsuitblack",
  category="so",
  cjkwd="a",
  description="BLACK CLUB SUIT",
  direction="on",
  linebreak="ai",
  mathclass="default",
  mathname="clubsuit",
  unicodeslot=0x2663,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2664]={
  adobename="spadesuitwhite",
  category="so",
  cjkwd="a",
  description="WHITE SPADE SUIT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2664,
 },
 [0x2665]={
  adobename="heartsuitblack",
  category="so",
  cjkwd="a",
  description="BLACK HEART SUIT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2665,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2666]={
  adobename="diamond",
  category="so",
  description="BLACK DIAMOND SUIT",
  direction="on",
  linebreak="al",
  mathclass="ordinary",
  mathname="blacklozenge",
  unicodeslot=0x2666,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2667]={
  adobename="clubsuitwhite",
  category="so",
  cjkwd="a",
  description="WHITE CLUB SUIT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2667,
 },
 [0x2668]={
  adobename="hotsprings",
  category="so",
  cjkwd="a",
  description="HOT SPRINGS",
  direction="on",
  linebreak="id",
  unicodeslot=0x2668,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2669]={
  adobename="quarternote",
  category="so",
  cjkwd="a",
  description="QUARTER NOTE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2669,
 },
 [0x266A]={
  adobename="musicalnote",
  category="so",
  cjkwd="a",
  description="EIGHTH NOTE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x266A,
 },
 [0x266B]={
  adobename="musicalnotedbl",
  category="so",
  description="BEAMED EIGHTH NOTES",
  direction="on",
  linebreak="al",
  unicodeslot=0x266B,
 },
 [0x266C]={
  adobename="beamedsixteenthnotes",
  category="so",
  cjkwd="a",
  description="BEAMED SIXTEENTH NOTES",
  direction="on",
  linebreak="ai",
  unicodeslot=0x266C,
 },
 [0x266D]={
  adobename="musicflatsign",
  category="so",
  cjkwd="a",
  description="MUSIC FLAT SIGN",
  direction="on",
  linebreak="ai",
  mathclass="default",
  mathname="flat",
  unicodeslot=0x266D,
 },
 [0x266E]={
  category="so",
  description="MUSIC NATURAL SIGN",
  direction="on",
  linebreak="al",
  mathclass="default",
  mathname="natural",
  unicodeslot=0x266E,
 },
 [0x266F]={
  adobename="musicsharpsign",
  category="sm",
  cjkwd="a",
  description="MUSIC SHARP SIGN",
  direction="on",
  linebreak="ai",
  mathclass="default",
  mathname="sharp",
  unicodeslot=0x266F,
 },
 [0x2670]={
  category="so",
  description="WEST SYRIAC CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2670,
 },
 [0x2671]={
  category="so",
  description="EAST SYRIAC CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2671,
 },
 [0x2672]={
  category="so",
  description="UNIVERSAL RECYCLING SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2672,
 },
 [0x2673]={
  category="so",
  description="RECYCLING SYMBOL FOR TYPE-0x0001 PLASTICS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2673,
 },
 [0x2674]={
  category="so",
  description="RECYCLING SYMBOL FOR TYPE-0x0002 PLASTICS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2674,
 },
 [0x2675]={
  category="so",
  description="RECYCLING SYMBOL FOR TYPE-0x0003 PLASTICS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2675,
 },
 [0x2676]={
  category="so",
  description="RECYCLING SYMBOL FOR TYPE-0x0004 PLASTICS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2676,
 },
 [0x2677]={
  category="so",
  description="RECYCLING SYMBOL FOR TYPE-0x0005 PLASTICS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2677,
 },
 [0x2678]={
  category="so",
  description="RECYCLING SYMBOL FOR TYPE-0x0006 PLASTICS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2678,
 },
 [0x2679]={
  category="so",
  description="RECYCLING SYMBOL FOR TYPE-0x0007 PLASTICS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2679,
 },
 [0x267A]={
  category="so",
  description="RECYCLING SYMBOL FOR GENERIC MATERIALS",
  direction="on",
  linebreak="al",
  unicodeslot=0x267A,
 },
 [0x267B]={
  category="so",
  description="BLACK UNIVERSAL RECYCLING SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x267B,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x267C]={
  category="so",
  description="RECYCLED PAPER SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x267C,
 },
 [0x267D]={
  category="so",
  description="PARTIALLY-RECYCLED PAPER SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x267D,
 },
 [0x267E]={
  category="so",
  description="PERMANENT PAPER SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x267E,
 },
 [0x267F]={
  category="so",
  description="WHEELCHAIR SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x267F,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2680]={
  category="so",
  description="DIE FACE-0x0001",
  direction="on",
  linebreak="al",
  unicodeslot=0x2680,
 },
 [0x2681]={
  category="so",
  description="DIE FACE-0x0002",
  direction="on",
  linebreak="al",
  unicodeslot=0x2681,
 },
 [0x2682]={
  category="so",
  description="DIE FACE-0x0003",
  direction="on",
  linebreak="al",
  unicodeslot=0x2682,
 },
 [0x2683]={
  category="so",
  description="DIE FACE-0x0004",
  direction="on",
  linebreak="al",
  unicodeslot=0x2683,
 },
 [0x2684]={
  category="so",
  description="DIE FACE-0x0005",
  direction="on",
  linebreak="al",
  unicodeslot=0x2684,
 },
 [0x2685]={
  category="so",
  description="DIE FACE-0x0006",
  direction="on",
  linebreak="al",
  unicodeslot=0x2685,
 },
 [0x2686]={
  category="so",
  description="WHITE CIRCLE WITH DOT RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2686,
 },
 [0x2687]={
  category="so",
  description="WHITE CIRCLE WITH TWO DOTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2687,
 },
 [0x2688]={
  category="so",
  description="BLACK CIRCLE WITH WHITE DOT RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2688,
 },
 [0x2689]={
  category="so",
  description="BLACK CIRCLE WITH TWO WHITE DOTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2689,
 },
 [0x268A]={
  category="so",
  description="MONOGRAM FOR YANG",
  direction="on",
  linebreak="al",
  unicodeslot=0x268A,
 },
 [0x268B]={
  category="so",
  description="MONOGRAM FOR YIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x268B,
 },
 [0x268C]={
  category="so",
  description="DIGRAM FOR GREATER YANG",
  direction="on",
  linebreak="al",
  unicodeslot=0x268C,
 },
 [0x268D]={
  category="so",
  description="DIGRAM FOR LESSER YIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x268D,
 },
 [0x268E]={
  category="so",
  description="DIGRAM FOR LESSER YANG",
  direction="on",
  linebreak="al",
  unicodeslot=0x268E,
 },
 [0x268F]={
  category="so",
  description="DIGRAM FOR GREATER YIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x268F,
 },
 [0x2690]={
  category="so",
  description="WHITE FLAG",
  direction="on",
  linebreak="al",
  unicodeslot=0x2690,
 },
 [0x2691]={
  category="so",
  description="BLACK FLAG",
  direction="on",
  linebreak="al",
  unicodeslot=0x2691,
 },
 [0x2692]={
  category="so",
  description="HAMMER AND PICK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2692,
 },
 [0x2693]={
  category="so",
  description="ANCHOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2693,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2694]={
  category="so",
  description="CROSSED SWORDS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2694,
 },
 [0x2695]={
  category="so",
  description="STAFF OF AESCULAPIUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2695,
 },
 [0x2696]={
  category="so",
  description="SCALES",
  direction="on",
  linebreak="al",
  unicodeslot=0x2696,
 },
 [0x2697]={
  category="so",
  description="ALEMBIC",
  direction="on",
  linebreak="al",
  unicodeslot=0x2697,
 },
 [0x2698]={
  category="so",
  description="FLOWER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2698,
 },
 [0x2699]={
  category="so",
  description="GEAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2699,
 },
 [0x269A]={
  category="so",
  description="STAFF OF HERMES",
  direction="on",
  linebreak="al",
  unicodeslot=0x269A,
 },
 [0x269B]={
  category="so",
  description="ATOM SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x269B,
 },
 [0x269C]={
  category="so",
  description="FLEUR-DE-LIS",
  direction="on",
  linebreak="al",
  unicodeslot=0x269C,
 },
 [0x269D]={
  category="so",
  description="OUTLINED WHITE STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x269D,
 },
 [0x269E]={
  category="so",
  cjkwd="a",
  description="THREE LINES CONVERGING RIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x269E,
 },
 [0x269F]={
  category="so",
  cjkwd="a",
  description="THREE LINES CONVERGING LEFT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x269F,
 },
 [0x26A0]={
  category="so",
  description="WARNING SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A0,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26A1]={
  category="so",
  description="HIGH VOLTAGE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A1,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26A2]={
  category="so",
  description="DOUBLED FEMALE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A2,
 },
 [0x26A3]={
  category="so",
  description="DOUBLED MALE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A3,
 },
 [0x26A4]={
  category="so",
  description="INTERLOCKED FEMALE AND MALE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A4,
 },
 [0x26A5]={
  category="so",
  description="MALE AND FEMALE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A5,
 },
 [0x26A6]={
  category="so",
  description="MALE WITH STROKE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A6,
 },
 [0x26A7]={
  category="so",
  description="MALE WITH STROKE AND MALE AND FEMALE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A7,
 },
 [0x26A8]={
  category="so",
  description="VERTICAL MALE WITH STROKE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A8,
 },
 [0x26A9]={
  category="so",
  description="HORIZONTAL MALE WITH STROKE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26A9,
 },
 [0x26AA]={
  category="so",
  description="MEDIUM WHITE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x26AA,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26AB]={
  category="so",
  description="MEDIUM BLACK CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x26AB,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26AC]={
  category="so",
  description="MEDIUM SMALL WHITE CIRCLE",
  direction="l",
  linebreak="al",
  unicodeslot=0x26AC,
 },
 [0x26AD]={
  category="so",
  description="MARRIAGE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x26AD,
 },
 [0x26AE]={
  category="so",
  description="DIVORCE SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x26AE,
 },
 [0x26AF]={
  category="so",
  description="UNMARRIED PARTNERSHIP SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x26AF,
 },
 [0x26B0]={
  category="so",
  description="COFFIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B0,
 },
 [0x26B1]={
  category="so",
  description="FUNERAL URN",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B1,
 },
 [0x26B2]={
  category="so",
  description="NEUTER",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B2,
 },
 [0x26B3]={
  category="so",
  description="CERES",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B3,
 },
 [0x26B4]={
  category="so",
  description="PALLAS",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B4,
 },
 [0x26B5]={
  category="so",
  description="JUNO",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B5,
 },
 [0x26B6]={
  category="so",
  description="VESTA",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B6,
 },
 [0x26B7]={
  category="so",
  description="CHIRON",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B7,
 },
 [0x26B8]={
  category="so",
  description="BLACK MOON LILITH",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B8,
 },
 [0x26B9]={
  category="so",
  description="SEXTILE",
  direction="on",
  linebreak="al",
  unicodeslot=0x26B9,
 },
 [0x26BA]={
  category="so",
  description="SEMISEXTILE",
  direction="on",
  linebreak="al",
  unicodeslot=0x26BA,
 },
 [0x26BB]={
  category="so",
  description="QUINCUNX",
  direction="on",
  linebreak="al",
  unicodeslot=0x26BB,
 },
 [0x26BC]={
  category="so",
  description="SESQUIQUADRATE",
  direction="on",
  linebreak="al",
  unicodeslot=0x26BC,
 },
 [0x26BD]={
  category="so",
  description="SOCCER BALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x26BD,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26BE]={
  category="so",
  cjkwd="a",
  description="BASEBALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x26BE,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26BF]={
  category="so",
  cjkwd="a",
  description="SQUARED KEY",
  direction="on",
  linebreak="id",
  unicodeslot=0x26BF,
 },
 [0x26C0]={
  category="so",
  description="WHITE DRAUGHTS MAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C0,
 },
 [0x26C1]={
  category="so",
  description="WHITE DRAUGHTS KING",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C1,
 },
 [0x26C2]={
  category="so",
  description="BLACK DRAUGHTS MAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C2,
 },
 [0x26C3]={
  category="so",
  description="BLACK DRAUGHTS KING",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C3,
 },
 [0x26C4]={
  category="so",
  cjkwd="a",
  description="SNOWMAN WITHOUT SNOW",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C4,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26C5]={
  category="so",
  cjkwd="a",
  description="SUN BEHIND CLOUD",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C5,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26C6]={
  category="so",
  cjkwd="a",
  description="RAIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C6,
 },
 [0x26C7]={
  category="so",
  cjkwd="a",
  description="BLACK SNOWMAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C7,
 },
 [0x26C8]={
  category="so",
  cjkwd="a",
  description="THUNDER CLOUD AND RAIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x26C8,
 },
 [0x26C9]={
  category="so",
  cjkwd="a",
  description="TURNED WHITE SHOGI PIECE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26C9,
 },
 [0x26CA]={
  category="so",
  cjkwd="a",
  description="TURNED BLACK SHOGI PIECE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26CA,
 },
 [0x26CB]={
  category="so",
  cjkwd="a",
  description="WHITE DIAMOND IN SQUARE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26CB,
 },
 [0x26CC]={
  category="so",
  cjkwd="a",
  description="CROSSING LANES",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26CC,
 },
 [0x26CD]={
  category="so",
  cjkwd="a",
  description="DISABLED CAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x26CD,
 },
 [0x26CE]={
  category="so",
  description="OPHIUCHUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x26CE,
 },
 [0x26CF]={
  category="so",
  cjkwd="a",
  description="PICK",
  direction="on",
  linebreak="id",
  unicodeslot=0x26CF,
 },
 [0x26D0]={
  category="so",
  cjkwd="a",
  description="CAR SLIDING",
  direction="on",
  linebreak="id",
  unicodeslot=0x26D0,
 },
 [0x26D1]={
  category="so",
  cjkwd="a",
  description="HELMET WITH WHITE CROSS",
  direction="on",
  linebreak="id",
  unicodeslot=0x26D1,
 },
 [0x26D2]={
  category="so",
  cjkwd="a",
  description="CIRCLED CROSSING LANES",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26D2,
 },
 [0x26D3]={
  category="so",
  cjkwd="a",
  description="CHAINS",
  direction="on",
  linebreak="id",
  unicodeslot=0x26D3,
 },
 [0x26D4]={
  category="so",
  cjkwd="a",
  description="NO ENTRY",
  direction="on",
  linebreak="id",
  unicodeslot=0x26D4,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26D5]={
  category="so",
  cjkwd="a",
  description="ALTERNATE ONE-WAY LEFT WAY TRAFFIC",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26D5,
 },
 [0x26D6]={
  category="so",
  cjkwd="a",
  description="BLACK TWO-WAY LEFT WAY TRAFFIC",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26D6,
 },
 [0x26D7]={
  category="so",
  cjkwd="a",
  description="WHITE TWO-WAY LEFT WAY TRAFFIC",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26D7,
 },
 [0x26D8]={
  category="so",
  cjkwd="a",
  description="BLACK LEFT LANE MERGE",
  direction="on",
  linebreak="id",
  unicodeslot=0x26D8,
 },
 [0x26D9]={
  category="so",
  cjkwd="a",
  description="WHITE LEFT LANE MERGE",
  direction="on",
  linebreak="id",
  unicodeslot=0x26D9,
 },
 [0x26DA]={
  category="so",
  cjkwd="a",
  description="DRIVE SLOW SIGN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26DA,
 },
 [0x26DB]={
  category="so",
  cjkwd="a",
  description="HEAVY WHITE DOWN-POINTING TRIANGLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26DB,
 },
 [0x26DC]={
  category="so",
  cjkwd="a",
  description="LEFT CLOSED ENTRY",
  direction="on",
  linebreak="id",
  unicodeslot=0x26DC,
 },
 [0x26DD]={
  category="so",
  cjkwd="a",
  description="SQUARED SALTIRE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26DD,
 },
 [0x26DE]={
  category="so",
  cjkwd="a",
  description="FALLING DIAGONAL IN WHITE CIRCLE IN BLACK SQUARE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26DE,
 },
 [0x26DF]={
  category="so",
  cjkwd="a",
  description="BLACK TRUCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x26DF,
 },
 [0x26E0]={
  category="so",
  cjkwd="a",
  description="RESTRICTED LEFT ENTRY-1",
  direction="on",
  linebreak="id",
  unicodeslot=0x26E0,
 },
 [0x26E1]={
  category="so",
  cjkwd="a",
  description="RESTRICTED LEFT ENTRY-2",
  direction="on",
  linebreak="id",
  unicodeslot=0x26E1,
 },
 [0x26E2]={
  category="so",
  description="ASTRONOMICAL SYMBOL FOR URANUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x26E2,
 },
 [0x26E3]={
  category="so",
  cjkwd="a",
  description="HEAVY CIRCLE WITH STROKE AND TWO DOTS ABOVE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26E3,
 },
 [0x26E4]={
  category="so",
  description="PENTAGRAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x26E4,
 },
 [0x26E5]={
  category="so",
  description="RIGHT-HANDED INTERLACED PENTAGRAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x26E5,
 },
 [0x26E6]={
  category="so",
  description="LEFT-HANDED INTERLACED PENTAGRAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x26E6,
 },
 [0x26E7]={
  category="so",
  description="INVERTED PENTAGRAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x26E7,
 },
 [0x26E8]={
  category="so",
  cjkwd="a",
  description="BLACK CROSS ON SHIELD",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26E8,
 },
 [0x26E9]={
  category="so",
  cjkwd="a",
  description="SHINTO SHRINE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26E9,
 },
 [0x26EA]={
  category="so",
  cjkwd="a",
  description="CHURCH",
  direction="on",
  linebreak="id",
  unicodeslot=0x26EA,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26EB]={
  category="so",
  cjkwd="a",
  description="CASTLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26EB,
 },
 [0x26EC]={
  category="so",
  cjkwd="a",
  description="HISTORIC SITE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26EC,
 },
 [0x26ED]={
  category="so",
  cjkwd="a",
  description="GEAR WITHOUT HUB",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26ED,
 },
 [0x26EE]={
  category="so",
  cjkwd="a",
  description="GEAR WITH HANDLES",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26EE,
 },
 [0x26EF]={
  category="so",
  cjkwd="a",
  description="MAP SYMBOL FOR LIGHTHOUSE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26EF,
 },
 [0x26F0]={
  category="so",
  cjkwd="a",
  description="MOUNTAIN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26F0,
 },
 [0x26F1]={
  category="so",
  cjkwd="a",
  description="UMBRELLA ON GROUND",
  direction="on",
  linebreak="id",
  unicodeslot=0x26F1,
 },
 [0x26F2]={
  category="so",
  cjkwd="a",
  description="FOUNTAIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x26F2,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26F3]={
  category="so",
  cjkwd="a",
  description="FLAG IN HOLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x26F3,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26F4]={
  category="so",
  cjkwd="a",
  description="FERRY",
  direction="on",
  linebreak="id",
  unicodeslot=0x26F4,
 },
 [0x26F5]={
  category="so",
  cjkwd="a",
  description="SAILBOAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x26F5,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26F6]={
  category="so",
  cjkwd="a",
  description="SQUARE FOUR CORNERS",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26F6,
 },
 [0x26F7]={
  category="so",
  cjkwd="a",
  description="SKIER",
  direction="on",
  linebreak="id",
  unicodeslot=0x26F7,
 },
 [0x26F8]={
  category="so",
  cjkwd="a",
  description="ICE SKATE",
  direction="on",
  linebreak="id",
  unicodeslot=0x26F8,
 },
 [0x26F9]={
  category="so",
  cjkwd="a",
  description="PERSON WITH BALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x26F9,
 },
 [0x26FA]={
  category="so",
  cjkwd="a",
  description="TENT",
  direction="on",
  linebreak="id",
  unicodeslot=0x26FA,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26FB]={
  category="so",
  cjkwd="a",
  description="JAPANESE BANK SYMBOL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26FB,
 },
 [0x26FC]={
  category="so",
  cjkwd="a",
  description="HEADSTONE GRAVEYARD SYMBOL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x26FC,
 },
 [0x26FD]={
  category="so",
  cjkwd="a",
  description="FUEL PUMP",
  direction="on",
  linebreak="id",
  unicodeslot=0x26FD,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x26FE]={
  category="so",
  cjkwd="a",
  description="CUP ON BLACK SQUARE",
  direction="on",
  linebreak="id",
  unicodeslot=0x26FE,
 },
 [0x26FF]={
  category="so",
  cjkwd="a",
  description="WHITE FLAG WITH HORIZONTAL MIDDLE BLACK STRIPE",
  direction="on",
  linebreak="id",
  unicodeslot=0x26FF,
 },
 [0x2701]={
  category="so",
  description="UPPER BLADE SCISSORS",
  direction="on",
  linebreak="id",
  unicodeslot=0x2701,
 },
 [0x2702]={
  category="so",
  description="BLACK SCISSORS",
  direction="on",
  linebreak="id",
  unicodeslot=0x2702,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2703]={
  category="so",
  description="LOWER BLADE SCISSORS",
  direction="on",
  linebreak="id",
  unicodeslot=0x2703,
 },
 [0x2704]={
  category="so",
  description="WHITE SCISSORS",
  direction="on",
  linebreak="id",
  unicodeslot=0x2704,
 },
 [0x2705]={
  category="so",
  description="WHITE HEAVY CHECK MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2705,
 },
 [0x2706]={
  category="so",
  description="TELEPHONE LOCATION SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2706,
 },
 [0x2707]={
  category="so",
  description="TAPE DRIVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2707,
 },
 [0x2708]={
  category="so",
  description="AIRPLANE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2708,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2709]={
  category="so",
  description="ENVELOPE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2709,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x270A]={
  category="so",
  description="RAISED FIST",
  direction="on",
  linebreak="id",
  unicodeslot=0x270A,
 },
 [0x270B]={
  category="so",
  description="RAISED HAND",
  direction="on",
  linebreak="id",
  unicodeslot=0x270B,
 },
 [0x270C]={
  category="so",
  description="VICTORY HAND",
  direction="on",
  linebreak="id",
  unicodeslot=0x270C,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x270D]={
  category="so",
  description="WRITING HAND",
  direction="on",
  linebreak="id",
  unicodeslot=0x270D,
 },
 [0x270E]={
  category="so",
  description="LOWER RIGHT PENCIL",
  direction="on",
  linebreak="al",
  unicodeslot=0x270E,
 },
 [0x270F]={
  category="so",
  description="PENCIL",
  direction="on",
  linebreak="al",
  unicodeslot=0x270F,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2710]={
  category="so",
  description="UPPER RIGHT PENCIL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2710,
 },
 [0x2711]={
  category="so",
  description="WHITE NIB",
  direction="on",
  linebreak="al",
  unicodeslot=0x2711,
 },
 [0x2712]={
  category="so",
  description="BLACK NIB",
  direction="on",
  linebreak="al",
  unicodeslot=0x2712,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2713]={
  adobename="checkmark",
  category="so",
  description="CHECK MARK",
  direction="on",
  linebreak="al",
  mathclass="nothing",
  mathname="checkmark",
  unicodeslot=0x2713,
 },
 [0x2714]={
  category="so",
  description="HEAVY CHECK MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2714,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2715]={
  category="so",
  description="MULTIPLICATION X",
  direction="on",
  linebreak="al",
  unicodeslot=0x2715,
 },
 [0x2716]={
  category="so",
  description="HEAVY MULTIPLICATION X",
  direction="on",
  linebreak="al",
  unicodeslot=0x2716,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2717]={
  category="so",
  description="BALLOT X",
  direction="on",
  linebreak="al",
  unicodeslot=0x2717,
 },
 [0x2718]={
  category="so",
  description="HEAVY BALLOT X",
  direction="on",
  linebreak="al",
  unicodeslot=0x2718,
 },
 [0x2719]={
  category="so",
  description="OUTLINED GREEK CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2719,
 },
 [0x271A]={
  category="so",
  description="HEAVY GREEK CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x271A,
 },
 [0x271B]={
  category="so",
  description="OPEN CENTRE CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x271B,
 },
 [0x271C]={
  category="so",
  description="HEAVY OPEN CENTRE CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x271C,
 },
 [0x271D]={
  category="so",
  description="LATIN CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x271D,
 },
 [0x271E]={
  category="so",
  description="SHADOWED WHITE LATIN CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x271E,
 },
 [0x271F]={
  category="so",
  description="OUTLINED LATIN CROSS",
  direction="on",
  linebreak="al",
  unicodeslot=0x271F,
 },
 [0x2720]={
  category="so",
  description="MALTESE CROSS",
  direction="on",
  linebreak="al",
  mathclass="nothing",
  mathname="maltese",
  unicodeslot=0x2720,
 },
 [0x2721]={
  category="so",
  description="STAR OF DAVID",
  direction="on",
  linebreak="al",
  unicodeslot=0x2721,
 },
 [0x2722]={
  category="so",
  description="FOUR TEARDROP-SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2722,
 },
 [0x2723]={
  category="so",
  description="FOUR BALLOON-SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2723,
 },
 [0x2724]={
  category="so",
  description="HEAVY FOUR BALLOON-SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2724,
 },
 [0x2725]={
  category="so",
  description="FOUR CLUB-SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2725,
 },
 [0x2726]={
  category="so",
  description="BLACK FOUR POINTED STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2726,
 },
 [0x2727]={
  category="so",
  description="WHITE FOUR POINTED STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2727,
 },
 [0x2728]={
  category="so",
  description="SPARKLES",
  direction="on",
  linebreak="al",
  unicodeslot=0x2728,
 },
 [0x2729]={
  category="so",
  description="STRESS OUTLINED WHITE STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2729,
 },
 [0x272A]={
  category="so",
  description="CIRCLED WHITE STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x272A,
 },
 [0x272B]={
  category="so",
  description="OPEN CENTRE BLACK STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x272B,
 },
 [0x272C]={
  category="so",
  description="BLACK CENTRE WHITE STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x272C,
 },
 [0x272D]={
  category="so",
  description="OUTLINED BLACK STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x272D,
 },
 [0x272E]={
  category="so",
  description="HEAVY OUTLINED BLACK STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x272E,
 },
 [0x272F]={
  category="so",
  description="PINWHEEL STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x272F,
 },
 [0x2730]={
  category="so",
  description="SHADOWED WHITE STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2730,
 },
 [0x2731]={
  category="so",
  description="HEAVY ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2731,
 },
 [0x2732]={
  category="so",
  description="OPEN CENTRE ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2732,
 },
 [0x2733]={
  category="so",
  description="EIGHT SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2733,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2734]={
  category="so",
  description="EIGHT POINTED BLACK STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2734,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2735]={
  category="so",
  description="EIGHT POINTED PINWHEEL STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2735,
 },
 [0x2736]={
  category="so",
  description="SIX POINTED BLACK STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2736,
 },
 [0x2737]={
  category="so",
  description="EIGHT POINTED RECTILINEAR BLACK STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2737,
 },
 [0x2738]={
  category="so",
  description="HEAVY EIGHT POINTED RECTILINEAR BLACK STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2738,
 },
 [0x2739]={
  category="so",
  description="TWELVE POINTED BLACK STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2739,
 },
 [0x273A]={
  category="so",
  description="SIXTEEN POINTED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x273A,
 },
 [0x273B]={
  category="so",
  description="TEARDROP-SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x273B,
 },
 [0x273C]={
  category="so",
  description="OPEN CENTRE TEARDROP-SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x273C,
 },
 [0x273D]={
  category="so",
  cjkwd="a",
  description="HEAVY TEARDROP-SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x273D,
 },
 [0x273E]={
  category="so",
  description="SIX PETALLED BLACK AND WHITE FLORETTE",
  direction="on",
  linebreak="al",
  unicodeslot=0x273E,
 },
 [0x273F]={
  category="so",
  description="BLACK FLORETTE",
  direction="on",
  linebreak="al",
  unicodeslot=0x273F,
 },
 [0x2740]={
  category="so",
  description="WHITE FLORETTE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2740,
 },
 [0x2741]={
  category="so",
  description="EIGHT PETALLED OUTLINED BLACK FLORETTE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2741,
 },
 [0x2742]={
  category="so",
  description="CIRCLED OPEN CENTRE EIGHT POINTED STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2742,
 },
 [0x2743]={
  category="so",
  description="HEAVY TEARDROP-SPOKED PINWHEEL ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2743,
 },
 [0x2744]={
  category="so",
  description="SNOWFLAKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2744,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2745]={
  category="so",
  description="TIGHT TRIFOLIATE SNOWFLAKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2745,
 },
 [0x2746]={
  category="so",
  description="HEAVY CHEVRON SNOWFLAKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2746,
 },
 [0x2747]={
  category="so",
  description="SPARKLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2747,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2748]={
  category="so",
  description="HEAVY SPARKLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2748,
 },
 [0x2749]={
  category="so",
  description="BALLOON-SPOKED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2749,
 },
 [0x274A]={
  category="so",
  description="EIGHT TEARDROP-SPOKED PROPELLER ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x274A,
 },
 [0x274B]={
  category="so",
  description="HEAVY EIGHT TEARDROP-SPOKED PROPELLER ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x274B,
 },
 [0x274C]={
  category="so",
  description="CROSS MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x274C,
 },
 [0x274D]={
  category="so",
  description="SHADOWED WHITE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x274D,
 },
 [0x274E]={
  category="so",
  description="NEGATIVE SQUARED CROSS MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x274E,
 },
 [0x274F]={
  category="so",
  description="LOWER RIGHT DROP-SHADOWED WHITE SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x274F,
 },
 [0x2750]={
  category="so",
  description="UPPER RIGHT DROP-SHADOWED WHITE SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2750,
 },
 [0x2751]={
  category="so",
  description="LOWER RIGHT SHADOWED WHITE SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2751,
 },
 [0x2752]={
  category="so",
  description="UPPER RIGHT SHADOWED WHITE SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2752,
 },
 [0x2753]={
  category="so",
  description="BLACK QUESTION MARK ORNAMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2753,
 },
 [0x2754]={
  category="so",
  description="WHITE QUESTION MARK ORNAMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2754,
 },
 [0x2755]={
  category="so",
  description="WHITE EXCLAMATION MARK ORNAMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2755,
 },
 [0x2756]={
  category="so",
  description="BLACK DIAMOND MINUS WHITE X",
  direction="on",
  linebreak="al",
  unicodeslot=0x2756,
 },
 [0x2757]={
  category="so",
  cjkwd="a",
  description="HEAVY EXCLAMATION MARK SYMBOL",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2757,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2758]={
  category="so",
  description="LIGHT VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2758,
 },
 [0x2759]={
  category="so",
  description="MEDIUM VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2759,
 },
 [0x275A]={
  category="so",
  description="HEAVY VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x275A,
 },
 [0x275B]={
  category="so",
  description="HEAVY SINGLE TURNED COMMA QUOTATION MARK ORNAMENT",
  direction="on",
  linebreak="qu",
  unicodeslot=0x275B,
 },
 [0x275C]={
  category="so",
  description="HEAVY SINGLE COMMA QUOTATION MARK ORNAMENT",
  direction="on",
  linebreak="qu",
  unicodeslot=0x275C,
 },
 [0x275D]={
  category="so",
  description="HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT",
  direction="on",
  linebreak="qu",
  unicodeslot=0x275D,
 },
 [0x275E]={
  category="so",
  description="HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT",
  direction="on",
  linebreak="qu",
  unicodeslot=0x275E,
 },
 [0x275F]={
  category="so",
  description="HEAVY LOW SINGLE COMMA QUOTATION MARK ORNAMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x275F,
 },
 [0x2760]={
  category="so",
  description="HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2760,
 },
 [0x2761]={
  category="so",
  description="CURVED STEM PARAGRAPH SIGN ORNAMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2761,
 },
 [0x2762]={
  category="so",
  description="HEAVY EXCLAMATION MARK ORNAMENT",
  direction="on",
  linebreak="ex",
  unicodeslot=0x2762,
 },
 [0x2763]={
  category="so",
  description="HEAVY HEART EXCLAMATION MARK ORNAMENT",
  direction="on",
  linebreak="ex",
  unicodeslot=0x2763,
 },
 [0x2764]={
  category="so",
  description="HEAVY BLACK HEART",
  direction="on",
  linebreak="al",
  unicodeslot=0x2764,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2765]={
  category="so",
  description="ROTATED HEAVY BLACK HEART BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2765,
 },
 [0x2766]={
  category="so",
  description="FLORAL HEART",
  direction="on",
  linebreak="al",
  unicodeslot=0x2766,
 },
 [0x2767]={
  category="so",
  description="ROTATED FLORAL HEART BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2767,
 },
 [0x2768]={
  category="ps",
  description="MEDIUM LEFT PARENTHESIS ORNAMENT",
  direction="on",
  linebreak="op",
  mirror=0x2769,
  unicodeslot=0x2768,
 },
 [0x2769]={
  category="pe",
  description="MEDIUM RIGHT PARENTHESIS ORNAMENT",
  direction="on",
  linebreak="cl",
  mirror=0x2768,
  unicodeslot=0x2769,
 },
 [0x276A]={
  category="ps",
  description="MEDIUM FLATTENED LEFT PARENTHESIS ORNAMENT",
  direction="on",
  linebreak="op",
  mirror=0x276B,
  unicodeslot=0x276A,
 },
 [0x276B]={
  category="pe",
  description="MEDIUM FLATTENED RIGHT PARENTHESIS ORNAMENT",
  direction="on",
  linebreak="cl",
  mirror=0x276A,
  unicodeslot=0x276B,
 },
 [0x276C]={
  category="ps",
  description="MEDIUM LEFT-POINTING ANGLE BRACKET ORNAMENT",
  direction="on",
  linebreak="op",
  mirror=0x276D,
  unicodeslot=0x276C,
 },
 [0x276D]={
  category="pe",
  description="MEDIUM RIGHT-POINTING ANGLE BRACKET ORNAMENT",
  direction="on",
  linebreak="cl",
  mirror=0x276C,
  unicodeslot=0x276D,
 },
 [0x276E]={
  category="ps",
  description="HEAVY LEFT-POINTING ANGLE QUOTATION MARK ORNAMENT",
  direction="on",
  linebreak="op",
  mirror=0x276F,
  unicodeslot=0x276E,
 },
 [0x276F]={
  category="pe",
  description="HEAVY RIGHT-POINTING ANGLE QUOTATION MARK ORNAMENT",
  direction="on",
  linebreak="cl",
  mirror=0x276E,
  unicodeslot=0x276F,
 },
 [0x2770]={
  category="ps",
  description="HEAVY LEFT-POINTING ANGLE BRACKET ORNAMENT",
  direction="on",
  linebreak="op",
  mirror=0x2771,
  unicodeslot=0x2770,
 },
 [0x2771]={
  category="pe",
  description="HEAVY RIGHT-POINTING ANGLE BRACKET ORNAMENT",
  direction="on",
  linebreak="cl",
  mirror=0x2770,
  unicodeslot=0x2771,
 },
 [0x2772]={
  category="ps",
  description="LIGHT LEFT TORTOISE SHELL BRACKET ORNAMENT",
  direction="on",
  linebreak="op",
  mirror=0x2773,
  unicodeslot=0x2772,
 },
 [0x2773]={
  category="pe",
  description="LIGHT RIGHT TORTOISE SHELL BRACKET ORNAMENT",
  direction="on",
  linebreak="cl",
  mirror=0x2772,
  unicodeslot=0x2773,
 },
 [0x2774]={
  category="ps",
  description="MEDIUM LEFT CURLY BRACKET ORNAMENT",
  direction="on",
  linebreak="op",
  mirror=0x2775,
  unicodeslot=0x2774,
 },
 [0x2775]={
  category="pe",
  description="MEDIUM RIGHT CURLY BRACKET ORNAMENT",
  direction="on",
  linebreak="cl",
  mirror=0x2774,
  unicodeslot=0x2775,
 },
 [0x2776]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT ONE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2776,
 },
 [0x2777]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT TWO",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2777,
 },
 [0x2778]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT THREE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2778,
 },
 [0x2779]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT FOUR",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2779,
 },
 [0x277A]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT FIVE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x277A,
 },
 [0x277B]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT SIX",
  direction="on",
  linebreak="ai",
  unicodeslot=0x277B,
 },
 [0x277C]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT SEVEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x277C,
 },
 [0x277D]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT EIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x277D,
 },
 [0x277E]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED DIGIT NINE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x277E,
 },
 [0x277F]={
  category="no",
  cjkwd="a",
  description="DINGBAT NEGATIVE CIRCLED NUMBER TEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x277F,
 },
 [0x2780]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT ONE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2780,
 },
 [0x2781]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT TWO",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2781,
 },
 [0x2782]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT THREE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2782,
 },
 [0x2783]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT FOUR",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2783,
 },
 [0x2784]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT FIVE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2784,
 },
 [0x2785]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT SIX",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2785,
 },
 [0x2786]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT SEVEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2786,
 },
 [0x2787]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT EIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2787,
 },
 [0x2788]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF DIGIT NINE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2788,
 },
 [0x2789]={
  category="no",
  description="DINGBAT CIRCLED SANS-SERIF NUMBER TEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2789,
 },
 [0x278A]={
  adobename="onecircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ONE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x278A,
 },
 [0x278B]={
  adobename="twocircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT TWO",
  direction="on",
  linebreak="ai",
  unicodeslot=0x278B,
 },
 [0x278C]={
  adobename="threecircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT THREE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x278C,
 },
 [0x278D]={
  adobename="fourcircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FOUR",
  direction="on",
  linebreak="ai",
  unicodeslot=0x278D,
 },
 [0x278E]={
  adobename="fivecircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FIVE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x278E,
 },
 [0x278F]={
  adobename="sixcircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SIX",
  direction="on",
  linebreak="ai",
  unicodeslot=0x278F,
 },
 [0x2790]={
  adobename="sevencircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SEVEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2790,
 },
 [0x2791]={
  adobename="eightcircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT EIGHT",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2791,
 },
 [0x2792]={
  adobename="ninecircleinversesansserif",
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT NINE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2792,
 },
 [0x2793]={
  category="no",
  description="DINGBAT NEGATIVE CIRCLED SANS-SERIF NUMBER TEN",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2793,
 },
 [0x2794]={
  category="so",
  description="HEAVY WIDE-HEADED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2794,
 },
 [0x2795]={
  category="so",
  description="HEAVY PLUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2795,
 },
 [0x2796]={
  category="so",
  description="HEAVY MINUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2796,
 },
 [0x2797]={
  category="so",
  description="HEAVY DIVISION SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2797,
 },
 [0x2798]={
  category="so",
  description="HEAVY SOUTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2798,
 },
 [0x2799]={
  category="so",
  description="HEAVY RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2799,
 },
 [0x279A]={
  category="so",
  description="HEAVY NORTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x279A,
 },
 [0x279B]={
  category="so",
  description="DRAFTING POINT RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x279B,
 },
 [0x279C]={
  category="so",
  description="HEAVY ROUND-TIPPED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x279C,
 },
 [0x279D]={
  category="so",
  description="TRIANGLE-HEADED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x279D,
 },
 [0x279E]={
  adobename="arrowrightheavy",
  category="so",
  description="HEAVY TRIANGLE-HEADED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x279E,
 },
 [0x279F]={
  category="so",
  description="DASHED TRIANGLE-HEADED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x279F,
 },
 [0x27A0]={
  category="so",
  description="HEAVY DASHED TRIANGLE-HEADED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A0,
 },
 [0x27A1]={
  category="so",
  description="BLACK RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A1,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x27A2]={
  category="so",
  description="THREE-D TOP-LIGHTED RIGHTWARDS ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A2,
 },
 [0x27A3]={
  category="so",
  description="THREE-D BOTTOM-LIGHTED RIGHTWARDS ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A3,
 },
 [0x27A4]={
  category="so",
  description="BLACK RIGHTWARDS ARROWHEAD",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A4,
 },
 [0x27A5]={
  category="so",
  description="HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A5,
 },
 [0x27A6]={
  category="so",
  description="HEAVY BLACK CURVED UPWARDS AND RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A6,
 },
 [0x27A7]={
  category="so",
  description="SQUAT BLACK RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A7,
 },
 [0x27A8]={
  category="so",
  description="HEAVY CONCAVE-POINTED BLACK RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A8,
 },
 [0x27A9]={
  category="so",
  description="RIGHT-SHADED WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27A9,
 },
 [0x27AA]={
  category="so",
  description="LEFT-SHADED WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27AA,
 },
 [0x27AB]={
  category="so",
  description="BACK-TILTED SHADOWED WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27AB,
 },
 [0x27AC]={
  category="so",
  description="FRONT-TILTED SHADOWED WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27AC,
 },
 [0x27AD]={
  category="so",
  description="HEAVY LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27AD,
 },
 [0x27AE]={
  category="so",
  description="HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27AE,
 },
 [0x27AF]={
  category="so",
  description="NOTCHED LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27AF,
 },
 [0x27B0]={
  category="so",
  description="CURLY LOOP",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B0,
 },
 [0x27B1]={
  category="so",
  description="NOTCHED UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B1,
 },
 [0x27B2]={
  category="so",
  description="CIRCLED HEAVY WHITE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B2,
 },
 [0x27B3]={
  category="so",
  description="WHITE-FEATHERED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B3,
 },
 [0x27B4]={
  category="so",
  description="BLACK-FEATHERED SOUTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B4,
 },
 [0x27B5]={
  category="so",
  description="BLACK-FEATHERED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B5,
 },
 [0x27B6]={
  category="so",
  description="BLACK-FEATHERED NORTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B6,
 },
 [0x27B7]={
  category="so",
  description="HEAVY BLACK-FEATHERED SOUTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B7,
 },
 [0x27B8]={
  category="so",
  description="HEAVY BLACK-FEATHERED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B8,
 },
 [0x27B9]={
  category="so",
  description="HEAVY BLACK-FEATHERED NORTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27B9,
 },
 [0x27BA]={
  category="so",
  description="TEARDROP-BARBED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27BA,
 },
 [0x27BB]={
  category="so",
  description="HEAVY TEARDROP-SHANKED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27BB,
 },
 [0x27BC]={
  category="so",
  description="WEDGE-TAILED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27BC,
 },
 [0x27BD]={
  category="so",
  description="HEAVY WEDGE-TAILED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27BD,
 },
 [0x27BE]={
  category="so",
  description="OPEN-OUTLINED RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27BE,
 },
 [0x27BF]={
  category="so",
  description="DOUBLE CURLY LOOP",
  direction="on",
  linebreak="al",
  unicodeslot=0x27BF,
 },
 [0x27C0]={
  category="sm",
  description="THREE DIMENSIONAL ANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x27C0,
 },
 [0x27C1]={
  category="sm",
  description="WHITE TRIANGLE CONTAINING SMALL WHITE TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x27C1,
 },
 [0x27C2]={
  category="sm",
  description="PERPENDICULAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x27C2,
 },
 [0x27C3]={
  category="sm",
  description="OPEN SUBSET",
  direction="on",
  linebreak="al",
  mirror=0x27C4,
  unicodeslot=0x27C3,
 },
 [0x27C4]={
  category="sm",
  description="OPEN SUPERSET",
  direction="on",
  linebreak="al",
  mirror=0x27C3,
  unicodeslot=0x27C4,
 },
 [0x27C5]={
  category="ps",
  description="LEFT S-SHAPED BAG DELIMITER",
  direction="on",
  linebreak="op",
  mirror=0x27C6,
  unicodeslot=0x27C5,
 },
 [0x27C6]={
  category="pe",
  description="RIGHT S-SHAPED BAG DELIMITER",
  direction="on",
  linebreak="cl",
  mirror=0x27C5,
  unicodeslot=0x27C6,
 },
 [0x27C7]={
  category="sm",
  description="OR WITH DOT INSIDE",
  direction="on",
  linebreak="al",
  unicodeslot=0x27C7,
 },
 [0x27C8]={
  category="sm",
  description="REVERSE SOLIDUS PRECEDING SUBSET",
  direction="on",
  linebreak="al",
  mirror=0x27C9,
  unicodeslot=0x27C8,
 },
 [0x27C9]={
  category="sm",
  description="SUPERSET PRECEDING SOLIDUS",
  direction="on",
  linebreak="al",
  mirror=0x27C8,
  unicodeslot=0x27C9,
 },
 [0x27CA]={
  category="sm",
  description="VERTICAL BAR WITH HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x27CA,
 },
 [0x27CB]={
  category="sm",
  comment="check math properties",
  description="MATHEMATICAL RISING DIAGONAL",
  direction="on",
  linebreak="al",
  mirror=0x27CD,
  unicodeslot=0x27CB,
 },
 [0x27CC]={
  category="sm",
  description="LONG DIVISION",
  direction="on",
  linebreak="al",
  unicodeslot=0x27CC,
 },
 [0x27CD]={
  category="sm",
  comment="check math properties",
  description="MATHEMATICAL FALLING DIAGONAL",
  direction="on",
  linebreak="al",
  mirror=0x27CB,
  unicodeslot=0x27CD,
 },
 [0x27CE]={
  category="sm",
  description="SQUARED LOGICAL AND",
  direction="on",
  linebreak="al",
  unicodeslot=0x27CE,
 },
 [0x27CF]={
  category="sm",
  description="SQUARED LOGICAL OR",
  direction="on",
  linebreak="al",
  unicodeslot=0x27CF,
 },
 [0x27D0]={
  category="sm",
  description="WHITE DIAMOND WITH CENTRED DOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x27D0,
 },
 [0x27D1]={
  category="sm",
  description="AND WITH DOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x27D1,
 },
 [0x27D2]={
  category="sm",
  description="ELEMENT OF OPENING UPWARDS",
  direction="on",
  linebreak="al",
  unicodeslot=0x27D2,
 },
 [0x27D3]={
  category="sm",
  description="LOWER RIGHT CORNER WITH DOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x27D3,
 },
 [0x27D4]={
  category="sm",
  description="UPPER LEFT CORNER WITH DOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x27D4,
 },
 [0x27D5]={
  category="sm",
  description="LEFT OUTER JOIN",
  direction="on",
  linebreak="al",
  mirror=0x27D6,
  unicodeslot=0x27D5,
 },
 [0x27D6]={
  category="sm",
  description="RIGHT OUTER JOIN",
  direction="on",
  linebreak="al",
  mirror=0x27D5,
  unicodeslot=0x27D6,
 },
 [0x27D7]={
  category="sm",
  description="FULL OUTER JOIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x27D7,
 },
 [0x27D8]={
  category="sm",
  description="LARGE UP TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x27D8,
 },
 [0x27D9]={
  category="sm",
  description="LARGE DOWN TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x27D9,
 },
 [0x27DA]={
  category="sm",
  description="LEFT AND RIGHT DOUBLE TURNSTILE",
  direction="on",
  linebreak="al",
  unicodeslot=0x27DA,
 },
 [0x27DB]={
  category="sm",
  description="LEFT AND RIGHT TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x27DB,
 },
 [0x27DC]={
  category="sm",
  description="LEFT MULTIMAP",
  direction="on",
  linebreak="al",
  unicodeslot=0x27DC,
 },
 [0x27DD]={
  category="sm",
  description="LONG RIGHT TACK",
  direction="on",
  linebreak="al",
  mirror=0x27DE,
  unicodeslot=0x27DD,
 },
 [0x27DE]={
  category="sm",
  description="LONG LEFT TACK",
  direction="on",
  linebreak="al",
  mirror=0x27DD,
  unicodeslot=0x27DE,
 },
 [0x27DF]={
  category="sm",
  description="UP TACK WITH CIRCLE ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x27DF,
 },
 [0x27E0]={
  category="sm",
  description="LOZENGE DIVIDED BY HORIZONTAL RULE",
  direction="on",
  linebreak="al",
  unicodeslot=0x27E0,
 },
 [0x27E1]={
  category="sm",
  description="WHITE CONCAVE-SIDED DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x27E1,
 },
 [0x27E2]={
  category="sm",
  description="WHITE CONCAVE-SIDED DIAMOND WITH LEFTWARDS TICK",
  direction="on",
  linebreak="al",
  mirror=0x27E3,
  unicodeslot=0x27E2,
 },
 [0x27E3]={
  category="sm",
  description="WHITE CONCAVE-SIDED DIAMOND WITH RIGHTWARDS TICK",
  direction="on",
  linebreak="al",
  mirror=0x27E2,
  unicodeslot=0x27E3,
 },
 [0x27E4]={
  category="sm",
  description="WHITE SQUARE WITH LEFTWARDS TICK",
  direction="on",
  linebreak="al",
  mirror=0x27E5,
  unicodeslot=0x27E4,
 },
 [0x27E5]={
  category="sm",
  description="WHITE SQUARE WITH RIGHTWARDS TICK",
  direction="on",
  linebreak="al",
  mirror=0x27E4,
  unicodeslot=0x27E5,
 },
 [0x27E6]={
  category="ps",
  cjkwd="na",
  description="MATHEMATICAL LEFT WHITE SQUARE BRACKET",
  direction="on",
  linebreak="op",
  mathclass="open",
  mathname="llbracket",
  mirror=0x27E7,
  unicodeslot=0x27E6,
 },
 [0x27E7]={
  category="pe",
  cjkwd="na",
  description="MATHEMATICAL RIGHT WHITE SQUARE BRACKET",
  direction="on",
  linebreak="cl",
  mathclass="close",
  mathname="rrbracket",
  mirror=0x27E6,
  unicodeslot=0x27E7,
 },
 [0x27E8]={
  category="ps",
  cjkwd="na",
  description="MATHEMATICAL LEFT ANGLE BRACKET",
  direction="on",
  linebreak="op",
  mathclass="open",
  mathname="langle",
  mirror=0x27E9,
  unicodeslot=0x27E8,
 },
 [0x27E9]={
  category="pe",
  cjkwd="na",
  description="MATHEMATICAL RIGHT ANGLE BRACKET",
  direction="on",
  linebreak="cl",
  mathclass="close",
  mathname="rangle",
  mirror=0x27E8,
  unicodeslot=0x27E9,
 },
 [0x27EA]={
  category="ps",
  cjkwd="na",
  description="MATHEMATICAL LEFT DOUBLE ANGLE BRACKET",
  direction="on",
  linebreak="op",
  mathclass="open",
  mathname="llangle",
  mirror=0x27EB,
  unicodeslot=0x27EA,
 },
 [0x27EB]={
  category="pe",
  cjkwd="na",
  description="MATHEMATICAL RIGHT DOUBLE ANGLE BRACKET",
  direction="on",
  linebreak="cl",
  mathclass="close",
  mathname="rrangle",
  mirror=0x27EA,
  unicodeslot=0x27EB,
 },
 [0x27EC]={
  category="ps",
  cjkwd="na",
  description="MATHEMATICAL LEFT WHITE TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x27ED,
  unicodeslot=0x27EC,
 },
 [0x27ED]={
  category="pe",
  cjkwd="na",
  description="MATHEMATICAL RIGHT WHITE TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x27EC,
  unicodeslot=0x27ED,
 },
 [0x27EE]={
  category="ps",
  description="MATHEMATICAL LEFT FLATTENED PARENTHESIS",
  direction="on",
  linebreak="op",
  mathclass="open",
  mathname="lgroup",
  mirror=0x27EF,
  unicodeslot=0x27EE,
 },
 [0x27EF]={
  category="pe",
  description="MATHEMATICAL RIGHT FLATTENED PARENTHESIS",
  direction="on",
  linebreak="cl",
  mathclass="close",
  mathname="rgroup",
  mirror=0x27EE,
  unicodeslot=0x27EF,
 },
 [0x27F0]={
  category="sm",
  description="UPWARDS QUADRUPLE ARROW",
  direction="on",
  linebreak="al",
  mathextensible="u",
  unicodeslot=0x27F0,
 },
 [0x27F1]={
  category="sm",
  description="DOWNWARDS QUADRUPLE ARROW",
  direction="on",
  linebreak="al",
  mathextensible="v",
  unicodeslot=0x27F1,
 },
 [0x27F2]={
  category="sm",
  description="ANTICLOCKWISE GAPPED CIRCLE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27F2,
 },
 [0x27F3]={
  category="sm",
  description="CLOCKWISE GAPPED CIRCLE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x27F3,
 },
 [0x27F4]={
  category="sm",
  description="RIGHT ARROW WITH CIRCLED PLUS",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x27F4,
 },
 [0x27F5]={
  category="sm",
  description="LONG LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="longleftarrow",
  unicodeslot=0x27F5,
 },
 [0x27F6]={
  category="sm",
  comment="the parent hack is needed for mathml",
  description="LONG RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathfiller="rightarrowfill",
  mathname="longrightarrow",
  mathparent=0x2192,
  unicodeslot=0x27F6,
 },
 [0x27F7]={
  category="sm",
  comment="the parent hack is needed for mathml",
  description="LONG LEFT RIGHT ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathfiller="leftrightarrowfill",
  mathname="longleftrightarrow",
  mathparent=0x2190,
  unicodeslot=0x27F7,
 },
 [0x27F8]={
  category="sm",
  description="LONG LEFTWARDS DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathfiller="Leftarrowfill",
  mathname="Longleftarrow",
  unicodeslot=0x27F8,
 },
 [0x27F9]={
  category="sm",
  description="LONG RIGHTWARDS DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathfiller="Rightarrowfill",
  mathname="Longrightarrow",
  unicodeslot=0x27F9,
 },
 [0x27FA]={
  category="sm",
  description="LONG LEFT RIGHT DOUBLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="h",
  mathfiller="Leftrightarrowfill",
  mathname="Longleftrightarrow",
  unicodeslot=0x27FA,
 },
 [0x27FB]={
  category="sm",
  description="LONG LEFTWARDS ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="longmapsfrom",
  unicodeslot=0x27FB,
 },
 [0x27FC]={
  category="sm",
  description="LONG RIGHTWARDS ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="longmapsto",
  unicodeslot=0x27FC,
 },
 [0x27FD]={
  category="sm",
  description="LONG LEFTWARDS DOUBLE ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="Longmapsfrom",
  unicodeslot=0x27FD,
 },
 [0x27FE]={
  category="sm",
  description="LONG RIGHTWARDS DOUBLE ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="Longmapsto",
  unicodeslot=0x27FE,
 },
 [0x27FF]={
  category="sm",
  description="LONG RIGHTWARDS SQUIGGLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="longrightsquigarrow",
  unicodeslot=0x27FF,
 },
 [0x2800]={
  category="so",
  description="BRAILLE PATTERN BLANK",
  direction="l",
  linebreak="al",
  unicodeslot=0x2800,
 },
 [0x2801]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0001",
  direction="l",
  linebreak="al",
  unicodeslot=0x2801,
 },
 [0x2802]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x2802,
 },
 [0x2803]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x000C",
  direction="l",
  linebreak="al",
  unicodeslot=0x2803,
 },
 [0x2804]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x2804,
 },
 [0x2805]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x000D",
  direction="l",
  linebreak="al",
  unicodeslot=0x2805,
 },
 [0x2806]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0017",
  direction="l",
  linebreak="al",
  unicodeslot=0x2806,
 },
 [0x2807]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x007B",
  direction="l",
  linebreak="al",
  unicodeslot=0x2807,
 },
 [0x2808]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x2808,
 },
 [0x2809]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x000E",
  direction="l",
  linebreak="al",
  unicodeslot=0x2809,
 },
 [0x280A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0018",
  direction="l",
  linebreak="al",
  unicodeslot=0x280A,
 },
 [0x280B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x007C",
  direction="l",
  linebreak="al",
  unicodeslot=0x280B,
 },
 [0x280C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0022",
  direction="l",
  linebreak="al",
  unicodeslot=0x280C,
 },
 [0x280D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0086",
  direction="l",
  linebreak="al",
  unicodeslot=0x280D,
 },
 [0x280E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00EA",
  direction="l",
  linebreak="al",
  unicodeslot=0x280E,
 },
 [0x280F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04D2",
  direction="l",
  linebreak="al",
  unicodeslot=0x280F,
 },
 [0x2810]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0005",
  direction="l",
  linebreak="al",
  unicodeslot=0x2810,
 },
 [0x2811]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x000F",
  direction="l",
  linebreak="al",
  unicodeslot=0x2811,
 },
 [0x2812]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0019",
  direction="l",
  linebreak="al",
  unicodeslot=0x2812,
 },
 [0x2813]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x007D",
  direction="l",
  linebreak="al",
  unicodeslot=0x2813,
 },
 [0x2814]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0023",
  direction="l",
  linebreak="al",
  unicodeslot=0x2814,
 },
 [0x2815]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0087",
  direction="l",
  linebreak="al",
  unicodeslot=0x2815,
 },
 [0x2816]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00EB",
  direction="l",
  linebreak="al",
  unicodeslot=0x2816,
 },
 [0x2817]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04D3",
  direction="l",
  linebreak="al",
  unicodeslot=0x2817,
 },
 [0x2818]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x002D",
  direction="l",
  linebreak="al",
  unicodeslot=0x2818,
 },
 [0x2819]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0091",
  direction="l",
  linebreak="al",
  unicodeslot=0x2819,
 },
 [0x281A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00F5",
  direction="l",
  linebreak="al",
  unicodeslot=0x281A,
 },
 [0x281B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04DD",
  direction="l",
  linebreak="al",
  unicodeslot=0x281B,
 },
 [0x281C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0159",
  direction="l",
  linebreak="al",
  unicodeslot=0x281C,
 },
 [0x281D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0541",
  direction="l",
  linebreak="al",
  unicodeslot=0x281D,
 },
 [0x281E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0929",
  direction="l",
  linebreak="al",
  unicodeslot=0x281E,
 },
 [0x281F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3039",
  direction="l",
  linebreak="al",
  unicodeslot=0x281F,
 },
 [0x2820]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0006",
  direction="l",
  linebreak="al",
  unicodeslot=0x2820,
 },
 [0x2821]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0010",
  direction="l",
  linebreak="al",
  unicodeslot=0x2821,
 },
 [0x2822]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x001A",
  direction="l",
  linebreak="al",
  unicodeslot=0x2822,
 },
 [0x2823]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x007E",
  direction="l",
  linebreak="al",
  unicodeslot=0x2823,
 },
 [0x2824]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0024",
  direction="l",
  linebreak="al",
  unicodeslot=0x2824,
 },
 [0x2825]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0088",
  direction="l",
  linebreak="al",
  unicodeslot=0x2825,
 },
 [0x2826]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00EC",
  direction="l",
  linebreak="al",
  unicodeslot=0x2826,
 },
 [0x2827]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04D4",
  direction="l",
  linebreak="al",
  unicodeslot=0x2827,
 },
 [0x2828]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x002E",
  direction="l",
  linebreak="al",
  unicodeslot=0x2828,
 },
 [0x2829]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0092",
  direction="l",
  linebreak="al",
  unicodeslot=0x2829,
 },
 [0x282A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00F6",
  direction="l",
  linebreak="al",
  unicodeslot=0x282A,
 },
 [0x282B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04DE",
  direction="l",
  linebreak="al",
  unicodeslot=0x282B,
 },
 [0x282C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x015A",
  direction="l",
  linebreak="al",
  unicodeslot=0x282C,
 },
 [0x282D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0542",
  direction="l",
  linebreak="al",
  unicodeslot=0x282D,
 },
 [0x282E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x092A",
  direction="l",
  linebreak="al",
  unicodeslot=0x282E,
 },
 [0x282F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x303A",
  direction="l",
  linebreak="al",
  unicodeslot=0x282F,
 },
 [0x2830]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0038",
  direction="l",
  linebreak="al",
  unicodeslot=0x2830,
 },
 [0x2831]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x009C",
  direction="l",
  linebreak="al",
  unicodeslot=0x2831,
 },
 [0x2832]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0100",
  direction="l",
  linebreak="al",
  unicodeslot=0x2832,
 },
 [0x2833]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04E8",
  direction="l",
  linebreak="al",
  unicodeslot=0x2833,
 },
 [0x2834]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0164",
  direction="l",
  linebreak="al",
  unicodeslot=0x2834,
 },
 [0x2835]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x054C",
  direction="l",
  linebreak="al",
  unicodeslot=0x2835,
 },
 [0x2836]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0934",
  direction="l",
  linebreak="al",
  unicodeslot=0x2836,
 },
 [0x2837]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3044",
  direction="l",
  linebreak="al",
  unicodeslot=0x2837,
 },
 [0x2838]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x01C8",
  direction="l",
  linebreak="al",
  unicodeslot=0x2838,
 },
 [0x2839]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x05B0",
  direction="l",
  linebreak="al",
  unicodeslot=0x2839,
 },
 [0x283A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0998",
  direction="l",
  linebreak="al",
  unicodeslot=0x283A,
 },
 [0x283B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x30A8",
  direction="l",
  linebreak="al",
  unicodeslot=0x283B,
 },
 [0x283C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0D80",
  direction="l",
  linebreak="al",
  unicodeslot=0x283C,
 },
 [0x283D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3490",
  direction="l",
  linebreak="al",
  unicodeslot=0x283D,
 },
 [0x283E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5BA0",
  direction="l",
  linebreak="al",
  unicodeslot=0x283E,
 },
 [0x283F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E240",
  direction="l",
  linebreak="al",
  unicodeslot=0x283F,
 },
 [0x2840]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0007",
  direction="l",
  linebreak="al",
  unicodeslot=0x2840,
 },
 [0x2841]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0011",
  direction="l",
  linebreak="al",
  unicodeslot=0x2841,
 },
 [0x2842]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x001B",
  direction="l",
  linebreak="al",
  unicodeslot=0x2842,
 },
 [0x2843]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x007F",
  direction="l",
  linebreak="al",
  unicodeslot=0x2843,
 },
 [0x2844]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0025",
  direction="l",
  linebreak="al",
  unicodeslot=0x2844,
 },
 [0x2845]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0089",
  direction="l",
  linebreak="al",
  unicodeslot=0x2845,
 },
 [0x2846]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00ED",
  direction="l",
  linebreak="al",
  unicodeslot=0x2846,
 },
 [0x2847]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04D5",
  direction="l",
  linebreak="al",
  unicodeslot=0x2847,
 },
 [0x2848]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x002F",
  direction="l",
  linebreak="al",
  unicodeslot=0x2848,
 },
 [0x2849]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0093",
  direction="l",
  linebreak="al",
  unicodeslot=0x2849,
 },
 [0x284A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00F7",
  direction="l",
  linebreak="al",
  unicodeslot=0x284A,
 },
 [0x284B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04DF",
  direction="l",
  linebreak="al",
  unicodeslot=0x284B,
 },
 [0x284C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x015B",
  direction="l",
  linebreak="al",
  unicodeslot=0x284C,
 },
 [0x284D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0543",
  direction="l",
  linebreak="al",
  unicodeslot=0x284D,
 },
 [0x284E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x092B",
  direction="l",
  linebreak="al",
  unicodeslot=0x284E,
 },
 [0x284F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x303B",
  direction="l",
  linebreak="al",
  unicodeslot=0x284F,
 },
 [0x2850]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0039",
  direction="l",
  linebreak="al",
  unicodeslot=0x2850,
 },
 [0x2851]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x009D",
  direction="l",
  linebreak="al",
  unicodeslot=0x2851,
 },
 [0x2852]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0101",
  direction="l",
  linebreak="al",
  unicodeslot=0x2852,
 },
 [0x2853]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04E9",
  direction="l",
  linebreak="al",
  unicodeslot=0x2853,
 },
 [0x2854]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0165",
  direction="l",
  linebreak="al",
  unicodeslot=0x2854,
 },
 [0x2855]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x054D",
  direction="l",
  linebreak="al",
  unicodeslot=0x2855,
 },
 [0x2856]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0935",
  direction="l",
  linebreak="al",
  unicodeslot=0x2856,
 },
 [0x2857]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3045",
  direction="l",
  linebreak="al",
  unicodeslot=0x2857,
 },
 [0x2858]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x01C9",
  direction="l",
  linebreak="al",
  unicodeslot=0x2858,
 },
 [0x2859]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x05B1",
  direction="l",
  linebreak="al",
  unicodeslot=0x2859,
 },
 [0x285A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0999",
  direction="l",
  linebreak="al",
  unicodeslot=0x285A,
 },
 [0x285B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x30A9",
  direction="l",
  linebreak="al",
  unicodeslot=0x285B,
 },
 [0x285C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0D81",
  direction="l",
  linebreak="al",
  unicodeslot=0x285C,
 },
 [0x285D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3491",
  direction="l",
  linebreak="al",
  unicodeslot=0x285D,
 },
 [0x285E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5BA1",
  direction="l",
  linebreak="al",
  unicodeslot=0x285E,
 },
 [0x285F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E241",
  direction="l",
  linebreak="al",
  unicodeslot=0x285F,
 },
 [0x2860]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0043",
  direction="l",
  linebreak="al",
  unicodeslot=0x2860,
 },
 [0x2861]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00A7",
  direction="l",
  linebreak="al",
  unicodeslot=0x2861,
 },
 [0x2862]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x010B",
  direction="l",
  linebreak="al",
  unicodeslot=0x2862,
 },
 [0x2863]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04F3",
  direction="l",
  linebreak="al",
  unicodeslot=0x2863,
 },
 [0x2864]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x016F",
  direction="l",
  linebreak="al",
  unicodeslot=0x2864,
 },
 [0x2865]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0557",
  direction="l",
  linebreak="al",
  unicodeslot=0x2865,
 },
 [0x2866]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x093F",
  direction="l",
  linebreak="al",
  unicodeslot=0x2866,
 },
 [0x2867]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x304F",
  direction="l",
  linebreak="al",
  unicodeslot=0x2867,
 },
 [0x2868]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x01D3",
  direction="l",
  linebreak="al",
  unicodeslot=0x2868,
 },
 [0x2869]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x05BB",
  direction="l",
  linebreak="al",
  unicodeslot=0x2869,
 },
 [0x286A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x09A3",
  direction="l",
  linebreak="al",
  unicodeslot=0x286A,
 },
 [0x286B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x30B3",
  direction="l",
  linebreak="al",
  unicodeslot=0x286B,
 },
 [0x286C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0D8B",
  direction="l",
  linebreak="al",
  unicodeslot=0x286C,
 },
 [0x286D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x349B",
  direction="l",
  linebreak="al",
  unicodeslot=0x286D,
 },
 [0x286E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5BAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x286E,
 },
 [0x286F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E24B",
  direction="l",
  linebreak="al",
  unicodeslot=0x286F,
 },
 [0x2870]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0237",
  direction="l",
  linebreak="al",
  unicodeslot=0x2870,
 },
 [0x2871]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x061F",
  direction="l",
  linebreak="al",
  unicodeslot=0x2871,
 },
 [0x2872]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0A07",
  direction="l",
  linebreak="al",
  unicodeslot=0x2872,
 },
 [0x2873]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3117",
  direction="l",
  linebreak="al",
  unicodeslot=0x2873,
 },
 [0x2874]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0DEF",
  direction="l",
  linebreak="al",
  unicodeslot=0x2874,
 },
 [0x2875]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x34FF",
  direction="l",
  linebreak="al",
  unicodeslot=0x2875,
 },
 [0x2876]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5C0F",
  direction="l",
  linebreak="al",
  unicodeslot=0x2876,
 },
 [0x2877]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E2AF",
  direction="l",
  linebreak="al",
  unicodeslot=0x2877,
 },
 [0x2878]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x11D7",
  direction="l",
  linebreak="al",
  unicodeslot=0x2878,
 },
 [0x2879]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x38E7",
  direction="l",
  linebreak="al",
  unicodeslot=0x2879,
 },
 [0x287A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5FF7",
  direction="l",
  linebreak="al",
  unicodeslot=0x287A,
 },
 [0x287B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E697",
  direction="l",
  linebreak="al",
  unicodeslot=0x287B,
 },
 [0x287C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x8707",
  direction="l",
  linebreak="al",
  unicodeslot=0x287C,
 },
 [0x287D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x20DA7",
  direction="l",
  linebreak="al",
  unicodeslot=0x287D,
 },
 [0x287E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x39447",
  direction="l",
  linebreak="al",
  unicodeslot=0x287E,
 },
 [0x287F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x12D687",
  direction="l",
  linebreak="al",
  unicodeslot=0x287F,
 },
 [0x2880]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0008",
  direction="l",
  linebreak="al",
  unicodeslot=0x2880,
 },
 [0x2881]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0012",
  direction="l",
  linebreak="al",
  unicodeslot=0x2881,
 },
 [0x2882]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x001C",
  direction="l",
  linebreak="al",
  unicodeslot=0x2882,
 },
 [0x2883]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0080",
  direction="l",
  linebreak="al",
  unicodeslot=0x2883,
 },
 [0x2884]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0026",
  direction="l",
  linebreak="al",
  unicodeslot=0x2884,
 },
 [0x2885]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x008A",
  direction="l",
  linebreak="al",
  unicodeslot=0x2885,
 },
 [0x2886]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2886,
 },
 [0x2887]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04D6",
  direction="l",
  linebreak="al",
  unicodeslot=0x2887,
 },
 [0x2888]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0030",
  direction="l",
  linebreak="al",
  unicodeslot=0x2888,
 },
 [0x2889]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0094",
  direction="l",
  linebreak="al",
  unicodeslot=0x2889,
 },
 [0x288A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00F8",
  direction="l",
  linebreak="al",
  unicodeslot=0x288A,
 },
 [0x288B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04E0",
  direction="l",
  linebreak="al",
  unicodeslot=0x288B,
 },
 [0x288C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x015C",
  direction="l",
  linebreak="al",
  unicodeslot=0x288C,
 },
 [0x288D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0544",
  direction="l",
  linebreak="al",
  unicodeslot=0x288D,
 },
 [0x288E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x092C",
  direction="l",
  linebreak="al",
  unicodeslot=0x288E,
 },
 [0x288F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x303C",
  direction="l",
  linebreak="al",
  unicodeslot=0x288F,
 },
 [0x2890]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x003A",
  direction="l",
  linebreak="al",
  unicodeslot=0x2890,
 },
 [0x2891]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x009E",
  direction="l",
  linebreak="al",
  unicodeslot=0x2891,
 },
 [0x2892]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0102",
  direction="l",
  linebreak="al",
  unicodeslot=0x2892,
 },
 [0x2893]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04EA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2893,
 },
 [0x2894]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0166",
  direction="l",
  linebreak="al",
  unicodeslot=0x2894,
 },
 [0x2895]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x054E",
  direction="l",
  linebreak="al",
  unicodeslot=0x2895,
 },
 [0x2896]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0936",
  direction="l",
  linebreak="al",
  unicodeslot=0x2896,
 },
 [0x2897]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3046",
  direction="l",
  linebreak="al",
  unicodeslot=0x2897,
 },
 [0x2898]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x01CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2898,
 },
 [0x2899]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x05B2",
  direction="l",
  linebreak="al",
  unicodeslot=0x2899,
 },
 [0x289A]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x099A",
  direction="l",
  linebreak="al",
  unicodeslot=0x289A,
 },
 [0x289B]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x30AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x289B,
 },
 [0x289C]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0D82",
  direction="l",
  linebreak="al",
  unicodeslot=0x289C,
 },
 [0x289D]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3492",
  direction="l",
  linebreak="al",
  unicodeslot=0x289D,
 },
 [0x289E]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5BA2",
  direction="l",
  linebreak="al",
  unicodeslot=0x289E,
 },
 [0x289F]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E242",
  direction="l",
  linebreak="al",
  unicodeslot=0x289F,
 },
 [0x28A0]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0044",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A0,
 },
 [0x28A1]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00A8",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A1,
 },
 [0x28A2]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x010C",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A2,
 },
 [0x28A3]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04F4",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A3,
 },
 [0x28A4]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0170",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A4,
 },
 [0x28A5]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0558",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A5,
 },
 [0x28A6]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0940",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A6,
 },
 [0x28A7]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3050",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A7,
 },
 [0x28A8]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x01D4",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A8,
 },
 [0x28A9]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x05BC",
  direction="l",
  linebreak="al",
  unicodeslot=0x28A9,
 },
 [0x28AA]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x09A4",
  direction="l",
  linebreak="al",
  unicodeslot=0x28AA,
 },
 [0x28AB]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x30B4",
  direction="l",
  linebreak="al",
  unicodeslot=0x28AB,
 },
 [0x28AC]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0D8C",
  direction="l",
  linebreak="al",
  unicodeslot=0x28AC,
 },
 [0x28AD]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x349C",
  direction="l",
  linebreak="al",
  unicodeslot=0x28AD,
 },
 [0x28AE]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5BAC",
  direction="l",
  linebreak="al",
  unicodeslot=0x28AE,
 },
 [0x28AF]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E24C",
  direction="l",
  linebreak="al",
  unicodeslot=0x28AF,
 },
 [0x28B0]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0238",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B0,
 },
 [0x28B1]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0620",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B1,
 },
 [0x28B2]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0A08",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B2,
 },
 [0x28B3]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3118",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B3,
 },
 [0x28B4]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0DF0",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B4,
 },
 [0x28B5]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3500",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B5,
 },
 [0x28B6]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5C10",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B6,
 },
 [0x28B7]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E2B0",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B7,
 },
 [0x28B8]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x11D8",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B8,
 },
 [0x28B9]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x38E8",
  direction="l",
  linebreak="al",
  unicodeslot=0x28B9,
 },
 [0x28BA]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5FF8",
  direction="l",
  linebreak="al",
  unicodeslot=0x28BA,
 },
 [0x28BB]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E698",
  direction="l",
  linebreak="al",
  unicodeslot=0x28BB,
 },
 [0x28BC]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x8708",
  direction="l",
  linebreak="al",
  unicodeslot=0x28BC,
 },
 [0x28BD]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x20DA8",
  direction="l",
  linebreak="al",
  unicodeslot=0x28BD,
 },
 [0x28BE]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x39448",
  direction="l",
  linebreak="al",
  unicodeslot=0x28BE,
 },
 [0x28BF]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x12D688",
  direction="l",
  linebreak="al",
  unicodeslot=0x28BF,
 },
 [0x28C0]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x004E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C0,
 },
 [0x28C1]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x00B2",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C1,
 },
 [0x28C2]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0116",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C2,
 },
 [0x28C3]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x04FE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C3,
 },
 [0x28C4]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x017A",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C4,
 },
 [0x28C5]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0562",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C5,
 },
 [0x28C6]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x094A",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C6,
 },
 [0x28C7]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x305A",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C7,
 },
 [0x28C8]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x01DE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C8,
 },
 [0x28C9]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x05C6",
  direction="l",
  linebreak="al",
  unicodeslot=0x28C9,
 },
 [0x28CA]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x09AE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28CA,
 },
 [0x28CB]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x30BE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28CB,
 },
 [0x28CC]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0D96",
  direction="l",
  linebreak="al",
  unicodeslot=0x28CC,
 },
 [0x28CD]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x34A6",
  direction="l",
  linebreak="al",
  unicodeslot=0x28CD,
 },
 [0x28CE]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5BB6",
  direction="l",
  linebreak="al",
  unicodeslot=0x28CE,
 },
 [0x28CF]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E256",
  direction="l",
  linebreak="al",
  unicodeslot=0x28CF,
 },
 [0x28D0]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0242",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D0,
 },
 [0x28D1]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x062A",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D1,
 },
 [0x28D2]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0A12",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D2,
 },
 [0x28D3]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3122",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D3,
 },
 [0x28D4]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0DFA",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D4,
 },
 [0x28D5]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x350A",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D5,
 },
 [0x28D6]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5C1A",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D6,
 },
 [0x28D7]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E2BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D7,
 },
 [0x28D8]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x11E2",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D8,
 },
 [0x28D9]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x38F2",
  direction="l",
  linebreak="al",
  unicodeslot=0x28D9,
 },
 [0x28DA]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x6002",
  direction="l",
  linebreak="al",
  unicodeslot=0x28DA,
 },
 [0x28DB]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E6A2",
  direction="l",
  linebreak="al",
  unicodeslot=0x28DB,
 },
 [0x28DC]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x8712",
  direction="l",
  linebreak="al",
  unicodeslot=0x28DC,
 },
 [0x28DD]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x20DB2",
  direction="l",
  linebreak="al",
  unicodeslot=0x28DD,
 },
 [0x28DE]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x39452",
  direction="l",
  linebreak="al",
  unicodeslot=0x28DE,
 },
 [0x28DF]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x12D692",
  direction="l",
  linebreak="al",
  unicodeslot=0x28DF,
 },
 [0x28E0]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x02A6",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E0,
 },
 [0x28E1]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x068E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E1,
 },
 [0x28E2]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0A76",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E2,
 },
 [0x28E3]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3186",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E3,
 },
 [0x28E4]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x0E5E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E4,
 },
 [0x28E5]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x356E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E5,
 },
 [0x28E6]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5C7E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E6,
 },
 [0x28E7]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E31E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E7,
 },
 [0x28E8]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1246",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E8,
 },
 [0x28E9]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3956",
  direction="l",
  linebreak="al",
  unicodeslot=0x28E9,
 },
 [0x28EA]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x6066",
  direction="l",
  linebreak="al",
  unicodeslot=0x28EA,
 },
 [0x28EB]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1E706",
  direction="l",
  linebreak="al",
  unicodeslot=0x28EB,
 },
 [0x28EC]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x8776",
  direction="l",
  linebreak="al",
  unicodeslot=0x28EC,
 },
 [0x28ED]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x20E16",
  direction="l",
  linebreak="al",
  unicodeslot=0x28ED,
 },
 [0x28EE]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x394B6",
  direction="l",
  linebreak="al",
  unicodeslot=0x28EE,
 },
 [0x28EF]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x12D6F6",
  direction="l",
  linebreak="al",
  unicodeslot=0x28EF,
 },
 [0x28F0]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x162E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F0,
 },
 [0x28F1]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3D3E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F1,
 },
 [0x28F2]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x644E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F2,
 },
 [0x28F3]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1EAEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F3,
 },
 [0x28F4]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x8B5E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F4,
 },
 [0x28F5]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x211FE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F5,
 },
 [0x28F6]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3989E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F6,
 },
 [0x28F7]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x12DADE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F7,
 },
 [0x28F8]={
  category="so",
  description="BRAILLE PATTERN DOTS-0xB26E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F8,
 },
 [0x28F9]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x2390E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28F9,
 },
 [0x28FA]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x3BFAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28FA,
 },
 [0x28FB]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x1301EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28FB,
 },
 [0x28FC]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x5464E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28FC,
 },
 [0x28FD]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x14888E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28FD,
 },
 [0x28FE]={
  category="so",
  description="BRAILLE PATTERN DOTS-0x23CACE",
  direction="l",
  linebreak="al",
  unicodeslot=0x28FE,
 },
 [0x28FF]={
  category="so",
  description="BRAILLE PATTERN DOTS-0xBC614E",
  direction="l",
  linebreak="al",
  unicodeslot=0x28FF,
 },
 [0x2900]={
  category="sm",
  description="RIGHTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2900,
 },
 [0x2901]={
  category="sm",
  description="RIGHTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2901,
 },
 [0x2902]={
  category="sm",
  description="LEFTWARDS DOUBLE ARROW WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2902,
 },
 [0x2903]={
  category="sm",
  description="RIGHTWARDS DOUBLE ARROW WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2903,
 },
 [0x2904]={
  category="sm",
  description="LEFT RIGHT DOUBLE ARROW WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="h",
  unicodeslot=0x2904,
 },
 [0x2905]={
  category="sm",
  description="RIGHTWARDS TWO-HEADED ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2905,
 },
 [0x2906]={
  category="sm",
  description="LEFTWARDS DOUBLE ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="Mapsfrom",
  unicodeslot=0x2906,
 },
 [0x2907]={
  category="sm",
  description="RIGHTWARDS DOUBLE ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="Mapsto",
  unicodeslot=0x2907,
 },
 [0x2908]={
  category="sm",
  description="DOWNWARDS ARROW WITH HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="d",
  unicodeslot=0x2908,
 },
 [0x2909]={
  category="sm",
  description="UPWARDS ARROW WITH HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="u",
  unicodeslot=0x2909,
 },
 [0x290A]={
  category="sm",
  description="UPWARDS TRIPLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="u",
  mathname="Uuparrow",
  unicodeslot=0x290A,
 },
 [0x290B]={
  category="sm",
  description="DOWNWARDS TRIPLE ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="d",
  mathname="Ddownarrow",
  unicodeslot=0x290B,
 },
 [0x290C]={
  category="sm",
  description="LEFTWARDS DOUBLE DASH ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="l",
  mathname="dashedleftarrow",
  unicodeslot=0x290C,
 },
 [0x290D]={
  category="sm",
  description="RIGHTWARDS DOUBLE DASH ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="dashedrightarrow",
  unicodeslot=0x290D,
 },
 [0x290E]={
  category="sm",
  description="LEFTWARDS TRIPLE DASH ARROW",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x290E,
 },
 [0x290F]={
  category="sm",
  description="RIGHTWARDS TRIPLE DASH ARROW",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x290F,
 },
 [0x2910]={
  category="sm",
  description="RIGHTWARDS TWO-HEADED TRIPLE DASH ARROW",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2910,
 },
 [0x2911]={
  category="sm",
  description="RIGHTWARDS ARROW WITH DOTTED STEM",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="dottedrightarrow",
  unicodeslot=0x2911,
 },
 [0x2912]={
  category="sm",
  description="UPWARDS ARROW TO BAR",
  direction="on",
  linebreak="al",
  mathextensible="u",
  unicodeslot=0x2912,
 },
 [0x2913]={
  category="sm",
  description="DOWNWARDS ARROW TO BAR",
  direction="on",
  linebreak="al",
  mathextensible="d",
  unicodeslot=0x2913,
 },
 [0x2914]={
  category="sm",
  description="RIGHTWARDS ARROW WITH TAIL WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2914,
 },
 [0x2915]={
  category="sm",
  description="RIGHTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2915,
 },
 [0x2916]={
  category="sm",
  description="RIGHTWARDS TWO-HEADED ARROW WITH TAIL",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  mathname="twoheadrightarrowtail",
  unicodeslot=0x2916,
 },
 [0x2917]={
  category="sm",
  description="RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathextensible="r",
  unicodeslot=0x2917,
 },
 [0x2918]={
  category="sm",
  description="RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2918,
 },
 [0x2919]={
  category="sm",
  description="LEFTWARDS ARROW-TAIL",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2919,
 },
 [0x291A]={
  category="sm",
  description="RIGHTWARDS ARROW-TAIL",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x291A,
 },
 [0x291B]={
  category="sm",
  description="LEFTWARDS DOUBLE ARROW-TAIL",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x291B,
 },
 [0x291C]={
  category="sm",
  description="RIGHTWARDS DOUBLE ARROW-TAIL",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x291C,
 },
 [0x291D]={
  category="sm",
  description="LEFTWARDS ARROW TO BLACK DIAMOND",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x291D,
 },
 [0x291E]={
  category="sm",
  description="RIGHTWARDS ARROW TO BLACK DIAMOND",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x291E,
 },
 [0x291F]={
  category="sm",
  description="LEFTWARDS ARROW FROM BAR TO BLACK DIAMOND",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x291F,
 },
 [0x2920]={
  category="sm",
  description="RIGHTWARDS ARROW FROM BAR TO BLACK DIAMOND",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2920,
 },
 [0x2921]={
  category="sm",
  description="NORTH WEST AND SOUTH EAST ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="nwsearrow",
  unicodeslot=0x2921,
 },
 [0x2922]={
  category="sm",
  description="NORTH EAST AND SOUTH WEST ARROW",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="neswarrow",
  unicodeslot=0x2922,
 },
 [0x2923]={
  category="sm",
  description="NORTH WEST ARROW WITH HOOK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lhooknwarrow",
  unicodeslot=0x2923,
 },
 [0x2924]={
  category="sm",
  description="NORTH EAST ARROW WITH HOOK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="rhooknearrow",
  unicodeslot=0x2924,
 },
 [0x2925]={
  category="sm",
  description="SOUTH EAST ARROW WITH HOOK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lhooksearrow",
  unicodeslot=0x2925,
 },
 [0x2926]={
  category="sm",
  description="SOUTH WEST ARROW WITH HOOK",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="rhookswarrow",
  unicodeslot=0x2926,
 },
 [0x2927]={
  category="sm",
  description="NORTH WEST ARROW AND NORTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2927,
 },
 [0x2928]={
  category="sm",
  description="NORTH EAST ARROW AND SOUTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2928,
 },
 [0x2929]={
  category="sm",
  description="SOUTH EAST ARROW AND SOUTH WEST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2929,
 },
 [0x292A]={
  category="sm",
  description="SOUTH WEST ARROW AND NORTH WEST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x292A,
 },
 [0x292B]={
  category="sm",
  description="RISING DIAGONAL CROSSING FALLING DIAGONAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x292B,
 },
 [0x292C]={
  category="sm",
  description="FALLING DIAGONAL CROSSING RISING DIAGONAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x292C,
 },
 [0x292D]={
  category="sm",
  description="SOUTH EAST ARROW CROSSING NORTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x292D,
 },
 [0x292E]={
  category="sm",
  description="NORTH EAST ARROW CROSSING SOUTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x292E,
 },
 [0x292F]={
  category="sm",
  description="FALLING DIAGONAL CROSSING NORTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x292F,
 },
 [0x2930]={
  category="sm",
  description="RISING DIAGONAL CROSSING SOUTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2930,
 },
 [0x2931]={
  category="sm",
  description="NORTH EAST ARROW CROSSING NORTH WEST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2931,
 },
 [0x2932]={
  category="sm",
  description="NORTH WEST ARROW CROSSING NORTH EAST ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2932,
 },
 [0x2933]={
  category="sm",
  description="WAVE ARROW POINTING DIRECTLY RIGHT",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2933,
 },
 [0x2934]={
  category="sm",
  description="ARROW POINTING RIGHTWARDS THEN CURVING UPWARDS",
  direction="on",
  linebreak="al",
  mathextensible="m",
  unicodeslot=0x2934,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2935]={
  category="sm",
  description="ARROW POINTING RIGHTWARDS THEN CURVING DOWNWARDS",
  direction="on",
  linebreak="al",
  mathextensible="m",
  unicodeslot=0x2935,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2936]={
  category="sm",
  description="ARROW POINTING DOWNWARDS THEN CURVING LEFTWARDS",
  direction="on",
  linebreak="al",
  mathextensible="m",
  unicodeslot=0x2936,
 },
 [0x2937]={
  category="sm",
  description="ARROW POINTING DOWNWARDS THEN CURVING RIGHTWARDS",
  direction="on",
  linebreak="al",
  mathextensible="m",
  unicodeslot=0x2937,
 },
 [0x2938]={
  category="sm",
  description="RIGHT-SIDE ARC CLOCKWISE ARROW",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2938,
 },
 [0x2939]={
  category="sm",
  description="LEFT-SIDE ARC ANTICLOCKWISE ARROW",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2939,
 },
 [0x293A]={
  category="sm",
  description="TOP ARC ANTICLOCKWISE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x293A,
 },
 [0x293B]={
  category="sm",
  description="BOTTOM ARC ANTICLOCKWISE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x293B,
 },
 [0x293C]={
  category="sm",
  description="TOP ARC CLOCKWISE ARROW WITH MINUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x293C,
 },
 [0x293D]={
  category="sm",
  description="TOP ARC ANTICLOCKWISE ARROW WITH PLUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x293D,
 },
 [0x293E]={
  category="sm",
  description="LOWER RIGHT SEMICIRCULAR CLOCKWISE ARROW",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x293E,
 },
 [0x293F]={
  category="sm",
  description="LOWER LEFT SEMICIRCULAR ANTICLOCKWISE ARROW",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x293F,
 },
 [0x2940]={
  category="sm",
  description="ANTICLOCKWISE CLOSED CIRCLE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2940,
 },
 [0x2941]={
  category="sm",
  description="CLOCKWISE CLOSED CIRCLE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2941,
 },
 [0x2942]={
  category="sm",
  description="RIGHTWARDS ARROW ABOVE SHORT LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2942,
 },
 [0x2943]={
  category="sm",
  description="LEFTWARDS ARROW ABOVE SHORT RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2943,
 },
 [0x2944]={
  category="sm",
  description="SHORT RIGHTWARDS ARROW ABOVE LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2944,
 },
 [0x2945]={
  category="sm",
  description="RIGHTWARDS ARROW WITH PLUS BELOW",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2945,
 },
 [0x2946]={
  category="sm",
  description="LEFTWARDS ARROW WITH PLUS BELOW",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2946,
 },
 [0x2947]={
  category="sm",
  description="RIGHTWARDS ARROW THROUGH X",
  direction="on",
  linebreak="al",
  unicodeslot=0x2947,
 },
 [0x2948]={
  category="sm",
  description="LEFT RIGHT ARROW THROUGH SMALL CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2948,
 },
 [0x2949]={
  category="sm",
  description="UPWARDS TWO-HEADED ARROW FROM SMALL CIRCLE",
  direction="on",
  linebreak="al",
  mathextensible="u",
  unicodeslot=0x2949,
 },
 [0x294A]={
  category="sm",
  description="LEFT BARB UP RIGHT BARB DOWN HARPOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x294A,
 },
 [0x294B]={
  category="sm",
  description="LEFT BARB DOWN RIGHT BARB UP HARPOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x294B,
 },
 [0x294C]={
  category="sm",
  description="UP BARB RIGHT DOWN BARB LEFT HARPOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x294C,
 },
 [0x294D]={
  category="sm",
  description="UP BARB LEFT DOWN BARB RIGHT HARPOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x294D,
 },
 [0x294E]={
  category="sm",
  description="LEFT BARB UP RIGHT BARB UP HARPOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x294E,
 },
 [0x294F]={
  category="sm",
  description="UP BARB RIGHT DOWN BARB RIGHT HARPOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x294F,
 },
 [0x2950]={
  category="sm",
  description="LEFT BARB DOWN RIGHT BARB DOWN HARPOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2950,
 },
 [0x2951]={
  category="sm",
  description="UP BARB LEFT DOWN BARB LEFT HARPOON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2951,
 },
 [0x2952]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB UP TO BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2952,
 },
 [0x2953]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB UP TO BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2953,
 },
 [0x2954]={
  category="sm",
  description="UPWARDS HARPOON WITH BARB RIGHT TO BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2954,
 },
 [0x2955]={
  category="sm",
  description="DOWNWARDS HARPOON WITH BARB RIGHT TO BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2955,
 },
 [0x2956]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB DOWN TO BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2956,
 },
 [0x2957]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB DOWN TO BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2957,
 },
 [0x2958]={
  category="sm",
  description="UPWARDS HARPOON WITH BARB LEFT TO BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2958,
 },
 [0x2959]={
  category="sm",
  description="DOWNWARDS HARPOON WITH BARB LEFT TO BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2959,
 },
 [0x295A]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB UP FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x295A,
 },
 [0x295B]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB UP FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x295B,
 },
 [0x295C]={
  category="sm",
  description="UPWARDS HARPOON WITH BARB RIGHT FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x295C,
 },
 [0x295D]={
  category="sm",
  description="DOWNWARDS HARPOON WITH BARB RIGHT FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x295D,
 },
 [0x295E]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB DOWN FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x295E,
 },
 [0x295F]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB DOWN FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x295F,
 },
 [0x2960]={
  category="sm",
  description="UPWARDS HARPOON WITH BARB LEFT FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2960,
 },
 [0x2961]={
  category="sm",
  description="DOWNWARDS HARPOON WITH BARB LEFT FROM BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2961,
 },
 [0x2962]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2962,
 },
 [0x2963]={
  category="sm",
  description="UPWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2963,
 },
 [0x2964]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2964,
 },
 [0x2965]={
  category="sm",
  description="DOWNWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2965,
 },
 [0x2966]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x2966,
 },
 [0x2967]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB DOWN ABOVE RIGHTWARDS HARPOON WITH BARB DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2967,
 },
 [0x2968]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x2968,
 },
 [0x2969]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB DOWN ABOVE LEFTWARDS HARPOON WITH BARB DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2969,
 },
 [0x296A]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB UP ABOVE LONG DASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x296A,
 },
 [0x296B]={
  category="sm",
  description="LEFTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x296B,
 },
 [0x296C]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB UP ABOVE LONG DASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x296C,
 },
 [0x296D]={
  category="sm",
  description="RIGHTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x296D,
 },
 [0x296E]={
  category="sm",
  description="UPWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x296E,
 },
 [0x296F]={
  category="sm",
  description="DOWNWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x296F,
 },
 [0x2970]={
  category="sm",
  description="RIGHT DOUBLE ARROW WITH ROUNDED HEAD",
  direction="on",
  linebreak="al",
  mathextensible="r",
  unicodeslot=0x2970,
 },
 [0x2971]={
  category="sm",
  description="EQUALS SIGN ABOVE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2971,
 },
 [0x2972]={
  category="sm",
  description="TILDE OPERATOR ABOVE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2972,
 },
 [0x2973]={
  category="sm",
  description="LEFTWARDS ARROW ABOVE TILDE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2973,
 },
 [0x2974]={
  category="sm",
  description="RIGHTWARDS ARROW ABOVE TILDE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2974,
 },
 [0x2975]={
  category="sm",
  description="RIGHTWARDS ARROW ABOVE ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2975,
 },
 [0x2976]={
  category="sm",
  description="LESS-THAN ABOVE LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2976,
 },
 [0x2977]={
  category="sm",
  description="LEFTWARDS ARROW THROUGH LESS-THAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2977,
 },
 [0x2978]={
  category="sm",
  description="GREATER-THAN ABOVE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2978,
 },
 [0x2979]={
  category="sm",
  description="SUBSET ABOVE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2979,
 },
 [0x297A]={
  category="sm",
  description="LEFTWARDS ARROW THROUGH SUBSET",
  direction="on",
  linebreak="al",
  unicodeslot=0x297A,
 },
 [0x297B]={
  category="sm",
  description="SUPERSET ABOVE LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x297B,
 },
 [0x297C]={
  category="sm",
  description="LEFT FISH TAIL",
  direction="on",
  linebreak="al",
  unicodeslot=0x297C,
 },
 [0x297D]={
  category="sm",
  description="RIGHT FISH TAIL",
  direction="on",
  linebreak="al",
  unicodeslot=0x297D,
 },
 [0x297E]={
  category="sm",
  description="UP FISH TAIL",
  direction="on",
  linebreak="al",
  unicodeslot=0x297E,
 },
 [0x297F]={
  category="sm",
  description="DOWN FISH TAIL",
  direction="on",
  linebreak="al",
  unicodeslot=0x297F,
 },
 [0x2980]={
  category="sm",
  description="TRIPLE VERTICAL BAR DELIMITER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2980,
 },
 [0x2981]={
  category="sm",
  description="Z NOTATION SPOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2981,
 },
 [0x2982]={
  category="sm",
  description="Z NOTATION TYPE COLON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2982,
 },
 [0x2983]={
  category="ps",
  description="LEFT WHITE CURLY BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x2984,
  unicodeslot=0x2983,
 },
 [0x2984]={
  category="pe",
  description="RIGHT WHITE CURLY BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2983,
  unicodeslot=0x2984,
 },
 [0x2985]={
  category="ps",
  cjkwd="na",
  description="LEFT WHITE PARENTHESIS",
  direction="on",
  linebreak="op",
  mirror=0x2986,
  unicodeslot=0x2985,
 },
 [0x2986]={
  category="pe",
  cjkwd="na",
  description="RIGHT WHITE PARENTHESIS",
  direction="on",
  linebreak="cl",
  mirror=0x2985,
  unicodeslot=0x2986,
 },
 [0x2987]={
  category="ps",
  description="Z NOTATION LEFT IMAGE BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x2988,
  unicodeslot=0x2987,
 },
 [0x2988]={
  category="pe",
  description="Z NOTATION RIGHT IMAGE BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2987,
  unicodeslot=0x2988,
 },
 [0x2989]={
  category="ps",
  description="Z NOTATION LEFT BINDING BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x298A,
  unicodeslot=0x2989,
 },
 [0x298A]={
  category="pe",
  description="Z NOTATION RIGHT BINDING BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2989,
  unicodeslot=0x298A,
 },
 [0x298B]={
  category="ps",
  description="LEFT SQUARE BRACKET WITH UNDERBAR",
  direction="on",
  linebreak="op",
  mirror=0x298C,
  unicodeslot=0x298B,
 },
 [0x298C]={
  category="pe",
  description="RIGHT SQUARE BRACKET WITH UNDERBAR",
  direction="on",
  linebreak="cl",
  mirror=0x298B,
  unicodeslot=0x298C,
 },
 [0x298D]={
  category="ps",
  description="LEFT SQUARE BRACKET WITH TICK IN TOP CORNER",
  direction="on",
  linebreak="op",
  mirror=0x2990,
  unicodeslot=0x298D,
 },
 [0x298E]={
  category="pe",
  description="RIGHT SQUARE BRACKET WITH TICK IN BOTTOM CORNER",
  direction="on",
  linebreak="cl",
  mirror=0x298F,
  unicodeslot=0x298E,
 },
 [0x298F]={
  category="ps",
  description="LEFT SQUARE BRACKET WITH TICK IN BOTTOM CORNER",
  direction="on",
  linebreak="op",
  mirror=0x298E,
  unicodeslot=0x298F,
 },
 [0x2990]={
  category="pe",
  description="RIGHT SQUARE BRACKET WITH TICK IN TOP CORNER",
  direction="on",
  linebreak="cl",
  mirror=0x298D,
  unicodeslot=0x2990,
 },
 [0x2991]={
  category="ps",
  description="LEFT ANGLE BRACKET WITH DOT",
  direction="on",
  linebreak="op",
  mirror=0x2992,
  unicodeslot=0x2991,
 },
 [0x2992]={
  category="pe",
  description="RIGHT ANGLE BRACKET WITH DOT",
  direction="on",
  linebreak="cl",
  mirror=0x2991,
  unicodeslot=0x2992,
 },
 [0x2993]={
  category="ps",
  description="LEFT ARC LESS-THAN BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x2994,
  unicodeslot=0x2993,
 },
 [0x2994]={
  category="pe",
  description="RIGHT ARC GREATER-THAN BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2993,
  unicodeslot=0x2994,
 },
 [0x2995]={
  category="ps",
  description="DOUBLE LEFT ARC GREATER-THAN BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x2996,
  unicodeslot=0x2995,
 },
 [0x2996]={
  category="pe",
  description="DOUBLE RIGHT ARC LESS-THAN BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2995,
  unicodeslot=0x2996,
 },
 [0x2997]={
  category="ps",
  description="LEFT BLACK TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x2998,
  unicodeslot=0x2997,
 },
 [0x2998]={
  category="pe",
  description="RIGHT BLACK TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2997,
  unicodeslot=0x2998,
 },
 [0x2999]={
  category="sm",
  description="DOTTED FENCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2999,
 },
 [0x299A]={
  category="sm",
  description="VERTICAL ZIGZAG LINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x299A,
 },
 [0x299B]={
  category="sm",
  description="MEASURED ANGLE OPENING LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x299B,
 },
 [0x299C]={
  category="sm",
  description="RIGHT ANGLE VARIANT WITH SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x299C,
 },
 [0x299D]={
  category="sm",
  description="MEASURED RIGHT ANGLE WITH DOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x299D,
 },
 [0x299E]={
  category="sm",
  description="ANGLE WITH S INSIDE",
  direction="on",
  linebreak="al",
  unicodeslot=0x299E,
 },
 [0x299F]={
  category="sm",
  description="ACUTE ANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x299F,
 },
 [0x29A0]={
  category="sm",
  description="SPHERICAL ANGLE OPENING LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A0,
 },
 [0x29A1]={
  category="sm",
  description="SPHERICAL ANGLE OPENING UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A1,
 },
 [0x29A2]={
  category="sm",
  description="TURNED ANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A2,
 },
 [0x29A3]={
  category="sm",
  description="REVERSED ANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A3,
 },
 [0x29A4]={
  category="sm",
  description="ANGLE WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A4,
 },
 [0x29A5]={
  category="sm",
  description="REVERSED ANGLE WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A5,
 },
 [0x29A6]={
  category="sm",
  description="OBLIQUE ANGLE OPENING UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A6,
 },
 [0x29A7]={
  category="sm",
  description="OBLIQUE ANGLE OPENING DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A7,
 },
 [0x29A8]={
  category="sm",
  description="MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A8,
 },
 [0x29A9]={
  category="sm",
  description="MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x29A9,
 },
 [0x29AA]={
  category="sm",
  description="MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x29AA,
 },
 [0x29AB]={
  category="sm",
  description="MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND LEFT",
  direction="on",
  linebreak="al",
  unicodeslot=0x29AB,
 },
 [0x29AC]={
  category="sm",
  description="MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x29AC,
 },
 [0x29AD]={
  category="sm",
  description="MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND UP",
  direction="on",
  linebreak="al",
  unicodeslot=0x29AD,
 },
 [0x29AE]={
  category="sm",
  description="MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x29AE,
 },
 [0x29AF]={
  category="sm",
  description="MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND DOWN",
  direction="on",
  linebreak="al",
  unicodeslot=0x29AF,
 },
 [0x29B0]={
  category="sm",
  description="REVERSED EMPTY SET",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B0,
 },
 [0x29B1]={
  category="sm",
  description="EMPTY SET WITH OVERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B1,
 },
 [0x29B2]={
  category="sm",
  description="EMPTY SET WITH SMALL CIRCLE ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B2,
 },
 [0x29B3]={
  category="sm",
  description="EMPTY SET WITH RIGHT ARROW ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B3,
 },
 [0x29B4]={
  category="sm",
  description="EMPTY SET WITH LEFT ARROW ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B4,
 },
 [0x29B5]={
  category="sm",
  description="CIRCLE WITH HORIZONTAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B5,
 },
 [0x29B6]={
  category="sm",
  description="CIRCLED VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B6,
 },
 [0x29B7]={
  category="sm",
  description="CIRCLED PARALLEL",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B7,
 },
 [0x29B8]={
  category="sm",
  description="CIRCLED REVERSE SOLIDUS",
  direction="on",
  linebreak="al",
  mirror=0x2298,
  unicodeslot=0x29B8,
 },
 [0x29B9]={
  category="sm",
  description="CIRCLED PERPENDICULAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29B9,
 },
 [0x29BA]={
  category="sm",
  description="CIRCLE DIVIDED BY HORIZONTAL BAR AND TOP HALF DIVIDED BY VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29BA,
 },
 [0x29BB]={
  category="sm",
  description="CIRCLE WITH SUPERIMPOSED X",
  direction="on",
  linebreak="al",
  unicodeslot=0x29BB,
 },
 [0x29BC]={
  category="sm",
  description="CIRCLED ANTICLOCKWISE-ROTATED DIVISION SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x29BC,
 },
 [0x29BD]={
  category="sm",
  description="UP ARROW THROUGH CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29BD,
 },
 [0x29BE]={
  category="sm",
  description="CIRCLED WHITE BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x29BE,
 },
 [0x29BF]={
  category="sm",
  description="CIRCLED BULLET",
  direction="on",
  linebreak="al",
  unicodeslot=0x29BF,
 },
 [0x29C0]={
  category="sm",
  description="CIRCLED LESS-THAN",
  direction="on",
  linebreak="al",
  mirror=0x29C1,
  unicodeslot=0x29C0,
 },
 [0x29C1]={
  category="sm",
  description="CIRCLED GREATER-THAN",
  direction="on",
  linebreak="al",
  mirror=0x29C0,
  unicodeslot=0x29C1,
 },
 [0x29C2]={
  category="sm",
  description="CIRCLE WITH SMALL CIRCLE TO THE RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x29C2,
 },
 [0x29C3]={
  category="sm",
  description="CIRCLE WITH TWO HORIZONTAL STROKES TO THE RIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x29C3,
 },
 [0x29C4]={
  category="sm",
  description="SQUARED RISING DIAGONAL SLASH",
  direction="on",
  linebreak="al",
  mirror=0x29C5,
  unicodeslot=0x29C4,
 },
 [0x29C5]={
  category="sm",
  description="SQUARED FALLING DIAGONAL SLASH",
  direction="on",
  linebreak="al",
  mirror=0x29C4,
  unicodeslot=0x29C5,
 },
 [0x29C6]={
  category="sm",
  description="SQUARED ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x29C6,
 },
 [0x29C7]={
  category="sm",
  description="SQUARED SMALL CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29C7,
 },
 [0x29C8]={
  category="sm",
  description="SQUARED SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29C8,
 },
 [0x29C9]={
  category="sm",
  description="TWO JOINED SQUARES",
  direction="on",
  linebreak="al",
  unicodeslot=0x29C9,
 },
 [0x29CA]={
  category="sm",
  description="TRIANGLE WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29CA,
 },
 [0x29CB]={
  category="sm",
  description="TRIANGLE WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29CB,
 },
 [0x29CC]={
  category="sm",
  description="S IN TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29CC,
 },
 [0x29CD]={
  category="sm",
  description="TRIANGLE WITH SERIFS AT BOTTOM",
  direction="on",
  linebreak="al",
  unicodeslot=0x29CD,
 },
 [0x29CE]={
  category="sm",
  description="RIGHT TRIANGLE ABOVE LEFT TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29CE,
 },
 [0x29CF]={
  category="sm",
  description="LEFT TRIANGLE BESIDE VERTICAL BAR",
  direction="on",
  linebreak="al",
  mirror=0x29D0,
  unicodeslot=0x29CF,
 },
 [0x29D0]={
  category="sm",
  description="VERTICAL BAR BESIDE RIGHT TRIANGLE",
  direction="on",
  linebreak="al",
  mirror=0x29CF,
  unicodeslot=0x29D0,
 },
 [0x29D1]={
  category="sm",
  description="BOWTIE WITH LEFT HALF BLACK",
  direction="on",
  linebreak="al",
  mirror=0x29D2,
  unicodeslot=0x29D1,
 },
 [0x29D2]={
  category="sm",
  description="BOWTIE WITH RIGHT HALF BLACK",
  direction="on",
  linebreak="al",
  mirror=0x29D1,
  unicodeslot=0x29D2,
 },
 [0x29D3]={
  category="sm",
  description="BLACK BOWTIE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29D3,
 },
 [0x29D4]={
  category="sm",
  description="TIMES WITH LEFT HALF BLACK",
  direction="on",
  linebreak="al",
  mirror=0x29D5,
  unicodeslot=0x29D4,
 },
 [0x29D5]={
  category="sm",
  description="TIMES WITH RIGHT HALF BLACK",
  direction="on",
  linebreak="al",
  mirror=0x29D4,
  unicodeslot=0x29D5,
 },
 [0x29D6]={
  category="sm",
  description="WHITE HOURGLASS",
  direction="on",
  linebreak="al",
  unicodeslot=0x29D6,
 },
 [0x29D7]={
  category="sm",
  description="BLACK HOURGLASS",
  direction="on",
  linebreak="al",
  unicodeslot=0x29D7,
 },
 [0x29D8]={
  category="ps",
  description="LEFT WIGGLY FENCE",
  direction="on",
  linebreak="op",
  mirror=0x29D9,
  unicodeslot=0x29D8,
 },
 [0x29D9]={
  category="pe",
  description="RIGHT WIGGLY FENCE",
  direction="on",
  linebreak="cl",
  mirror=0x29D8,
  unicodeslot=0x29D9,
 },
 [0x29DA]={
  category="ps",
  description="LEFT DOUBLE WIGGLY FENCE",
  direction="on",
  linebreak="op",
  mirror=0x29DB,
  unicodeslot=0x29DA,
 },
 [0x29DB]={
  category="pe",
  description="RIGHT DOUBLE WIGGLY FENCE",
  direction="on",
  linebreak="cl",
  mirror=0x29DA,
  unicodeslot=0x29DB,
 },
 [0x29DC]={
  category="sm",
  description="INCOMPLETE INFINITY",
  direction="on",
  linebreak="al",
  unicodeslot=0x29DC,
 },
 [0x29DD]={
  category="sm",
  description="TIE OVER INFINITY",
  direction="on",
  linebreak="al",
  unicodeslot=0x29DD,
 },
 [0x29DE]={
  category="sm",
  description="INFINITY NEGATED WITH VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29DE,
 },
 [0x29DF]={
  category="sm",
  description="DOUBLE-ENDED MULTIMAP",
  direction="on",
  linebreak="al",
  unicodeslot=0x29DF,
 },
 [0x29E0]={
  category="sm",
  description="SQUARE WITH CONTOURED OUTLINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E0,
 },
 [0x29E1]={
  category="sm",
  description="INCREASES AS",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E1,
 },
 [0x29E2]={
  category="sm",
  description="SHUFFLE PRODUCT",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E2,
 },
 [0x29E3]={
  category="sm",
  description="EQUALS SIGN AND SLANTED PARALLEL",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E3,
 },
 [0x29E4]={
  category="sm",
  description="EQUALS SIGN AND SLANTED PARALLEL WITH TILDE ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E4,
 },
 [0x29E5]={
  category="sm",
  description="IDENTICAL TO AND SLANTED PARALLEL",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E5,
 },
 [0x29E6]={
  category="sm",
  description="GLEICH STARK",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E6,
 },
 [0x29E7]={
  category="sm",
  description="THERMODYNAMIC",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E7,
 },
 [0x29E8]={
  category="sm",
  description="DOWN-POINTING TRIANGLE WITH LEFT HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E8,
 },
 [0x29E9]={
  category="sm",
  description="DOWN-POINTING TRIANGLE WITH RIGHT HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x29E9,
 },
 [0x29EA]={
  category="sm",
  description="BLACK DIAMOND WITH DOWN ARROW",
  direction="on",
  linebreak="al",
  mathextensible="d",
  unicodeslot=0x29EA,
 },
 [0x29EB]={
  category="sm",
  description="BLACK LOZENGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29EB,
 },
 [0x29EC]={
  category="sm",
  description="WHITE CIRCLE WITH DOWN ARROW",
  direction="on",
  linebreak="al",
  mathextensible="d",
  unicodeslot=0x29EC,
 },
 [0x29ED]={
  category="sm",
  description="BLACK CIRCLE WITH DOWN ARROW",
  direction="on",
  linebreak="al",
  mathextensible="d",
  unicodeslot=0x29ED,
 },
 [0x29EE]={
  category="sm",
  description="ERROR-BARRED WHITE SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29EE,
 },
 [0x29EF]={
  category="sm",
  description="ERROR-BARRED BLACK SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29EF,
 },
 [0x29F0]={
  category="sm",
  description="ERROR-BARRED WHITE DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x29F0,
 },
 [0x29F1]={
  category="sm",
  description="ERROR-BARRED BLACK DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x29F1,
 },
 [0x29F2]={
  category="sm",
  description="ERROR-BARRED WHITE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29F2,
 },
 [0x29F3]={
  category="sm",
  description="ERROR-BARRED BLACK CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29F3,
 },
 [0x29F4]={
  category="sm",
  description="RULE-DELAYED",
  direction="on",
  linebreak="al",
  unicodeslot=0x29F4,
 },
 [0x29F5]={
  category="sm",
  description="REVERSE SOLIDUS OPERATOR",
  direction="on",
  linebreak="al",
  mirror=0x2215,
  unicodeslot=0x29F5,
 },
 [0x29F6]={
  category="sm",
  description="SOLIDUS WITH OVERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x29F6,
 },
 [0x29F7]={
  category="sm",
  description="REVERSE SOLIDUS WITH HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x29F7,
 },
 [0x29F8]={
  category="sm",
  description="BIG SOLIDUS",
  direction="on",
  linebreak="al",
  mirror=0x29F9,
  unicodeslot=0x29F8,
 },
 [0x29F9]={
  category="sm",
  description="BIG REVERSE SOLIDUS",
  direction="on",
  linebreak="al",
  mirror=0x29F8,
  unicodeslot=0x29F9,
 },
 [0x29FA]={
  category="sm",
  description="DOUBLE PLUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x29FA,
 },
 [0x29FB]={
  category="sm",
  description="TRIPLE PLUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x29FB,
 },
 [0x29FC]={
  category="ps",
  description="LEFT-POINTING CURVED ANGLE BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x29FD,
  unicodeslot=0x29FC,
 },
 [0x29FD]={
  category="pe",
  description="RIGHT-POINTING CURVED ANGLE BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x29FC,
  unicodeslot=0x29FD,
 },
 [0x29FE]={
  category="sm",
  description="TINY",
  direction="on",
  linebreak="al",
  unicodeslot=0x29FE,
 },
 [0x29FF]={
  category="sm",
  description="MINY",
  direction="on",
  linebreak="al",
  unicodeslot=0x29FF,
 },
 [0x2A00]={
  category="sm",
  description="N-ARY CIRCLED DOT OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigodot",
  unicodeslot=0x2A00,
 },
 [0x2A01]={
  category="sm",
  description="N-ARY CIRCLED PLUS OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigoplus",
  unicodeslot=0x2A01,
 },
 [0x2A02]={
  category="sm",
  description="N-ARY CIRCLED TIMES OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigotimes",
  unicodeslot=0x2A02,
 },
 [0x2A03]={
  category="sm",
  description="N-ARY UNION OPERATOR WITH DOT",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigudot",
  unicodeslot=0x2A03,
 },
 [0x2A04]={
  category="sm",
  description="N-ARY UNION OPERATOR WITH PLUS",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="biguplus",
  unicodeslot=0x2A04,
 },
 [0x2A05]={
  category="sm",
  description="N-ARY SQUARE INTERSECTION OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigsqcap",
  unicodeslot=0x2A05,
 },
 [0x2A06]={
  category="sm",
  description="N-ARY SQUARE UNION OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigsqcup",
  unicodeslot=0x2A06,
 },
 [0x2A07]={
  category="sm",
  description="TWO LOGICAL AND OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A07,
 },
 [0x2A08]={
  category="sm",
  description="TWO LOGICAL OR OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A08,
 },
 [0x2A09]={
  category="sm",
  description="N-ARY TIMES OPERATOR",
  direction="on",
  linebreak="al",
  mathclass="limop",
  mathname="bigtimes",
  unicodeslot=0x2A09,
 },
 [0x2A0A]={
  category="sm",
  description="MODULO TWO SUM",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A0A,
 },
 [0x2A0B]={
  category="sm",
  description="SUMMATION WITH INTEGRAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A0B,
 },
 [0x2A0C]={
  category="sm",
  description="QUADRUPLE INTEGRAL OPERATOR",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x222B, 0x222B, 0x222B, 0x222B },
  unicodeslot=0x2A0C,
 },
 [0x2A0D]={
  category="sm",
  description="FINITE PART INTEGRAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A0D,
 },
 [0x2A0E]={
  category="sm",
  description="INTEGRAL WITH DOUBLE STROKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A0E,
 },
 [0x2A0F]={
  category="sm",
  description="INTEGRAL AVERAGE WITH SLASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A0F,
 },
 [0x2A10]={
  category="sm",
  description="CIRCULATION FUNCTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A10,
 },
 [0x2A11]={
  category="sm",
  description="ANTICLOCKWISE INTEGRATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A11,
 },
 [0x2A12]={
  category="sm",
  description="LINE INTEGRATION WITH RECTANGULAR PATH AROUND POLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A12,
 },
 [0x2A13]={
  category="sm",
  description="LINE INTEGRATION WITH SEMICIRCULAR PATH AROUND POLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A13,
 },
 [0x2A14]={
  category="sm",
  description="LINE INTEGRATION NOT INCLUDING THE POLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A14,
 },
 [0x2A15]={
  category="sm",
  description="INTEGRAL AROUND A POINT OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A15,
 },
 [0x2A16]={
  category="sm",
  description="QUATERNION INTEGRAL OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A16,
 },
 [0x2A17]={
  category="sm",
  description="INTEGRAL WITH LEFTWARDS ARROW WITH HOOK",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2A17,
 },
 [0x2A18]={
  category="sm",
  description="INTEGRAL WITH TIMES SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A18,
 },
 [0x2A19]={
  category="sm",
  description="INTEGRAL WITH INTERSECTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A19,
 },
 [0x2A1A]={
  category="sm",
  description="INTEGRAL WITH UNION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A1A,
 },
 [0x2A1B]={
  category="sm",
  description="INTEGRAL WITH OVERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A1B,
 },
 [0x2A1C]={
  category="sm",
  description="INTEGRAL WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A1C,
 },
 [0x2A1D]={
  category="sm",
  description="JOIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A1D,
 },
 [0x2A1E]={
  category="sm",
  description="LARGE LEFT TRIANGLE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A1E,
 },
 [0x2A1F]={
  category="sm",
  description="Z NOTATION SCHEMA COMPOSITION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A1F,
 },
 [0x2A20]={
  category="sm",
  description="Z NOTATION SCHEMA PIPING",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A20,
 },
 [0x2A21]={
  category="sm",
  description="Z NOTATION SCHEMA PROJECTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A21,
 },
 [0x2A22]={
  category="sm",
  description="PLUS SIGN WITH SMALL CIRCLE ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A22,
 },
 [0x2A23]={
  category="sm",
  description="PLUS SIGN WITH CIRCUMFLEX ACCENT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A23,
 },
 [0x2A24]={
  category="sm",
  description="PLUS SIGN WITH TILDE ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A24,
 },
 [0x2A25]={
  category="sm",
  description="PLUS SIGN WITH DOT BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A25,
 },
 [0x2A26]={
  category="sm",
  description="PLUS SIGN WITH TILDE BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A26,
 },
 [0x2A27]={
  category="sm",
  description="PLUS SIGN WITH SUBSCRIPT TWO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A27,
 },
 [0x2A28]={
  category="sm",
  description="PLUS SIGN WITH BLACK TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A28,
 },
 [0x2A29]={
  category="sm",
  description="MINUS SIGN WITH COMMA ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A29,
 },
 [0x2A2A]={
  category="sm",
  description="MINUS SIGN WITH DOT BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A2A,
 },
 [0x2A2B]={
  category="sm",
  description="MINUS SIGN WITH FALLING DOTS",
  direction="on",
  linebreak="al",
  mirror=0x2A2C,
  unicodeslot=0x2A2B,
 },
 [0x2A2C]={
  category="sm",
  description="MINUS SIGN WITH RISING DOTS",
  direction="on",
  linebreak="al",
  mirror=0x2A2B,
  unicodeslot=0x2A2C,
 },
 [0x2A2D]={
  category="sm",
  description="PLUS SIGN IN LEFT HALF CIRCLE",
  direction="on",
  linebreak="al",
  mirror=0x2A2E,
  unicodeslot=0x2A2D,
 },
 [0x2A2E]={
  category="sm",
  description="PLUS SIGN IN RIGHT HALF CIRCLE",
  direction="on",
  linebreak="al",
  mirror=0x2A2D,
  unicodeslot=0x2A2E,
 },
 [0x2A2F]={
  category="sm",
  description="VECTOR OR CROSS PRODUCT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A2F,
 },
 [0x2A30]={
  category="sm",
  description="MULTIPLICATION SIGN WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A30,
 },
 [0x2A31]={
  category="sm",
  description="MULTIPLICATION SIGN WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A31,
 },
 [0x2A32]={
  category="sm",
  description="SEMIDIRECT PRODUCT WITH BOTTOM CLOSED",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A32,
 },
 [0x2A33]={
  category="sm",
  description="SMASH PRODUCT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A33,
 },
 [0x2A34]={
  category="sm",
  description="MULTIPLICATION SIGN IN LEFT HALF CIRCLE",
  direction="on",
  linebreak="al",
  mirror=0x2A35,
  unicodeslot=0x2A34,
 },
 [0x2A35]={
  category="sm",
  description="MULTIPLICATION SIGN IN RIGHT HALF CIRCLE",
  direction="on",
  linebreak="al",
  mirror=0x2A34,
  unicodeslot=0x2A35,
 },
 [0x2A36]={
  category="sm",
  description="CIRCLED MULTIPLICATION SIGN WITH CIRCUMFLEX ACCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A36,
 },
 [0x2A37]={
  category="sm",
  description="MULTIPLICATION SIGN IN DOUBLE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A37,
 },
 [0x2A38]={
  category="sm",
  description="CIRCLED DIVISION SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A38,
 },
 [0x2A39]={
  category="sm",
  description="PLUS SIGN IN TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A39,
 },
 [0x2A3A]={
  category="sm",
  description="MINUS SIGN IN TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A3A,
 },
 [0x2A3B]={
  category="sm",
  description="MULTIPLICATION SIGN IN TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A3B,
 },
 [0x2A3C]={
  category="sm",
  description="INTERIOR PRODUCT",
  direction="on",
  linebreak="al",
  mirror=0x2A3D,
  unicodeslot=0x2A3C,
  variants={
   [0xFE00]="tall variant with narrow foot",
  },
 },
 [0x2A3D]={
  category="sm",
  description="RIGHTHAND INTERIOR PRODUCT",
  direction="on",
  linebreak="al",
  mirror=0x2A3C,
  unicodeslot=0x2A3D,
  variants={
   [0xFE00]="tall variant with narrow foot",
  },
 },
 [0x2A3E]={
  category="sm",
  description="Z NOTATION RELATIONAL COMPOSITION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A3E,
 },
 [0x2A3F]={
  category="sm",
  description="AMALGAMATION OR COPRODUCT",
  direction="on",
  linebreak="al",
  mathclass="binary",
  mathname="amalg",
  unicodeslot=0x2A3F,
 },
 [0x2A40]={
  category="sm",
  description="INTERSECTION WITH DOT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A40,
 },
 [0x2A41]={
  category="sm",
  description="UNION WITH MINUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A41,
 },
 [0x2A42]={
  category="sm",
  description="UNION WITH OVERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A42,
 },
 [0x2A43]={
  category="sm",
  description="INTERSECTION WITH OVERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A43,
 },
 [0x2A44]={
  category="sm",
  description="INTERSECTION WITH LOGICAL AND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A44,
 },
 [0x2A45]={
  category="sm",
  description="UNION WITH LOGICAL OR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A45,
 },
 [0x2A46]={
  category="sm",
  description="UNION ABOVE INTERSECTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A46,
 },
 [0x2A47]={
  category="sm",
  description="INTERSECTION ABOVE UNION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A47,
 },
 [0x2A48]={
  category="sm",
  description="UNION ABOVE BAR ABOVE INTERSECTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A48,
 },
 [0x2A49]={
  category="sm",
  description="INTERSECTION ABOVE BAR ABOVE UNION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A49,
 },
 [0x2A4A]={
  category="sm",
  description="UNION BESIDE AND JOINED WITH UNION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A4A,
 },
 [0x2A4B]={
  category="sm",
  description="INTERSECTION BESIDE AND JOINED WITH INTERSECTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A4B,
 },
 [0x2A4C]={
  category="sm",
  description="CLOSED UNION WITH SERIFS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A4C,
 },
 [0x2A4D]={
  category="sm",
  description="CLOSED INTERSECTION WITH SERIFS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A4D,
 },
 [0x2A4E]={
  category="sm",
  description="DOUBLE SQUARE INTERSECTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A4E,
 },
 [0x2A4F]={
  category="sm",
  description="DOUBLE SQUARE UNION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A4F,
 },
 [0x2A50]={
  category="sm",
  description="CLOSED UNION WITH SERIFS AND SMASH PRODUCT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A50,
 },
 [0x2A51]={
  category="sm",
  description="LOGICAL AND WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A51,
 },
 [0x2A52]={
  category="sm",
  description="LOGICAL OR WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A52,
 },
 [0x2A53]={
  category="sm",
  description="DOUBLE LOGICAL AND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A53,
 },
 [0x2A54]={
  category="sm",
  description="DOUBLE LOGICAL OR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A54,
 },
 [0x2A55]={
  category="sm",
  description="TWO INTERSECTING LOGICAL AND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A55,
 },
 [0x2A56]={
  category="sm",
  description="TWO INTERSECTING LOGICAL OR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A56,
 },
 [0x2A57]={
  category="sm",
  description="SLOPING LARGE OR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A57,
 },
 [0x2A58]={
  category="sm",
  description="SLOPING LARGE AND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A58,
 },
 [0x2A59]={
  category="sm",
  description="LOGICAL OR OVERLAPPING LOGICAL AND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A59,
 },
 [0x2A5A]={
  category="sm",
  description="LOGICAL AND WITH MIDDLE STEM",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A5A,
 },
 [0x2A5B]={
  category="sm",
  description="LOGICAL OR WITH MIDDLE STEM",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A5B,
 },
 [0x2A5C]={
  category="sm",
  description="LOGICAL AND WITH HORIZONTAL DASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A5C,
 },
 [0x2A5D]={
  category="sm",
  description="LOGICAL OR WITH HORIZONTAL DASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A5D,
 },
 [0x2A5E]={
  category="sm",
  description="LOGICAL AND WITH DOUBLE OVERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A5E,
 },
 [0x2A5F]={
  category="sm",
  description="LOGICAL AND WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A5F,
 },
 [0x2A60]={
  category="sm",
  description="LOGICAL AND WITH DOUBLE UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A60,
 },
 [0x2A61]={
  category="sm",
  description="SMALL VEE WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A61,
 },
 [0x2A62]={
  category="sm",
  description="LOGICAL OR WITH DOUBLE OVERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A62,
 },
 [0x2A63]={
  category="sm",
  description="LOGICAL OR WITH DOUBLE UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A63,
 },
 [0x2A64]={
  category="sm",
  description="Z NOTATION DOMAIN ANTIRESTRICTION",
  direction="on",
  linebreak="al",
  mirror=0x2A65,
  unicodeslot=0x2A64,
 },
 [0x2A65]={
  category="sm",
  description="Z NOTATION RANGE ANTIRESTRICTION",
  direction="on",
  linebreak="al",
  mirror=0x2A64,
  unicodeslot=0x2A65,
 },
 [0x2A66]={
  category="sm",
  description="EQUALS SIGN WITH DOT BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A66,
 },
 [0x2A67]={
  category="sm",
  description="IDENTICAL WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A67,
 },
 [0x2A68]={
  category="sm",
  description="TRIPLE HORIZONTAL BAR WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A68,
 },
 [0x2A69]={
  category="sm",
  description="TRIPLE HORIZONTAL BAR WITH TRIPLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A69,
 },
 [0x2A6A]={
  category="sm",
  description="TILDE OPERATOR WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A6A,
 },
 [0x2A6B]={
  category="sm",
  description="TILDE OPERATOR WITH RISING DOTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A6B,
 },
 [0x2A6C]={
  category="sm",
  description="SIMILAR MINUS SIMILAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A6C,
 },
 [0x2A6D]={
  category="sm",
  description="CONGRUENT WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A6D,
 },
 [0x2A6E]={
  category="sm",
  description="EQUALS WITH ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A6E,
 },
 [0x2A6F]={
  category="sm",
  description="ALMOST EQUAL TO WITH CIRCUMFLEX ACCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A6F,
 },
 [0x2A70]={
  category="sm",
  description="APPROXIMATELY EQUAL OR EQUAL TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A70,
 },
 [0x2A71]={
  category="sm",
  description="EQUALS SIGN ABOVE PLUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A71,
 },
 [0x2A72]={
  category="sm",
  description="PLUS SIGN ABOVE EQUALS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A72,
 },
 [0x2A73]={
  category="sm",
  description="EQUALS SIGN ABOVE TILDE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A73,
 },
 [0x2A74]={
  category="sm",
  description="DOUBLE COLON EQUAL",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="coloncolonequals",
  specials={ "compat", 0x003A, 0x003A, 0x003D },
  unicodeslot=0x2A74,
 },
 [0x2A75]={
  category="sm",
  description="TWO CONSECUTIVE EQUALS SIGNS",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x003D, 0x003D },
  unicodeslot=0x2A75,
 },
 [0x2A76]={
  category="sm",
  description="THREE CONSECUTIVE EQUALS SIGNS",
  direction="on",
  linebreak="al",
  specials={ "compat", 0x003D, 0x003D, 0x003D },
  unicodeslot=0x2A76,
 },
 [0x2A77]={
  category="sm",
  description="EQUALS SIGN WITH TWO DOTS ABOVE AND TWO DOTS BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A77,
 },
 [0x2A78]={
  category="sm",
  description="EQUIVALENT WITH FOUR DOTS ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A78,
 },
 [0x2A79]={
  category="sm",
  description="LESS-THAN WITH CIRCLE INSIDE",
  direction="on",
  linebreak="al",
  mirror=0x2A7A,
  unicodeslot=0x2A79,
 },
 [0x2A7A]={
  category="sm",
  description="GREATER-THAN WITH CIRCLE INSIDE",
  direction="on",
  linebreak="al",
  mirror=0x2A79,
  unicodeslot=0x2A7A,
 },
 [0x2A7B]={
  category="sm",
  description="LESS-THAN WITH QUESTION MARK ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A7B,
 },
 [0x2A7C]={
  category="sm",
  description="GREATER-THAN WITH QUESTION MARK ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A7C,
 },
 [0x2A7D]={
  category="sm",
  description="LESS-THAN OR SLANTED EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="leqslant",
  mirror=0x2A7E,
  unicodeslot=0x2A7D,
 },
 [0x2A7E]={
  category="sm",
  description="GREATER-THAN OR SLANTED EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="geqslant",
  mirror=0x2A7D,
  unicodeslot=0x2A7E,
 },
 [0x2A7F]={
  category="sm",
  description="LESS-THAN OR SLANTED EQUAL TO WITH DOT INSIDE",
  direction="on",
  linebreak="al",
  mirror=0x2A80,
  unicodeslot=0x2A7F,
 },
 [0x2A80]={
  category="sm",
  description="GREATER-THAN OR SLANTED EQUAL TO WITH DOT INSIDE",
  direction="on",
  linebreak="al",
  mirror=0x2A7F,
  unicodeslot=0x2A80,
 },
 [0x2A81]={
  category="sm",
  description="LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  mirror=0x2A82,
  unicodeslot=0x2A81,
 },
 [0x2A82]={
  category="sm",
  description="GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  mirror=0x2A81,
  unicodeslot=0x2A82,
 },
 [0x2A83]={
  category="sm",
  description="LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE RIGHT",
  direction="on",
  linebreak="al",
  mirror=0x2A84,
  unicodeslot=0x2A83,
 },
 [0x2A84]={
  category="sm",
  description="GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE LEFT",
  direction="on",
  linebreak="al",
  mirror=0x2A83,
  unicodeslot=0x2A84,
 },
 [0x2A85]={
  category="sm",
  description="LESS-THAN OR APPROXIMATE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lessapprox",
  unicodeslot=0x2A85,
 },
 [0x2A86]={
  category="sm",
  description="GREATER-THAN OR APPROXIMATE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gtrapprox",
  unicodeslot=0x2A86,
 },
 [0x2A87]={
  category="sm",
  description="LESS-THAN AND SINGLE-LINE NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lneq",
  unicodeslot=0x2A87,
 },
 [0x2A88]={
  category="sm",
  description="GREATER-THAN AND SINGLE-LINE NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="rneq",
  unicodeslot=0x2A88,
 },
 [0x2A89]={
  category="sm",
  description="LESS-THAN AND NOT APPROXIMATE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lnapprox",
  unicodeslot=0x2A89,
 },
 [0x2A8A]={
  category="sm",
  description="GREATER-THAN AND NOT APPROXIMATE",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gnapprox",
  unicodeslot=0x2A8A,
 },
 [0x2A8B]={
  category="sm",
  description="LESS-THAN ABOVE DOUBLE-LINE EQUAL ABOVE GREATER-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="lesseqqgtr",
  mirror=0x2A8C,
  unicodeslot=0x2A8B,
 },
 [0x2A8C]={
  category="sm",
  description="GREATER-THAN ABOVE DOUBLE-LINE EQUAL ABOVE LESS-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="gtreqqless",
  mirror=0x2A8B,
  unicodeslot=0x2A8C,
 },
 [0x2A8D]={
  category="sm",
  description="LESS-THAN ABOVE SIMILAR OR EQUAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A8D,
 },
 [0x2A8E]={
  category="sm",
  description="GREATER-THAN ABOVE SIMILAR OR EQUAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A8E,
 },
 [0x2A8F]={
  category="sm",
  description="LESS-THAN ABOVE SIMILAR ABOVE GREATER-THAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A8F,
 },
 [0x2A90]={
  category="sm",
  description="GREATER-THAN ABOVE SIMILAR ABOVE LESS-THAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A90,
 },
 [0x2A91]={
  category="sm",
  description="LESS-THAN ABOVE GREATER-THAN ABOVE DOUBLE-LINE EQUAL",
  direction="on",
  linebreak="al",
  mirror=0x2A92,
  unicodeslot=0x2A91,
 },
 [0x2A92]={
  category="sm",
  description="GREATER-THAN ABOVE LESS-THAN ABOVE DOUBLE-LINE EQUAL",
  direction="on",
  linebreak="al",
  mirror=0x2A91,
  unicodeslot=0x2A92,
 },
 [0x2A93]={
  category="sm",
  description="LESS-THAN ABOVE SLANTED EQUAL ABOVE GREATER-THAN ABOVE SLANTED EQUAL",
  direction="on",
  linebreak="al",
  mirror=0x2A94,
  unicodeslot=0x2A93,
 },
 [0x2A94]={
  category="sm",
  description="GREATER-THAN ABOVE SLANTED EQUAL ABOVE LESS-THAN ABOVE SLANTED EQUAL",
  direction="on",
  linebreak="al",
  mirror=0x2A93,
  unicodeslot=0x2A94,
 },
 [0x2A95]={
  category="sm",
  description="SLANTED EQUAL TO OR LESS-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="eqslantless",
  mirror=0x2A96,
  unicodeslot=0x2A95,
 },
 [0x2A96]={
  category="sm",
  description="SLANTED EQUAL TO OR GREATER-THAN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="eqslantgtr",
  mirror=0x2A95,
  unicodeslot=0x2A96,
 },
 [0x2A97]={
  category="sm",
  description="SLANTED EQUAL TO OR LESS-THAN WITH DOT INSIDE",
  direction="on",
  linebreak="al",
  mirror=0x2A98,
  unicodeslot=0x2A97,
 },
 [0x2A98]={
  category="sm",
  description="SLANTED EQUAL TO OR GREATER-THAN WITH DOT INSIDE",
  direction="on",
  linebreak="al",
  mirror=0x2A97,
  unicodeslot=0x2A98,
 },
 [0x2A99]={
  category="sm",
  description="DOUBLE-LINE EQUAL TO OR LESS-THAN",
  direction="on",
  linebreak="al",
  mirror=0x2A9A,
  unicodeslot=0x2A99,
 },
 [0x2A9A]={
  category="sm",
  description="DOUBLE-LINE EQUAL TO OR GREATER-THAN",
  direction="on",
  linebreak="al",
  mirror=0x2A99,
  unicodeslot=0x2A9A,
 },
 [0x2A9B]={
  category="sm",
  description="DOUBLE-LINE SLANTED EQUAL TO OR LESS-THAN",
  direction="on",
  linebreak="al",
  mirror=0x2A9C,
  unicodeslot=0x2A9B,
 },
 [0x2A9C]={
  category="sm",
  description="DOUBLE-LINE SLANTED EQUAL TO OR GREATER-THAN",
  direction="on",
  linebreak="al",
  mirror=0x2A9B,
  unicodeslot=0x2A9C,
 },
 [0x2A9D]={
  category="sm",
  description="SIMILAR OR LESS-THAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A9D,
  variants={
   [0xFE00]="with similar following the slant of the upper leg",
  },
 },
 [0x2A9E]={
  category="sm",
  description="SIMILAR OR GREATER-THAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A9E,
  variants={
   [0xFE00]="with similar following the slant of the upper leg",
  },
 },
 [0x2A9F]={
  category="sm",
  description="SIMILAR ABOVE LESS-THAN ABOVE EQUALS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2A9F,
 },
 [0x2AA0]={
  category="sm",
  description="SIMILAR ABOVE GREATER-THAN ABOVE EQUALS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AA0,
 },
 [0x2AA1]={
  category="sm",
  description="DOUBLE NESTED LESS-THAN",
  direction="on",
  linebreak="al",
  mirror=0x2AA2,
  unicodeslot=0x2AA1,
 },
 [0x2AA2]={
  category="sm",
  description="DOUBLE NESTED GREATER-THAN",
  direction="on",
  linebreak="al",
  mirror=0x2AA1,
  unicodeslot=0x2AA2,
 },
 [0x2AA3]={
  category="sm",
  description="DOUBLE NESTED LESS-THAN WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AA3,
 },
 [0x2AA4]={
  category="sm",
  description="GREATER-THAN OVERLAPPING LESS-THAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AA4,
 },
 [0x2AA5]={
  category="sm",
  description="GREATER-THAN BESIDE LESS-THAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AA5,
 },
 [0x2AA6]={
  category="sm",
  description="LESS-THAN CLOSED BY CURVE",
  direction="on",
  linebreak="al",
  mirror=0x2AA7,
  unicodeslot=0x2AA6,
 },
 [0x2AA7]={
  category="sm",
  description="GREATER-THAN CLOSED BY CURVE",
  direction="on",
  linebreak="al",
  mirror=0x2AA6,
  unicodeslot=0x2AA7,
 },
 [0x2AA8]={
  category="sm",
  description="LESS-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL",
  direction="on",
  linebreak="al",
  mirror=0x2AA9,
  unicodeslot=0x2AA8,
 },
 [0x2AA9]={
  category="sm",
  description="GREATER-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL",
  direction="on",
  linebreak="al",
  mirror=0x2AA8,
  unicodeslot=0x2AA9,
 },
 [0x2AAA]={
  category="sm",
  description="SMALLER THAN",
  direction="on",
  linebreak="al",
  mirror=0x2AAB,
  unicodeslot=0x2AAA,
 },
 [0x2AAB]={
  category="sm",
  description="LARGER THAN",
  direction="on",
  linebreak="al",
  mirror=0x2AAA,
  unicodeslot=0x2AAB,
 },
 [0x2AAC]={
  category="sm",
  description="SMALLER THAN OR EQUAL TO",
  direction="on",
  linebreak="al",
  mirror=0x2AAD,
  unicodeslot=0x2AAC,
  variants={
   [0xFE00]="with slanted equal",
  },
 },
 [0x2AAD]={
  category="sm",
  description="LARGER THAN OR EQUAL TO",
  direction="on",
  linebreak="al",
  mirror=0x2AAC,
  unicodeslot=0x2AAD,
  variants={
   [0xFE00]="with slanted equal",
  },
 },
 [0x2AAE]={
  category="sm",
  description="EQUALS SIGN WITH BUMPY ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AAE,
 },
 [0x2AAF]={
  category="sm",
  description="PRECEDES ABOVE SINGLE-LINE EQUALS SIGN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="preceq",
  mirror=0x2AB0,
  unicodeslot=0x2AAF,
 },
 [0x2AB0]={
  category="sm",
  description="SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succeq",
  mirror=0x2AAF,
  unicodeslot=0x2AB0,
 },
 [0x2AB1]={
  category="sm",
  description="PRECEDES ABOVE SINGLE-LINE NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="precneq",
  unicodeslot=0x2AB1,
 },
 [0x2AB2]={
  category="sm",
  description="SUCCEEDS ABOVE SINGLE-LINE NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succneq",
  unicodeslot=0x2AB2,
 },
 [0x2AB3]={
  category="sm",
  description="PRECEDES ABOVE EQUALS SIGN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="preceqq",
  mirror=0x2AB4,
  unicodeslot=0x2AB3,
 },
 [0x2AB4]={
  category="sm",
  description="SUCCEEDS ABOVE EQUALS SIGN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succeqq",
  mirror=0x2AB3,
  unicodeslot=0x2AB4,
 },
 [0x2AB5]={
  category="sm",
  description="PRECEDES ABOVE NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="precneqq",
  unicodeslot=0x2AB5,
 },
 [0x2AB6]={
  category="sm",
  description="SUCCEEDS ABOVE NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succneqq",
  unicodeslot=0x2AB6,
 },
 [0x2AB7]={
  category="sm",
  description="PRECEDES ABOVE ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="precapprox",
  unicodeslot=0x2AB7,
 },
 [0x2AB8]={
  category="sm",
  description="SUCCEEDS ABOVE ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succapprox",
  unicodeslot=0x2AB8,
 },
 [0x2AB9]={
  category="sm",
  description="PRECEDES ABOVE NOT ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="precnapprox",
  unicodeslot=0x2AB9,
 },
 [0x2ABA]={
  category="sm",
  description="SUCCEEDS ABOVE NOT ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="succnapprox",
  unicodeslot=0x2ABA,
 },
 [0x2ABB]={
  category="sm",
  description="DOUBLE PRECEDES",
  direction="on",
  linebreak="al",
  mirror=0x2ABC,
  unicodeslot=0x2ABB,
 },
 [0x2ABC]={
  category="sm",
  description="DOUBLE SUCCEEDS",
  direction="on",
  linebreak="al",
  mirror=0x2ABB,
  unicodeslot=0x2ABC,
 },
 [0x2ABD]={
  category="sm",
  description="SUBSET WITH DOT",
  direction="on",
  linebreak="al",
  mirror=0x2ABE,
  unicodeslot=0x2ABD,
 },
 [0x2ABE]={
  category="sm",
  description="SUPERSET WITH DOT",
  direction="on",
  linebreak="al",
  mirror=0x2ABD,
  unicodeslot=0x2ABE,
 },
 [0x2ABF]={
  category="sm",
  description="SUBSET WITH PLUS SIGN BELOW",
  direction="on",
  linebreak="al",
  mirror=0x2AC0,
  unicodeslot=0x2ABF,
 },
 [0x2AC0]={
  category="sm",
  description="SUPERSET WITH PLUS SIGN BELOW",
  direction="on",
  linebreak="al",
  mirror=0x2ABF,
  unicodeslot=0x2AC0,
 },
 [0x2AC1]={
  category="sm",
  description="SUBSET WITH MULTIPLICATION SIGN BELOW",
  direction="on",
  linebreak="al",
  mirror=0x2AC2,
  unicodeslot=0x2AC1,
 },
 [0x2AC2]={
  category="sm",
  description="SUPERSET WITH MULTIPLICATION SIGN BELOW",
  direction="on",
  linebreak="al",
  mirror=0x2AC1,
  unicodeslot=0x2AC2,
 },
 [0x2AC3]={
  category="sm",
  description="SUBSET OF OR EQUAL TO WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  mirror=0x2AC4,
  unicodeslot=0x2AC3,
 },
 [0x2AC4]={
  category="sm",
  description="SUPERSET OF OR EQUAL TO WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  mirror=0x2AC3,
  unicodeslot=0x2AC4,
 },
 [0x2AC5]={
  category="sm",
  description="SUBSET OF ABOVE EQUALS SIGN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="subseteqq",
  mirror=0x2AC6,
  unicodeslot=0x2AC5,
 },
 [0x2AC6]={
  category="sm",
  description="SUPERSET OF ABOVE EQUALS SIGN",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="supseteqq",
  mirror=0x2AC5,
  unicodeslot=0x2AC6,
 },
 [0x2AC7]={
  category="sm",
  description="SUBSET OF ABOVE TILDE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AC7,
 },
 [0x2AC8]={
  category="sm",
  description="SUPERSET OF ABOVE TILDE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AC8,
 },
 [0x2AC9]={
  category="sm",
  description="SUBSET OF ABOVE ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AC9,
 },
 [0x2ACA]={
  category="sm",
  description="SUPERSET OF ABOVE ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2ACA,
 },
 [0x2ACB]={
  category="sm",
  description="SUBSET OF ABOVE NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="subsetneqq",
  unicodeslot=0x2ACB,
  variants={
   [0xFE00]="with stroke through bottom members",
  },
 },
 [0x2ACC]={
  category="sm",
  description="SUPERSET OF ABOVE NOT EQUAL TO",
  direction="on",
  linebreak="al",
  mathclass="relation",
  mathname="supsetneqq",
  unicodeslot=0x2ACC,
  variants={
   [0xFE00]="with stroke through bottom members",
  },
 },
 [0x2ACD]={
  category="sm",
  description="SQUARE LEFT OPEN BOX OPERATOR",
  direction="on",
  linebreak="al",
  mirror=0x2ACE,
  unicodeslot=0x2ACD,
 },
 [0x2ACE]={
  category="sm",
  description="SQUARE RIGHT OPEN BOX OPERATOR",
  direction="on",
  linebreak="al",
  mirror=0x2ACD,
  unicodeslot=0x2ACE,
 },
 [0x2ACF]={
  category="sm",
  description="CLOSED SUBSET",
  direction="on",
  linebreak="al",
  mirror=0x2AD0,
  unicodeslot=0x2ACF,
 },
 [0x2AD0]={
  category="sm",
  description="CLOSED SUPERSET",
  direction="on",
  linebreak="al",
  mirror=0x2ACF,
  unicodeslot=0x2AD0,
 },
 [0x2AD1]={
  category="sm",
  description="CLOSED SUBSET OR EQUAL TO",
  direction="on",
  linebreak="al",
  mirror=0x2AD2,
  unicodeslot=0x2AD1,
 },
 [0x2AD2]={
  category="sm",
  description="CLOSED SUPERSET OR EQUAL TO",
  direction="on",
  linebreak="al",
  mirror=0x2AD1,
  unicodeslot=0x2AD2,
 },
 [0x2AD3]={
  category="sm",
  description="SUBSET ABOVE SUPERSET",
  direction="on",
  linebreak="al",
  mirror=0x2AD4,
  unicodeslot=0x2AD3,
 },
 [0x2AD4]={
  category="sm",
  description="SUPERSET ABOVE SUBSET",
  direction="on",
  linebreak="al",
  mirror=0x2AD3,
  unicodeslot=0x2AD4,
 },
 [0x2AD5]={
  category="sm",
  description="SUBSET ABOVE SUBSET",
  direction="on",
  linebreak="al",
  mirror=0x2AD6,
  unicodeslot=0x2AD5,
 },
 [0x2AD6]={
  category="sm",
  description="SUPERSET ABOVE SUPERSET",
  direction="on",
  linebreak="al",
  mirror=0x2AD5,
  unicodeslot=0x2AD6,
 },
 [0x2AD7]={
  category="sm",
  description="SUPERSET BESIDE SUBSET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AD7,
 },
 [0x2AD8]={
  category="sm",
  description="SUPERSET BESIDE AND JOINED BY DASH WITH SUBSET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AD8,
 },
 [0x2AD9]={
  category="sm",
  description="ELEMENT OF OPENING DOWNWARDS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AD9,
 },
 [0x2ADA]={
  category="sm",
  description="PITCHFORK WITH TEE TOP",
  direction="on",
  linebreak="al",
  unicodeslot=0x2ADA,
 },
 [0x2ADB]={
  category="sm",
  description="TRANSVERSAL INTERSECTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2ADB,
 },
 [0x2ADC]={
  category="sm",
  description="FORKING",
  direction="on",
  linebreak="al",
  specials={ "char", 0x2ADD, 0x0338 },
  unicodeslot=0x2ADC,
 },
 [0x2ADD]={
  category="sm",
  description="NONFORKING",
  direction="on",
  linebreak="al",
  unicodeslot=0x2ADD,
 },
 [0x2ADE]={
  category="sm",
  description="SHORT LEFT TACK",
  direction="on",
  linebreak="al",
  mirror=0x22A6,
  unicodeslot=0x2ADE,
 },
 [0x2ADF]={
  category="sm",
  description="SHORT DOWN TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2ADF,
 },
 [0x2AE0]={
  category="sm",
  description="SHORT UP TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AE0,
 },
 [0x2AE1]={
  category="sm",
  description="PERPENDICULAR WITH S",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AE1,
 },
 [0x2AE2]={
  category="sm",
  description="VERTICAL BAR TRIPLE RIGHT TURNSTILE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AE2,
 },
 [0x2AE3]={
  category="sm",
  description="DOUBLE VERTICAL BAR LEFT TURNSTILE",
  direction="on",
  linebreak="al",
  mirror=0x22A9,
  unicodeslot=0x2AE3,
 },
 [0x2AE4]={
  category="sm",
  description="VERTICAL BAR DOUBLE LEFT TURNSTILE",
  direction="on",
  linebreak="al",
  mirror=0x22A8,
  unicodeslot=0x2AE4,
 },
 [0x2AE5]={
  category="sm",
  description="DOUBLE VERTICAL BAR DOUBLE LEFT TURNSTILE",
  direction="on",
  linebreak="al",
  mirror=0x22AB,
  unicodeslot=0x2AE5,
 },
 [0x2AE6]={
  category="sm",
  description="LONG DASH FROM LEFT MEMBER OF DOUBLE VERTICAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AE6,
 },
 [0x2AE7]={
  category="sm",
  description="SHORT DOWN TACK WITH OVERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AE7,
 },
 [0x2AE8]={
  category="sm",
  description="SHORT UP TACK WITH UNDERBAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AE8,
 },
 [0x2AE9]={
  category="sm",
  description="SHORT UP TACK ABOVE SHORT DOWN TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AE9,
 },
 [0x2AEA]={
  category="sm",
  description="DOUBLE DOWN TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AEA,
 },
 [0x2AEB]={
  category="sm",
  description="DOUBLE UP TACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AEB,
 },
 [0x2AEC]={
  category="sm",
  description="DOUBLE STROKE NOT SIGN",
  direction="on",
  linebreak="al",
  mirror=0x2AED,
  unicodeslot=0x2AEC,
 },
 [0x2AED]={
  category="sm",
  description="REVERSED DOUBLE STROKE NOT SIGN",
  direction="on",
  linebreak="al",
  mirror=0x2AEC,
  unicodeslot=0x2AED,
 },
 [0x2AEE]={
  category="sm",
  description="DOES NOT DIVIDE WITH REVERSED NEGATION SLASH",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AEE,
 },
 [0x2AEF]={
  category="sm",
  description="VERTICAL LINE WITH CIRCLE ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AEF,
 },
 [0x2AF0]={
  category="sm",
  description="VERTICAL LINE WITH CIRCLE BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AF0,
 },
 [0x2AF1]={
  category="sm",
  description="DOWN TACK WITH CIRCLE BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AF1,
 },
 [0x2AF2]={
  category="sm",
  description="PARALLEL WITH HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AF2,
 },
 [0x2AF3]={
  category="sm",
  description="PARALLEL WITH TILDE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AF3,
 },
 [0x2AF4]={
  category="sm",
  description="TRIPLE VERTICAL BAR BINARY RELATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AF4,
 },
 [0x2AF5]={
  category="sm",
  description="TRIPLE VERTICAL BAR WITH HORIZONTAL STROKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AF5,
 },
 [0x2AF6]={
  category="sm",
  description="TRIPLE COLON OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AF6,
 },
 [0x2AF7]={
  category="sm",
  description="TRIPLE NESTED LESS-THAN",
  direction="on",
  linebreak="al",
  mirror=0x2AF8,
  unicodeslot=0x2AF7,
 },
 [0x2AF8]={
  category="sm",
  description="TRIPLE NESTED GREATER-THAN",
  direction="on",
  linebreak="al",
  mirror=0x2AF7,
  unicodeslot=0x2AF8,
 },
 [0x2AF9]={
  category="sm",
  description="DOUBLE-LINE SLANTED LESS-THAN OR EQUAL TO",
  direction="on",
  linebreak="al",
  mirror=0x2AFA,
  unicodeslot=0x2AF9,
 },
 [0x2AFA]={
  category="sm",
  description="DOUBLE-LINE SLANTED GREATER-THAN OR EQUAL TO",
  direction="on",
  linebreak="al",
  mirror=0x2AF9,
  unicodeslot=0x2AFA,
 },
 [0x2AFB]={
  category="sm",
  description="TRIPLE SOLIDUS BINARY RELATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AFB,
 },
 [0x2AFC]={
  category="sm",
  description="LARGE TRIPLE VERTICAL BAR OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AFC,
 },
 [0x2AFD]={
  category="sm",
  description="DOUBLE SOLIDUS OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AFD,
 },
 [0x2AFE]={
  category="sm",
  description="WHITE VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AFE,
 },
 [0x2AFF]={
  category="sm",
  description="N-ARY WHITE VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2AFF,
 },
 [0x2B00]={
  category="so",
  description="NORTH EAST WHITE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B00,
 },
 [0x2B01]={
  category="so",
  description="NORTH WEST WHITE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B01,
 },
 [0x2B02]={
  category="so",
  description="SOUTH EAST WHITE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B02,
 },
 [0x2B03]={
  category="so",
  description="SOUTH WEST WHITE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B03,
 },
 [0x2B04]={
  category="so",
  description="LEFT RIGHT WHITE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B04,
 },
 [0x2B05]={
  category="so",
  description="LEFTWARDS BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B05,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2B06]={
  category="so",
  description="UPWARDS BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B06,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2B07]={
  category="so",
  description="DOWNWARDS BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B07,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2B08]={
  category="so",
  description="NORTH EAST BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B08,
 },
 [0x2B09]={
  category="so",
  description="NORTH WEST BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B09,
 },
 [0x2B0A]={
  category="so",
  description="SOUTH EAST BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B0A,
 },
 [0x2B0B]={
  category="so",
  description="SOUTH WEST BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B0B,
 },
 [0x2B0C]={
  category="so",
  description="LEFT RIGHT BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B0C,
 },
 [0x2B0D]={
  category="so",
  description="UP DOWN BLACK ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B0D,
 },
 [0x2B0E]={
  category="so",
  description="RIGHTWARDS ARROW WITH TIP DOWNWARDS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B0E,
 },
 [0x2B0F]={
  category="so",
  description="RIGHTWARDS ARROW WITH TIP UPWARDS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B0F,
 },
 [0x2B10]={
  category="so",
  description="LEFTWARDS ARROW WITH TIP DOWNWARDS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B10,
 },
 [0x2B11]={
  category="so",
  description="LEFTWARDS ARROW WITH TIP UPWARDS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B11,
 },
 [0x2B12]={
  category="so",
  description="SQUARE WITH TOP HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B12,
 },
 [0x2B13]={
  category="so",
  description="SQUARE WITH BOTTOM HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B13,
 },
 [0x2B14]={
  category="so",
  description="SQUARE WITH UPPER RIGHT DIAGONAL HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B14,
 },
 [0x2B15]={
  category="so",
  description="SQUARE WITH LOWER LEFT DIAGONAL HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B15,
 },
 [0x2B16]={
  category="so",
  description="DIAMOND WITH LEFT HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B16,
 },
 [0x2B17]={
  category="so",
  description="DIAMOND WITH RIGHT HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B17,
 },
 [0x2B18]={
  category="so",
  description="DIAMOND WITH TOP HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B18,
 },
 [0x2B19]={
  category="so",
  description="DIAMOND WITH BOTTOM HALF BLACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B19,
 },
 [0x2B1A]={
  category="so",
  description="DOTTED SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B1A,
 },
 [0x2B1B]={
  category="so",
  description="BLACK LARGE SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B1B,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2B1C]={
  category="so",
  description="WHITE LARGE SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B1C,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2B1D]={
  category="so",
  description="BLACK VERY SMALL SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B1D,
 },
 [0x2B1E]={
  category="so",
  description="WHITE VERY SMALL SQUARE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B1E,
 },
 [0x2B1F]={
  category="so",
  description="BLACK PENTAGON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B1F,
 },
 [0x2B20]={
  category="so",
  description="WHITE PENTAGON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B20,
 },
 [0x2B21]={
  category="so",
  description="WHITE HEXAGON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B21,
 },
 [0x2B22]={
  category="so",
  description="BLACK HEXAGON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B22,
 },
 [0x2B23]={
  category="so",
  description="HORIZONTAL BLACK HEXAGON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B23,
 },
 [0x2B24]={
  category="so",
  description="BLACK LARGE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B24,
 },
 [0x2B25]={
  category="so",
  description="BLACK MEDIUM DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B25,
 },
 [0x2B26]={
  category="so",
  description="WHITE MEDIUM DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B26,
 },
 [0x2B27]={
  category="so",
  description="BLACK MEDIUM LOZENGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B27,
 },
 [0x2B28]={
  category="so",
  description="WHITE MEDIUM LOZENGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B28,
 },
 [0x2B29]={
  category="so",
  description="BLACK SMALL DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B29,
 },
 [0x2B2A]={
  category="so",
  description="BLACK SMALL LOZENGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B2A,
 },
 [0x2B2B]={
  category="so",
  description="WHITE SMALL LOZENGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B2B,
 },
 [0x2B2C]={
  category="so",
  description="BLACK HORIZONTAL ELLIPSE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B2C,
 },
 [0x2B2D]={
  category="so",
  description="WHITE HORIZONTAL ELLIPSE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B2D,
 },
 [0x2B2E]={
  category="so",
  description="BLACK VERTICAL ELLIPSE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B2E,
 },
 [0x2B2F]={
  category="so",
  description="WHITE VERTICAL ELLIPSE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B2F,
 },
 [0x2B30]={
  category="sm",
  description="LEFT ARROW WITH SMALL CIRCLE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B30,
 },
 [0x2B31]={
  category="sm",
  description="THREE LEFTWARDS ARROWS",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B31,
 },
 [0x2B32]={
  category="sm",
  description="LEFT ARROW WITH CIRCLED PLUS",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B32,
 },
 [0x2B33]={
  category="sm",
  description="LONG LEFTWARDS SQUIGGLE ARROW",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B33,
 },
 [0x2B34]={
  category="sm",
  description="LEFTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B34,
 },
 [0x2B35]={
  category="sm",
  description="LEFTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B35,
 },
 [0x2B36]={
  category="sm",
  description="LEFTWARDS TWO-HEADED ARROW FROM BAR",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B36,
 },
 [0x2B37]={
  category="sm",
  description="LEFTWARDS TWO-HEADED TRIPLE DASH ARROW",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B37,
 },
 [0x2B38]={
  category="sm",
  description="LEFTWARDS ARROW WITH DOTTED STEM",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B38,
 },
 [0x2B39]={
  category="sm",
  description="LEFTWARDS ARROW WITH TAIL WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B39,
 },
 [0x2B3A]={
  category="sm",
  description="LEFTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B3A,
 },
 [0x2B3B]={
  category="sm",
  description="LEFTWARDS TWO-HEADED ARROW WITH TAIL",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B3B,
 },
 [0x2B3C]={
  category="sm",
  description="LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B3C,
 },
 [0x2B3D]={
  category="sm",
  description="LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B3D,
 },
 [0x2B3E]={
  category="sm",
  description="LEFTWARDS ARROW THROUGH X",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B3E,
 },
 [0x2B3F]={
  category="sm",
  description="WAVE ARROW POINTING DIRECTLY LEFT",
  direction="on",
  linebreak="al",
  mathextensible="l",
  unicodeslot=0x2B3F,
 },
 [0x2B40]={
  category="sm",
  description="EQUALS SIGN ABOVE LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B40,
 },
 [0x2B41]={
  category="sm",
  description="REVERSE TILDE OPERATOR ABOVE LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B41,
 },
 [0x2B42]={
  category="sm",
  description="LEFTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B42,
 },
 [0x2B43]={
  category="sm",
  description="RIGHTWARDS ARROW THROUGH GREATER-THAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B43,
 },
 [0x2B44]={
  category="sm",
  description="RIGHTWARDS ARROW THROUGH SUPERSET",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B44,
 },
 [0x2B45]={
  category="so",
  description="LEFTWARDS QUADRUPLE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B45,
 },
 [0x2B46]={
  category="so",
  description="RIGHTWARDS QUADRUPLE ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B46,
 },
 [0x2B47]={
  category="sm",
  description="REVERSE TILDE OPERATOR ABOVE RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B47,
 },
 [0x2B48]={
  category="sm",
  description="RIGHTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B48,
 },
 [0x2B49]={
  category="sm",
  description="TILDE OPERATOR ABOVE LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B49,
 },
 [0x2B4A]={
  category="sm",
  description="LEFTWARDS ARROW ABOVE ALMOST EQUAL TO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B4A,
 },
 [0x2B4B]={
  category="sm",
  description="LEFTWARDS ARROW ABOVE REVERSE TILDE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B4B,
 },
 [0x2B4C]={
  category="sm",
  description="RIGHTWARDS ARROW ABOVE REVERSE TILDE OPERATOR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B4C,
 },
 [0x2B50]={
  category="so",
  description="WHITE MEDIUM STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B50,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2B51]={
  category="so",
  description="BLACK SMALL STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B51,
 },
 [0x2B52]={
  category="so",
  description="WHITE SMALL STAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B52,
 },
 [0x2B53]={
  category="so",
  description="BLACK RIGHT-POINTING PENTAGON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B53,
 },
 [0x2B54]={
  category="so",
  description="WHITE RIGHT-POINTING PENTAGON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2B54,
 },
 [0x2B55]={
  category="so",
  cjkwd="a",
  description="HEAVY LARGE CIRCLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2B55,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x2B56]={
  category="so",
  cjkwd="a",
  description="HEAVY OVAL WITH OVAL INSIDE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2B56,
 },
 [0x2B57]={
  category="so",
  cjkwd="a",
  description="HEAVY CIRCLE WITH CIRCLE INSIDE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2B57,
 },
 [0x2B58]={
  category="so",
  cjkwd="a",
  description="HEAVY CIRCLE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2B58,
 },
 [0x2B59]={
  category="so",
  cjkwd="a",
  description="HEAVY CIRCLED SALTIRE",
  direction="on",
  linebreak="ai",
  unicodeslot=0x2B59,
 },
 [0x2C00]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER AZU",
  direction="l",
  lccode=0x2C30,
  linebreak="al",
  unicodeslot=0x2C00,
 },
 [0x2C01]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER BUKY",
  direction="l",
  lccode=0x2C31,
  linebreak="al",
  unicodeslot=0x2C01,
 },
 [0x2C02]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER VEDE",
  direction="l",
  lccode=0x2C32,
  linebreak="al",
  unicodeslot=0x2C02,
 },
 [0x2C03]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER GLAGOLI",
  direction="l",
  lccode=0x2C33,
  linebreak="al",
  unicodeslot=0x2C03,
 },
 [0x2C04]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER DOBRO",
  direction="l",
  lccode=0x2C34,
  linebreak="al",
  unicodeslot=0x2C04,
 },
 [0x2C05]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER YESTU",
  direction="l",
  lccode=0x2C35,
  linebreak="al",
  unicodeslot=0x2C05,
 },
 [0x2C06]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER ZHIVETE",
  direction="l",
  lccode=0x2C36,
  linebreak="al",
  unicodeslot=0x2C06,
 },
 [0x2C07]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER DZELO",
  direction="l",
  lccode=0x2C37,
  linebreak="al",
  unicodeslot=0x2C07,
 },
 [0x2C08]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER ZEMLJA",
  direction="l",
  lccode=0x2C38,
  linebreak="al",
  unicodeslot=0x2C08,
 },
 [0x2C09]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER IZHE",
  direction="l",
  lccode=0x2C39,
  linebreak="al",
  unicodeslot=0x2C09,
 },
 [0x2C0A]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER INITIAL IZHE",
  direction="l",
  lccode=0x2C3A,
  linebreak="al",
  unicodeslot=0x2C0A,
 },
 [0x2C0B]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER I",
  direction="l",
  lccode=0x2C3B,
  linebreak="al",
  unicodeslot=0x2C0B,
 },
 [0x2C0C]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER DJERVI",
  direction="l",
  lccode=0x2C3C,
  linebreak="al",
  unicodeslot=0x2C0C,
 },
 [0x2C0D]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER KAKO",
  direction="l",
  lccode=0x2C3D,
  linebreak="al",
  unicodeslot=0x2C0D,
 },
 [0x2C0E]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER LJUDIJE",
  direction="l",
  lccode=0x2C3E,
  linebreak="al",
  unicodeslot=0x2C0E,
 },
 [0x2C0F]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER MYSLITE",
  direction="l",
  lccode=0x2C3F,
  linebreak="al",
  unicodeslot=0x2C0F,
 },
 [0x2C10]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER NASHI",
  direction="l",
  lccode=0x2C40,
  linebreak="al",
  unicodeslot=0x2C10,
 },
 [0x2C11]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER ONU",
  direction="l",
  lccode=0x2C41,
  linebreak="al",
  unicodeslot=0x2C11,
 },
 [0x2C12]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER POKOJI",
  direction="l",
  lccode=0x2C42,
  linebreak="al",
  unicodeslot=0x2C12,
 },
 [0x2C13]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER RITSI",
  direction="l",
  lccode=0x2C43,
  linebreak="al",
  unicodeslot=0x2C13,
 },
 [0x2C14]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER SLOVO",
  direction="l",
  lccode=0x2C44,
  linebreak="al",
  unicodeslot=0x2C14,
 },
 [0x2C15]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER TVRIDO",
  direction="l",
  lccode=0x2C45,
  linebreak="al",
  unicodeslot=0x2C15,
 },
 [0x2C16]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER UKU",
  direction="l",
  lccode=0x2C46,
  linebreak="al",
  unicodeslot=0x2C16,
 },
 [0x2C17]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER FRITU",
  direction="l",
  lccode=0x2C47,
  linebreak="al",
  unicodeslot=0x2C17,
 },
 [0x2C18]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER HERU",
  direction="l",
  lccode=0x2C48,
  linebreak="al",
  unicodeslot=0x2C18,
 },
 [0x2C19]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER OTU",
  direction="l",
  lccode=0x2C49,
  linebreak="al",
  unicodeslot=0x2C19,
 },
 [0x2C1A]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER PE",
  direction="l",
  lccode=0x2C4A,
  linebreak="al",
  unicodeslot=0x2C1A,
 },
 [0x2C1B]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER SHTA",
  direction="l",
  lccode=0x2C4B,
  linebreak="al",
  unicodeslot=0x2C1B,
 },
 [0x2C1C]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER TSI",
  direction="l",
  lccode=0x2C4C,
  linebreak="al",
  unicodeslot=0x2C1C,
 },
 [0x2C1D]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER CHRIVI",
  direction="l",
  lccode=0x2C4D,
  linebreak="al",
  unicodeslot=0x2C1D,
 },
 [0x2C1E]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER SHA",
  direction="l",
  lccode=0x2C4E,
  linebreak="al",
  unicodeslot=0x2C1E,
 },
 [0x2C1F]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER YERU",
  direction="l",
  lccode=0x2C4F,
  linebreak="al",
  unicodeslot=0x2C1F,
 },
 [0x2C20]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER YERI",
  direction="l",
  lccode=0x2C50,
  linebreak="al",
  unicodeslot=0x2C20,
 },
 [0x2C21]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER YATI",
  direction="l",
  lccode=0x2C51,
  linebreak="al",
  unicodeslot=0x2C21,
 },
 [0x2C22]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER SPIDERY HA",
  direction="l",
  lccode=0x2C52,
  linebreak="al",
  unicodeslot=0x2C22,
 },
 [0x2C23]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER YU",
  direction="l",
  lccode=0x2C53,
  linebreak="al",
  unicodeslot=0x2C23,
 },
 [0x2C24]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER SMALL YUS",
  direction="l",
  lccode=0x2C54,
  linebreak="al",
  unicodeslot=0x2C24,
 },
 [0x2C25]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER SMALL YUS WITH TAIL",
  direction="l",
  lccode=0x2C55,
  linebreak="al",
  unicodeslot=0x2C25,
 },
 [0x2C26]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER YO",
  direction="l",
  lccode=0x2C56,
  linebreak="al",
  unicodeslot=0x2C26,
 },
 [0x2C27]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER IOTATED SMALL YUS",
  direction="l",
  lccode=0x2C57,
  linebreak="al",
  unicodeslot=0x2C27,
 },
 [0x2C28]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER BIG YUS",
  direction="l",
  lccode=0x2C58,
  linebreak="al",
  unicodeslot=0x2C28,
 },
 [0x2C29]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER IOTATED BIG YUS",
  direction="l",
  lccode=0x2C59,
  linebreak="al",
  unicodeslot=0x2C29,
 },
 [0x2C2A]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER FITA",
  direction="l",
  lccode=0x2C5A,
  linebreak="al",
  unicodeslot=0x2C2A,
 },
 [0x2C2B]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER IZHITSA",
  direction="l",
  lccode=0x2C5B,
  linebreak="al",
  unicodeslot=0x2C2B,
 },
 [0x2C2C]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER SHTAPIC",
  direction="l",
  lccode=0x2C5C,
  linebreak="al",
  unicodeslot=0x2C2C,
 },
 [0x2C2D]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER TROKUTASTI A",
  direction="l",
  lccode=0x2C5D,
  linebreak="al",
  unicodeslot=0x2C2D,
 },
 [0x2C2E]={
  category="lu",
  description="GLAGOLITIC CAPITAL LETTER LATINATE MYSLITE",
  direction="l",
  lccode=0x2C5E,
  linebreak="al",
  unicodeslot=0x2C2E,
 },
 [0x2C30]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER AZU",
  direction="l",
  linebreak="al",
  uccode=0x2C00,
  unicodeslot=0x2C30,
 },
 [0x2C31]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER BUKY",
  direction="l",
  linebreak="al",
  uccode=0x2C01,
  unicodeslot=0x2C31,
 },
 [0x2C32]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER VEDE",
  direction="l",
  linebreak="al",
  uccode=0x2C02,
  unicodeslot=0x2C32,
 },
 [0x2C33]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER GLAGOLI",
  direction="l",
  linebreak="al",
  uccode=0x2C03,
  unicodeslot=0x2C33,
 },
 [0x2C34]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER DOBRO",
  direction="l",
  linebreak="al",
  uccode=0x2C04,
  unicodeslot=0x2C34,
 },
 [0x2C35]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER YESTU",
  direction="l",
  linebreak="al",
  uccode=0x2C05,
  unicodeslot=0x2C35,
 },
 [0x2C36]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER ZHIVETE",
  direction="l",
  linebreak="al",
  uccode=0x2C06,
  unicodeslot=0x2C36,
 },
 [0x2C37]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER DZELO",
  direction="l",
  linebreak="al",
  uccode=0x2C07,
  unicodeslot=0x2C37,
 },
 [0x2C38]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER ZEMLJA",
  direction="l",
  linebreak="al",
  uccode=0x2C08,
  unicodeslot=0x2C38,
 },
 [0x2C39]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER IZHE",
  direction="l",
  linebreak="al",
  uccode=0x2C09,
  unicodeslot=0x2C39,
 },
 [0x2C3A]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER INITIAL IZHE",
  direction="l",
  linebreak="al",
  uccode=0x2C0A,
  unicodeslot=0x2C3A,
 },
 [0x2C3B]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER I",
  direction="l",
  linebreak="al",
  uccode=0x2C0B,
  unicodeslot=0x2C3B,
 },
 [0x2C3C]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER DJERVI",
  direction="l",
  linebreak="al",
  uccode=0x2C0C,
  unicodeslot=0x2C3C,
 },
 [0x2C3D]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER KAKO",
  direction="l",
  linebreak="al",
  uccode=0x2C0D,
  unicodeslot=0x2C3D,
 },
 [0x2C3E]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER LJUDIJE",
  direction="l",
  linebreak="al",
  uccode=0x2C0E,
  unicodeslot=0x2C3E,
 },
 [0x2C3F]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER MYSLITE",
  direction="l",
  linebreak="al",
  uccode=0x2C0F,
  unicodeslot=0x2C3F,
 },
 [0x2C40]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER NASHI",
  direction="l",
  linebreak="al",
  uccode=0x2C10,
  unicodeslot=0x2C40,
 },
 [0x2C41]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER ONU",
  direction="l",
  linebreak="al",
  uccode=0x2C11,
  unicodeslot=0x2C41,
 },
 [0x2C42]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER POKOJI",
  direction="l",
  linebreak="al",
  uccode=0x2C12,
  unicodeslot=0x2C42,
 },
 [0x2C43]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER RITSI",
  direction="l",
  linebreak="al",
  uccode=0x2C13,
  unicodeslot=0x2C43,
 },
 [0x2C44]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER SLOVO",
  direction="l",
  linebreak="al",
  uccode=0x2C14,
  unicodeslot=0x2C44,
 },
 [0x2C45]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER TVRIDO",
  direction="l",
  linebreak="al",
  uccode=0x2C15,
  unicodeslot=0x2C45,
 },
 [0x2C46]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER UKU",
  direction="l",
  linebreak="al",
  uccode=0x2C16,
  unicodeslot=0x2C46,
 },
 [0x2C47]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER FRITU",
  direction="l",
  linebreak="al",
  uccode=0x2C17,
  unicodeslot=0x2C47,
 },
 [0x2C48]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER HERU",
  direction="l",
  linebreak="al",
  uccode=0x2C18,
  unicodeslot=0x2C48,
 },
 [0x2C49]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER OTU",
  direction="l",
  linebreak="al",
  uccode=0x2C19,
  unicodeslot=0x2C49,
 },
 [0x2C4A]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER PE",
  direction="l",
  linebreak="al",
  uccode=0x2C1A,
  unicodeslot=0x2C4A,
 },
 [0x2C4B]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER SHTA",
  direction="l",
  linebreak="al",
  uccode=0x2C1B,
  unicodeslot=0x2C4B,
 },
 [0x2C4C]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER TSI",
  direction="l",
  linebreak="al",
  uccode=0x2C1C,
  unicodeslot=0x2C4C,
 },
 [0x2C4D]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER CHRIVI",
  direction="l",
  linebreak="al",
  uccode=0x2C1D,
  unicodeslot=0x2C4D,
 },
 [0x2C4E]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER SHA",
  direction="l",
  linebreak="al",
  uccode=0x2C1E,
  unicodeslot=0x2C4E,
 },
 [0x2C4F]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER YERU",
  direction="l",
  linebreak="al",
  uccode=0x2C1F,
  unicodeslot=0x2C4F,
 },
 [0x2C50]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER YERI",
  direction="l",
  linebreak="al",
  uccode=0x2C20,
  unicodeslot=0x2C50,
 },
 [0x2C51]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER YATI",
  direction="l",
  linebreak="al",
  uccode=0x2C21,
  unicodeslot=0x2C51,
 },
 [0x2C52]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER SPIDERY HA",
  direction="l",
  linebreak="al",
  uccode=0x2C22,
  unicodeslot=0x2C52,
 },
 [0x2C53]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER YU",
  direction="l",
  linebreak="al",
  uccode=0x2C23,
  unicodeslot=0x2C53,
 },
 [0x2C54]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER SMALL YUS",
  direction="l",
  linebreak="al",
  uccode=0x2C24,
  unicodeslot=0x2C54,
 },
 [0x2C55]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER SMALL YUS WITH TAIL",
  direction="l",
  linebreak="al",
  uccode=0x2C25,
  unicodeslot=0x2C55,
 },
 [0x2C56]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER YO",
  direction="l",
  linebreak="al",
  uccode=0x2C26,
  unicodeslot=0x2C56,
 },
 [0x2C57]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER IOTATED SMALL YUS",
  direction="l",
  linebreak="al",
  uccode=0x2C27,
  unicodeslot=0x2C57,
 },
 [0x2C58]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER BIG YUS",
  direction="l",
  linebreak="al",
  uccode=0x2C28,
  unicodeslot=0x2C58,
 },
 [0x2C59]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER IOTATED BIG YUS",
  direction="l",
  linebreak="al",
  uccode=0x2C29,
  unicodeslot=0x2C59,
 },
 [0x2C5A]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER FITA",
  direction="l",
  linebreak="al",
  uccode=0x2C2A,
  unicodeslot=0x2C5A,
 },
 [0x2C5B]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER IZHITSA",
  direction="l",
  linebreak="al",
  uccode=0x2C2B,
  unicodeslot=0x2C5B,
 },
 [0x2C5C]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER SHTAPIC",
  direction="l",
  linebreak="al",
  uccode=0x2C2C,
  unicodeslot=0x2C5C,
 },
 [0x2C5D]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER TROKUTASTI A",
  direction="l",
  linebreak="al",
  uccode=0x2C2D,
  unicodeslot=0x2C5D,
 },
 [0x2C5E]={
  category="ll",
  description="GLAGOLITIC SMALL LETTER LATINATE MYSLITE",
  direction="l",
  linebreak="al",
  uccode=0x2C2E,
  unicodeslot=0x2C5E,
 },
 [0x2C60]={
  category="lu",
  description="LATIN CAPITAL LETTER L WITH DOUBLE BAR",
  direction="l",
  lccode=0x2C61,
  linebreak="al",
  shcode=0x004C,
  unicodeslot=0x2C60,
 },
 [0x2C61]={
  category="ll",
  description="LATIN SMALL LETTER L WITH DOUBLE BAR",
  direction="l",
  linebreak="al",
  shcode=0x006C,
  uccode=0x2C60,
  unicodeslot=0x2C61,
 },
 [0x2C62]={
  category="lu",
  description="LATIN CAPITAL LETTER L WITH MIDDLE TILDE",
  direction="l",
  lccode=0x026B,
  linebreak="al",
  shcode=0x004C,
  unicodeslot=0x2C62,
 },
 [0x2C63]={
  category="lu",
  description="LATIN CAPITAL LETTER P WITH STROKE",
  direction="l",
  lccode=0x1D7D,
  linebreak="al",
  shcode=0x0050,
  unicodeslot=0x2C63,
 },
 [0x2C64]={
  category="lu",
  description="LATIN CAPITAL LETTER R WITH TAIL",
  direction="l",
  lccode=0x027D,
  linebreak="al",
  shcode=0x0052,
  unicodeslot=0x2C64,
 },
 [0x2C65]={
  category="ll",
  description="LATIN SMALL LETTER A WITH STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0061,
  uccode=0x023A,
  unicodeslot=0x2C65,
 },
 [0x2C66]={
  category="ll",
  description="LATIN SMALL LETTER T WITH DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  shcode=0x0074,
  uccode=0x023E,
  unicodeslot=0x2C66,
 },
 [0x2C67]={
  category="lu",
  description="LATIN CAPITAL LETTER H WITH DESCENDER",
  direction="l",
  lccode=0x2C68,
  linebreak="al",
  shcode=0x0048,
  unicodeslot=0x2C67,
 },
 [0x2C68]={
  category="ll",
  description="LATIN SMALL LETTER H WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x0068,
  uccode=0x2C67,
  unicodeslot=0x2C68,
 },
 [0x2C69]={
  category="lu",
  description="LATIN CAPITAL LETTER K WITH DESCENDER",
  direction="l",
  lccode=0x2C6A,
  linebreak="al",
  shcode=0x004B,
  unicodeslot=0x2C69,
 },
 [0x2C6A]={
  category="ll",
  description="LATIN SMALL LETTER K WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x006B,
  uccode=0x2C69,
  unicodeslot=0x2C6A,
 },
 [0x2C6B]={
  category="lu",
  description="LATIN CAPITAL LETTER Z WITH DESCENDER",
  direction="l",
  lccode=0x2C6C,
  linebreak="al",
  shcode=0x005A,
  unicodeslot=0x2C6B,
 },
 [0x2C6C]={
  category="ll",
  description="LATIN SMALL LETTER Z WITH DESCENDER",
  direction="l",
  linebreak="al",
  shcode=0x007A,
  uccode=0x2C6B,
  unicodeslot=0x2C6C,
 },
 [0x2C6D]={
  category="lu",
  description="LATIN CAPITAL LETTER ALPHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C6D,
 },
 [0x2C6E]={
  category="lu",
  description="LATIN CAPITAL LETTER M WITH HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C6E,
 },
 [0x2C6F]={
  category="lu",
  description="LATIN CAPITAL LETTER TURNED A",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C6F,
 },
 [0x2C70]={
  category="lu",
  description="LATIN CAPITAL LETTER TURNED ALPHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C70,
 },
 [0x2C71]={
  category="ll",
  description="LATIN SMALL LETTER V WITH RIGHT HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C71,
 },
 [0x2C72]={
  category="lu",
  description="LATIN CAPITAL LETTER W WITH HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C72,
 },
 [0x2C73]={
  category="ll",
  description="LATIN SMALL LETTER W WITH HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C73,
 },
 [0x2C74]={
  category="ll",
  description="LATIN SMALL LETTER V WITH CURL",
  direction="l",
  linebreak="al",
  shcode=0x0076,
  unicodeslot=0x2C74,
 },
 [0x2C75]={
  category="lu",
  description="LATIN CAPITAL LETTER HALF H",
  direction="l",
  lccode=0x2C76,
  linebreak="al",
  unicodeslot=0x2C75,
 },
 [0x2C76]={
  category="ll",
  description="LATIN SMALL LETTER HALF H",
  direction="l",
  linebreak="al",
  uccode=0x2C75,
  unicodeslot=0x2C76,
 },
 [0x2C77]={
  category="ll",
  description="LATIN SMALL LETTER TAILLESS PHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C77,
 },
 [0x2C78]={
  category="ll",
  description="LATIN SMALL LETTER E WITH NOTCH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C78,
 },
 [0x2C79]={
  category="ll",
  description="LATIN SMALL LETTER TURNED R WITH TAIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C79,
 },
 [0x2C7A]={
  category="ll",
  description="LATIN SMALL LETTER O WITH LOW RING INSIDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C7A,
 },
 [0x2C7B]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL TURNED E",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C7B,
 },
 [0x2C7C]={
  category="ll",
  description="LATIN SUBSCRIPT SMALL LETTER J",
  direction="l",
  linebreak="al",
  specials={ "sub", 0x006A },
  unicodeslot=0x2C7C,
 },
 [0x2C7D]={
  category="lm",
  description="MODIFIER LETTER CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0056 },
  unicodeslot=0x2C7D,
 },
 [0x2C7E]={
  category="lu",
  description="LATIN CAPITAL LETTER S WITH SWASH TAIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C7E,
 },
 [0x2C7F]={
  category="lu",
  description="LATIN CAPITAL LETTER Z WITH SWASH TAIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x2C7F,
 },
 [0x2C80]={
  category="lu",
  description="COPTIC CAPITAL LETTER ALFA",
  direction="l",
  lccode=0x2C81,
  linebreak="al",
  unicodeslot=0x2C80,
 },
 [0x2C81]={
  category="ll",
  description="COPTIC SMALL LETTER ALFA",
  direction="l",
  linebreak="al",
  uccode=0x2C80,
  unicodeslot=0x2C81,
 },
 [0x2C82]={
  category="lu",
  description="COPTIC CAPITAL LETTER VIDA",
  direction="l",
  lccode=0x2C83,
  linebreak="al",
  unicodeslot=0x2C82,
 },
 [0x2C83]={
  category="ll",
  description="COPTIC SMALL LETTER VIDA",
  direction="l",
  linebreak="al",
  uccode=0x2C82,
  unicodeslot=0x2C83,
 },
 [0x2C84]={
  category="lu",
  description="COPTIC CAPITAL LETTER GAMMA",
  direction="l",
  lccode=0x2C85,
  linebreak="al",
  unicodeslot=0x2C84,
 },
 [0x2C85]={
  category="ll",
  description="COPTIC SMALL LETTER GAMMA",
  direction="l",
  linebreak="al",
  uccode=0x2C84,
  unicodeslot=0x2C85,
 },
 [0x2C86]={
  category="lu",
  description="COPTIC CAPITAL LETTER DALDA",
  direction="l",
  lccode=0x2C87,
  linebreak="al",
  unicodeslot=0x2C86,
 },
 [0x2C87]={
  category="ll",
  description="COPTIC SMALL LETTER DALDA",
  direction="l",
  linebreak="al",
  uccode=0x2C86,
  unicodeslot=0x2C87,
 },
 [0x2C88]={
  category="lu",
  description="COPTIC CAPITAL LETTER EIE",
  direction="l",
  lccode=0x2C89,
  linebreak="al",
  unicodeslot=0x2C88,
 },
 [0x2C89]={
  category="ll",
  description="COPTIC SMALL LETTER EIE",
  direction="l",
  linebreak="al",
  uccode=0x2C88,
  unicodeslot=0x2C89,
 },
 [0x2C8A]={
  category="lu",
  description="COPTIC CAPITAL LETTER SOU",
  direction="l",
  lccode=0x2C8B,
  linebreak="al",
  unicodeslot=0x2C8A,
 },
 [0x2C8B]={
  category="ll",
  description="COPTIC SMALL LETTER SOU",
  direction="l",
  linebreak="al",
  uccode=0x2C8A,
  unicodeslot=0x2C8B,
 },
 [0x2C8C]={
  category="lu",
  description="COPTIC CAPITAL LETTER ZATA",
  direction="l",
  lccode=0x2C8D,
  linebreak="al",
  unicodeslot=0x2C8C,
 },
 [0x2C8D]={
  category="ll",
  description="COPTIC SMALL LETTER ZATA",
  direction="l",
  linebreak="al",
  uccode=0x2C8C,
  unicodeslot=0x2C8D,
 },
 [0x2C8E]={
  category="lu",
  description="COPTIC CAPITAL LETTER HATE",
  direction="l",
  lccode=0x2C8F,
  linebreak="al",
  unicodeslot=0x2C8E,
 },
 [0x2C8F]={
  category="ll",
  description="COPTIC SMALL LETTER HATE",
  direction="l",
  linebreak="al",
  uccode=0x2C8E,
  unicodeslot=0x2C8F,
 },
 [0x2C90]={
  category="lu",
  description="COPTIC CAPITAL LETTER THETHE",
  direction="l",
  lccode=0x2C91,
  linebreak="al",
  unicodeslot=0x2C90,
 },
 [0x2C91]={
  category="ll",
  description="COPTIC SMALL LETTER THETHE",
  direction="l",
  linebreak="al",
  uccode=0x2C90,
  unicodeslot=0x2C91,
 },
 [0x2C92]={
  category="lu",
  description="COPTIC CAPITAL LETTER IAUDA",
  direction="l",
  lccode=0x2C93,
  linebreak="al",
  unicodeslot=0x2C92,
 },
 [0x2C93]={
  category="ll",
  description="COPTIC SMALL LETTER IAUDA",
  direction="l",
  linebreak="al",
  uccode=0x2C92,
  unicodeslot=0x2C93,
 },
 [0x2C94]={
  category="lu",
  description="COPTIC CAPITAL LETTER KAPA",
  direction="l",
  lccode=0x2C95,
  linebreak="al",
  unicodeslot=0x2C94,
 },
 [0x2C95]={
  category="ll",
  description="COPTIC SMALL LETTER KAPA",
  direction="l",
  linebreak="al",
  uccode=0x2C94,
  unicodeslot=0x2C95,
 },
 [0x2C96]={
  category="lu",
  description="COPTIC CAPITAL LETTER LAULA",
  direction="l",
  lccode=0x2C97,
  linebreak="al",
  unicodeslot=0x2C96,
 },
 [0x2C97]={
  category="ll",
  description="COPTIC SMALL LETTER LAULA",
  direction="l",
  linebreak="al",
  uccode=0x2C96,
  unicodeslot=0x2C97,
 },
 [0x2C98]={
  category="lu",
  description="COPTIC CAPITAL LETTER MI",
  direction="l",
  lccode=0x2C99,
  linebreak="al",
  unicodeslot=0x2C98,
 },
 [0x2C99]={
  category="ll",
  description="COPTIC SMALL LETTER MI",
  direction="l",
  linebreak="al",
  uccode=0x2C98,
  unicodeslot=0x2C99,
 },
 [0x2C9A]={
  category="lu",
  description="COPTIC CAPITAL LETTER NI",
  direction="l",
  lccode=0x2C9B,
  linebreak="al",
  unicodeslot=0x2C9A,
 },
 [0x2C9B]={
  category="ll",
  description="COPTIC SMALL LETTER NI",
  direction="l",
  linebreak="al",
  uccode=0x2C9A,
  unicodeslot=0x2C9B,
 },
 [0x2C9C]={
  category="lu",
  description="COPTIC CAPITAL LETTER KSI",
  direction="l",
  lccode=0x2C9D,
  linebreak="al",
  unicodeslot=0x2C9C,
 },
 [0x2C9D]={
  category="ll",
  description="COPTIC SMALL LETTER KSI",
  direction="l",
  linebreak="al",
  uccode=0x2C9C,
  unicodeslot=0x2C9D,
 },
 [0x2C9E]={
  category="lu",
  description="COPTIC CAPITAL LETTER O",
  direction="l",
  lccode=0x2C9F,
  linebreak="al",
  unicodeslot=0x2C9E,
 },
 [0x2C9F]={
  category="ll",
  description="COPTIC SMALL LETTER O",
  direction="l",
  linebreak="al",
  uccode=0x2C9E,
  unicodeslot=0x2C9F,
 },
 [0x2CA0]={
  category="lu",
  description="COPTIC CAPITAL LETTER PI",
  direction="l",
  lccode=0x2CA1,
  linebreak="al",
  unicodeslot=0x2CA0,
 },
 [0x2CA1]={
  category="ll",
  description="COPTIC SMALL LETTER PI",
  direction="l",
  linebreak="al",
  uccode=0x2CA0,
  unicodeslot=0x2CA1,
 },
 [0x2CA2]={
  category="lu",
  description="COPTIC CAPITAL LETTER RO",
  direction="l",
  lccode=0x2CA3,
  linebreak="al",
  unicodeslot=0x2CA2,
 },
 [0x2CA3]={
  category="ll",
  description="COPTIC SMALL LETTER RO",
  direction="l",
  linebreak="al",
  uccode=0x2CA2,
  unicodeslot=0x2CA3,
 },
 [0x2CA4]={
  category="lu",
  description="COPTIC CAPITAL LETTER SIMA",
  direction="l",
  lccode=0x2CA5,
  linebreak="al",
  unicodeslot=0x2CA4,
 },
 [0x2CA5]={
  category="ll",
  description="COPTIC SMALL LETTER SIMA",
  direction="l",
  linebreak="al",
  uccode=0x2CA4,
  unicodeslot=0x2CA5,
 },
 [0x2CA6]={
  category="lu",
  description="COPTIC CAPITAL LETTER TAU",
  direction="l",
  lccode=0x2CA7,
  linebreak="al",
  unicodeslot=0x2CA6,
 },
 [0x2CA7]={
  category="ll",
  description="COPTIC SMALL LETTER TAU",
  direction="l",
  linebreak="al",
  uccode=0x2CA6,
  unicodeslot=0x2CA7,
 },
 [0x2CA8]={
  category="lu",
  description="COPTIC CAPITAL LETTER UA",
  direction="l",
  lccode=0x2CA9,
  linebreak="al",
  unicodeslot=0x2CA8,
 },
 [0x2CA9]={
  category="ll",
  description="COPTIC SMALL LETTER UA",
  direction="l",
  linebreak="al",
  uccode=0x2CA8,
  unicodeslot=0x2CA9,
 },
 [0x2CAA]={
  category="lu",
  description="COPTIC CAPITAL LETTER FI",
  direction="l",
  lccode=0x2CAB,
  linebreak="al",
  unicodeslot=0x2CAA,
 },
 [0x2CAB]={
  category="ll",
  description="COPTIC SMALL LETTER FI",
  direction="l",
  linebreak="al",
  uccode=0x2CAA,
  unicodeslot=0x2CAB,
 },
 [0x2CAC]={
  category="lu",
  description="COPTIC CAPITAL LETTER KHI",
  direction="l",
  lccode=0x2CAD,
  linebreak="al",
  unicodeslot=0x2CAC,
 },
 [0x2CAD]={
  category="ll",
  description="COPTIC SMALL LETTER KHI",
  direction="l",
  linebreak="al",
  uccode=0x2CAC,
  unicodeslot=0x2CAD,
 },
 [0x2CAE]={
  category="lu",
  description="COPTIC CAPITAL LETTER PSI",
  direction="l",
  lccode=0x2CAF,
  linebreak="al",
  unicodeslot=0x2CAE,
 },
 [0x2CAF]={
  category="ll",
  description="COPTIC SMALL LETTER PSI",
  direction="l",
  linebreak="al",
  uccode=0x2CAE,
  unicodeslot=0x2CAF,
 },
 [0x2CB0]={
  category="lu",
  description="COPTIC CAPITAL LETTER OOU",
  direction="l",
  lccode=0x2CB1,
  linebreak="al",
  unicodeslot=0x2CB0,
 },
 [0x2CB1]={
  category="ll",
  description="COPTIC SMALL LETTER OOU",
  direction="l",
  linebreak="al",
  uccode=0x2CB0,
  unicodeslot=0x2CB1,
 },
 [0x2CB2]={
  category="lu",
  description="COPTIC CAPITAL LETTER DIALECT-P ALEF",
  direction="l",
  lccode=0x2CB3,
  linebreak="al",
  unicodeslot=0x2CB2,
 },
 [0x2CB3]={
  category="ll",
  description="COPTIC SMALL LETTER DIALECT-P ALEF",
  direction="l",
  linebreak="al",
  uccode=0x2CB2,
  unicodeslot=0x2CB3,
 },
 [0x2CB4]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC AIN",
  direction="l",
  lccode=0x2CB5,
  linebreak="al",
  unicodeslot=0x2CB4,
 },
 [0x2CB5]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC AIN",
  direction="l",
  linebreak="al",
  uccode=0x2CB4,
  unicodeslot=0x2CB5,
 },
 [0x2CB6]={
  category="lu",
  description="COPTIC CAPITAL LETTER CRYPTOGRAMMIC EIE",
  direction="l",
  lccode=0x2CB7,
  linebreak="al",
  unicodeslot=0x2CB6,
 },
 [0x2CB7]={
  category="ll",
  description="COPTIC SMALL LETTER CRYPTOGRAMMIC EIE",
  direction="l",
  linebreak="al",
  uccode=0x2CB6,
  unicodeslot=0x2CB7,
 },
 [0x2CB8]={
  category="lu",
  description="COPTIC CAPITAL LETTER DIALECT-P KAPA",
  direction="l",
  lccode=0x2CB9,
  linebreak="al",
  unicodeslot=0x2CB8,
 },
 [0x2CB9]={
  category="ll",
  description="COPTIC SMALL LETTER DIALECT-P KAPA",
  direction="l",
  linebreak="al",
  uccode=0x2CB8,
  unicodeslot=0x2CB9,
 },
 [0x2CBA]={
  category="lu",
  description="COPTIC CAPITAL LETTER DIALECT-P NI",
  direction="l",
  lccode=0x2CBB,
  linebreak="al",
  unicodeslot=0x2CBA,
 },
 [0x2CBB]={
  category="ll",
  description="COPTIC SMALL LETTER DIALECT-P NI",
  direction="l",
  linebreak="al",
  uccode=0x2CBA,
  unicodeslot=0x2CBB,
 },
 [0x2CBC]={
  category="lu",
  description="COPTIC CAPITAL LETTER CRYPTOGRAMMIC NI",
  direction="l",
  lccode=0x2CBD,
  linebreak="al",
  unicodeslot=0x2CBC,
 },
 [0x2CBD]={
  category="ll",
  description="COPTIC SMALL LETTER CRYPTOGRAMMIC NI",
  direction="l",
  linebreak="al",
  uccode=0x2CBC,
  unicodeslot=0x2CBD,
 },
 [0x2CBE]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC OOU",
  direction="l",
  lccode=0x2CBF,
  linebreak="al",
  unicodeslot=0x2CBE,
 },
 [0x2CBF]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC OOU",
  direction="l",
  linebreak="al",
  uccode=0x2CBE,
  unicodeslot=0x2CBF,
 },
 [0x2CC0]={
  category="lu",
  description="COPTIC CAPITAL LETTER SAMPI",
  direction="l",
  lccode=0x2CC1,
  linebreak="al",
  unicodeslot=0x2CC0,
 },
 [0x2CC1]={
  category="ll",
  description="COPTIC SMALL LETTER SAMPI",
  direction="l",
  linebreak="al",
  uccode=0x2CC0,
  unicodeslot=0x2CC1,
 },
 [0x2CC2]={
  category="lu",
  description="COPTIC CAPITAL LETTER CROSSED SHEI",
  direction="l",
  lccode=0x2CC3,
  linebreak="al",
  unicodeslot=0x2CC2,
 },
 [0x2CC3]={
  category="ll",
  description="COPTIC SMALL LETTER CROSSED SHEI",
  direction="l",
  linebreak="al",
  uccode=0x2CC2,
  unicodeslot=0x2CC3,
 },
 [0x2CC4]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC SHEI",
  direction="l",
  lccode=0x2CC5,
  linebreak="al",
  unicodeslot=0x2CC4,
 },
 [0x2CC5]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC SHEI",
  direction="l",
  linebreak="al",
  uccode=0x2CC4,
  unicodeslot=0x2CC5,
 },
 [0x2CC6]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC ESH",
  direction="l",
  lccode=0x2CC7,
  linebreak="al",
  unicodeslot=0x2CC6,
 },
 [0x2CC7]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC ESH",
  direction="l",
  linebreak="al",
  uccode=0x2CC6,
  unicodeslot=0x2CC7,
 },
 [0x2CC8]={
  category="lu",
  description="COPTIC CAPITAL LETTER AKHMIMIC KHEI",
  direction="l",
  lccode=0x2CC9,
  linebreak="al",
  unicodeslot=0x2CC8,
 },
 [0x2CC9]={
  category="ll",
  description="COPTIC SMALL LETTER AKHMIMIC KHEI",
  direction="l",
  linebreak="al",
  uccode=0x2CC8,
  unicodeslot=0x2CC9,
 },
 [0x2CCA]={
  category="lu",
  description="COPTIC CAPITAL LETTER DIALECT-P HORI",
  direction="l",
  lccode=0x2CCB,
  linebreak="al",
  unicodeslot=0x2CCA,
 },
 [0x2CCB]={
  category="ll",
  description="COPTIC SMALL LETTER DIALECT-P HORI",
  direction="l",
  linebreak="al",
  uccode=0x2CCA,
  unicodeslot=0x2CCB,
 },
 [0x2CCC]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC HORI",
  direction="l",
  lccode=0x2CCD,
  linebreak="al",
  unicodeslot=0x2CCC,
 },
 [0x2CCD]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC HORI",
  direction="l",
  linebreak="al",
  uccode=0x2CCC,
  unicodeslot=0x2CCD,
 },
 [0x2CCE]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC HA",
  direction="l",
  lccode=0x2CCF,
  linebreak="al",
  unicodeslot=0x2CCE,
 },
 [0x2CCF]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC HA",
  direction="l",
  linebreak="al",
  uccode=0x2CCE,
  unicodeslot=0x2CCF,
 },
 [0x2CD0]={
  category="lu",
  description="COPTIC CAPITAL LETTER L-SHAPED HA",
  direction="l",
  lccode=0x2CD1,
  linebreak="al",
  unicodeslot=0x2CD0,
 },
 [0x2CD1]={
  category="ll",
  description="COPTIC SMALL LETTER L-SHAPED HA",
  direction="l",
  linebreak="al",
  uccode=0x2CD0,
  unicodeslot=0x2CD1,
 },
 [0x2CD2]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC HEI",
  direction="l",
  lccode=0x2CD3,
  linebreak="al",
  unicodeslot=0x2CD2,
 },
 [0x2CD3]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC HEI",
  direction="l",
  linebreak="al",
  uccode=0x2CD2,
  unicodeslot=0x2CD3,
 },
 [0x2CD4]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC HAT",
  direction="l",
  lccode=0x2CD5,
  linebreak="al",
  unicodeslot=0x2CD4,
 },
 [0x2CD5]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC HAT",
  direction="l",
  linebreak="al",
  uccode=0x2CD4,
  unicodeslot=0x2CD5,
 },
 [0x2CD6]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC GANGIA",
  direction="l",
  lccode=0x2CD7,
  linebreak="al",
  unicodeslot=0x2CD6,
 },
 [0x2CD7]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC GANGIA",
  direction="l",
  linebreak="al",
  uccode=0x2CD6,
  unicodeslot=0x2CD7,
 },
 [0x2CD8]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC DJA",
  direction="l",
  lccode=0x2CD9,
  linebreak="al",
  unicodeslot=0x2CD8,
 },
 [0x2CD9]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC DJA",
  direction="l",
  linebreak="al",
  uccode=0x2CD8,
  unicodeslot=0x2CD9,
 },
 [0x2CDA]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD COPTIC SHIMA",
  direction="l",
  lccode=0x2CDB,
  linebreak="al",
  unicodeslot=0x2CDA,
 },
 [0x2CDB]={
  category="ll",
  description="COPTIC SMALL LETTER OLD COPTIC SHIMA",
  direction="l",
  linebreak="al",
  uccode=0x2CDA,
  unicodeslot=0x2CDB,
 },
 [0x2CDC]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD NUBIAN SHIMA",
  direction="l",
  lccode=0x2CDD,
  linebreak="al",
  unicodeslot=0x2CDC,
 },
 [0x2CDD]={
  category="ll",
  description="COPTIC SMALL LETTER OLD NUBIAN SHIMA",
  direction="l",
  linebreak="al",
  uccode=0x2CDC,
  unicodeslot=0x2CDD,
 },
 [0x2CDE]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD NUBIAN NGI",
  direction="l",
  lccode=0x2CDF,
  linebreak="al",
  unicodeslot=0x2CDE,
 },
 [0x2CDF]={
  category="ll",
  description="COPTIC SMALL LETTER OLD NUBIAN NGI",
  direction="l",
  linebreak="al",
  uccode=0x2CDE,
  unicodeslot=0x2CDF,
 },
 [0x2CE0]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD NUBIAN NYI",
  direction="l",
  lccode=0x2CE1,
  linebreak="al",
  unicodeslot=0x2CE0,
 },
 [0x2CE1]={
  category="ll",
  description="COPTIC SMALL LETTER OLD NUBIAN NYI",
  direction="l",
  linebreak="al",
  uccode=0x2CE0,
  unicodeslot=0x2CE1,
 },
 [0x2CE2]={
  category="lu",
  description="COPTIC CAPITAL LETTER OLD NUBIAN WAU",
  direction="l",
  lccode=0x2CE3,
  linebreak="al",
  unicodeslot=0x2CE2,
 },
 [0x2CE3]={
  category="ll",
  description="COPTIC SMALL LETTER OLD NUBIAN WAU",
  direction="l",
  linebreak="al",
  uccode=0x2CE2,
  unicodeslot=0x2CE3,
 },
 [0x2CE4]={
  category="ll",
  description="COPTIC SYMBOL KAI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2CE4,
 },
 [0x2CE5]={
  category="so",
  description="COPTIC SYMBOL MI RO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2CE5,
 },
 [0x2CE6]={
  category="so",
  description="COPTIC SYMBOL PI RO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2CE6,
 },
 [0x2CE7]={
  category="so",
  description="COPTIC SYMBOL STAUROS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2CE7,
 },
 [0x2CE8]={
  category="so",
  description="COPTIC SYMBOL TAU RO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2CE8,
 },
 [0x2CE9]={
  category="so",
  description="COPTIC SYMBOL KHI RO",
  direction="on",
  linebreak="al",
  unicodeslot=0x2CE9,
 },
 [0x2CEA]={
  category="so",
  description="COPTIC SYMBOL SHIMA SIMA",
  direction="on",
  linebreak="al",
  unicodeslot=0x2CEA,
 },
 [0x2CEB]={
  category="lu",
  description="COPTIC CAPITAL LETTER CRYPTOGRAMMIC SHEI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2CEB,
 },
 [0x2CEC]={
  category="ll",
  description="COPTIC SMALL LETTER CRYPTOGRAMMIC SHEI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2CEC,
 },
 [0x2CED]={
  category="lu",
  description="COPTIC CAPITAL LETTER CRYPTOGRAMMIC GANGIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2CED,
 },
 [0x2CEE]={
  category="ll",
  description="COPTIC SMALL LETTER CRYPTOGRAMMIC GANGIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2CEE,
 },
 [0x2CEF]={
  category="mn",
  description="COPTIC COMBINING NI ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2CEF,
 },
 [0x2CF0]={
  category="mn",
  description="COPTIC COMBINING SPIRITUS ASPER",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2CF0,
 },
 [0x2CF1]={
  category="mn",
  description="COPTIC COMBINING SPIRITUS LENIS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2CF1,
 },
 [0x2CF2]={
  category="lu",
  description="COPTIC CAPITAL LETTER BOHAIRIC KHEI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2CF2,
 },
 [0x2CF3]={
  category="ll",
  description="COPTIC SMALL LETTER BOHAIRIC KHEI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2CF3,
 },
 [0x2CF9]={
  category="po",
  description="COPTIC OLD NUBIAN FULL STOP",
  direction="on",
  linebreak="ex",
  unicodeslot=0x2CF9,
 },
 [0x2CFA]={
  category="po",
  description="COPTIC OLD NUBIAN DIRECT QUESTION MARK",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2CFA,
 },
 [0x2CFB]={
  category="po",
  description="COPTIC OLD NUBIAN INDIRECT QUESTION MARK",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2CFB,
 },
 [0x2CFC]={
  category="po",
  description="COPTIC OLD NUBIAN VERSE DIVIDER",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2CFC,
 },
 [0x2CFD]={
  category="no",
  description="COPTIC FRACTION ONE HALF",
  direction="on",
  linebreak="al",
  unicodeslot=0x2CFD,
 },
 [0x2CFE]={
  category="po",
  description="COPTIC FULL STOP",
  direction="on",
  linebreak="ex",
  unicodeslot=0x2CFE,
 },
 [0x2CFF]={
  category="po",
  description="COPTIC MORPHOLOGICAL DIVIDER",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2CFF,
 },
 [0x2D00]={
  category="ll",
  description="GEORGIAN SMALL LETTER AN",
  direction="l",
  linebreak="al",
  uccode=0x10A0,
  unicodeslot=0x2D00,
 },
 [0x2D01]={
  category="ll",
  description="GEORGIAN SMALL LETTER BAN",
  direction="l",
  linebreak="al",
  uccode=0x10A1,
  unicodeslot=0x2D01,
 },
 [0x2D02]={
  category="ll",
  description="GEORGIAN SMALL LETTER GAN",
  direction="l",
  linebreak="al",
  uccode=0x10A2,
  unicodeslot=0x2D02,
 },
 [0x2D03]={
  category="ll",
  description="GEORGIAN SMALL LETTER DON",
  direction="l",
  linebreak="al",
  uccode=0x10A3,
  unicodeslot=0x2D03,
 },
 [0x2D04]={
  category="ll",
  description="GEORGIAN SMALL LETTER EN",
  direction="l",
  linebreak="al",
  uccode=0x10A4,
  unicodeslot=0x2D04,
 },
 [0x2D05]={
  category="ll",
  description="GEORGIAN SMALL LETTER VIN",
  direction="l",
  linebreak="al",
  uccode=0x10A5,
  unicodeslot=0x2D05,
 },
 [0x2D06]={
  category="ll",
  description="GEORGIAN SMALL LETTER ZEN",
  direction="l",
  linebreak="al",
  uccode=0x10A6,
  unicodeslot=0x2D06,
 },
 [0x2D07]={
  category="ll",
  description="GEORGIAN SMALL LETTER TAN",
  direction="l",
  linebreak="al",
  uccode=0x10A7,
  unicodeslot=0x2D07,
 },
 [0x2D08]={
  category="ll",
  description="GEORGIAN SMALL LETTER IN",
  direction="l",
  linebreak="al",
  uccode=0x10A8,
  unicodeslot=0x2D08,
 },
 [0x2D09]={
  category="ll",
  description="GEORGIAN SMALL LETTER KAN",
  direction="l",
  linebreak="al",
  uccode=0x10A9,
  unicodeslot=0x2D09,
 },
 [0x2D0A]={
  category="ll",
  description="GEORGIAN SMALL LETTER LAS",
  direction="l",
  linebreak="al",
  uccode=0x10AA,
  unicodeslot=0x2D0A,
 },
 [0x2D0B]={
  category="ll",
  description="GEORGIAN SMALL LETTER MAN",
  direction="l",
  linebreak="al",
  uccode=0x10AB,
  unicodeslot=0x2D0B,
 },
 [0x2D0C]={
  category="ll",
  description="GEORGIAN SMALL LETTER NAR",
  direction="l",
  linebreak="al",
  uccode=0x10AC,
  unicodeslot=0x2D0C,
 },
 [0x2D0D]={
  category="ll",
  description="GEORGIAN SMALL LETTER ON",
  direction="l",
  linebreak="al",
  uccode=0x10AD,
  unicodeslot=0x2D0D,
 },
 [0x2D0E]={
  category="ll",
  description="GEORGIAN SMALL LETTER PAR",
  direction="l",
  linebreak="al",
  uccode=0x10AE,
  unicodeslot=0x2D0E,
 },
 [0x2D0F]={
  category="ll",
  description="GEORGIAN SMALL LETTER ZHAR",
  direction="l",
  linebreak="al",
  uccode=0x10AF,
  unicodeslot=0x2D0F,
 },
 [0x2D10]={
  category="ll",
  description="GEORGIAN SMALL LETTER RAE",
  direction="l",
  linebreak="al",
  uccode=0x10B0,
  unicodeslot=0x2D10,
 },
 [0x2D11]={
  category="ll",
  description="GEORGIAN SMALL LETTER SAN",
  direction="l",
  linebreak="al",
  uccode=0x10B1,
  unicodeslot=0x2D11,
 },
 [0x2D12]={
  category="ll",
  description="GEORGIAN SMALL LETTER TAR",
  direction="l",
  linebreak="al",
  uccode=0x10B2,
  unicodeslot=0x2D12,
 },
 [0x2D13]={
  category="ll",
  description="GEORGIAN SMALL LETTER UN",
  direction="l",
  linebreak="al",
  uccode=0x10B3,
  unicodeslot=0x2D13,
 },
 [0x2D14]={
  category="ll",
  description="GEORGIAN SMALL LETTER PHAR",
  direction="l",
  linebreak="al",
  uccode=0x10B4,
  unicodeslot=0x2D14,
 },
 [0x2D15]={
  category="ll",
  description="GEORGIAN SMALL LETTER KHAR",
  direction="l",
  linebreak="al",
  uccode=0x10B5,
  unicodeslot=0x2D15,
 },
 [0x2D16]={
  category="ll",
  description="GEORGIAN SMALL LETTER GHAN",
  direction="l",
  linebreak="al",
  uccode=0x10B6,
  unicodeslot=0x2D16,
 },
 [0x2D17]={
  category="ll",
  description="GEORGIAN SMALL LETTER QAR",
  direction="l",
  linebreak="al",
  uccode=0x10B7,
  unicodeslot=0x2D17,
 },
 [0x2D18]={
  category="ll",
  description="GEORGIAN SMALL LETTER SHIN",
  direction="l",
  linebreak="al",
  uccode=0x10B8,
  unicodeslot=0x2D18,
 },
 [0x2D19]={
  category="ll",
  description="GEORGIAN SMALL LETTER CHIN",
  direction="l",
  linebreak="al",
  uccode=0x10B9,
  unicodeslot=0x2D19,
 },
 [0x2D1A]={
  category="ll",
  description="GEORGIAN SMALL LETTER CAN",
  direction="l",
  linebreak="al",
  uccode=0x10BA,
  unicodeslot=0x2D1A,
 },
 [0x2D1B]={
  category="ll",
  description="GEORGIAN SMALL LETTER JIL",
  direction="l",
  linebreak="al",
  uccode=0x10BB,
  unicodeslot=0x2D1B,
 },
 [0x2D1C]={
  category="ll",
  description="GEORGIAN SMALL LETTER CIL",
  direction="l",
  linebreak="al",
  uccode=0x10BC,
  unicodeslot=0x2D1C,
 },
 [0x2D1D]={
  category="ll",
  description="GEORGIAN SMALL LETTER CHAR",
  direction="l",
  linebreak="al",
  uccode=0x10BD,
  unicodeslot=0x2D1D,
 },
 [0x2D1E]={
  category="ll",
  description="GEORGIAN SMALL LETTER XAN",
  direction="l",
  linebreak="al",
  uccode=0x10BE,
  unicodeslot=0x2D1E,
 },
 [0x2D1F]={
  category="ll",
  description="GEORGIAN SMALL LETTER JHAN",
  direction="l",
  linebreak="al",
  uccode=0x10BF,
  unicodeslot=0x2D1F,
 },
 [0x2D20]={
  category="ll",
  description="GEORGIAN SMALL LETTER HAE",
  direction="l",
  linebreak="al",
  uccode=0x10C0,
  unicodeslot=0x2D20,
 },
 [0x2D21]={
  category="ll",
  description="GEORGIAN SMALL LETTER HE",
  direction="l",
  linebreak="al",
  uccode=0x10C1,
  unicodeslot=0x2D21,
 },
 [0x2D22]={
  category="ll",
  description="GEORGIAN SMALL LETTER HIE",
  direction="l",
  linebreak="al",
  uccode=0x10C2,
  unicodeslot=0x2D22,
 },
 [0x2D23]={
  category="ll",
  description="GEORGIAN SMALL LETTER WE",
  direction="l",
  linebreak="al",
  uccode=0x10C3,
  unicodeslot=0x2D23,
 },
 [0x2D24]={
  category="ll",
  description="GEORGIAN SMALL LETTER HAR",
  direction="l",
  linebreak="al",
  uccode=0x10C4,
  unicodeslot=0x2D24,
 },
 [0x2D25]={
  category="ll",
  description="GEORGIAN SMALL LETTER HOE",
  direction="l",
  linebreak="al",
  uccode=0x10C5,
  unicodeslot=0x2D25,
 },
 [0x2D27]={
  category="ll",
  description="GEORGIAN SMALL LETTER YN",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D27,
 },
 [0x2D2D]={
  category="ll",
  description="GEORGIAN SMALL LETTER AEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D2D,
 },
 [0x2D30]={
  category="lo",
  description="TIFINAGH LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D30,
 },
 [0x2D31]={
  category="lo",
  description="TIFINAGH LETTER YAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D31,
 },
 [0x2D32]={
  category="lo",
  description="TIFINAGH LETTER YABH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D32,
 },
 [0x2D33]={
  category="lo",
  description="TIFINAGH LETTER YAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D33,
 },
 [0x2D34]={
  category="lo",
  description="TIFINAGH LETTER YAGHH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D34,
 },
 [0x2D35]={
  category="lo",
  description="TIFINAGH LETTER BERBER ACADEMY YAJ",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D35,
 },
 [0x2D36]={
  category="lo",
  description="TIFINAGH LETTER YAJ",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D36,
 },
 [0x2D37]={
  category="lo",
  description="TIFINAGH LETTER YAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D37,
 },
 [0x2D38]={
  category="lo",
  description="TIFINAGH LETTER YADH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D38,
 },
 [0x2D39]={
  category="lo",
  description="TIFINAGH LETTER YADD",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D39,
 },
 [0x2D3A]={
  category="lo",
  description="TIFINAGH LETTER YADDH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D3A,
 },
 [0x2D3B]={
  category="lo",
  description="TIFINAGH LETTER YEY",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D3B,
 },
 [0x2D3C]={
  category="lo",
  description="TIFINAGH LETTER YAF",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D3C,
 },
 [0x2D3D]={
  category="lo",
  description="TIFINAGH LETTER YAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D3D,
 },
 [0x2D3E]={
  category="lo",
  description="TIFINAGH LETTER TUAREG YAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D3E,
 },
 [0x2D3F]={
  category="lo",
  description="TIFINAGH LETTER YAKHH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D3F,
 },
 [0x2D40]={
  category="lo",
  description="TIFINAGH LETTER YAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D40,
 },
 [0x2D41]={
  category="lo",
  description="TIFINAGH LETTER BERBER ACADEMY YAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D41,
 },
 [0x2D42]={
  category="lo",
  description="TIFINAGH LETTER TUAREG YAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D42,
 },
 [0x2D43]={
  category="lo",
  description="TIFINAGH LETTER YAHH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D43,
 },
 [0x2D44]={
  category="lo",
  description="TIFINAGH LETTER YAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D44,
 },
 [0x2D45]={
  category="lo",
  description="TIFINAGH LETTER YAKH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D45,
 },
 [0x2D46]={
  category="lo",
  description="TIFINAGH LETTER TUAREG YAKH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D46,
 },
 [0x2D47]={
  category="lo",
  description="TIFINAGH LETTER YAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D47,
 },
 [0x2D48]={
  category="lo",
  description="TIFINAGH LETTER TUAREG YAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D48,
 },
 [0x2D49]={
  category="lo",
  description="TIFINAGH LETTER YI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D49,
 },
 [0x2D4A]={
  category="lo",
  description="TIFINAGH LETTER YAZH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D4A,
 },
 [0x2D4B]={
  category="lo",
  description="TIFINAGH LETTER AHAGGAR YAZH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D4B,
 },
 [0x2D4C]={
  category="lo",
  description="TIFINAGH LETTER TUAREG YAZH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D4C,
 },
 [0x2D4D]={
  category="lo",
  description="TIFINAGH LETTER YAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D4D,
 },
 [0x2D4E]={
  category="lo",
  description="TIFINAGH LETTER YAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D4E,
 },
 [0x2D4F]={
  category="lo",
  description="TIFINAGH LETTER YAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D4F,
 },
 [0x2D50]={
  category="lo",
  description="TIFINAGH LETTER TUAREG YAGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D50,
 },
 [0x2D51]={
  category="lo",
  description="TIFINAGH LETTER TUAREG YANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D51,
 },
 [0x2D52]={
  category="lo",
  description="TIFINAGH LETTER YAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D52,
 },
 [0x2D53]={
  category="lo",
  description="TIFINAGH LETTER YU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D53,
 },
 [0x2D54]={
  category="lo",
  description="TIFINAGH LETTER YAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D54,
 },
 [0x2D55]={
  category="lo",
  description="TIFINAGH LETTER YARR",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D55,
 },
 [0x2D56]={
  category="lo",
  description="TIFINAGH LETTER YAGH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D56,
 },
 [0x2D57]={
  category="lo",
  description="TIFINAGH LETTER TUAREG YAGH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D57,
 },
 [0x2D58]={
  category="lo",
  description="TIFINAGH LETTER AYER YAGH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D58,
 },
 [0x2D59]={
  category="lo",
  description="TIFINAGH LETTER YAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D59,
 },
 [0x2D5A]={
  category="lo",
  description="TIFINAGH LETTER YASS",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D5A,
 },
 [0x2D5B]={
  category="lo",
  description="TIFINAGH LETTER YASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D5B,
 },
 [0x2D5C]={
  category="lo",
  description="TIFINAGH LETTER YAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D5C,
 },
 [0x2D5D]={
  category="lo",
  description="TIFINAGH LETTER YATH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D5D,
 },
 [0x2D5E]={
  category="lo",
  description="TIFINAGH LETTER YACH",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D5E,
 },
 [0x2D5F]={
  category="lo",
  description="TIFINAGH LETTER YATT",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D5F,
 },
 [0x2D60]={
  category="lo",
  description="TIFINAGH LETTER YAV",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D60,
 },
 [0x2D61]={
  category="lo",
  description="TIFINAGH LETTER YAW",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D61,
 },
 [0x2D62]={
  category="lo",
  description="TIFINAGH LETTER YAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D62,
 },
 [0x2D63]={
  category="lo",
  description="TIFINAGH LETTER YAZ",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D63,
 },
 [0x2D64]={
  category="lo",
  description="TIFINAGH LETTER TAWELLEMET YAZ",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D64,
 },
 [0x2D65]={
  category="lo",
  description="TIFINAGH LETTER YAZZ",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D65,
 },
 [0x2D66]={
  category="lo",
  description="TIFINAGH LETTER YE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D66,
 },
 [0x2D67]={
  category="lo",
  description="TIFINAGH LETTER YO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D67,
 },
 [0x2D6F]={
  category="lm",
  description="TIFINAGH MODIFIER LETTER LABIALIZATION MARK",
  direction="l",
  linebreak="al",
  specials={ "super", 0x2D61 },
  unicodeslot=0x2D6F,
 },
 [0x2D70]={
  category="po",
  description="TIFINAGH SEPARATOR MARK",
  direction="l",
  linebreak="ba",
  unicodeslot=0x2D70,
 },
 [0x2D7F]={
  category="mn",
  description="TIFINAGH CONSONANT JOINER",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2D7F,
 },
 [0x2D80]={
  category="lo",
  description="ETHIOPIC SYLLABLE LOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D80,
 },
 [0x2D81]={
  category="lo",
  description="ETHIOPIC SYLLABLE MOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D81,
 },
 [0x2D82]={
  category="lo",
  description="ETHIOPIC SYLLABLE ROA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D82,
 },
 [0x2D83]={
  category="lo",
  description="ETHIOPIC SYLLABLE SOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D83,
 },
 [0x2D84]={
  category="lo",
  description="ETHIOPIC SYLLABLE SHOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D84,
 },
 [0x2D85]={
  category="lo",
  description="ETHIOPIC SYLLABLE BOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D85,
 },
 [0x2D86]={
  category="lo",
  description="ETHIOPIC SYLLABLE TOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D86,
 },
 [0x2D87]={
  category="lo",
  description="ETHIOPIC SYLLABLE COA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D87,
 },
 [0x2D88]={
  category="lo",
  description="ETHIOPIC SYLLABLE NOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D88,
 },
 [0x2D89]={
  category="lo",
  description="ETHIOPIC SYLLABLE NYOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D89,
 },
 [0x2D8A]={
  category="lo",
  description="ETHIOPIC SYLLABLE GLOTTAL OA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D8A,
 },
 [0x2D8B]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D8B,
 },
 [0x2D8C]={
  category="lo",
  description="ETHIOPIC SYLLABLE DOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D8C,
 },
 [0x2D8D]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D8D,
 },
 [0x2D8E]={
  category="lo",
  description="ETHIOPIC SYLLABLE JOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D8E,
 },
 [0x2D8F]={
  category="lo",
  description="ETHIOPIC SYLLABLE THOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D8F,
 },
 [0x2D90]={
  category="lo",
  description="ETHIOPIC SYLLABLE CHOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D90,
 },
 [0x2D91]={
  category="lo",
  description="ETHIOPIC SYLLABLE PHOA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D91,
 },
 [0x2D92]={
  category="lo",
  description="ETHIOPIC SYLLABLE POA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D92,
 },
 [0x2D93]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D93,
 },
 [0x2D94]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGWI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D94,
 },
 [0x2D95]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGWEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D95,
 },
 [0x2D96]={
  category="lo",
  description="ETHIOPIC SYLLABLE GGWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2D96,
 },
 [0x2DA0]={
  category="lo",
  description="ETHIOPIC SYLLABLE SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA0,
 },
 [0x2DA1]={
  category="lo",
  description="ETHIOPIC SYLLABLE SSU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA1,
 },
 [0x2DA2]={
  category="lo",
  description="ETHIOPIC SYLLABLE SSI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA2,
 },
 [0x2DA3]={
  category="lo",
  description="ETHIOPIC SYLLABLE SSAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA3,
 },
 [0x2DA4]={
  category="lo",
  description="ETHIOPIC SYLLABLE SSEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA4,
 },
 [0x2DA5]={
  category="lo",
  description="ETHIOPIC SYLLABLE SSE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA5,
 },
 [0x2DA6]={
  category="lo",
  description="ETHIOPIC SYLLABLE SSO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA6,
 },
 [0x2DA8]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA8,
 },
 [0x2DA9]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DA9,
 },
 [0x2DAA]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DAA,
 },
 [0x2DAB]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DAB,
 },
 [0x2DAC]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DAC,
 },
 [0x2DAD]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DAD,
 },
 [0x2DAE]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DAE,
 },
 [0x2DB0]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB0,
 },
 [0x2DB1]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB1,
 },
 [0x2DB2]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB2,
 },
 [0x2DB3]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZZAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB3,
 },
 [0x2DB4]={
  category="lo",
  cjkwd="w",
  description="ETHIOPIC SYLLABLE ZZEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB4,
 },
 [0x2DB5]={
  category="lo",
  cjkwd="w",
  description="ETHIOPIC SYLLABLE ZZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB5,
 },
 [0x2DB6]={
  category="lo",
  description="ETHIOPIC SYLLABLE ZZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB6,
 },
 [0x2DB8]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB8,
 },
 [0x2DB9]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DB9,
 },
 [0x2DBA]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DBA,
 },
 [0x2DBB]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHAA",
  direction="l",
  linebreak="id",
  unicodeslot=0x2DBB,
 },
 [0x2DBC]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHEE",
  direction="l",
  linebreak="id",
  unicodeslot=0x2DBC,
 },
 [0x2DBD]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DBD,
 },
 [0x2DBE]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DBE,
 },
 [0x2DC0]={
  category="lo",
  description="ETHIOPIC SYLLABLE QYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC0,
 },
 [0x2DC1]={
  category="lo",
  description="ETHIOPIC SYLLABLE QYU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC1,
 },
 [0x2DC2]={
  category="lo",
  description="ETHIOPIC SYLLABLE QYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC2,
 },
 [0x2DC3]={
  category="lo",
  description="ETHIOPIC SYLLABLE QYAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC3,
 },
 [0x2DC4]={
  category="lo",
  description="ETHIOPIC SYLLABLE QYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC4,
 },
 [0x2DC5]={
  category="lo",
  description="ETHIOPIC SYLLABLE QYE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC5,
 },
 [0x2DC6]={
  category="lo",
  description="ETHIOPIC SYLLABLE QYO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC6,
 },
 [0x2DC8]={
  category="lo",
  description="ETHIOPIC SYLLABLE KYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC8,
 },
 [0x2DC9]={
  category="lo",
  description="ETHIOPIC SYLLABLE KYU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DC9,
 },
 [0x2DCA]={
  category="lo",
  description="ETHIOPIC SYLLABLE KYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DCA,
 },
 [0x2DCB]={
  category="lo",
  description="ETHIOPIC SYLLABLE KYAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DCB,
 },
 [0x2DCC]={
  category="lo",
  description="ETHIOPIC SYLLABLE KYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DCC,
 },
 [0x2DCD]={
  category="lo",
  description="ETHIOPIC SYLLABLE KYE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DCD,
 },
 [0x2DCE]={
  category="lo",
  description="ETHIOPIC SYLLABLE KYO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DCE,
 },
 [0x2DD0]={
  category="lo",
  description="ETHIOPIC SYLLABLE XYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD0,
 },
 [0x2DD1]={
  category="lo",
  description="ETHIOPIC SYLLABLE XYU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD1,
 },
 [0x2DD2]={
  category="lo",
  description="ETHIOPIC SYLLABLE XYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD2,
 },
 [0x2DD3]={
  category="lo",
  description="ETHIOPIC SYLLABLE XYAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD3,
 },
 [0x2DD4]={
  category="lo",
  description="ETHIOPIC SYLLABLE XYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD4,
 },
 [0x2DD5]={
  category="lo",
  description="ETHIOPIC SYLLABLE XYE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD5,
 },
 [0x2DD6]={
  category="lo",
  description="ETHIOPIC SYLLABLE XYO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD6,
 },
 [0x2DD8]={
  category="lo",
  description="ETHIOPIC SYLLABLE GYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD8,
 },
 [0x2DD9]={
  category="lo",
  description="ETHIOPIC SYLLABLE GYU",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DD9,
 },
 [0x2DDA]={
  category="lo",
  description="ETHIOPIC SYLLABLE GYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DDA,
 },
 [0x2DDB]={
  category="lo",
  description="ETHIOPIC SYLLABLE GYAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DDB,
 },
 [0x2DDC]={
  category="lo",
  description="ETHIOPIC SYLLABLE GYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DDC,
 },
 [0x2DDD]={
  category="lo",
  description="ETHIOPIC SYLLABLE GYE",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DDD,
 },
 [0x2DDE]={
  category="lo",
  description="ETHIOPIC SYLLABLE GYO",
  direction="l",
  linebreak="al",
  unicodeslot=0x2DDE,
 },
 [0x2DE0]={
  category="mn",
  description="COMBINING CYRILLIC LETTER BE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE0,
 },
 [0x2DE1]={
  category="mn",
  description="COMBINING CYRILLIC LETTER VE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE1,
 },
 [0x2DE2]={
  category="mn",
  description="COMBINING CYRILLIC LETTER GHE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE2,
 },
 [0x2DE3]={
  category="mn",
  description="COMBINING CYRILLIC LETTER DE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE3,
 },
 [0x2DE4]={
  category="mn",
  description="COMBINING CYRILLIC LETTER ZHE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE4,
 },
 [0x2DE5]={
  category="mn",
  description="COMBINING CYRILLIC LETTER ZE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE5,
 },
 [0x2DE6]={
  category="mn",
  description="COMBINING CYRILLIC LETTER KA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE6,
 },
 [0x2DE7]={
  category="mn",
  description="COMBINING CYRILLIC LETTER EL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE7,
 },
 [0x2DE8]={
  category="mn",
  description="COMBINING CYRILLIC LETTER EM",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE8,
 },
 [0x2DE9]={
  category="mn",
  description="COMBINING CYRILLIC LETTER EN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DE9,
 },
 [0x2DEA]={
  category="mn",
  description="COMBINING CYRILLIC LETTER O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DEA,
 },
 [0x2DEB]={
  category="mn",
  description="COMBINING CYRILLIC LETTER PE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DEB,
 },
 [0x2DEC]={
  category="mn",
  description="COMBINING CYRILLIC LETTER ER",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DEC,
 },
 [0x2DED]={
  category="mn",
  description="COMBINING CYRILLIC LETTER ES",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DED,
 },
 [0x2DEE]={
  category="mn",
  description="COMBINING CYRILLIC LETTER TE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DEE,
 },
 [0x2DEF]={
  category="mn",
  description="COMBINING CYRILLIC LETTER HA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DEF,
 },
 [0x2DF0]={
  category="mn",
  description="COMBINING CYRILLIC LETTER TSE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF0,
 },
 [0x2DF1]={
  category="mn",
  description="COMBINING CYRILLIC LETTER CHE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF1,
 },
 [0x2DF2]={
  category="mn",
  description="COMBINING CYRILLIC LETTER SHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF2,
 },
 [0x2DF3]={
  category="mn",
  description="COMBINING CYRILLIC LETTER SHCHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF3,
 },
 [0x2DF4]={
  category="mn",
  description="COMBINING CYRILLIC LETTER FITA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF4,
 },
 [0x2DF5]={
  category="mn",
  description="COMBINING CYRILLIC LETTER ES-TE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF5,
 },
 [0x2DF6]={
  category="mn",
  cjkwd="w",
  description="COMBINING CYRILLIC LETTER A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF6,
 },
 [0x2DF7]={
  category="mn",
  cjkwd="w",
  description="COMBINING CYRILLIC LETTER IE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF7,
 },
 [0x2DF8]={
  category="mn",
  description="COMBINING CYRILLIC LETTER DJERV",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF8,
 },
 [0x2DF9]={
  category="mn",
  description="COMBINING CYRILLIC LETTER MONOGRAPH UK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DF9,
 },
 [0x2DFA]={
  category="mn",
  description="COMBINING CYRILLIC LETTER YAT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DFA,
 },
 [0x2DFB]={
  category="mn",
  description="COMBINING CYRILLIC LETTER YU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DFB,
 },
 [0x2DFC]={
  category="mn",
  description="COMBINING CYRILLIC LETTER IOTIFIED A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DFC,
 },
 [0x2DFD]={
  category="mn",
  description="COMBINING CYRILLIC LETTER LITTLE YUS",
  direction="nsm",
  linebreak="id",
  unicodeslot=0x2DFD,
 },
 [0x2DFE]={
  category="mn",
  description="COMBINING CYRILLIC LETTER BIG YUS",
  direction="nsm",
  linebreak="id",
  unicodeslot=0x2DFE,
 },
 [0x2DFF]={
  category="mn",
  description="COMBINING CYRILLIC LETTER IOTIFIED BIG YUS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x2DFF,
 },
 [0x2E00]={
  category="po",
  description="RIGHT ANGLE SUBSTITUTION MARKER",
  direction="on",
  linebreak="qu",
  unicodeslot=0x2E00,
 },
 [0x2E01]={
  category="po",
  description="RIGHT ANGLE DOTTED SUBSTITUTION MARKER",
  direction="on",
  linebreak="qu",
  unicodeslot=0x2E01,
 },
 [0x2E02]={
  category="pi",
  description="LEFT SUBSTITUTION BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E03,
  unicodeslot=0x2E02,
 },
 [0x2E03]={
  category="pf",
  description="RIGHT SUBSTITUTION BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E02,
  unicodeslot=0x2E03,
 },
 [0x2E04]={
  category="pi",
  description="LEFT DOTTED SUBSTITUTION BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E05,
  unicodeslot=0x2E04,
 },
 [0x2E05]={
  category="pf",
  description="RIGHT DOTTED SUBSTITUTION BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E04,
  unicodeslot=0x2E05,
 },
 [0x2E06]={
  category="po",
  description="RAISED INTERPOLATION MARKER",
  direction="on",
  linebreak="qu",
  unicodeslot=0x2E06,
 },
 [0x2E07]={
  category="po",
  description="RAISED DOTTED INTERPOLATION MARKER",
  direction="on",
  linebreak="qu",
  unicodeslot=0x2E07,
 },
 [0x2E08]={
  category="po",
  description="DOTTED TRANSPOSITION MARKER",
  direction="on",
  linebreak="qu",
  unicodeslot=0x2E08,
 },
 [0x2E09]={
  category="pi",
  description="LEFT TRANSPOSITION BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E0A,
  unicodeslot=0x2E09,
 },
 [0x2E0A]={
  category="pf",
  description="RIGHT TRANSPOSITION BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E09,
  unicodeslot=0x2E0A,
 },
 [0x2E0B]={
  category="po",
  description="RAISED SQUARE",
  direction="on",
  linebreak="qu",
  unicodeslot=0x2E0B,
 },
 [0x2E0C]={
  category="pi",
  description="LEFT RAISED OMISSION BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E0D,
  unicodeslot=0x2E0C,
 },
 [0x2E0D]={
  category="pf",
  description="RIGHT RAISED OMISSION BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E0C,
  unicodeslot=0x2E0D,
 },
 [0x2E0E]={
  category="po",
  description="EDITORIAL CORONIS",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E0E,
 },
 [0x2E0F]={
  category="po",
  description="PARAGRAPHOS",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E0F,
 },
 [0x2E10]={
  category="po",
  description="FORKED PARAGRAPHOS",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E10,
 },
 [0x2E11]={
  category="po",
  description="REVERSED FORKED PARAGRAPHOS",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E11,
 },
 [0x2E12]={
  category="po",
  description="HYPODIASTOLE",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E12,
 },
 [0x2E13]={
  category="po",
  description="DOTTED OBELOS",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E13,
 },
 [0x2E14]={
  category="po",
  description="DOWNWARDS ANCORA",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E14,
 },
 [0x2E15]={
  category="po",
  description="UPWARDS ANCORA",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E15,
 },
 [0x2E16]={
  category="po",
  description="DOTTED RIGHT-POINTING ANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E16,
 },
 [0x2E17]={
  category="pd",
  description="DOUBLE OBLIQUE HYPHEN",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E17,
 },
 [0x2E18]={
  category="po",
  description="INVERTED INTERROBANG",
  direction="on",
  linebreak="op",
  unicodeslot=0x2E18,
 },
 [0x2E19]={
  category="po",
  description="PALM BRANCH",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E19,
 },
 [0x2E1A]={
  category="pd",
  description="HYPHEN WITH DIAERESIS",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E1A,
 },
 [0x2E1B]={
  category="po",
  description="TILDE WITH RING ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E1B,
 },
 [0x2E1C]={
  category="pi",
  description="LEFT LOW PARAPHRASE BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E1D,
  unicodeslot=0x2E1C,
 },
 [0x2E1D]={
  category="pf",
  description="RIGHT LOW PARAPHRASE BRACKET",
  direction="on",
  linebreak="qu",
  mirror=0x2E1C,
  unicodeslot=0x2E1D,
 },
 [0x2E1E]={
  category="po",
  description="TILDE WITH DOT ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E1E,
 },
 [0x2E1F]={
  category="po",
  description="TILDE WITH DOT BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E1F,
 },
 [0x2E20]={
  category="pi",
  description="LEFT VERTICAL BAR WITH QUILL",
  direction="on",
  linebreak="qu",
  mirror=0x2E21,
  unicodeslot=0x2E20,
 },
 [0x2E21]={
  category="pf",
  description="RIGHT VERTICAL BAR WITH QUILL",
  direction="on",
  linebreak="qu",
  mirror=0x2E20,
  unicodeslot=0x2E21,
 },
 [0x2E22]={
  category="ps",
  description="TOP LEFT HALF BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x2E23,
  unicodeslot=0x2E22,
 },
 [0x2E23]={
  category="pe",
  description="TOP RIGHT HALF BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2E22,
  unicodeslot=0x2E23,
 },
 [0x2E24]={
  category="ps",
  description="BOTTOM LEFT HALF BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x2E25,
  unicodeslot=0x2E24,
 },
 [0x2E25]={
  category="pe",
  description="BOTTOM RIGHT HALF BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2E24,
  unicodeslot=0x2E25,
 },
 [0x2E26]={
  category="ps",
  description="LEFT SIDEWAYS U BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x2E27,
  unicodeslot=0x2E26,
 },
 [0x2E27]={
  category="pe",
  description="RIGHT SIDEWAYS U BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x2E26,
  unicodeslot=0x2E27,
 },
 [0x2E28]={
  category="ps",
  description="LEFT DOUBLE PARENTHESIS",
  direction="on",
  linebreak="op",
  mirror=0x2E29,
  unicodeslot=0x2E28,
 },
 [0x2E29]={
  category="pe",
  description="RIGHT DOUBLE PARENTHESIS",
  direction="on",
  linebreak="cl",
  mirror=0x2E28,
  unicodeslot=0x2E29,
 },
 [0x2E2A]={
  category="po",
  description="TWO DOTS OVER ONE DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E2A,
 },
 [0x2E2B]={
  category="po",
  description="ONE DOT OVER TWO DOTS PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E2B,
 },
 [0x2E2C]={
  category="po",
  description="SQUARED FOUR DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E2C,
 },
 [0x2E2D]={
  category="po",
  description="FIVE DOT MARK",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E2D,
 },
 [0x2E2E]={
  category="po",
  description="REVERSED QUESTION MARK",
  direction="on",
  linebreak="ex",
  unicodeslot=0x2E2E,
 },
 [0x2E2F]={
  category="lm",
  description="VERTICAL TILDE",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E2F,
 },
 [0x2E30]={
  category="po",
  description="RING POINT",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E30,
 },
 [0x2E31]={
  category="po",
  description="WORD SEPARATOR MIDDLE DOT",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E31,
 },
 [0x2E32]={
  category="po",
  description="TURNED COMMA",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E32,
 },
 [0x2E33]={
  category="po",
  description="RAISED DOT",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E33,
 },
 [0x2E34]={
  category="po",
  description="RAISED COMMA",
  direction="on",
  linebreak="ba",
  unicodeslot=0x2E34,
 },
 [0x2E35]={
  category="po",
  description="TURNED SEMICOLON",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E35,
 },
 [0x2E36]={
  category="po",
  description="DAGGER WITH LEFT GUARD",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E36,
 },
 [0x2E37]={
  category="po",
  description="DAGGER WITH RIGHT GUARD",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E37,
 },
 [0x2E38]={
  category="po",
  description="TURNED DAGGER",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E38,
 },
 [0x2E39]={
  category="po",
  description="TOP HALF SECTION SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x2E39,
 },
 [0x2E3A]={
  category="pd",
  description="TWO-EM DASH",
  direction="on",
  linebreak="b2",
  unicodeslot=0x2E3A,
 },
 [0x2E3B]={
  category="pd",
  description="THREE-EM DASH",
  direction="on",
  linebreak="b2",
  unicodeslot=0x2E3B,
 },
 [0x2E80]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL REPEAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E80,
 },
 [0x2E81]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL CLIFF",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E81,
 },
 [0x2E82]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SECOND ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E82,
 },
 [0x2E83]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SECOND TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E83,
 },
 [0x2E84]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SECOND THREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E84,
 },
 [0x2E85]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL PERSON",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E85,
 },
 [0x2E86]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL BOX",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E86,
 },
 [0x2E87]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL TABLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E87,
 },
 [0x2E88]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL KNIFE ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E88,
 },
 [0x2E89]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL KNIFE TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E89,
 },
 [0x2E8A]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL DIVINATION",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E8A,
 },
 [0x2E8B]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SEAL",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E8B,
 },
 [0x2E8C]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SMALL ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E8C,
 },
 [0x2E8D]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SMALL TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E8D,
 },
 [0x2E8E]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL LAME ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E8E,
 },
 [0x2E8F]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL LAME TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E8F,
 },
 [0x2E90]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL LAME THREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E90,
 },
 [0x2E91]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL LAME FOUR",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E91,
 },
 [0x2E92]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SNAKE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E92,
 },
 [0x2E93]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL THREAD",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E93,
 },
 [0x2E94]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SNOUT ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E94,
 },
 [0x2E95]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SNOUT TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E95,
 },
 [0x2E96]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL HEART ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E96,
 },
 [0x2E97]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL HEART TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E97,
 },
 [0x2E98]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL HAND",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E98,
 },
 [0x2E99]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL RAP",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E99,
 },
 [0x2E9B]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL CHOKE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E9B,
 },
 [0x2E9C]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SUN",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E9C,
 },
 [0x2E9D]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL MOON",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E9D,
 },
 [0x2E9E]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL DEATH",
  direction="on",
  linebreak="id",
  unicodeslot=0x2E9E,
 },
 [0x2E9F]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL MOTHER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6BCD },
  unicodeslot=0x2E9F,
 },
 [0x2EA0]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL CIVILIAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA0,
 },
 [0x2EA1]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL WATER ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA1,
 },
 [0x2EA2]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL WATER TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA2,
 },
 [0x2EA3]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL FIRE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA3,
 },
 [0x2EA4]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL PAW ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA4,
 },
 [0x2EA5]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL PAW TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA5,
 },
 [0x2EA6]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SIMPLIFIED HALF TREE TRUNK",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA6,
 },
 [0x2EA7]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL COW",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA7,
 },
 [0x2EA8]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL DOG",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA8,
 },
 [0x2EA9]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL JADE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EA9,
 },
 [0x2EAA]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL BOLT OF CLOTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EAA,
 },
 [0x2EAB]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL EYE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EAB,
 },
 [0x2EAC]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SPIRIT ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EAC,
 },
 [0x2EAD]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SPIRIT TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EAD,
 },
 [0x2EAE]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL BAMBOO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EAE,
 },
 [0x2EAF]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SILK",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EAF,
 },
 [0x2EB0]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED SILK",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB0,
 },
 [0x2EB1]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL NET ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB1,
 },
 [0x2EB2]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL NET TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB2,
 },
 [0x2EB3]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL NET THREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB3,
 },
 [0x2EB4]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL NET FOUR",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB4,
 },
 [0x2EB5]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL MESH",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB5,
 },
 [0x2EB6]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SHEEP",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB6,
 },
 [0x2EB7]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL RAM",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB7,
 },
 [0x2EB8]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL EWE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB8,
 },
 [0x2EB9]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL OLD",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EB9,
 },
 [0x2EBA]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL BRUSH ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EBA,
 },
 [0x2EBB]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL BRUSH TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EBB,
 },
 [0x2EBC]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL MEAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EBC,
 },
 [0x2EBD]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL MORTAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EBD,
 },
 [0x2EBE]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL GRASS ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EBE,
 },
 [0x2EBF]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL GRASS TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EBF,
 },
 [0x2EC0]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL GRASS THREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC0,
 },
 [0x2EC1]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL TIGER",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC1,
 },
 [0x2EC2]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL CLOTHES",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC2,
 },
 [0x2EC3]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL WEST ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC3,
 },
 [0x2EC4]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL WEST TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC4,
 },
 [0x2EC5]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED SEE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC5,
 },
 [0x2EC6]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SIMPLIFIED HORN",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC6,
 },
 [0x2EC7]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL HORN",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC7,
 },
 [0x2EC8]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED SPEECH",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC8,
 },
 [0x2EC9]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED SHELL",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EC9,
 },
 [0x2ECA]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL FOOT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ECA,
 },
 [0x2ECB]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED CART",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ECB,
 },
 [0x2ECC]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SIMPLIFIED WALK",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ECC,
 },
 [0x2ECD]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL WALK ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ECD,
 },
 [0x2ECE]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL WALK TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ECE,
 },
 [0x2ECF]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL CITY",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ECF,
 },
 [0x2ED0]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED GOLD",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED0,
 },
 [0x2ED1]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL LONG ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED1,
 },
 [0x2ED2]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL LONG TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED2,
 },
 [0x2ED3]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED LONG",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED3,
 },
 [0x2ED4]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED GATE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED4,
 },
 [0x2ED5]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL MOUND ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED5,
 },
 [0x2ED6]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL MOUND TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED6,
 },
 [0x2ED7]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL RAIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED7,
 },
 [0x2ED8]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL BLUE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED8,
 },
 [0x2ED9]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED TANNED LEATHER",
  direction="on",
  linebreak="id",
  unicodeslot=0x2ED9,
 },
 [0x2EDA]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED LEAF",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EDA,
 },
 [0x2EDB]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED WIND",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EDB,
 },
 [0x2EDC]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED FLY",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EDC,
 },
 [0x2EDD]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL EAT ONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EDD,
 },
 [0x2EDE]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL EAT TWO",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EDE,
 },
 [0x2EDF]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL EAT THREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EDF,
 },
 [0x2EE0]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED EAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE0,
 },
 [0x2EE1]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL HEAD",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE1,
 },
 [0x2EE2]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED HORSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE2,
 },
 [0x2EE3]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL BONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE3,
 },
 [0x2EE4]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL GHOST",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE4,
 },
 [0x2EE5]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED FISH",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE5,
 },
 [0x2EE6]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED BIRD",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE6,
 },
 [0x2EE7]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED SALT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE7,
 },
 [0x2EE8]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SIMPLIFIED WHEAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE8,
 },
 [0x2EE9]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL SIMPLIFIED YELLOW",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EE9,
 },
 [0x2EEA]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED FROG",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EEA,
 },
 [0x2EEB]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL J-SIMPLIFIED EVEN",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EEB,
 },
 [0x2EEC]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED EVEN",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EEC,
 },
 [0x2EED]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL J-SIMPLIFIED TOOTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EED,
 },
 [0x2EEE]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED TOOTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EEE,
 },
 [0x2EEF]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL J-SIMPLIFIED DRAGON",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EEF,
 },
 [0x2EF0]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED DRAGON",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EF0,
 },
 [0x2EF1]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL TURTLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EF1,
 },
 [0x2EF2]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL J-SIMPLIFIED TURTLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2EF2,
 },
 [0x2EF3]={
  category="so",
  cjkwd="w",
  description="CJK RADICAL C-SIMPLIFIED TURTLE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F9F },
  unicodeslot=0x2EF3,
 },
 [0x2F00]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL ONE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4E00 },
  unicodeslot=0x2F00,
 },
 [0x2F01]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4E28 },
  unicodeslot=0x2F01,
 },
 [0x2F02]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DOT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4E36 },
  unicodeslot=0x2F02,
 },
 [0x2F03]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SLASH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4E3F },
  unicodeslot=0x2F03,
 },
 [0x2F04]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SECOND",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4E59 },
  unicodeslot=0x2F04,
 },
 [0x2F05]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HOOK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4E85 },
  unicodeslot=0x2F05,
 },
 [0x2F06]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TWO",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4E8C },
  unicodeslot=0x2F06,
 },
 [0x2F07]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LID",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4EA0 },
  unicodeslot=0x2F07,
 },
 [0x2F08]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MAN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x4EBA },
  unicodeslot=0x2F08,
 },
 [0x2F09]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LEGS",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x513F },
  unicodeslot=0x2F09,
 },
 [0x2F0A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL ENTER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5165 },
  unicodeslot=0x2F0A,
 },
 [0x2F0B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL EIGHT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x516B },
  unicodeslot=0x2F0B,
 },
 [0x2F0C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DOWN BOX",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5182 },
  unicodeslot=0x2F0C,
 },
 [0x2F0D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL COVER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5196 },
  unicodeslot=0x2F0D,
 },
 [0x2F0E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL ICE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x51AB },
  unicodeslot=0x2F0E,
 },
 [0x2F0F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TABLE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x51E0 },
  unicodeslot=0x2F0F,
 },
 [0x2F10]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL OPEN BOX",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x51F5 },
  unicodeslot=0x2F10,
 },
 [0x2F11]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL KNIFE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5200 },
  unicodeslot=0x2F11,
 },
 [0x2F12]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL POWER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x529B },
  unicodeslot=0x2F12,
 },
 [0x2F13]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WRAP",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x52F9 },
  unicodeslot=0x2F13,
 },
 [0x2F14]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SPOON",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5315 },
  unicodeslot=0x2F14,
 },
 [0x2F15]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL RIGHT OPEN BOX",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x531A },
  unicodeslot=0x2F15,
 },
 [0x2F16]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HIDING ENCLOSURE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5338 },
  unicodeslot=0x2F16,
 },
 [0x2F17]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TEN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5341 },
  unicodeslot=0x2F17,
 },
 [0x2F18]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DIVINATION",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x535C },
  unicodeslot=0x2F18,
 },
 [0x2F19]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SEAL",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5369 },
  unicodeslot=0x2F19,
 },
 [0x2F1A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CLIFF",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5382 },
  unicodeslot=0x2F1A,
 },
 [0x2F1B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL PRIVATE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x53B6 },
  unicodeslot=0x2F1B,
 },
 [0x2F1C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL AGAIN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x53C8 },
  unicodeslot=0x2F1C,
 },
 [0x2F1D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MOUTH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x53E3 },
  unicodeslot=0x2F1D,
 },
 [0x2F1E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL ENCLOSURE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x56D7 },
  unicodeslot=0x2F1E,
 },
 [0x2F1F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL EARTH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x571F },
  unicodeslot=0x2F1F,
 },
 [0x2F20]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SCHOLAR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x58EB },
  unicodeslot=0x2F20,
 },
 [0x2F21]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL GO",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5902 },
  unicodeslot=0x2F21,
 },
 [0x2F22]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL GO SLOWLY",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x590A },
  unicodeslot=0x2F22,
 },
 [0x2F23]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL EVENING",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5915 },
  unicodeslot=0x2F23,
 },
 [0x2F24]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BIG",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5927 },
  unicodeslot=0x2F24,
 },
 [0x2F25]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WOMAN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5973 },
  unicodeslot=0x2F25,
 },
 [0x2F26]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CHILD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5B50 },
  unicodeslot=0x2F26,
 },
 [0x2F27]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL ROOF",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5B80 },
  unicodeslot=0x2F27,
 },
 [0x2F28]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL INCH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5BF8 },
  unicodeslot=0x2F28,
 },
 [0x2F29]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SMALL",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5C0F },
  unicodeslot=0x2F29,
 },
 [0x2F2A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LAME",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5C22 },
  unicodeslot=0x2F2A,
 },
 [0x2F2B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CORPSE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5C38 },
  unicodeslot=0x2F2B,
 },
 [0x2F2C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SPROUT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5C6E },
  unicodeslot=0x2F2C,
 },
 [0x2F2D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MOUNTAIN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5C71 },
  unicodeslot=0x2F2D,
 },
 [0x2F2E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL RIVER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5DDB },
  unicodeslot=0x2F2E,
 },
 [0x2F2F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WORK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5DE5 },
  unicodeslot=0x2F2F,
 },
 [0x2F30]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL ONESELF",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5DF1 },
  unicodeslot=0x2F30,
 },
 [0x2F31]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TURBAN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5DFE },
  unicodeslot=0x2F31,
 },
 [0x2F32]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DRY",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5E72 },
  unicodeslot=0x2F32,
 },
 [0x2F33]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SHORT THREAD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5E7A },
  unicodeslot=0x2F33,
 },
 [0x2F34]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DOTTED CLIFF",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5E7F },
  unicodeslot=0x2F34,
 },
 [0x2F35]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LONG STRIDE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5EF4 },
  unicodeslot=0x2F35,
 },
 [0x2F36]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TWO HANDS",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5EFE },
  unicodeslot=0x2F36,
 },
 [0x2F37]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SHOOT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5F0B },
  unicodeslot=0x2F37,
 },
 [0x2F38]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BOW",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5F13 },
  unicodeslot=0x2F38,
 },
 [0x2F39]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SNOUT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5F50 },
  unicodeslot=0x2F39,
 },
 [0x2F3A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BRISTLE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5F61 },
  unicodeslot=0x2F3A,
 },
 [0x2F3B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL STEP",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5F73 },
  unicodeslot=0x2F3B,
 },
 [0x2F3C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HEART",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x5FC3 },
  unicodeslot=0x2F3C,
 },
 [0x2F3D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HALBERD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6208 },
  unicodeslot=0x2F3D,
 },
 [0x2F3E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DOOR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6236 },
  unicodeslot=0x2F3E,
 },
 [0x2F3F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HAND",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x624B },
  unicodeslot=0x2F3F,
 },
 [0x2F40]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BRANCH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x652F },
  unicodeslot=0x2F40,
 },
 [0x2F41]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL RAP",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6534 },
  unicodeslot=0x2F41,
 },
 [0x2F42]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SCRIPT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6587 },
  unicodeslot=0x2F42,
 },
 [0x2F43]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DIPPER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6597 },
  unicodeslot=0x2F43,
 },
 [0x2F44]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL AXE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x65A4 },
  unicodeslot=0x2F44,
 },
 [0x2F45]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SQUARE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x65B9 },
  unicodeslot=0x2F45,
 },
 [0x2F46]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL NOT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x65E0 },
  unicodeslot=0x2F46,
 },
 [0x2F47]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SUN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x65E5 },
  unicodeslot=0x2F47,
 },
 [0x2F48]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SAY",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x66F0 },
  unicodeslot=0x2F48,
 },
 [0x2F49]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MOON",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6708 },
  unicodeslot=0x2F49,
 },
 [0x2F4A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TREE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6728 },
  unicodeslot=0x2F4A,
 },
 [0x2F4B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LACK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6B20 },
  unicodeslot=0x2F4B,
 },
 [0x2F4C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL STOP",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6B62 },
  unicodeslot=0x2F4C,
 },
 [0x2F4D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DEATH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6B79 },
  unicodeslot=0x2F4D,
 },
 [0x2F4E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WEAPON",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6BB3 },
  unicodeslot=0x2F4E,
 },
 [0x2F4F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DO NOT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6BCB },
  unicodeslot=0x2F4F,
 },
 [0x2F50]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL COMPARE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6BD4 },
  unicodeslot=0x2F50,
 },
 [0x2F51]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FUR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6BDB },
  unicodeslot=0x2F51,
 },
 [0x2F52]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CLAN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6C0F },
  unicodeslot=0x2F52,
 },
 [0x2F53]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL STEAM",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6C14 },
  unicodeslot=0x2F53,
 },
 [0x2F54]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WATER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x6C34 },
  unicodeslot=0x2F54,
 },
 [0x2F55]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FIRE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x706B },
  unicodeslot=0x2F55,
 },
 [0x2F56]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CLAW",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x722A },
  unicodeslot=0x2F56,
 },
 [0x2F57]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FATHER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7236 },
  unicodeslot=0x2F57,
 },
 [0x2F58]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DOUBLE X",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x723B },
  unicodeslot=0x2F58,
 },
 [0x2F59]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HALF TREE TRUNK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x723F },
  unicodeslot=0x2F59,
 },
 [0x2F5A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SLICE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7247 },
  unicodeslot=0x2F5A,
 },
 [0x2F5B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FANG",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7259 },
  unicodeslot=0x2F5B,
 },
 [0x2F5C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL COW",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x725B },
  unicodeslot=0x2F5C,
 },
 [0x2F5D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DOG",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x72AC },
  unicodeslot=0x2F5D,
 },
 [0x2F5E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL PROFOUND",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7384 },
  unicodeslot=0x2F5E,
 },
 [0x2F5F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL JADE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7389 },
  unicodeslot=0x2F5F,
 },
 [0x2F60]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MELON",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x74DC },
  unicodeslot=0x2F60,
 },
 [0x2F61]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TILE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x74E6 },
  unicodeslot=0x2F61,
 },
 [0x2F62]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SWEET",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7518 },
  unicodeslot=0x2F62,
 },
 [0x2F63]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LIFE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x751F },
  unicodeslot=0x2F63,
 },
 [0x2F64]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL USE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7528 },
  unicodeslot=0x2F64,
 },
 [0x2F65]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FIELD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7530 },
  unicodeslot=0x2F65,
 },
 [0x2F66]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BOLT OF CLOTH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x758B },
  unicodeslot=0x2F66,
 },
 [0x2F67]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SICKNESS",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7592 },
  unicodeslot=0x2F67,
 },
 [0x2F68]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DOTTED TENT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7676 },
  unicodeslot=0x2F68,
 },
 [0x2F69]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WHITE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x767D },
  unicodeslot=0x2F69,
 },
 [0x2F6A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SKIN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x76AE },
  unicodeslot=0x2F6A,
 },
 [0x2F6B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DISH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x76BF },
  unicodeslot=0x2F6B,
 },
 [0x2F6C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL EYE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x76EE },
  unicodeslot=0x2F6C,
 },
 [0x2F6D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SPEAR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x77DB },
  unicodeslot=0x2F6D,
 },
 [0x2F6E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL ARROW",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x77E2 },
  unicodeslot=0x2F6E,
 },
 [0x2F6F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL STONE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x77F3 },
  unicodeslot=0x2F6F,
 },
 [0x2F70]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SPIRIT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x793A },
  unicodeslot=0x2F70,
 },
 [0x2F71]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TRACK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x79B8 },
  unicodeslot=0x2F71,
 },
 [0x2F72]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL GRAIN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x79BE },
  unicodeslot=0x2F72,
 },
 [0x2F73]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CAVE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7A74 },
  unicodeslot=0x2F73,
 },
 [0x2F74]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL STAND",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7ACB },
  unicodeslot=0x2F74,
 },
 [0x2F75]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BAMBOO",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7AF9 },
  unicodeslot=0x2F75,
 },
 [0x2F76]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL RICE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7C73 },
  unicodeslot=0x2F76,
 },
 [0x2F77]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SILK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7CF8 },
  unicodeslot=0x2F77,
 },
 [0x2F78]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL JAR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7F36 },
  unicodeslot=0x2F78,
 },
 [0x2F79]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL NET",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7F51 },
  unicodeslot=0x2F79,
 },
 [0x2F7A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SHEEP",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7F8A },
  unicodeslot=0x2F7A,
 },
 [0x2F7B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FEATHER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x7FBD },
  unicodeslot=0x2F7B,
 },
 [0x2F7C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL OLD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8001 },
  unicodeslot=0x2F7C,
 },
 [0x2F7D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL AND",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x800C },
  unicodeslot=0x2F7D,
 },
 [0x2F7E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL PLOW",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8012 },
  unicodeslot=0x2F7E,
 },
 [0x2F7F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL EAR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8033 },
  unicodeslot=0x2F7F,
 },
 [0x2F80]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BRUSH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x807F },
  unicodeslot=0x2F80,
 },
 [0x2F81]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MEAT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8089 },
  unicodeslot=0x2F81,
 },
 [0x2F82]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MINISTER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x81E3 },
  unicodeslot=0x2F82,
 },
 [0x2F83]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SELF",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x81EA },
  unicodeslot=0x2F83,
 },
 [0x2F84]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL ARRIVE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x81F3 },
  unicodeslot=0x2F84,
 },
 [0x2F85]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MORTAR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x81FC },
  unicodeslot=0x2F85,
 },
 [0x2F86]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TONGUE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x820C },
  unicodeslot=0x2F86,
 },
 [0x2F87]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL OPPOSE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x821B },
  unicodeslot=0x2F87,
 },
 [0x2F88]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BOAT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x821F },
  unicodeslot=0x2F88,
 },
 [0x2F89]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL STOPPING",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x826E },
  unicodeslot=0x2F89,
 },
 [0x2F8A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL COLOR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8272 },
  unicodeslot=0x2F8A,
 },
 [0x2F8B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL GRASS",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8278 },
  unicodeslot=0x2F8B,
 },
 [0x2F8C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TIGER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x864D },
  unicodeslot=0x2F8C,
 },
 [0x2F8D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL INSECT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x866B },
  unicodeslot=0x2F8D,
 },
 [0x2F8E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BLOOD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8840 },
  unicodeslot=0x2F8E,
 },
 [0x2F8F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WALK ENCLOSURE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x884C },
  unicodeslot=0x2F8F,
 },
 [0x2F90]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CLOTHES",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8863 },
  unicodeslot=0x2F90,
 },
 [0x2F91]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WEST",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x897E },
  unicodeslot=0x2F91,
 },
 [0x2F92]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SEE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x898B },
  unicodeslot=0x2F92,
 },
 [0x2F93]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HORN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x89D2 },
  unicodeslot=0x2F93,
 },
 [0x2F94]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SPEECH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8A00 },
  unicodeslot=0x2F94,
 },
 [0x2F95]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL VALLEY",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8C37 },
  unicodeslot=0x2F95,
 },
 [0x2F96]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BEAN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8C46 },
  unicodeslot=0x2F96,
 },
 [0x2F97]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL PIG",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8C55 },
  unicodeslot=0x2F97,
 },
 [0x2F98]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BADGER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8C78 },
  unicodeslot=0x2F98,
 },
 [0x2F99]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SHELL",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8C9D },
  unicodeslot=0x2F99,
 },
 [0x2F9A]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL RED",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8D64 },
  unicodeslot=0x2F9A,
 },
 [0x2F9B]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL RUN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8D70 },
  unicodeslot=0x2F9B,
 },
 [0x2F9C]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FOOT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8DB3 },
  unicodeslot=0x2F9C,
 },
 [0x2F9D]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BODY",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8EAB },
  unicodeslot=0x2F9D,
 },
 [0x2F9E]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CART",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8ECA },
  unicodeslot=0x2F9E,
 },
 [0x2F9F]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BITTER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8F9B },
  unicodeslot=0x2F9F,
 },
 [0x2FA0]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MORNING",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8FB0 },
  unicodeslot=0x2FA0,
 },
 [0x2FA1]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WALK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x8FB5 },
  unicodeslot=0x2FA1,
 },
 [0x2FA2]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CITY",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9091 },
  unicodeslot=0x2FA2,
 },
 [0x2FA3]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9149 },
  unicodeslot=0x2FA3,
 },
 [0x2FA4]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DISTINGUISH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x91C6 },
  unicodeslot=0x2FA4,
 },
 [0x2FA5]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL VILLAGE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x91CC },
  unicodeslot=0x2FA5,
 },
 [0x2FA6]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL GOLD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x91D1 },
  unicodeslot=0x2FA6,
 },
 [0x2FA7]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LONG",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9577 },
  unicodeslot=0x2FA7,
 },
 [0x2FA8]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL GATE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9580 },
  unicodeslot=0x2FA8,
 },
 [0x2FA9]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MOUND",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x961C },
  unicodeslot=0x2FA9,
 },
 [0x2FAA]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SLAVE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x96B6 },
  unicodeslot=0x2FAA,
 },
 [0x2FAB]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SHORT TAILED BIRD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x96B9 },
  unicodeslot=0x2FAB,
 },
 [0x2FAC]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL RAIN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x96E8 },
  unicodeslot=0x2FAC,
 },
 [0x2FAD]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BLUE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9751 },
  unicodeslot=0x2FAD,
 },
 [0x2FAE]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WRONG",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x975E },
  unicodeslot=0x2FAE,
 },
 [0x2FAF]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FACE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9762 },
  unicodeslot=0x2FAF,
 },
 [0x2FB0]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LEATHER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9769 },
  unicodeslot=0x2FB0,
 },
 [0x2FB1]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TANNED LEATHER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x97CB },
  unicodeslot=0x2FB1,
 },
 [0x2FB2]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LEEK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x97ED },
  unicodeslot=0x2FB2,
 },
 [0x2FB3]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SOUND",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x97F3 },
  unicodeslot=0x2FB3,
 },
 [0x2FB4]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL LEAF",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9801 },
  unicodeslot=0x2FB4,
 },
 [0x2FB5]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WIND",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x98A8 },
  unicodeslot=0x2FB5,
 },
 [0x2FB6]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FLY",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x98DB },
  unicodeslot=0x2FB6,
 },
 [0x2FB7]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL EAT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x98DF },
  unicodeslot=0x2FB7,
 },
 [0x2FB8]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HEAD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9996 },
  unicodeslot=0x2FB8,
 },
 [0x2FB9]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FRAGRANT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9999 },
  unicodeslot=0x2FB9,
 },
 [0x2FBA]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HORSE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x99AC },
  unicodeslot=0x2FBA,
 },
 [0x2FBB]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BONE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9AA8 },
  unicodeslot=0x2FBB,
 },
 [0x2FBC]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TALL",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9AD8 },
  unicodeslot=0x2FBC,
 },
 [0x2FBD]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HAIR",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9ADF },
  unicodeslot=0x2FBD,
 },
 [0x2FBE]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FIGHT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9B25 },
  unicodeslot=0x2FBE,
 },
 [0x2FBF]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SACRIFICIAL WINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9B2F },
  unicodeslot=0x2FBF,
 },
 [0x2FC0]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL CAULDRON",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9B32 },
  unicodeslot=0x2FC0,
 },
 [0x2FC1]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL GHOST",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9B3C },
  unicodeslot=0x2FC1,
 },
 [0x2FC2]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FISH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9B5A },
  unicodeslot=0x2FC2,
 },
 [0x2FC3]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BIRD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9CE5 },
  unicodeslot=0x2FC3,
 },
 [0x2FC4]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL SALT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9E75 },
  unicodeslot=0x2FC4,
 },
 [0x2FC5]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DEER",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9E7F },
  unicodeslot=0x2FC5,
 },
 [0x2FC6]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL WHEAT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9EA5 },
  unicodeslot=0x2FC6,
 },
 [0x2FC7]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL HEMP",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9EBB },
  unicodeslot=0x2FC7,
 },
 [0x2FC8]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL YELLOW",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9EC3 },
  unicodeslot=0x2FC8,
 },
 [0x2FC9]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL MILLET",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9ECD },
  unicodeslot=0x2FC9,
 },
 [0x2FCA]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL BLACK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9ED1 },
  unicodeslot=0x2FCA,
 },
 [0x2FCB]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL EMBROIDERY",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9EF9 },
  unicodeslot=0x2FCB,
 },
 [0x2FCC]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FROG",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9EFD },
  unicodeslot=0x2FCC,
 },
 [0x2FCD]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TRIPOD",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F0E },
  unicodeslot=0x2FCD,
 },
 [0x2FCE]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DRUM",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F13 },
  unicodeslot=0x2FCE,
 },
 [0x2FCF]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL RAT",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F20 },
  unicodeslot=0x2FCF,
 },
 [0x2FD0]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL NOSE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F3B },
  unicodeslot=0x2FD0,
 },
 [0x2FD1]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL EVEN",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F4A },
  unicodeslot=0x2FD1,
 },
 [0x2FD2]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TOOTH",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F52 },
  unicodeslot=0x2FD2,
 },
 [0x2FD3]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL DRAGON",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F8D },
  unicodeslot=0x2FD3,
 },
 [0x2FD4]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL TURTLE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9F9C },
  unicodeslot=0x2FD4,
 },
 [0x2FD5]={
  category="so",
  cjkwd="w",
  description="KANGXI RADICAL FLUTE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x9FA0 },
  unicodeslot=0x2FD5,
 },
 [0x2FF0]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO RIGHT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF0,
 },
 [0x2FF1]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO BELOW",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF1,
 },
 [0x2FF2]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO MIDDLE AND RIGHT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF2,
 },
 [0x2FF3]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO MIDDLE AND BELOW",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF3,
 },
 [0x2FF4]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER FULL SURROUND",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF4,
 },
 [0x2FF5]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM ABOVE",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF5,
 },
 [0x2FF6]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM BELOW",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF6,
 },
 [0x2FF7]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LEFT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF7,
 },
 [0x2FF8]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER LEFT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF8,
 },
 [0x2FF9]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER RIGHT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FF9,
 },
 [0x2FFA]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LOWER LEFT",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FFA,
 },
 [0x2FFB]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC DESCRIPTION CHARACTER OVERLAID",
  direction="on",
  linebreak="id",
  unicodeslot=0x2FFB,
 },
 [0x3000]={
  adobename="ideographicspace",
  category="zs",
  cjkwd="f",
  contextname="ideographicspace",
  description="IDEOGRAPHIC SPACE",
  direction="ws",
  linebreak="id",
  specials={ "wide", 0x0020 },
  unicodeslot=0x3000,
 },
 [0x3001]={
  adobename="ideographiccomma",
  category="po",
  cjkwd="w",
  description="IDEOGRAPHIC COMMA",
  direction="on",
  linebreak="cl",
  unicodeslot=0x3001,
 },
 [0x3002]={
  adobename="ideographicperiod",
  category="po",
  cjkwd="w",
  description="IDEOGRAPHIC FULL STOP",
  direction="on",
  linebreak="cl",
  unicodeslot=0x3002,
 },
 [0x3003]={
  adobename="dittomark",
  category="po",
  cjkwd="w",
  description="DITTO MARK",
  direction="on",
  linebreak="id",
  unicodeslot=0x3003,
 },
 [0x3004]={
  adobename="jis",
  category="so",
  cjkwd="w",
  description="JAPANESE INDUSTRIAL STANDARD SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x3004,
 },
 [0x3005]={
  adobename="ideographiciterationmark",
  category="lm",
  cjkwd="w",
  description="IDEOGRAPHIC ITERATION MARK",
  direction="l",
  linebreak="ns",
  unicodeslot=0x3005,
 },
 [0x3006]={
  adobename="ideographicclose",
  category="lo",
  cjkwd="w",
  description="IDEOGRAPHIC CLOSING MARK",
  direction="l",
  linebreak="id",
  unicodeslot=0x3006,
 },
 [0x3007]={
  adobename="ideographiczero",
  category="nl",
  cjkwd="w",
  description="IDEOGRAPHIC NUMBER ZERO",
  direction="l",
  linebreak="id",
  unicodeslot=0x3007,
 },
 [0x3008]={
  adobename="anglebracketleft",
  category="ps",
  cjkwd="w",
  description="LEFT ANGLE BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x3009,
  unicodeslot=0x3008,
 },
 [0x3009]={
  adobename="anglebracketright",
  category="pe",
  cjkwd="w",
  description="RIGHT ANGLE BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x3008,
  unicodeslot=0x3009,
 },
 [0x300A]={
  adobename="dblanglebracketleft",
  category="ps",
  cjkwd="w",
  description="LEFT DOUBLE ANGLE BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x300B,
  unicodeslot=0x300A,
 },
 [0x300B]={
  adobename="dblanglebracketright",
  category="pe",
  cjkwd="w",
  description="RIGHT DOUBLE ANGLE BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x300A,
  unicodeslot=0x300B,
 },
 [0x300C]={
  adobename="cornerbracketleft",
  category="ps",
  cjkwd="w",
  description="LEFT CORNER BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x300D,
  unicodeslot=0x300C,
 },
 [0x300D]={
  adobename="cornerbracketright",
  category="pe",
  cjkwd="w",
  description="RIGHT CORNER BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x300C,
  unicodeslot=0x300D,
 },
 [0x300E]={
  adobename="whitecornerbracketleft",
  category="ps",
  cjkwd="w",
  description="LEFT WHITE CORNER BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x300F,
  unicodeslot=0x300E,
 },
 [0x300F]={
  adobename="whitecornerbracketright",
  category="pe",
  cjkwd="w",
  description="RIGHT WHITE CORNER BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x300E,
  unicodeslot=0x300F,
 },
 [0x3010]={
  adobename="blacklenticularbracketleft",
  category="ps",
  cjkwd="w",
  description="LEFT BLACK LENTICULAR BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x3011,
  unicodeslot=0x3010,
 },
 [0x3011]={
  adobename="blacklenticularbracketright",
  category="pe",
  cjkwd="w",
  description="RIGHT BLACK LENTICULAR BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x3010,
  unicodeslot=0x3011,
 },
 [0x3012]={
  adobename="postalmark",
  category="so",
  cjkwd="w",
  description="POSTAL MARK",
  direction="on",
  linebreak="id",
  unicodeslot=0x3012,
 },
 [0x3013]={
  adobename="getamark",
  category="so",
  cjkwd="w",
  description="GETA MARK",
  direction="on",
  linebreak="id",
  unicodeslot=0x3013,
 },
 [0x3014]={
  adobename="tortoiseshellbracketleft",
  category="ps",
  cjkwd="w",
  description="LEFT TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x3015,
  unicodeslot=0x3014,
 },
 [0x3015]={
  adobename="tortoiseshellbracketright",
  category="pe",
  cjkwd="w",
  description="RIGHT TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x3014,
  unicodeslot=0x3015,
 },
 [0x3016]={
  adobename="whitelenticularbracketleft",
  category="ps",
  cjkwd="w",
  description="LEFT WHITE LENTICULAR BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x3017,
  unicodeslot=0x3016,
 },
 [0x3017]={
  adobename="whitelenticularbracketright",
  category="pe",
  cjkwd="w",
  description="RIGHT WHITE LENTICULAR BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x3016,
  unicodeslot=0x3017,
 },
 [0x3018]={
  adobename="whitetortoiseshellbracketleft",
  category="ps",
  cjkwd="w",
  description="LEFT WHITE TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x3019,
  unicodeslot=0x3018,
 },
 [0x3019]={
  adobename="whitetortoiseshellbracketright",
  category="pe",
  cjkwd="w",
  description="RIGHT WHITE TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x3018,
  unicodeslot=0x3019,
 },
 [0x301A]={
  category="ps",
  cjkwd="w",
  description="LEFT WHITE SQUARE BRACKET",
  direction="on",
  linebreak="op",
  mirror=0x301B,
  unicodeslot=0x301A,
 },
 [0x301B]={
  category="pe",
  cjkwd="w",
  description="RIGHT WHITE SQUARE BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0x301A,
  unicodeslot=0x301B,
 },
 [0x301C]={
  adobename="wavedash",
  category="pd",
  cjkwd="w",
  description="WAVE DASH",
  direction="on",
  linebreak="ns",
  unicodeslot=0x301C,
 },
 [0x301D]={
  adobename="quotedblprimereversed",
  category="ps",
  cjkwd="w",
  description="REVERSED DOUBLE PRIME QUOTATION MARK",
  direction="on",
  linebreak="op",
  unicodeslot=0x301D,
 },
 [0x301E]={
  adobename="quotedblprime",
  category="pe",
  cjkwd="w",
  description="DOUBLE PRIME QUOTATION MARK",
  direction="on",
  linebreak="cl",
  unicodeslot=0x301E,
 },
 [0x301F]={
  category="pe",
  cjkwd="w",
  description="LOW DOUBLE PRIME QUOTATION MARK",
  direction="on",
  linebreak="cl",
  unicodeslot=0x301F,
 },
 [0x3020]={
  adobename="postalmarkface",
  category="so",
  cjkwd="w",
  description="POSTAL MARK FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x3020,
 },
 [0x3021]={
  adobename="onehangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL ONE",
  direction="l",
  linebreak="id",
  unicodeslot=0x3021,
 },
 [0x3022]={
  adobename="twohangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL TWO",
  direction="l",
  linebreak="id",
  unicodeslot=0x3022,
 },
 [0x3023]={
  adobename="threehangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL THREE",
  direction="l",
  linebreak="id",
  unicodeslot=0x3023,
 },
 [0x3024]={
  adobename="fourhangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL FOUR",
  direction="l",
  linebreak="id",
  unicodeslot=0x3024,
 },
 [0x3025]={
  adobename="fivehangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL FIVE",
  direction="l",
  linebreak="id",
  unicodeslot=0x3025,
 },
 [0x3026]={
  adobename="sixhangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL SIX",
  direction="l",
  linebreak="id",
  unicodeslot=0x3026,
 },
 [0x3027]={
  adobename="sevenhangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL SEVEN",
  direction="l",
  linebreak="id",
  unicodeslot=0x3027,
 },
 [0x3028]={
  adobename="eighthangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL EIGHT",
  direction="l",
  linebreak="id",
  unicodeslot=0x3028,
 },
 [0x3029]={
  adobename="ninehangzhou",
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL NINE",
  direction="l",
  linebreak="id",
  unicodeslot=0x3029,
 },
 [0x302A]={
  category="mn",
  cjkwd="w",
  description="IDEOGRAPHIC LEVEL TONE MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x302A,
 },
 [0x302B]={
  category="mn",
  cjkwd="w",
  description="IDEOGRAPHIC RISING TONE MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x302B,
 },
 [0x302C]={
  category="mn",
  cjkwd="w",
  description="IDEOGRAPHIC DEPARTING TONE MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x302C,
 },
 [0x302D]={
  category="mn",
  cjkwd="w",
  description="IDEOGRAPHIC ENTERING TONE MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x302D,
 },
 [0x302E]={
  category="mn",
  cjkwd="w",
  description="HANGUL SINGLE DOT TONE MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x302E,
 },
 [0x302F]={
  category="mn",
  cjkwd="w",
  description="HANGUL DOUBLE DOT TONE MARK",
  direction="l",
  linebreak="cm",
  unicodeslot=0x302F,
 },
 [0x3030]={
  category="pd",
  cjkwd="w",
  description="WAVY DASH",
  direction="on",
  linebreak="id",
  unicodeslot=0x3030,
 },
 [0x3031]={
  category="lm",
  cjkwd="w",
  description="VERTICAL KANA REPEAT MARK",
  direction="l",
  linebreak="id",
  unicodeslot=0x3031,
 },
 [0x3032]={
  category="lm",
  cjkwd="w",
  description="VERTICAL KANA REPEAT WITH VOICED SOUND MARK",
  direction="l",
  linebreak="id",
  unicodeslot=0x3032,
 },
 [0x3033]={
  category="lm",
  cjkwd="w",
  description="VERTICAL KANA REPEAT MARK UPPER HALF",
  direction="l",
  linebreak="id",
  unicodeslot=0x3033,
 },
 [0x3034]={
  category="lm",
  cjkwd="w",
  description="VERTICAL KANA REPEAT WITH VOICED SOUND MARK UPPER HALF",
  direction="l",
  linebreak="id",
  unicodeslot=0x3034,
 },
 [0x3035]={
  category="lm",
  cjkwd="w",
  description="VERTICAL KANA REPEAT MARK LOWER HALF",
  direction="l",
  linebreak="id",
  unicodeslot=0x3035,
 },
 [0x3036]={
  adobename="circlepostalmark",
  category="so",
  cjkwd="w",
  description="CIRCLED POSTAL MARK",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x3012 },
  unicodeslot=0x3036,
 },
 [0x3037]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH LINE FEED SEPARATOR SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x3037,
 },
 [0x3038]={
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL TEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x5341 },
  unicodeslot=0x3038,
 },
 [0x3039]={
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL TWENTY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x5344 },
  unicodeslot=0x3039,
 },
 [0x303A]={
  category="nl",
  cjkwd="w",
  description="HANGZHOU NUMERAL THIRTY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x5345 },
  unicodeslot=0x303A,
 },
 [0x303B]={
  category="lm",
  cjkwd="w",
  description="VERTICAL IDEOGRAPHIC ITERATION MARK",
  direction="l",
  linebreak="ns",
  unicodeslot=0x303B,
 },
 [0x303C]={
  category="lo",
  cjkwd="w",
  description="MASU MARK",
  direction="l",
  linebreak="ns",
  unicodeslot=0x303C,
 },
 [0x303D]={
  category="po",
  cjkwd="w",
  description="PART ALTERNATION MARK",
  direction="on",
  linebreak="id",
  unicodeslot=0x303D,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x303E]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC VARIATION INDICATOR",
  direction="on",
  linebreak="id",
  unicodeslot=0x303E,
 },
 [0x303F]={
  category="so",
  contextname="ideographichalffillspace",
  description="IDEOGRAPHIC HALF FILL SPACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x303F,
 },
 [0x3041]={
  adobename="asmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL A",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3041,
 },
 [0x3042]={
  adobename="ahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER A",
  direction="l",
  linebreak="id",
  unicodeslot=0x3042,
 },
 [0x3043]={
  adobename="ismallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL I",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3043,
 },
 [0x3044]={
  adobename="ihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER I",
  direction="l",
  linebreak="id",
  unicodeslot=0x3044,
 },
 [0x3045]={
  adobename="usmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL U",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3045,
 },
 [0x3046]={
  adobename="uhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER U",
  direction="l",
  linebreak="id",
  unicodeslot=0x3046,
 },
 [0x3047]={
  adobename="esmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL E",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3047,
 },
 [0x3048]={
  adobename="ehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER E",
  direction="l",
  linebreak="id",
  unicodeslot=0x3048,
 },
 [0x3049]={
  adobename="osmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL O",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3049,
 },
 [0x304A]={
  adobename="ohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER O",
  direction="l",
  linebreak="id",
  unicodeslot=0x304A,
 },
 [0x304B]={
  adobename="kahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER KA",
  direction="l",
  linebreak="id",
  unicodeslot=0x304B,
 },
 [0x304C]={
  adobename="gahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER GA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x304B, 0x3099 },
  unicodeslot=0x304C,
 },
 [0x304D]={
  adobename="kihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER KI",
  direction="l",
  linebreak="id",
  unicodeslot=0x304D,
 },
 [0x304E]={
  adobename="gihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER GI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x304D, 0x3099 },
  unicodeslot=0x304E,
 },
 [0x304F]={
  adobename="kuhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER KU",
  direction="l",
  linebreak="id",
  unicodeslot=0x304F,
 },
 [0x3050]={
  adobename="guhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER GU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x304F, 0x3099 },
  unicodeslot=0x3050,
 },
 [0x3051]={
  adobename="kehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER KE",
  direction="l",
  linebreak="id",
  unicodeslot=0x3051,
 },
 [0x3052]={
  adobename="gehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER GE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3051, 0x3099 },
  unicodeslot=0x3052,
 },
 [0x3053]={
  adobename="kohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER KO",
  direction="l",
  linebreak="id",
  unicodeslot=0x3053,
 },
 [0x3054]={
  adobename="gohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER GO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3053, 0x3099 },
  unicodeslot=0x3054,
 },
 [0x3055]={
  adobename="sahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SA",
  direction="l",
  linebreak="id",
  unicodeslot=0x3055,
 },
 [0x3056]={
  adobename="zahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER ZA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3055, 0x3099 },
  unicodeslot=0x3056,
 },
 [0x3057]={
  adobename="sihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SI",
  direction="l",
  linebreak="id",
  unicodeslot=0x3057,
 },
 [0x3058]={
  adobename="zihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER ZI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3057, 0x3099 },
  unicodeslot=0x3058,
 },
 [0x3059]={
  adobename="suhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SU",
  direction="l",
  linebreak="id",
  unicodeslot=0x3059,
 },
 [0x305A]={
  adobename="zuhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER ZU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3059, 0x3099 },
  unicodeslot=0x305A,
 },
 [0x305B]={
  adobename="sehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SE",
  direction="l",
  linebreak="id",
  unicodeslot=0x305B,
 },
 [0x305C]={
  adobename="zehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER ZE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x305B, 0x3099 },
  unicodeslot=0x305C,
 },
 [0x305D]={
  adobename="sohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SO",
  direction="l",
  linebreak="id",
  unicodeslot=0x305D,
 },
 [0x305E]={
  adobename="zohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER ZO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x305D, 0x3099 },
  unicodeslot=0x305E,
 },
 [0x305F]={
  adobename="tahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER TA",
  direction="l",
  linebreak="id",
  unicodeslot=0x305F,
 },
 [0x3060]={
  adobename="dahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x305F, 0x3099 },
  unicodeslot=0x3060,
 },
 [0x3061]={
  adobename="tihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER TI",
  direction="l",
  linebreak="id",
  unicodeslot=0x3061,
 },
 [0x3062]={
  adobename="dihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER DI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3061, 0x3099 },
  unicodeslot=0x3062,
 },
 [0x3063]={
  adobename="tusmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL TU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3063,
 },
 [0x3064]={
  adobename="tuhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER TU",
  direction="l",
  linebreak="id",
  unicodeslot=0x3064,
 },
 [0x3065]={
  adobename="duhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER DU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3064, 0x3099 },
  unicodeslot=0x3065,
 },
 [0x3066]={
  adobename="tehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER TE",
  direction="l",
  linebreak="id",
  unicodeslot=0x3066,
 },
 [0x3067]={
  adobename="dehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3066, 0x3099 },
  unicodeslot=0x3067,
 },
 [0x3068]={
  adobename="tohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER TO",
  direction="l",
  linebreak="id",
  unicodeslot=0x3068,
 },
 [0x3069]={
  adobename="dohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER DO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3068, 0x3099 },
  unicodeslot=0x3069,
 },
 [0x306A]={
  adobename="nahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER NA",
  direction="l",
  linebreak="id",
  unicodeslot=0x306A,
 },
 [0x306B]={
  adobename="nihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER NI",
  direction="l",
  linebreak="id",
  unicodeslot=0x306B,
 },
 [0x306C]={
  adobename="nuhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER NU",
  direction="l",
  linebreak="id",
  unicodeslot=0x306C,
 },
 [0x306D]={
  adobename="nehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER NE",
  direction="l",
  linebreak="id",
  unicodeslot=0x306D,
 },
 [0x306E]={
  adobename="nohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER NO",
  direction="l",
  linebreak="id",
  unicodeslot=0x306E,
 },
 [0x306F]={
  adobename="hahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER HA",
  direction="l",
  linebreak="id",
  unicodeslot=0x306F,
 },
 [0x3070]={
  adobename="bahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x306F, 0x3099 },
  unicodeslot=0x3070,
 },
 [0x3071]={
  adobename="pahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER PA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x306F, 0x309A },
  unicodeslot=0x3071,
 },
 [0x3072]={
  adobename="hihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER HI",
  direction="l",
  linebreak="id",
  unicodeslot=0x3072,
 },
 [0x3073]={
  adobename="bihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER BI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3072, 0x3099 },
  unicodeslot=0x3073,
 },
 [0x3074]={
  adobename="pihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER PI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3072, 0x309A },
  unicodeslot=0x3074,
 },
 [0x3075]={
  adobename="huhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER HU",
  direction="l",
  linebreak="id",
  unicodeslot=0x3075,
 },
 [0x3076]={
  adobename="buhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER BU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3075, 0x3099 },
  unicodeslot=0x3076,
 },
 [0x3077]={
  adobename="puhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER PU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3075, 0x309A },
  unicodeslot=0x3077,
 },
 [0x3078]={
  adobename="hehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER HE",
  direction="l",
  linebreak="id",
  unicodeslot=0x3078,
 },
 [0x3079]={
  adobename="behiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3078, 0x3099 },
  unicodeslot=0x3079,
 },
 [0x307A]={
  adobename="pehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER PE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3078, 0x309A },
  unicodeslot=0x307A,
 },
 [0x307B]={
  adobename="hohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER HO",
  direction="l",
  linebreak="id",
  unicodeslot=0x307B,
 },
 [0x307C]={
  adobename="bohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER BO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x307B, 0x3099 },
  unicodeslot=0x307C,
 },
 [0x307D]={
  adobename="pohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER PO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x307B, 0x309A },
  unicodeslot=0x307D,
 },
 [0x307E]={
  adobename="mahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER MA",
  direction="l",
  linebreak="id",
  unicodeslot=0x307E,
 },
 [0x307F]={
  adobename="mihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER MI",
  direction="l",
  linebreak="id",
  unicodeslot=0x307F,
 },
 [0x3080]={
  adobename="muhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER MU",
  direction="l",
  linebreak="id",
  unicodeslot=0x3080,
 },
 [0x3081]={
  adobename="mehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER ME",
  direction="l",
  linebreak="id",
  unicodeslot=0x3081,
 },
 [0x3082]={
  adobename="mohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER MO",
  direction="l",
  linebreak="id",
  unicodeslot=0x3082,
 },
 [0x3083]={
  adobename="yasmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL YA",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3083,
 },
 [0x3084]={
  adobename="yahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER YA",
  direction="l",
  linebreak="id",
  unicodeslot=0x3084,
 },
 [0x3085]={
  adobename="yusmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL YU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3085,
 },
 [0x3086]={
  adobename="yuhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER YU",
  direction="l",
  linebreak="id",
  unicodeslot=0x3086,
 },
 [0x3087]={
  adobename="yosmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL YO",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3087,
 },
 [0x3088]={
  adobename="yohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER YO",
  direction="l",
  linebreak="id",
  unicodeslot=0x3088,
 },
 [0x3089]={
  adobename="rahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER RA",
  direction="l",
  linebreak="id",
  unicodeslot=0x3089,
 },
 [0x308A]={
  adobename="rihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER RI",
  direction="l",
  linebreak="id",
  unicodeslot=0x308A,
 },
 [0x308B]={
  adobename="ruhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER RU",
  direction="l",
  linebreak="id",
  unicodeslot=0x308B,
 },
 [0x308C]={
  adobename="rehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER RE",
  direction="l",
  linebreak="id",
  unicodeslot=0x308C,
 },
 [0x308D]={
  adobename="rohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER RO",
  direction="l",
  linebreak="id",
  unicodeslot=0x308D,
 },
 [0x308E]={
  adobename="wasmallhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL WA",
  direction="l",
  linebreak="cj",
  unicodeslot=0x308E,
 },
 [0x308F]={
  adobename="wahiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER WA",
  direction="l",
  linebreak="id",
  unicodeslot=0x308F,
 },
 [0x3090]={
  adobename="wihiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER WI",
  direction="l",
  linebreak="id",
  unicodeslot=0x3090,
 },
 [0x3091]={
  adobename="wehiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER WE",
  direction="l",
  linebreak="id",
  unicodeslot=0x3091,
 },
 [0x3092]={
  adobename="wohiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER WO",
  direction="l",
  linebreak="id",
  unicodeslot=0x3092,
 },
 [0x3093]={
  adobename="nhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER N",
  direction="l",
  linebreak="id",
  unicodeslot=0x3093,
 },
 [0x3094]={
  adobename="vuhiragana",
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER VU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3046, 0x3099 },
  unicodeslot=0x3094,
 },
 [0x3095]={
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL KA",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3095,
 },
 [0x3096]={
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER SMALL KE",
  direction="l",
  linebreak="cj",
  unicodeslot=0x3096,
 },
 [0x3099]={
  category="mn",
  cjkwd="w",
  description="COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x3099,
 },
 [0x309A]={
  category="mn",
  cjkwd="w",
  description="COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x309A,
 },
 [0x309B]={
  adobename="voicedmarkkana",
  category="sk",
  cjkwd="w",
  description="KATAKANA-HIRAGANA VOICED SOUND MARK",
  direction="on",
  linebreak="ns",
  specials={ "compat", 0x0020, 0x3099 },
  unicodeslot=0x309B,
 },
 [0x309C]={
  adobename="semivoicedmarkkana",
  category="sk",
  cjkwd="w",
  description="KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK",
  direction="on",
  linebreak="ns",
  specials={ "compat", 0x0020, 0x309A },
  unicodeslot=0x309C,
 },
 [0x309D]={
  adobename="iterationhiragana",
  category="lm",
  cjkwd="w",
  description="HIRAGANA ITERATION MARK",
  direction="l",
  linebreak="ns",
  unicodeslot=0x309D,
 },
 [0x309E]={
  adobename="voicediterationhiragana",
  category="lm",
  cjkwd="w",
  description="HIRAGANA VOICED ITERATION MARK",
  direction="l",
  linebreak="ns",
  specials={ "char", 0x309D, 0x3099 },
  unicodeslot=0x309E,
 },
 [0x309F]={
  category="lo",
  cjkwd="w",
  description="HIRAGANA DIGRAPH YORI",
  direction="l",
  linebreak="id",
  specials={ "vertical", 0x3088, 0x308A },
  unicodeslot=0x309F,
 },
 [0x30A0]={
  category="pd",
  cjkwd="w",
  description="KATAKANA-HIRAGANA DOUBLE HYPHEN",
  direction="on",
  linebreak="ns",
  unicodeslot=0x30A0,
 },
 [0x30A1]={
  adobename="asmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL A",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30A1,
 },
 [0x30A2]={
  adobename="akatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER A",
  direction="l",
  linebreak="id",
  unicodeslot=0x30A2,
 },
 [0x30A3]={
  adobename="ismallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL I",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30A3,
 },
 [0x30A4]={
  adobename="ikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER I",
  direction="l",
  linebreak="id",
  unicodeslot=0x30A4,
 },
 [0x30A5]={
  adobename="usmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL U",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30A5,
 },
 [0x30A6]={
  adobename="ukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER U",
  direction="l",
  linebreak="id",
  unicodeslot=0x30A6,
 },
 [0x30A7]={
  adobename="esmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL E",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30A7,
 },
 [0x30A8]={
  adobename="ekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER E",
  direction="l",
  linebreak="id",
  unicodeslot=0x30A8,
 },
 [0x30A9]={
  adobename="osmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL O",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30A9,
 },
 [0x30AA]={
  adobename="okatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER O",
  direction="l",
  linebreak="id",
  unicodeslot=0x30AA,
 },
 [0x30AB]={
  adobename="kakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER KA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30AB,
 },
 [0x30AC]={
  adobename="gakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER GA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30AB, 0x3099 },
  unicodeslot=0x30AC,
 },
 [0x30AD]={
  adobename="kikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER KI",
  direction="l",
  linebreak="id",
  unicodeslot=0x30AD,
 },
 [0x30AE]={
  adobename="gikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER GI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30AD, 0x3099 },
  unicodeslot=0x30AE,
 },
 [0x30AF]={
  adobename="kukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER KU",
  direction="l",
  linebreak="id",
  unicodeslot=0x30AF,
 },
 [0x30B0]={
  adobename="gukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER GU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30AF, 0x3099 },
  unicodeslot=0x30B0,
 },
 [0x30B1]={
  adobename="kekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER KE",
  direction="l",
  linebreak="id",
  unicodeslot=0x30B1,
 },
 [0x30B2]={
  adobename="gekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER GE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30B1, 0x3099 },
  unicodeslot=0x30B2,
 },
 [0x30B3]={
  adobename="kokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER KO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30B3,
 },
 [0x30B4]={
  adobename="gokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER GO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30B3, 0x3099 },
  unicodeslot=0x30B4,
 },
 [0x30B5]={
  adobename="sakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30B5,
 },
 [0x30B6]={
  adobename="zakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER ZA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30B5, 0x3099 },
  unicodeslot=0x30B6,
 },
 [0x30B7]={
  adobename="sikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SI",
  direction="l",
  linebreak="id",
  unicodeslot=0x30B7,
 },
 [0x30B8]={
  adobename="zikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER ZI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30B7, 0x3099 },
  unicodeslot=0x30B8,
 },
 [0x30B9]={
  adobename="sukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SU",
  direction="l",
  linebreak="id",
  unicodeslot=0x30B9,
 },
 [0x30BA]={
  adobename="zukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER ZU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30B9, 0x3099 },
  unicodeslot=0x30BA,
 },
 [0x30BB]={
  adobename="sekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SE",
  direction="l",
  linebreak="id",
  unicodeslot=0x30BB,
 },
 [0x30BC]={
  adobename="zekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER ZE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30BB, 0x3099 },
  unicodeslot=0x30BC,
 },
 [0x30BD]={
  adobename="sokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30BD,
 },
 [0x30BE]={
  adobename="zokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER ZO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30BD, 0x3099 },
  unicodeslot=0x30BE,
 },
 [0x30BF]={
  adobename="takatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER TA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30BF,
 },
 [0x30C0]={
  adobename="dakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30BF, 0x3099 },
  unicodeslot=0x30C0,
 },
 [0x30C1]={
  adobename="tikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER TI",
  direction="l",
  linebreak="id",
  unicodeslot=0x30C1,
 },
 [0x30C2]={
  adobename="dikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER DI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30C1, 0x3099 },
  unicodeslot=0x30C2,
 },
 [0x30C3]={
  adobename="tusmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL TU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30C3,
 },
 [0x30C4]={
  adobename="tukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER TU",
  direction="l",
  linebreak="id",
  unicodeslot=0x30C4,
 },
 [0x30C5]={
  adobename="dukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER DU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30C4, 0x3099 },
  unicodeslot=0x30C5,
 },
 [0x30C6]={
  adobename="tekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER TE",
  direction="l",
  linebreak="id",
  unicodeslot=0x30C6,
 },
 [0x30C7]={
  adobename="dekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30C6, 0x3099 },
  unicodeslot=0x30C7,
 },
 [0x30C8]={
  adobename="tokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER TO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30C8,
 },
 [0x30C9]={
  adobename="dokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER DO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30C8, 0x3099 },
  unicodeslot=0x30C9,
 },
 [0x30CA]={
  adobename="nakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER NA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30CA,
 },
 [0x30CB]={
  adobename="nikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER NI",
  direction="l",
  linebreak="id",
  unicodeslot=0x30CB,
 },
 [0x30CC]={
  adobename="nukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER NU",
  direction="l",
  linebreak="id",
  unicodeslot=0x30CC,
 },
 [0x30CD]={
  adobename="nekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER NE",
  direction="l",
  linebreak="id",
  unicodeslot=0x30CD,
 },
 [0x30CE]={
  adobename="nokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER NO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30CE,
 },
 [0x30CF]={
  adobename="hakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER HA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30CF,
 },
 [0x30D0]={
  adobename="bakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30CF, 0x3099 },
  unicodeslot=0x30D0,
 },
 [0x30D1]={
  adobename="pakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER PA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30CF, 0x309A },
  unicodeslot=0x30D1,
 },
 [0x30D2]={
  adobename="hikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER HI",
  direction="l",
  linebreak="id",
  unicodeslot=0x30D2,
 },
 [0x30D3]={
  adobename="bikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER BI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30D2, 0x3099 },
  unicodeslot=0x30D3,
 },
 [0x30D4]={
  adobename="pikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER PI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30D2, 0x309A },
  unicodeslot=0x30D4,
 },
 [0x30D5]={
  adobename="hukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER HU",
  direction="l",
  linebreak="id",
  unicodeslot=0x30D5,
 },
 [0x30D6]={
  adobename="bukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER BU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30D5, 0x3099 },
  unicodeslot=0x30D6,
 },
 [0x30D7]={
  adobename="pukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER PU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30D5, 0x309A },
  unicodeslot=0x30D7,
 },
 [0x30D8]={
  adobename="hekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER HE",
  direction="l",
  linebreak="id",
  unicodeslot=0x30D8,
 },
 [0x30D9]={
  adobename="bekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30D8, 0x3099 },
  unicodeslot=0x30D9,
 },
 [0x30DA]={
  adobename="pekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER PE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30D8, 0x309A },
  unicodeslot=0x30DA,
 },
 [0x30DB]={
  adobename="hokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER HO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30DB,
 },
 [0x30DC]={
  adobename="bokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER BO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30DB, 0x3099 },
  unicodeslot=0x30DC,
 },
 [0x30DD]={
  adobename="pokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER PO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30DB, 0x309A },
  unicodeslot=0x30DD,
 },
 [0x30DE]={
  adobename="makatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER MA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30DE,
 },
 [0x30DF]={
  adobename="mikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER MI",
  direction="l",
  linebreak="id",
  unicodeslot=0x30DF,
 },
 [0x30E0]={
  adobename="mukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER MU",
  direction="l",
  linebreak="id",
  unicodeslot=0x30E0,
 },
 [0x30E1]={
  adobename="mekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER ME",
  direction="l",
  linebreak="id",
  unicodeslot=0x30E1,
 },
 [0x30E2]={
  adobename="mokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER MO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30E2,
 },
 [0x30E3]={
  adobename="yasmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL YA",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30E3,
 },
 [0x30E4]={
  adobename="yakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER YA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30E4,
 },
 [0x30E5]={
  adobename="yusmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL YU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30E5,
 },
 [0x30E6]={
  adobename="yukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER YU",
  direction="l",
  linebreak="id",
  unicodeslot=0x30E6,
 },
 [0x30E7]={
  adobename="yosmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL YO",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30E7,
 },
 [0x30E8]={
  adobename="yokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER YO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30E8,
 },
 [0x30E9]={
  adobename="rakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER RA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30E9,
 },
 [0x30EA]={
  adobename="rikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER RI",
  direction="l",
  linebreak="id",
  unicodeslot=0x30EA,
 },
 [0x30EB]={
  adobename="rukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER RU",
  direction="l",
  linebreak="id",
  unicodeslot=0x30EB,
 },
 [0x30EC]={
  adobename="rekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER RE",
  direction="l",
  linebreak="id",
  unicodeslot=0x30EC,
 },
 [0x30ED]={
  adobename="rokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER RO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30ED,
 },
 [0x30EE]={
  adobename="wasmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL WA",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30EE,
 },
 [0x30EF]={
  adobename="wakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER WA",
  direction="l",
  linebreak="id",
  unicodeslot=0x30EF,
 },
 [0x30F0]={
  adobename="wikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER WI",
  direction="l",
  linebreak="id",
  unicodeslot=0x30F0,
 },
 [0x30F1]={
  adobename="wekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER WE",
  direction="l",
  linebreak="id",
  unicodeslot=0x30F1,
 },
 [0x30F2]={
  adobename="wokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER WO",
  direction="l",
  linebreak="id",
  unicodeslot=0x30F2,
 },
 [0x30F3]={
  adobename="nkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER N",
  direction="l",
  linebreak="id",
  unicodeslot=0x30F3,
 },
 [0x30F4]={
  adobename="vukatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER VU",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30A6, 0x3099 },
  unicodeslot=0x30F4,
 },
 [0x30F5]={
  adobename="kasmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL KA",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30F5,
 },
 [0x30F6]={
  adobename="kesmallkatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL KE",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30F6,
 },
 [0x30F7]={
  adobename="vakatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER VA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30EF, 0x3099 },
  unicodeslot=0x30F7,
 },
 [0x30F8]={
  adobename="vikatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER VI",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30F0, 0x3099 },
  unicodeslot=0x30F8,
 },
 [0x30F9]={
  adobename="vekatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER VE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30F1, 0x3099 },
  unicodeslot=0x30F9,
 },
 [0x30FA]={
  adobename="vokatakana",
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER VO",
  direction="l",
  linebreak="id",
  specials={ "char", 0x30F2, 0x3099 },
  unicodeslot=0x30FA,
 },
 [0x30FB]={
  adobename="dotkatakana",
  category="po",
  cjkwd="w",
  description="KATAKANA MIDDLE DOT",
  direction="on",
  linebreak="ns",
  unicodeslot=0x30FB,
 },
 [0x30FC]={
  adobename="prolongedkana",
  category="lm",
  cjkwd="w",
  description="KATAKANA-HIRAGANA PROLONGED SOUND MARK",
  direction="l",
  linebreak="cj",
  unicodeslot=0x30FC,
 },
 [0x30FD]={
  adobename="iterationkatakana",
  category="lm",
  cjkwd="w",
  description="KATAKANA ITERATION MARK",
  direction="l",
  linebreak="ns",
  unicodeslot=0x30FD,
 },
 [0x30FE]={
  adobename="voicediterationkatakana",
  category="lm",
  cjkwd="w",
  description="KATAKANA VOICED ITERATION MARK",
  direction="l",
  linebreak="ns",
  specials={ "char", 0x30FD, 0x3099 },
  unicodeslot=0x30FE,
 },
 [0x30FF]={
  category="lo",
  cjkwd="w",
  description="KATAKANA DIGRAPH KOTO",
  direction="l",
  linebreak="id",
  specials={ "vertical", 0x30B3, 0x30C8 },
  unicodeslot=0x30FF,
 },
 [0x3105]={
  adobename="bbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER B",
  direction="l",
  linebreak="id",
  unicodeslot=0x3105,
 },
 [0x3106]={
  adobename="pbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER P",
  direction="l",
  linebreak="id",
  unicodeslot=0x3106,
 },
 [0x3107]={
  adobename="mbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER M",
  direction="l",
  linebreak="id",
  unicodeslot=0x3107,
 },
 [0x3108]={
  adobename="fbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER F",
  direction="l",
  linebreak="id",
  unicodeslot=0x3108,
 },
 [0x3109]={
  adobename="dbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER D",
  direction="l",
  linebreak="id",
  unicodeslot=0x3109,
 },
 [0x310A]={
  adobename="tbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER T",
  direction="l",
  linebreak="id",
  unicodeslot=0x310A,
 },
 [0x310B]={
  adobename="nbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER N",
  direction="l",
  linebreak="id",
  unicodeslot=0x310B,
 },
 [0x310C]={
  adobename="lbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER L",
  direction="l",
  linebreak="id",
  unicodeslot=0x310C,
 },
 [0x310D]={
  adobename="gbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER G",
  direction="l",
  linebreak="id",
  unicodeslot=0x310D,
 },
 [0x310E]={
  adobename="kbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER K",
  direction="l",
  linebreak="id",
  unicodeslot=0x310E,
 },
 [0x310F]={
  adobename="hbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER H",
  direction="l",
  linebreak="id",
  unicodeslot=0x310F,
 },
 [0x3110]={
  adobename="jbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER J",
  direction="l",
  linebreak="id",
  unicodeslot=0x3110,
 },
 [0x3111]={
  adobename="qbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER Q",
  direction="l",
  linebreak="id",
  unicodeslot=0x3111,
 },
 [0x3112]={
  adobename="xbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER X",
  direction="l",
  linebreak="id",
  unicodeslot=0x3112,
 },
 [0x3113]={
  adobename="zhbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ZH",
  direction="l",
  linebreak="id",
  unicodeslot=0x3113,
 },
 [0x3114]={
  adobename="chbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER CH",
  direction="l",
  linebreak="id",
  unicodeslot=0x3114,
 },
 [0x3115]={
  adobename="shbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER SH",
  direction="l",
  linebreak="id",
  unicodeslot=0x3115,
 },
 [0x3116]={
  adobename="rbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER R",
  direction="l",
  linebreak="id",
  unicodeslot=0x3116,
 },
 [0x3117]={
  adobename="zbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER Z",
  direction="l",
  linebreak="id",
  unicodeslot=0x3117,
 },
 [0x3118]={
  adobename="cbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER C",
  direction="l",
  linebreak="id",
  unicodeslot=0x3118,
 },
 [0x3119]={
  adobename="sbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER S",
  direction="l",
  linebreak="id",
  unicodeslot=0x3119,
 },
 [0x311A]={
  adobename="abopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER A",
  direction="l",
  linebreak="id",
  unicodeslot=0x311A,
 },
 [0x311B]={
  adobename="obopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER O",
  direction="l",
  linebreak="id",
  unicodeslot=0x311B,
 },
 [0x311C]={
  adobename="ebopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER E",
  direction="l",
  linebreak="id",
  unicodeslot=0x311C,
 },
 [0x311D]={
  adobename="ehbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER EH",
  direction="l",
  linebreak="id",
  unicodeslot=0x311D,
 },
 [0x311E]={
  adobename="aibopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER AI",
  direction="l",
  linebreak="id",
  unicodeslot=0x311E,
 },
 [0x311F]={
  adobename="eibopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER EI",
  direction="l",
  linebreak="id",
  unicodeslot=0x311F,
 },
 [0x3120]={
  adobename="aubopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER AU",
  direction="l",
  linebreak="id",
  unicodeslot=0x3120,
 },
 [0x3121]={
  adobename="oubopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER OU",
  direction="l",
  linebreak="id",
  unicodeslot=0x3121,
 },
 [0x3122]={
  adobename="anbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER AN",
  direction="l",
  linebreak="id",
  unicodeslot=0x3122,
 },
 [0x3123]={
  adobename="enbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER EN",
  direction="l",
  linebreak="id",
  unicodeslot=0x3123,
 },
 [0x3124]={
  adobename="angbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ANG",
  direction="l",
  linebreak="id",
  unicodeslot=0x3124,
 },
 [0x3125]={
  adobename="engbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ENG",
  direction="l",
  linebreak="id",
  unicodeslot=0x3125,
 },
 [0x3126]={
  adobename="erbopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ER",
  direction="l",
  linebreak="id",
  unicodeslot=0x3126,
 },
 [0x3127]={
  adobename="ibopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER I",
  direction="l",
  linebreak="id",
  unicodeslot=0x3127,
 },
 [0x3128]={
  adobename="ubopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER U",
  direction="l",
  linebreak="id",
  unicodeslot=0x3128,
 },
 [0x3129]={
  adobename="iubopomofo",
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER IU",
  direction="l",
  linebreak="id",
  unicodeslot=0x3129,
 },
 [0x312A]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER V",
  direction="l",
  linebreak="id",
  unicodeslot=0x312A,
 },
 [0x312B]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER NG",
  direction="l",
  linebreak="id",
  unicodeslot=0x312B,
 },
 [0x312C]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER GN",
  direction="l",
  linebreak="id",
  unicodeslot=0x312C,
 },
 [0x312D]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER IH",
  direction="l",
  linebreak="id",
  unicodeslot=0x312D,
 },
 [0x3131]={
  adobename="kiyeokkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER KIYEOK",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1100 },
  unicodeslot=0x3131,
 },
 [0x3132]={
  adobename="ssangkiyeokkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SSANGKIYEOK",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1101 },
  unicodeslot=0x3132,
 },
 [0x3133]={
  adobename="kiyeoksioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER KIYEOK-SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11AA },
  unicodeslot=0x3133,
 },
 [0x3134]={
  adobename="nieunkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER NIEUN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1102 },
  unicodeslot=0x3134,
 },
 [0x3135]={
  adobename="nieuncieuckorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER NIEUN-CIEUC",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11AC },
  unicodeslot=0x3135,
 },
 [0x3136]={
  adobename="nieunhieuhkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER NIEUN-HIEUH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11AD },
  unicodeslot=0x3136,
 },
 [0x3137]={
  adobename="tikeutkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER TIKEUT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1103 },
  unicodeslot=0x3137,
 },
 [0x3138]={
  adobename="ssangtikeutkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SSANGTIKEUT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1104 },
  unicodeslot=0x3138,
 },
 [0x3139]={
  adobename="rieulkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1105 },
  unicodeslot=0x3139,
 },
 [0x313A]={
  adobename="rieulkiyeokkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-KIYEOK",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11B0 },
  unicodeslot=0x313A,
 },
 [0x313B]={
  adobename="rieulmieumkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-MIEUM",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11B1 },
  unicodeslot=0x313B,
 },
 [0x313C]={
  adobename="rieulpieupkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-PIEUP",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11B2 },
  unicodeslot=0x313C,
 },
 [0x313D]={
  adobename="rieulsioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11B3 },
  unicodeslot=0x313D,
 },
 [0x313E]={
  adobename="rieulthieuthkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-THIEUTH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11B4 },
  unicodeslot=0x313E,
 },
 [0x313F]={
  adobename="rieulphieuphkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-PHIEUPH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11B5 },
  unicodeslot=0x313F,
 },
 [0x3140]={
  adobename="rieulhieuhkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-HIEUH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x111A },
  unicodeslot=0x3140,
 },
 [0x3141]={
  adobename="mieumkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER MIEUM",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1106 },
  unicodeslot=0x3141,
 },
 [0x3142]={
  adobename="pieupkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PIEUP",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1107 },
  unicodeslot=0x3142,
 },
 [0x3143]={
  adobename="ssangpieupkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SSANGPIEUP",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1108 },
  unicodeslot=0x3143,
 },
 [0x3144]={
  adobename="pieupsioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PIEUP-SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1121 },
  unicodeslot=0x3144,
 },
 [0x3145]={
  adobename="sioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1109 },
  unicodeslot=0x3145,
 },
 [0x3146]={
  adobename="ssangsioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SSANGSIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x110A },
  unicodeslot=0x3146,
 },
 [0x3147]={
  adobename="ieungkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER IEUNG",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x110B },
  unicodeslot=0x3147,
 },
 [0x3148]={
  adobename="cieuckorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER CIEUC",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x110C },
  unicodeslot=0x3148,
 },
 [0x3149]={
  adobename="ssangcieuckorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SSANGCIEUC",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x110D },
  unicodeslot=0x3149,
 },
 [0x314A]={
  adobename="chieuchkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER CHIEUCH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x110E },
  unicodeslot=0x314A,
 },
 [0x314B]={
  adobename="khieukhkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER KHIEUKH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x110F },
  unicodeslot=0x314B,
 },
 [0x314C]={
  adobename="thieuthkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER THIEUTH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1110 },
  unicodeslot=0x314C,
 },
 [0x314D]={
  adobename="phieuphkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PHIEUPH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1111 },
  unicodeslot=0x314D,
 },
 [0x314E]={
  adobename="hieuhkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER HIEUH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1112 },
  unicodeslot=0x314E,
 },
 [0x314F]={
  adobename="akorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1161 },
  unicodeslot=0x314F,
 },
 [0x3150]={
  adobename="aekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER AE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1162 },
  unicodeslot=0x3150,
 },
 [0x3151]={
  adobename="yakorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YA",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1163 },
  unicodeslot=0x3151,
 },
 [0x3152]={
  adobename="yaekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YAE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1164 },
  unicodeslot=0x3152,
 },
 [0x3153]={
  adobename="eokorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER EO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1165 },
  unicodeslot=0x3153,
 },
 [0x3154]={
  adobename="ekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER E",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1166 },
  unicodeslot=0x3154,
 },
 [0x3155]={
  adobename="yeokorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YEO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1167 },
  unicodeslot=0x3155,
 },
 [0x3156]={
  adobename="yekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1168 },
  unicodeslot=0x3156,
 },
 [0x3157]={
  adobename="okorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER O",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1169 },
  unicodeslot=0x3157,
 },
 [0x3158]={
  adobename="wakorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER WA",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x116A },
  unicodeslot=0x3158,
 },
 [0x3159]={
  adobename="waekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER WAE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x116B },
  unicodeslot=0x3159,
 },
 [0x315A]={
  adobename="oekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER OE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x116C },
  unicodeslot=0x315A,
 },
 [0x315B]={
  adobename="yokorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x116D },
  unicodeslot=0x315B,
 },
 [0x315C]={
  adobename="ukorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER U",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x116E },
  unicodeslot=0x315C,
 },
 [0x315D]={
  adobename="weokorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER WEO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x116F },
  unicodeslot=0x315D,
 },
 [0x315E]={
  adobename="wekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER WE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1170 },
  unicodeslot=0x315E,
 },
 [0x315F]={
  adobename="wikorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER WI",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1171 },
  unicodeslot=0x315F,
 },
 [0x3160]={
  adobename="yukorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YU",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1172 },
  unicodeslot=0x3160,
 },
 [0x3161]={
  adobename="eukorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER EU",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1173 },
  unicodeslot=0x3161,
 },
 [0x3162]={
  adobename="yikorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YI",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1174 },
  unicodeslot=0x3162,
 },
 [0x3163]={
  adobename="ikorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER I",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1175 },
  unicodeslot=0x3163,
 },
 [0x3164]={
  adobename="hangulfiller",
  category="lo",
  cjkwd="w",
  description="HANGUL FILLER",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1160 },
  unicodeslot=0x3164,
 },
 [0x3165]={
  adobename="ssangnieunkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SSANGNIEUN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1114 },
  unicodeslot=0x3165,
 },
 [0x3166]={
  adobename="nieuntikeutkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER NIEUN-TIKEUT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1115 },
  unicodeslot=0x3166,
 },
 [0x3167]={
  adobename="nieunsioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER NIEUN-SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11C7 },
  unicodeslot=0x3167,
 },
 [0x3168]={
  adobename="nieunpansioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER NIEUN-PANSIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11C8 },
  unicodeslot=0x3168,
 },
 [0x3169]={
  adobename="rieulkiyeoksioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-KIYEOK-SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11CC },
  unicodeslot=0x3169,
 },
 [0x316A]={
  adobename="rieultikeutkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-TIKEUT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11CE },
  unicodeslot=0x316A,
 },
 [0x316B]={
  adobename="rieulpieupsioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-PIEUP-SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11D3 },
  unicodeslot=0x316B,
 },
 [0x316C]={
  adobename="rieulpansioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-PANSIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11D7 },
  unicodeslot=0x316C,
 },
 [0x316D]={
  adobename="rieulyeorinhieuhkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER RIEUL-YEORINHIEUH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11D9 },
  unicodeslot=0x316D,
 },
 [0x316E]={
  adobename="mieumpieupkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER MIEUM-PIEUP",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x111C },
  unicodeslot=0x316E,
 },
 [0x316F]={
  adobename="mieumsioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER MIEUM-SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11DD },
  unicodeslot=0x316F,
 },
 [0x3170]={
  adobename="mieumpansioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER MIEUM-PANSIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11DF },
  unicodeslot=0x3170,
 },
 [0x3171]={
  adobename="kapyeounmieumkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER KAPYEOUNMIEUM",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x111D },
  unicodeslot=0x3171,
 },
 [0x3172]={
  adobename="pieupkiyeokkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PIEUP-KIYEOK",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x111E },
  unicodeslot=0x3172,
 },
 [0x3173]={
  adobename="pieuptikeutkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PIEUP-TIKEUT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1120 },
  unicodeslot=0x3173,
 },
 [0x3174]={
  adobename="pieupsioskiyeokkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PIEUP-SIOS-KIYEOK",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1122 },
  unicodeslot=0x3174,
 },
 [0x3175]={
  adobename="pieupsiostikeutkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PIEUP-SIOS-TIKEUT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1123 },
  unicodeslot=0x3175,
 },
 [0x3176]={
  adobename="pieupcieuckorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PIEUP-CIEUC",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1127 },
  unicodeslot=0x3176,
 },
 [0x3177]={
  adobename="pieupthieuthkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PIEUP-THIEUTH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1129 },
  unicodeslot=0x3177,
 },
 [0x3178]={
  adobename="kapyeounpieupkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER KAPYEOUNPIEUP",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x112B },
  unicodeslot=0x3178,
 },
 [0x3179]={
  adobename="kapyeounssangpieupkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER KAPYEOUNSSANGPIEUP",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x112C },
  unicodeslot=0x3179,
 },
 [0x317A]={
  adobename="sioskiyeokkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SIOS-KIYEOK",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x112D },
  unicodeslot=0x317A,
 },
 [0x317B]={
  adobename="siosnieunkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SIOS-NIEUN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x112E },
  unicodeslot=0x317B,
 },
 [0x317C]={
  adobename="siostikeutkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SIOS-TIKEUT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x112F },
  unicodeslot=0x317C,
 },
 [0x317D]={
  adobename="siospieupkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SIOS-PIEUP",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1132 },
  unicodeslot=0x317D,
 },
 [0x317E]={
  adobename="sioscieuckorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SIOS-CIEUC",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1136 },
  unicodeslot=0x317E,
 },
 [0x317F]={
  adobename="pansioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER PANSIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1140 },
  unicodeslot=0x317F,
 },
 [0x3180]={
  adobename="ssangieungkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SSANGIEUNG",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1147 },
  unicodeslot=0x3180,
 },
 [0x3181]={
  adobename="yesieungkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YESIEUNG",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x114C },
  unicodeslot=0x3181,
 },
 [0x3182]={
  adobename="yesieungsioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YESIEUNG-SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11F1 },
  unicodeslot=0x3182,
 },
 [0x3183]={
  adobename="yesieungpansioskorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YESIEUNG-PANSIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11F2 },
  unicodeslot=0x3183,
 },
 [0x3184]={
  adobename="kapyeounphieuphkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER KAPYEOUNPHIEUPH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1157 },
  unicodeslot=0x3184,
 },
 [0x3185]={
  adobename="ssanghieuhkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER SSANGHIEUH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1158 },
  unicodeslot=0x3185,
 },
 [0x3186]={
  adobename="yeorinhieuhkorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YEORINHIEUH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1159 },
  unicodeslot=0x3186,
 },
 [0x3187]={
  adobename="yoyakorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YO-YA",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1184 },
  unicodeslot=0x3187,
 },
 [0x3188]={
  adobename="yoyaekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YO-YAE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1185 },
  unicodeslot=0x3188,
 },
 [0x3189]={
  adobename="yoikorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YO-I",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1188 },
  unicodeslot=0x3189,
 },
 [0x318A]={
  adobename="yuyeokorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YU-YEO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1191 },
  unicodeslot=0x318A,
 },
 [0x318B]={
  adobename="yuyekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YU-YE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1192 },
  unicodeslot=0x318B,
 },
 [0x318C]={
  adobename="yuikorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER YU-I",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x1194 },
  unicodeslot=0x318C,
 },
 [0x318D]={
  adobename="araeakorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER ARAEA",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x119E },
  unicodeslot=0x318D,
 },
 [0x318E]={
  adobename="araeaekorean",
  category="lo",
  cjkwd="w",
  description="HANGUL LETTER ARAEAE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x11A1 },
  unicodeslot=0x318E,
 },
 [0x3190]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION LINKING MARK",
  direction="l",
  linebreak="id",
  unicodeslot=0x3190,
 },
 [0x3191]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION REVERSE MARK",
  direction="l",
  linebreak="id",
  unicodeslot=0x3191,
 },
 [0x3192]={
  category="no",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION ONE MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E00 },
  unicodeslot=0x3192,
 },
 [0x3193]={
  category="no",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION TWO MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E8C },
  unicodeslot=0x3193,
 },
 [0x3194]={
  category="no",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION THREE MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E09 },
  unicodeslot=0x3194,
 },
 [0x3195]={
  category="no",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION FOUR MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x56DB },
  unicodeslot=0x3195,
 },
 [0x3196]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION TOP MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E0A },
  unicodeslot=0x3196,
 },
 [0x3197]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION MIDDLE MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E2D },
  unicodeslot=0x3197,
 },
 [0x3198]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION BOTTOM MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E0B },
  unicodeslot=0x3198,
 },
 [0x3199]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION FIRST MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x7532 },
  unicodeslot=0x3199,
 },
 [0x319A]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION SECOND MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E59 },
  unicodeslot=0x319A,
 },
 [0x319B]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION THIRD MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E19 },
  unicodeslot=0x319B,
 },
 [0x319C]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION FOURTH MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4E01 },
  unicodeslot=0x319C,
 },
 [0x319D]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION HEAVEN MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x5929 },
  unicodeslot=0x319D,
 },
 [0x319E]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION EARTH MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x5730 },
  unicodeslot=0x319E,
 },
 [0x319F]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC ANNOTATION MAN MARK",
  direction="l",
  linebreak="id",
  specials={ "super", 0x4EBA },
  unicodeslot=0x319F,
 },
 [0x31A0]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER BU",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A0,
 },
 [0x31A1]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ZI",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A1,
 },
 [0x31A2]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER JI",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A2,
 },
 [0x31A3]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER GU",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A3,
 },
 [0x31A4]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER EE",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A4,
 },
 [0x31A5]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ENN",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A5,
 },
 [0x31A6]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER OO",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A6,
 },
 [0x31A7]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ONN",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A7,
 },
 [0x31A8]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER IR",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A8,
 },
 [0x31A9]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ANN",
  direction="l",
  linebreak="id",
  unicodeslot=0x31A9,
 },
 [0x31AA]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER INN",
  direction="l",
  linebreak="id",
  unicodeslot=0x31AA,
 },
 [0x31AB]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER UNN",
  direction="l",
  linebreak="id",
  unicodeslot=0x31AB,
 },
 [0x31AC]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER IM",
  direction="l",
  linebreak="id",
  unicodeslot=0x31AC,
 },
 [0x31AD]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER NGG",
  direction="l",
  linebreak="id",
  unicodeslot=0x31AD,
 },
 [0x31AE]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER AINN",
  direction="l",
  linebreak="id",
  unicodeslot=0x31AE,
 },
 [0x31AF]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER AUNN",
  direction="l",
  linebreak="id",
  unicodeslot=0x31AF,
 },
 [0x31B0]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER AM",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B0,
 },
 [0x31B1]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER OM",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B1,
 },
 [0x31B2]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ONG",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B2,
 },
 [0x31B3]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER INNN",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B3,
 },
 [0x31B4]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO FINAL LETTER P",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B4,
 },
 [0x31B5]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO FINAL LETTER T",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B5,
 },
 [0x31B6]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO FINAL LETTER K",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B6,
 },
 [0x31B7]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO FINAL LETTER H",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B7,
 },
 [0x31B8]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER GH",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B8,
 },
 [0x31B9]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER LH",
  direction="l",
  linebreak="id",
  unicodeslot=0x31B9,
 },
 [0x31BA]={
  category="lo",
  cjkwd="w",
  description="BOPOMOFO LETTER ZY",
  direction="l",
  linebreak="id",
  unicodeslot=0x31BA,
 },
 [0x31C0]={
  category="so",
  cjkwd="w",
  description="CJK STROKE T",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C0,
 },
 [0x31C1]={
  category="so",
  cjkwd="w",
  description="CJK STROKE WG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C1,
 },
 [0x31C2]={
  category="so",
  cjkwd="w",
  description="CJK STROKE XG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C2,
 },
 [0x31C3]={
  category="so",
  cjkwd="w",
  description="CJK STROKE BXG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C3,
 },
 [0x31C4]={
  category="so",
  cjkwd="w",
  description="CJK STROKE SW",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C4,
 },
 [0x31C5]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZZ",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C5,
 },
 [0x31C6]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C6,
 },
 [0x31C7]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HP",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C7,
 },
 [0x31C8]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZWG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C8,
 },
 [0x31C9]={
  category="so",
  cjkwd="w",
  description="CJK STROKE SZWG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31C9,
 },
 [0x31CA]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZT",
  direction="on",
  linebreak="id",
  unicodeslot=0x31CA,
 },
 [0x31CB]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZZP",
  direction="on",
  linebreak="id",
  unicodeslot=0x31CB,
 },
 [0x31CC]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HPWG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31CC,
 },
 [0x31CD]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZW",
  direction="on",
  linebreak="id",
  unicodeslot=0x31CD,
 },
 [0x31CE]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZZZ",
  direction="on",
  linebreak="id",
  unicodeslot=0x31CE,
 },
 [0x31CF]={
  category="so",
  cjkwd="w",
  description="CJK STROKE N",
  direction="on",
  linebreak="id",
  unicodeslot=0x31CF,
 },
 [0x31D0]={
  category="so",
  cjkwd="w",
  description="CJK STROKE H",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D0,
 },
 [0x31D1]={
  category="so",
  cjkwd="w",
  description="CJK STROKE S",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D1,
 },
 [0x31D2]={
  category="so",
  cjkwd="w",
  description="CJK STROKE P",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D2,
 },
 [0x31D3]={
  category="so",
  cjkwd="w",
  description="CJK STROKE SP",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D3,
 },
 [0x31D4]={
  category="so",
  cjkwd="w",
  description="CJK STROKE D",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D4,
 },
 [0x31D5]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZ",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D5,
 },
 [0x31D6]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D6,
 },
 [0x31D7]={
  category="so",
  cjkwd="w",
  description="CJK STROKE SZ",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D7,
 },
 [0x31D8]={
  category="so",
  cjkwd="w",
  description="CJK STROKE SWZ",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D8,
 },
 [0x31D9]={
  category="so",
  cjkwd="w",
  description="CJK STROKE ST",
  direction="on",
  linebreak="id",
  unicodeslot=0x31D9,
 },
 [0x31DA]={
  category="so",
  cjkwd="w",
  description="CJK STROKE SG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31DA,
 },
 [0x31DB]={
  category="so",
  cjkwd="w",
  description="CJK STROKE PD",
  direction="on",
  linebreak="id",
  unicodeslot=0x31DB,
 },
 [0x31DC]={
  category="so",
  cjkwd="w",
  description="CJK STROKE PZ",
  direction="on",
  linebreak="id",
  unicodeslot=0x31DC,
 },
 [0x31DD]={
  category="so",
  cjkwd="w",
  description="CJK STROKE TN",
  direction="on",
  linebreak="id",
  unicodeslot=0x31DD,
 },
 [0x31DE]={
  category="so",
  cjkwd="w",
  description="CJK STROKE SZZ",
  direction="on",
  linebreak="id",
  unicodeslot=0x31DE,
 },
 [0x31DF]={
  category="so",
  cjkwd="w",
  description="CJK STROKE SWG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31DF,
 },
 [0x31E0]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HXWG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31E0,
 },
 [0x31E1]={
  category="so",
  cjkwd="w",
  description="CJK STROKE HZZZG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31E1,
 },
 [0x31E2]={
  category="so",
  cjkwd="w",
  description="CJK STROKE PG",
  direction="on",
  linebreak="id",
  unicodeslot=0x31E2,
 },
 [0x31E3]={
  category="so",
  cjkwd="w",
  description="CJK STROKE Q",
  direction="on",
  linebreak="id",
  unicodeslot=0x31E3,
 },
 [0x31F0]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL KU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F0,
 },
 [0x31F1]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL SI",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F1,
 },
 [0x31F2]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL SU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F2,
 },
 [0x31F3]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL TO",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F3,
 },
 [0x31F4]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL NU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F4,
 },
 [0x31F5]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL HA",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F5,
 },
 [0x31F6]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL HI",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F6,
 },
 [0x31F7]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL HU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F7,
 },
 [0x31F8]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL HE",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F8,
 },
 [0x31F9]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL HO",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31F9,
 },
 [0x31FA]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL MU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31FA,
 },
 [0x31FB]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL RA",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31FB,
 },
 [0x31FC]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL RI",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31FC,
 },
 [0x31FD]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL RU",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31FD,
 },
 [0x31FE]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL RE",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31FE,
 },
 [0x31FF]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER SMALL RO",
  direction="l",
  linebreak="cj",
  unicodeslot=0x31FF,
 },
 [0x3200]={
  adobename="kiyeokparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL KIYEOK",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1100, 0x0029 },
  unicodeslot=0x3200,
 },
 [0x3201]={
  adobename="nieunparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL NIEUN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1102, 0x0029 },
  unicodeslot=0x3201,
 },
 [0x3202]={
  adobename="tikeutparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL TIKEUT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1103, 0x0029 },
  unicodeslot=0x3202,
 },
 [0x3203]={
  adobename="rieulparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL RIEUL",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1105, 0x0029 },
  unicodeslot=0x3203,
 },
 [0x3204]={
  adobename="mieumparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL MIEUM",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1106, 0x0029 },
  unicodeslot=0x3204,
 },
 [0x3205]={
  adobename="pieupparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL PIEUP",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1107, 0x0029 },
  unicodeslot=0x3205,
 },
 [0x3206]={
  adobename="siosparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL SIOS",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1109, 0x0029 },
  unicodeslot=0x3206,
 },
 [0x3207]={
  adobename="ieungparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL IEUNG",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110B, 0x0029 },
  unicodeslot=0x3207,
 },
 [0x3208]={
  adobename="cieucparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL CIEUC",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110C, 0x0029 },
  unicodeslot=0x3208,
 },
 [0x3209]={
  adobename="chieuchparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL CHIEUCH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110E, 0x0029 },
  unicodeslot=0x3209,
 },
 [0x320A]={
  adobename="khieukhparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL KHIEUKH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110F, 0x0029 },
  unicodeslot=0x320A,
 },
 [0x320B]={
  adobename="thieuthparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL THIEUTH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1110, 0x0029 },
  unicodeslot=0x320B,
 },
 [0x320C]={
  adobename="phieuphparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL PHIEUPH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1111, 0x0029 },
  unicodeslot=0x320C,
 },
 [0x320D]={
  adobename="hieuhparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL HIEUH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1112, 0x0029 },
  unicodeslot=0x320D,
 },
 [0x320E]={
  adobename="kiyeokaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL KIYEOK A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1100, 0x1161, 0x0029 },
  unicodeslot=0x320E,
 },
 [0x320F]={
  adobename="nieunaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL NIEUN A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1102, 0x1161, 0x0029 },
  unicodeslot=0x320F,
 },
 [0x3210]={
  adobename="tikeutaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL TIKEUT A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1103, 0x1161, 0x0029 },
  unicodeslot=0x3210,
 },
 [0x3211]={
  adobename="rieulaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL RIEUL A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1105, 0x1161, 0x0029 },
  unicodeslot=0x3211,
 },
 [0x3212]={
  adobename="mieumaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL MIEUM A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1106, 0x1161, 0x0029 },
  unicodeslot=0x3212,
 },
 [0x3213]={
  adobename="pieupaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL PIEUP A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1107, 0x1161, 0x0029 },
  unicodeslot=0x3213,
 },
 [0x3214]={
  adobename="siosaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL SIOS A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1109, 0x1161, 0x0029 },
  unicodeslot=0x3214,
 },
 [0x3215]={
  adobename="ieungaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL IEUNG A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110B, 0x1161, 0x0029 },
  unicodeslot=0x3215,
 },
 [0x3216]={
  adobename="cieucaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL CIEUC A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110C, 0x1161, 0x0029 },
  unicodeslot=0x3216,
 },
 [0x3217]={
  adobename="chieuchaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL CHIEUCH A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110E, 0x1161, 0x0029 },
  unicodeslot=0x3217,
 },
 [0x3218]={
  adobename="khieukhaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL KHIEUKH A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110F, 0x1161, 0x0029 },
  unicodeslot=0x3218,
 },
 [0x3219]={
  adobename="thieuthaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL THIEUTH A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1110, 0x1161, 0x0029 },
  unicodeslot=0x3219,
 },
 [0x321A]={
  adobename="phieuphaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL PHIEUPH A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1111, 0x1161, 0x0029 },
  unicodeslot=0x321A,
 },
 [0x321B]={
  adobename="hieuhaparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL HIEUH A",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x1112, 0x1161, 0x0029 },
  unicodeslot=0x321B,
 },
 [0x321C]={
  adobename="cieucuparenkorean",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED HANGUL CIEUC U",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110C, 0x116E, 0x0029 },
  unicodeslot=0x321C,
 },
 [0x321D]={
  category="so",
  cjkwd="w",
  description="PARENTHESIZED KOREAN CHARACTER OJEON",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110B, 0x1169, 0x110C, 0x1165, 0x11AB, 0x0029 },
  unicodeslot=0x321D,
 },
 [0x321E]={
  category="so",
  cjkwd="w",
  description="PARENTHESIZED KOREAN CHARACTER O HU",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x0028, 0x110B, 0x1169, 0x1112, 0x116E, 0x0029 },
  unicodeslot=0x321E,
 },
 [0x3220]={
  adobename="oneideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH ONE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4E00, 0x0029 },
  unicodeslot=0x3220,
 },
 [0x3221]={
  adobename="twoideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH TWO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4E8C, 0x0029 },
  unicodeslot=0x3221,
 },
 [0x3222]={
  adobename="threeideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH THREE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4E09, 0x0029 },
  unicodeslot=0x3222,
 },
 [0x3223]={
  adobename="fourideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH FOUR",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x56DB, 0x0029 },
  unicodeslot=0x3223,
 },
 [0x3224]={
  adobename="fiveideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH FIVE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4E94, 0x0029 },
  unicodeslot=0x3224,
 },
 [0x3225]={
  adobename="sixideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH SIX",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x516D, 0x0029 },
  unicodeslot=0x3225,
 },
 [0x3226]={
  adobename="sevenideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH SEVEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4E03, 0x0029 },
  unicodeslot=0x3226,
 },
 [0x3227]={
  adobename="eightideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH EIGHT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x516B, 0x0029 },
  unicodeslot=0x3227,
 },
 [0x3228]={
  adobename="nineideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH NINE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4E5D, 0x0029 },
  unicodeslot=0x3228,
 },
 [0x3229]={
  adobename="tenideographicparen",
  category="no",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH TEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x5341, 0x0029 },
  unicodeslot=0x3229,
 },
 [0x322A]={
  adobename="ideographicmoonparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH MOON",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x6708, 0x0029 },
  unicodeslot=0x322A,
 },
 [0x322B]={
  adobename="ideographicfireparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH FIRE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x706B, 0x0029 },
  unicodeslot=0x322B,
 },
 [0x322C]={
  adobename="ideographicwaterparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH WATER",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x6C34, 0x0029 },
  unicodeslot=0x322C,
 },
 [0x322D]={
  adobename="ideographicwoodparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH WOOD",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x6728, 0x0029 },
  unicodeslot=0x322D,
 },
 [0x322E]={
  adobename="ideographicmetalparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH METAL",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x91D1, 0x0029 },
  unicodeslot=0x322E,
 },
 [0x322F]={
  adobename="ideographicearthparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH EARTH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x571F, 0x0029 },
  unicodeslot=0x322F,
 },
 [0x3230]={
  adobename="ideographicsunparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH SUN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x65E5, 0x0029 },
  unicodeslot=0x3230,
 },
 [0x3231]={
  adobename="ideographicstockparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH STOCK",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x682A, 0x0029 },
  unicodeslot=0x3231,
 },
 [0x3232]={
  adobename="ideographichaveparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH HAVE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x6709, 0x0029 },
  unicodeslot=0x3232,
 },
 [0x3233]={
  adobename="ideographicsocietyparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH SOCIETY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x793E, 0x0029 },
  unicodeslot=0x3233,
 },
 [0x3234]={
  adobename="ideographicnameparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH NAME",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x540D, 0x0029 },
  unicodeslot=0x3234,
 },
 [0x3235]={
  adobename="ideographicspecialparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH SPECIAL",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x7279, 0x0029 },
  unicodeslot=0x3235,
 },
 [0x3236]={
  adobename="ideographicfinancialparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH FINANCIAL",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x8CA1, 0x0029 },
  unicodeslot=0x3236,
 },
 [0x3237]={
  adobename="ideographiccongratulationparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH CONGRATULATION",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x795D, 0x0029 },
  unicodeslot=0x3237,
 },
 [0x3238]={
  adobename="ideographiclaborparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH LABOR",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x52B4, 0x0029 },
  unicodeslot=0x3238,
 },
 [0x3239]={
  adobename="ideographicrepresentparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH REPRESENT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4EE3, 0x0029 },
  unicodeslot=0x3239,
 },
 [0x323A]={
  adobename="ideographiccallparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH CALL",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x547C, 0x0029 },
  unicodeslot=0x323A,
 },
 [0x323B]={
  adobename="ideographicstudyparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH STUDY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x5B66, 0x0029 },
  unicodeslot=0x323B,
 },
 [0x323C]={
  adobename="ideographicsuperviseparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH SUPERVISE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x76E3, 0x0029 },
  unicodeslot=0x323C,
 },
 [0x323D]={
  adobename="ideographicenterpriseparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH ENTERPRISE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4F01, 0x0029 },
  unicodeslot=0x323D,
 },
 [0x323E]={
  adobename="ideographicresourceparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH RESOURCE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x8CC7, 0x0029 },
  unicodeslot=0x323E,
 },
 [0x323F]={
  adobename="ideographicallianceparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH ALLIANCE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x5354, 0x0029 },
  unicodeslot=0x323F,
 },
 [0x3240]={
  adobename="ideographicfestivalparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH FESTIVAL",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x796D, 0x0029 },
  unicodeslot=0x3240,
 },
 [0x3241]={
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH REST",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x4F11, 0x0029 },
  unicodeslot=0x3241,
 },
 [0x3242]={
  adobename="ideographicselfparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH SELF",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x81EA, 0x0029 },
  unicodeslot=0x3242,
 },
 [0x3243]={
  adobename="ideographicreachparen",
  category="so",
  cjkwd="w",
  description="PARENTHESIZED IDEOGRAPH REACH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0028, 0x81F3, 0x0029 },
  unicodeslot=0x3243,
 },
 [0x3244]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH QUESTION",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x554F },
  unicodeslot=0x3244,
 },
 [0x3245]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH KINDERGARTEN",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5E7C },
  unicodeslot=0x3245,
 },
 [0x3246]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SCHOOL",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x6587 },
  unicodeslot=0x3246,
 },
 [0x3247]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH KOTO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x7B8F },
  unicodeslot=0x3247,
 },
 [0x3248]={
  category="so",
  cjkwd="a",
  description="CIRCLED NUMBER TEN ON BLACK SQUARE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x3248,
 },
 [0x3249]={
  category="so",
  cjkwd="a",
  description="CIRCLED NUMBER TWENTY ON BLACK SQUARE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x3249,
 },
 [0x324A]={
  category="so",
  cjkwd="a",
  description="CIRCLED NUMBER THIRTY ON BLACK SQUARE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x324A,
 },
 [0x324B]={
  category="so",
  cjkwd="a",
  description="CIRCLED NUMBER FORTY ON BLACK SQUARE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x324B,
 },
 [0x324C]={
  category="so",
  cjkwd="a",
  description="CIRCLED NUMBER FIFTY ON BLACK SQUARE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x324C,
 },
 [0x324D]={
  category="so",
  cjkwd="a",
  description="CIRCLED NUMBER SIXTY ON BLACK SQUARE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x324D,
 },
 [0x324E]={
  category="so",
  cjkwd="a",
  description="CIRCLED NUMBER SEVENTY ON BLACK SQUARE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x324E,
 },
 [0x324F]={
  category="so",
  cjkwd="a",
  description="CIRCLED NUMBER EIGHTY ON BLACK SQUARE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x324F,
 },
 [0x3250]={
  category="so",
  cjkwd="w",
  description="PARTNERSHIP SIGN",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0050, 0x0054, 0x0045 },
  unicodeslot=0x3250,
 },
 [0x3251]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY ONE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0031 },
  unicodeslot=0x3251,
 },
 [0x3252]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY TWO",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0032 },
  unicodeslot=0x3252,
 },
 [0x3253]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY THREE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0033 },
  unicodeslot=0x3253,
 },
 [0x3254]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY FOUR",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0034 },
  unicodeslot=0x3254,
 },
 [0x3255]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY FIVE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0035 },
  unicodeslot=0x3255,
 },
 [0x3256]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY SIX",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0036 },
  unicodeslot=0x3256,
 },
 [0x3257]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY SEVEN",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0037 },
  unicodeslot=0x3257,
 },
 [0x3258]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY EIGHT",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0038 },
  unicodeslot=0x3258,
 },
 [0x3259]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER TWENTY NINE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0032, 0x0039 },
  unicodeslot=0x3259,
 },
 [0x325A]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0030 },
  unicodeslot=0x325A,
 },
 [0x325B]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY ONE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0031 },
  unicodeslot=0x325B,
 },
 [0x325C]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY TWO",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0032 },
  unicodeslot=0x325C,
 },
 [0x325D]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY THREE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0033 },
  unicodeslot=0x325D,
 },
 [0x325E]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY FOUR",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0034 },
  unicodeslot=0x325E,
 },
 [0x325F]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY FIVE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0035 },
  unicodeslot=0x325F,
 },
 [0x3260]={
  adobename="kiyeokcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL KIYEOK",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1100 },
  unicodeslot=0x3260,
 },
 [0x3261]={
  adobename="nieuncirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL NIEUN",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1102 },
  unicodeslot=0x3261,
 },
 [0x3262]={
  adobename="tikeutcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL TIKEUT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1103 },
  unicodeslot=0x3262,
 },
 [0x3263]={
  adobename="rieulcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL RIEUL",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1105 },
  unicodeslot=0x3263,
 },
 [0x3264]={
  adobename="mieumcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL MIEUM",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1106 },
  unicodeslot=0x3264,
 },
 [0x3265]={
  adobename="pieupcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL PIEUP",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1107 },
  unicodeslot=0x3265,
 },
 [0x3266]={
  adobename="sioscirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL SIOS",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1109 },
  unicodeslot=0x3266,
 },
 [0x3267]={
  adobename="ieungcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL IEUNG",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x110B },
  unicodeslot=0x3267,
 },
 [0x3268]={
  adobename="cieuccirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL CIEUC",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x110C },
  unicodeslot=0x3268,
 },
 [0x3269]={
  adobename="chieuchcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL CHIEUCH",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x110E },
  unicodeslot=0x3269,
 },
 [0x326A]={
  adobename="khieukhcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL KHIEUKH",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x110F },
  unicodeslot=0x326A,
 },
 [0x326B]={
  adobename="thieuthcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL THIEUTH",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1110 },
  unicodeslot=0x326B,
 },
 [0x326C]={
  adobename="phieuphcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL PHIEUPH",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1111 },
  unicodeslot=0x326C,
 },
 [0x326D]={
  adobename="hieuhcirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL HIEUH",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1112 },
  unicodeslot=0x326D,
 },
 [0x326E]={
  adobename="kiyeokacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL KIYEOK A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1100, 0x1161 },
  unicodeslot=0x326E,
 },
 [0x326F]={
  adobename="nieunacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL NIEUN A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1102, 0x1161 },
  unicodeslot=0x326F,
 },
 [0x3270]={
  adobename="tikeutacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL TIKEUT A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1103, 0x1161 },
  unicodeslot=0x3270,
 },
 [0x3271]={
  adobename="rieulacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL RIEUL A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1105, 0x1161 },
  unicodeslot=0x3271,
 },
 [0x3272]={
  adobename="mieumacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL MIEUM A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1106, 0x1161 },
  unicodeslot=0x3272,
 },
 [0x3273]={
  adobename="pieupacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL PIEUP A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1107, 0x1161 },
  unicodeslot=0x3273,
 },
 [0x3274]={
  adobename="siosacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL SIOS A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1109, 0x1161 },
  unicodeslot=0x3274,
 },
 [0x3275]={
  adobename="ieungacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL IEUNG A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x110B, 0x1161 },
  unicodeslot=0x3275,
 },
 [0x3276]={
  adobename="cieucacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL CIEUC A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x110C, 0x1161 },
  unicodeslot=0x3276,
 },
 [0x3277]={
  adobename="chieuchacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL CHIEUCH A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x110E, 0x1161 },
  unicodeslot=0x3277,
 },
 [0x3278]={
  adobename="khieukhacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL KHIEUKH A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x110F, 0x1161 },
  unicodeslot=0x3278,
 },
 [0x3279]={
  adobename="thieuthacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL THIEUTH A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1110, 0x1161 },
  unicodeslot=0x3279,
 },
 [0x327A]={
  adobename="phieuphacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL PHIEUPH A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1111, 0x1161 },
  unicodeslot=0x327A,
 },
 [0x327B]={
  adobename="hieuhacirclekorean",
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL HIEUH A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x1112, 0x1161 },
  unicodeslot=0x327B,
 },
 [0x327C]={
  category="so",
  cjkwd="w",
  description="CIRCLED KOREAN CHARACTER CHAMKO",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x110E, 0x1161, 0x11B7, 0x1100, 0x1169 },
  unicodeslot=0x327C,
 },
 [0x327D]={
  category="so",
  cjkwd="w",
  description="CIRCLED KOREAN CHARACTER JUEUI",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x110C, 0x116E, 0x110B, 0x1174 },
  unicodeslot=0x327D,
 },
 [0x327E]={
  category="so",
  cjkwd="w",
  description="CIRCLED HANGUL IEUNG U",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x110B, 0x116E },
  unicodeslot=0x327E,
 },
 [0x327F]={
  adobename="koreanstandardsymbol",
  category="so",
  cjkwd="w",
  description="KOREAN STANDARD SYMBOL",
  direction="l",
  linebreak="id",
  unicodeslot=0x327F,
 },
 [0x3280]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH ONE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E00 },
  unicodeslot=0x3280,
 },
 [0x3281]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH TWO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E8C },
  unicodeslot=0x3281,
 },
 [0x3282]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH THREE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E09 },
  unicodeslot=0x3282,
 },
 [0x3283]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH FOUR",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x56DB },
  unicodeslot=0x3283,
 },
 [0x3284]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH FIVE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E94 },
  unicodeslot=0x3284,
 },
 [0x3285]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SIX",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x516D },
  unicodeslot=0x3285,
 },
 [0x3286]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SEVEN",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E03 },
  unicodeslot=0x3286,
 },
 [0x3287]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH EIGHT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x516B },
  unicodeslot=0x3287,
 },
 [0x3288]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH NINE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E5D },
  unicodeslot=0x3288,
 },
 [0x3289]={
  category="no",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH TEN",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5341 },
  unicodeslot=0x3289,
 },
 [0x328A]={
  adobename="ideographmooncircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH MOON",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x6708 },
  unicodeslot=0x328A,
 },
 [0x328B]={
  adobename="ideographfirecircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH FIRE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x706B },
  unicodeslot=0x328B,
 },
 [0x328C]={
  adobename="ideographwatercircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH WATER",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x6C34 },
  unicodeslot=0x328C,
 },
 [0x328D]={
  adobename="ideographwoodcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH WOOD",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x6728 },
  unicodeslot=0x328D,
 },
 [0x328E]={
  adobename="ideographmetalcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH METAL",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x91D1 },
  unicodeslot=0x328E,
 },
 [0x328F]={
  adobename="ideographearthcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH EARTH",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x571F },
  unicodeslot=0x328F,
 },
 [0x3290]={
  adobename="ideographsuncircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SUN",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x65E5 },
  unicodeslot=0x3290,
 },
 [0x3291]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH STOCK",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x682A },
  unicodeslot=0x3291,
 },
 [0x3292]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH HAVE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x6709 },
  unicodeslot=0x3292,
 },
 [0x3293]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SOCIETY",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x793E },
  unicodeslot=0x3293,
 },
 [0x3294]={
  adobename="ideographnamecircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH NAME",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x540D },
  unicodeslot=0x3294,
 },
 [0x3295]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SPECIAL",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x7279 },
  unicodeslot=0x3295,
 },
 [0x3296]={
  adobename="ideographicfinancialcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH FINANCIAL",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x8CA1 },
  unicodeslot=0x3296,
 },
 [0x3297]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH CONGRATULATION",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x795D },
  unicodeslot=0x3297,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x3298]={
  adobename="ideographiclaborcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH LABOR",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x52B4 },
  unicodeslot=0x3298,
 },
 [0x3299]={
  adobename="ideographicsecretcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SECRET",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x79D8 },
  unicodeslot=0x3299,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x329A]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH MALE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x7537 },
  unicodeslot=0x329A,
 },
 [0x329B]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH FEMALE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5973 },
  unicodeslot=0x329B,
 },
 [0x329C]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SUITABLE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x9069 },
  unicodeslot=0x329C,
 },
 [0x329D]={
  adobename="ideographicexcellentcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH EXCELLENT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x512A },
  unicodeslot=0x329D,
 },
 [0x329E]={
  adobename="ideographicprintcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH PRINT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5370 },
  unicodeslot=0x329E,
 },
 [0x329F]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH ATTENTION",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x6CE8 },
  unicodeslot=0x329F,
 },
 [0x32A0]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH ITEM",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x9805 },
  unicodeslot=0x32A0,
 },
 [0x32A1]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH REST",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4F11 },
  unicodeslot=0x32A1,
 },
 [0x32A2]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH COPY",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5199 },
  unicodeslot=0x32A2,
 },
 [0x32A3]={
  adobename="ideographiccorrectcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH CORRECT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x6B63 },
  unicodeslot=0x32A3,
 },
 [0x32A4]={
  adobename="ideographichighcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH HIGH",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E0A },
  unicodeslot=0x32A4,
 },
 [0x32A5]={
  adobename="ideographiccentrecircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH CENTRE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E2D },
  unicodeslot=0x32A5,
 },
 [0x32A6]={
  adobename="ideographiclowcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH LOW",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4E0B },
  unicodeslot=0x32A6,
 },
 [0x32A7]={
  adobename="ideographicleftcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH LEFT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5DE6 },
  unicodeslot=0x32A7,
 },
 [0x32A8]={
  adobename="ideographicrightcircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH RIGHT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x53F3 },
  unicodeslot=0x32A8,
 },
 [0x32A9]={
  adobename="ideographicmedicinecircle",
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH MEDICINE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x533B },
  unicodeslot=0x32A9,
 },
 [0x32AA]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH RELIGION",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5B97 },
  unicodeslot=0x32AA,
 },
 [0x32AB]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH STUDY",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5B66 },
  unicodeslot=0x32AB,
 },
 [0x32AC]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH SUPERVISE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x76E3 },
  unicodeslot=0x32AC,
 },
 [0x32AD]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH ENTERPRISE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x4F01 },
  unicodeslot=0x32AD,
 },
 [0x32AE]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH RESOURCE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x8CC7 },
  unicodeslot=0x32AE,
 },
 [0x32AF]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH ALLIANCE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5354 },
  unicodeslot=0x32AF,
 },
 [0x32B0]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH NIGHT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x591C },
  unicodeslot=0x32B0,
 },
 [0x32B1]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY SIX",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0036 },
  unicodeslot=0x32B1,
 },
 [0x32B2]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY SEVEN",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0037 },
  unicodeslot=0x32B2,
 },
 [0x32B3]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY EIGHT",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0038 },
  unicodeslot=0x32B3,
 },
 [0x32B4]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER THIRTY NINE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0033, 0x0039 },
  unicodeslot=0x32B4,
 },
 [0x32B5]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0030 },
  unicodeslot=0x32B5,
 },
 [0x32B6]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY ONE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0031 },
  unicodeslot=0x32B6,
 },
 [0x32B7]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY TWO",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0032 },
  unicodeslot=0x32B7,
 },
 [0x32B8]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY THREE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0033 },
  unicodeslot=0x32B8,
 },
 [0x32B9]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY FOUR",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0034 },
  unicodeslot=0x32B9,
 },
 [0x32BA]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY FIVE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0035 },
  unicodeslot=0x32BA,
 },
 [0x32BB]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY SIX",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0036 },
  unicodeslot=0x32BB,
 },
 [0x32BC]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY SEVEN",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0037 },
  unicodeslot=0x32BC,
 },
 [0x32BD]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY EIGHT",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0038 },
  unicodeslot=0x32BD,
 },
 [0x32BE]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FORTY NINE",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0034, 0x0039 },
  unicodeslot=0x32BE,
 },
 [0x32BF]={
  category="no",
  cjkwd="w",
  description="CIRCLED NUMBER FIFTY",
  direction="on",
  linebreak="id",
  specials={ "circle", 0x0035, 0x0030 },
  unicodeslot=0x32BF,
 },
 [0x32C0]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR JANUARY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x6708 },
  unicodeslot=0x32C0,
 },
 [0x32C1]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR FEBRUARY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x6708 },
  unicodeslot=0x32C1,
 },
 [0x32C2]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR MARCH",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0033, 0x6708 },
  unicodeslot=0x32C2,
 },
 [0x32C3]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR APRIL",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0034, 0x6708 },
  unicodeslot=0x32C3,
 },
 [0x32C4]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR MAY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0035, 0x6708 },
  unicodeslot=0x32C4,
 },
 [0x32C5]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR JUNE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0036, 0x6708 },
  unicodeslot=0x32C5,
 },
 [0x32C6]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR JULY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0037, 0x6708 },
  unicodeslot=0x32C6,
 },
 [0x32C7]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR AUGUST",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0038, 0x6708 },
  unicodeslot=0x32C7,
 },
 [0x32C8]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR SEPTEMBER",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0039, 0x6708 },
  unicodeslot=0x32C8,
 },
 [0x32C9]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR OCTOBER",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0030, 0x6708 },
  unicodeslot=0x32C9,
 },
 [0x32CA]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR NOVEMBER",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0031, 0x6708 },
  unicodeslot=0x32CA,
 },
 [0x32CB]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DECEMBER",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0032, 0x6708 },
  unicodeslot=0x32CB,
 },
 [0x32CC]={
  category="so",
  cjkwd="w",
  description="SQUARE HG",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0048, 0x0067 },
  unicodeslot=0x32CC,
 },
 [0x32CD]={
  category="so",
  cjkwd="w",
  description="SQUARE ERG",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0065, 0x0072, 0x0067 },
  unicodeslot=0x32CD,
 },
 [0x32CE]={
  category="so",
  cjkwd="w",
  description="SQUARE EV",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0065, 0x0056 },
  unicodeslot=0x32CE,
 },
 [0x32CF]={
  category="so",
  cjkwd="w",
  description="LIMITED LIABILITY SIGN",
  direction="on",
  linebreak="id",
  specials={ "square", 0x004C, 0x0054, 0x0044 },
  unicodeslot=0x32CF,
 },
 [0x32D0]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA A",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30A2 },
  unicodeslot=0x32D0,
 },
 [0x32D1]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA I",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30A4 },
  unicodeslot=0x32D1,
 },
 [0x32D2]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA U",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30A6 },
  unicodeslot=0x32D2,
 },
 [0x32D3]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA E",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30A8 },
  unicodeslot=0x32D3,
 },
 [0x32D4]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA O",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30AA },
  unicodeslot=0x32D4,
 },
 [0x32D5]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA KA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30AB },
  unicodeslot=0x32D5,
 },
 [0x32D6]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA KI",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30AD },
  unicodeslot=0x32D6,
 },
 [0x32D7]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA KU",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30AF },
  unicodeslot=0x32D7,
 },
 [0x32D8]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA KE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30B1 },
  unicodeslot=0x32D8,
 },
 [0x32D9]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA KO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30B3 },
  unicodeslot=0x32D9,
 },
 [0x32DA]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA SA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30B5 },
  unicodeslot=0x32DA,
 },
 [0x32DB]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA SI",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30B7 },
  unicodeslot=0x32DB,
 },
 [0x32DC]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA SU",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30B9 },
  unicodeslot=0x32DC,
 },
 [0x32DD]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA SE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30BB },
  unicodeslot=0x32DD,
 },
 [0x32DE]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA SO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30BD },
  unicodeslot=0x32DE,
 },
 [0x32DF]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA TA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30BF },
  unicodeslot=0x32DF,
 },
 [0x32E0]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA TI",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30C1 },
  unicodeslot=0x32E0,
 },
 [0x32E1]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA TU",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30C4 },
  unicodeslot=0x32E1,
 },
 [0x32E2]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA TE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30C6 },
  unicodeslot=0x32E2,
 },
 [0x32E3]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA TO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30C8 },
  unicodeslot=0x32E3,
 },
 [0x32E4]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA NA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30CA },
  unicodeslot=0x32E4,
 },
 [0x32E5]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA NI",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30CB },
  unicodeslot=0x32E5,
 },
 [0x32E6]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA NU",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30CC },
  unicodeslot=0x32E6,
 },
 [0x32E7]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA NE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30CD },
  unicodeslot=0x32E7,
 },
 [0x32E8]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA NO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30CE },
  unicodeslot=0x32E8,
 },
 [0x32E9]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA HA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30CF },
  unicodeslot=0x32E9,
 },
 [0x32EA]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA HI",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30D2 },
  unicodeslot=0x32EA,
 },
 [0x32EB]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA HU",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30D5 },
  unicodeslot=0x32EB,
 },
 [0x32EC]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA HE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30D8 },
  unicodeslot=0x32EC,
 },
 [0x32ED]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA HO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30DB },
  unicodeslot=0x32ED,
 },
 [0x32EE]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA MA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30DE },
  unicodeslot=0x32EE,
 },
 [0x32EF]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA MI",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30DF },
  unicodeslot=0x32EF,
 },
 [0x32F0]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA MU",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30E0 },
  unicodeslot=0x32F0,
 },
 [0x32F1]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA ME",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30E1 },
  unicodeslot=0x32F1,
 },
 [0x32F2]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA MO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30E2 },
  unicodeslot=0x32F2,
 },
 [0x32F3]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA YA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30E4 },
  unicodeslot=0x32F3,
 },
 [0x32F4]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA YU",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30E6 },
  unicodeslot=0x32F4,
 },
 [0x32F5]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA YO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30E8 },
  unicodeslot=0x32F5,
 },
 [0x32F6]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA RA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30E9 },
  unicodeslot=0x32F6,
 },
 [0x32F7]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA RI",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30EA },
  unicodeslot=0x32F7,
 },
 [0x32F8]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA RU",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30EB },
  unicodeslot=0x32F8,
 },
 [0x32F9]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA RE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30EC },
  unicodeslot=0x32F9,
 },
 [0x32FA]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA RO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30ED },
  unicodeslot=0x32FA,
 },
 [0x32FB]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA WA",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30EF },
  unicodeslot=0x32FB,
 },
 [0x32FC]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA WI",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30F0 },
  unicodeslot=0x32FC,
 },
 [0x32FD]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA WE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30F1 },
  unicodeslot=0x32FD,
 },
 [0x32FE]={
  category="so",
  cjkwd="w",
  description="CIRCLED KATAKANA WO",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x30F2 },
  unicodeslot=0x32FE,
 },
 [0x3300]={
  adobename="apaatosquare",
  category="so",
  cjkwd="w",
  description="SQUARE APAATO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A2, 0x30D1, 0x30FC, 0x30C8 },
  unicodeslot=0x3300,
 },
 [0x3301]={
  category="so",
  cjkwd="w",
  description="SQUARE ARUHUA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A2, 0x30EB, 0x30D5, 0x30A1 },
  unicodeslot=0x3301,
 },
 [0x3302]={
  category="so",
  cjkwd="w",
  description="SQUARE ANPEA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A2, 0x30F3, 0x30DA, 0x30A2 },
  unicodeslot=0x3302,
 },
 [0x3303]={
  adobename="aarusquare",
  category="so",
  cjkwd="w",
  description="SQUARE AARU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A2, 0x30FC, 0x30EB },
  unicodeslot=0x3303,
 },
 [0x3304]={
  category="so",
  cjkwd="w",
  description="SQUARE ININGU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A4, 0x30CB, 0x30F3, 0x30B0 },
  unicodeslot=0x3304,
 },
 [0x3305]={
  adobename="intisquare",
  category="so",
  cjkwd="w",
  description="SQUARE INTI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A4, 0x30F3, 0x30C1 },
  unicodeslot=0x3305,
 },
 [0x3306]={
  category="so",
  cjkwd="w",
  description="SQUARE UON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A6, 0x30A9, 0x30F3 },
  unicodeslot=0x3306,
 },
 [0x3307]={
  category="so",
  cjkwd="w",
  description="SQUARE ESUKUUDO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A8, 0x30B9, 0x30AF, 0x30FC, 0x30C9 },
  unicodeslot=0x3307,
 },
 [0x3308]={
  category="so",
  cjkwd="w",
  description="SQUARE EEKAA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30A8, 0x30FC, 0x30AB, 0x30FC },
  unicodeslot=0x3308,
 },
 [0x3309]={
  category="so",
  cjkwd="w",
  description="SQUARE ONSU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AA, 0x30F3, 0x30B9 },
  unicodeslot=0x3309,
 },
 [0x330A]={
  category="so",
  cjkwd="w",
  description="SQUARE OOMU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AA, 0x30FC, 0x30E0 },
  unicodeslot=0x330A,
 },
 [0x330B]={
  category="so",
  cjkwd="w",
  description="SQUARE KAIRI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AB, 0x30A4, 0x30EA },
  unicodeslot=0x330B,
 },
 [0x330C]={
  category="so",
  cjkwd="w",
  description="SQUARE KARATTO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AB, 0x30E9, 0x30C3, 0x30C8 },
  unicodeslot=0x330C,
 },
 [0x330D]={
  adobename="karoriisquare",
  category="so",
  cjkwd="w",
  description="SQUARE KARORII",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AB, 0x30ED, 0x30EA, 0x30FC },
  unicodeslot=0x330D,
 },
 [0x330E]={
  category="so",
  cjkwd="w",
  description="SQUARE GARON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AC, 0x30ED, 0x30F3 },
  unicodeslot=0x330E,
 },
 [0x330F]={
  category="so",
  cjkwd="w",
  description="SQUARE GANMA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AC, 0x30F3, 0x30DE },
  unicodeslot=0x330F,
 },
 [0x3310]={
  category="so",
  cjkwd="w",
  description="SQUARE GIGA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AE, 0x30AC },
  unicodeslot=0x3310,
 },
 [0x3311]={
  category="so",
  cjkwd="w",
  description="SQUARE GINII",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AE, 0x30CB, 0x30FC },
  unicodeslot=0x3311,
 },
 [0x3312]={
  category="so",
  cjkwd="w",
  description="SQUARE KYURII",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AD, 0x30E5, 0x30EA, 0x30FC },
  unicodeslot=0x3312,
 },
 [0x3313]={
  category="so",
  cjkwd="w",
  description="SQUARE GIRUDAA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AE, 0x30EB, 0x30C0, 0x30FC },
  unicodeslot=0x3313,
 },
 [0x3314]={
  adobename="kirosquare",
  category="so",
  cjkwd="w",
  description="SQUARE KIRO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AD, 0x30ED },
  unicodeslot=0x3314,
 },
 [0x3315]={
  adobename="kiroguramusquare",
  category="so",
  cjkwd="w",
  description="SQUARE KIROGURAMU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AD, 0x30ED, 0x30B0, 0x30E9, 0x30E0 },
  unicodeslot=0x3315,
 },
 [0x3316]={
  adobename="kiromeetorusquare",
  category="so",
  cjkwd="w",
  description="SQUARE KIROMEETORU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AD, 0x30ED, 0x30E1, 0x30FC, 0x30C8, 0x30EB },
  unicodeslot=0x3316,
 },
 [0x3317]={
  category="so",
  cjkwd="w",
  description="SQUARE KIROWATTO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AD, 0x30ED, 0x30EF, 0x30C3, 0x30C8 },
  unicodeslot=0x3317,
 },
 [0x3318]={
  adobename="guramusquare",
  category="so",
  cjkwd="w",
  description="SQUARE GURAMU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B0, 0x30E9, 0x30E0 },
  unicodeslot=0x3318,
 },
 [0x3319]={
  category="so",
  cjkwd="w",
  description="SQUARE GURAMUTON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B0, 0x30E9, 0x30E0, 0x30C8, 0x30F3 },
  unicodeslot=0x3319,
 },
 [0x331A]={
  category="so",
  cjkwd="w",
  description="SQUARE KURUZEIRO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AF, 0x30EB, 0x30BC, 0x30A4, 0x30ED },
  unicodeslot=0x331A,
 },
 [0x331B]={
  category="so",
  cjkwd="w",
  description="SQUARE KUROONE",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30AF, 0x30ED, 0x30FC, 0x30CD },
  unicodeslot=0x331B,
 },
 [0x331C]={
  category="so",
  cjkwd="w",
  description="SQUARE KEESU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B1, 0x30FC, 0x30B9 },
  unicodeslot=0x331C,
 },
 [0x331D]={
  category="so",
  cjkwd="w",
  description="SQUARE KORUNA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B3, 0x30EB, 0x30CA },
  unicodeslot=0x331D,
 },
 [0x331E]={
  adobename="kooposquare",
  category="so",
  cjkwd="w",
  description="SQUARE KOOPO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B3, 0x30FC, 0x30DD },
  unicodeslot=0x331E,
 },
 [0x331F]={
  category="so",
  cjkwd="w",
  description="SQUARE SAIKURU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B5, 0x30A4, 0x30AF, 0x30EB },
  unicodeslot=0x331F,
 },
 [0x3320]={
  category="so",
  cjkwd="w",
  description="SQUARE SANTIIMU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B5, 0x30F3, 0x30C1, 0x30FC, 0x30E0 },
  unicodeslot=0x3320,
 },
 [0x3321]={
  category="so",
  cjkwd="w",
  description="SQUARE SIRINGU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B7, 0x30EA, 0x30F3, 0x30B0 },
  unicodeslot=0x3321,
 },
 [0x3322]={
  adobename="sentisquare",
  category="so",
  cjkwd="w",
  description="SQUARE SENTI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30BB, 0x30F3, 0x30C1 },
  unicodeslot=0x3322,
 },
 [0x3323]={
  adobename="sentosquare",
  category="so",
  cjkwd="w",
  description="SQUARE SENTO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30BB, 0x30F3, 0x30C8 },
  unicodeslot=0x3323,
 },
 [0x3324]={
  category="so",
  cjkwd="w",
  description="SQUARE DAASU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30C0, 0x30FC, 0x30B9 },
  unicodeslot=0x3324,
 },
 [0x3325]={
  category="so",
  cjkwd="w",
  description="SQUARE DESI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30C7, 0x30B7 },
  unicodeslot=0x3325,
 },
 [0x3326]={
  adobename="dorusquare",
  category="so",
  cjkwd="w",
  description="SQUARE DORU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30C9, 0x30EB },
  unicodeslot=0x3326,
 },
 [0x3327]={
  adobename="tonsquare",
  category="so",
  cjkwd="w",
  description="SQUARE TON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30C8, 0x30F3 },
  unicodeslot=0x3327,
 },
 [0x3328]={
  category="so",
  cjkwd="w",
  description="SQUARE NANO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30CA, 0x30CE },
  unicodeslot=0x3328,
 },
 [0x3329]={
  category="so",
  cjkwd="w",
  description="SQUARE NOTTO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30CE, 0x30C3, 0x30C8 },
  unicodeslot=0x3329,
 },
 [0x332A]={
  adobename="haitusquare",
  category="so",
  cjkwd="w",
  description="SQUARE HAITU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30CF, 0x30A4, 0x30C4 },
  unicodeslot=0x332A,
 },
 [0x332B]={
  adobename="paasentosquare",
  category="so",
  cjkwd="w",
  description="SQUARE PAASENTO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D1, 0x30FC, 0x30BB, 0x30F3, 0x30C8 },
  unicodeslot=0x332B,
 },
 [0x332C]={
  category="so",
  cjkwd="w",
  description="SQUARE PAATU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D1, 0x30FC, 0x30C4 },
  unicodeslot=0x332C,
 },
 [0x332D]={
  category="so",
  cjkwd="w",
  description="SQUARE BAARERU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D0, 0x30FC, 0x30EC, 0x30EB },
  unicodeslot=0x332D,
 },
 [0x332E]={
  category="so",
  cjkwd="w",
  description="SQUARE PIASUTORU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D4, 0x30A2, 0x30B9, 0x30C8, 0x30EB },
  unicodeslot=0x332E,
 },
 [0x332F]={
  category="so",
  cjkwd="w",
  description="SQUARE PIKURU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D4, 0x30AF, 0x30EB },
  unicodeslot=0x332F,
 },
 [0x3330]={
  category="so",
  cjkwd="w",
  description="SQUARE PIKO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D4, 0x30B3 },
  unicodeslot=0x3330,
 },
 [0x3331]={
  adobename="birusquare",
  category="so",
  cjkwd="w",
  description="SQUARE BIRU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D3, 0x30EB },
  unicodeslot=0x3331,
 },
 [0x3332]={
  category="so",
  cjkwd="w",
  description="SQUARE HUARADDO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D5, 0x30A1, 0x30E9, 0x30C3, 0x30C9 },
  unicodeslot=0x3332,
 },
 [0x3333]={
  adobename="huiitosquare",
  category="so",
  cjkwd="w",
  description="SQUARE HUIITO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D5, 0x30A3, 0x30FC, 0x30C8 },
  unicodeslot=0x3333,
 },
 [0x3334]={
  category="so",
  cjkwd="w",
  description="SQUARE BUSSYERU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D6, 0x30C3, 0x30B7, 0x30A7, 0x30EB },
  unicodeslot=0x3334,
 },
 [0x3335]={
  category="so",
  cjkwd="w",
  description="SQUARE HURAN",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D5, 0x30E9, 0x30F3 },
  unicodeslot=0x3335,
 },
 [0x3336]={
  adobename="hekutaarusquare",
  category="so",
  cjkwd="w",
  description="SQUARE HEKUTAARU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D8, 0x30AF, 0x30BF, 0x30FC, 0x30EB },
  unicodeslot=0x3336,
 },
 [0x3337]={
  category="so",
  cjkwd="w",
  description="SQUARE PESO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DA, 0x30BD },
  unicodeslot=0x3337,
 },
 [0x3338]={
  category="so",
  cjkwd="w",
  description="SQUARE PENIHI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DA, 0x30CB, 0x30D2 },
  unicodeslot=0x3338,
 },
 [0x3339]={
  adobename="herutusquare",
  category="so",
  cjkwd="w",
  description="SQUARE HERUTU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D8, 0x30EB, 0x30C4 },
  unicodeslot=0x3339,
 },
 [0x333A]={
  category="so",
  cjkwd="w",
  description="SQUARE PENSU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DA, 0x30F3, 0x30B9 },
  unicodeslot=0x333A,
 },
 [0x333B]={
  adobename="peezisquare",
  category="so",
  cjkwd="w",
  description="SQUARE PEEZI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DA, 0x30FC, 0x30B8 },
  unicodeslot=0x333B,
 },
 [0x333C]={
  category="so",
  cjkwd="w",
  description="SQUARE BEETA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30D9, 0x30FC, 0x30BF },
  unicodeslot=0x333C,
 },
 [0x333D]={
  category="so",
  cjkwd="w",
  description="SQUARE POINTO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DD, 0x30A4, 0x30F3, 0x30C8 },
  unicodeslot=0x333D,
 },
 [0x333E]={
  category="so",
  cjkwd="w",
  description="SQUARE BORUTO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DC, 0x30EB, 0x30C8 },
  unicodeslot=0x333E,
 },
 [0x333F]={
  category="so",
  cjkwd="w",
  description="SQUARE HON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DB, 0x30F3 },
  unicodeslot=0x333F,
 },
 [0x3340]={
  category="so",
  cjkwd="w",
  description="SQUARE PONDO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DD, 0x30F3, 0x30C9 },
  unicodeslot=0x3340,
 },
 [0x3341]={
  category="so",
  cjkwd="w",
  description="SQUARE HOORU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DB, 0x30FC, 0x30EB },
  unicodeslot=0x3341,
 },
 [0x3342]={
  adobename="hoonsquare",
  category="so",
  cjkwd="w",
  description="SQUARE HOON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DB, 0x30FC, 0x30F3 },
  unicodeslot=0x3342,
 },
 [0x3343]={
  category="so",
  cjkwd="w",
  description="SQUARE MAIKURO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DE, 0x30A4, 0x30AF, 0x30ED },
  unicodeslot=0x3343,
 },
 [0x3344]={
  category="so",
  cjkwd="w",
  description="SQUARE MAIRU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DE, 0x30A4, 0x30EB },
  unicodeslot=0x3344,
 },
 [0x3345]={
  category="so",
  cjkwd="w",
  description="SQUARE MAHHA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DE, 0x30C3, 0x30CF },
  unicodeslot=0x3345,
 },
 [0x3346]={
  category="so",
  cjkwd="w",
  description="SQUARE MARUKU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DE, 0x30EB, 0x30AF },
  unicodeslot=0x3346,
 },
 [0x3347]={
  adobename="mansyonsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MANSYON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DE, 0x30F3, 0x30B7, 0x30E7, 0x30F3 },
  unicodeslot=0x3347,
 },
 [0x3348]={
  category="so",
  cjkwd="w",
  description="SQUARE MIKURON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DF, 0x30AF, 0x30ED, 0x30F3 },
  unicodeslot=0x3348,
 },
 [0x3349]={
  adobename="mirisquare",
  category="so",
  cjkwd="w",
  description="SQUARE MIRI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DF, 0x30EA },
  unicodeslot=0x3349,
 },
 [0x334A]={
  adobename="miribaarusquare",
  category="so",
  cjkwd="w",
  description="SQUARE MIRIBAARU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30DF, 0x30EA, 0x30D0, 0x30FC, 0x30EB },
  unicodeslot=0x334A,
 },
 [0x334B]={
  category="so",
  cjkwd="w",
  description="SQUARE MEGA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30E1, 0x30AC },
  unicodeslot=0x334B,
 },
 [0x334C]={
  category="so",
  cjkwd="w",
  description="SQUARE MEGATON",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30E1, 0x30AC, 0x30C8, 0x30F3 },
  unicodeslot=0x334C,
 },
 [0x334D]={
  adobename="meetorusquare",
  category="so",
  cjkwd="w",
  description="SQUARE MEETORU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30E1, 0x30FC, 0x30C8, 0x30EB },
  unicodeslot=0x334D,
 },
 [0x334E]={
  adobename="yaadosquare",
  category="so",
  cjkwd="w",
  description="SQUARE YAADO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30E4, 0x30FC, 0x30C9 },
  unicodeslot=0x334E,
 },
 [0x334F]={
  category="so",
  cjkwd="w",
  description="SQUARE YAARU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30E4, 0x30FC, 0x30EB },
  unicodeslot=0x334F,
 },
 [0x3350]={
  category="so",
  cjkwd="w",
  description="SQUARE YUAN",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30E6, 0x30A2, 0x30F3 },
  unicodeslot=0x3350,
 },
 [0x3351]={
  adobename="rittorusquare",
  category="so",
  cjkwd="w",
  description="SQUARE RITTORU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30EA, 0x30C3, 0x30C8, 0x30EB },
  unicodeslot=0x3351,
 },
 [0x3352]={
  category="so",
  cjkwd="w",
  description="SQUARE RIRA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30EA, 0x30E9 },
  unicodeslot=0x3352,
 },
 [0x3353]={
  category="so",
  cjkwd="w",
  description="SQUARE RUPII",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30EB, 0x30D4, 0x30FC },
  unicodeslot=0x3353,
 },
 [0x3354]={
  category="so",
  cjkwd="w",
  description="SQUARE RUUBURU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30EB, 0x30FC, 0x30D6, 0x30EB },
  unicodeslot=0x3354,
 },
 [0x3355]={
  category="so",
  cjkwd="w",
  description="SQUARE REMU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30EC, 0x30E0 },
  unicodeslot=0x3355,
 },
 [0x3356]={
  category="so",
  cjkwd="w",
  description="SQUARE RENTOGEN",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30EC, 0x30F3, 0x30C8, 0x30B2, 0x30F3 },
  unicodeslot=0x3356,
 },
 [0x3357]={
  adobename="wattosquare",
  category="so",
  cjkwd="w",
  description="SQUARE WATTO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30EF, 0x30C3, 0x30C8 },
  unicodeslot=0x3357,
 },
 [0x3358]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ZERO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0030, 0x70B9 },
  unicodeslot=0x3358,
 },
 [0x3359]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ONE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x70B9 },
  unicodeslot=0x3359,
 },
 [0x335A]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x70B9 },
  unicodeslot=0x335A,
 },
 [0x335B]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THREE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0033, 0x70B9 },
  unicodeslot=0x335B,
 },
 [0x335C]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOUR",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0034, 0x70B9 },
  unicodeslot=0x335C,
 },
 [0x335D]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIVE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0035, 0x70B9 },
  unicodeslot=0x335D,
 },
 [0x335E]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIX",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0036, 0x70B9 },
  unicodeslot=0x335E,
 },
 [0x335F]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0037, 0x70B9 },
  unicodeslot=0x335F,
 },
 [0x3360]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0038, 0x70B9 },
  unicodeslot=0x3360,
 },
 [0x3361]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0039, 0x70B9 },
  unicodeslot=0x3361,
 },
 [0x3362]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0030, 0x70B9 },
  unicodeslot=0x3362,
 },
 [0x3363]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ELEVEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0031, 0x70B9 },
  unicodeslot=0x3363,
 },
 [0x3364]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWELVE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0032, 0x70B9 },
  unicodeslot=0x3364,
 },
 [0x3365]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THIRTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0033, 0x70B9 },
  unicodeslot=0x3365,
 },
 [0x3366]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOURTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0034, 0x70B9 },
  unicodeslot=0x3366,
 },
 [0x3367]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIFTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0035, 0x70B9 },
  unicodeslot=0x3367,
 },
 [0x3368]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIXTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0036, 0x70B9 },
  unicodeslot=0x3368,
 },
 [0x3369]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVENTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0037, 0x70B9 },
  unicodeslot=0x3369,
 },
 [0x336A]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0038, 0x70B9 },
  unicodeslot=0x336A,
 },
 [0x336B]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINETEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0039, 0x70B9 },
  unicodeslot=0x336B,
 },
 [0x336C]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0030, 0x70B9 },
  unicodeslot=0x336C,
 },
 [0x336D]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-ONE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0031, 0x70B9 },
  unicodeslot=0x336D,
 },
 [0x336E]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-TWO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0032, 0x70B9 },
  unicodeslot=0x336E,
 },
 [0x336F]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-THREE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0033, 0x70B9 },
  unicodeslot=0x336F,
 },
 [0x3370]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-FOUR",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0034, 0x70B9 },
  unicodeslot=0x3370,
 },
 [0x3371]={
  category="so",
  cjkwd="w",
  description="SQUARE HPA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0068, 0x0050, 0x0061 },
  unicodeslot=0x3371,
 },
 [0x3372]={
  category="so",
  cjkwd="w",
  description="SQUARE DA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0064, 0x0061 },
  unicodeslot=0x3372,
 },
 [0x3373]={
  category="so",
  cjkwd="w",
  description="SQUARE AU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0041, 0x0055 },
  unicodeslot=0x3373,
 },
 [0x3374]={
  category="so",
  cjkwd="w",
  description="SQUARE BAR",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0062, 0x0061, 0x0072 },
  unicodeslot=0x3374,
 },
 [0x3375]={
  category="so",
  cjkwd="w",
  description="SQUARE OV",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006F, 0x0056 },
  unicodeslot=0x3375,
 },
 [0x3376]={
  category="so",
  cjkwd="w",
  description="SQUARE PC",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0070, 0x0063 },
  unicodeslot=0x3376,
 },
 [0x3377]={
  category="so",
  cjkwd="w",
  description="SQUARE DM",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0064, 0x006D },
  unicodeslot=0x3377,
 },
 [0x3378]={
  category="so",
  cjkwd="w",
  description="SQUARE DM SQUARED",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0064, 0x006D, 0x00B2 },
  unicodeslot=0x3378,
 },
 [0x3379]={
  category="so",
  cjkwd="w",
  description="SQUARE DM CUBED",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0064, 0x006D, 0x00B3 },
  unicodeslot=0x3379,
 },
 [0x337A]={
  category="so",
  cjkwd="w",
  description="SQUARE IU",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0049, 0x0055 },
  unicodeslot=0x337A,
 },
 [0x337B]={
  adobename="heiseierasquare",
  category="so",
  cjkwd="w",
  description="SQUARE ERA NAME HEISEI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5E73, 0x6210 },
  unicodeslot=0x337B,
 },
 [0x337C]={
  adobename="syouwaerasquare",
  category="so",
  cjkwd="w",
  description="SQUARE ERA NAME SYOUWA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x662D, 0x548C },
  unicodeslot=0x337C,
 },
 [0x337D]={
  adobename="taisyouerasquare",
  category="so",
  cjkwd="w",
  description="SQUARE ERA NAME TAISYOU",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5927, 0x6B63 },
  unicodeslot=0x337D,
 },
 [0x337E]={
  adobename="meizierasquare",
  category="so",
  cjkwd="w",
  description="SQUARE ERA NAME MEIZI",
  direction="l",
  linebreak="id",
  specials={ "square", 0x660E, 0x6CBB },
  unicodeslot=0x337E,
 },
 [0x337F]={
  adobename="corporationsquare",
  category="so",
  cjkwd="w",
  description="SQUARE CORPORATION",
  direction="l",
  linebreak="id",
  specials={ "square", 0x682A, 0x5F0F, 0x4F1A, 0x793E },
  unicodeslot=0x337F,
 },
 [0x3380]={
  adobename="paampssquare",
  category="so",
  cjkwd="w",
  description="SQUARE PA AMPS",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0070, 0x0041 },
  unicodeslot=0x3380,
 },
 [0x3381]={
  adobename="nasquare",
  category="so",
  cjkwd="w",
  description="SQUARE NA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006E, 0x0041 },
  unicodeslot=0x3381,
 },
 [0x3382]={
  adobename="muasquare",
  category="so",
  cjkwd="w",
  description="SQUARE MU A",
  direction="l",
  linebreak="id",
  specials={ "square", 0x03BC, 0x0041 },
  unicodeslot=0x3382,
 },
 [0x3383]={
  adobename="masquare",
  category="so",
  cjkwd="w",
  description="SQUARE MA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x0041 },
  unicodeslot=0x3383,
 },
 [0x3384]={
  adobename="kasquare",
  category="so",
  cjkwd="w",
  description="SQUARE KA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x0041 },
  unicodeslot=0x3384,
 },
 [0x3385]={
  adobename="KBsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KB",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004B, 0x0042 },
  unicodeslot=0x3385,
 },
 [0x3386]={
  adobename="MBsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MB",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004D, 0x0042 },
  unicodeslot=0x3386,
 },
 [0x3387]={
  adobename="GBsquare",
  category="so",
  cjkwd="w",
  description="SQUARE GB",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0047, 0x0042 },
  unicodeslot=0x3387,
 },
 [0x3388]={
  adobename="calsquare",
  category="so",
  cjkwd="w",
  description="SQUARE CAL",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0063, 0x0061, 0x006C },
  unicodeslot=0x3388,
 },
 [0x3389]={
  adobename="kcalsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KCAL",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x0063, 0x0061, 0x006C },
  unicodeslot=0x3389,
 },
 [0x338A]={
  adobename="pfsquare",
  category="so",
  cjkwd="w",
  description="SQUARE PF",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0070, 0x0046 },
  unicodeslot=0x338A,
 },
 [0x338B]={
  adobename="nfsquare",
  category="so",
  cjkwd="w",
  description="SQUARE NF",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006E, 0x0046 },
  unicodeslot=0x338B,
 },
 [0x338C]={
  adobename="mufsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MU F",
  direction="l",
  linebreak="id",
  specials={ "square", 0x03BC, 0x0046 },
  unicodeslot=0x338C,
 },
 [0x338D]={
  adobename="mugsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MU G",
  direction="l",
  linebreak="id",
  specials={ "square", 0x03BC, 0x0067 },
  unicodeslot=0x338D,
 },
 [0x338E]={
  adobename="squaremg",
  category="so",
  cjkwd="w",
  description="SQUARE MG",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x0067 },
  unicodeslot=0x338E,
 },
 [0x338F]={
  adobename="squarekg",
  category="so",
  cjkwd="w",
  description="SQUARE KG",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x0067 },
  unicodeslot=0x338F,
 },
 [0x3390]={
  adobename="Hzsquare",
  category="so",
  cjkwd="w",
  description="SQUARE HZ",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0048, 0x007A },
  unicodeslot=0x3390,
 },
 [0x3391]={
  adobename="khzsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KHZ",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x0048, 0x007A },
  unicodeslot=0x3391,
 },
 [0x3392]={
  adobename="mhzsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MHZ",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004D, 0x0048, 0x007A },
  unicodeslot=0x3392,
 },
 [0x3393]={
  adobename="ghzsquare",
  category="so",
  cjkwd="w",
  description="SQUARE GHZ",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0047, 0x0048, 0x007A },
  unicodeslot=0x3393,
 },
 [0x3394]={
  adobename="thzsquare",
  category="so",
  cjkwd="w",
  description="SQUARE THZ",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0054, 0x0048, 0x007A },
  unicodeslot=0x3394,
 },
 [0x3395]={
  adobename="mulsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MU L",
  direction="l",
  linebreak="id",
  specials={ "square", 0x03BC, 0x2113 },
  unicodeslot=0x3395,
 },
 [0x3396]={
  adobename="mlsquare",
  category="so",
  cjkwd="w",
  description="SQUARE ML",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x2113 },
  unicodeslot=0x3396,
 },
 [0x3397]={
  adobename="dlsquare",
  category="so",
  cjkwd="w",
  description="SQUARE DL",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0064, 0x2113 },
  unicodeslot=0x3397,
 },
 [0x3398]={
  adobename="klsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KL",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x2113 },
  unicodeslot=0x3398,
 },
 [0x3399]={
  adobename="fmsquare",
  category="so",
  cjkwd="w",
  description="SQUARE FM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0066, 0x006D },
  unicodeslot=0x3399,
 },
 [0x339A]={
  adobename="nmsquare",
  category="so",
  cjkwd="w",
  description="SQUARE NM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006E, 0x006D },
  unicodeslot=0x339A,
 },
 [0x339B]={
  adobename="mumsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MU M",
  direction="l",
  linebreak="id",
  specials={ "square", 0x03BC, 0x006D },
  unicodeslot=0x339B,
 },
 [0x339C]={
  adobename="squaremm",
  category="so",
  cjkwd="w",
  description="SQUARE MM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x006D },
  unicodeslot=0x339C,
 },
 [0x339D]={
  adobename="squarecm",
  category="so",
  cjkwd="w",
  description="SQUARE CM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0063, 0x006D },
  unicodeslot=0x339D,
 },
 [0x339E]={
  adobename="squarekm",
  category="so",
  cjkwd="w",
  description="SQUARE KM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x006D },
  unicodeslot=0x339E,
 },
 [0x339F]={
  adobename="mmsquaredsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MM SQUARED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x006D, 0x00B2 },
  unicodeslot=0x339F,
 },
 [0x33A0]={
  adobename="cmsquaredsquare",
  category="so",
  cjkwd="w",
  description="SQUARE CM SQUARED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0063, 0x006D, 0x00B2 },
  unicodeslot=0x33A0,
 },
 [0x33A1]={
  adobename="squaremsquared",
  category="so",
  cjkwd="w",
  description="SQUARE M SQUARED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x00B2 },
  unicodeslot=0x33A1,
 },
 [0x33A2]={
  adobename="kmsquaredsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KM SQUARED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x006D, 0x00B2 },
  unicodeslot=0x33A2,
 },
 [0x33A3]={
  adobename="mmcubedsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MM CUBED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x006D, 0x00B3 },
  unicodeslot=0x33A3,
 },
 [0x33A4]={
  adobename="cmcubedsquare",
  category="so",
  cjkwd="w",
  description="SQUARE CM CUBED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0063, 0x006D, 0x00B3 },
  unicodeslot=0x33A4,
 },
 [0x33A5]={
  adobename="mcubedsquare",
  category="so",
  cjkwd="w",
  description="SQUARE M CUBED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x00B3 },
  unicodeslot=0x33A5,
 },
 [0x33A6]={
  adobename="kmcubedsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KM CUBED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x006D, 0x00B3 },
  unicodeslot=0x33A6,
 },
 [0x33A7]={
  adobename="moverssquare",
  category="so",
  cjkwd="w",
  description="SQUARE M OVER S",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x2215, 0x0073 },
  unicodeslot=0x33A7,
 },
 [0x33A8]={
  adobename="moverssquaredsquare",
  category="so",
  cjkwd="w",
  description="SQUARE M OVER S SQUARED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x2215, 0x0073, 0x00B2 },
  unicodeslot=0x33A8,
 },
 [0x33A9]={
  adobename="pasquare",
  category="so",
  cjkwd="w",
  description="SQUARE PA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0050, 0x0061 },
  unicodeslot=0x33A9,
 },
 [0x33AA]={
  adobename="kpasquare",
  category="so",
  cjkwd="w",
  description="SQUARE KPA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x0050, 0x0061 },
  unicodeslot=0x33AA,
 },
 [0x33AB]={
  adobename="mpasquare",
  category="so",
  cjkwd="w",
  description="SQUARE MPA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004D, 0x0050, 0x0061 },
  unicodeslot=0x33AB,
 },
 [0x33AC]={
  adobename="gpasquare",
  category="so",
  cjkwd="w",
  description="SQUARE GPA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0047, 0x0050, 0x0061 },
  unicodeslot=0x33AC,
 },
 [0x33AD]={
  adobename="radsquare",
  category="so",
  cjkwd="w",
  description="SQUARE RAD",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0072, 0x0061, 0x0064 },
  unicodeslot=0x33AD,
 },
 [0x33AE]={
  adobename="radoverssquare",
  category="so",
  cjkwd="w",
  description="SQUARE RAD OVER S",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0072, 0x0061, 0x0064, 0x2215, 0x0073 },
  unicodeslot=0x33AE,
 },
 [0x33AF]={
  adobename="radoverssquaredsquare",
  category="so",
  cjkwd="w",
  description="SQUARE RAD OVER S SQUARED",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0072, 0x0061, 0x0064, 0x2215, 0x0073, 0x00B2 },
  unicodeslot=0x33AF,
 },
 [0x33B0]={
  adobename="pssquare",
  category="so",
  cjkwd="w",
  description="SQUARE PS",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0070, 0x0073 },
  unicodeslot=0x33B0,
 },
 [0x33B1]={
  adobename="nssquare",
  category="so",
  cjkwd="w",
  description="SQUARE NS",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006E, 0x0073 },
  unicodeslot=0x33B1,
 },
 [0x33B2]={
  adobename="mussquare",
  category="so",
  cjkwd="w",
  description="SQUARE MU S",
  direction="l",
  linebreak="id",
  specials={ "square", 0x03BC, 0x0073 },
  unicodeslot=0x33B2,
 },
 [0x33B3]={
  adobename="mssquare",
  category="so",
  cjkwd="w",
  description="SQUARE MS",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x0073 },
  unicodeslot=0x33B3,
 },
 [0x33B4]={
  adobename="pvsquare",
  category="so",
  cjkwd="w",
  description="SQUARE PV",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0070, 0x0056 },
  unicodeslot=0x33B4,
 },
 [0x33B5]={
  adobename="nvsquare",
  category="so",
  cjkwd="w",
  description="SQUARE NV",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006E, 0x0056 },
  unicodeslot=0x33B5,
 },
 [0x33B6]={
  adobename="muvsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MU V",
  direction="l",
  linebreak="id",
  specials={ "square", 0x03BC, 0x0056 },
  unicodeslot=0x33B6,
 },
 [0x33B7]={
  adobename="mvsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MV",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x0056 },
  unicodeslot=0x33B7,
 },
 [0x33B8]={
  adobename="kvsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KV",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x0056 },
  unicodeslot=0x33B8,
 },
 [0x33B9]={
  adobename="mvmegasquare",
  category="so",
  cjkwd="w",
  description="SQUARE MV MEGA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004D, 0x0056 },
  unicodeslot=0x33B9,
 },
 [0x33BA]={
  adobename="pwsquare",
  category="so",
  cjkwd="w",
  description="SQUARE PW",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0070, 0x0057 },
  unicodeslot=0x33BA,
 },
 [0x33BB]={
  adobename="nwsquare",
  category="so",
  cjkwd="w",
  description="SQUARE NW",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006E, 0x0057 },
  unicodeslot=0x33BB,
 },
 [0x33BC]={
  adobename="muwsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MU W",
  direction="l",
  linebreak="id",
  specials={ "square", 0x03BC, 0x0057 },
  unicodeslot=0x33BC,
 },
 [0x33BD]={
  adobename="mwsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MW",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x0057 },
  unicodeslot=0x33BD,
 },
 [0x33BE]={
  adobename="kwsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KW",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x0057 },
  unicodeslot=0x33BE,
 },
 [0x33BF]={
  adobename="mwmegasquare",
  category="so",
  cjkwd="w",
  description="SQUARE MW MEGA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004D, 0x0057 },
  unicodeslot=0x33BF,
 },
 [0x33C0]={
  adobename="kohmsquare",
  category="so",
  cjkwd="w",
  description="SQUARE K OHM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x03A9 },
  unicodeslot=0x33C0,
 },
 [0x33C1]={
  adobename="mohmsquare",
  category="so",
  cjkwd="w",
  description="SQUARE M OHM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004D, 0x03A9 },
  unicodeslot=0x33C1,
 },
 [0x33C2]={
  adobename="amsquare",
  category="so",
  cjkwd="w",
  description="SQUARE AM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0061, 0x002E, 0x006D, 0x002E },
  unicodeslot=0x33C2,
 },
 [0x33C3]={
  adobename="bqsquare",
  category="so",
  cjkwd="w",
  description="SQUARE BQ",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0042, 0x0071 },
  unicodeslot=0x33C3,
 },
 [0x33C4]={
  adobename="squarecc",
  category="so",
  cjkwd="w",
  description="SQUARE CC",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0063, 0x0063 },
  unicodeslot=0x33C4,
 },
 [0x33C5]={
  adobename="cdsquare",
  category="so",
  cjkwd="w",
  description="SQUARE CD",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0063, 0x0064 },
  unicodeslot=0x33C5,
 },
 [0x33C6]={
  adobename="coverkgsquare",
  category="so",
  cjkwd="w",
  description="SQUARE C OVER KG",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0043, 0x2215, 0x006B, 0x0067 },
  unicodeslot=0x33C6,
 },
 [0x33C7]={
  adobename="cosquare",
  category="so",
  cjkwd="w",
  description="SQUARE CO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0043, 0x006F, 0x002E },
  unicodeslot=0x33C7,
 },
 [0x33C8]={
  adobename="dbsquare",
  category="so",
  cjkwd="w",
  description="SQUARE DB",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0064, 0x0042 },
  unicodeslot=0x33C8,
 },
 [0x33C9]={
  adobename="gysquare",
  category="so",
  cjkwd="w",
  description="SQUARE GY",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0047, 0x0079 },
  unicodeslot=0x33C9,
 },
 [0x33CA]={
  adobename="hasquare",
  category="so",
  cjkwd="w",
  description="SQUARE HA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0068, 0x0061 },
  unicodeslot=0x33CA,
 },
 [0x33CB]={
  adobename="HPsquare",
  category="so",
  cjkwd="w",
  description="SQUARE HP",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0048, 0x0050 },
  unicodeslot=0x33CB,
 },
 [0x33CC]={
  category="so",
  cjkwd="w",
  description="SQUARE IN",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0069, 0x006E },
  unicodeslot=0x33CC,
 },
 [0x33CD]={
  adobename="KKsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KK",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004B, 0x004B },
  unicodeslot=0x33CD,
 },
 [0x33CE]={
  adobename="squarekmcapital",
  category="so",
  cjkwd="w",
  description="SQUARE KM CAPITAL",
  direction="l",
  linebreak="id",
  specials={ "square", 0x004B, 0x004D },
  unicodeslot=0x33CE,
 },
 [0x33CF]={
  adobename="ktsquare",
  category="so",
  cjkwd="w",
  description="SQUARE KT",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006B, 0x0074 },
  unicodeslot=0x33CF,
 },
 [0x33D0]={
  adobename="lmsquare",
  category="so",
  cjkwd="w",
  description="SQUARE LM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006C, 0x006D },
  unicodeslot=0x33D0,
 },
 [0x33D1]={
  adobename="squareln",
  category="so",
  cjkwd="w",
  description="SQUARE LN",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006C, 0x006E },
  unicodeslot=0x33D1,
 },
 [0x33D2]={
  adobename="squarelog",
  category="so",
  cjkwd="w",
  description="SQUARE LOG",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006C, 0x006F, 0x0067 },
  unicodeslot=0x33D2,
 },
 [0x33D3]={
  adobename="lxsquare",
  category="so",
  cjkwd="w",
  description="SQUARE LX",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006C, 0x0078 },
  unicodeslot=0x33D3,
 },
 [0x33D4]={
  adobename="mbsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MB SMALL",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x0062 },
  unicodeslot=0x33D4,
 },
 [0x33D5]={
  adobename="squaremil",
  category="so",
  cjkwd="w",
  description="SQUARE MIL",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x0069, 0x006C },
  unicodeslot=0x33D5,
 },
 [0x33D6]={
  adobename="molsquare",
  category="so",
  cjkwd="w",
  description="SQUARE MOL",
  direction="l",
  linebreak="id",
  specials={ "square", 0x006D, 0x006F, 0x006C },
  unicodeslot=0x33D6,
 },
 [0x33D7]={
  category="so",
  cjkwd="w",
  description="SQUARE PH",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0050, 0x0048 },
  unicodeslot=0x33D7,
 },
 [0x33D8]={
  adobename="pmsquare",
  category="so",
  cjkwd="w",
  description="SQUARE PM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0070, 0x002E, 0x006D, 0x002E },
  unicodeslot=0x33D8,
 },
 [0x33D9]={
  category="so",
  cjkwd="w",
  description="SQUARE PPM",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0050, 0x0050, 0x004D },
  unicodeslot=0x33D9,
 },
 [0x33DA]={
  category="so",
  cjkwd="w",
  description="SQUARE PR",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0050, 0x0052 },
  unicodeslot=0x33DA,
 },
 [0x33DB]={
  adobename="srsquare",
  category="so",
  cjkwd="w",
  description="SQUARE SR",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0073, 0x0072 },
  unicodeslot=0x33DB,
 },
 [0x33DC]={
  adobename="svsquare",
  category="so",
  cjkwd="w",
  description="SQUARE SV",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0053, 0x0076 },
  unicodeslot=0x33DC,
 },
 [0x33DD]={
  adobename="wbsquare",
  category="so",
  cjkwd="w",
  description="SQUARE WB",
  direction="l",
  linebreak="id",
  specials={ "square", 0x0057, 0x0062 },
  unicodeslot=0x33DD,
 },
 [0x33DE]={
  category="so",
  cjkwd="w",
  description="SQUARE V OVER M",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0056, 0x2215, 0x006D },
  unicodeslot=0x33DE,
 },
 [0x33DF]={
  category="so",
  cjkwd="w",
  description="SQUARE A OVER M",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0041, 0x2215, 0x006D },
  unicodeslot=0x33DF,
 },
 [0x33E0]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ONE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x65E5 },
  unicodeslot=0x33E0,
 },
 [0x33E1]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x65E5 },
  unicodeslot=0x33E1,
 },
 [0x33E2]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THREE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0033, 0x65E5 },
  unicodeslot=0x33E2,
 },
 [0x33E3]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOUR",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0034, 0x65E5 },
  unicodeslot=0x33E3,
 },
 [0x33E4]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIVE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0035, 0x65E5 },
  unicodeslot=0x33E4,
 },
 [0x33E5]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIX",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0036, 0x65E5 },
  unicodeslot=0x33E5,
 },
 [0x33E6]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0037, 0x65E5 },
  unicodeslot=0x33E6,
 },
 [0x33E7]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0038, 0x65E5 },
  unicodeslot=0x33E7,
 },
 [0x33E8]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0039, 0x65E5 },
  unicodeslot=0x33E8,
 },
 [0x33E9]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0030, 0x65E5 },
  unicodeslot=0x33E9,
 },
 [0x33EA]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ELEVEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0031, 0x65E5 },
  unicodeslot=0x33EA,
 },
 [0x33EB]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWELVE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0032, 0x65E5 },
  unicodeslot=0x33EB,
 },
 [0x33EC]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0033, 0x65E5 },
  unicodeslot=0x33EC,
 },
 [0x33ED]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOURTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0034, 0x65E5 },
  unicodeslot=0x33ED,
 },
 [0x33EE]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIFTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0035, 0x65E5 },
  unicodeslot=0x33EE,
 },
 [0x33EF]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIXTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0036, 0x65E5 },
  unicodeslot=0x33EF,
 },
 [0x33F0]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVENTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0037, 0x65E5 },
  unicodeslot=0x33F0,
 },
 [0x33F1]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHTEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0038, 0x65E5 },
  unicodeslot=0x33F1,
 },
 [0x33F2]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINETEEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0031, 0x0039, 0x65E5 },
  unicodeslot=0x33F2,
 },
 [0x33F3]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0030, 0x65E5 },
  unicodeslot=0x33F3,
 },
 [0x33F4]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-ONE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0031, 0x65E5 },
  unicodeslot=0x33F4,
 },
 [0x33F5]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-TWO",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0032, 0x65E5 },
  unicodeslot=0x33F5,
 },
 [0x33F6]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-THREE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0033, 0x65E5 },
  unicodeslot=0x33F6,
 },
 [0x33F7]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FOUR",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0034, 0x65E5 },
  unicodeslot=0x33F7,
 },
 [0x33F8]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FIVE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0035, 0x65E5 },
  unicodeslot=0x33F8,
 },
 [0x33F9]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SIX",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0036, 0x65E5 },
  unicodeslot=0x33F9,
 },
 [0x33FA]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SEVEN",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0037, 0x65E5 },
  unicodeslot=0x33FA,
 },
 [0x33FB]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-EIGHT",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0038, 0x65E5 },
  unicodeslot=0x33FB,
 },
 [0x33FC]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-NINE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0032, 0x0039, 0x65E5 },
  unicodeslot=0x33FC,
 },
 [0x33FD]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0033, 0x0030, 0x65E5 },
  unicodeslot=0x33FD,
 },
 [0x33FE]={
  category="so",
  cjkwd="w",
  description="IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY-ONE",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x0033, 0x0031, 0x65E5 },
  unicodeslot=0x33FE,
 },
 [0x33FF]={
  category="so",
  cjkwd="w",
  description="SQUARE GAL",
  direction="on",
  linebreak="id",
  specials={ "square", 0x0067, 0x0061, 0x006C },
  unicodeslot=0x33FF,
 },
 [0x4DC0]={
  category="so",
  description="HEXAGRAM FOR THE CREATIVE HEAVEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC0,
 },
 [0x4DC1]={
  category="so",
  description="HEXAGRAM FOR THE RECEPTIVE EARTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC1,
 },
 [0x4DC2]={
  category="so",
  description="HEXAGRAM FOR DIFFICULTY AT THE BEGINNING",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC2,
 },
 [0x4DC3]={
  category="so",
  description="HEXAGRAM FOR YOUTHFUL FOLLY",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC3,
 },
 [0x4DC4]={
  category="so",
  description="HEXAGRAM FOR WAITING",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC4,
 },
 [0x4DC5]={
  category="so",
  description="HEXAGRAM FOR CONFLICT",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC5,
 },
 [0x4DC6]={
  category="so",
  description="HEXAGRAM FOR THE ARMY",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC6,
 },
 [0x4DC7]={
  category="so",
  description="HEXAGRAM FOR HOLDING TOGETHER",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC7,
 },
 [0x4DC8]={
  category="so",
  description="HEXAGRAM FOR SMALL TAMING",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC8,
 },
 [0x4DC9]={
  category="so",
  description="HEXAGRAM FOR TREADING",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DC9,
 },
 [0x4DCA]={
  category="so",
  description="HEXAGRAM FOR PEACE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DCA,
 },
 [0x4DCB]={
  category="so",
  description="HEXAGRAM FOR STANDSTILL",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DCB,
 },
 [0x4DCC]={
  category="so",
  description="HEXAGRAM FOR FELLOWSHIP",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DCC,
 },
 [0x4DCD]={
  category="so",
  description="HEXAGRAM FOR GREAT POSSESSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DCD,
 },
 [0x4DCE]={
  category="so",
  description="HEXAGRAM FOR MODESTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DCE,
 },
 [0x4DCF]={
  category="so",
  description="HEXAGRAM FOR ENTHUSIASM",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DCF,
 },
 [0x4DD0]={
  category="so",
  description="HEXAGRAM FOR FOLLOWING",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD0,
 },
 [0x4DD1]={
  category="so",
  description="HEXAGRAM FOR WORK ON THE DECAYED",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD1,
 },
 [0x4DD2]={
  category="so",
  description="HEXAGRAM FOR APPROACH",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD2,
 },
 [0x4DD3]={
  category="so",
  description="HEXAGRAM FOR CONTEMPLATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD3,
 },
 [0x4DD4]={
  category="so",
  description="HEXAGRAM FOR BITING THROUGH",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD4,
 },
 [0x4DD5]={
  category="so",
  description="HEXAGRAM FOR GRACE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD5,
 },
 [0x4DD6]={
  category="so",
  description="HEXAGRAM FOR SPLITTING APART",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD6,
 },
 [0x4DD7]={
  category="so",
  description="HEXAGRAM FOR RETURN",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD7,
 },
 [0x4DD8]={
  category="so",
  description="HEXAGRAM FOR INNOCENCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD8,
 },
 [0x4DD9]={
  category="so",
  description="HEXAGRAM FOR GREAT TAMING",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DD9,
 },
 [0x4DDA]={
  category="so",
  description="HEXAGRAM FOR MOUTH CORNERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DDA,
 },
 [0x4DDB]={
  category="so",
  description="HEXAGRAM FOR GREAT PREPONDERANCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DDB,
 },
 [0x4DDC]={
  category="so",
  description="HEXAGRAM FOR THE ABYSMAL WATER",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DDC,
 },
 [0x4DDD]={
  category="so",
  description="HEXAGRAM FOR THE CLINGING FIRE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DDD,
 },
 [0x4DDE]={
  category="so",
  description="HEXAGRAM FOR INFLUENCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DDE,
 },
 [0x4DDF]={
  category="so",
  description="HEXAGRAM FOR DURATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DDF,
 },
 [0x4DE0]={
  category="so",
  description="HEXAGRAM FOR RETREAT",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE0,
 },
 [0x4DE1]={
  category="so",
  description="HEXAGRAM FOR GREAT POWER",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE1,
 },
 [0x4DE2]={
  category="so",
  description="HEXAGRAM FOR PROGRESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE2,
 },
 [0x4DE3]={
  category="so",
  description="HEXAGRAM FOR DARKENING OF THE LIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE3,
 },
 [0x4DE4]={
  category="so",
  description="HEXAGRAM FOR THE FAMILY",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE4,
 },
 [0x4DE5]={
  category="so",
  description="HEXAGRAM FOR OPPOSITION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE5,
 },
 [0x4DE6]={
  category="so",
  description="HEXAGRAM FOR OBSTRUCTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE6,
 },
 [0x4DE7]={
  category="so",
  description="HEXAGRAM FOR DELIVERANCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE7,
 },
 [0x4DE8]={
  category="so",
  description="HEXAGRAM FOR DECREASE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE8,
 },
 [0x4DE9]={
  category="so",
  description="HEXAGRAM FOR INCREASE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DE9,
 },
 [0x4DEA]={
  category="so",
  description="HEXAGRAM FOR BREAKTHROUGH",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DEA,
 },
 [0x4DEB]={
  category="so",
  description="HEXAGRAM FOR COMING TO MEET",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DEB,
 },
 [0x4DEC]={
  category="so",
  description="HEXAGRAM FOR GATHERING TOGETHER",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DEC,
 },
 [0x4DED]={
  category="so",
  description="HEXAGRAM FOR PUSHING UPWARD",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DED,
 },
 [0x4DEE]={
  category="so",
  description="HEXAGRAM FOR OPPRESSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DEE,
 },
 [0x4DEF]={
  category="so",
  description="HEXAGRAM FOR THE WELL",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DEF,
 },
 [0x4DF0]={
  category="so",
  description="HEXAGRAM FOR REVOLUTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF0,
 },
 [0x4DF1]={
  category="so",
  description="HEXAGRAM FOR THE CAULDRON",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF1,
 },
 [0x4DF2]={
  category="so",
  description="HEXAGRAM FOR THE AROUSING THUNDER",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF2,
 },
 [0x4DF3]={
  category="so",
  description="HEXAGRAM FOR THE KEEPING STILL MOUNTAIN",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF3,
 },
 [0x4DF4]={
  category="so",
  description="HEXAGRAM FOR DEVELOPMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF4,
 },
 [0x4DF5]={
  category="so",
  description="HEXAGRAM FOR THE MARRYING MAIDEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF5,
 },
 [0x4DF6]={
  category="so",
  description="HEXAGRAM FOR ABUNDANCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF6,
 },
 [0x4DF7]={
  category="so",
  description="HEXAGRAM FOR THE WANDERER",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF7,
 },
 [0x4DF8]={
  category="so",
  description="HEXAGRAM FOR THE GENTLE WIND",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF8,
 },
 [0x4DF9]={
  category="so",
  description="HEXAGRAM FOR THE JOYOUS LAKE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DF9,
 },
 [0x4DFA]={
  category="so",
  description="HEXAGRAM FOR DISPERSION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DFA,
 },
 [0x4DFB]={
  category="so",
  description="HEXAGRAM FOR LIMITATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DFB,
 },
 [0x4DFC]={
  category="so",
  description="HEXAGRAM FOR INNER TRUTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DFC,
 },
 [0x4DFD]={
  category="so",
  description="HEXAGRAM FOR SMALL PREPONDERANCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DFD,
 },
 [0x4DFE]={
  category="so",
  description="HEXAGRAM FOR AFTER COMPLETION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DFE,
 },
 [0x4DFF]={
  category="so",
  description="HEXAGRAM FOR BEFORE COMPLETION",
  direction="on",
  linebreak="al",
  unicodeslot=0x4DFF,
 },
 [0xA000]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE IT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA000,
 },
 [0xA001]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE IX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA001,
 },
 [0xA002]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE I",
  direction="l",
  linebreak="id",
  unicodeslot=0xA002,
 },
 [0xA003]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE IP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA003,
 },
 [0xA004]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE IET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA004,
 },
 [0xA005]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE IEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA005,
 },
 [0xA006]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE IE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA006,
 },
 [0xA007]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE IEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA007,
 },
 [0xA008]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE AT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA008,
 },
 [0xA009]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE AX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA009,
 },
 [0xA00A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE A",
  direction="l",
  linebreak="id",
  unicodeslot=0xA00A,
 },
 [0xA00B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE AP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA00B,
 },
 [0xA00C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE UOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA00C,
 },
 [0xA00D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE UO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA00D,
 },
 [0xA00E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE UOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA00E,
 },
 [0xA00F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE OT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA00F,
 },
 [0xA010]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE OX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA010,
 },
 [0xA011]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE O",
  direction="l",
  linebreak="id",
  unicodeslot=0xA011,
 },
 [0xA012]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE OP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA012,
 },
 [0xA013]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE EX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA013,
 },
 [0xA014]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE E",
  direction="l",
  linebreak="id",
  unicodeslot=0xA014,
 },
 [0xA015]={
  category="lm",
  cjkwd="w",
  description="YI SYLLABLE WU",
  direction="l",
  linebreak="ns",
  unicodeslot=0xA015,
 },
 [0xA016]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA016,
 },
 [0xA017]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA017,
 },
 [0xA018]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA018,
 },
 [0xA019]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA019,
 },
 [0xA01A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA01A,
 },
 [0xA01B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA01B,
 },
 [0xA01C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA01C,
 },
 [0xA01D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA01D,
 },
 [0xA01E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA01E,
 },
 [0xA01F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA01F,
 },
 [0xA020]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA020,
 },
 [0xA021]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA021,
 },
 [0xA022]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA022,
 },
 [0xA023]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA023,
 },
 [0xA024]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA024,
 },
 [0xA025]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA025,
 },
 [0xA026]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA026,
 },
 [0xA027]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA027,
 },
 [0xA028]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA028,
 },
 [0xA029]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA029,
 },
 [0xA02A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA02A,
 },
 [0xA02B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA02B,
 },
 [0xA02C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA02C,
 },
 [0xA02D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA02D,
 },
 [0xA02E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA02E,
 },
 [0xA02F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA02F,
 },
 [0xA030]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA030,
 },
 [0xA031]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA031,
 },
 [0xA032]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA032,
 },
 [0xA033]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA033,
 },
 [0xA034]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA034,
 },
 [0xA035]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA035,
 },
 [0xA036]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA036,
 },
 [0xA037]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA037,
 },
 [0xA038]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA038,
 },
 [0xA039]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA039,
 },
 [0xA03A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA03A,
 },
 [0xA03B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA03B,
 },
 [0xA03C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA03C,
 },
 [0xA03D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA03D,
 },
 [0xA03E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA03E,
 },
 [0xA03F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA03F,
 },
 [0xA040]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA040,
 },
 [0xA041]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA041,
 },
 [0xA042]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA042,
 },
 [0xA043]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA043,
 },
 [0xA044]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA044,
 },
 [0xA045]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA045,
 },
 [0xA046]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE POT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA046,
 },
 [0xA047]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE POX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA047,
 },
 [0xA048]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA048,
 },
 [0xA049]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE POP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA049,
 },
 [0xA04A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA04A,
 },
 [0xA04B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA04B,
 },
 [0xA04C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA04C,
 },
 [0xA04D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA04D,
 },
 [0xA04E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA04E,
 },
 [0xA04F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA04F,
 },
 [0xA050]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA050,
 },
 [0xA051]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA051,
 },
 [0xA052]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA052,
 },
 [0xA053]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA053,
 },
 [0xA054]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA054,
 },
 [0xA055]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE PYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA055,
 },
 [0xA056]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA056,
 },
 [0xA057]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA057,
 },
 [0xA058]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA058,
 },
 [0xA059]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA059,
 },
 [0xA05A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA05A,
 },
 [0xA05B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA05B,
 },
 [0xA05C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA05C,
 },
 [0xA05D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA05D,
 },
 [0xA05E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA05E,
 },
 [0xA05F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA05F,
 },
 [0xA060]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA060,
 },
 [0xA061]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA061,
 },
 [0xA062]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA062,
 },
 [0xA063]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA063,
 },
 [0xA064]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA064,
 },
 [0xA065]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA065,
 },
 [0xA066]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA066,
 },
 [0xA067]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA067,
 },
 [0xA068]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA068,
 },
 [0xA069]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA069,
 },
 [0xA06A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA06A,
 },
 [0xA06B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA06B,
 },
 [0xA06C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA06C,
 },
 [0xA06D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA06D,
 },
 [0xA06E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA06E,
 },
 [0xA06F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA06F,
 },
 [0xA070]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA070,
 },
 [0xA071]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA071,
 },
 [0xA072]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA072,
 },
 [0xA073]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA073,
 },
 [0xA074]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA074,
 },
 [0xA075]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE BBYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA075,
 },
 [0xA076]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA076,
 },
 [0xA077]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA077,
 },
 [0xA078]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA078,
 },
 [0xA079]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA079,
 },
 [0xA07A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA07A,
 },
 [0xA07B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA07B,
 },
 [0xA07C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA07C,
 },
 [0xA07D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA07D,
 },
 [0xA07E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA07E,
 },
 [0xA07F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA07F,
 },
 [0xA080]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA080,
 },
 [0xA081]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA081,
 },
 [0xA082]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA082,
 },
 [0xA083]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA083,
 },
 [0xA084]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA084,
 },
 [0xA085]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA085,
 },
 [0xA086]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA086,
 },
 [0xA087]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA087,
 },
 [0xA088]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA088,
 },
 [0xA089]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA089,
 },
 [0xA08A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA08A,
 },
 [0xA08B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA08B,
 },
 [0xA08C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA08C,
 },
 [0xA08D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA08D,
 },
 [0xA08E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA08E,
 },
 [0xA08F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA08F,
 },
 [0xA090]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NBYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA090,
 },
 [0xA091]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA091,
 },
 [0xA092]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA092,
 },
 [0xA093]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA093,
 },
 [0xA094]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA094,
 },
 [0xA095]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA095,
 },
 [0xA096]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA096,
 },
 [0xA097]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA097,
 },
 [0xA098]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA098,
 },
 [0xA099]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA099,
 },
 [0xA09A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA09A,
 },
 [0xA09B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA09B,
 },
 [0xA09C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA09C,
 },
 [0xA09D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA09D,
 },
 [0xA09E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA09E,
 },
 [0xA09F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA09F,
 },
 [0xA0A0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A0,
 },
 [0xA0A1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A1,
 },
 [0xA0A2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A2,
 },
 [0xA0A3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A3,
 },
 [0xA0A4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A4,
 },
 [0xA0A5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A5,
 },
 [0xA0A6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A6,
 },
 [0xA0A7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A7,
 },
 [0xA0A8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A8,
 },
 [0xA0A9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0A9,
 },
 [0xA0AA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0AA,
 },
 [0xA0AB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0AB,
 },
 [0xA0AC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0AC,
 },
 [0xA0AD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HMYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0AD,
 },
 [0xA0AE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0AE,
 },
 [0xA0AF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0AF,
 },
 [0xA0B0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B0,
 },
 [0xA0B1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B1,
 },
 [0xA0B2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B2,
 },
 [0xA0B3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B3,
 },
 [0xA0B4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B4,
 },
 [0xA0B5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B5,
 },
 [0xA0B6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B6,
 },
 [0xA0B7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B7,
 },
 [0xA0B8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B8,
 },
 [0xA0B9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0B9,
 },
 [0xA0BA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0BA,
 },
 [0xA0BB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0BB,
 },
 [0xA0BC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0BC,
 },
 [0xA0BD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0BD,
 },
 [0xA0BE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0BE,
 },
 [0xA0BF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0BF,
 },
 [0xA0C0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C0,
 },
 [0xA0C1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C1,
 },
 [0xA0C2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ME",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C2,
 },
 [0xA0C3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C3,
 },
 [0xA0C4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C4,
 },
 [0xA0C5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C5,
 },
 [0xA0C6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C6,
 },
 [0xA0C7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C7,
 },
 [0xA0C8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C8,
 },
 [0xA0C9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0C9,
 },
 [0xA0CA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0CA,
 },
 [0xA0CB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0CB,
 },
 [0xA0CC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0CC,
 },
 [0xA0CD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0CD,
 },
 [0xA0CE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0CE,
 },
 [0xA0CF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0CF,
 },
 [0xA0D0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D0,
 },
 [0xA0D1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D1,
 },
 [0xA0D2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D2,
 },
 [0xA0D3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D3,
 },
 [0xA0D4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D4,
 },
 [0xA0D5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D5,
 },
 [0xA0D6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D6,
 },
 [0xA0D7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D7,
 },
 [0xA0D8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D8,
 },
 [0xA0D9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0D9,
 },
 [0xA0DA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0DA,
 },
 [0xA0DB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0DB,
 },
 [0xA0DC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0DC,
 },
 [0xA0DD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0DD,
 },
 [0xA0DE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0DE,
 },
 [0xA0DF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0DF,
 },
 [0xA0E0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E0,
 },
 [0xA0E1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE FYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E1,
 },
 [0xA0E2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E2,
 },
 [0xA0E3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E3,
 },
 [0xA0E4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E4,
 },
 [0xA0E5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E5,
 },
 [0xA0E6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E6,
 },
 [0xA0E7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E7,
 },
 [0xA0E8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E8,
 },
 [0xA0E9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0E9,
 },
 [0xA0EA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0EA,
 },
 [0xA0EB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0EB,
 },
 [0xA0EC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0EC,
 },
 [0xA0ED]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0ED,
 },
 [0xA0EE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0EE,
 },
 [0xA0EF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0EF,
 },
 [0xA0F0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F0,
 },
 [0xA0F1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F1,
 },
 [0xA0F2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F2,
 },
 [0xA0F3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F3,
 },
 [0xA0F4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F4,
 },
 [0xA0F5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F5,
 },
 [0xA0F6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F6,
 },
 [0xA0F7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F7,
 },
 [0xA0F8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F8,
 },
 [0xA0F9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0F9,
 },
 [0xA0FA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0FA,
 },
 [0xA0FB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0FB,
 },
 [0xA0FC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0FC,
 },
 [0xA0FD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0FD,
 },
 [0xA0FE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0FE,
 },
 [0xA0FF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE VYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA0FF,
 },
 [0xA100]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA100,
 },
 [0xA101]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA101,
 },
 [0xA102]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA102,
 },
 [0xA103]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA103,
 },
 [0xA104]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA104,
 },
 [0xA105]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA105,
 },
 [0xA106]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA106,
 },
 [0xA107]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA107,
 },
 [0xA108]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA108,
 },
 [0xA109]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA109,
 },
 [0xA10A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA10A,
 },
 [0xA10B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA10B,
 },
 [0xA10C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA10C,
 },
 [0xA10D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA10D,
 },
 [0xA10E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA10E,
 },
 [0xA10F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA10F,
 },
 [0xA110]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA110,
 },
 [0xA111]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA111,
 },
 [0xA112]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA112,
 },
 [0xA113]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA113,
 },
 [0xA114]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA114,
 },
 [0xA115]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA115,
 },
 [0xA116]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA116,
 },
 [0xA117]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA117,
 },
 [0xA118]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA118,
 },
 [0xA119]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA119,
 },
 [0xA11A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA11A,
 },
 [0xA11B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA11B,
 },
 [0xA11C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA11C,
 },
 [0xA11D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA11D,
 },
 [0xA11E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA11E,
 },
 [0xA11F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA11F,
 },
 [0xA120]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA120,
 },
 [0xA121]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA121,
 },
 [0xA122]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA122,
 },
 [0xA123]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA123,
 },
 [0xA124]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA124,
 },
 [0xA125]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA125,
 },
 [0xA126]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA126,
 },
 [0xA127]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA127,
 },
 [0xA128]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA128,
 },
 [0xA129]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA129,
 },
 [0xA12A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA12A,
 },
 [0xA12B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA12B,
 },
 [0xA12C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA12C,
 },
 [0xA12D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA12D,
 },
 [0xA12E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA12E,
 },
 [0xA12F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA12F,
 },
 [0xA130]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA130,
 },
 [0xA131]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA131,
 },
 [0xA132]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA132,
 },
 [0xA133]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA133,
 },
 [0xA134]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA134,
 },
 [0xA135]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE TUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA135,
 },
 [0xA136]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA136,
 },
 [0xA137]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA137,
 },
 [0xA138]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA138,
 },
 [0xA139]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA139,
 },
 [0xA13A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA13A,
 },
 [0xA13B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA13B,
 },
 [0xA13C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA13C,
 },
 [0xA13D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA13D,
 },
 [0xA13E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA13E,
 },
 [0xA13F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA13F,
 },
 [0xA140]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA140,
 },
 [0xA141]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA141,
 },
 [0xA142]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA142,
 },
 [0xA143]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA143,
 },
 [0xA144]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA144,
 },
 [0xA145]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA145,
 },
 [0xA146]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA146,
 },
 [0xA147]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA147,
 },
 [0xA148]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA148,
 },
 [0xA149]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA149,
 },
 [0xA14A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA14A,
 },
 [0xA14B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA14B,
 },
 [0xA14C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA14C,
 },
 [0xA14D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA14D,
 },
 [0xA14E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA14E,
 },
 [0xA14F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA14F,
 },
 [0xA150]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE DDUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA150,
 },
 [0xA151]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA151,
 },
 [0xA152]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA152,
 },
 [0xA153]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA153,
 },
 [0xA154]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA154,
 },
 [0xA155]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA155,
 },
 [0xA156]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA156,
 },
 [0xA157]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA157,
 },
 [0xA158]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA158,
 },
 [0xA159]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA159,
 },
 [0xA15A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA15A,
 },
 [0xA15B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA15B,
 },
 [0xA15C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA15C,
 },
 [0xA15D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA15D,
 },
 [0xA15E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA15E,
 },
 [0xA15F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA15F,
 },
 [0xA160]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA160,
 },
 [0xA161]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA161,
 },
 [0xA162]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA162,
 },
 [0xA163]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA163,
 },
 [0xA164]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA164,
 },
 [0xA165]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA165,
 },
 [0xA166]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA166,
 },
 [0xA167]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NDUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA167,
 },
 [0xA168]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA168,
 },
 [0xA169]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA169,
 },
 [0xA16A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA16A,
 },
 [0xA16B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA16B,
 },
 [0xA16C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA16C,
 },
 [0xA16D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA16D,
 },
 [0xA16E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA16E,
 },
 [0xA16F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA16F,
 },
 [0xA170]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA170,
 },
 [0xA171]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA171,
 },
 [0xA172]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA172,
 },
 [0xA173]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA173,
 },
 [0xA174]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA174,
 },
 [0xA175]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA175,
 },
 [0xA176]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA176,
 },
 [0xA177]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA177,
 },
 [0xA178]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA178,
 },
 [0xA179]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA179,
 },
 [0xA17A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA17A,
 },
 [0xA17B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA17B,
 },
 [0xA17C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HNUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA17C,
 },
 [0xA17D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA17D,
 },
 [0xA17E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA17E,
 },
 [0xA17F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA17F,
 },
 [0xA180]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA180,
 },
 [0xA181]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA181,
 },
 [0xA182]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA182,
 },
 [0xA183]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA183,
 },
 [0xA184]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA184,
 },
 [0xA185]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA185,
 },
 [0xA186]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA186,
 },
 [0xA187]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA187,
 },
 [0xA188]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA188,
 },
 [0xA189]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA189,
 },
 [0xA18A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA18A,
 },
 [0xA18B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA18B,
 },
 [0xA18C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA18C,
 },
 [0xA18D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA18D,
 },
 [0xA18E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA18E,
 },
 [0xA18F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA18F,
 },
 [0xA190]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA190,
 },
 [0xA191]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA191,
 },
 [0xA192]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA192,
 },
 [0xA193]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA193,
 },
 [0xA194]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA194,
 },
 [0xA195]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA195,
 },
 [0xA196]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA196,
 },
 [0xA197]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA197,
 },
 [0xA198]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA198,
 },
 [0xA199]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA199,
 },
 [0xA19A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA19A,
 },
 [0xA19B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA19B,
 },
 [0xA19C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA19C,
 },
 [0xA19D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA19D,
 },
 [0xA19E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA19E,
 },
 [0xA19F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA19F,
 },
 [0xA1A0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A0,
 },
 [0xA1A1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A1,
 },
 [0xA1A2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A2,
 },
 [0xA1A3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A3,
 },
 [0xA1A4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A4,
 },
 [0xA1A5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A5,
 },
 [0xA1A6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A6,
 },
 [0xA1A7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A7,
 },
 [0xA1A8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A8,
 },
 [0xA1A9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1A9,
 },
 [0xA1AA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1AA,
 },
 [0xA1AB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1AB,
 },
 [0xA1AC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1AC,
 },
 [0xA1AD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1AD,
 },
 [0xA1AE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1AE,
 },
 [0xA1AF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1AF,
 },
 [0xA1B0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B0,
 },
 [0xA1B1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B1,
 },
 [0xA1B2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B2,
 },
 [0xA1B3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B3,
 },
 [0xA1B4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B4,
 },
 [0xA1B5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B5,
 },
 [0xA1B6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HLYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B6,
 },
 [0xA1B7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B7,
 },
 [0xA1B8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B8,
 },
 [0xA1B9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1B9,
 },
 [0xA1BA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1BA,
 },
 [0xA1BB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1BB,
 },
 [0xA1BC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1BC,
 },
 [0xA1BD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1BD,
 },
 [0xA1BE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1BE,
 },
 [0xA1BF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1BF,
 },
 [0xA1C0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C0,
 },
 [0xA1C1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C1,
 },
 [0xA1C2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C2,
 },
 [0xA1C3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C3,
 },
 [0xA1C4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C4,
 },
 [0xA1C5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C5,
 },
 [0xA1C6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C6,
 },
 [0xA1C7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C7,
 },
 [0xA1C8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C8,
 },
 [0xA1C9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1C9,
 },
 [0xA1CA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1CA,
 },
 [0xA1CB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1CB,
 },
 [0xA1CC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1CC,
 },
 [0xA1CD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1CD,
 },
 [0xA1CE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1CE,
 },
 [0xA1CF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1CF,
 },
 [0xA1D0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D0,
 },
 [0xA1D1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D1,
 },
 [0xA1D2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D2,
 },
 [0xA1D3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D3,
 },
 [0xA1D4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D4,
 },
 [0xA1D5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D5,
 },
 [0xA1D6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D6,
 },
 [0xA1D7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D7,
 },
 [0xA1D8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D8,
 },
 [0xA1D9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE LYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1D9,
 },
 [0xA1DA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1DA,
 },
 [0xA1DB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1DB,
 },
 [0xA1DC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1DC,
 },
 [0xA1DD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1DD,
 },
 [0xA1DE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1DE,
 },
 [0xA1DF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1DF,
 },
 [0xA1E0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E0,
 },
 [0xA1E1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E1,
 },
 [0xA1E2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E2,
 },
 [0xA1E3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E3,
 },
 [0xA1E4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E4,
 },
 [0xA1E5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E5,
 },
 [0xA1E6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E6,
 },
 [0xA1E7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E7,
 },
 [0xA1E8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E8,
 },
 [0xA1E9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1E9,
 },
 [0xA1EA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1EA,
 },
 [0xA1EB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1EB,
 },
 [0xA1EC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1EC,
 },
 [0xA1ED]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1ED,
 },
 [0xA1EE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1EE,
 },
 [0xA1EF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1EF,
 },
 [0xA1F0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F0,
 },
 [0xA1F1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F1,
 },
 [0xA1F2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F2,
 },
 [0xA1F3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F3,
 },
 [0xA1F4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F4,
 },
 [0xA1F5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F5,
 },
 [0xA1F6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F6,
 },
 [0xA1F7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F7,
 },
 [0xA1F8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F8,
 },
 [0xA1F9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1F9,
 },
 [0xA1FA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1FA,
 },
 [0xA1FB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1FB,
 },
 [0xA1FC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1FC,
 },
 [0xA1FD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1FD,
 },
 [0xA1FE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1FE,
 },
 [0xA1FF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA1FF,
 },
 [0xA200]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA200,
 },
 [0xA201]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA201,
 },
 [0xA202]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA202,
 },
 [0xA203]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA203,
 },
 [0xA204]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA204,
 },
 [0xA205]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA205,
 },
 [0xA206]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA206,
 },
 [0xA207]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA207,
 },
 [0xA208]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA208,
 },
 [0xA209]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA209,
 },
 [0xA20A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA20A,
 },
 [0xA20B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA20B,
 },
 [0xA20C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA20C,
 },
 [0xA20D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA20D,
 },
 [0xA20E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA20E,
 },
 [0xA20F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA20F,
 },
 [0xA210]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA210,
 },
 [0xA211]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA211,
 },
 [0xA212]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA212,
 },
 [0xA213]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE KUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA213,
 },
 [0xA214]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA214,
 },
 [0xA215]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA215,
 },
 [0xA216]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA216,
 },
 [0xA217]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA217,
 },
 [0xA218]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA218,
 },
 [0xA219]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA219,
 },
 [0xA21A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA21A,
 },
 [0xA21B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA21B,
 },
 [0xA21C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA21C,
 },
 [0xA21D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA21D,
 },
 [0xA21E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA21E,
 },
 [0xA21F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA21F,
 },
 [0xA220]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA220,
 },
 [0xA221]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA221,
 },
 [0xA222]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA222,
 },
 [0xA223]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA223,
 },
 [0xA224]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA224,
 },
 [0xA225]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA225,
 },
 [0xA226]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA226,
 },
 [0xA227]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA227,
 },
 [0xA228]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA228,
 },
 [0xA229]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA229,
 },
 [0xA22A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA22A,
 },
 [0xA22B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA22B,
 },
 [0xA22C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA22C,
 },
 [0xA22D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA22D,
 },
 [0xA22E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA22E,
 },
 [0xA22F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE GGUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA22F,
 },
 [0xA230]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA230,
 },
 [0xA231]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA231,
 },
 [0xA232]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA232,
 },
 [0xA233]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA233,
 },
 [0xA234]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA234,
 },
 [0xA235]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA235,
 },
 [0xA236]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA236,
 },
 [0xA237]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA237,
 },
 [0xA238]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA238,
 },
 [0xA239]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA239,
 },
 [0xA23A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA23A,
 },
 [0xA23B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA23B,
 },
 [0xA23C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA23C,
 },
 [0xA23D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA23D,
 },
 [0xA23E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA23E,
 },
 [0xA23F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA23F,
 },
 [0xA240]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA240,
 },
 [0xA241]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA241,
 },
 [0xA242]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA242,
 },
 [0xA243]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA243,
 },
 [0xA244]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA244,
 },
 [0xA245]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE MGUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA245,
 },
 [0xA246]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA246,
 },
 [0xA247]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA247,
 },
 [0xA248]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA248,
 },
 [0xA249]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA249,
 },
 [0xA24A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA24A,
 },
 [0xA24B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA24B,
 },
 [0xA24C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA24C,
 },
 [0xA24D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA24D,
 },
 [0xA24E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA24E,
 },
 [0xA24F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA24F,
 },
 [0xA250]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA250,
 },
 [0xA251]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA251,
 },
 [0xA252]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA252,
 },
 [0xA253]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA253,
 },
 [0xA254]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA254,
 },
 [0xA255]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA255,
 },
 [0xA256]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA256,
 },
 [0xA257]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA257,
 },
 [0xA258]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA258,
 },
 [0xA259]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA259,
 },
 [0xA25A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA25A,
 },
 [0xA25B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA25B,
 },
 [0xA25C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HXEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA25C,
 },
 [0xA25D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA25D,
 },
 [0xA25E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA25E,
 },
 [0xA25F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA25F,
 },
 [0xA260]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA260,
 },
 [0xA261]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA261,
 },
 [0xA262]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA262,
 },
 [0xA263]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA263,
 },
 [0xA264]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA264,
 },
 [0xA265]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA265,
 },
 [0xA266]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA266,
 },
 [0xA267]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA267,
 },
 [0xA268]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA268,
 },
 [0xA269]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA269,
 },
 [0xA26A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA26A,
 },
 [0xA26B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA26B,
 },
 [0xA26C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA26C,
 },
 [0xA26D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NGEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA26D,
 },
 [0xA26E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA26E,
 },
 [0xA26F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA26F,
 },
 [0xA270]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA270,
 },
 [0xA271]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA271,
 },
 [0xA272]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA272,
 },
 [0xA273]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA273,
 },
 [0xA274]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA274,
 },
 [0xA275]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA275,
 },
 [0xA276]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA276,
 },
 [0xA277]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA277,
 },
 [0xA278]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA278,
 },
 [0xA279]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA279,
 },
 [0xA27A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA27A,
 },
 [0xA27B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA27B,
 },
 [0xA27C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA27C,
 },
 [0xA27D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA27D,
 },
 [0xA27E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA27E,
 },
 [0xA27F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE HEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA27F,
 },
 [0xA280]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA280,
 },
 [0xA281]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA281,
 },
 [0xA282]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA282,
 },
 [0xA283]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA283,
 },
 [0xA284]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA284,
 },
 [0xA285]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA285,
 },
 [0xA286]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA286,
 },
 [0xA287]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA287,
 },
 [0xA288]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA288,
 },
 [0xA289]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA289,
 },
 [0xA28A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA28A,
 },
 [0xA28B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA28B,
 },
 [0xA28C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE WEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA28C,
 },
 [0xA28D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA28D,
 },
 [0xA28E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA28E,
 },
 [0xA28F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA28F,
 },
 [0xA290]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA290,
 },
 [0xA291]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA291,
 },
 [0xA292]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA292,
 },
 [0xA293]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA293,
 },
 [0xA294]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA294,
 },
 [0xA295]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA295,
 },
 [0xA296]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA296,
 },
 [0xA297]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA297,
 },
 [0xA298]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA298,
 },
 [0xA299]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA299,
 },
 [0xA29A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA29A,
 },
 [0xA29B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA29B,
 },
 [0xA29C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA29C,
 },
 [0xA29D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA29D,
 },
 [0xA29E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA29E,
 },
 [0xA29F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA29F,
 },
 [0xA2A0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A0,
 },
 [0xA2A1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A1,
 },
 [0xA2A2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A2,
 },
 [0xA2A3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A3,
 },
 [0xA2A4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A4,
 },
 [0xA2A5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A5,
 },
 [0xA2A6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A6,
 },
 [0xA2A7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A7,
 },
 [0xA2A8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A8,
 },
 [0xA2A9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2A9,
 },
 [0xA2AA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2AA,
 },
 [0xA2AB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2AB,
 },
 [0xA2AC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2AC,
 },
 [0xA2AD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2AD,
 },
 [0xA2AE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2AE,
 },
 [0xA2AF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2AF,
 },
 [0xA2B0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B0,
 },
 [0xA2B1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B1,
 },
 [0xA2B2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B2,
 },
 [0xA2B3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B3,
 },
 [0xA2B4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B4,
 },
 [0xA2B5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B5,
 },
 [0xA2B6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B6,
 },
 [0xA2B7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B7,
 },
 [0xA2B8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B8,
 },
 [0xA2B9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2B9,
 },
 [0xA2BA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2BA,
 },
 [0xA2BB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2BB,
 },
 [0xA2BC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2BC,
 },
 [0xA2BD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE COT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2BD,
 },
 [0xA2BE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE COX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2BE,
 },
 [0xA2BF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2BF,
 },
 [0xA2C0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE COP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C0,
 },
 [0xA2C1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C1,
 },
 [0xA2C2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C2,
 },
 [0xA2C3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C3,
 },
 [0xA2C4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C4,
 },
 [0xA2C5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C5,
 },
 [0xA2C6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C6,
 },
 [0xA2C7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C7,
 },
 [0xA2C8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C8,
 },
 [0xA2C9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2C9,
 },
 [0xA2CA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2CA,
 },
 [0xA2CB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2CB,
 },
 [0xA2CC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2CC,
 },
 [0xA2CD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2CD,
 },
 [0xA2CE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2CE,
 },
 [0xA2CF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2CF,
 },
 [0xA2D0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D0,
 },
 [0xA2D1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D1,
 },
 [0xA2D2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D2,
 },
 [0xA2D3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D3,
 },
 [0xA2D4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D4,
 },
 [0xA2D5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D5,
 },
 [0xA2D6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D6,
 },
 [0xA2D7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D7,
 },
 [0xA2D8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D8,
 },
 [0xA2D9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2D9,
 },
 [0xA2DA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2DA,
 },
 [0xA2DB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2DB,
 },
 [0xA2DC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2DC,
 },
 [0xA2DD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2DD,
 },
 [0xA2DE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2DE,
 },
 [0xA2DF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2DF,
 },
 [0xA2E0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E0,
 },
 [0xA2E1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E1,
 },
 [0xA2E2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E2,
 },
 [0xA2E3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E3,
 },
 [0xA2E4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E4,
 },
 [0xA2E5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E5,
 },
 [0xA2E6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E6,
 },
 [0xA2E7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E7,
 },
 [0xA2E8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E8,
 },
 [0xA2E9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2E9,
 },
 [0xA2EA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2EA,
 },
 [0xA2EB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2EB,
 },
 [0xA2EC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZZYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2EC,
 },
 [0xA2ED]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2ED,
 },
 [0xA2EE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2EE,
 },
 [0xA2EF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2EF,
 },
 [0xA2F0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F0,
 },
 [0xA2F1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F1,
 },
 [0xA2F2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F2,
 },
 [0xA2F3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F3,
 },
 [0xA2F4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F4,
 },
 [0xA2F5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F5,
 },
 [0xA2F6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F6,
 },
 [0xA2F7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F7,
 },
 [0xA2F8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F8,
 },
 [0xA2F9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2F9,
 },
 [0xA2FA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2FA,
 },
 [0xA2FB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2FB,
 },
 [0xA2FC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2FC,
 },
 [0xA2FD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2FD,
 },
 [0xA2FE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2FE,
 },
 [0xA2FF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA2FF,
 },
 [0xA300]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA300,
 },
 [0xA301]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA301,
 },
 [0xA302]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA302,
 },
 [0xA303]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA303,
 },
 [0xA304]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA304,
 },
 [0xA305]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA305,
 },
 [0xA306]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA306,
 },
 [0xA307]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA307,
 },
 [0xA308]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NZYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA308,
 },
 [0xA309]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA309,
 },
 [0xA30A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA30A,
 },
 [0xA30B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA30B,
 },
 [0xA30C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA30C,
 },
 [0xA30D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA30D,
 },
 [0xA30E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA30E,
 },
 [0xA30F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA30F,
 },
 [0xA310]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA310,
 },
 [0xA311]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA311,
 },
 [0xA312]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA312,
 },
 [0xA313]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA313,
 },
 [0xA314]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA314,
 },
 [0xA315]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA315,
 },
 [0xA316]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA316,
 },
 [0xA317]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA317,
 },
 [0xA318]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA318,
 },
 [0xA319]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA319,
 },
 [0xA31A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA31A,
 },
 [0xA31B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA31B,
 },
 [0xA31C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA31C,
 },
 [0xA31D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA31D,
 },
 [0xA31E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA31E,
 },
 [0xA31F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA31F,
 },
 [0xA320]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA320,
 },
 [0xA321]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA321,
 },
 [0xA322]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA322,
 },
 [0xA323]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA323,
 },
 [0xA324]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA324,
 },
 [0xA325]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA325,
 },
 [0xA326]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA326,
 },
 [0xA327]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA327,
 },
 [0xA328]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA328,
 },
 [0xA329]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA329,
 },
 [0xA32A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA32A,
 },
 [0xA32B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA32B,
 },
 [0xA32C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA32C,
 },
 [0xA32D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA32D,
 },
 [0xA32E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA32E,
 },
 [0xA32F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA32F,
 },
 [0xA330]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA330,
 },
 [0xA331]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA331,
 },
 [0xA332]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA332,
 },
 [0xA333]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA333,
 },
 [0xA334]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA334,
 },
 [0xA335]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA335,
 },
 [0xA336]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA336,
 },
 [0xA337]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA337,
 },
 [0xA338]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA338,
 },
 [0xA339]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA339,
 },
 [0xA33A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA33A,
 },
 [0xA33B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA33B,
 },
 [0xA33C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA33C,
 },
 [0xA33D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA33D,
 },
 [0xA33E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA33E,
 },
 [0xA33F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA33F,
 },
 [0xA340]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA340,
 },
 [0xA341]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA341,
 },
 [0xA342]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA342,
 },
 [0xA343]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA343,
 },
 [0xA344]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA344,
 },
 [0xA345]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SSYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA345,
 },
 [0xA346]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA346,
 },
 [0xA347]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA347,
 },
 [0xA348]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA348,
 },
 [0xA349]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA349,
 },
 [0xA34A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA34A,
 },
 [0xA34B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA34B,
 },
 [0xA34C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA34C,
 },
 [0xA34D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA34D,
 },
 [0xA34E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA34E,
 },
 [0xA34F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA34F,
 },
 [0xA350]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA350,
 },
 [0xA351]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA351,
 },
 [0xA352]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA352,
 },
 [0xA353]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA353,
 },
 [0xA354]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA354,
 },
 [0xA355]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA355,
 },
 [0xA356]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA356,
 },
 [0xA357]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA357,
 },
 [0xA358]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA358,
 },
 [0xA359]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA359,
 },
 [0xA35A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA35A,
 },
 [0xA35B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA35B,
 },
 [0xA35C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA35C,
 },
 [0xA35D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA35D,
 },
 [0xA35E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA35E,
 },
 [0xA35F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA35F,
 },
 [0xA360]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ZHYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA360,
 },
 [0xA361]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA361,
 },
 [0xA362]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA362,
 },
 [0xA363]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA363,
 },
 [0xA364]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA364,
 },
 [0xA365]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA365,
 },
 [0xA366]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA366,
 },
 [0xA367]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA367,
 },
 [0xA368]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA368,
 },
 [0xA369]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA369,
 },
 [0xA36A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA36A,
 },
 [0xA36B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA36B,
 },
 [0xA36C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA36C,
 },
 [0xA36D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA36D,
 },
 [0xA36E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA36E,
 },
 [0xA36F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA36F,
 },
 [0xA370]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA370,
 },
 [0xA371]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA371,
 },
 [0xA372]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA372,
 },
 [0xA373]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA373,
 },
 [0xA374]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA374,
 },
 [0xA375]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA375,
 },
 [0xA376]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA376,
 },
 [0xA377]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA377,
 },
 [0xA378]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA378,
 },
 [0xA379]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA379,
 },
 [0xA37A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA37A,
 },
 [0xA37B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE CHYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA37B,
 },
 [0xA37C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA37C,
 },
 [0xA37D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA37D,
 },
 [0xA37E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA37E,
 },
 [0xA37F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA37F,
 },
 [0xA380]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RROT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA380,
 },
 [0xA381]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RROX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA381,
 },
 [0xA382]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA382,
 },
 [0xA383]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RROP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA383,
 },
 [0xA384]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA384,
 },
 [0xA385]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RREX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA385,
 },
 [0xA386]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA386,
 },
 [0xA387]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RREP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA387,
 },
 [0xA388]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA388,
 },
 [0xA389]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA389,
 },
 [0xA38A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA38A,
 },
 [0xA38B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA38B,
 },
 [0xA38C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA38C,
 },
 [0xA38D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA38D,
 },
 [0xA38E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA38E,
 },
 [0xA38F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA38F,
 },
 [0xA390]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA390,
 },
 [0xA391]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA391,
 },
 [0xA392]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA392,
 },
 [0xA393]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RRYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA393,
 },
 [0xA394]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA394,
 },
 [0xA395]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA395,
 },
 [0xA396]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA396,
 },
 [0xA397]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA397,
 },
 [0xA398]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NROX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA398,
 },
 [0xA399]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA399,
 },
 [0xA39A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NROP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA39A,
 },
 [0xA39B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA39B,
 },
 [0xA39C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NREX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA39C,
 },
 [0xA39D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA39D,
 },
 [0xA39E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NREP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA39E,
 },
 [0xA39F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA39F,
 },
 [0xA3A0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A0,
 },
 [0xA3A1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A1,
 },
 [0xA3A2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A2,
 },
 [0xA3A3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A3,
 },
 [0xA3A4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A4,
 },
 [0xA3A5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A5,
 },
 [0xA3A6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A6,
 },
 [0xA3A7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A7,
 },
 [0xA3A8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A8,
 },
 [0xA3A9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3A9,
 },
 [0xA3AA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NRYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3AA,
 },
 [0xA3AB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3AB,
 },
 [0xA3AC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3AC,
 },
 [0xA3AD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3AD,
 },
 [0xA3AE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3AE,
 },
 [0xA3AF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3AF,
 },
 [0xA3B0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B0,
 },
 [0xA3B1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B1,
 },
 [0xA3B2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B2,
 },
 [0xA3B3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B3,
 },
 [0xA3B4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B4,
 },
 [0xA3B5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B5,
 },
 [0xA3B6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B6,
 },
 [0xA3B7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B7,
 },
 [0xA3B8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B8,
 },
 [0xA3B9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3B9,
 },
 [0xA3BA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3BA,
 },
 [0xA3BB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3BB,
 },
 [0xA3BC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3BC,
 },
 [0xA3BD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3BD,
 },
 [0xA3BE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3BE,
 },
 [0xA3BF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3BF,
 },
 [0xA3C0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C0,
 },
 [0xA3C1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C1,
 },
 [0xA3C2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C2,
 },
 [0xA3C3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C3,
 },
 [0xA3C4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C4,
 },
 [0xA3C5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE SHYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C5,
 },
 [0xA3C6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RAT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C6,
 },
 [0xA3C7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RAX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C7,
 },
 [0xA3C8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RA",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C8,
 },
 [0xA3C9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RAP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3C9,
 },
 [0xA3CA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3CA,
 },
 [0xA3CB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3CB,
 },
 [0xA3CC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3CC,
 },
 [0xA3CD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ROT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3CD,
 },
 [0xA3CE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ROX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3CE,
 },
 [0xA3CF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3CF,
 },
 [0xA3D0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE ROP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D0,
 },
 [0xA3D1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE REX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D1,
 },
 [0xA3D2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D2,
 },
 [0xA3D3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE REP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D3,
 },
 [0xA3D4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D4,
 },
 [0xA3D5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D5,
 },
 [0xA3D6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D6,
 },
 [0xA3D7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D7,
 },
 [0xA3D8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D8,
 },
 [0xA3D9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3D9,
 },
 [0xA3DA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3DA,
 },
 [0xA3DB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3DB,
 },
 [0xA3DC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3DC,
 },
 [0xA3DD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3DD,
 },
 [0xA3DE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3DE,
 },
 [0xA3DF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE RYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3DF,
 },
 [0xA3E0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E0,
 },
 [0xA3E1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E1,
 },
 [0xA3E2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E2,
 },
 [0xA3E3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E3,
 },
 [0xA3E4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E4,
 },
 [0xA3E5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E5,
 },
 [0xA3E6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E6,
 },
 [0xA3E7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E7,
 },
 [0xA3E8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E8,
 },
 [0xA3E9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3E9,
 },
 [0xA3EA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3EA,
 },
 [0xA3EB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3EB,
 },
 [0xA3EC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3EC,
 },
 [0xA3ED]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3ED,
 },
 [0xA3EE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3EE,
 },
 [0xA3EF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3EF,
 },
 [0xA3F0]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F0,
 },
 [0xA3F1]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F1,
 },
 [0xA3F2]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F2,
 },
 [0xA3F3]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F3,
 },
 [0xA3F4]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F4,
 },
 [0xA3F5]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F5,
 },
 [0xA3F6]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F6,
 },
 [0xA3F7]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F7,
 },
 [0xA3F8]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F8,
 },
 [0xA3F9]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3F9,
 },
 [0xA3FA]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3FA,
 },
 [0xA3FB]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3FB,
 },
 [0xA3FC]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3FC,
 },
 [0xA3FD]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3FD,
 },
 [0xA3FE]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3FE,
 },
 [0xA3FF]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA3FF,
 },
 [0xA400]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA400,
 },
 [0xA401]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA401,
 },
 [0xA402]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA402,
 },
 [0xA403]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA403,
 },
 [0xA404]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA404,
 },
 [0xA405]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA405,
 },
 [0xA406]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA406,
 },
 [0xA407]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA407,
 },
 [0xA408]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA408,
 },
 [0xA409]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA409,
 },
 [0xA40A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA40A,
 },
 [0xA40B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA40B,
 },
 [0xA40C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA40C,
 },
 [0xA40D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA40D,
 },
 [0xA40E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA40E,
 },
 [0xA40F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA40F,
 },
 [0xA410]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA410,
 },
 [0xA411]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA411,
 },
 [0xA412]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA412,
 },
 [0xA413]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA413,
 },
 [0xA414]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA414,
 },
 [0xA415]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA415,
 },
 [0xA416]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA416,
 },
 [0xA417]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE QYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA417,
 },
 [0xA418]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA418,
 },
 [0xA419]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA419,
 },
 [0xA41A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA41A,
 },
 [0xA41B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA41B,
 },
 [0xA41C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA41C,
 },
 [0xA41D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA41D,
 },
 [0xA41E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA41E,
 },
 [0xA41F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA41F,
 },
 [0xA420]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA420,
 },
 [0xA421]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA421,
 },
 [0xA422]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA422,
 },
 [0xA423]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA423,
 },
 [0xA424]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA424,
 },
 [0xA425]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA425,
 },
 [0xA426]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA426,
 },
 [0xA427]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA427,
 },
 [0xA428]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA428,
 },
 [0xA429]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA429,
 },
 [0xA42A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA42A,
 },
 [0xA42B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA42B,
 },
 [0xA42C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA42C,
 },
 [0xA42D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA42D,
 },
 [0xA42E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA42E,
 },
 [0xA42F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA42F,
 },
 [0xA430]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE JJYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA430,
 },
 [0xA431]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA431,
 },
 [0xA432]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA432,
 },
 [0xA433]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA433,
 },
 [0xA434]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA434,
 },
 [0xA435]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA435,
 },
 [0xA436]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA436,
 },
 [0xA437]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA437,
 },
 [0xA438]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA438,
 },
 [0xA439]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA439,
 },
 [0xA43A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA43A,
 },
 [0xA43B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA43B,
 },
 [0xA43C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA43C,
 },
 [0xA43D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA43D,
 },
 [0xA43E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA43E,
 },
 [0xA43F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA43F,
 },
 [0xA440]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA440,
 },
 [0xA441]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA441,
 },
 [0xA442]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA442,
 },
 [0xA443]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA443,
 },
 [0xA444]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA444,
 },
 [0xA445]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA445,
 },
 [0xA446]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA446,
 },
 [0xA447]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA447,
 },
 [0xA448]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA448,
 },
 [0xA449]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NJYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA449,
 },
 [0xA44A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA44A,
 },
 [0xA44B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA44B,
 },
 [0xA44C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA44C,
 },
 [0xA44D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA44D,
 },
 [0xA44E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA44E,
 },
 [0xA44F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA44F,
 },
 [0xA450]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA450,
 },
 [0xA451]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA451,
 },
 [0xA452]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA452,
 },
 [0xA453]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA453,
 },
 [0xA454]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA454,
 },
 [0xA455]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA455,
 },
 [0xA456]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA456,
 },
 [0xA457]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA457,
 },
 [0xA458]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA458,
 },
 [0xA459]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA459,
 },
 [0xA45A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA45A,
 },
 [0xA45B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA45B,
 },
 [0xA45C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE NYUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA45C,
 },
 [0xA45D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA45D,
 },
 [0xA45E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA45E,
 },
 [0xA45F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA45F,
 },
 [0xA460]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA460,
 },
 [0xA461]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA461,
 },
 [0xA462]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA462,
 },
 [0xA463]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA463,
 },
 [0xA464]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA464,
 },
 [0xA465]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA465,
 },
 [0xA466]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA466,
 },
 [0xA467]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA467,
 },
 [0xA468]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA468,
 },
 [0xA469]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA469,
 },
 [0xA46A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA46A,
 },
 [0xA46B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA46B,
 },
 [0xA46C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA46C,
 },
 [0xA46D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA46D,
 },
 [0xA46E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA46E,
 },
 [0xA46F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA46F,
 },
 [0xA470]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE XYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA470,
 },
 [0xA471]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YIT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA471,
 },
 [0xA472]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YIX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA472,
 },
 [0xA473]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YI",
  direction="l",
  linebreak="id",
  unicodeslot=0xA473,
 },
 [0xA474]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YIP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA474,
 },
 [0xA475]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YIET",
  direction="l",
  linebreak="id",
  unicodeslot=0xA475,
 },
 [0xA476]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YIEX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA476,
 },
 [0xA477]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YIE",
  direction="l",
  linebreak="id",
  unicodeslot=0xA477,
 },
 [0xA478]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YIEP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA478,
 },
 [0xA479]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YUOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA479,
 },
 [0xA47A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YUOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA47A,
 },
 [0xA47B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YUO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA47B,
 },
 [0xA47C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YUOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA47C,
 },
 [0xA47D]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YOT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA47D,
 },
 [0xA47E]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YOX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA47E,
 },
 [0xA47F]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YO",
  direction="l",
  linebreak="id",
  unicodeslot=0xA47F,
 },
 [0xA480]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YOP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA480,
 },
 [0xA481]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YUT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA481,
 },
 [0xA482]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YUX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA482,
 },
 [0xA483]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YU",
  direction="l",
  linebreak="id",
  unicodeslot=0xA483,
 },
 [0xA484]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YUP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA484,
 },
 [0xA485]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YURX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA485,
 },
 [0xA486]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YUR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA486,
 },
 [0xA487]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YYT",
  direction="l",
  linebreak="id",
  unicodeslot=0xA487,
 },
 [0xA488]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YYX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA488,
 },
 [0xA489]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YY",
  direction="l",
  linebreak="id",
  unicodeslot=0xA489,
 },
 [0xA48A]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YYP",
  direction="l",
  linebreak="id",
  unicodeslot=0xA48A,
 },
 [0xA48B]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YYRX",
  direction="l",
  linebreak="id",
  unicodeslot=0xA48B,
 },
 [0xA48C]={
  category="lo",
  cjkwd="w",
  description="YI SYLLABLE YYR",
  direction="l",
  linebreak="id",
  unicodeslot=0xA48C,
 },
 [0xA490]={
  category="so",
  cjkwd="w",
  description="YI RADICAL QOT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA490,
 },
 [0xA491]={
  category="so",
  cjkwd="w",
  description="YI RADICAL LI",
  direction="on",
  linebreak="id",
  unicodeslot=0xA491,
 },
 [0xA492]={
  category="so",
  cjkwd="w",
  description="YI RADICAL KIT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA492,
 },
 [0xA493]={
  category="so",
  cjkwd="w",
  description="YI RADICAL NYIP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA493,
 },
 [0xA494]={
  category="so",
  cjkwd="w",
  description="YI RADICAL CYP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA494,
 },
 [0xA495]={
  category="so",
  cjkwd="w",
  description="YI RADICAL SSI",
  direction="on",
  linebreak="id",
  unicodeslot=0xA495,
 },
 [0xA496]={
  category="so",
  cjkwd="w",
  description="YI RADICAL GGOP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA496,
 },
 [0xA497]={
  category="so",
  cjkwd="w",
  description="YI RADICAL GEP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA497,
 },
 [0xA498]={
  category="so",
  cjkwd="w",
  description="YI RADICAL MI",
  direction="on",
  linebreak="id",
  unicodeslot=0xA498,
 },
 [0xA499]={
  category="so",
  cjkwd="w",
  description="YI RADICAL HXIT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA499,
 },
 [0xA49A]={
  category="so",
  cjkwd="w",
  description="YI RADICAL LYR",
  direction="on",
  linebreak="id",
  unicodeslot=0xA49A,
 },
 [0xA49B]={
  category="so",
  cjkwd="w",
  description="YI RADICAL BBUT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA49B,
 },
 [0xA49C]={
  category="so",
  cjkwd="w",
  description="YI RADICAL MOP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA49C,
 },
 [0xA49D]={
  category="so",
  cjkwd="w",
  description="YI RADICAL YO",
  direction="on",
  linebreak="id",
  unicodeslot=0xA49D,
 },
 [0xA49E]={
  category="so",
  cjkwd="w",
  description="YI RADICAL PUT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA49E,
 },
 [0xA49F]={
  category="so",
  cjkwd="w",
  description="YI RADICAL HXUO",
  direction="on",
  linebreak="id",
  unicodeslot=0xA49F,
 },
 [0xA4A0]={
  category="so",
  cjkwd="w",
  description="YI RADICAL TAT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A0,
 },
 [0xA4A1]={
  category="so",
  cjkwd="w",
  description="YI RADICAL GA",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A1,
 },
 [0xA4A2]={
  category="so",
  cjkwd="w",
  description="YI RADICAL ZUP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A2,
 },
 [0xA4A3]={
  category="so",
  cjkwd="w",
  description="YI RADICAL CYT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A3,
 },
 [0xA4A4]={
  category="so",
  cjkwd="w",
  description="YI RADICAL DDUR",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A4,
 },
 [0xA4A5]={
  category="so",
  cjkwd="w",
  description="YI RADICAL BUR",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A5,
 },
 [0xA4A6]={
  category="so",
  cjkwd="w",
  description="YI RADICAL GGUO",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A6,
 },
 [0xA4A7]={
  category="so",
  cjkwd="w",
  description="YI RADICAL NYOP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A7,
 },
 [0xA4A8]={
  category="so",
  cjkwd="w",
  description="YI RADICAL TU",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A8,
 },
 [0xA4A9]={
  category="so",
  cjkwd="w",
  description="YI RADICAL OP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4A9,
 },
 [0xA4AA]={
  category="so",
  cjkwd="w",
  description="YI RADICAL JJUT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4AA,
 },
 [0xA4AB]={
  category="so",
  cjkwd="w",
  description="YI RADICAL ZOT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4AB,
 },
 [0xA4AC]={
  category="so",
  cjkwd="w",
  description="YI RADICAL PYT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4AC,
 },
 [0xA4AD]={
  category="so",
  cjkwd="w",
  description="YI RADICAL HMO",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4AD,
 },
 [0xA4AE]={
  category="so",
  cjkwd="w",
  description="YI RADICAL YIT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4AE,
 },
 [0xA4AF]={
  category="so",
  cjkwd="w",
  description="YI RADICAL VUR",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4AF,
 },
 [0xA4B0]={
  category="so",
  cjkwd="w",
  description="YI RADICAL SHY",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B0,
 },
 [0xA4B1]={
  category="so",
  cjkwd="w",
  description="YI RADICAL VEP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B1,
 },
 [0xA4B2]={
  category="so",
  cjkwd="w",
  description="YI RADICAL ZA",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B2,
 },
 [0xA4B3]={
  category="so",
  cjkwd="w",
  description="YI RADICAL JO",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B3,
 },
 [0xA4B4]={
  category="so",
  cjkwd="w",
  description="YI RADICAL NZUP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B4,
 },
 [0xA4B5]={
  category="so",
  cjkwd="w",
  description="YI RADICAL JJY",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B5,
 },
 [0xA4B6]={
  category="so",
  cjkwd="w",
  description="YI RADICAL GOT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B6,
 },
 [0xA4B7]={
  category="so",
  cjkwd="w",
  description="YI RADICAL JJIE",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B7,
 },
 [0xA4B8]={
  category="so",
  cjkwd="w",
  description="YI RADICAL WO",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B8,
 },
 [0xA4B9]={
  category="so",
  cjkwd="w",
  description="YI RADICAL DU",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4B9,
 },
 [0xA4BA]={
  category="so",
  cjkwd="w",
  description="YI RADICAL SHUR",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4BA,
 },
 [0xA4BB]={
  category="so",
  cjkwd="w",
  description="YI RADICAL LIE",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4BB,
 },
 [0xA4BC]={
  category="so",
  cjkwd="w",
  description="YI RADICAL CY",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4BC,
 },
 [0xA4BD]={
  category="so",
  cjkwd="w",
  description="YI RADICAL CUOP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4BD,
 },
 [0xA4BE]={
  category="so",
  cjkwd="w",
  description="YI RADICAL CIP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4BE,
 },
 [0xA4BF]={
  category="so",
  cjkwd="w",
  description="YI RADICAL HXOP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4BF,
 },
 [0xA4C0]={
  category="so",
  cjkwd="w",
  description="YI RADICAL SHAT",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4C0,
 },
 [0xA4C1]={
  category="so",
  cjkwd="w",
  description="YI RADICAL ZUR",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4C1,
 },
 [0xA4C2]={
  category="so",
  cjkwd="w",
  description="YI RADICAL SHOP",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4C2,
 },
 [0xA4C3]={
  category="so",
  cjkwd="w",
  description="YI RADICAL CHE",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4C3,
 },
 [0xA4C4]={
  category="so",
  cjkwd="w",
  description="YI RADICAL ZZIET",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4C4,
 },
 [0xA4C5]={
  category="so",
  cjkwd="w",
  description="YI RADICAL NBIE",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4C5,
 },
 [0xA4C6]={
  category="so",
  cjkwd="w",
  description="YI RADICAL KE",
  direction="on",
  linebreak="id",
  unicodeslot=0xA4C6,
 },
 [0xA4D0]={
  category="lo",
  description="LISU LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D0,
 },
 [0xA4D1]={
  category="lo",
  description="LISU LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D1,
 },
 [0xA4D2]={
  category="lo",
  description="LISU LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D2,
 },
 [0xA4D3]={
  category="lo",
  description="LISU LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D3,
 },
 [0xA4D4]={
  category="lo",
  description="LISU LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D4,
 },
 [0xA4D5]={
  category="lo",
  description="LISU LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D5,
 },
 [0xA4D6]={
  category="lo",
  description="LISU LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D6,
 },
 [0xA4D7]={
  category="lo",
  description="LISU LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D7,
 },
 [0xA4D8]={
  category="lo",
  description="LISU LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D8,
 },
 [0xA4D9]={
  category="lo",
  description="LISU LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4D9,
 },
 [0xA4DA]={
  category="lo",
  description="LISU LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4DA,
 },
 [0xA4DB]={
  category="lo",
  description="LISU LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4DB,
 },
 [0xA4DC]={
  category="lo",
  description="LISU LETTER DZA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4DC,
 },
 [0xA4DD]={
  category="lo",
  description="LISU LETTER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4DD,
 },
 [0xA4DE]={
  category="lo",
  description="LISU LETTER TSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4DE,
 },
 [0xA4DF]={
  category="lo",
  description="LISU LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4DF,
 },
 [0xA4E0]={
  category="lo",
  description="LISU LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E0,
 },
 [0xA4E1]={
  category="lo",
  description="LISU LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E1,
 },
 [0xA4E2]={
  category="lo",
  description="LISU LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E2,
 },
 [0xA4E3]={
  category="lo",
  description="LISU LETTER ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E3,
 },
 [0xA4E4]={
  category="lo",
  description="LISU LETTER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E4,
 },
 [0xA4E5]={
  category="lo",
  description="LISU LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E5,
 },
 [0xA4E6]={
  category="lo",
  description="LISU LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E6,
 },
 [0xA4E7]={
  category="lo",
  description="LISU LETTER XA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E7,
 },
 [0xA4E8]={
  category="lo",
  description="LISU LETTER HHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E8,
 },
 [0xA4E9]={
  category="lo",
  description="LISU LETTER FA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4E9,
 },
 [0xA4EA]={
  category="lo",
  description="LISU LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4EA,
 },
 [0xA4EB]={
  category="lo",
  description="LISU LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4EB,
 },
 [0xA4EC]={
  category="lo",
  description="LISU LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4EC,
 },
 [0xA4ED]={
  category="lo",
  description="LISU LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4ED,
 },
 [0xA4EE]={
  category="lo",
  description="LISU LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4EE,
 },
 [0xA4EF]={
  category="lo",
  description="LISU LETTER AE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4EF,
 },
 [0xA4F0]={
  category="lo",
  description="LISU LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F0,
 },
 [0xA4F1]={
  category="lo",
  description="LISU LETTER EU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F1,
 },
 [0xA4F2]={
  category="lo",
  description="LISU LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F2,
 },
 [0xA4F3]={
  category="lo",
  description="LISU LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F3,
 },
 [0xA4F4]={
  category="lo",
  description="LISU LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F4,
 },
 [0xA4F5]={
  category="lo",
  description="LISU LETTER UE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F5,
 },
 [0xA4F6]={
  category="lo",
  description="LISU LETTER UH",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F6,
 },
 [0xA4F7]={
  category="lo",
  description="LISU LETTER OE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F7,
 },
 [0xA4F8]={
  category="lm",
  description="LISU LETTER TONE MYA TI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F8,
 },
 [0xA4F9]={
  category="lm",
  description="LISU LETTER TONE NA PO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4F9,
 },
 [0xA4FA]={
  category="lm",
  description="LISU LETTER TONE MYA CYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4FA,
 },
 [0xA4FB]={
  category="lm",
  description="LISU LETTER TONE MYA BO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4FB,
 },
 [0xA4FC]={
  category="lm",
  description="LISU LETTER TONE MYA NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4FC,
 },
 [0xA4FD]={
  category="lm",
  description="LISU LETTER TONE MYA JEU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA4FD,
 },
 [0xA4FE]={
  category="po",
  description="LISU PUNCTUATION COMMA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA4FE,
 },
 [0xA4FF]={
  category="po",
  description="LISU PUNCTUATION FULL STOP",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA4FF,
 },
 [0xA500]={
  category="lo",
  description="VAI SYLLABLE EE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA500,
 },
 [0xA501]={
  category="lo",
  description="VAI SYLLABLE EEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA501,
 },
 [0xA502]={
  category="lo",
  description="VAI SYLLABLE HEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA502,
 },
 [0xA503]={
  category="lo",
  description="VAI SYLLABLE WEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA503,
 },
 [0xA504]={
  category="lo",
  description="VAI SYLLABLE WEEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA504,
 },
 [0xA505]={
  category="lo",
  description="VAI SYLLABLE PEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA505,
 },
 [0xA506]={
  category="lo",
  description="VAI SYLLABLE BHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA506,
 },
 [0xA507]={
  category="lo",
  description="VAI SYLLABLE BEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA507,
 },
 [0xA508]={
  category="lo",
  description="VAI SYLLABLE MBEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA508,
 },
 [0xA509]={
  category="lo",
  description="VAI SYLLABLE KPEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA509,
 },
 [0xA50A]={
  category="lo",
  description="VAI SYLLABLE MGBEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA50A,
 },
 [0xA50B]={
  category="lo",
  description="VAI SYLLABLE GBEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA50B,
 },
 [0xA50C]={
  category="lo",
  description="VAI SYLLABLE FEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA50C,
 },
 [0xA50D]={
  category="lo",
  description="VAI SYLLABLE VEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA50D,
 },
 [0xA50E]={
  category="lo",
  description="VAI SYLLABLE TEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA50E,
 },
 [0xA50F]={
  category="lo",
  description="VAI SYLLABLE THEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA50F,
 },
 [0xA510]={
  category="lo",
  description="VAI SYLLABLE DHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA510,
 },
 [0xA511]={
  category="lo",
  description="VAI SYLLABLE DHHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA511,
 },
 [0xA512]={
  category="lo",
  description="VAI SYLLABLE LEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA512,
 },
 [0xA513]={
  category="lo",
  description="VAI SYLLABLE REE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA513,
 },
 [0xA514]={
  category="lo",
  description="VAI SYLLABLE DEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA514,
 },
 [0xA515]={
  category="lo",
  description="VAI SYLLABLE NDEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA515,
 },
 [0xA516]={
  category="lo",
  description="VAI SYLLABLE SEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA516,
 },
 [0xA517]={
  category="lo",
  description="VAI SYLLABLE SHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA517,
 },
 [0xA518]={
  category="lo",
  description="VAI SYLLABLE ZEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA518,
 },
 [0xA519]={
  category="lo",
  description="VAI SYLLABLE ZHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA519,
 },
 [0xA51A]={
  category="lo",
  description="VAI SYLLABLE CEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA51A,
 },
 [0xA51B]={
  category="lo",
  description="VAI SYLLABLE JEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA51B,
 },
 [0xA51C]={
  category="lo",
  description="VAI SYLLABLE NJEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA51C,
 },
 [0xA51D]={
  category="lo",
  description="VAI SYLLABLE YEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA51D,
 },
 [0xA51E]={
  category="lo",
  description="VAI SYLLABLE KEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA51E,
 },
 [0xA51F]={
  category="lo",
  description="VAI SYLLABLE NGGEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA51F,
 },
 [0xA520]={
  category="lo",
  description="VAI SYLLABLE GEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA520,
 },
 [0xA521]={
  category="lo",
  description="VAI SYLLABLE MEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA521,
 },
 [0xA522]={
  category="lo",
  description="VAI SYLLABLE NEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA522,
 },
 [0xA523]={
  category="lo",
  description="VAI SYLLABLE NYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA523,
 },
 [0xA524]={
  category="lo",
  description="VAI SYLLABLE I",
  direction="l",
  linebreak="al",
  unicodeslot=0xA524,
 },
 [0xA525]={
  category="lo",
  description="VAI SYLLABLE IN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA525,
 },
 [0xA526]={
  category="lo",
  description="VAI SYLLABLE HI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA526,
 },
 [0xA527]={
  category="lo",
  description="VAI SYLLABLE HIN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA527,
 },
 [0xA528]={
  category="lo",
  description="VAI SYLLABLE WI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA528,
 },
 [0xA529]={
  category="lo",
  description="VAI SYLLABLE WIN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA529,
 },
 [0xA52A]={
  category="lo",
  description="VAI SYLLABLE PI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA52A,
 },
 [0xA52B]={
  category="lo",
  description="VAI SYLLABLE BHI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA52B,
 },
 [0xA52C]={
  category="lo",
  description="VAI SYLLABLE BI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA52C,
 },
 [0xA52D]={
  category="lo",
  description="VAI SYLLABLE MBI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA52D,
 },
 [0xA52E]={
  category="lo",
  description="VAI SYLLABLE KPI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA52E,
 },
 [0xA52F]={
  category="lo",
  description="VAI SYLLABLE MGBI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA52F,
 },
 [0xA530]={
  category="lo",
  description="VAI SYLLABLE GBI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA530,
 },
 [0xA531]={
  category="lo",
  description="VAI SYLLABLE FI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA531,
 },
 [0xA532]={
  category="lo",
  description="VAI SYLLABLE VI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA532,
 },
 [0xA533]={
  category="lo",
  description="VAI SYLLABLE TI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA533,
 },
 [0xA534]={
  category="lo",
  description="VAI SYLLABLE THI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA534,
 },
 [0xA535]={
  category="lo",
  description="VAI SYLLABLE DHI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA535,
 },
 [0xA536]={
  category="lo",
  description="VAI SYLLABLE DHHI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA536,
 },
 [0xA537]={
  category="lo",
  description="VAI SYLLABLE LI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA537,
 },
 [0xA538]={
  category="lo",
  description="VAI SYLLABLE RI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA538,
 },
 [0xA539]={
  category="lo",
  description="VAI SYLLABLE DI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA539,
 },
 [0xA53A]={
  category="lo",
  description="VAI SYLLABLE NDI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA53A,
 },
 [0xA53B]={
  category="lo",
  description="VAI SYLLABLE SI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA53B,
 },
 [0xA53C]={
  category="lo",
  description="VAI SYLLABLE SHI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA53C,
 },
 [0xA53D]={
  category="lo",
  description="VAI SYLLABLE ZI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA53D,
 },
 [0xA53E]={
  category="lo",
  description="VAI SYLLABLE ZHI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA53E,
 },
 [0xA53F]={
  category="lo",
  description="VAI SYLLABLE CI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA53F,
 },
 [0xA540]={
  category="lo",
  description="VAI SYLLABLE JI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA540,
 },
 [0xA541]={
  category="lo",
  description="VAI SYLLABLE NJI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA541,
 },
 [0xA542]={
  category="lo",
  description="VAI SYLLABLE YI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA542,
 },
 [0xA543]={
  category="lo",
  description="VAI SYLLABLE KI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA543,
 },
 [0xA544]={
  category="lo",
  description="VAI SYLLABLE NGGI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA544,
 },
 [0xA545]={
  category="lo",
  description="VAI SYLLABLE GI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA545,
 },
 [0xA546]={
  category="lo",
  description="VAI SYLLABLE MI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA546,
 },
 [0xA547]={
  category="lo",
  description="VAI SYLLABLE NI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA547,
 },
 [0xA548]={
  category="lo",
  description="VAI SYLLABLE NYI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA548,
 },
 [0xA549]={
  category="lo",
  description="VAI SYLLABLE A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA549,
 },
 [0xA54A]={
  category="lo",
  description="VAI SYLLABLE AN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA54A,
 },
 [0xA54B]={
  category="lo",
  description="VAI SYLLABLE NGAN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA54B,
 },
 [0xA54C]={
  category="lo",
  description="VAI SYLLABLE HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA54C,
 },
 [0xA54D]={
  category="lo",
  description="VAI SYLLABLE HAN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA54D,
 },
 [0xA54E]={
  category="lo",
  description="VAI SYLLABLE WA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA54E,
 },
 [0xA54F]={
  category="lo",
  description="VAI SYLLABLE WAN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA54F,
 },
 [0xA550]={
  category="lo",
  description="VAI SYLLABLE PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA550,
 },
 [0xA551]={
  category="lo",
  description="VAI SYLLABLE BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA551,
 },
 [0xA552]={
  category="lo",
  description="VAI SYLLABLE BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA552,
 },
 [0xA553]={
  category="lo",
  description="VAI SYLLABLE MBA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA553,
 },
 [0xA554]={
  category="lo",
  description="VAI SYLLABLE KPA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA554,
 },
 [0xA555]={
  category="lo",
  description="VAI SYLLABLE KPAN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA555,
 },
 [0xA556]={
  category="lo",
  description="VAI SYLLABLE MGBA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA556,
 },
 [0xA557]={
  category="lo",
  description="VAI SYLLABLE GBA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA557,
 },
 [0xA558]={
  category="lo",
  description="VAI SYLLABLE FA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA558,
 },
 [0xA559]={
  category="lo",
  description="VAI SYLLABLE VA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA559,
 },
 [0xA55A]={
  category="lo",
  description="VAI SYLLABLE TA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA55A,
 },
 [0xA55B]={
  category="lo",
  description="VAI SYLLABLE THA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA55B,
 },
 [0xA55C]={
  category="lo",
  description="VAI SYLLABLE DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA55C,
 },
 [0xA55D]={
  category="lo",
  description="VAI SYLLABLE DHHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA55D,
 },
 [0xA55E]={
  category="lo",
  description="VAI SYLLABLE LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA55E,
 },
 [0xA55F]={
  category="lo",
  description="VAI SYLLABLE RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA55F,
 },
 [0xA560]={
  category="lo",
  description="VAI SYLLABLE DA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA560,
 },
 [0xA561]={
  category="lo",
  description="VAI SYLLABLE NDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA561,
 },
 [0xA562]={
  category="lo",
  description="VAI SYLLABLE SA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA562,
 },
 [0xA563]={
  category="lo",
  description="VAI SYLLABLE SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA563,
 },
 [0xA564]={
  category="lo",
  description="VAI SYLLABLE ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA564,
 },
 [0xA565]={
  category="lo",
  description="VAI SYLLABLE ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA565,
 },
 [0xA566]={
  category="lo",
  description="VAI SYLLABLE CA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA566,
 },
 [0xA567]={
  category="lo",
  description="VAI SYLLABLE JA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA567,
 },
 [0xA568]={
  category="lo",
  description="VAI SYLLABLE NJA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA568,
 },
 [0xA569]={
  category="lo",
  description="VAI SYLLABLE YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA569,
 },
 [0xA56A]={
  category="lo",
  description="VAI SYLLABLE KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA56A,
 },
 [0xA56B]={
  category="lo",
  description="VAI SYLLABLE KAN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA56B,
 },
 [0xA56C]={
  category="lo",
  description="VAI SYLLABLE NGGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA56C,
 },
 [0xA56D]={
  category="lo",
  description="VAI SYLLABLE GA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA56D,
 },
 [0xA56E]={
  category="lo",
  description="VAI SYLLABLE MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA56E,
 },
 [0xA56F]={
  category="lo",
  description="VAI SYLLABLE NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA56F,
 },
 [0xA570]={
  category="lo",
  description="VAI SYLLABLE NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA570,
 },
 [0xA571]={
  category="lo",
  description="VAI SYLLABLE OO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA571,
 },
 [0xA572]={
  category="lo",
  description="VAI SYLLABLE OON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA572,
 },
 [0xA573]={
  category="lo",
  description="VAI SYLLABLE HOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA573,
 },
 [0xA574]={
  category="lo",
  description="VAI SYLLABLE WOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA574,
 },
 [0xA575]={
  category="lo",
  description="VAI SYLLABLE WOON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA575,
 },
 [0xA576]={
  category="lo",
  description="VAI SYLLABLE POO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA576,
 },
 [0xA577]={
  category="lo",
  description="VAI SYLLABLE BHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA577,
 },
 [0xA578]={
  category="lo",
  description="VAI SYLLABLE BOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA578,
 },
 [0xA579]={
  category="lo",
  description="VAI SYLLABLE MBOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA579,
 },
 [0xA57A]={
  category="lo",
  description="VAI SYLLABLE KPOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA57A,
 },
 [0xA57B]={
  category="lo",
  description="VAI SYLLABLE MGBOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA57B,
 },
 [0xA57C]={
  category="lo",
  description="VAI SYLLABLE GBOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA57C,
 },
 [0xA57D]={
  category="lo",
  description="VAI SYLLABLE FOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA57D,
 },
 [0xA57E]={
  category="lo",
  description="VAI SYLLABLE VOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA57E,
 },
 [0xA57F]={
  category="lo",
  description="VAI SYLLABLE TOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA57F,
 },
 [0xA580]={
  category="lo",
  description="VAI SYLLABLE THOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA580,
 },
 [0xA581]={
  category="lo",
  description="VAI SYLLABLE DHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA581,
 },
 [0xA582]={
  category="lo",
  description="VAI SYLLABLE DHHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA582,
 },
 [0xA583]={
  category="lo",
  description="VAI SYLLABLE LOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA583,
 },
 [0xA584]={
  category="lo",
  description="VAI SYLLABLE ROO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA584,
 },
 [0xA585]={
  category="lo",
  description="VAI SYLLABLE DOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA585,
 },
 [0xA586]={
  category="lo",
  description="VAI SYLLABLE NDOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA586,
 },
 [0xA587]={
  category="lo",
  description="VAI SYLLABLE SOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA587,
 },
 [0xA588]={
  category="lo",
  description="VAI SYLLABLE SHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA588,
 },
 [0xA589]={
  category="lo",
  description="VAI SYLLABLE ZOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA589,
 },
 [0xA58A]={
  category="lo",
  description="VAI SYLLABLE ZHOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA58A,
 },
 [0xA58B]={
  category="lo",
  description="VAI SYLLABLE COO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA58B,
 },
 [0xA58C]={
  category="lo",
  description="VAI SYLLABLE JOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA58C,
 },
 [0xA58D]={
  category="lo",
  description="VAI SYLLABLE NJOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA58D,
 },
 [0xA58E]={
  category="lo",
  description="VAI SYLLABLE YOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA58E,
 },
 [0xA58F]={
  category="lo",
  description="VAI SYLLABLE KOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA58F,
 },
 [0xA590]={
  category="lo",
  description="VAI SYLLABLE NGGOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA590,
 },
 [0xA591]={
  category="lo",
  description="VAI SYLLABLE GOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA591,
 },
 [0xA592]={
  category="lo",
  description="VAI SYLLABLE MOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA592,
 },
 [0xA593]={
  category="lo",
  description="VAI SYLLABLE NOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA593,
 },
 [0xA594]={
  category="lo",
  description="VAI SYLLABLE NYOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA594,
 },
 [0xA595]={
  category="lo",
  description="VAI SYLLABLE U",
  direction="l",
  linebreak="al",
  unicodeslot=0xA595,
 },
 [0xA596]={
  category="lo",
  description="VAI SYLLABLE UN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA596,
 },
 [0xA597]={
  category="lo",
  description="VAI SYLLABLE HU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA597,
 },
 [0xA598]={
  category="lo",
  description="VAI SYLLABLE HUN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA598,
 },
 [0xA599]={
  category="lo",
  description="VAI SYLLABLE WU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA599,
 },
 [0xA59A]={
  category="lo",
  description="VAI SYLLABLE WUN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA59A,
 },
 [0xA59B]={
  category="lo",
  description="VAI SYLLABLE PU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA59B,
 },
 [0xA59C]={
  category="lo",
  description="VAI SYLLABLE BHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA59C,
 },
 [0xA59D]={
  category="lo",
  description="VAI SYLLABLE BU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA59D,
 },
 [0xA59E]={
  category="lo",
  description="VAI SYLLABLE MBU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA59E,
 },
 [0xA59F]={
  category="lo",
  description="VAI SYLLABLE KPU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA59F,
 },
 [0xA5A0]={
  category="lo",
  description="VAI SYLLABLE MGBU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A0,
 },
 [0xA5A1]={
  category="lo",
  description="VAI SYLLABLE GBU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A1,
 },
 [0xA5A2]={
  category="lo",
  description="VAI SYLLABLE FU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A2,
 },
 [0xA5A3]={
  category="lo",
  description="VAI SYLLABLE VU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A3,
 },
 [0xA5A4]={
  category="lo",
  description="VAI SYLLABLE TU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A4,
 },
 [0xA5A5]={
  category="lo",
  description="VAI SYLLABLE THU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A5,
 },
 [0xA5A6]={
  category="lo",
  description="VAI SYLLABLE DHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A6,
 },
 [0xA5A7]={
  category="lo",
  description="VAI SYLLABLE DHHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A7,
 },
 [0xA5A8]={
  category="lo",
  description="VAI SYLLABLE LU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A8,
 },
 [0xA5A9]={
  category="lo",
  description="VAI SYLLABLE RU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5A9,
 },
 [0xA5AA]={
  category="lo",
  description="VAI SYLLABLE DU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5AA,
 },
 [0xA5AB]={
  category="lo",
  description="VAI SYLLABLE NDU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5AB,
 },
 [0xA5AC]={
  category="lo",
  description="VAI SYLLABLE SU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5AC,
 },
 [0xA5AD]={
  category="lo",
  description="VAI SYLLABLE SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5AD,
 },
 [0xA5AE]={
  category="lo",
  description="VAI SYLLABLE ZU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5AE,
 },
 [0xA5AF]={
  category="lo",
  description="VAI SYLLABLE ZHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5AF,
 },
 [0xA5B0]={
  category="lo",
  description="VAI SYLLABLE CU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B0,
 },
 [0xA5B1]={
  category="lo",
  description="VAI SYLLABLE JU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B1,
 },
 [0xA5B2]={
  category="lo",
  description="VAI SYLLABLE NJU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B2,
 },
 [0xA5B3]={
  category="lo",
  description="VAI SYLLABLE YU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B3,
 },
 [0xA5B4]={
  category="lo",
  description="VAI SYLLABLE KU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B4,
 },
 [0xA5B5]={
  category="lo",
  description="VAI SYLLABLE NGGU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B5,
 },
 [0xA5B6]={
  category="lo",
  description="VAI SYLLABLE GU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B6,
 },
 [0xA5B7]={
  category="lo",
  description="VAI SYLLABLE MU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B7,
 },
 [0xA5B8]={
  category="lo",
  description="VAI SYLLABLE NU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B8,
 },
 [0xA5B9]={
  category="lo",
  description="VAI SYLLABLE NYU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5B9,
 },
 [0xA5BA]={
  category="lo",
  description="VAI SYLLABLE O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5BA,
 },
 [0xA5BB]={
  category="lo",
  description="VAI SYLLABLE ON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5BB,
 },
 [0xA5BC]={
  category="lo",
  description="VAI SYLLABLE NGON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5BC,
 },
 [0xA5BD]={
  category="lo",
  description="VAI SYLLABLE HO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5BD,
 },
 [0xA5BE]={
  category="lo",
  description="VAI SYLLABLE HON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5BE,
 },
 [0xA5BF]={
  category="lo",
  description="VAI SYLLABLE WO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5BF,
 },
 [0xA5C0]={
  category="lo",
  description="VAI SYLLABLE WON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C0,
 },
 [0xA5C1]={
  category="lo",
  description="VAI SYLLABLE PO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C1,
 },
 [0xA5C2]={
  category="lo",
  description="VAI SYLLABLE BHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C2,
 },
 [0xA5C3]={
  category="lo",
  description="VAI SYLLABLE BO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C3,
 },
 [0xA5C4]={
  category="lo",
  description="VAI SYLLABLE MBO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C4,
 },
 [0xA5C5]={
  category="lo",
  description="VAI SYLLABLE KPO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C5,
 },
 [0xA5C6]={
  category="lo",
  description="VAI SYLLABLE MGBO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C6,
 },
 [0xA5C7]={
  category="lo",
  description="VAI SYLLABLE GBO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C7,
 },
 [0xA5C8]={
  category="lo",
  description="VAI SYLLABLE GBON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C8,
 },
 [0xA5C9]={
  category="lo",
  description="VAI SYLLABLE FO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5C9,
 },
 [0xA5CA]={
  category="lo",
  description="VAI SYLLABLE VO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5CA,
 },
 [0xA5CB]={
  category="lo",
  description="VAI SYLLABLE TO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5CB,
 },
 [0xA5CC]={
  category="lo",
  description="VAI SYLLABLE THO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5CC,
 },
 [0xA5CD]={
  category="lo",
  description="VAI SYLLABLE DHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5CD,
 },
 [0xA5CE]={
  category="lo",
  description="VAI SYLLABLE DHHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5CE,
 },
 [0xA5CF]={
  category="lo",
  description="VAI SYLLABLE LO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5CF,
 },
 [0xA5D0]={
  category="lo",
  description="VAI SYLLABLE RO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D0,
 },
 [0xA5D1]={
  category="lo",
  description="VAI SYLLABLE DO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D1,
 },
 [0xA5D2]={
  category="lo",
  description="VAI SYLLABLE NDO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D2,
 },
 [0xA5D3]={
  category="lo",
  description="VAI SYLLABLE SO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D3,
 },
 [0xA5D4]={
  category="lo",
  description="VAI SYLLABLE SHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D4,
 },
 [0xA5D5]={
  category="lo",
  description="VAI SYLLABLE ZO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D5,
 },
 [0xA5D6]={
  category="lo",
  description="VAI SYLLABLE ZHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D6,
 },
 [0xA5D7]={
  category="lo",
  description="VAI SYLLABLE CO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D7,
 },
 [0xA5D8]={
  category="lo",
  description="VAI SYLLABLE JO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D8,
 },
 [0xA5D9]={
  category="lo",
  description="VAI SYLLABLE NJO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5D9,
 },
 [0xA5DA]={
  category="lo",
  description="VAI SYLLABLE YO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5DA,
 },
 [0xA5DB]={
  category="lo",
  description="VAI SYLLABLE KO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5DB,
 },
 [0xA5DC]={
  category="lo",
  description="VAI SYLLABLE NGGO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5DC,
 },
 [0xA5DD]={
  category="lo",
  description="VAI SYLLABLE GO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5DD,
 },
 [0xA5DE]={
  category="lo",
  description="VAI SYLLABLE MO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5DE,
 },
 [0xA5DF]={
  category="lo",
  description="VAI SYLLABLE NO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5DF,
 },
 [0xA5E0]={
  category="lo",
  description="VAI SYLLABLE NYO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E0,
 },
 [0xA5E1]={
  category="lo",
  description="VAI SYLLABLE E",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E1,
 },
 [0xA5E2]={
  category="lo",
  description="VAI SYLLABLE EN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E2,
 },
 [0xA5E3]={
  category="lo",
  description="VAI SYLLABLE NGEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E3,
 },
 [0xA5E4]={
  category="lo",
  description="VAI SYLLABLE HE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E4,
 },
 [0xA5E5]={
  category="lo",
  description="VAI SYLLABLE HEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E5,
 },
 [0xA5E6]={
  category="lo",
  description="VAI SYLLABLE WE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E6,
 },
 [0xA5E7]={
  category="lo",
  description="VAI SYLLABLE WEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E7,
 },
 [0xA5E8]={
  category="lo",
  description="VAI SYLLABLE PE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E8,
 },
 [0xA5E9]={
  category="lo",
  description="VAI SYLLABLE BHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5E9,
 },
 [0xA5EA]={
  category="lo",
  description="VAI SYLLABLE BE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5EA,
 },
 [0xA5EB]={
  category="lo",
  description="VAI SYLLABLE MBE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5EB,
 },
 [0xA5EC]={
  category="lo",
  description="VAI SYLLABLE KPE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5EC,
 },
 [0xA5ED]={
  category="lo",
  description="VAI SYLLABLE KPEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5ED,
 },
 [0xA5EE]={
  category="lo",
  description="VAI SYLLABLE MGBE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5EE,
 },
 [0xA5EF]={
  category="lo",
  description="VAI SYLLABLE GBE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5EF,
 },
 [0xA5F0]={
  category="lo",
  description="VAI SYLLABLE GBEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F0,
 },
 [0xA5F1]={
  category="lo",
  description="VAI SYLLABLE FE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F1,
 },
 [0xA5F2]={
  category="lo",
  description="VAI SYLLABLE VE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F2,
 },
 [0xA5F3]={
  category="lo",
  description="VAI SYLLABLE TE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F3,
 },
 [0xA5F4]={
  category="lo",
  description="VAI SYLLABLE THE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F4,
 },
 [0xA5F5]={
  category="lo",
  description="VAI SYLLABLE DHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F5,
 },
 [0xA5F6]={
  category="lo",
  description="VAI SYLLABLE DHHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F6,
 },
 [0xA5F7]={
  category="lo",
  description="VAI SYLLABLE LE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F7,
 },
 [0xA5F8]={
  category="lo",
  description="VAI SYLLABLE RE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F8,
 },
 [0xA5F9]={
  category="lo",
  description="VAI SYLLABLE DE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5F9,
 },
 [0xA5FA]={
  category="lo",
  description="VAI SYLLABLE NDE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5FA,
 },
 [0xA5FB]={
  category="lo",
  description="VAI SYLLABLE SE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5FB,
 },
 [0xA5FC]={
  category="lo",
  description="VAI SYLLABLE SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5FC,
 },
 [0xA5FD]={
  category="lo",
  description="VAI SYLLABLE ZE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5FD,
 },
 [0xA5FE]={
  category="lo",
  description="VAI SYLLABLE ZHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5FE,
 },
 [0xA5FF]={
  category="lo",
  description="VAI SYLLABLE CE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA5FF,
 },
 [0xA600]={
  category="lo",
  description="VAI SYLLABLE JE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA600,
 },
 [0xA601]={
  category="lo",
  description="VAI SYLLABLE NJE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA601,
 },
 [0xA602]={
  category="lo",
  description="VAI SYLLABLE YE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA602,
 },
 [0xA603]={
  category="lo",
  description="VAI SYLLABLE KE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA603,
 },
 [0xA604]={
  category="lo",
  description="VAI SYLLABLE NGGE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA604,
 },
 [0xA605]={
  category="lo",
  description="VAI SYLLABLE NGGEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA605,
 },
 [0xA606]={
  category="lo",
  description="VAI SYLLABLE GE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA606,
 },
 [0xA607]={
  category="lo",
  description="VAI SYLLABLE GEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA607,
 },
 [0xA608]={
  category="lo",
  description="VAI SYLLABLE ME",
  direction="l",
  linebreak="al",
  unicodeslot=0xA608,
 },
 [0xA609]={
  category="lo",
  description="VAI SYLLABLE NE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA609,
 },
 [0xA60A]={
  category="lo",
  description="VAI SYLLABLE NYE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA60A,
 },
 [0xA60B]={
  category="lo",
  description="VAI SYLLABLE NG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA60B,
 },
 [0xA60C]={
  category="lm",
  description="VAI SYLLABLE LENGTHENER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA60C,
 },
 [0xA60D]={
  category="po",
  description="VAI COMMA",
  direction="on",
  linebreak="ba",
  unicodeslot=0xA60D,
 },
 [0xA60E]={
  category="po",
  description="VAI FULL STOP",
  direction="on",
  linebreak="ex",
  unicodeslot=0xA60E,
 },
 [0xA60F]={
  category="po",
  description="VAI QUESTION MARK",
  direction="on",
  linebreak="ba",
  unicodeslot=0xA60F,
 },
 [0xA610]={
  category="lo",
  description="VAI SYLLABLE NDOLE FA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA610,
 },
 [0xA611]={
  category="lo",
  description="VAI SYLLABLE NDOLE KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA611,
 },
 [0xA612]={
  category="lo",
  description="VAI SYLLABLE NDOLE SOO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA612,
 },
 [0xA613]={
  category="lo",
  description="VAI SYMBOL FEENG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA613,
 },
 [0xA614]={
  category="lo",
  description="VAI SYMBOL KEENG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA614,
 },
 [0xA615]={
  category="lo",
  description="VAI SYMBOL TING",
  direction="l",
  linebreak="al",
  unicodeslot=0xA615,
 },
 [0xA616]={
  category="lo",
  description="VAI SYMBOL NII",
  direction="l",
  linebreak="al",
  unicodeslot=0xA616,
 },
 [0xA617]={
  category="lo",
  description="VAI SYMBOL BANG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA617,
 },
 [0xA618]={
  category="lo",
  description="VAI SYMBOL FAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA618,
 },
 [0xA619]={
  category="lo",
  description="VAI SYMBOL TAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA619,
 },
 [0xA61A]={
  category="lo",
  description="VAI SYMBOL DANG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA61A,
 },
 [0xA61B]={
  category="lo",
  description="VAI SYMBOL DOONG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA61B,
 },
 [0xA61C]={
  category="lo",
  description="VAI SYMBOL KUNG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA61C,
 },
 [0xA61D]={
  category="lo",
  description="VAI SYMBOL TONG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA61D,
 },
 [0xA61E]={
  category="lo",
  description="VAI SYMBOL DO-O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA61E,
 },
 [0xA61F]={
  category="lo",
  description="VAI SYMBOL JONG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA61F,
 },
 [0xA620]={
  category="nd",
  description="VAI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA620,
 },
 [0xA621]={
  category="nd",
  description="VAI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA621,
 },
 [0xA622]={
  category="nd",
  description="VAI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA622,
 },
 [0xA623]={
  category="nd",
  description="VAI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA623,
 },
 [0xA624]={
  category="nd",
  description="VAI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA624,
 },
 [0xA625]={
  category="nd",
  description="VAI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA625,
 },
 [0xA626]={
  category="nd",
  description="VAI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA626,
 },
 [0xA627]={
  category="nd",
  description="VAI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA627,
 },
 [0xA628]={
  category="nd",
  description="VAI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA628,
 },
 [0xA629]={
  category="nd",
  description="VAI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA629,
 },
 [0xA62A]={
  category="lo",
  description="VAI SYLLABLE NDOLE MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA62A,
 },
 [0xA62B]={
  category="lo",
  description="VAI SYLLABLE NDOLE DO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA62B,
 },
 [0xA640]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER ZEMLYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA640,
 },
 [0xA641]={
  category="ll",
  description="CYRILLIC SMALL LETTER ZEMLYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA641,
 },
 [0xA642]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER DZELO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA642,
 },
 [0xA643]={
  category="ll",
  description="CYRILLIC SMALL LETTER DZELO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA643,
 },
 [0xA644]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER REVERSED DZE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA644,
 },
 [0xA645]={
  category="ll",
  description="CYRILLIC SMALL LETTER REVERSED DZE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA645,
 },
 [0xA646]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER IOTA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA646,
 },
 [0xA647]={
  category="ll",
  description="CYRILLIC SMALL LETTER IOTA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA647,
 },
 [0xA648]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER DJERV",
  direction="l",
  linebreak="al",
  unicodeslot=0xA648,
 },
 [0xA649]={
  category="ll",
  description="CYRILLIC SMALL LETTER DJERV",
  direction="l",
  linebreak="al",
  unicodeslot=0xA649,
 },
 [0xA64A]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER MONOGRAPH UK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA64A,
 },
 [0xA64B]={
  category="ll",
  description="CYRILLIC SMALL LETTER MONOGRAPH UK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA64B,
 },
 [0xA64C]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER BROAD OMEGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA64C,
 },
 [0xA64D]={
  category="ll",
  description="CYRILLIC SMALL LETTER BROAD OMEGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA64D,
 },
 [0xA64E]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER NEUTRAL YER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA64E,
 },
 [0xA64F]={
  category="ll",
  description="CYRILLIC SMALL LETTER NEUTRAL YER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA64F,
 },
 [0xA650]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER YERU WITH BACK YER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA650,
 },
 [0xA651]={
  category="ll",
  description="CYRILLIC SMALL LETTER YERU WITH BACK YER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA651,
 },
 [0xA652]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER IOTIFIED YAT",
  direction="l",
  linebreak="al",
  unicodeslot=0xA652,
 },
 [0xA653]={
  category="ll",
  description="CYRILLIC SMALL LETTER IOTIFIED YAT",
  direction="l",
  linebreak="al",
  unicodeslot=0xA653,
 },
 [0xA654]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER REVERSED YU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA654,
 },
 [0xA655]={
  category="ll",
  description="CYRILLIC SMALL LETTER REVERSED YU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA655,
 },
 [0xA656]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER IOTIFIED A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA656,
 },
 [0xA657]={
  category="ll",
  description="CYRILLIC SMALL LETTER IOTIFIED A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA657,
 },
 [0xA658]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER CLOSED LITTLE YUS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA658,
 },
 [0xA659]={
  category="ll",
  description="CYRILLIC SMALL LETTER CLOSED LITTLE YUS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA659,
 },
 [0xA65A]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER BLENDED YUS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA65A,
 },
 [0xA65B]={
  category="ll",
  description="CYRILLIC SMALL LETTER BLENDED YUS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA65B,
 },
 [0xA65C]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER IOTIFIED CLOSED LITTLE YUS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA65C,
 },
 [0xA65D]={
  category="ll",
  description="CYRILLIC SMALL LETTER IOTIFIED CLOSED LITTLE YUS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA65D,
 },
 [0xA65E]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER YN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA65E,
 },
 [0xA65F]={
  category="ll",
  description="CYRILLIC SMALL LETTER YN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA65F,
 },
 [0xA660]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER REVERSED TSE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA660,
 },
 [0xA661]={
  category="ll",
  description="CYRILLIC SMALL LETTER REVERSED TSE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA661,
 },
 [0xA662]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER SOFT DE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA662,
 },
 [0xA663]={
  category="ll",
  description="CYRILLIC SMALL LETTER SOFT DE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA663,
 },
 [0xA664]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER SOFT EL",
  direction="l",
  linebreak="al",
  unicodeslot=0xA664,
 },
 [0xA665]={
  category="ll",
  description="CYRILLIC SMALL LETTER SOFT EL",
  direction="l",
  linebreak="al",
  unicodeslot=0xA665,
 },
 [0xA666]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER SOFT EM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA666,
 },
 [0xA667]={
  category="ll",
  description="CYRILLIC SMALL LETTER SOFT EM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA667,
 },
 [0xA668]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER MONOCULAR O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA668,
 },
 [0xA669]={
  category="ll",
  description="CYRILLIC SMALL LETTER MONOCULAR O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA669,
 },
 [0xA66A]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER BINOCULAR O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA66A,
 },
 [0xA66B]={
  category="ll",
  description="CYRILLIC SMALL LETTER BINOCULAR O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA66B,
 },
 [0xA66C]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER DOUBLE MONOCULAR O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA66C,
 },
 [0xA66D]={
  category="ll",
  description="CYRILLIC SMALL LETTER DOUBLE MONOCULAR O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA66D,
 },
 [0xA66E]={
  category="lo",
  description="CYRILLIC LETTER MULTIOCULAR O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA66E,
 },
 [0xA66F]={
  category="mn",
  description="COMBINING CYRILLIC VZMET",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA66F,
 },
 [0xA670]={
  category="me",
  description="COMBINING CYRILLIC TEN MILLIONS SIGN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA670,
 },
 [0xA671]={
  category="me",
  description="COMBINING CYRILLIC HUNDRED MILLIONS SIGN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA671,
 },
 [0xA672]={
  category="me",
  description="COMBINING CYRILLIC THOUSAND MILLIONS SIGN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA672,
 },
 [0xA673]={
  category="po",
  description="SLAVONIC ASTERISK",
  direction="on",
  linebreak="al",
  unicodeslot=0xA673,
 },
 [0xA674]={
  category="mn",
  description="COMBINING CYRILLIC LETTER UKRAINIAN IE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA674,
 },
 [0xA675]={
  category="mn",
  description="COMBINING CYRILLIC LETTER I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA675,
 },
 [0xA676]={
  category="mn",
  description="COMBINING CYRILLIC LETTER YI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA676,
 },
 [0xA677]={
  category="mn",
  description="COMBINING CYRILLIC LETTER U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA677,
 },
 [0xA678]={
  category="mn",
  description="COMBINING CYRILLIC LETTER HARD SIGN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA678,
 },
 [0xA679]={
  category="mn",
  description="COMBINING CYRILLIC LETTER YERU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA679,
 },
 [0xA67A]={
  category="mn",
  description="COMBINING CYRILLIC LETTER SOFT SIGN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA67A,
 },
 [0xA67B]={
  category="mn",
  description="COMBINING CYRILLIC LETTER OMEGA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA67B,
 },
 [0xA67C]={
  category="mn",
  description="COMBINING CYRILLIC KAVYKA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA67C,
 },
 [0xA67D]={
  category="mn",
  description="COMBINING CYRILLIC PAYEROK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA67D,
 },
 [0xA67E]={
  category="po",
  description="CYRILLIC KAVYKA",
  direction="on",
  linebreak="al",
  unicodeslot=0xA67E,
 },
 [0xA67F]={
  category="lm",
  description="CYRILLIC PAYEROK",
  direction="on",
  linebreak="al",
  unicodeslot=0xA67F,
 },
 [0xA680]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER DWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA680,
 },
 [0xA681]={
  category="ll",
  description="CYRILLIC SMALL LETTER DWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA681,
 },
 [0xA682]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER DZWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA682,
 },
 [0xA683]={
  category="ll",
  description="CYRILLIC SMALL LETTER DZWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA683,
 },
 [0xA684]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER ZHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA684,
 },
 [0xA685]={
  category="ll",
  description="CYRILLIC SMALL LETTER ZHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA685,
 },
 [0xA686]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER CCHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA686,
 },
 [0xA687]={
  category="ll",
  description="CYRILLIC SMALL LETTER CCHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA687,
 },
 [0xA688]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER DZZE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA688,
 },
 [0xA689]={
  category="ll",
  description="CYRILLIC SMALL LETTER DZZE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA689,
 },
 [0xA68A]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER TE WITH MIDDLE HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA68A,
 },
 [0xA68B]={
  category="ll",
  description="CYRILLIC SMALL LETTER TE WITH MIDDLE HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA68B,
 },
 [0xA68C]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER TWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA68C,
 },
 [0xA68D]={
  category="ll",
  description="CYRILLIC SMALL LETTER TWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA68D,
 },
 [0xA68E]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER TSWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA68E,
 },
 [0xA68F]={
  category="ll",
  description="CYRILLIC SMALL LETTER TSWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA68F,
 },
 [0xA690]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER TSSE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA690,
 },
 [0xA691]={
  category="ll",
  description="CYRILLIC SMALL LETTER TSSE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA691,
 },
 [0xA692]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER TCHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA692,
 },
 [0xA693]={
  category="ll",
  description="CYRILLIC SMALL LETTER TCHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA693,
 },
 [0xA694]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER HWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA694,
 },
 [0xA695]={
  category="ll",
  description="CYRILLIC SMALL LETTER HWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA695,
 },
 [0xA696]={
  category="lu",
  description="CYRILLIC CAPITAL LETTER SHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA696,
 },
 [0xA697]={
  category="ll",
  description="CYRILLIC SMALL LETTER SHWE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA697,
 },
 [0xA69F]={
  category="mn",
  description="COMBINING CYRILLIC LETTER IOTIFIED E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA69F,
 },
 [0xA6A0]={
  category="lo",
  description="BAMUM LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A0,
 },
 [0xA6A1]={
  category="lo",
  description="BAMUM LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A1,
 },
 [0xA6A2]={
  category="lo",
  description="BAMUM LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A2,
 },
 [0xA6A3]={
  category="lo",
  description="BAMUM LETTER KU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A3,
 },
 [0xA6A4]={
  category="lo",
  description="BAMUM LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A4,
 },
 [0xA6A5]={
  category="lo",
  description="BAMUM LETTER REE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A5,
 },
 [0xA6A6]={
  category="lo",
  description="BAMUM LETTER TAE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A6,
 },
 [0xA6A7]={
  category="lo",
  description="BAMUM LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A7,
 },
 [0xA6A8]={
  category="lo",
  description="BAMUM LETTER NYI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A8,
 },
 [0xA6A9]={
  category="lo",
  description="BAMUM LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6A9,
 },
 [0xA6AA]={
  category="lo",
  description="BAMUM LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6AA,
 },
 [0xA6AB]={
  category="lo",
  description="BAMUM LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6AB,
 },
 [0xA6AC]={
  category="lo",
  description="BAMUM LETTER RII",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6AC,
 },
 [0xA6AD]={
  category="lo",
  description="BAMUM LETTER RIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6AD,
 },
 [0xA6AE]={
  category="lo",
  description="BAMUM LETTER LEEEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6AE,
 },
 [0xA6AF]={
  category="lo",
  description="BAMUM LETTER MEEEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6AF,
 },
 [0xA6B0]={
  category="lo",
  description="BAMUM LETTER TAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B0,
 },
 [0xA6B1]={
  category="lo",
  description="BAMUM LETTER NDAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B1,
 },
 [0xA6B2]={
  category="lo",
  description="BAMUM LETTER NJAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B2,
 },
 [0xA6B3]={
  category="lo",
  description="BAMUM LETTER M",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B3,
 },
 [0xA6B4]={
  category="lo",
  description="BAMUM LETTER SUU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B4,
 },
 [0xA6B5]={
  category="lo",
  description="BAMUM LETTER MU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B5,
 },
 [0xA6B6]={
  category="lo",
  description="BAMUM LETTER SHII",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B6,
 },
 [0xA6B7]={
  category="lo",
  description="BAMUM LETTER SI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B7,
 },
 [0xA6B8]={
  category="lo",
  description="BAMUM LETTER SHEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B8,
 },
 [0xA6B9]={
  category="lo",
  description="BAMUM LETTER SEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6B9,
 },
 [0xA6BA]={
  category="lo",
  description="BAMUM LETTER KYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6BA,
 },
 [0xA6BB]={
  category="lo",
  description="BAMUM LETTER KET",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6BB,
 },
 [0xA6BC]={
  category="lo",
  description="BAMUM LETTER NUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6BC,
 },
 [0xA6BD]={
  category="lo",
  description="BAMUM LETTER NU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6BD,
 },
 [0xA6BE]={
  category="lo",
  description="BAMUM LETTER NJUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6BE,
 },
 [0xA6BF]={
  category="lo",
  description="BAMUM LETTER YOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6BF,
 },
 [0xA6C0]={
  category="lo",
  description="BAMUM LETTER SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C0,
 },
 [0xA6C1]={
  category="lo",
  description="BAMUM LETTER YUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C1,
 },
 [0xA6C2]={
  category="lo",
  description="BAMUM LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C2,
 },
 [0xA6C3]={
  category="lo",
  description="BAMUM LETTER NSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C3,
 },
 [0xA6C4]={
  category="lo",
  description="BAMUM LETTER KEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C4,
 },
 [0xA6C5]={
  category="lo",
  description="BAMUM LETTER PEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C5,
 },
 [0xA6C6]={
  category="lo",
  description="BAMUM LETTER NJEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C6,
 },
 [0xA6C7]={
  category="lo",
  description="BAMUM LETTER NTEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C7,
 },
 [0xA6C8]={
  category="lo",
  description="BAMUM LETTER PUE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C8,
 },
 [0xA6C9]={
  category="lo",
  description="BAMUM LETTER WUE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6C9,
 },
 [0xA6CA]={
  category="lo",
  description="BAMUM LETTER PEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6CA,
 },
 [0xA6CB]={
  category="lo",
  description="BAMUM LETTER FEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6CB,
 },
 [0xA6CC]={
  category="lo",
  description="BAMUM LETTER RU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6CC,
 },
 [0xA6CD]={
  category="lo",
  description="BAMUM LETTER LU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6CD,
 },
 [0xA6CE]={
  category="lo",
  description="BAMUM LETTER MI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6CE,
 },
 [0xA6CF]={
  category="lo",
  description="BAMUM LETTER NI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6CF,
 },
 [0xA6D0]={
  category="lo",
  description="BAMUM LETTER REUX",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D0,
 },
 [0xA6D1]={
  category="lo",
  description="BAMUM LETTER RAE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D1,
 },
 [0xA6D2]={
  category="lo",
  description="BAMUM LETTER KEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D2,
 },
 [0xA6D3]={
  category="lo",
  description="BAMUM LETTER NGKWAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D3,
 },
 [0xA6D4]={
  category="lo",
  description="BAMUM LETTER NGGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D4,
 },
 [0xA6D5]={
  category="lo",
  description="BAMUM LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D5,
 },
 [0xA6D6]={
  category="lo",
  description="BAMUM LETTER SHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D6,
 },
 [0xA6D7]={
  category="lo",
  description="BAMUM LETTER PUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D7,
 },
 [0xA6D8]={
  category="lo",
  description="BAMUM LETTER FU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D8,
 },
 [0xA6D9]={
  category="lo",
  description="BAMUM LETTER FOM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6D9,
 },
 [0xA6DA]={
  category="lo",
  description="BAMUM LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6DA,
 },
 [0xA6DB]={
  category="lo",
  description="BAMUM LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6DB,
 },
 [0xA6DC]={
  category="lo",
  description="BAMUM LETTER LI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6DC,
 },
 [0xA6DD]={
  category="lo",
  description="BAMUM LETTER PI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6DD,
 },
 [0xA6DE]={
  category="lo",
  description="BAMUM LETTER LOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6DE,
 },
 [0xA6DF]={
  category="lo",
  description="BAMUM LETTER KO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6DF,
 },
 [0xA6E0]={
  category="lo",
  description="BAMUM LETTER MBEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E0,
 },
 [0xA6E1]={
  category="lo",
  description="BAMUM LETTER REN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E1,
 },
 [0xA6E2]={
  category="lo",
  description="BAMUM LETTER MEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E2,
 },
 [0xA6E3]={
  category="lo",
  description="BAMUM LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E3,
 },
 [0xA6E4]={
  category="lo",
  description="BAMUM LETTER TI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E4,
 },
 [0xA6E5]={
  category="lo",
  description="BAMUM LETTER KI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E5,
 },
 [0xA6E6]={
  category="nl",
  description="BAMUM LETTER MO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E6,
 },
 [0xA6E7]={
  category="nl",
  description="BAMUM LETTER MBAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E7,
 },
 [0xA6E8]={
  category="nl",
  description="BAMUM LETTER TET",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E8,
 },
 [0xA6E9]={
  category="nl",
  description="BAMUM LETTER KPA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6E9,
 },
 [0xA6EA]={
  category="nl",
  description="BAMUM LETTER TEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6EA,
 },
 [0xA6EB]={
  category="nl",
  description="BAMUM LETTER NTUU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6EB,
 },
 [0xA6EC]={
  category="nl",
  description="BAMUM LETTER SAMBA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6EC,
 },
 [0xA6ED]={
  category="nl",
  description="BAMUM LETTER FAAMAE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6ED,
 },
 [0xA6EE]={
  category="nl",
  description="BAMUM LETTER KOVUU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6EE,
 },
 [0xA6EF]={
  category="nl",
  description="BAMUM LETTER KOGHOM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6EF,
 },
 [0xA6F0]={
  category="mn",
  description="BAMUM COMBINING MARK KOQNDON",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA6F0,
 },
 [0xA6F1]={
  category="mn",
  description="BAMUM COMBINING MARK TUKWENTIS",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA6F1,
 },
 [0xA6F2]={
  category="po",
  description="BAMUM NJAEMLI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA6F2,
 },
 [0xA6F3]={
  category="po",
  description="BAMUM FULL STOP",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA6F3,
 },
 [0xA6F4]={
  category="po",
  description="BAMUM COLON",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA6F4,
 },
 [0xA6F5]={
  category="po",
  description="BAMUM COMMA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA6F5,
 },
 [0xA6F6]={
  category="po",
  description="BAMUM SEMICOLON",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA6F6,
 },
 [0xA6F7]={
  category="po",
  description="BAMUM QUESTION MARK",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA6F7,
 },
 [0xA700]={
  category="sk",
  description="MODIFIER LETTER CHINESE TONE YIN PING",
  direction="on",
  linebreak="al",
  unicodeslot=0xA700,
 },
 [0xA701]={
  category="sk",
  description="MODIFIER LETTER CHINESE TONE YANG PING",
  direction="on",
  linebreak="al",
  unicodeslot=0xA701,
 },
 [0xA702]={
  category="sk",
  description="MODIFIER LETTER CHINESE TONE YIN SHANG",
  direction="on",
  linebreak="al",
  unicodeslot=0xA702,
 },
 [0xA703]={
  category="sk",
  description="MODIFIER LETTER CHINESE TONE YANG SHANG",
  direction="on",
  linebreak="al",
  unicodeslot=0xA703,
 },
 [0xA704]={
  category="sk",
  description="MODIFIER LETTER CHINESE TONE YIN QU",
  direction="on",
  linebreak="al",
  unicodeslot=0xA704,
 },
 [0xA705]={
  category="sk",
  description="MODIFIER LETTER CHINESE TONE YANG QU",
  direction="on",
  linebreak="al",
  unicodeslot=0xA705,
 },
 [0xA706]={
  category="sk",
  description="MODIFIER LETTER CHINESE TONE YIN RU",
  direction="on",
  linebreak="al",
  unicodeslot=0xA706,
 },
 [0xA707]={
  category="sk",
  description="MODIFIER LETTER CHINESE TONE YANG RU",
  direction="on",
  linebreak="al",
  unicodeslot=0xA707,
 },
 [0xA708]={
  category="sk",
  description="MODIFIER LETTER EXTRA-HIGH DOTTED TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA708,
 },
 [0xA709]={
  category="sk",
  description="MODIFIER LETTER HIGH DOTTED TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA709,
 },
 [0xA70A]={
  category="sk",
  description="MODIFIER LETTER MID DOTTED TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA70A,
 },
 [0xA70B]={
  category="sk",
  description="MODIFIER LETTER LOW DOTTED TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA70B,
 },
 [0xA70C]={
  category="sk",
  description="MODIFIER LETTER EXTRA-LOW DOTTED TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA70C,
 },
 [0xA70D]={
  category="sk",
  description="MODIFIER LETTER EXTRA-HIGH DOTTED LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA70D,
 },
 [0xA70E]={
  category="sk",
  description="MODIFIER LETTER HIGH DOTTED LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA70E,
 },
 [0xA70F]={
  category="sk",
  description="MODIFIER LETTER MID DOTTED LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA70F,
 },
 [0xA710]={
  category="sk",
  description="MODIFIER LETTER LOW DOTTED LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA710,
 },
 [0xA711]={
  category="sk",
  description="MODIFIER LETTER EXTRA-LOW DOTTED LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA711,
 },
 [0xA712]={
  category="sk",
  description="MODIFIER LETTER EXTRA-HIGH LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA712,
 },
 [0xA713]={
  category="sk",
  description="MODIFIER LETTER HIGH LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA713,
 },
 [0xA714]={
  category="sk",
  description="MODIFIER LETTER MID LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA714,
 },
 [0xA715]={
  category="sk",
  description="MODIFIER LETTER LOW LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA715,
 },
 [0xA716]={
  category="sk",
  description="MODIFIER LETTER EXTRA-LOW LEFT-STEM TONE BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA716,
 },
 [0xA717]={
  category="lm",
  description="MODIFIER LETTER DOT VERTICAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA717,
 },
 [0xA718]={
  category="lm",
  description="MODIFIER LETTER DOT SLASH",
  direction="on",
  linebreak="al",
  unicodeslot=0xA718,
 },
 [0xA719]={
  category="lm",
  description="MODIFIER LETTER DOT HORIZONTAL BAR",
  direction="on",
  linebreak="al",
  unicodeslot=0xA719,
 },
 [0xA71A]={
  category="lm",
  description="MODIFIER LETTER LOWER RIGHT CORNER ANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0xA71A,
 },
 [0xA71B]={
  category="lm",
  description="MODIFIER LETTER RAISED UP ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0xA71B,
 },
 [0xA71C]={
  category="lm",
  description="MODIFIER LETTER RAISED DOWN ARROW",
  direction="on",
  linebreak="al",
  unicodeslot=0xA71C,
 },
 [0xA71D]={
  category="lm",
  description="MODIFIER LETTER RAISED EXCLAMATION MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0xA71D,
 },
 [0xA71E]={
  category="lm",
  description="MODIFIER LETTER RAISED INVERTED EXCLAMATION MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0xA71E,
 },
 [0xA71F]={
  category="lm",
  description="MODIFIER LETTER LOW INVERTED EXCLAMATION MARK",
  direction="on",
  linebreak="al",
  unicodeslot=0xA71F,
 },
 [0xA720]={
  category="sk",
  description="MODIFIER LETTER STRESS AND HIGH TONE",
  direction="on",
  linebreak="al",
  unicodeslot=0xA720,
 },
 [0xA721]={
  category="sk",
  description="MODIFIER LETTER STRESS AND LOW TONE",
  direction="on",
  linebreak="al",
  unicodeslot=0xA721,
 },
 [0xA722]={
  category="lu",
  description="LATIN CAPITAL LETTER EGYPTOLOGICAL ALEF",
  direction="l",
  linebreak="al",
  unicodeslot=0xA722,
 },
 [0xA723]={
  category="ll",
  description="LATIN SMALL LETTER EGYPTOLOGICAL ALEF",
  direction="l",
  linebreak="al",
  unicodeslot=0xA723,
 },
 [0xA724]={
  category="lu",
  description="LATIN CAPITAL LETTER EGYPTOLOGICAL AIN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA724,
 },
 [0xA725]={
  category="ll",
  description="LATIN SMALL LETTER EGYPTOLOGICAL AIN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA725,
 },
 [0xA726]={
  category="lu",
  description="LATIN CAPITAL LETTER HENG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA726,
 },
 [0xA727]={
  category="ll",
  description="LATIN SMALL LETTER HENG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA727,
 },
 [0xA728]={
  category="lu",
  description="LATIN CAPITAL LETTER TZ",
  direction="l",
  linebreak="al",
  unicodeslot=0xA728,
 },
 [0xA729]={
  category="ll",
  description="LATIN SMALL LETTER TZ",
  direction="l",
  linebreak="al",
  unicodeslot=0xA729,
 },
 [0xA72A]={
  category="lu",
  description="LATIN CAPITAL LETTER TRESILLO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA72A,
 },
 [0xA72B]={
  category="ll",
  description="LATIN SMALL LETTER TRESILLO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA72B,
 },
 [0xA72C]={
  category="lu",
  description="LATIN CAPITAL LETTER CUATRILLO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA72C,
 },
 [0xA72D]={
  category="ll",
  description="LATIN SMALL LETTER CUATRILLO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA72D,
 },
 [0xA72E]={
  category="lu",
  description="LATIN CAPITAL LETTER CUATRILLO WITH COMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA72E,
 },
 [0xA72F]={
  category="ll",
  description="LATIN SMALL LETTER CUATRILLO WITH COMMA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA72F,
 },
 [0xA730]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL F",
  direction="l",
  linebreak="al",
  unicodeslot=0xA730,
 },
 [0xA731]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL S",
  direction="l",
  linebreak="al",
  unicodeslot=0xA731,
 },
 [0xA732]={
  category="lu",
  description="LATIN CAPITAL LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA732,
 },
 [0xA733]={
  category="ll",
  description="LATIN SMALL LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA733,
 },
 [0xA734]={
  category="lu",
  description="LATIN CAPITAL LETTER AO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA734,
 },
 [0xA735]={
  category="ll",
  description="LATIN SMALL LETTER AO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA735,
 },
 [0xA736]={
  category="lu",
  description="LATIN CAPITAL LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA736,
 },
 [0xA737]={
  category="ll",
  description="LATIN SMALL LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA737,
 },
 [0xA738]={
  category="lu",
  description="LATIN CAPITAL LETTER AV",
  direction="l",
  linebreak="al",
  unicodeslot=0xA738,
 },
 [0xA739]={
  category="ll",
  description="LATIN SMALL LETTER AV",
  direction="l",
  linebreak="al",
  unicodeslot=0xA739,
 },
 [0xA73A]={
  category="lu",
  description="LATIN CAPITAL LETTER AV WITH HORIZONTAL BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0xA73A,
 },
 [0xA73B]={
  category="ll",
  description="LATIN SMALL LETTER AV WITH HORIZONTAL BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0xA73B,
 },
 [0xA73C]={
  category="lu",
  description="LATIN CAPITAL LETTER AY",
  direction="l",
  linebreak="al",
  unicodeslot=0xA73C,
 },
 [0xA73D]={
  category="ll",
  description="LATIN SMALL LETTER AY",
  direction="l",
  linebreak="al",
  unicodeslot=0xA73D,
 },
 [0xA73E]={
  category="lu",
  description="LATIN CAPITAL LETTER REVERSED C WITH DOT",
  direction="l",
  linebreak="al",
  unicodeslot=0xA73E,
 },
 [0xA73F]={
  category="ll",
  description="LATIN SMALL LETTER REVERSED C WITH DOT",
  direction="l",
  linebreak="al",
  unicodeslot=0xA73F,
 },
 [0xA740]={
  category="lu",
  description="LATIN CAPITAL LETTER K WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA740,
 },
 [0xA741]={
  category="ll",
  description="LATIN SMALL LETTER K WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA741,
 },
 [0xA742]={
  category="lu",
  description="LATIN CAPITAL LETTER K WITH DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA742,
 },
 [0xA743]={
  category="ll",
  description="LATIN SMALL LETTER K WITH DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA743,
 },
 [0xA744]={
  category="lu",
  description="LATIN CAPITAL LETTER K WITH STROKE AND DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA744,
 },
 [0xA745]={
  category="ll",
  description="LATIN SMALL LETTER K WITH STROKE AND DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA745,
 },
 [0xA746]={
  category="lu",
  description="LATIN CAPITAL LETTER BROKEN L",
  direction="l",
  linebreak="al",
  unicodeslot=0xA746,
 },
 [0xA747]={
  category="ll",
  description="LATIN SMALL LETTER BROKEN L",
  direction="l",
  linebreak="al",
  unicodeslot=0xA747,
 },
 [0xA748]={
  category="lu",
  description="LATIN CAPITAL LETTER L WITH HIGH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA748,
 },
 [0xA749]={
  category="ll",
  description="LATIN SMALL LETTER L WITH HIGH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA749,
 },
 [0xA74A]={
  category="lu",
  description="LATIN CAPITAL LETTER O WITH LONG STROKE OVERLAY",
  direction="l",
  linebreak="al",
  unicodeslot=0xA74A,
 },
 [0xA74B]={
  category="ll",
  description="LATIN SMALL LETTER O WITH LONG STROKE OVERLAY",
  direction="l",
  linebreak="al",
  unicodeslot=0xA74B,
 },
 [0xA74C]={
  category="lu",
  description="LATIN CAPITAL LETTER O WITH LOOP",
  direction="l",
  linebreak="al",
  unicodeslot=0xA74C,
 },
 [0xA74D]={
  category="ll",
  description="LATIN SMALL LETTER O WITH LOOP",
  direction="l",
  linebreak="al",
  unicodeslot=0xA74D,
 },
 [0xA74E]={
  category="lu",
  description="LATIN CAPITAL LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA74E,
 },
 [0xA74F]={
  category="ll",
  description="LATIN SMALL LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA74F,
 },
 [0xA750]={
  category="lu",
  description="LATIN CAPITAL LETTER P WITH STROKE THROUGH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA750,
 },
 [0xA751]={
  category="ll",
  description="LATIN SMALL LETTER P WITH STROKE THROUGH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA751,
 },
 [0xA752]={
  category="lu",
  description="LATIN CAPITAL LETTER P WITH FLOURISH",
  direction="l",
  linebreak="al",
  unicodeslot=0xA752,
 },
 [0xA753]={
  category="ll",
  description="LATIN SMALL LETTER P WITH FLOURISH",
  direction="l",
  linebreak="al",
  unicodeslot=0xA753,
 },
 [0xA754]={
  category="lu",
  description="LATIN CAPITAL LETTER P WITH SQUIRREL TAIL",
  direction="l",
  linebreak="al",
  unicodeslot=0xA754,
 },
 [0xA755]={
  category="ll",
  description="LATIN SMALL LETTER P WITH SQUIRREL TAIL",
  direction="l",
  linebreak="al",
  unicodeslot=0xA755,
 },
 [0xA756]={
  category="lu",
  description="LATIN CAPITAL LETTER Q WITH STROKE THROUGH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA756,
 },
 [0xA757]={
  category="ll",
  description="LATIN SMALL LETTER Q WITH STROKE THROUGH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA757,
 },
 [0xA758]={
  category="lu",
  description="LATIN CAPITAL LETTER Q WITH DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA758,
 },
 [0xA759]={
  category="ll",
  description="LATIN SMALL LETTER Q WITH DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA759,
 },
 [0xA75A]={
  category="lu",
  description="LATIN CAPITAL LETTER R ROTUNDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA75A,
 },
 [0xA75B]={
  category="ll",
  description="LATIN SMALL LETTER R ROTUNDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA75B,
 },
 [0xA75C]={
  category="lu",
  description="LATIN CAPITAL LETTER RUM ROTUNDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA75C,
 },
 [0xA75D]={
  category="ll",
  description="LATIN SMALL LETTER RUM ROTUNDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA75D,
 },
 [0xA75E]={
  category="lu",
  description="LATIN CAPITAL LETTER V WITH DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA75E,
 },
 [0xA75F]={
  category="ll",
  description="LATIN SMALL LETTER V WITH DIAGONAL STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA75F,
 },
 [0xA760]={
  category="lu",
  description="LATIN CAPITAL LETTER VY",
  direction="l",
  linebreak="al",
  unicodeslot=0xA760,
 },
 [0xA761]={
  category="ll",
  description="LATIN SMALL LETTER VY",
  direction="l",
  linebreak="al",
  unicodeslot=0xA761,
 },
 [0xA762]={
  category="lu",
  description="LATIN CAPITAL LETTER VISIGOTHIC Z",
  direction="l",
  linebreak="al",
  unicodeslot=0xA762,
 },
 [0xA763]={
  category="ll",
  description="LATIN SMALL LETTER VISIGOTHIC Z",
  direction="l",
  linebreak="al",
  unicodeslot=0xA763,
 },
 [0xA764]={
  category="lu",
  description="LATIN CAPITAL LETTER THORN WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA764,
 },
 [0xA765]={
  category="ll",
  description="LATIN SMALL LETTER THORN WITH STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA765,
 },
 [0xA766]={
  category="lu",
  description="LATIN CAPITAL LETTER THORN WITH STROKE THROUGH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA766,
 },
 [0xA767]={
  category="ll",
  description="LATIN SMALL LETTER THORN WITH STROKE THROUGH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA767,
 },
 [0xA768]={
  category="lu",
  description="LATIN CAPITAL LETTER VEND",
  direction="l",
  linebreak="al",
  unicodeslot=0xA768,
 },
 [0xA769]={
  category="ll",
  description="LATIN SMALL LETTER VEND",
  direction="l",
  linebreak="al",
  unicodeslot=0xA769,
 },
 [0xA76A]={
  category="lu",
  description="LATIN CAPITAL LETTER ET",
  direction="l",
  linebreak="al",
  unicodeslot=0xA76A,
 },
 [0xA76B]={
  category="ll",
  description="LATIN SMALL LETTER ET",
  direction="l",
  linebreak="al",
  unicodeslot=0xA76B,
 },
 [0xA76C]={
  category="lu",
  description="LATIN CAPITAL LETTER IS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA76C,
 },
 [0xA76D]={
  category="ll",
  description="LATIN SMALL LETTER IS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA76D,
 },
 [0xA76E]={
  category="lu",
  description="LATIN CAPITAL LETTER CON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA76E,
 },
 [0xA76F]={
  category="ll",
  description="LATIN SMALL LETTER CON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA76F,
 },
 [0xA770]={
  category="lm",
  description="MODIFIER LETTER US",
  direction="l",
  linebreak="al",
  specials={ "super", 0xA76F },
  unicodeslot=0xA770,
 },
 [0xA771]={
  category="ll",
  description="LATIN SMALL LETTER DUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA771,
 },
 [0xA772]={
  category="ll",
  description="LATIN SMALL LETTER LUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA772,
 },
 [0xA773]={
  category="ll",
  description="LATIN SMALL LETTER MUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA773,
 },
 [0xA774]={
  category="ll",
  description="LATIN SMALL LETTER NUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA774,
 },
 [0xA775]={
  category="ll",
  description="LATIN SMALL LETTER RUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA775,
 },
 [0xA776]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL RUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA776,
 },
 [0xA777]={
  category="ll",
  description="LATIN SMALL LETTER TUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA777,
 },
 [0xA778]={
  category="ll",
  description="LATIN SMALL LETTER UM",
  direction="l",
  linebreak="al",
  unicodeslot=0xA778,
 },
 [0xA779]={
  category="lu",
  description="LATIN CAPITAL LETTER INSULAR D",
  direction="l",
  linebreak="al",
  unicodeslot=0xA779,
 },
 [0xA77A]={
  category="ll",
  description="LATIN SMALL LETTER INSULAR D",
  direction="l",
  linebreak="al",
  unicodeslot=0xA77A,
 },
 [0xA77B]={
  category="lu",
  description="LATIN CAPITAL LETTER INSULAR F",
  direction="l",
  linebreak="al",
  unicodeslot=0xA77B,
 },
 [0xA77C]={
  category="ll",
  description="LATIN SMALL LETTER INSULAR F",
  direction="l",
  linebreak="al",
  unicodeslot=0xA77C,
 },
 [0xA77D]={
  category="lu",
  description="LATIN CAPITAL LETTER INSULAR G",
  direction="l",
  linebreak="al",
  unicodeslot=0xA77D,
 },
 [0xA77E]={
  category="lu",
  description="LATIN CAPITAL LETTER TURNED INSULAR G",
  direction="l",
  linebreak="al",
  unicodeslot=0xA77E,
 },
 [0xA77F]={
  category="ll",
  description="LATIN SMALL LETTER TURNED INSULAR G",
  direction="l",
  linebreak="al",
  unicodeslot=0xA77F,
 },
 [0xA780]={
  category="lu",
  description="LATIN CAPITAL LETTER TURNED L",
  direction="l",
  linebreak="al",
  unicodeslot=0xA780,
 },
 [0xA781]={
  category="ll",
  description="LATIN SMALL LETTER TURNED L",
  direction="l",
  linebreak="al",
  unicodeslot=0xA781,
 },
 [0xA782]={
  category="lu",
  description="LATIN CAPITAL LETTER INSULAR R",
  direction="l",
  linebreak="al",
  unicodeslot=0xA782,
 },
 [0xA783]={
  category="ll",
  description="LATIN SMALL LETTER INSULAR R",
  direction="l",
  linebreak="al",
  unicodeslot=0xA783,
 },
 [0xA784]={
  category="lu",
  description="LATIN CAPITAL LETTER INSULAR S",
  direction="l",
  linebreak="al",
  unicodeslot=0xA784,
 },
 [0xA785]={
  category="ll",
  description="LATIN SMALL LETTER INSULAR S",
  direction="l",
  linebreak="al",
  unicodeslot=0xA785,
 },
 [0xA786]={
  category="lu",
  description="LATIN CAPITAL LETTER INSULAR T",
  direction="l",
  linebreak="al",
  unicodeslot=0xA786,
 },
 [0xA787]={
  category="ll",
  description="LATIN SMALL LETTER INSULAR T",
  direction="l",
  linebreak="al",
  unicodeslot=0xA787,
 },
 [0xA788]={
  category="lm",
  description="MODIFIER LETTER LOW CIRCUMFLEX ACCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0xA788,
 },
 [0xA789]={
  category="sk",
  description="MODIFIER LETTER COLON",
  direction="l",
  linebreak="al",
  unicodeslot=0xA789,
 },
 [0xA78A]={
  category="sk",
  description="MODIFIER LETTER SHORT EQUALS SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA78A,
 },
 [0xA78B]={
  category="lu",
  description="LATIN CAPITAL LETTER SALTILLO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA78B,
 },
 [0xA78C]={
  category="ll",
  description="LATIN SMALL LETTER SALTILLO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA78C,
 },
 [0xA78D]={
  category="lu",
  description="LATIN CAPITAL LETTER TURNED H",
  direction="l",
  linebreak="al",
  unicodeslot=0xA78D,
 },
 [0xA78E]={
  category="ll",
  description="LATIN SMALL LETTER L WITH RETROFLEX HOOK AND BELT",
  direction="l",
  linebreak="al",
  unicodeslot=0xA78E,
 },
 [0xA790]={
  category="lu",
  description="LATIN CAPITAL LETTER N WITH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA790,
 },
 [0xA791]={
  category="ll",
  description="LATIN SMALL LETTER N WITH DESCENDER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA791,
 },
 [0xA792]={
  category="lu",
  description="LATIN CAPITAL LETTER C WITH BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0xA792,
 },
 [0xA793]={
  category="ll",
  description="LATIN SMALL LETTER C WITH BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0xA793,
 },
 [0xA7A0]={
  category="lu",
  description="LATIN CAPITAL LETTER G WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A0,
 },
 [0xA7A1]={
  category="ll",
  description="LATIN SMALL LETTER G WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A1,
 },
 [0xA7A2]={
  category="lu",
  description="LATIN CAPITAL LETTER K WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A2,
 },
 [0xA7A3]={
  category="ll",
  description="LATIN SMALL LETTER K WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A3,
 },
 [0xA7A4]={
  category="lu",
  description="LATIN CAPITAL LETTER N WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A4,
 },
 [0xA7A5]={
  category="ll",
  description="LATIN SMALL LETTER N WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A5,
 },
 [0xA7A6]={
  category="lu",
  description="LATIN CAPITAL LETTER R WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A6,
 },
 [0xA7A7]={
  category="ll",
  description="LATIN SMALL LETTER R WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A7,
 },
 [0xA7A8]={
  category="lu",
  description="LATIN CAPITAL LETTER S WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A8,
 },
 [0xA7A9]={
  category="ll",
  description="LATIN SMALL LETTER S WITH OBLIQUE STROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7A9,
 },
 [0xA7AA]={
  category="lu",
  description="LATIN CAPITAL LETTER H WITH HOOK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7AA,
 },
 [0xA7F8]={
  category="lm",
  description="MODIFIER LETTER CAPITAL H WITH STROKE",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0126 },
  unicodeslot=0xA7F8,
 },
 [0xA7F9]={
  category="lm",
  description="MODIFIER LETTER SMALL LIGATURE OE",
  direction="l",
  linebreak="al",
  specials={ "super", 0x0153 },
  unicodeslot=0xA7F9,
 },
 [0xA7FA]={
  category="ll",
  description="LATIN LETTER SMALL CAPITAL TURNED M",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7FA,
 },
 [0xA7FB]={
  category="lo",
  description="LATIN EPIGRAPHIC LETTER REVERSED F",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7FB,
 },
 [0xA7FC]={
  category="lo",
  description="LATIN EPIGRAPHIC LETTER REVERSED P",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7FC,
 },
 [0xA7FD]={
  category="lo",
  description="LATIN EPIGRAPHIC LETTER INVERTED M",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7FD,
 },
 [0xA7FE]={
  category="lo",
  description="LATIN EPIGRAPHIC LETTER I LONGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7FE,
 },
 [0xA7FF]={
  category="lo",
  description="LATIN EPIGRAPHIC LETTER ARCHAIC M",
  direction="l",
  linebreak="al",
  unicodeslot=0xA7FF,
 },
 [0xA800]={
  category="lo",
  description="SYLOTI NAGRI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA800,
 },
 [0xA801]={
  category="lo",
  description="SYLOTI NAGRI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xA801,
 },
 [0xA802]={
  category="mc",
  description="SYLOTI NAGRI SIGN DVISVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA802,
 },
 [0xA803]={
  category="lo",
  description="SYLOTI NAGRI LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0xA803,
 },
 [0xA804]={
  category="lo",
  description="SYLOTI NAGRI LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0xA804,
 },
 [0xA805]={
  category="lo",
  description="SYLOTI NAGRI LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA805,
 },
 [0xA806]={
  category="mn",
  description="SYLOTI NAGRI SIGN HASANTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA806,
 },
 [0xA807]={
  category="lo",
  description="SYLOTI NAGRI LETTER KO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA807,
 },
 [0xA808]={
  category="lo",
  description="SYLOTI NAGRI LETTER KHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA808,
 },
 [0xA809]={
  category="lo",
  description="SYLOTI NAGRI LETTER GO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA809,
 },
 [0xA80A]={
  category="lo",
  description="SYLOTI NAGRI LETTER GHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA80A,
 },
 [0xA80B]={
  category="mn",
  description="SYLOTI NAGRI SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA80B,
 },
 [0xA80C]={
  category="lo",
  description="SYLOTI NAGRI LETTER CO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA80C,
 },
 [0xA80D]={
  category="lo",
  description="SYLOTI NAGRI LETTER CHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA80D,
 },
 [0xA80E]={
  category="lo",
  description="SYLOTI NAGRI LETTER JO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA80E,
 },
 [0xA80F]={
  category="lo",
  description="SYLOTI NAGRI LETTER JHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA80F,
 },
 [0xA810]={
  category="lo",
  description="SYLOTI NAGRI LETTER TTO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA810,
 },
 [0xA811]={
  category="lo",
  description="SYLOTI NAGRI LETTER TTHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA811,
 },
 [0xA812]={
  category="lo",
  description="SYLOTI NAGRI LETTER DDO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA812,
 },
 [0xA813]={
  category="lo",
  description="SYLOTI NAGRI LETTER DDHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA813,
 },
 [0xA814]={
  category="lo",
  description="SYLOTI NAGRI LETTER TO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA814,
 },
 [0xA815]={
  category="lo",
  description="SYLOTI NAGRI LETTER THO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA815,
 },
 [0xA816]={
  category="lo",
  description="SYLOTI NAGRI LETTER DO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA816,
 },
 [0xA817]={
  category="lo",
  description="SYLOTI NAGRI LETTER DHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA817,
 },
 [0xA818]={
  category="lo",
  description="SYLOTI NAGRI LETTER NO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA818,
 },
 [0xA819]={
  category="lo",
  description="SYLOTI NAGRI LETTER PO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA819,
 },
 [0xA81A]={
  category="lo",
  description="SYLOTI NAGRI LETTER PHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA81A,
 },
 [0xA81B]={
  category="lo",
  description="SYLOTI NAGRI LETTER BO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA81B,
 },
 [0xA81C]={
  category="lo",
  description="SYLOTI NAGRI LETTER BHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA81C,
 },
 [0xA81D]={
  category="lo",
  description="SYLOTI NAGRI LETTER MO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA81D,
 },
 [0xA81E]={
  category="lo",
  description="SYLOTI NAGRI LETTER RO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA81E,
 },
 [0xA81F]={
  category="lo",
  description="SYLOTI NAGRI LETTER LO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA81F,
 },
 [0xA820]={
  category="lo",
  description="SYLOTI NAGRI LETTER RRO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA820,
 },
 [0xA821]={
  category="lo",
  description="SYLOTI NAGRI LETTER SO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA821,
 },
 [0xA822]={
  category="lo",
  description="SYLOTI NAGRI LETTER HO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA822,
 },
 [0xA823]={
  category="mc",
  description="SYLOTI NAGRI VOWEL SIGN A",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA823,
 },
 [0xA824]={
  category="mc",
  description="SYLOTI NAGRI VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA824,
 },
 [0xA825]={
  category="mn",
  description="SYLOTI NAGRI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA825,
 },
 [0xA826]={
  category="mn",
  description="SYLOTI NAGRI VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA826,
 },
 [0xA827]={
  category="mc",
  description="SYLOTI NAGRI VOWEL SIGN OO",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA827,
 },
 [0xA828]={
  category="so",
  description="SYLOTI NAGRI POETRY MARK-0x0001",
  direction="on",
  linebreak="al",
  unicodeslot=0xA828,
 },
 [0xA829]={
  category="so",
  description="SYLOTI NAGRI POETRY MARK-0x0002",
  direction="on",
  linebreak="al",
  unicodeslot=0xA829,
 },
 [0xA82A]={
  category="so",
  description="SYLOTI NAGRI POETRY MARK-0x0003",
  direction="on",
  linebreak="al",
  unicodeslot=0xA82A,
 },
 [0xA82B]={
  category="so",
  description="SYLOTI NAGRI POETRY MARK-0x0004",
  direction="on",
  linebreak="al",
  unicodeslot=0xA82B,
 },
 [0xA830]={
  category="no",
  description="NORTH INDIC FRACTION ONE QUARTER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA830,
 },
 [0xA831]={
  category="no",
  description="NORTH INDIC FRACTION ONE HALF",
  direction="l",
  linebreak="al",
  unicodeslot=0xA831,
 },
 [0xA832]={
  category="no",
  description="NORTH INDIC FRACTION THREE QUARTERS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA832,
 },
 [0xA833]={
  category="no",
  description="NORTH INDIC FRACTION ONE SIXTEENTH",
  direction="l",
  linebreak="al",
  unicodeslot=0xA833,
 },
 [0xA834]={
  category="no",
  description="NORTH INDIC FRACTION ONE EIGHTH",
  direction="l",
  linebreak="al",
  unicodeslot=0xA834,
 },
 [0xA835]={
  category="no",
  description="NORTH INDIC FRACTION THREE SIXTEENTHS",
  direction="l",
  linebreak="al",
  unicodeslot=0xA835,
 },
 [0xA836]={
  category="so",
  description="NORTH INDIC QUARTER MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA836,
 },
 [0xA837]={
  category="so",
  description="NORTH INDIC PLACEHOLDER MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA837,
 },
 [0xA838]={
  category="sc",
  description="NORTH INDIC RUPEE MARK",
  direction="et",
  linebreak="po",
  unicodeslot=0xA838,
 },
 [0xA839]={
  category="so",
  description="NORTH INDIC QUANTITY MARK",
  direction="et",
  linebreak="al",
  unicodeslot=0xA839,
 },
 [0xA840]={
  category="lo",
  description="PHAGS-PA LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA840,
 },
 [0xA841]={
  category="lo",
  description="PHAGS-PA LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA841,
 },
 [0xA842]={
  category="lo",
  description="PHAGS-PA LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA842,
 },
 [0xA843]={
  category="lo",
  description="PHAGS-PA LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA843,
 },
 [0xA844]={
  category="lo",
  description="PHAGS-PA LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA844,
 },
 [0xA845]={
  category="lo",
  description="PHAGS-PA LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA845,
 },
 [0xA846]={
  category="lo",
  description="PHAGS-PA LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA846,
 },
 [0xA847]={
  category="lo",
  description="PHAGS-PA LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA847,
 },
 [0xA848]={
  category="lo",
  description="PHAGS-PA LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA848,
 },
 [0xA849]={
  category="lo",
  description="PHAGS-PA LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA849,
 },
 [0xA84A]={
  category="lo",
  description="PHAGS-PA LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA84A,
 },
 [0xA84B]={
  category="lo",
  description="PHAGS-PA LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA84B,
 },
 [0xA84C]={
  category="lo",
  description="PHAGS-PA LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA84C,
 },
 [0xA84D]={
  category="lo",
  description="PHAGS-PA LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA84D,
 },
 [0xA84E]={
  category="lo",
  description="PHAGS-PA LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA84E,
 },
 [0xA84F]={
  category="lo",
  description="PHAGS-PA LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA84F,
 },
 [0xA850]={
  category="lo",
  description="PHAGS-PA LETTER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA850,
 },
 [0xA851]={
  category="lo",
  description="PHAGS-PA LETTER TSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA851,
 },
 [0xA852]={
  category="lo",
  description="PHAGS-PA LETTER DZA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA852,
 },
 [0xA853]={
  category="lo",
  description="PHAGS-PA LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA853,
 },
 [0xA854]={
  category="lo",
  description="PHAGS-PA LETTER ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA854,
 },
 [0xA855]={
  category="lo",
  description="PHAGS-PA LETTER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA855,
 },
 [0xA856]={
  category="lo",
  description="PHAGS-PA LETTER SMALL A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA856,
  variants={
   [0xFE00]="phags-pa letter reversed shaping small a",
  },
 },
 [0xA857]={
  category="lo",
  description="PHAGS-PA LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA857,
 },
 [0xA858]={
  category="lo",
  description="PHAGS-PA LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA858,
 },
 [0xA859]={
  category="lo",
  description="PHAGS-PA LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA859,
 },
 [0xA85A]={
  category="lo",
  description="PHAGS-PA LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA85A,
 },
 [0xA85B]={
  category="lo",
  description="PHAGS-PA LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA85B,
 },
 [0xA85C]={
  category="lo",
  description="PHAGS-PA LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA85C,
  variants={
   [0xFE00]="phags-pa letter reversed shaping ha",
  },
 },
 [0xA85D]={
  category="lo",
  description="PHAGS-PA LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA85D,
 },
 [0xA85E]={
  category="lo",
  description="PHAGS-PA LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xA85E,
  variants={
   [0xFE00]="phags-pa letter reversed shaping i",
  },
 },
 [0xA85F]={
  category="lo",
  description="PHAGS-PA LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0xA85F,
  variants={
   [0xFE00]="phags-pa letter reversed shaping u",
  },
 },
 [0xA860]={
  category="lo",
  description="PHAGS-PA LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0xA860,
  variants={
   [0xFE00]="phags-pa letter reversed shaping e",
  },
 },
 [0xA861]={
  category="lo",
  description="PHAGS-PA LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA861,
 },
 [0xA862]={
  category="lo",
  description="PHAGS-PA LETTER QA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA862,
 },
 [0xA863]={
  category="lo",
  description="PHAGS-PA LETTER XA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA863,
 },
 [0xA864]={
  category="lo",
  description="PHAGS-PA LETTER FA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA864,
 },
 [0xA865]={
  category="lo",
  description="PHAGS-PA LETTER GGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA865,
 },
 [0xA866]={
  category="lo",
  description="PHAGS-PA LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA866,
 },
 [0xA867]={
  category="lo",
  description="PHAGS-PA SUBJOINED LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA867,
 },
 [0xA868]={
  category="lo",
  description="PHAGS-PA SUBJOINED LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA868,
  variants={
   [0xFE00]="phags-pa letter reversed shaping subjoined ya",
  },
 },
 [0xA869]={
  category="lo",
  description="PHAGS-PA LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA869,
 },
 [0xA86A]={
  category="lo",
  description="PHAGS-PA LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA86A,
 },
 [0xA86B]={
  category="lo",
  description="PHAGS-PA LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA86B,
 },
 [0xA86C]={
  category="lo",
  description="PHAGS-PA LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA86C,
 },
 [0xA86D]={
  category="lo",
  description="PHAGS-PA LETTER ALTERNATE YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA86D,
 },
 [0xA86E]={
  category="lo",
  description="PHAGS-PA LETTER VOICELESS SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA86E,
 },
 [0xA86F]={
  category="lo",
  description="PHAGS-PA LETTER VOICED HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA86F,
 },
 [0xA870]={
  category="lo",
  description="PHAGS-PA LETTER ASPIRATED FA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA870,
 },
 [0xA871]={
  category="lo",
  description="PHAGS-PA SUBJOINED LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA871,
 },
 [0xA872]={
  category="lo",
  description="PHAGS-PA SUPERFIXED LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA872,
 },
 [0xA873]={
  category="lo",
  description="PHAGS-PA LETTER CANDRABINDU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA873,
 },
 [0xA874]={
  category="po",
  description="PHAGS-PA SINGLE HEAD MARK",
  direction="on",
  linebreak="bb",
  unicodeslot=0xA874,
 },
 [0xA875]={
  category="po",
  description="PHAGS-PA DOUBLE HEAD MARK",
  direction="on",
  linebreak="bb",
  unicodeslot=0xA875,
 },
 [0xA876]={
  category="po",
  description="PHAGS-PA MARK SHAD",
  direction="on",
  linebreak="ex",
  unicodeslot=0xA876,
 },
 [0xA877]={
  category="po",
  description="PHAGS-PA MARK DOUBLE SHAD",
  direction="on",
  linebreak="ex",
  unicodeslot=0xA877,
 },
 [0xA880]={
  category="mc",
  description="SAURASHTRA SIGN ANUSVARA",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA880,
 },
 [0xA881]={
  category="mc",
  description="SAURASHTRA SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA881,
 },
 [0xA882]={
  category="lo",
  description="SAURASHTRA LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA882,
 },
 [0xA883]={
  category="lo",
  description="SAURASHTRA LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA883,
 },
 [0xA884]={
  category="lo",
  description="SAURASHTRA LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xA884,
 },
 [0xA885]={
  category="lo",
  description="SAURASHTRA LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0xA885,
 },
 [0xA886]={
  category="lo",
  description="SAURASHTRA LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0xA886,
 },
 [0xA887]={
  category="lo",
  description="SAURASHTRA LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA887,
 },
 [0xA888]={
  category="lo",
  description="SAURASHTRA LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0xA888,
 },
 [0xA889]={
  category="lo",
  description="SAURASHTRA LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0xA889,
 },
 [0xA88A]={
  category="lo",
  description="SAURASHTRA LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0xA88A,
 },
 [0xA88B]={
  category="lo",
  description="SAURASHTRA LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0xA88B,
 },
 [0xA88C]={
  category="lo",
  description="SAURASHTRA LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0xA88C,
 },
 [0xA88D]={
  category="lo",
  description="SAURASHTRA LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA88D,
 },
 [0xA88E]={
  category="lo",
  description="SAURASHTRA LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA88E,
 },
 [0xA88F]={
  category="lo",
  description="SAURASHTRA LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA88F,
 },
 [0xA890]={
  category="lo",
  description="SAURASHTRA LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA890,
 },
 [0xA891]={
  category="lo",
  description="SAURASHTRA LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA891,
 },
 [0xA892]={
  category="lo",
  description="SAURASHTRA LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA892,
 },
 [0xA893]={
  category="lo",
  description="SAURASHTRA LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA893,
 },
 [0xA894]={
  category="lo",
  description="SAURASHTRA LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA894,
 },
 [0xA895]={
  category="lo",
  description="SAURASHTRA LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA895,
 },
 [0xA896]={
  category="lo",
  description="SAURASHTRA LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA896,
 },
 [0xA897]={
  category="lo",
  description="SAURASHTRA LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA897,
 },
 [0xA898]={
  category="lo",
  description="SAURASHTRA LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA898,
 },
 [0xA899]={
  category="lo",
  description="SAURASHTRA LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA899,
 },
 [0xA89A]={
  category="lo",
  description="SAURASHTRA LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA89A,
 },
 [0xA89B]={
  category="lo",
  description="SAURASHTRA LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA89B,
 },
 [0xA89C]={
  category="lo",
  description="SAURASHTRA LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA89C,
 },
 [0xA89D]={
  category="lo",
  description="SAURASHTRA LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA89D,
 },
 [0xA89E]={
  category="lo",
  description="SAURASHTRA LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA89E,
 },
 [0xA89F]={
  category="lo",
  description="SAURASHTRA LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA89F,
 },
 [0xA8A0]={
  category="lo",
  description="SAURASHTRA LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A0,
 },
 [0xA8A1]={
  category="lo",
  description="SAURASHTRA LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A1,
 },
 [0xA8A2]={
  category="lo",
  description="SAURASHTRA LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A2,
 },
 [0xA8A3]={
  category="lo",
  description="SAURASHTRA LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A3,
 },
 [0xA8A4]={
  category="lo",
  description="SAURASHTRA LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A4,
 },
 [0xA8A5]={
  category="lo",
  description="SAURASHTRA LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A5,
 },
 [0xA8A6]={
  category="lo",
  description="SAURASHTRA LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A6,
 },
 [0xA8A7]={
  category="lo",
  description="SAURASHTRA LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A7,
 },
 [0xA8A8]={
  category="lo",
  description="SAURASHTRA LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A8,
 },
 [0xA8A9]={
  category="lo",
  description="SAURASHTRA LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8A9,
 },
 [0xA8AA]={
  category="lo",
  description="SAURASHTRA LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8AA,
 },
 [0xA8AB]={
  category="lo",
  description="SAURASHTRA LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8AB,
 },
 [0xA8AC]={
  category="lo",
  description="SAURASHTRA LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8AC,
 },
 [0xA8AD]={
  category="lo",
  description="SAURASHTRA LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8AD,
 },
 [0xA8AE]={
  category="lo",
  description="SAURASHTRA LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8AE,
 },
 [0xA8AF]={
  category="lo",
  description="SAURASHTRA LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8AF,
 },
 [0xA8B0]={
  category="lo",
  description="SAURASHTRA LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8B0,
 },
 [0xA8B1]={
  category="lo",
  description="SAURASHTRA LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8B1,
 },
 [0xA8B2]={
  category="lo",
  description="SAURASHTRA LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8B2,
 },
 [0xA8B3]={
  category="lo",
  description="SAURASHTRA LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8B3,
 },
 [0xA8B4]={
  category="mc",
  description="SAURASHTRA CONSONANT SIGN HAARU",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8B4,
 },
 [0xA8B5]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8B5,
 },
 [0xA8B6]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8B6,
 },
 [0xA8B7]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8B7,
 },
 [0xA8B8]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN U",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8B8,
 },
 [0xA8B9]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN UU",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8B9,
 },
 [0xA8BA]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN VOCALIC R",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8BA,
 },
 [0xA8BB]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN VOCALIC RR",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8BB,
 },
 [0xA8BC]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN VOCALIC L",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8BC,
 },
 [0xA8BD]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN VOCALIC LL",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8BD,
 },
 [0xA8BE]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8BE,
 },
 [0xA8BF]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN EE",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8BF,
 },
 [0xA8C0]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8C0,
 },
 [0xA8C1]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8C1,
 },
 [0xA8C2]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN OO",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8C2,
 },
 [0xA8C3]={
  category="mc",
  description="SAURASHTRA VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA8C3,
 },
 [0xA8C4]={
  category="mn",
  description="SAURASHTRA SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8C4,
 },
 [0xA8CE]={
  category="po",
  description="SAURASHTRA DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA8CE,
 },
 [0xA8CF]={
  category="po",
  description="SAURASHTRA DOUBLE DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA8CF,
 },
 [0xA8D0]={
  category="nd",
  description="SAURASHTRA DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D0,
 },
 [0xA8D1]={
  category="nd",
  description="SAURASHTRA DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D1,
 },
 [0xA8D2]={
  category="nd",
  description="SAURASHTRA DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D2,
 },
 [0xA8D3]={
  category="nd",
  description="SAURASHTRA DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D3,
 },
 [0xA8D4]={
  category="nd",
  description="SAURASHTRA DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D4,
 },
 [0xA8D5]={
  category="nd",
  description="SAURASHTRA DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D5,
 },
 [0xA8D6]={
  category="nd",
  description="SAURASHTRA DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D6,
 },
 [0xA8D7]={
  category="nd",
  description="SAURASHTRA DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D7,
 },
 [0xA8D8]={
  category="nd",
  description="SAURASHTRA DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D8,
 },
 [0xA8D9]={
  category="nd",
  description="SAURASHTRA DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA8D9,
 },
 [0xA8E0]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT ZERO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E0,
 },
 [0xA8E1]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT ONE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E1,
 },
 [0xA8E2]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT TWO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E2,
 },
 [0xA8E3]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT THREE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E3,
 },
 [0xA8E4]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT FOUR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E4,
 },
 [0xA8E5]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT FIVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E5,
 },
 [0xA8E6]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT SIX",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E6,
 },
 [0xA8E7]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT SEVEN",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E7,
 },
 [0xA8E8]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT EIGHT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E8,
 },
 [0xA8E9]={
  category="mn",
  description="COMBINING DEVANAGARI DIGIT NINE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8E9,
 },
 [0xA8EA]={
  category="mn",
  description="COMBINING DEVANAGARI LETTER A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8EA,
 },
 [0xA8EB]={
  category="mn",
  description="COMBINING DEVANAGARI LETTER U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8EB,
 },
 [0xA8EC]={
  category="mn",
  description="COMBINING DEVANAGARI LETTER KA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8EC,
 },
 [0xA8ED]={
  category="mn",
  description="COMBINING DEVANAGARI LETTER NA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8ED,
 },
 [0xA8EE]={
  category="mn",
  description="COMBINING DEVANAGARI LETTER PA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8EE,
 },
 [0xA8EF]={
  category="mn",
  description="COMBINING DEVANAGARI LETTER RA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8EF,
 },
 [0xA8F0]={
  category="mn",
  description="COMBINING DEVANAGARI LETTER VI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8F0,
 },
 [0xA8F1]={
  category="mn",
  description="COMBINING DEVANAGARI SIGN AVAGRAHA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA8F1,
 },
 [0xA8F2]={
  category="lo",
  description="DEVANAGARI SIGN SPACING CANDRABINDU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8F2,
 },
 [0xA8F3]={
  category="lo",
  description="DEVANAGARI SIGN CANDRABINDU VIRAMA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8F3,
 },
 [0xA8F4]={
  category="lo",
  description="DEVANAGARI SIGN DOUBLE CANDRABINDU VIRAMA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8F4,
 },
 [0xA8F5]={
  category="lo",
  description="DEVANAGARI SIGN CANDRABINDU TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8F5,
 },
 [0xA8F6]={
  category="lo",
  description="DEVANAGARI SIGN CANDRABINDU THREE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8F6,
 },
 [0xA8F7]={
  category="lo",
  description="DEVANAGARI SIGN CANDRABINDU AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8F7,
 },
 [0xA8F8]={
  category="po",
  description="DEVANAGARI SIGN PUSHPIKA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8F8,
 },
 [0xA8F9]={
  category="po",
  description="DEVANAGARI GAP FILLER",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8F9,
 },
 [0xA8FA]={
  category="po",
  description="DEVANAGARI CARET",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8FA,
 },
 [0xA8FB]={
  category="lo",
  description="DEVANAGARI HEADSTROKE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA8FB,
 },
 [0xA900]={
  category="nd",
  description="KAYAH LI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA900,
 },
 [0xA901]={
  category="nd",
  description="KAYAH LI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA901,
 },
 [0xA902]={
  category="nd",
  description="KAYAH LI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA902,
 },
 [0xA903]={
  category="nd",
  description="KAYAH LI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA903,
 },
 [0xA904]={
  category="nd",
  description="KAYAH LI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA904,
 },
 [0xA905]={
  category="nd",
  description="KAYAH LI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA905,
 },
 [0xA906]={
  category="nd",
  description="KAYAH LI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA906,
 },
 [0xA907]={
  category="nd",
  description="KAYAH LI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA907,
 },
 [0xA908]={
  category="nd",
  description="KAYAH LI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA908,
 },
 [0xA909]={
  category="nd",
  description="KAYAH LI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA909,
 },
 [0xA90A]={
  category="lo",
  description="KAYAH LI LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA90A,
 },
 [0xA90B]={
  category="lo",
  description="KAYAH LI LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA90B,
 },
 [0xA90C]={
  category="lo",
  description="KAYAH LI LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA90C,
 },
 [0xA90D]={
  category="lo",
  description="KAYAH LI LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA90D,
 },
 [0xA90E]={
  category="lo",
  description="KAYAH LI LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA90E,
 },
 [0xA90F]={
  category="lo",
  description="KAYAH LI LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA90F,
 },
 [0xA910]={
  category="lo",
  description="KAYAH LI LETTER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA910,
 },
 [0xA911]={
  category="lo",
  description="KAYAH LI LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA911,
 },
 [0xA912]={
  category="lo",
  description="KAYAH LI LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA912,
 },
 [0xA913]={
  category="lo",
  description="KAYAH LI LETTER HTA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA913,
 },
 [0xA914]={
  category="lo",
  description="KAYAH LI LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA914,
 },
 [0xA915]={
  category="lo",
  description="KAYAH LI LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA915,
 },
 [0xA916]={
  category="lo",
  description="KAYAH LI LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA916,
 },
 [0xA917]={
  category="lo",
  description="KAYAH LI LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA917,
 },
 [0xA918]={
  category="lo",
  description="KAYAH LI LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA918,
 },
 [0xA919]={
  category="lo",
  description="KAYAH LI LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA919,
 },
 [0xA91A]={
  category="lo",
  description="KAYAH LI LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA91A,
 },
 [0xA91B]={
  category="lo",
  description="KAYAH LI LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA91B,
 },
 [0xA91C]={
  category="lo",
  description="KAYAH LI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA91C,
 },
 [0xA91D]={
  category="lo",
  description="KAYAH LI LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA91D,
 },
 [0xA91E]={
  category="lo",
  description="KAYAH LI LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA91E,
 },
 [0xA91F]={
  category="lo",
  description="KAYAH LI LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA91F,
 },
 [0xA920]={
  category="lo",
  description="KAYAH LI LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA920,
 },
 [0xA921]={
  category="lo",
  description="KAYAH LI LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA921,
 },
 [0xA922]={
  category="lo",
  description="KAYAH LI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA922,
 },
 [0xA923]={
  category="lo",
  description="KAYAH LI LETTER OE",
  direction="l",
  linebreak="al",
  unicodeslot=0xA923,
 },
 [0xA924]={
  category="lo",
  description="KAYAH LI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xA924,
 },
 [0xA925]={
  category="lo",
  description="KAYAH LI LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0xA925,
 },
 [0xA926]={
  category="mn",
  description="KAYAH LI VOWEL UE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA926,
 },
 [0xA927]={
  category="mn",
  description="KAYAH LI VOWEL E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA927,
 },
 [0xA928]={
  category="mn",
  description="KAYAH LI VOWEL U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA928,
 },
 [0xA929]={
  category="mn",
  description="KAYAH LI VOWEL EE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA929,
 },
 [0xA92A]={
  category="mn",
  description="KAYAH LI VOWEL O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA92A,
 },
 [0xA92B]={
  category="mn",
  description="KAYAH LI TONE PLOPHU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA92B,
 },
 [0xA92C]={
  category="mn",
  description="KAYAH LI TONE CALYA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA92C,
 },
 [0xA92D]={
  category="mn",
  description="KAYAH LI TONE CALYA PLOPHU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA92D,
 },
 [0xA92E]={
  category="po",
  description="KAYAH LI SIGN CWI",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA92E,
 },
 [0xA92F]={
  category="po",
  description="KAYAH LI SIGN SHYA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA92F,
 },
 [0xA930]={
  category="lo",
  description="REJANG LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA930,
 },
 [0xA931]={
  category="lo",
  description="REJANG LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA931,
 },
 [0xA932]={
  category="lo",
  description="REJANG LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA932,
 },
 [0xA933]={
  category="lo",
  description="REJANG LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA933,
 },
 [0xA934]={
  category="lo",
  description="REJANG LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA934,
 },
 [0xA935]={
  category="lo",
  description="REJANG LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA935,
 },
 [0xA936]={
  category="lo",
  description="REJANG LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA936,
 },
 [0xA937]={
  category="lo",
  description="REJANG LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA937,
 },
 [0xA938]={
  category="lo",
  description="REJANG LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA938,
 },
 [0xA939]={
  category="lo",
  description="REJANG LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA939,
 },
 [0xA93A]={
  category="lo",
  description="REJANG LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA93A,
 },
 [0xA93B]={
  category="lo",
  description="REJANG LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA93B,
 },
 [0xA93C]={
  category="lo",
  description="REJANG LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA93C,
 },
 [0xA93D]={
  category="lo",
  description="REJANG LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA93D,
 },
 [0xA93E]={
  category="lo",
  description="REJANG LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA93E,
 },
 [0xA93F]={
  category="lo",
  description="REJANG LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA93F,
 },
 [0xA940]={
  category="lo",
  description="REJANG LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA940,
 },
 [0xA941]={
  category="lo",
  description="REJANG LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA941,
 },
 [0xA942]={
  category="lo",
  description="REJANG LETTER MBA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA942,
 },
 [0xA943]={
  category="lo",
  description="REJANG LETTER NGGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA943,
 },
 [0xA944]={
  category="lo",
  description="REJANG LETTER NDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA944,
 },
 [0xA945]={
  category="lo",
  description="REJANG LETTER NYJA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA945,
 },
 [0xA946]={
  category="lo",
  description="REJANG LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA946,
 },
 [0xA947]={
  category="mn",
  description="REJANG VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA947,
 },
 [0xA948]={
  category="mn",
  description="REJANG VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA948,
 },
 [0xA949]={
  category="mn",
  description="REJANG VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA949,
 },
 [0xA94A]={
  category="mn",
  description="REJANG VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA94A,
 },
 [0xA94B]={
  category="mn",
  description="REJANG VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA94B,
 },
 [0xA94C]={
  category="mn",
  description="REJANG VOWEL SIGN AU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA94C,
 },
 [0xA94D]={
  category="mn",
  description="REJANG VOWEL SIGN EU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA94D,
 },
 [0xA94E]={
  category="mn",
  description="REJANG VOWEL SIGN EA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA94E,
 },
 [0xA94F]={
  category="mn",
  description="REJANG CONSONANT SIGN NG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA94F,
 },
 [0xA950]={
  category="mn",
  description="REJANG CONSONANT SIGN N",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA950,
 },
 [0xA951]={
  category="mn",
  description="REJANG CONSONANT SIGN R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA951,
 },
 [0xA952]={
  category="mc",
  description="REJANG CONSONANT SIGN H",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA952,
 },
 [0xA953]={
  category="mc",
  description="REJANG VIRAMA",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA953,
 },
 [0xA95F]={
  category="po",
  description="REJANG SECTION MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA95F,
 },
 [0xA960]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG TIKEUT-MIEUM",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA960,
 },
 [0xA961]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG TIKEUT-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA961,
 },
 [0xA962]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG TIKEUT-SIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA962,
 },
 [0xA963]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG TIKEUT-CIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA963,
 },
 [0xA964]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA964,
 },
 [0xA965]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-SSANGKIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA965,
 },
 [0xA966]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA966,
 },
 [0xA967]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-SSANGTIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA967,
 },
 [0xA968]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-MIEUM",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA968,
 },
 [0xA969]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA969,
 },
 [0xA96A]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-SSANGPIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA96A,
 },
 [0xA96B]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-KAPYEOUNPIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA96B,
 },
 [0xA96C]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-SIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA96C,
 },
 [0xA96D]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-CIEUC",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA96D,
 },
 [0xA96E]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG RIEUL-KHIEUKH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA96E,
 },
 [0xA96F]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG MIEUM-KIYEOK",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA96F,
 },
 [0xA970]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG MIEUM-TIKEUT",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA970,
 },
 [0xA971]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG MIEUM-SIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA971,
 },
 [0xA972]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-SIOS-THIEUTH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA972,
 },
 [0xA973]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-KHIEUKH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA973,
 },
 [0xA974]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PIEUP-HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA974,
 },
 [0xA975]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGSIOS-PIEUP",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA975,
 },
 [0xA976]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-RIEUL",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA976,
 },
 [0xA977]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG IEUNG-HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA977,
 },
 [0xA978]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGCIEUC-HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA978,
 },
 [0xA979]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGTHIEUTH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA979,
 },
 [0xA97A]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG PHIEUPH-HIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA97A,
 },
 [0xA97B]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG HIEUH-SIOS",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA97B,
 },
 [0xA97C]={
  category="lo",
  cjkwd="w",
  description="HANGUL CHOSEONG SSANGYEORINHIEUH",
  direction="l",
  linebreak="jl",
  unicodeslot=0xA97C,
 },
 [0xA980]={
  category="mn",
  description="JAVANESE SIGN PANYANGGA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA980,
 },
 [0xA981]={
  category="mn",
  description="JAVANESE SIGN CECAK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA981,
 },
 [0xA982]={
  category="mn",
  description="JAVANESE SIGN LAYAR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA982,
 },
 [0xA983]={
  category="mc",
  description="JAVANESE SIGN WIGNYAN",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA983,
 },
 [0xA984]={
  category="lo",
  description="JAVANESE LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xA984,
 },
 [0xA985]={
  category="lo",
  description="JAVANESE LETTER I KAWI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA985,
 },
 [0xA986]={
  category="lo",
  description="JAVANESE LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xA986,
 },
 [0xA987]={
  category="lo",
  description="JAVANESE LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0xA987,
 },
 [0xA988]={
  category="lo",
  description="JAVANESE LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0xA988,
 },
 [0xA989]={
  category="lo",
  description="JAVANESE LETTER PA CEREK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA989,
 },
 [0xA98A]={
  category="lo",
  description="JAVANESE LETTER NGA LELET",
  direction="l",
  linebreak="al",
  unicodeslot=0xA98A,
 },
 [0xA98B]={
  category="lo",
  description="JAVANESE LETTER NGA LELET RASWADI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA98B,
 },
 [0xA98C]={
  category="lo",
  description="JAVANESE LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0xA98C,
 },
 [0xA98D]={
  category="lo",
  description="JAVANESE LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0xA98D,
 },
 [0xA98E]={
  category="lo",
  description="JAVANESE LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0xA98E,
 },
 [0xA98F]={
  category="lo",
  description="JAVANESE LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA98F,
 },
 [0xA990]={
  category="lo",
  description="JAVANESE LETTER KA SASAK",
  direction="l",
  linebreak="al",
  unicodeslot=0xA990,
 },
 [0xA991]={
  category="lo",
  description="JAVANESE LETTER KA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA991,
 },
 [0xA992]={
  category="lo",
  description="JAVANESE LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA992,
 },
 [0xA993]={
  category="lo",
  description="JAVANESE LETTER GA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA993,
 },
 [0xA994]={
  category="lo",
  description="JAVANESE LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA994,
 },
 [0xA995]={
  category="lo",
  description="JAVANESE LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA995,
 },
 [0xA996]={
  category="lo",
  description="JAVANESE LETTER CA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA996,
 },
 [0xA997]={
  category="lo",
  description="JAVANESE LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA997,
 },
 [0xA998]={
  category="lo",
  description="JAVANESE LETTER NYA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA998,
 },
 [0xA999]={
  category="lo",
  description="JAVANESE LETTER JA MAHAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA999,
 },
 [0xA99A]={
  category="lo",
  description="JAVANESE LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA99A,
 },
 [0xA99B]={
  category="lo",
  description="JAVANESE LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA99B,
 },
 [0xA99C]={
  category="lo",
  description="JAVANESE LETTER TTA MAHAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA99C,
 },
 [0xA99D]={
  category="lo",
  description="JAVANESE LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA99D,
 },
 [0xA99E]={
  category="lo",
  description="JAVANESE LETTER DDA MAHAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA99E,
 },
 [0xA99F]={
  category="lo",
  description="JAVANESE LETTER NA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA99F,
 },
 [0xA9A0]={
  category="lo",
  description="JAVANESE LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A0,
 },
 [0xA9A1]={
  category="lo",
  description="JAVANESE LETTER TA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A1,
 },
 [0xA9A2]={
  category="lo",
  description="JAVANESE LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A2,
 },
 [0xA9A3]={
  category="lo",
  description="JAVANESE LETTER DA MAHAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A3,
 },
 [0xA9A4]={
  category="lo",
  description="JAVANESE LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A4,
 },
 [0xA9A5]={
  category="lo",
  description="JAVANESE LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A5,
 },
 [0xA9A6]={
  category="lo",
  description="JAVANESE LETTER PA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A6,
 },
 [0xA9A7]={
  category="lo",
  description="JAVANESE LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A7,
 },
 [0xA9A8]={
  category="lo",
  description="JAVANESE LETTER BA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A8,
 },
 [0xA9A9]={
  category="lo",
  description="JAVANESE LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9A9,
 },
 [0xA9AA]={
  category="lo",
  description="JAVANESE LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9AA,
 },
 [0xA9AB]={
  category="lo",
  description="JAVANESE LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9AB,
 },
 [0xA9AC]={
  category="lo",
  description="JAVANESE LETTER RA AGUNG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9AC,
 },
 [0xA9AD]={
  category="lo",
  description="JAVANESE LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9AD,
 },
 [0xA9AE]={
  category="lo",
  description="JAVANESE LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9AE,
 },
 [0xA9AF]={
  category="lo",
  description="JAVANESE LETTER SA MURDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9AF,
 },
 [0xA9B0]={
  category="lo",
  description="JAVANESE LETTER SA MAHAPRANA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9B0,
 },
 [0xA9B1]={
  category="lo",
  description="JAVANESE LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9B1,
 },
 [0xA9B2]={
  category="lo",
  description="JAVANESE LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9B2,
 },
 [0xA9B3]={
  category="mn",
  description="JAVANESE SIGN CECAK TELU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA9B3,
 },
 [0xA9B4]={
  category="mc",
  description="JAVANESE VOWEL SIGN TARUNG",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA9B4,
 },
 [0xA9B5]={
  category="mc",
  description="JAVANESE VOWEL SIGN TOLONG",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA9B5,
 },
 [0xA9B6]={
  category="mn",
  description="JAVANESE VOWEL SIGN WULU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA9B6,
 },
 [0xA9B7]={
  category="mn",
  description="JAVANESE VOWEL SIGN WULU MELIK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA9B7,
 },
 [0xA9B8]={
  category="mn",
  description="JAVANESE VOWEL SIGN SUKU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA9B8,
 },
 [0xA9B9]={
  category="mn",
  description="JAVANESE VOWEL SIGN SUKU MENDUT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA9B9,
 },
 [0xA9BA]={
  category="mc",
  description="JAVANESE VOWEL SIGN TALING",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA9BA,
 },
 [0xA9BB]={
  category="mc",
  description="JAVANESE VOWEL SIGN DIRGA MURE",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA9BB,
 },
 [0xA9BC]={
  category="mn",
  description="JAVANESE VOWEL SIGN PEPET",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xA9BC,
 },
 [0xA9BD]={
  category="mc",
  description="JAVANESE CONSONANT SIGN KERET",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA9BD,
 },
 [0xA9BE]={
  category="mc",
  description="JAVANESE CONSONANT SIGN PENGKAL",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA9BE,
 },
 [0xA9BF]={
  category="mc",
  description="JAVANESE CONSONANT SIGN CAKRA",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA9BF,
 },
 [0xA9C0]={
  category="mc",
  description="JAVANESE PANGKON",
  direction="l",
  linebreak="cm",
  unicodeslot=0xA9C0,
 },
 [0xA9C1]={
  category="po",
  description="JAVANESE LEFT RERENGGAN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9C1,
 },
 [0xA9C2]={
  category="po",
  description="JAVANESE RIGHT RERENGGAN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9C2,
 },
 [0xA9C3]={
  category="po",
  description="JAVANESE PADA ANDAP",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9C3,
 },
 [0xA9C4]={
  category="po",
  description="JAVANESE PADA MADYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9C4,
 },
 [0xA9C5]={
  category="po",
  description="JAVANESE PADA LUHUR",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9C5,
 },
 [0xA9C6]={
  category="po",
  description="JAVANESE PADA WINDU",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9C6,
 },
 [0xA9C7]={
  category="po",
  description="JAVANESE PADA PANGKAT",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA9C7,
 },
 [0xA9C8]={
  category="po",
  description="JAVANESE PADA LINGSA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA9C8,
 },
 [0xA9C9]={
  category="po",
  description="JAVANESE PADA LUNGSI",
  direction="l",
  linebreak="ba",
  unicodeslot=0xA9C9,
 },
 [0xA9CA]={
  category="po",
  description="JAVANESE PADA ADEG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9CA,
 },
 [0xA9CB]={
  category="po",
  description="JAVANESE PADA ADEG ADEG",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9CB,
 },
 [0xA9CC]={
  category="po",
  description="JAVANESE PADA PISELEH",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9CC,
 },
 [0xA9CD]={
  category="po",
  description="JAVANESE TURNED PADA PISELEH",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9CD,
 },
 [0xA9CF]={
  category="lm",
  description="JAVANESE PANGRANGKEP",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9CF,
 },
 [0xA9D0]={
  category="nd",
  description="JAVANESE DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D0,
 },
 [0xA9D1]={
  category="nd",
  description="JAVANESE DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D1,
 },
 [0xA9D2]={
  category="nd",
  description="JAVANESE DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D2,
 },
 [0xA9D3]={
  category="nd",
  description="JAVANESE DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D3,
 },
 [0xA9D4]={
  category="nd",
  description="JAVANESE DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D4,
 },
 [0xA9D5]={
  category="nd",
  description="JAVANESE DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D5,
 },
 [0xA9D6]={
  category="nd",
  description="JAVANESE DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D6,
 },
 [0xA9D7]={
  category="nd",
  description="JAVANESE DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D7,
 },
 [0xA9D8]={
  category="nd",
  description="JAVANESE DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D8,
 },
 [0xA9D9]={
  category="nd",
  description="JAVANESE DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xA9D9,
 },
 [0xA9DE]={
  category="po",
  description="JAVANESE PADA TIRTA TUMETES",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9DE,
 },
 [0xA9DF]={
  category="po",
  description="JAVANESE PADA ISEN-ISEN",
  direction="l",
  linebreak="al",
  unicodeslot=0xA9DF,
 },
 [0xAA00]={
  category="lo",
  description="CHAM LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA00,
 },
 [0xAA01]={
  category="lo",
  description="CHAM LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA01,
 },
 [0xAA02]={
  category="lo",
  description="CHAM LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA02,
 },
 [0xAA03]={
  category="lo",
  description="CHAM LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA03,
 },
 [0xAA04]={
  category="lo",
  description="CHAM LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA04,
 },
 [0xAA05]={
  category="lo",
  description="CHAM LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA05,
 },
 [0xAA06]={
  category="lo",
  description="CHAM LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA06,
 },
 [0xAA07]={
  category="lo",
  description="CHAM LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA07,
 },
 [0xAA08]={
  category="lo",
  description="CHAM LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA08,
 },
 [0xAA09]={
  category="lo",
  description="CHAM LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA09,
 },
 [0xAA0A]={
  category="lo",
  description="CHAM LETTER NGUE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA0A,
 },
 [0xAA0B]={
  category="lo",
  description="CHAM LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA0B,
 },
 [0xAA0C]={
  category="lo",
  description="CHAM LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA0C,
 },
 [0xAA0D]={
  category="lo",
  description="CHAM LETTER CHHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA0D,
 },
 [0xAA0E]={
  category="lo",
  description="CHAM LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA0E,
 },
 [0xAA0F]={
  category="lo",
  description="CHAM LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA0F,
 },
 [0xAA10]={
  category="lo",
  description="CHAM LETTER NHUE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA10,
 },
 [0xAA11]={
  category="lo",
  description="CHAM LETTER NHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA11,
 },
 [0xAA12]={
  category="lo",
  description="CHAM LETTER NHJA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA12,
 },
 [0xAA13]={
  category="lo",
  description="CHAM LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA13,
 },
 [0xAA14]={
  category="lo",
  description="CHAM LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA14,
 },
 [0xAA15]={
  category="lo",
  description="CHAM LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA15,
 },
 [0xAA16]={
  category="lo",
  description="CHAM LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA16,
 },
 [0xAA17]={
  category="lo",
  description="CHAM LETTER NUE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA17,
 },
 [0xAA18]={
  category="lo",
  description="CHAM LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA18,
 },
 [0xAA19]={
  category="lo",
  description="CHAM LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA19,
 },
 [0xAA1A]={
  category="lo",
  description="CHAM LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA1A,
 },
 [0xAA1B]={
  category="lo",
  description="CHAM LETTER PPA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA1B,
 },
 [0xAA1C]={
  category="lo",
  description="CHAM LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA1C,
 },
 [0xAA1D]={
  category="lo",
  description="CHAM LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA1D,
 },
 [0xAA1E]={
  category="lo",
  description="CHAM LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA1E,
 },
 [0xAA1F]={
  category="lo",
  description="CHAM LETTER MUE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA1F,
 },
 [0xAA20]={
  category="lo",
  description="CHAM LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA20,
 },
 [0xAA21]={
  category="lo",
  description="CHAM LETTER BBA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA21,
 },
 [0xAA22]={
  category="lo",
  description="CHAM LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA22,
 },
 [0xAA23]={
  category="lo",
  description="CHAM LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA23,
 },
 [0xAA24]={
  category="lo",
  description="CHAM LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA24,
 },
 [0xAA25]={
  category="lo",
  description="CHAM LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA25,
 },
 [0xAA26]={
  category="lo",
  description="CHAM LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA26,
 },
 [0xAA27]={
  category="lo",
  description="CHAM LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA27,
 },
 [0xAA28]={
  category="lo",
  description="CHAM LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA28,
 },
 [0xAA29]={
  category="mn",
  description="CHAM VOWEL SIGN AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA29,
 },
 [0xAA2A]={
  category="mn",
  description="CHAM VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA2A,
 },
 [0xAA2B]={
  category="mn",
  description="CHAM VOWEL SIGN II",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA2B,
 },
 [0xAA2C]={
  category="mn",
  description="CHAM VOWEL SIGN EI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA2C,
 },
 [0xAA2D]={
  category="mn",
  description="CHAM VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA2D,
 },
 [0xAA2E]={
  category="mn",
  description="CHAM VOWEL SIGN OE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA2E,
 },
 [0xAA2F]={
  category="mc",
  description="CHAM VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAA2F,
 },
 [0xAA30]={
  category="mc",
  description="CHAM VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAA30,
 },
 [0xAA31]={
  category="mn",
  description="CHAM VOWEL SIGN AU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA31,
 },
 [0xAA32]={
  category="mn",
  description="CHAM VOWEL SIGN UE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA32,
 },
 [0xAA33]={
  category="mc",
  description="CHAM CONSONANT SIGN YA",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAA33,
 },
 [0xAA34]={
  category="mc",
  description="CHAM CONSONANT SIGN RA",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAA34,
 },
 [0xAA35]={
  category="mn",
  description="CHAM CONSONANT SIGN LA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA35,
 },
 [0xAA36]={
  category="mn",
  description="CHAM CONSONANT SIGN WA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA36,
 },
 [0xAA40]={
  category="lo",
  description="CHAM LETTER FINAL K",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA40,
 },
 [0xAA41]={
  category="lo",
  description="CHAM LETTER FINAL G",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA41,
 },
 [0xAA42]={
  category="lo",
  description="CHAM LETTER FINAL NG",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA42,
 },
 [0xAA43]={
  category="mn",
  description="CHAM CONSONANT SIGN FINAL NG",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA43,
 },
 [0xAA44]={
  category="lo",
  description="CHAM LETTER FINAL CH",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA44,
 },
 [0xAA45]={
  category="lo",
  description="CHAM LETTER FINAL T",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA45,
 },
 [0xAA46]={
  category="lo",
  description="CHAM LETTER FINAL N",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA46,
 },
 [0xAA47]={
  category="lo",
  description="CHAM LETTER FINAL P",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA47,
 },
 [0xAA48]={
  category="lo",
  description="CHAM LETTER FINAL Y",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA48,
 },
 [0xAA49]={
  category="lo",
  description="CHAM LETTER FINAL R",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA49,
 },
 [0xAA4A]={
  category="lo",
  description="CHAM LETTER FINAL L",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA4A,
 },
 [0xAA4B]={
  category="lo",
  description="CHAM LETTER FINAL SS",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA4B,
 },
 [0xAA4C]={
  category="mn",
  description="CHAM CONSONANT SIGN FINAL M",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAA4C,
 },
 [0xAA4D]={
  category="mc",
  description="CHAM CONSONANT SIGN FINAL H",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAA4D,
 },
 [0xAA50]={
  category="nd",
  description="CHAM DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA50,
 },
 [0xAA51]={
  category="nd",
  description="CHAM DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA51,
 },
 [0xAA52]={
  category="nd",
  description="CHAM DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA52,
 },
 [0xAA53]={
  category="nd",
  description="CHAM DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA53,
 },
 [0xAA54]={
  category="nd",
  description="CHAM DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA54,
 },
 [0xAA55]={
  category="nd",
  description="CHAM DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA55,
 },
 [0xAA56]={
  category="nd",
  description="CHAM DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA56,
 },
 [0xAA57]={
  category="nd",
  description="CHAM DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA57,
 },
 [0xAA58]={
  category="nd",
  description="CHAM DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA58,
 },
 [0xAA59]={
  category="nd",
  description="CHAM DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xAA59,
 },
 [0xAA5C]={
  category="po",
  description="CHAM PUNCTUATION SPIRAL",
  direction="l",
  linebreak="al",
  unicodeslot=0xAA5C,
 },
 [0xAA5D]={
  category="po",
  description="CHAM PUNCTUATION DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xAA5D,
 },
 [0xAA5E]={
  category="po",
  description="CHAM PUNCTUATION DOUBLE DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xAA5E,
 },
 [0xAA5F]={
  category="po",
  description="CHAM PUNCTUATION TRIPLE DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0xAA5F,
 },
 [0xAA60]={
  category="lo",
  description="MYANMAR LETTER KHAMTI GA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA60,
 },
 [0xAA61]={
  category="lo",
  description="MYANMAR LETTER KHAMTI CA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA61,
 },
 [0xAA62]={
  category="lo",
  description="MYANMAR LETTER KHAMTI CHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA62,
 },
 [0xAA63]={
  category="lo",
  description="MYANMAR LETTER KHAMTI JA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA63,
 },
 [0xAA64]={
  category="lo",
  description="MYANMAR LETTER KHAMTI JHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA64,
 },
 [0xAA65]={
  category="lo",
  description="MYANMAR LETTER KHAMTI NYA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA65,
 },
 [0xAA66]={
  category="lo",
  description="MYANMAR LETTER KHAMTI TTA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA66,
 },
 [0xAA67]={
  category="lo",
  description="MYANMAR LETTER KHAMTI TTHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA67,
 },
 [0xAA68]={
  category="lo",
  description="MYANMAR LETTER KHAMTI DDA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA68,
 },
 [0xAA69]={
  category="lo",
  description="MYANMAR LETTER KHAMTI DDHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA69,
 },
 [0xAA6A]={
  category="lo",
  description="MYANMAR LETTER KHAMTI DHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA6A,
 },
 [0xAA6B]={
  category="lo",
  description="MYANMAR LETTER KHAMTI NA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA6B,
 },
 [0xAA6C]={
  category="lo",
  description="MYANMAR LETTER KHAMTI SA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA6C,
 },
 [0xAA6D]={
  category="lo",
  description="MYANMAR LETTER KHAMTI HA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA6D,
 },
 [0xAA6E]={
  category="lo",
  description="MYANMAR LETTER KHAMTI HHA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA6E,
 },
 [0xAA6F]={
  category="lo",
  description="MYANMAR LETTER KHAMTI FA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA6F,
 },
 [0xAA70]={
  category="lm",
  description="MYANMAR MODIFIER LETTER KHAMTI REDUPLICATION",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA70,
 },
 [0xAA71]={
  category="lo",
  description="MYANMAR LETTER KHAMTI XA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA71,
 },
 [0xAA72]={
  category="lo",
  description="MYANMAR LETTER KHAMTI ZA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA72,
 },
 [0xAA73]={
  category="lo",
  description="MYANMAR LETTER KHAMTI RA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA73,
 },
 [0xAA74]={
  category="lo",
  description="MYANMAR LOGOGRAM KHAMTI OAY",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA74,
 },
 [0xAA75]={
  category="lo",
  description="MYANMAR LOGOGRAM KHAMTI QN",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA75,
 },
 [0xAA76]={
  category="lo",
  description="MYANMAR LOGOGRAM KHAMTI HM",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA76,
 },
 [0xAA77]={
  category="so",
  description="MYANMAR SYMBOL AITON EXCLAMATION",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA77,
 },
 [0xAA78]={
  category="so",
  description="MYANMAR SYMBOL AITON ONE",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA78,
 },
 [0xAA79]={
  category="so",
  description="MYANMAR SYMBOL AITON TWO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA79,
 },
 [0xAA7A]={
  category="lo",
  description="MYANMAR LETTER AITON RA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA7A,
 },
 [0xAA7B]={
  category="mc",
  description="MYANMAR SIGN PAO KAREN TONE",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA7B,
 },
 [0xAA80]={
  category="lo",
  description="TAI VIET LETTER LOW KO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA80,
 },
 [0xAA81]={
  category="lo",
  description="TAI VIET LETTER HIGH KO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA81,
 },
 [0xAA82]={
  category="lo",
  description="TAI VIET LETTER LOW KHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA82,
 },
 [0xAA83]={
  category="lo",
  description="TAI VIET LETTER HIGH KHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA83,
 },
 [0xAA84]={
  category="lo",
  description="TAI VIET LETTER LOW KHHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA84,
 },
 [0xAA85]={
  category="lo",
  description="TAI VIET LETTER HIGH KHHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA85,
 },
 [0xAA86]={
  category="lo",
  description="TAI VIET LETTER LOW GO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA86,
 },
 [0xAA87]={
  category="lo",
  description="TAI VIET LETTER HIGH GO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA87,
 },
 [0xAA88]={
  category="lo",
  description="TAI VIET LETTER LOW NGO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA88,
 },
 [0xAA89]={
  category="lo",
  description="TAI VIET LETTER HIGH NGO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA89,
 },
 [0xAA8A]={
  category="lo",
  description="TAI VIET LETTER LOW CO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA8A,
 },
 [0xAA8B]={
  category="lo",
  description="TAI VIET LETTER HIGH CO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA8B,
 },
 [0xAA8C]={
  category="lo",
  description="TAI VIET LETTER LOW CHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA8C,
 },
 [0xAA8D]={
  category="lo",
  description="TAI VIET LETTER HIGH CHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA8D,
 },
 [0xAA8E]={
  category="lo",
  description="TAI VIET LETTER LOW SO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA8E,
 },
 [0xAA8F]={
  category="lo",
  description="TAI VIET LETTER HIGH SO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA8F,
 },
 [0xAA90]={
  category="lo",
  description="TAI VIET LETTER LOW NYO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA90,
 },
 [0xAA91]={
  category="lo",
  description="TAI VIET LETTER HIGH NYO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA91,
 },
 [0xAA92]={
  category="lo",
  description="TAI VIET LETTER LOW DO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA92,
 },
 [0xAA93]={
  category="lo",
  description="TAI VIET LETTER HIGH DO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA93,
 },
 [0xAA94]={
  category="lo",
  description="TAI VIET LETTER LOW TO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA94,
 },
 [0xAA95]={
  category="lo",
  description="TAI VIET LETTER HIGH TO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA95,
 },
 [0xAA96]={
  category="lo",
  description="TAI VIET LETTER LOW THO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA96,
 },
 [0xAA97]={
  category="lo",
  description="TAI VIET LETTER HIGH THO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA97,
 },
 [0xAA98]={
  category="lo",
  description="TAI VIET LETTER LOW NO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA98,
 },
 [0xAA99]={
  category="lo",
  description="TAI VIET LETTER HIGH NO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA99,
 },
 [0xAA9A]={
  category="lo",
  description="TAI VIET LETTER LOW BO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA9A,
 },
 [0xAA9B]={
  category="lo",
  description="TAI VIET LETTER HIGH BO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA9B,
 },
 [0xAA9C]={
  category="lo",
  description="TAI VIET LETTER LOW PO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA9C,
 },
 [0xAA9D]={
  category="lo",
  description="TAI VIET LETTER HIGH PO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA9D,
 },
 [0xAA9E]={
  category="lo",
  description="TAI VIET LETTER LOW PHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA9E,
 },
 [0xAA9F]={
  category="lo",
  description="TAI VIET LETTER HIGH PHO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAA9F,
 },
 [0xAAA0]={
  category="lo",
  description="TAI VIET LETTER LOW FO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA0,
 },
 [0xAAA1]={
  category="lo",
  description="TAI VIET LETTER HIGH FO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA1,
 },
 [0xAAA2]={
  category="lo",
  description="TAI VIET LETTER LOW MO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA2,
 },
 [0xAAA3]={
  category="lo",
  description="TAI VIET LETTER HIGH MO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA3,
 },
 [0xAAA4]={
  category="lo",
  description="TAI VIET LETTER LOW YO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA4,
 },
 [0xAAA5]={
  category="lo",
  description="TAI VIET LETTER HIGH YO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA5,
 },
 [0xAAA6]={
  category="lo",
  description="TAI VIET LETTER LOW RO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA6,
 },
 [0xAAA7]={
  category="lo",
  description="TAI VIET LETTER HIGH RO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA7,
 },
 [0xAAA8]={
  category="lo",
  description="TAI VIET LETTER LOW LO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA8,
 },
 [0xAAA9]={
  category="lo",
  description="TAI VIET LETTER HIGH LO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAA9,
 },
 [0xAAAA]={
  category="lo",
  description="TAI VIET LETTER LOW VO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAAA,
 },
 [0xAAAB]={
  category="lo",
  description="TAI VIET LETTER HIGH VO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAAB,
 },
 [0xAAAC]={
  category="lo",
  description="TAI VIET LETTER LOW HO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAAC,
 },
 [0xAAAD]={
  category="lo",
  description="TAI VIET LETTER HIGH HO",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAAD,
 },
 [0xAAAE]={
  category="lo",
  description="TAI VIET LETTER LOW O",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAAE,
 },
 [0xAAAF]={
  category="lo",
  description="TAI VIET LETTER HIGH O",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAAF,
 },
 [0xAAB0]={
  category="mn",
  description="TAI VIET MAI KANG",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAAB0,
 },
 [0xAAB1]={
  category="lo",
  description="TAI VIET VOWEL AA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAB1,
 },
 [0xAAB2]={
  category="mn",
  description="TAI VIET VOWEL I",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAAB2,
 },
 [0xAAB3]={
  category="mn",
  description="TAI VIET VOWEL UE",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAAB3,
 },
 [0xAAB4]={
  category="mn",
  description="TAI VIET VOWEL U",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAAB4,
 },
 [0xAAB5]={
  category="lo",
  description="TAI VIET VOWEL E",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAB5,
 },
 [0xAAB6]={
  category="lo",
  description="TAI VIET VOWEL O",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAB6,
 },
 [0xAAB7]={
  category="mn",
  description="TAI VIET MAI KHIT",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAAB7,
 },
 [0xAAB8]={
  category="mn",
  description="TAI VIET VOWEL IA",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAAB8,
 },
 [0xAAB9]={
  category="lo",
  description="TAI VIET VOWEL UEA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAB9,
 },
 [0xAABA]={
  category="lo",
  description="TAI VIET VOWEL UA",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAABA,
 },
 [0xAABB]={
  category="lo",
  description="TAI VIET VOWEL AUE",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAABB,
 },
 [0xAABC]={
  category="lo",
  description="TAI VIET VOWEL AY",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAABC,
 },
 [0xAABD]={
  category="lo",
  description="TAI VIET VOWEL AN",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAABD,
 },
 [0xAABE]={
  category="mn",
  description="TAI VIET VOWEL AM",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAABE,
 },
 [0xAABF]={
  category="mn",
  description="TAI VIET TONE MAI EK",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAABF,
 },
 [0xAAC0]={
  category="lo",
  description="TAI VIET TONE MAI NUENG",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAC0,
 },
 [0xAAC1]={
  category="mn",
  description="TAI VIET TONE MAI THO",
  direction="nsm",
  linebreak="sa",
  unicodeslot=0xAAC1,
 },
 [0xAAC2]={
  category="lo",
  description="TAI VIET TONE MAI SONG",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAAC2,
 },
 [0xAADB]={
  category="lo",
  description="TAI VIET SYMBOL KON",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAADB,
 },
 [0xAADC]={
  category="lo",
  description="TAI VIET SYMBOL NUENG",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAADC,
 },
 [0xAADD]={
  category="lm",
  description="TAI VIET SYMBOL SAM",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAADD,
 },
 [0xAADE]={
  category="po",
  description="TAI VIET SYMBOL HO HOI",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAADE,
 },
 [0xAADF]={
  category="po",
  description="TAI VIET SYMBOL KOI KOI",
  direction="l",
  linebreak="sa",
  unicodeslot=0xAADF,
 },
 [0xAAE0]={
  category="lo",
  description="MEETEI MAYEK LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE0,
 },
 [0xAAE1]={
  category="lo",
  description="MEETEI MAYEK LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE1,
 },
 [0xAAE2]={
  category="lo",
  description="MEETEI MAYEK LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE2,
 },
 [0xAAE3]={
  category="lo",
  description="MEETEI MAYEK LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE3,
 },
 [0xAAE4]={
  category="lo",
  description="MEETEI MAYEK LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE4,
 },
 [0xAAE5]={
  category="lo",
  description="MEETEI MAYEK LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE5,
 },
 [0xAAE6]={
  category="lo",
  description="MEETEI MAYEK LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE6,
 },
 [0xAAE7]={
  category="lo",
  description="MEETEI MAYEK LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE7,
 },
 [0xAAE8]={
  category="lo",
  description="MEETEI MAYEK LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE8,
 },
 [0xAAE9]={
  category="lo",
  description="MEETEI MAYEK LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAE9,
 },
 [0xAAEA]={
  category="lo",
  description="MEETEI MAYEK LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAEA,
 },
 [0xAAEB]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAAEB,
 },
 [0xAAEC]={
  category="mn",
  description="MEETEI MAYEK VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAAEC,
 },
 [0xAAED]={
  category="mn",
  description="MEETEI MAYEK VOWEL SIGN AAI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAAED,
 },
 [0xAAEE]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAAEE,
 },
 [0xAAEF]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN AAU",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAAEF,
 },
 [0xAAF0]={
  category="po",
  description="MEETEI MAYEK CHEIKHAN",
  direction="l",
  linebreak="ba",
  unicodeslot=0xAAF0,
 },
 [0xAAF1]={
  category="po",
  description="MEETEI MAYEK AHANG KHUDAM",
  direction="l",
  linebreak="ba",
  unicodeslot=0xAAF1,
 },
 [0xAAF2]={
  category="lo",
  description="MEETEI MAYEK ANJI",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAF2,
 },
 [0xAAF3]={
  category="lm",
  description="MEETEI MAYEK SYLLABLE REPETITION MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAF3,
 },
 [0xAAF4]={
  category="lm",
  description="MEETEI MAYEK WORD REPETITION MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0xAAF4,
 },
 [0xAAF5]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0xAAF5,
 },
 [0xAAF6]={
  category="mn",
  description="MEETEI MAYEK VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xAAF6,
 },
 [0xAB01]={
  category="lo",
  description="ETHIOPIC SYLLABLE TTHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB01,
 },
 [0xAB02]={
  category="lo",
  description="ETHIOPIC SYLLABLE TTHI",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB02,
 },
 [0xAB03]={
  category="lo",
  description="ETHIOPIC SYLLABLE TTHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB03,
 },
 [0xAB04]={
  category="lo",
  description="ETHIOPIC SYLLABLE TTHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB04,
 },
 [0xAB05]={
  category="lo",
  description="ETHIOPIC SYLLABLE TTHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB05,
 },
 [0xAB06]={
  category="lo",
  description="ETHIOPIC SYLLABLE TTHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB06,
 },
 [0xAB09]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB09,
 },
 [0xAB0A]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDHI",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB0A,
 },
 [0xAB0B]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB0B,
 },
 [0xAB0C]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB0C,
 },
 [0xAB0D]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB0D,
 },
 [0xAB0E]={
  category="lo",
  description="ETHIOPIC SYLLABLE DDHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB0E,
 },
 [0xAB11]={
  category="lo",
  description="ETHIOPIC SYLLABLE DZU",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB11,
 },
 [0xAB12]={
  category="lo",
  description="ETHIOPIC SYLLABLE DZI",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB12,
 },
 [0xAB13]={
  category="lo",
  description="ETHIOPIC SYLLABLE DZAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB13,
 },
 [0xAB14]={
  category="lo",
  description="ETHIOPIC SYLLABLE DZEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB14,
 },
 [0xAB15]={
  category="lo",
  description="ETHIOPIC SYLLABLE DZE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB15,
 },
 [0xAB16]={
  category="lo",
  description="ETHIOPIC SYLLABLE DZO",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB16,
 },
 [0xAB20]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHHA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB20,
 },
 [0xAB21]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHHU",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB21,
 },
 [0xAB22]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHHI",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB22,
 },
 [0xAB23]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB23,
 },
 [0xAB24]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB24,
 },
 [0xAB25]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHHE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB25,
 },
 [0xAB26]={
  category="lo",
  description="ETHIOPIC SYLLABLE CCHHO",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB26,
 },
 [0xAB28]={
  category="lo",
  description="ETHIOPIC SYLLABLE BBA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB28,
 },
 [0xAB29]={
  category="lo",
  description="ETHIOPIC SYLLABLE BBU",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB29,
 },
 [0xAB2A]={
  category="lo",
  description="ETHIOPIC SYLLABLE BBI",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB2A,
 },
 [0xAB2B]={
  category="lo",
  description="ETHIOPIC SYLLABLE BBAA",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB2B,
 },
 [0xAB2C]={
  category="lo",
  description="ETHIOPIC SYLLABLE BBEE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB2C,
 },
 [0xAB2D]={
  category="lo",
  description="ETHIOPIC SYLLABLE BBE",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB2D,
 },
 [0xAB2E]={
  category="lo",
  description="ETHIOPIC SYLLABLE BBO",
  direction="l",
  linebreak="al",
  unicodeslot=0xAB2E,
 },
 [0xABC0]={
  category="lo",
  description="MEETEI MAYEK LETTER KOK",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC0,
 },
 [0xABC1]={
  category="lo",
  description="MEETEI MAYEK LETTER SAM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC1,
 },
 [0xABC2]={
  category="lo",
  description="MEETEI MAYEK LETTER LAI",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC2,
 },
 [0xABC3]={
  category="lo",
  description="MEETEI MAYEK LETTER MIT",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC3,
 },
 [0xABC4]={
  category="lo",
  description="MEETEI MAYEK LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC4,
 },
 [0xABC5]={
  category="lo",
  description="MEETEI MAYEK LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC5,
 },
 [0xABC6]={
  category="lo",
  description="MEETEI MAYEK LETTER CHIL",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC6,
 },
 [0xABC7]={
  category="lo",
  description="MEETEI MAYEK LETTER TIL",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC7,
 },
 [0xABC8]={
  category="lo",
  description="MEETEI MAYEK LETTER KHOU",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC8,
 },
 [0xABC9]={
  category="lo",
  description="MEETEI MAYEK LETTER NGOU",
  direction="l",
  linebreak="al",
  unicodeslot=0xABC9,
 },
 [0xABCA]={
  category="lo",
  description="MEETEI MAYEK LETTER THOU",
  direction="l",
  linebreak="al",
  unicodeslot=0xABCA,
 },
 [0xABCB]={
  category="lo",
  description="MEETEI MAYEK LETTER WAI",
  direction="l",
  linebreak="al",
  unicodeslot=0xABCB,
 },
 [0xABCC]={
  category="lo",
  description="MEETEI MAYEK LETTER YANG",
  direction="l",
  linebreak="al",
  unicodeslot=0xABCC,
 },
 [0xABCD]={
  category="lo",
  description="MEETEI MAYEK LETTER HUK",
  direction="l",
  linebreak="al",
  unicodeslot=0xABCD,
 },
 [0xABCE]={
  category="lo",
  description="MEETEI MAYEK LETTER UN",
  direction="l",
  linebreak="al",
  unicodeslot=0xABCE,
 },
 [0xABCF]={
  category="lo",
  description="MEETEI MAYEK LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0xABCF,
 },
 [0xABD0]={
  category="lo",
  description="MEETEI MAYEK LETTER PHAM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD0,
 },
 [0xABD1]={
  category="lo",
  description="MEETEI MAYEK LETTER ATIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD1,
 },
 [0xABD2]={
  category="lo",
  description="MEETEI MAYEK LETTER GOK",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD2,
 },
 [0xABD3]={
  category="lo",
  description="MEETEI MAYEK LETTER JHAM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD3,
 },
 [0xABD4]={
  category="lo",
  description="MEETEI MAYEK LETTER RAI",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD4,
 },
 [0xABD5]={
  category="lo",
  description="MEETEI MAYEK LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD5,
 },
 [0xABD6]={
  category="lo",
  description="MEETEI MAYEK LETTER JIL",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD6,
 },
 [0xABD7]={
  category="lo",
  description="MEETEI MAYEK LETTER DIL",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD7,
 },
 [0xABD8]={
  category="lo",
  description="MEETEI MAYEK LETTER GHOU",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD8,
 },
 [0xABD9]={
  category="lo",
  description="MEETEI MAYEK LETTER DHOU",
  direction="l",
  linebreak="al",
  unicodeslot=0xABD9,
 },
 [0xABDA]={
  category="lo",
  description="MEETEI MAYEK LETTER BHAM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABDA,
 },
 [0xABDB]={
  category="lo",
  description="MEETEI MAYEK LETTER KOK LONSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABDB,
 },
 [0xABDC]={
  category="lo",
  description="MEETEI MAYEK LETTER LAI LONSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABDC,
 },
 [0xABDD]={
  category="lo",
  description="MEETEI MAYEK LETTER MIT LONSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABDD,
 },
 [0xABDE]={
  category="lo",
  description="MEETEI MAYEK LETTER PA LONSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABDE,
 },
 [0xABDF]={
  category="lo",
  description="MEETEI MAYEK LETTER NA LONSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABDF,
 },
 [0xABE0]={
  category="lo",
  description="MEETEI MAYEK LETTER TIL LONSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABE0,
 },
 [0xABE1]={
  category="lo",
  description="MEETEI MAYEK LETTER NGOU LONSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABE1,
 },
 [0xABE2]={
  category="lo",
  description="MEETEI MAYEK LETTER I LONSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0xABE2,
 },
 [0xABE3]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN ONAP",
  direction="l",
  linebreak="cm",
  unicodeslot=0xABE3,
 },
 [0xABE4]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN INAP",
  direction="l",
  linebreak="cm",
  unicodeslot=0xABE4,
 },
 [0xABE5]={
  category="mn",
  description="MEETEI MAYEK VOWEL SIGN ANAP",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xABE5,
 },
 [0xABE6]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN YENAP",
  direction="l",
  linebreak="cm",
  unicodeslot=0xABE6,
 },
 [0xABE7]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN SOUNAP",
  direction="l",
  linebreak="cm",
  unicodeslot=0xABE7,
 },
 [0xABE8]={
  category="mn",
  description="MEETEI MAYEK VOWEL SIGN UNAP",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xABE8,
 },
 [0xABE9]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN CHEINAP",
  direction="l",
  linebreak="cm",
  unicodeslot=0xABE9,
 },
 [0xABEA]={
  category="mc",
  description="MEETEI MAYEK VOWEL SIGN NUNG",
  direction="l",
  linebreak="cm",
  unicodeslot=0xABEA,
 },
 [0xABEB]={
  category="po",
  description="MEETEI MAYEK CHEIKHEI",
  direction="l",
  linebreak="ba",
  unicodeslot=0xABEB,
 },
 [0xABEC]={
  category="mc",
  description="MEETEI MAYEK LUM IYEK",
  direction="l",
  linebreak="cm",
  unicodeslot=0xABEC,
 },
 [0xABED]={
  category="mn",
  description="MEETEI MAYEK APUN IYEK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xABED,
 },
 [0xABF0]={
  category="nd",
  description="MEETEI MAYEK DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF0,
 },
 [0xABF1]={
  category="nd",
  description="MEETEI MAYEK DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF1,
 },
 [0xABF2]={
  category="nd",
  description="MEETEI MAYEK DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF2,
 },
 [0xABF3]={
  category="nd",
  description="MEETEI MAYEK DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF3,
 },
 [0xABF4]={
  category="nd",
  description="MEETEI MAYEK DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF4,
 },
 [0xABF5]={
  category="nd",
  description="MEETEI MAYEK DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF5,
 },
 [0xABF6]={
  category="nd",
  description="MEETEI MAYEK DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF6,
 },
 [0xABF7]={
  category="nd",
  description="MEETEI MAYEK DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF7,
 },
 [0xABF8]={
  category="nd",
  description="MEETEI MAYEK DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF8,
 },
 [0xABF9]={
  category="nd",
  description="MEETEI MAYEK DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0xABF9,
 },
 [0xD7B0]={
  category="lo",
  description="HANGUL JUNGSEONG O-YEO",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B0,
 },
 [0xD7B1]={
  category="lo",
  description="HANGUL JUNGSEONG O-O-I",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B1,
 },
 [0xD7B2]={
  category="lo",
  description="HANGUL JUNGSEONG YO-A",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B2,
 },
 [0xD7B3]={
  category="lo",
  description="HANGUL JUNGSEONG YO-AE",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B3,
 },
 [0xD7B4]={
  category="lo",
  description="HANGUL JUNGSEONG YO-EO",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B4,
 },
 [0xD7B5]={
  category="lo",
  description="HANGUL JUNGSEONG U-YEO",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B5,
 },
 [0xD7B6]={
  category="lo",
  description="HANGUL JUNGSEONG U-I-I",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B6,
 },
 [0xD7B7]={
  category="lo",
  description="HANGUL JUNGSEONG YU-AE",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B7,
 },
 [0xD7B8]={
  category="lo",
  description="HANGUL JUNGSEONG YU-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B8,
 },
 [0xD7B9]={
  category="lo",
  description="HANGUL JUNGSEONG EU-A",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7B9,
 },
 [0xD7BA]={
  category="lo",
  description="HANGUL JUNGSEONG EU-EO",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7BA,
 },
 [0xD7BB]={
  category="lo",
  description="HANGUL JUNGSEONG EU-E",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7BB,
 },
 [0xD7BC]={
  category="lo",
  description="HANGUL JUNGSEONG EU-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7BC,
 },
 [0xD7BD]={
  category="lo",
  description="HANGUL JUNGSEONG I-YA-O",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7BD,
 },
 [0xD7BE]={
  category="lo",
  description="HANGUL JUNGSEONG I-YAE",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7BE,
 },
 [0xD7BF]={
  category="lo",
  description="HANGUL JUNGSEONG I-YEO",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7BF,
 },
 [0xD7C0]={
  category="lo",
  description="HANGUL JUNGSEONG I-YE",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7C0,
 },
 [0xD7C1]={
  category="lo",
  description="HANGUL JUNGSEONG I-O-I",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7C1,
 },
 [0xD7C2]={
  category="lo",
  description="HANGUL JUNGSEONG I-YO",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7C2,
 },
 [0xD7C3]={
  category="lo",
  description="HANGUL JUNGSEONG I-YU",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7C3,
 },
 [0xD7C4]={
  category="lo",
  description="HANGUL JUNGSEONG I-I",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7C4,
 },
 [0xD7C5]={
  category="lo",
  description="HANGUL JUNGSEONG ARAEA-A",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7C5,
 },
 [0xD7C6]={
  category="lo",
  description="HANGUL JUNGSEONG ARAEA-E",
  direction="l",
  linebreak="jv",
  unicodeslot=0xD7C6,
 },
 [0xD7CB]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-RIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7CB,
 },
 [0xD7CC]={
  category="lo",
  description="HANGUL JONGSEONG NIEUN-CHIEUCH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7CC,
 },
 [0xD7CD]={
  category="lo",
  description="HANGUL JONGSEONG SSANGTIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7CD,
 },
 [0xD7CE]={
  category="lo",
  description="HANGUL JONGSEONG SSANGTIKEUT-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7CE,
 },
 [0xD7CF]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7CF,
 },
 [0xD7D0]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D0,
 },
 [0xD7D1]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT-SIOS-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D1,
 },
 [0xD7D2]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT-CIEUC",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D2,
 },
 [0xD7D3]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT-CHIEUCH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D3,
 },
 [0xD7D4]={
  category="lo",
  description="HANGUL JONGSEONG TIKEUT-THIEUTH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D4,
 },
 [0xD7D5]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-SSANGKIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D5,
 },
 [0xD7D6]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-KIYEOK-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D6,
 },
 [0xD7D7]={
  category="lo",
  description="HANGUL JONGSEONG SSANGRIEUL-KHIEUKH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D7,
 },
 [0xD7D8]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-MIEUM-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D8,
 },
 [0xD7D9]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-PIEUP-TIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7D9,
 },
 [0xD7DA]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-PIEUP-PHIEUPH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7DA,
 },
 [0xD7DB]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-YESIEUNG",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7DB,
 },
 [0xD7DC]={
  category="lo",
  description="HANGUL JONGSEONG RIEUL-YEORINHIEUH-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7DC,
 },
 [0xD7DD]={
  category="lo",
  description="HANGUL JONGSEONG KAPYEOUNRIEUL",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7DD,
 },
 [0xD7DE]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-NIEUN",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7DE,
 },
 [0xD7DF]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-SSANGNIEUN",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7DF,
 },
 [0xD7E0]={
  category="lo",
  description="HANGUL JONGSEONG SSANGMIEUM",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E0,
 },
 [0xD7E1]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-PIEUP-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E1,
 },
 [0xD7E2]={
  category="lo",
  description="HANGUL JONGSEONG MIEUM-CIEUC",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E2,
 },
 [0xD7E3]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-TIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E3,
 },
 [0xD7E4]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-RIEUL-PHIEUPH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E4,
 },
 [0xD7E5]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-MIEUM",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E5,
 },
 [0xD7E6]={
  category="lo",
  description="HANGUL JONGSEONG SSANGPIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E6,
 },
 [0xD7E7]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-SIOS-TIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E7,
 },
 [0xD7E8]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-CIEUC",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E8,
 },
 [0xD7E9]={
  category="lo",
  description="HANGUL JONGSEONG PIEUP-CHIEUCH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7E9,
 },
 [0xD7EA]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-MIEUM",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7EA,
 },
 [0xD7EB]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-KAPYEOUNPIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7EB,
 },
 [0xD7EC]={
  category="lo",
  description="HANGUL JONGSEONG SSANGSIOS-KIYEOK",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7EC,
 },
 [0xD7ED]={
  category="lo",
  description="HANGUL JONGSEONG SSANGSIOS-TIKEUT",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7ED,
 },
 [0xD7EE]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-PANSIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7EE,
 },
 [0xD7EF]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-CIEUC",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7EF,
 },
 [0xD7F0]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-CHIEUCH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F0,
 },
 [0xD7F1]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-THIEUTH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F1,
 },
 [0xD7F2]={
  category="lo",
  description="HANGUL JONGSEONG SIOS-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F2,
 },
 [0xD7F3]={
  category="lo",
  description="HANGUL JONGSEONG PANSIOS-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F3,
 },
 [0xD7F4]={
  category="lo",
  description="HANGUL JONGSEONG PANSIOS-KAPYEOUNPIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F4,
 },
 [0xD7F5]={
  category="lo",
  description="HANGUL JONGSEONG YESIEUNG-MIEUM",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F5,
 },
 [0xD7F6]={
  category="lo",
  description="HANGUL JONGSEONG YESIEUNG-HIEUH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F6,
 },
 [0xD7F7]={
  category="lo",
  description="HANGUL JONGSEONG CIEUC-PIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F7,
 },
 [0xD7F8]={
  category="lo",
  description="HANGUL JONGSEONG CIEUC-SSANGPIEUP",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F8,
 },
 [0xD7F9]={
  category="lo",
  description="HANGUL JONGSEONG SSANGCIEUC",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7F9,
 },
 [0xD7FA]={
  category="lo",
  description="HANGUL JONGSEONG PHIEUPH-SIOS",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7FA,
 },
 [0xD7FB]={
  category="lo",
  description="HANGUL JONGSEONG PHIEUPH-THIEUTH",
  direction="l",
  linebreak="jt",
  unicodeslot=0xD7FB,
 },
 [0xD800]={
  category="cs",
  description="<Non Private Use High Surrogate, First>",
  direction="l",
  linebreak="sg",
  unicodeslot=0xD800,
 },
 [0xDB7F]={
  category="cs",
  description="<Non Private Use High Surrogate, Last>",
  direction="l",
  linebreak="sg",
  unicodeslot=0xDB7F,
 },
 [0xDB80]={
  category="cs",
  description="<Private Use High Surrogate, First>",
  direction="l",
  linebreak="sg",
  unicodeslot=0xDB80,
 },
 [0xDBFF]={
  category="cs",
  description="<Private Use High Surrogate, Last>",
  direction="l",
  linebreak="sg",
  unicodeslot=0xDBFF,
 },
 [0xDC00]={
  category="cs",
  description="<Low Surrogate, First>",
  direction="l",
  linebreak="sg",
  unicodeslot=0xDC00,
 },
 [0xDFFF]={
  category="cs",
  description="<Low Surrogate, Last>",
  direction="l",
  linebreak="sg",
  unicodeslot=0xDFFF,
 },
 [0xE000]={
  category="co",
  cjkwd="a",
  description="<Private Use, First>",
  direction="l",
  unicodeslot=0xE000,
 },
 [0xF8FF]={
  adobename="apple",
  category="co",
  cjkwd="a",
  description="<Private Use, Last>",
  direction="l",
  unicodeslot=0xF8FF,
 },
 [0xF900]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0384",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8C48 },
  unicodeslot=0xF900,
 },
 [0xF901]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0385",
  direction="l",
  linebreak="id",
  specials={ "char", 0x66F4 },
  unicodeslot=0xF901,
 },
 [0xF902]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0386",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8ECA },
  unicodeslot=0xF902,
 },
 [0xF903]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0387",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8CC8 },
  unicodeslot=0xF903,
 },
 [0xF904]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0388",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6ED1 },
  unicodeslot=0xF904,
 },
 [0xF905]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0389",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E32 },
  unicodeslot=0xF905,
 },
 [0xF906]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x038A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x53E5 },
  unicodeslot=0xF906,
 },
 [0xF907]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x038B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F9C },
  unicodeslot=0xF907,
 },
 [0xF908]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x038C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F9C },
  unicodeslot=0xF908,
 },
 [0xF909]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x038D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5951 },
  unicodeslot=0xF909,
 },
 [0xF90A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005AA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x91D1 },
  unicodeslot=0xF90A,
 },
 [0xF90B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005AB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5587 },
  unicodeslot=0xF90B,
 },
 [0xF90C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005AC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5948 },
  unicodeslot=0xF90C,
 },
 [0xF90D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005AD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61F6 },
  unicodeslot=0xF90D,
 },
 [0xF90E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005AE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7669 },
  unicodeslot=0xF90E,
 },
 [0xF90F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005AF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7F85 },
  unicodeslot=0xF90F,
 },
 [0xF910]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x038E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x863F },
  unicodeslot=0xF910,
 },
 [0xF911]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x038F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x87BA },
  unicodeslot=0xF911,
 },
 [0xF912]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0390",
  direction="l",
  linebreak="id",
  specials={ "char", 0x88F8 },
  unicodeslot=0xF912,
 },
 [0xF913]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0391",
  direction="l",
  linebreak="id",
  specials={ "char", 0x908F },
  unicodeslot=0xF913,
 },
 [0xF914]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0392",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6A02 },
  unicodeslot=0xF914,
 },
 [0xF915]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0393",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D1B },
  unicodeslot=0xF915,
 },
 [0xF916]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0394",
  direction="l",
  linebreak="id",
  specials={ "char", 0x70D9 },
  unicodeslot=0xF916,
 },
 [0xF917]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0395",
  direction="l",
  linebreak="id",
  specials={ "char", 0x73DE },
  unicodeslot=0xF917,
 },
 [0xF918]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0396",
  direction="l",
  linebreak="id",
  specials={ "char", 0x843D },
  unicodeslot=0xF918,
 },
 [0xF919]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0397",
  direction="l",
  linebreak="id",
  specials={ "char", 0x916A },
  unicodeslot=0xF919,
 },
 [0xF91A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x99F1 },
  unicodeslot=0xF91A,
 },
 [0xF91B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005BB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E82 },
  unicodeslot=0xF91B,
 },
 [0xF91C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005BC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5375 },
  unicodeslot=0xF91C,
 },
 [0xF91D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005BD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6B04 },
  unicodeslot=0xF91D,
 },
 [0xF91E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x721B },
  unicodeslot=0xF91E,
 },
 [0xF91F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005BF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x862D },
  unicodeslot=0xF91F,
 },
 [0xF920]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0398",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9E1E },
  unicodeslot=0xF920,
 },
 [0xF921]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0399",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5D50 },
  unicodeslot=0xF921,
 },
 [0xF922]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x039A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6FEB },
  unicodeslot=0xF922,
 },
 [0xF923]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x039B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x85CD },
  unicodeslot=0xF923,
 },
 [0xF924]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x039C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8964 },
  unicodeslot=0xF924,
 },
 [0xF925]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x039D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x62C9 },
  unicodeslot=0xF925,
 },
 [0xF926]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x039E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x81D8 },
  unicodeslot=0xF926,
 },
 [0xF927]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x039F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x881F },
  unicodeslot=0xF927,
 },
 [0xF928]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5ECA },
  unicodeslot=0xF928,
 },
 [0xF929]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6717 },
  unicodeslot=0xF929,
 },
 [0xF92A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005CA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D6A },
  unicodeslot=0xF92A,
 },
 [0xF92B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005CB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x72FC },
  unicodeslot=0xF92B,
 },
 [0xF92C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005CC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x90CE },
  unicodeslot=0xF92C,
 },
 [0xF92D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005CD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4F86 },
  unicodeslot=0xF92D,
 },
 [0xF92E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005CE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51B7 },
  unicodeslot=0xF92E,
 },
 [0xF92F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005CF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52DE },
  unicodeslot=0xF92F,
 },
 [0xF930]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x64C4 },
  unicodeslot=0xF930,
 },
 [0xF931]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6AD3 },
  unicodeslot=0xF931,
 },
 [0xF932]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7210 },
  unicodeslot=0xF932,
 },
 [0xF933]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x76E7 },
  unicodeslot=0xF933,
 },
 [0xF934]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8001 },
  unicodeslot=0xF934,
 },
 [0xF935]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8606 },
  unicodeslot=0xF935,
 },
 [0xF936]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A8",
  direction="l",
  linebreak="id",
  specials={ "char", 0x865C },
  unicodeslot=0xF936,
 },
 [0xF937]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03A9",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8DEF },
  unicodeslot=0xF937,
 },
 [0xF938]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03AA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9732 },
  unicodeslot=0xF938,
 },
 [0xF939]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03AB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9B6F },
  unicodeslot=0xF939,
 },
 [0xF93A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9DFA },
  unicodeslot=0xF93A,
 },
 [0xF93B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005DB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x788C },
  unicodeslot=0xF93B,
 },
 [0xF93C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005DC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x797F },
  unicodeslot=0xF93C,
 },
 [0xF93D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005DD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7DA0 },
  unicodeslot=0xF93D,
 },
 [0xF93E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83C9 },
  unicodeslot=0xF93E,
 },
 [0xF93F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005DF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9304 },
  unicodeslot=0xF93F,
 },
 [0xF940]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03AC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9E7F },
  unicodeslot=0xF940,
 },
 [0xF941]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03AD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AD6 },
  unicodeslot=0xF941,
 },
 [0xF942]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03AE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x58DF },
  unicodeslot=0xF942,
 },
 [0xF943]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03AF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F04 },
  unicodeslot=0xF943,
 },
 [0xF944]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7C60 },
  unicodeslot=0xF944,
 },
 [0xF945]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x807E },
  unicodeslot=0xF945,
 },
 [0xF946]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7262 },
  unicodeslot=0xF946,
 },
 [0xF947]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x78CA },
  unicodeslot=0xF947,
 },
 [0xF948]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8CC2 },
  unicodeslot=0xF948,
 },
 [0xF949]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96F7 },
  unicodeslot=0xF949,
 },
 [0xF94A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005EA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x58D8 },
  unicodeslot=0xF94A,
 },
 [0xF94B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005EB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C62 },
  unicodeslot=0xF94B,
 },
 [0xF94C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005EC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6A13 },
  unicodeslot=0xF94C,
 },
 [0xF94D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005ED",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6DDA },
  unicodeslot=0xF94D,
 },
 [0xF94E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005EE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6F0F },
  unicodeslot=0xF94E,
 },
 [0xF94F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005EF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7D2F },
  unicodeslot=0xF94F,
 },
 [0xF950]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7E37 },
  unicodeslot=0xF950,
 },
 [0xF951]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x964B },
  unicodeslot=0xF951,
 },
 [0xF952]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B8",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52D2 },
  unicodeslot=0xF952,
 },
 [0xF953]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03B9",
  direction="l",
  linebreak="id",
  specials={ "char", 0x808B },
  unicodeslot=0xF953,
 },
 [0xF954]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51DC },
  unicodeslot=0xF954,
 },
 [0xF955]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03BB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51CC },
  unicodeslot=0xF955,
 },
 [0xF956]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03BC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7A1C },
  unicodeslot=0xF956,
 },
 [0xF957]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03BD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7DBE },
  unicodeslot=0xF957,
 },
 [0xF958]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83F1 },
  unicodeslot=0xF958,
 },
 [0xF959]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03BF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9675 },
  unicodeslot=0xF959,
 },
 [0xF95A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005FA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8B80 },
  unicodeslot=0xF95A,
 },
 [0xF95B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005FB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x62CF },
  unicodeslot=0xF95B,
 },
 [0xF95C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005FC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6A02 },
  unicodeslot=0xF95C,
 },
 [0xF95D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005FD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AFE },
  unicodeslot=0xF95D,
 },
 [0xF95E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005FE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E39 },
  unicodeslot=0xF95E,
 },
 [0xF95F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x005FF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5BE7 },
  unicodeslot=0xF95F,
 },
 [0xF960]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6012 },
  unicodeslot=0xF960,
 },
 [0xF961]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7387 },
  unicodeslot=0xF961,
 },
 [0xF962]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7570 },
  unicodeslot=0xF962,
 },
 [0xF963]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5317 },
  unicodeslot=0xF963,
 },
 [0xF964]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x78FB },
  unicodeslot=0xF964,
 },
 [0xF965]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4FBF },
  unicodeslot=0xF965,
 },
 [0xF966]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5FA9 },
  unicodeslot=0xF966,
 },
 [0xF967]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E0D },
  unicodeslot=0xF967,
 },
 [0xF968]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C8",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6CCC },
  unicodeslot=0xF968,
 },
 [0xF969]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03C9",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6578 },
  unicodeslot=0xF969,
 },
 [0xF96A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0060A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7D22 },
  unicodeslot=0xF96A,
 },
 [0xF96B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0060B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x53C3 },
  unicodeslot=0xF96B,
 },
 [0xF96C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0060C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x585E },
  unicodeslot=0xF96C,
 },
 [0xF96D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0060D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7701 },
  unicodeslot=0xF96D,
 },
 [0xF96E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0060E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8449 },
  unicodeslot=0xF96E,
 },
 [0xF96F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0060F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AAA },
  unicodeslot=0xF96F,
 },
 [0xF970]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03CA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6BBA },
  unicodeslot=0xF970,
 },
 [0xF971]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03CB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8FB0 },
  unicodeslot=0xF971,
 },
 [0xF972]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03CC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6C88 },
  unicodeslot=0xF972,
 },
 [0xF973]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03CD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x62FE },
  unicodeslot=0xF973,
 },
 [0xF974]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03CE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x82E5 },
  unicodeslot=0xF974,
 },
 [0xF975]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03CF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x63A0 },
  unicodeslot=0xF975,
 },
 [0xF976]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7565 },
  unicodeslot=0xF976,
 },
 [0xF977]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4EAE },
  unicodeslot=0xF977,
 },
 [0xF978]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5169 },
  unicodeslot=0xF978,
 },
 [0xF979]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51C9 },
  unicodeslot=0xF979,
 },
 [0xF97A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0061A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6881 },
  unicodeslot=0xF97A,
 },
 [0xF97B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0061B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7CE7 },
  unicodeslot=0xF97B,
 },
 [0xF97C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0061C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x826F },
  unicodeslot=0xF97C,
 },
 [0xF97D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0061D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AD2 },
  unicodeslot=0xF97D,
 },
 [0xF97E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0061E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x91CF },
  unicodeslot=0xF97E,
 },
 [0xF97F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0061F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52F5 },
  unicodeslot=0xF97F,
 },
 [0xF980]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5442 },
  unicodeslot=0xF980,
 },
 [0xF981]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5973 },
  unicodeslot=0xF981,
 },
 [0xF982]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5EEC },
  unicodeslot=0xF982,
 },
 [0xF983]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x65C5 },
  unicodeslot=0xF983,
 },
 [0xF984]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D8",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6FFE },
  unicodeslot=0xF984,
 },
 [0xF985]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03D9",
  direction="l",
  linebreak="id",
  specials={ "char", 0x792A },
  unicodeslot=0xF985,
 },
 [0xF986]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x95AD },
  unicodeslot=0xF986,
 },
 [0xF987]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03DB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9A6A },
  unicodeslot=0xF987,
 },
 [0xF988]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03DC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9E97 },
  unicodeslot=0xF988,
 },
 [0xF989]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03DD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9ECE },
  unicodeslot=0xF989,
 },
 [0xF98A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0062A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x529B },
  unicodeslot=0xF98A,
 },
 [0xF98B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0062B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x66C6 },
  unicodeslot=0xF98B,
 },
 [0xF98C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0062C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6B77 },
  unicodeslot=0xF98C,
 },
 [0xF98D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0062D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8F62 },
  unicodeslot=0xF98D,
 },
 [0xF98E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0062E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5E74 },
  unicodeslot=0xF98E,
 },
 [0xF98F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0062F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6190 },
  unicodeslot=0xF98F,
 },
 [0xF990]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6200 },
  unicodeslot=0xF990,
 },
 [0xF991]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03DF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x649A },
  unicodeslot=0xF991,
 },
 [0xF992]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03E0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6F23 },
  unicodeslot=0xF992,
 },
 [0xF993]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03E1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7149 },
  unicodeslot=0xF993,
 },
 [0xF994]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03E2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7489 },
  unicodeslot=0xF994,
 },
 [0xF995]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03E3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x79CA },
  unicodeslot=0xF995,
 },
 [0xF996]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03E4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7DF4 },
  unicodeslot=0xF996,
 },
 [0xF997]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03E5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x806F },
  unicodeslot=0xF997,
 },
 [0xF998]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03E6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8F26 },
  unicodeslot=0xF998,
 },
 [0xF999]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x03E7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x84EE },
  unicodeslot=0xF999,
 },
 [0xF99A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0063A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9023 },
  unicodeslot=0xF99A,
 },
 [0xF99B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0063B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x934A },
  unicodeslot=0xF99B,
 },
 [0xF99C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0063C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5217 },
  unicodeslot=0xF99C,
 },
 [0xF99D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0063D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52A3 },
  unicodeslot=0xF99D,
 },
 [0xF99E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0063E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x54BD },
  unicodeslot=0xF99E,
 },
 [0xF99F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0063F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x70C8 },
  unicodeslot=0xF99F,
 },
 [0xF9A0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x88C2 },
  unicodeslot=0xF9A0,
 },
 [0xF9A1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AAA },
  unicodeslot=0xF9A1,
 },
 [0xF9A2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5EC9 },
  unicodeslot=0xF9A2,
 },
 [0xF9A3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5FF5 },
  unicodeslot=0xF9A3,
 },
 [0xF9A4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x637B },
  unicodeslot=0xF9A4,
 },
 [0xF9A5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6BAE },
  unicodeslot=0xF9A5,
 },
 [0xF9A6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7C3E },
  unicodeslot=0xF9A6,
 },
 [0xF9A7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7375 },
  unicodeslot=0xF9A7,
 },
 [0xF9A8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4EE4 },
  unicodeslot=0xF9A8,
 },
 [0xF9A9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009A0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x56F9 },
  unicodeslot=0xF9A9,
 },
 [0xF9AA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009AA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5BE7 },
  unicodeslot=0xF9AA,
 },
 [0xF9AB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009AB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5DBA },
  unicodeslot=0xF9AB,
 },
 [0xF9AC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009AC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x601C },
  unicodeslot=0xF9AC,
 },
 [0xF9AD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009AD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x73B2 },
  unicodeslot=0xF9AD,
 },
 [0xF9AE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009AE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7469 },
  unicodeslot=0xF9AE,
 },
 [0xF9AF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009AF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7F9A },
  unicodeslot=0xF9AF,
 },
 [0xF9B0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8046 },
  unicodeslot=0xF9B0,
 },
 [0xF9B1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9234 },
  unicodeslot=0xF9B1,
 },
 [0xF9B2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96F6 },
  unicodeslot=0xF9B2,
 },
 [0xF9B3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9748 },
  unicodeslot=0xF9B3,
 },
 [0xF9B4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9818 },
  unicodeslot=0xF9B4,
 },
 [0xF9B5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4F8B },
  unicodeslot=0xF9B5,
 },
 [0xF9B6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x79AE },
  unicodeslot=0xF9B6,
 },
 [0xF9B7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x91B4 },
  unicodeslot=0xF9B7,
 },
 [0xF9B8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96B8 },
  unicodeslot=0xF9B8,
 },
 [0xF9B9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009B0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x60E1 },
  unicodeslot=0xF9B9,
 },
 [0xF9BA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E86 },
  unicodeslot=0xF9BA,
 },
 [0xF9BB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009BB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x50DA },
  unicodeslot=0xF9BB,
 },
 [0xF9BC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009BC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5BEE },
  unicodeslot=0xF9BC,
 },
 [0xF9BD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009BD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C3F },
  unicodeslot=0xF9BD,
 },
 [0xF9BE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6599 },
  unicodeslot=0xF9BE,
 },
 [0xF9BF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009BF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6A02 },
  unicodeslot=0xF9BF,
 },
 [0xF9C0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x71CE },
  unicodeslot=0xF9C0,
 },
 [0xF9C1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7642 },
  unicodeslot=0xF9C1,
 },
 [0xF9C2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x84FC },
  unicodeslot=0xF9C2,
 },
 [0xF9C3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x907C },
  unicodeslot=0xF9C3,
 },
 [0xF9C4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F8D },
  unicodeslot=0xF9C4,
 },
 [0xF9C5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6688 },
  unicodeslot=0xF9C5,
 },
 [0xF9C6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x962E },
  unicodeslot=0xF9C6,
 },
 [0xF9C7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5289 },
  unicodeslot=0xF9C7,
 },
 [0xF9C8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x677B },
  unicodeslot=0xF9C8,
 },
 [0xF9C9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009C0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x67F3 },
  unicodeslot=0xF9C9,
 },
 [0xF9CA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009CA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D41 },
  unicodeslot=0xF9CA,
 },
 [0xF9CB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009CB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6E9C },
  unicodeslot=0xF9CB,
 },
 [0xF9CC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009CC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7409 },
  unicodeslot=0xF9CC,
 },
 [0xF9CD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009CD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7559 },
  unicodeslot=0xF9CD,
 },
 [0xF9CE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009CE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x786B },
  unicodeslot=0xF9CE,
 },
 [0xF9CF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009CF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7D10 },
  unicodeslot=0xF9CF,
 },
 [0xF9D0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x985E },
  unicodeslot=0xF9D0,
 },
 [0xF9D1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x516D },
  unicodeslot=0xF9D1,
 },
 [0xF9D2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x622E },
  unicodeslot=0xF9D2,
 },
 [0xF9D3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9678 },
  unicodeslot=0xF9D3,
 },
 [0xF9D4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x502B },
  unicodeslot=0xF9D4,
 },
 [0xF9D5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5D19 },
  unicodeslot=0xF9D5,
 },
 [0xF9D6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6DEA },
  unicodeslot=0xF9D6,
 },
 [0xF9D7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8F2A },
  unicodeslot=0xF9D7,
 },
 [0xF9D8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F8B },
  unicodeslot=0xF9D8,
 },
 [0xF9D9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009D0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6144 },
  unicodeslot=0xF9D9,
 },
 [0xF9DA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6817 },
  unicodeslot=0xF9DA,
 },
 [0xF9DB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009DB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7387 },
  unicodeslot=0xF9DB,
 },
 [0xF9DC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009DC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9686 },
  unicodeslot=0xF9DC,
 },
 [0xF9DD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009DD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5229 },
  unicodeslot=0xF9DD,
 },
 [0xF9DE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x540F },
  unicodeslot=0xF9DE,
 },
 [0xF9DF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009DF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C65 },
  unicodeslot=0xF9DF,
 },
 [0xF9E0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6613 },
  unicodeslot=0xF9E0,
 },
 [0xF9E1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x674E },
  unicodeslot=0xF9E1,
 },
 [0xF9E2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x68A8 },
  unicodeslot=0xF9E2,
 },
 [0xF9E3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6CE5 },
  unicodeslot=0xF9E3,
 },
 [0xF9E4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7406 },
  unicodeslot=0xF9E4,
 },
 [0xF9E5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x75E2 },
  unicodeslot=0xF9E5,
 },
 [0xF9E6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7F79 },
  unicodeslot=0xF9E6,
 },
 [0xF9E7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x88CF },
  unicodeslot=0xF9E7,
 },
 [0xF9E8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x88E1 },
  unicodeslot=0xF9E8,
 },
 [0xF9E9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009E0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x91CC },
  unicodeslot=0xF9E9,
 },
 [0xF9EA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009EA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96E2 },
  unicodeslot=0xF9EA,
 },
 [0xF9EB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009EB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x533F },
  unicodeslot=0xF9EB,
 },
 [0xF9EC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009EC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6EBA },
  unicodeslot=0xF9EC,
 },
 [0xF9ED]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009ED",
  direction="l",
  linebreak="id",
  specials={ "char", 0x541D },
  unicodeslot=0xF9ED,
 },
 [0xF9EE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009EE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x71D0 },
  unicodeslot=0xF9EE,
 },
 [0xF9EF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009EF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7498 },
  unicodeslot=0xF9EF,
 },
 [0xF9F0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x85FA },
  unicodeslot=0xF9F0,
 },
 [0xF9F1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96A3 },
  unicodeslot=0xF9F1,
 },
 [0xF9F2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9C57 },
  unicodeslot=0xF9F2,
 },
 [0xF9F3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9E9F },
  unicodeslot=0xF9F3,
 },
 [0xF9F4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6797 },
  unicodeslot=0xF9F4,
 },
 [0xF9F5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6DCB },
  unicodeslot=0xF9F5,
 },
 [0xF9F6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x81E8 },
  unicodeslot=0xF9F6,
 },
 [0xF9F7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7ACB },
  unicodeslot=0xF9F7,
 },
 [0xF9F8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7B20 },
  unicodeslot=0xF9F8,
 },
 [0xF9F9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009F0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7C92 },
  unicodeslot=0xF9F9,
 },
 [0xF9FA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009FA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x72C0 },
  unicodeslot=0xF9FA,
 },
 [0xF9FB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009FB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7099 },
  unicodeslot=0xF9FB,
 },
 [0xF9FC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009FC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8B58 },
  unicodeslot=0xF9FC,
 },
 [0xF9FD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009FD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4EC0 },
  unicodeslot=0xF9FD,
 },
 [0xF9FE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009FE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8336 },
  unicodeslot=0xF9FE,
 },
 [0xF9FF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-F0x0009FF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x523A },
  unicodeslot=0xF9FF,
 },
 [0xFA00]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5207 },
  unicodeslot=0xFA00,
 },
 [0xFA01]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5EA6 },
  unicodeslot=0xFA01,
 },
 [0xFA02]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x62D3 },
  unicodeslot=0xFA02,
 },
 [0xFA03]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7CD6 },
  unicodeslot=0xFA03,
 },
 [0xFA04]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5B85 },
  unicodeslot=0xFA04,
 },
 [0xFA05]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D1E },
  unicodeslot=0xFA05,
 },
 [0xFA06]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x66B4 },
  unicodeslot=0xFA06,
 },
 [0xFA07]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8F3B },
  unicodeslot=0xFA07,
 },
 [0xFA08]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x884C },
  unicodeslot=0xFA08,
 },
 [0xFA09]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x964D },
  unicodeslot=0xFA09,
 },
 [0xFA0A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0000A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x898B },
  unicodeslot=0xFA0A,
 },
 [0xFA0B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0000B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5ED3 },
  unicodeslot=0xFA0B,
 },
 [0xFA0C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0000C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5140 },
  unicodeslot=0xFA0C,
 },
 [0xFA0D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0000D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x55C0 },
  unicodeslot=0xFA0D,
 },
 [0xFA0E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0000E",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA0E,
 },
 [0xFA0F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0000F",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA0F,
 },
 [0xFA10]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x000A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x585A },
  unicodeslot=0xFA10,
 },
 [0xFA11]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x000B",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA11,
 },
 [0xFA12]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x000C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6674 },
  unicodeslot=0xFA12,
 },
 [0xFA13]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x000D",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA13,
 },
 [0xFA14]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x000E",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA14,
 },
 [0xFA15]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x000F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51DE },
  unicodeslot=0xFA15,
 },
 [0xFA16]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0010",
  direction="l",
  linebreak="id",
  specials={ "char", 0x732A },
  unicodeslot=0xFA16,
 },
 [0xFA17]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0011",
  direction="l",
  linebreak="id",
  specials={ "char", 0x76CA },
  unicodeslot=0xFA17,
 },
 [0xFA18]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0012",
  direction="l",
  linebreak="id",
  specials={ "char", 0x793C },
  unicodeslot=0xFA18,
 },
 [0xFA19]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0013",
  direction="l",
  linebreak="id",
  specials={ "char", 0x795E },
  unicodeslot=0xFA19,
 },
 [0xFA1A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0001A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7965 },
  unicodeslot=0xFA1A,
 },
 [0xFA1B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0001B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x798F },
  unicodeslot=0xFA1B,
 },
 [0xFA1C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0001C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9756 },
  unicodeslot=0xFA1C,
 },
 [0xFA1D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0001D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7CBE },
  unicodeslot=0xFA1D,
 },
 [0xFA1E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0001E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7FBD },
  unicodeslot=0xFA1E,
 },
 [0xFA1F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0001F",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA1F,
 },
 [0xFA20]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0014",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8612 },
  unicodeslot=0xFA20,
 },
 [0xFA21]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0015",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA21,
 },
 [0xFA22]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0016",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AF8 },
  unicodeslot=0xFA22,
 },
 [0xFA23]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0017",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA23,
 },
 [0xFA24]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0018",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA24,
 },
 [0xFA25]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0019",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9038 },
  unicodeslot=0xFA25,
 },
 [0xFA26]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x001A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x90FD },
  unicodeslot=0xFA26,
 },
 [0xFA27]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x001B",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA27,
 },
 [0xFA28]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x001C",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA28,
 },
 [0xFA29]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x001D",
  direction="l",
  linebreak="id",
  unicodeslot=0xFA29,
 },
 [0xFA2A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0002A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x98EF },
  unicodeslot=0xFA2A,
 },
 [0xFA2B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0002B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x98FC },
  unicodeslot=0xFA2B,
 },
 [0xFA2C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0002C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9928 },
  unicodeslot=0xFA2C,
 },
 [0xFA2D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0002D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9DB4 },
  unicodeslot=0xFA2D,
 },
 [0xFA2E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA2E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x90DE },
  unicodeslot=0xFA2E,
 },
 [0xFA2F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA2F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96B7 },
  unicodeslot=0xFA2F,
 },
 [0xFA30]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x001E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4FAE },
  unicodeslot=0xFA30,
 },
 [0xFA31]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x001F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x50E7 },
  unicodeslot=0xFA31,
 },
 [0xFA32]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0020",
  direction="l",
  linebreak="id",
  specials={ "char", 0x514D },
  unicodeslot=0xFA32,
 },
 [0xFA33]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0021",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52C9 },
  unicodeslot=0xFA33,
 },
 [0xFA34]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0022",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52E4 },
  unicodeslot=0xFA34,
 },
 [0xFA35]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0023",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5351 },
  unicodeslot=0xFA35,
 },
 [0xFA36]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0024",
  direction="l",
  linebreak="id",
  specials={ "char", 0x559D },
  unicodeslot=0xFA36,
 },
 [0xFA37]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0025",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5606 },
  unicodeslot=0xFA37,
 },
 [0xFA38]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0026",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5668 },
  unicodeslot=0xFA38,
 },
 [0xFA39]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0027",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5840 },
  unicodeslot=0xFA39,
 },
 [0xFA3A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0003A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x58A8 },
  unicodeslot=0xFA3A,
 },
 [0xFA3B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0003B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C64 },
  unicodeslot=0xFA3B,
 },
 [0xFA3C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0003C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C6E },
  unicodeslot=0xFA3C,
 },
 [0xFA3D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0003D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6094 },
  unicodeslot=0xFA3D,
 },
 [0xFA3E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0003E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6168 },
  unicodeslot=0xFA3E,
 },
 [0xFA3F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0003F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x618E },
  unicodeslot=0xFA3F,
 },
 [0xFA40]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0028",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61F2 },
  unicodeslot=0xFA40,
 },
 [0xFA41]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0029",
  direction="l",
  linebreak="id",
  specials={ "char", 0x654F },
  unicodeslot=0xFA41,
 },
 [0xFA42]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x002A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x65E2 },
  unicodeslot=0xFA42,
 },
 [0xFA43]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x002B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6691 },
  unicodeslot=0xFA43,
 },
 [0xFA44]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x002C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6885 },
  unicodeslot=0xFA44,
 },
 [0xFA45]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x002D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D77 },
  unicodeslot=0xFA45,
 },
 [0xFA46]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x002E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6E1A },
  unicodeslot=0xFA46,
 },
 [0xFA47]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x002F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6F22 },
  unicodeslot=0xFA47,
 },
 [0xFA48]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0030",
  direction="l",
  linebreak="id",
  specials={ "char", 0x716E },
  unicodeslot=0xFA48,
 },
 [0xFA49]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0031",
  direction="l",
  linebreak="id",
  specials={ "char", 0x722B },
  unicodeslot=0xFA49,
 },
 [0xFA4A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0004A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7422 },
  unicodeslot=0xFA4A,
 },
 [0xFA4B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0004B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7891 },
  unicodeslot=0xFA4B,
 },
 [0xFA4C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0004C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x793E },
  unicodeslot=0xFA4C,
 },
 [0xFA4D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0004D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7949 },
  unicodeslot=0xFA4D,
 },
 [0xFA4E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0004E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7948 },
  unicodeslot=0xFA4E,
 },
 [0xFA4F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0004F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7950 },
  unicodeslot=0xFA4F,
 },
 [0xFA50]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0032",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7956 },
  unicodeslot=0xFA50,
 },
 [0xFA51]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0033",
  direction="l",
  linebreak="id",
  specials={ "char", 0x795D },
  unicodeslot=0xFA51,
 },
 [0xFA52]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0034",
  direction="l",
  linebreak="id",
  specials={ "char", 0x798D },
  unicodeslot=0xFA52,
 },
 [0xFA53]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0035",
  direction="l",
  linebreak="id",
  specials={ "char", 0x798E },
  unicodeslot=0xFA53,
 },
 [0xFA54]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0036",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7A40 },
  unicodeslot=0xFA54,
 },
 [0xFA55]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0037",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7A81 },
  unicodeslot=0xFA55,
 },
 [0xFA56]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0038",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7BC0 },
  unicodeslot=0xFA56,
 },
 [0xFA57]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0039",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7DF4 },
  unicodeslot=0xFA57,
 },
 [0xFA58]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x003A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7E09 },
  unicodeslot=0xFA58,
 },
 [0xFA59]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x003B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7E41 },
  unicodeslot=0xFA59,
 },
 [0xFA5A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0005A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7F72 },
  unicodeslot=0xFA5A,
 },
 [0xFA5B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0005B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8005 },
  unicodeslot=0xFA5B,
 },
 [0xFA5C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0005C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x81ED },
  unicodeslot=0xFA5C,
 },
 [0xFA5D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0005D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8279 },
  unicodeslot=0xFA5D,
 },
 [0xFA5E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0005E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8279 },
  unicodeslot=0xFA5E,
 },
 [0xFA5F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0005F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8457 },
  unicodeslot=0xFA5F,
 },
 [0xFA60]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x003C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8910 },
  unicodeslot=0xFA60,
 },
 [0xFA61]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x003D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8996 },
  unicodeslot=0xFA61,
 },
 [0xFA62]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x003E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8B01 },
  unicodeslot=0xFA62,
 },
 [0xFA63]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x003F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8B39 },
  unicodeslot=0xFA63,
 },
 [0xFA64]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0040",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8CD3 },
  unicodeslot=0xFA64,
 },
 [0xFA65]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0041",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8D08 },
  unicodeslot=0xFA65,
 },
 [0xFA66]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0042",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8FB6 },
  unicodeslot=0xFA66,
 },
 [0xFA67]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0043",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9038 },
  unicodeslot=0xFA67,
 },
 [0xFA68]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0044",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96E3 },
  unicodeslot=0xFA68,
 },
 [0xFA69]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0045",
  direction="l",
  linebreak="id",
  specials={ "char", 0x97FF },
  unicodeslot=0xFA69,
 },
 [0xFA6A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0006A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x983B },
  unicodeslot=0xFA6A,
 },
 [0xFA6B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA6B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6075 },
  unicodeslot=0xFA6B,
 },
 [0xFA6C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA6C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x242EE },
  unicodeslot=0xFA6C,
 },
 [0xFA6D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA6D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8218 },
  unicodeslot=0xFA6D,
 },
 [0xFA70]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0046",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E26 },
  unicodeslot=0xFA70,
 },
 [0xFA71]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0047",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51B5 },
  unicodeslot=0xFA71,
 },
 [0xFA72]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0048",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5168 },
  unicodeslot=0xFA72,
 },
 [0xFA73]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0049",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4F80 },
  unicodeslot=0xFA73,
 },
 [0xFA74]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x004A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5145 },
  unicodeslot=0xFA74,
 },
 [0xFA75]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x004B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5180 },
  unicodeslot=0xFA75,
 },
 [0xFA76]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x004C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52C7 },
  unicodeslot=0xFA76,
 },
 [0xFA77]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x004D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52FA },
  unicodeslot=0xFA77,
 },
 [0xFA78]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x004E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x559D },
  unicodeslot=0xFA78,
 },
 [0xFA79]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x004F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5555 },
  unicodeslot=0xFA79,
 },
 [0xFA7A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0007A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5599 },
  unicodeslot=0xFA7A,
 },
 [0xFA7B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0007B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x55E2 },
  unicodeslot=0xFA7B,
 },
 [0xFA7C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0007C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x585A },
  unicodeslot=0xFA7C,
 },
 [0xFA7D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0007D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x58B3 },
  unicodeslot=0xFA7D,
 },
 [0xFA7E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0007E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5944 },
  unicodeslot=0xFA7E,
 },
 [0xFA7F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0007F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5954 },
  unicodeslot=0xFA7F,
 },
 [0xFA80]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0050",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5A62 },
  unicodeslot=0xFA80,
 },
 [0xFA81]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0051",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5B28 },
  unicodeslot=0xFA81,
 },
 [0xFA82]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0052",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5ED2 },
  unicodeslot=0xFA82,
 },
 [0xFA83]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0053",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5ED9 },
  unicodeslot=0xFA83,
 },
 [0xFA84]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0054",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F69 },
  unicodeslot=0xFA84,
 },
 [0xFA85]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0055",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5FAD },
  unicodeslot=0xFA85,
 },
 [0xFA86]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0056",
  direction="l",
  linebreak="id",
  specials={ "char", 0x60D8 },
  unicodeslot=0xFA86,
 },
 [0xFA87]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0057",
  direction="l",
  linebreak="id",
  specials={ "char", 0x614E },
  unicodeslot=0xFA87,
 },
 [0xFA88]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0058",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6108 },
  unicodeslot=0xFA88,
 },
 [0xFA89]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0059",
  direction="l",
  linebreak="id",
  specials={ "char", 0x618E },
  unicodeslot=0xFA89,
 },
 [0xFA8A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0008A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6160 },
  unicodeslot=0xFA8A,
 },
 [0xFA8B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0008B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61F2 },
  unicodeslot=0xFA8B,
 },
 [0xFA8C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0008C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6234 },
  unicodeslot=0xFA8C,
 },
 [0xFA8D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0008D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x63C4 },
  unicodeslot=0xFA8D,
 },
 [0xFA8E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0008E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x641C },
  unicodeslot=0xFA8E,
 },
 [0xFA8F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0008F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6452 },
  unicodeslot=0xFA8F,
 },
 [0xFA90]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x005A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6556 },
  unicodeslot=0xFA90,
 },
 [0xFA91]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x005B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6674 },
  unicodeslot=0xFA91,
 },
 [0xFA92]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x005C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6717 },
  unicodeslot=0xFA92,
 },
 [0xFA93]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x005D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x671B },
  unicodeslot=0xFA93,
 },
 [0xFA94]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x005E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6756 },
  unicodeslot=0xFA94,
 },
 [0xFA95]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x005F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6B79 },
  unicodeslot=0xFA95,
 },
 [0xFA96]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0060",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6BBA },
  unicodeslot=0xFA96,
 },
 [0xFA97]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0061",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D41 },
  unicodeslot=0xFA97,
 },
 [0xFA98]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0062",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6EDB },
  unicodeslot=0xFA98,
 },
 [0xFA99]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0063",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6ECB },
  unicodeslot=0xFA99,
 },
 [0xFA9A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0009A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6F22 },
  unicodeslot=0xFA9A,
 },
 [0xFA9B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0009B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x701E },
  unicodeslot=0xFA9B,
 },
 [0xFA9C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0009C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x716E },
  unicodeslot=0xFA9C,
 },
 [0xFA9D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0009D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x77A7 },
  unicodeslot=0xFA9D,
 },
 [0xFA9E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0009E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7235 },
  unicodeslot=0xFA9E,
 },
 [0xFA9F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FA0x0009F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x72AF },
  unicodeslot=0xFA9F,
 },
 [0xFAA0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x732A },
  unicodeslot=0xFAA0,
 },
 [0xFAA1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7471 },
  unicodeslot=0xFAA1,
 },
 [0xFAA2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7506 },
  unicodeslot=0xFAA2,
 },
 [0xFAA3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x753B },
  unicodeslot=0xFAA3,
 },
 [0xFAA4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x761D },
  unicodeslot=0xFAA4,
 },
 [0xFAA5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x761F },
  unicodeslot=0xFAA5,
 },
 [0xFAA6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x76CA },
  unicodeslot=0xFAA6,
 },
 [0xFAA7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x76DB },
  unicodeslot=0xFAA7,
 },
 [0xFAA8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x76F4 },
  unicodeslot=0xFAA8,
 },
 [0xFAA9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAA0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x774A },
  unicodeslot=0xFAA9,
 },
 [0xFAAA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAAA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7740 },
  unicodeslot=0xFAAA,
 },
 [0xFAAB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAAB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x78CC },
  unicodeslot=0xFAAB,
 },
 [0xFAAC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAAC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7AB1 },
  unicodeslot=0xFAAC,
 },
 [0xFAAD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAAD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7BC0 },
  unicodeslot=0xFAAD,
 },
 [0xFAAE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAAE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7C7B },
  unicodeslot=0xFAAE,
 },
 [0xFAAF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAAF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7D5B },
  unicodeslot=0xFAAF,
 },
 [0xFAB0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7DF4 },
  unicodeslot=0xFAB0,
 },
 [0xFAB1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7F3E },
  unicodeslot=0xFAB1,
 },
 [0xFAB2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8005 },
  unicodeslot=0xFAB2,
 },
 [0xFAB3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8352 },
  unicodeslot=0xFAB3,
 },
 [0xFAB4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83EF },
  unicodeslot=0xFAB4,
 },
 [0xFAB5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8779 },
  unicodeslot=0xFAB5,
 },
 [0xFAB6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8941 },
  unicodeslot=0xFAB6,
 },
 [0xFAB7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8986 },
  unicodeslot=0xFAB7,
 },
 [0xFAB8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8996 },
  unicodeslot=0xFAB8,
 },
 [0xFAB9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAB0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8ABF },
  unicodeslot=0xFAB9,
 },
 [0xFABA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FABA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AF8 },
  unicodeslot=0xFABA,
 },
 [0xFABB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FABB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8ACB },
  unicodeslot=0xFABB,
 },
 [0xFABC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FABC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8B01 },
  unicodeslot=0xFABC,
 },
 [0xFABD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FABD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AFE },
  unicodeslot=0xFABD,
 },
 [0xFABE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FABE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AED },
  unicodeslot=0xFABE,
 },
 [0xFABF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FABF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8B39 },
  unicodeslot=0xFABF,
 },
 [0xFAC0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8B8A },
  unicodeslot=0xFAC0,
 },
 [0xFAC1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8D08 },
  unicodeslot=0xFAC1,
 },
 [0xFAC2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8F38 },
  unicodeslot=0xFAC2,
 },
 [0xFAC3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9072 },
  unicodeslot=0xFAC3,
 },
 [0xFAC4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9199 },
  unicodeslot=0xFAC4,
 },
 [0xFAC5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9276 },
  unicodeslot=0xFAC5,
 },
 [0xFAC6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x967C },
  unicodeslot=0xFAC6,
 },
 [0xFAC7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96E3 },
  unicodeslot=0xFAC7,
 },
 [0xFAC8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9756 },
  unicodeslot=0xFAC8,
 },
 [0xFAC9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAC0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x97DB },
  unicodeslot=0xFAC9,
 },
 [0xFACA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FACA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x97FF },
  unicodeslot=0xFACA,
 },
 [0xFACB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FACB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x980B },
  unicodeslot=0xFACB,
 },
 [0xFACC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FACC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x983B },
  unicodeslot=0xFACC,
 },
 [0xFACD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FACD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9B12 },
  unicodeslot=0xFACD,
 },
 [0xFACE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FACE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F9C },
  unicodeslot=0xFACE,
 },
 [0xFACF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FACF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2284A },
  unicodeslot=0xFACF,
 },
 [0xFAD0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x22844 },
  unicodeslot=0xFAD0,
 },
 [0xFAD1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x233D5 },
  unicodeslot=0xFAD1,
 },
 [0xFAD2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3B9D },
  unicodeslot=0xFAD2,
 },
 [0xFAD3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4018 },
  unicodeslot=0xFAD3,
 },
 [0xFAD4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4039 },
  unicodeslot=0xFAD4,
 },
 [0xFAD5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25249 },
  unicodeslot=0xFAD5,
 },
 [0xFAD6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25CD0 },
  unicodeslot=0xFAD6,
 },
 [0xFAD7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x27ED3 },
  unicodeslot=0xFAD7,
 },
 [0xFAD8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F43 },
  unicodeslot=0xFAD8,
 },
 [0xFAD9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-FAD0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F8E },
  unicodeslot=0xFAD9,
 },
 [0xFB00]={
  adobename="ff",
  category="ll",
  contextname="ffligature",
  description="LATIN SMALL LIGATURE FF",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0066, 0x0066 },
  unicodeslot=0xFB00,
 },
 [0xFB01]={
  adobename="fi",
  category="ll",
  contextname="filigature",
  description="LATIN SMALL LIGATURE FI",
  direction="l",
  linebreak="al",
  shcode={ 0x0066, 0x0069 },
  specials={ "compat", 0x0066, 0x0069 },
  unicodeslot=0xFB01,
 },
 [0xFB02]={
  adobename="fl",
  category="ll",
  contextname="flligature",
  description="LATIN SMALL LIGATURE FL",
  direction="l",
  linebreak="al",
  shcode={ 0x0066, 0x006C },
  specials={ "compat", 0x0066, 0x006C },
  unicodeslot=0xFB02,
 },
 [0xFB03]={
  adobename="ffi",
  category="ll",
  contextname="ffiligature",
  description="LATIN SMALL LIGATURE FFI",
  direction="l",
  linebreak="al",
  shcode={ 0x0066, 0x0069 },
  specials={ "compat", 0x0066, 0x0066, 0x0069 },
  unicodeslot=0xFB03,
 },
 [0xFB04]={
  adobename="ffl",
  category="ll",
  contextname="fflligature",
  description="LATIN SMALL LIGATURE FFL",
  direction="l",
  linebreak="al",
  shcode={ 0x0066, 0x006C },
  specials={ "compat", 0x0066, 0x0066, 0x006C },
  unicodeslot=0xFB04,
 },
 [0xFB05]={
  category="ll",
  description="LATIN SMALL LIGATURE LONG S T",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x017F, 0x0074 },
  unicodeslot=0xFB05,
 },
 [0xFB06]={
  category="ll",
  contextname="stligature",
  description="LATIN SMALL LIGATURE ST",
  direction="l",
  linebreak="al",
  shcode={ 0x0073, 0x0074 },
  specials={ "compat", 0x0073, 0x0074 },
  unicodeslot=0xFB06,
 },
 [0xFB13]={
  category="ll",
  description="ARMENIAN SMALL LIGATURE MEN NOW",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0574, 0x0576 },
  unicodeslot=0xFB13,
 },
 [0xFB14]={
  category="ll",
  description="ARMENIAN SMALL LIGATURE MEN ECH",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0574, 0x0565 },
  unicodeslot=0xFB14,
 },
 [0xFB15]={
  category="ll",
  description="ARMENIAN SMALL LIGATURE MEN INI",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0574, 0x056B },
  unicodeslot=0xFB15,
 },
 [0xFB16]={
  category="ll",
  description="ARMENIAN SMALL LIGATURE VEW NOW",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x057E, 0x0576 },
  unicodeslot=0xFB16,
 },
 [0xFB17]={
  category="ll",
  description="ARMENIAN SMALL LIGATURE MEN XEH",
  direction="l",
  linebreak="al",
  specials={ "compat", 0x0574, 0x056D },
  unicodeslot=0xFB17,
 },
 [0xFB1D]={
  category="lo",
  description="HEBREW LETTER YOD WITH HIRIQ",
  direction="r",
  linebreak="hl",
  shcode=0x05D9,
  specials={ "char", 0x05D9, 0x05B4 },
  unicodeslot=0xFB1D,
 },
 [0xFB1E]={
  category="mn",
  description="HEBREW POINT JUDEO-SPANISH VARIKA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFB1E,
 },
 [0xFB1F]={
  adobename="yodyodpatahhebrew",
  category="lo",
  description="HEBREW LIGATURE YIDDISH YOD YOD PATAH",
  direction="r",
  linebreak="hl",
  specials={ "char", 0x05F2, 0x05B7 },
  unicodeslot=0xFB1F,
 },
 [0xFB20]={
  adobename="ayinaltonehebrew",
  category="lo",
  description="HEBREW LETTER ALTERNATIVE AYIN",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05E2 },
  unicodeslot=0xFB20,
 },
 [0xFB21]={
  category="lo",
  description="HEBREW LETTER WIDE ALEF",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05D0 },
  unicodeslot=0xFB21,
 },
 [0xFB22]={
  category="lo",
  description="HEBREW LETTER WIDE DALET",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05D3 },
  unicodeslot=0xFB22,
 },
 [0xFB23]={
  category="lo",
  description="HEBREW LETTER WIDE HE",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05D4 },
  unicodeslot=0xFB23,
 },
 [0xFB24]={
  category="lo",
  description="HEBREW LETTER WIDE KAF",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05DB },
  unicodeslot=0xFB24,
 },
 [0xFB25]={
  category="lo",
  description="HEBREW LETTER WIDE LAMED",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05DC },
  unicodeslot=0xFB25,
 },
 [0xFB26]={
  category="lo",
  description="HEBREW LETTER WIDE FINAL MEM",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05DD },
  unicodeslot=0xFB26,
 },
 [0xFB27]={
  category="lo",
  description="HEBREW LETTER WIDE RESH",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05E8 },
  unicodeslot=0xFB27,
 },
 [0xFB28]={
  category="lo",
  description="HEBREW LETTER WIDE TAV",
  direction="r",
  linebreak="hl",
  specials={ "font", 0x05EA },
  unicodeslot=0xFB28,
 },
 [0xFB29]={
  category="sm",
  description="HEBREW LETTER ALTERNATIVE PLUS SIGN",
  direction="es",
  linebreak="al",
  specials={ "font", 0x002B },
  unicodeslot=0xFB29,
 },
 [0xFB2A]={
  adobename="shinshindothebrew",
  category="lo",
  description="HEBREW LETTER SHIN WITH SHIN DOT",
  direction="r",
  linebreak="hl",
  shcode=0x05E9,
  specials={ "char", 0x05E9, 0x05C1 },
  unicodeslot=0xFB2A,
 },
 [0xFB2B]={
  adobename="shinsindothebrew",
  category="lo",
  description="HEBREW LETTER SHIN WITH SIN DOT",
  direction="r",
  linebreak="hl",
  shcode=0x05E9,
  specials={ "char", 0x05E9, 0x05C2 },
  unicodeslot=0xFB2B,
 },
 [0xFB2C]={
  adobename="shindageshshindothebrew",
  category="lo",
  description="HEBREW LETTER SHIN WITH DAGESH AND SHIN DOT",
  direction="r",
  linebreak="hl",
  shcode=0x05E9,
  specials={ "char", 0xFB49, 0x05C1 },
  unicodeslot=0xFB2C,
 },
 [0xFB2D]={
  adobename="shindageshsindothebrew",
  category="lo",
  description="HEBREW LETTER SHIN WITH DAGESH AND SIN DOT",
  direction="r",
  linebreak="hl",
  shcode=0x05E9,
  specials={ "char", 0xFB49, 0x05C2 },
  unicodeslot=0xFB2D,
 },
 [0xFB2E]={
  adobename="alefpatahhebrew",
  category="lo",
  description="HEBREW LETTER ALEF WITH PATAH",
  direction="r",
  linebreak="hl",
  shcode=0x05D0,
  specials={ "char", 0x05D0, 0x05B7 },
  unicodeslot=0xFB2E,
 },
 [0xFB2F]={
  adobename="alefqamatshebrew",
  category="lo",
  description="HEBREW LETTER ALEF WITH QAMATS",
  direction="r",
  linebreak="hl",
  shcode=0x05D0,
  specials={ "char", 0x05D0, 0x05B8 },
  unicodeslot=0xFB2F,
 },
 [0xFB30]={
  adobename="alefdageshhebrew",
  category="lo",
  description="HEBREW LETTER ALEF WITH MAPIQ",
  direction="r",
  linebreak="hl",
  shcode=0x05D0,
  specials={ "char", 0x05D0, 0x05BC },
  unicodeslot=0xFB30,
 },
 [0xFB31]={
  adobename="betdageshhebrew",
  category="lo",
  description="HEBREW LETTER BET WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05D1,
  specials={ "char", 0x05D1, 0x05BC },
  unicodeslot=0xFB31,
 },
 [0xFB32]={
  adobename="gimeldageshhebrew",
  category="lo",
  description="HEBREW LETTER GIMEL WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05D2,
  specials={ "char", 0x05D2, 0x05BC },
  unicodeslot=0xFB32,
 },
 [0xFB33]={
  adobename="daletdageshhebrew",
  category="lo",
  description="HEBREW LETTER DALET WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05D3,
  specials={ "char", 0x05D3, 0x05BC },
  unicodeslot=0xFB33,
 },
 [0xFB34]={
  adobename="hedageshhebrew",
  category="lo",
  description="HEBREW LETTER HE WITH MAPIQ",
  direction="r",
  linebreak="hl",
  shcode=0x05D4,
  specials={ "char", 0x05D4, 0x05BC },
  unicodeslot=0xFB34,
 },
 [0xFB35]={
  adobename="vavdageshhebrew",
  category="lo",
  description="HEBREW LETTER VAV WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05D5,
  specials={ "char", 0x05D5, 0x05BC },
  unicodeslot=0xFB35,
 },
 [0xFB36]={
  adobename="zayindageshhebrew",
  category="lo",
  description="HEBREW LETTER ZAYIN WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05D6,
  specials={ "char", 0x05D6, 0x05BC },
  unicodeslot=0xFB36,
 },
 [0xFB38]={
  adobename="tetdageshhebrew",
  category="lo",
  description="HEBREW LETTER TET WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05D8,
  specials={ "char", 0x05D8, 0x05BC },
  unicodeslot=0xFB38,
 },
 [0xFB39]={
  adobename="yoddageshhebrew",
  category="lo",
  description="HEBREW LETTER YOD WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05D9,
  specials={ "char", 0x05D9, 0x05BC },
  unicodeslot=0xFB39,
 },
 [0xFB3A]={
  adobename="finalkafdageshhebrew",
  category="lo",
  description="HEBREW LETTER FINAL KAF WITH DAGESH",
  direction="r",
  linebreak="hl",
  specials={ "char", 0x05DA, 0x05BC },
  unicodeslot=0xFB3A,
 },
 [0xFB3B]={
  adobename="kafdageshhebrew",
  category="lo",
  description="HEBREW LETTER KAF WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05DB,
  specials={ "char", 0x05DB, 0x05BC },
  unicodeslot=0xFB3B,
 },
 [0xFB3C]={
  adobename="lameddageshhebrew",
  category="lo",
  description="HEBREW LETTER LAMED WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05DC,
  specials={ "char", 0x05DC, 0x05BC },
  unicodeslot=0xFB3C,
 },
 [0xFB3E]={
  adobename="memdageshhebrew",
  category="lo",
  description="HEBREW LETTER MEM WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05DE,
  specials={ "char", 0x05DE, 0x05BC },
  unicodeslot=0xFB3E,
 },
 [0xFB40]={
  adobename="nundageshhebrew",
  category="lo",
  description="HEBREW LETTER NUN WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05E0,
  specials={ "char", 0x05E0, 0x05BC },
  unicodeslot=0xFB40,
 },
 [0xFB41]={
  adobename="samekhdageshhebrew",
  category="lo",
  description="HEBREW LETTER SAMEKH WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05E1,
  specials={ "char", 0x05E1, 0x05BC },
  unicodeslot=0xFB41,
 },
 [0xFB43]={
  adobename="pefinaldageshhebrew",
  category="lo",
  description="HEBREW LETTER FINAL PE WITH DAGESH",
  direction="r",
  linebreak="hl",
  specials={ "char", 0x05E3, 0x05BC },
  unicodeslot=0xFB43,
 },
 [0xFB44]={
  adobename="pedageshhebrew",
  category="lo",
  description="HEBREW LETTER PE WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05E4,
  specials={ "char", 0x05E4, 0x05BC },
  unicodeslot=0xFB44,
 },
 [0xFB46]={
  adobename="tsadidageshhebrew",
  category="lo",
  description="HEBREW LETTER TSADI WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05E6,
  specials={ "char", 0x05E6, 0x05BC },
  unicodeslot=0xFB46,
 },
 [0xFB47]={
  adobename="qofdageshhebrew",
  category="lo",
  description="HEBREW LETTER QOF WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05E7,
  specials={ "char", 0x05E7, 0x05BC },
  unicodeslot=0xFB47,
 },
 [0xFB48]={
  adobename="reshdageshhebrew",
  category="lo",
  description="HEBREW LETTER RESH WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05E8,
  specials={ "char", 0x05E8, 0x05BC },
  unicodeslot=0xFB48,
 },
 [0xFB49]={
  adobename="shindageshhebrew",
  category="lo",
  description="HEBREW LETTER SHIN WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05E9,
  specials={ "char", 0x05E9, 0x05BC },
  unicodeslot=0xFB49,
 },
 [0xFB4A]={
  adobename="tavdageshhebrew",
  category="lo",
  description="HEBREW LETTER TAV WITH DAGESH",
  direction="r",
  linebreak="hl",
  shcode=0x05EA,
  specials={ "char", 0x05EA, 0x05BC },
  unicodeslot=0xFB4A,
 },
 [0xFB4B]={
  adobename="vavholamhebrew",
  category="lo",
  description="HEBREW LETTER VAV WITH HOLAM",
  direction="r",
  linebreak="hl",
  shcode=0x05D5,
  specials={ "char", 0x05D5, 0x05B9 },
  unicodeslot=0xFB4B,
 },
 [0xFB4C]={
  adobename="betrafehebrew",
  category="lo",
  description="HEBREW LETTER BET WITH RAFE",
  direction="r",
  linebreak="hl",
  shcode=0x05D1,
  specials={ "char", 0x05D1, 0x05BF },
  unicodeslot=0xFB4C,
 },
 [0xFB4D]={
  adobename="kafrafehebrew",
  category="lo",
  description="HEBREW LETTER KAF WITH RAFE",
  direction="r",
  linebreak="hl",
  shcode=0x05DB,
  specials={ "char", 0x05DB, 0x05BF },
  unicodeslot=0xFB4D,
 },
 [0xFB4E]={
  adobename="perafehebrew",
  category="lo",
  description="HEBREW LETTER PE WITH RAFE",
  direction="r",
  linebreak="hl",
  shcode=0x05E4,
  specials={ "char", 0x05E4, 0x05BF },
  unicodeslot=0xFB4E,
 },
 [0xFB4F]={
  adobename="aleflamedhebrew",
  category="lo",
  description="HEBREW LIGATURE ALEF LAMED",
  direction="r",
  linebreak="hl",
  specials={ "compat", 0x05D0, 0x05DC },
  unicodeslot=0xFB4F,
 },
 [0xFB50]={
  category="lo",
  description="ARABIC LETTER ALEF WASLA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0671 },
  unicodeslot=0xFB50,
 },
 [0xFB51]={
  category="lo",
  description="ARABIC LETTER ALEF WASLA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0671 },
  unicodeslot=0xFB51,
 },
 [0xFB52]={
  category="lo",
  description="ARABIC LETTER BEEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x067B },
  unicodeslot=0xFB52,
 },
 [0xFB53]={
  category="lo",
  description="ARABIC LETTER BEEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x067B },
  unicodeslot=0xFB53,
 },
 [0xFB54]={
  category="lo",
  description="ARABIC LETTER BEEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x067B },
  unicodeslot=0xFB54,
 },
 [0xFB55]={
  category="lo",
  description="ARABIC LETTER BEEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x067B },
  unicodeslot=0xFB55,
 },
 [0xFB56]={
  category="lo",
  description="ARABIC LETTER PEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x067E },
  unicodeslot=0xFB56,
 },
 [0xFB57]={
  adobename="pehfinalarabic",
  category="lo",
  description="ARABIC LETTER PEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x067E },
  unicodeslot=0xFB57,
 },
 [0xFB58]={
  adobename="pehinitialarabic",
  category="lo",
  description="ARABIC LETTER PEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x067E },
  unicodeslot=0xFB58,
 },
 [0xFB59]={
  adobename="pehmedialarabic",
  category="lo",
  description="ARABIC LETTER PEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x067E },
  unicodeslot=0xFB59,
 },
 [0xFB5A]={
  category="lo",
  description="ARABIC LETTER BEHEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0680 },
  unicodeslot=0xFB5A,
 },
 [0xFB5B]={
  category="lo",
  description="ARABIC LETTER BEHEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0680 },
  unicodeslot=0xFB5B,
 },
 [0xFB5C]={
  category="lo",
  description="ARABIC LETTER BEHEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0680 },
  unicodeslot=0xFB5C,
 },
 [0xFB5D]={
  category="lo",
  description="ARABIC LETTER BEHEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0680 },
  unicodeslot=0xFB5D,
 },
 [0xFB5E]={
  category="lo",
  description="ARABIC LETTER TTEHEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x067A },
  unicodeslot=0xFB5E,
 },
 [0xFB5F]={
  category="lo",
  description="ARABIC LETTER TTEHEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x067A },
  unicodeslot=0xFB5F,
 },
 [0xFB60]={
  category="lo",
  description="ARABIC LETTER TTEHEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x067A },
  unicodeslot=0xFB60,
 },
 [0xFB61]={
  category="lo",
  description="ARABIC LETTER TTEHEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x067A },
  unicodeslot=0xFB61,
 },
 [0xFB62]={
  category="lo",
  description="ARABIC LETTER TEHEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x067F },
  unicodeslot=0xFB62,
 },
 [0xFB63]={
  category="lo",
  description="ARABIC LETTER TEHEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x067F },
  unicodeslot=0xFB63,
 },
 [0xFB64]={
  category="lo",
  description="ARABIC LETTER TEHEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x067F },
  unicodeslot=0xFB64,
 },
 [0xFB65]={
  category="lo",
  description="ARABIC LETTER TEHEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x067F },
  unicodeslot=0xFB65,
 },
 [0xFB66]={
  category="lo",
  description="ARABIC LETTER TTEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0679 },
  unicodeslot=0xFB66,
 },
 [0xFB67]={
  adobename="ttehfinalarabic",
  category="lo",
  description="ARABIC LETTER TTEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0679 },
  unicodeslot=0xFB67,
 },
 [0xFB68]={
  adobename="ttehinitialarabic",
  category="lo",
  description="ARABIC LETTER TTEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0679 },
  unicodeslot=0xFB68,
 },
 [0xFB69]={
  adobename="ttehmedialarabic",
  category="lo",
  description="ARABIC LETTER TTEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0679 },
  unicodeslot=0xFB69,
 },
 [0xFB6A]={
  category="lo",
  description="ARABIC LETTER VEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06A4 },
  unicodeslot=0xFB6A,
 },
 [0xFB6B]={
  adobename="vehfinalarabic",
  category="lo",
  description="ARABIC LETTER VEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06A4 },
  unicodeslot=0xFB6B,
 },
 [0xFB6C]={
  adobename="vehinitialarabic",
  category="lo",
  description="ARABIC LETTER VEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06A4 },
  unicodeslot=0xFB6C,
 },
 [0xFB6D]={
  adobename="vehmedialarabic",
  category="lo",
  description="ARABIC LETTER VEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06A4 },
  unicodeslot=0xFB6D,
 },
 [0xFB6E]={
  category="lo",
  description="ARABIC LETTER PEHEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06A6 },
  unicodeslot=0xFB6E,
 },
 [0xFB6F]={
  category="lo",
  description="ARABIC LETTER PEHEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06A6 },
  unicodeslot=0xFB6F,
 },
 [0xFB70]={
  category="lo",
  description="ARABIC LETTER PEHEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06A6 },
  unicodeslot=0xFB70,
 },
 [0xFB71]={
  category="lo",
  description="ARABIC LETTER PEHEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06A6 },
  unicodeslot=0xFB71,
 },
 [0xFB72]={
  category="lo",
  description="ARABIC LETTER DYEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0684 },
  unicodeslot=0xFB72,
 },
 [0xFB73]={
  category="lo",
  description="ARABIC LETTER DYEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0684 },
  unicodeslot=0xFB73,
 },
 [0xFB74]={
  category="lo",
  description="ARABIC LETTER DYEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0684 },
  unicodeslot=0xFB74,
 },
 [0xFB75]={
  category="lo",
  description="ARABIC LETTER DYEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0684 },
  unicodeslot=0xFB75,
 },
 [0xFB76]={
  category="lo",
  description="ARABIC LETTER NYEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0683 },
  unicodeslot=0xFB76,
 },
 [0xFB77]={
  category="lo",
  description="ARABIC LETTER NYEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0683 },
  unicodeslot=0xFB77,
 },
 [0xFB78]={
  category="lo",
  description="ARABIC LETTER NYEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0683 },
  unicodeslot=0xFB78,
 },
 [0xFB79]={
  category="lo",
  description="ARABIC LETTER NYEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0683 },
  unicodeslot=0xFB79,
 },
 [0xFB7A]={
  category="lo",
  description="ARABIC LETTER TCHEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0686 },
  unicodeslot=0xFB7A,
 },
 [0xFB7B]={
  adobename="tchehfinalarabic",
  category="lo",
  description="ARABIC LETTER TCHEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0686 },
  unicodeslot=0xFB7B,
 },
 [0xFB7C]={
  adobename="tchehmeeminitialarabic",
  category="lo",
  description="ARABIC LETTER TCHEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0686 },
  unicodeslot=0xFB7C,
 },
 [0xFB7D]={
  adobename="tchehmedialarabic",
  category="lo",
  description="ARABIC LETTER TCHEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0686 },
  unicodeslot=0xFB7D,
 },
 [0xFB7E]={
  category="lo",
  description="ARABIC LETTER TCHEHEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0687 },
  unicodeslot=0xFB7E,
 },
 [0xFB7F]={
  category="lo",
  description="ARABIC LETTER TCHEHEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0687 },
  unicodeslot=0xFB7F,
 },
 [0xFB80]={
  category="lo",
  description="ARABIC LETTER TCHEHEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0687 },
  unicodeslot=0xFB80,
 },
 [0xFB81]={
  category="lo",
  description="ARABIC LETTER TCHEHEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0687 },
  unicodeslot=0xFB81,
 },
 [0xFB82]={
  category="lo",
  description="ARABIC LETTER DDAHAL ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x068D },
  unicodeslot=0xFB82,
 },
 [0xFB83]={
  category="lo",
  description="ARABIC LETTER DDAHAL FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x068D },
  unicodeslot=0xFB83,
 },
 [0xFB84]={
  category="lo",
  description="ARABIC LETTER DAHAL ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x068C },
  unicodeslot=0xFB84,
 },
 [0xFB85]={
  category="lo",
  description="ARABIC LETTER DAHAL FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x068C },
  unicodeslot=0xFB85,
 },
 [0xFB86]={
  category="lo",
  description="ARABIC LETTER DUL ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x068E },
  unicodeslot=0xFB86,
 },
 [0xFB87]={
  category="lo",
  description="ARABIC LETTER DUL FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x068E },
  unicodeslot=0xFB87,
 },
 [0xFB88]={
  category="lo",
  description="ARABIC LETTER DDAL ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0688 },
  unicodeslot=0xFB88,
 },
 [0xFB89]={
  adobename="ddalfinalarabic",
  category="lo",
  description="ARABIC LETTER DDAL FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0688 },
  unicodeslot=0xFB89,
 },
 [0xFB8A]={
  category="lo",
  description="ARABIC LETTER JEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0698 },
  unicodeslot=0xFB8A,
 },
 [0xFB8B]={
  adobename="jehfinalarabic",
  category="lo",
  description="ARABIC LETTER JEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0698 },
  unicodeslot=0xFB8B,
 },
 [0xFB8C]={
  category="lo",
  description="ARABIC LETTER RREH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0691 },
  unicodeslot=0xFB8C,
 },
 [0xFB8D]={
  adobename="rrehfinalarabic",
  category="lo",
  description="ARABIC LETTER RREH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0691 },
  unicodeslot=0xFB8D,
 },
 [0xFB8E]={
  category="lo",
  description="ARABIC LETTER KEHEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06A9 },
  unicodeslot=0xFB8E,
 },
 [0xFB8F]={
  category="lo",
  description="ARABIC LETTER KEHEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06A9 },
  unicodeslot=0xFB8F,
 },
 [0xFB90]={
  category="lo",
  description="ARABIC LETTER KEHEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06A9 },
  unicodeslot=0xFB90,
 },
 [0xFB91]={
  category="lo",
  description="ARABIC LETTER KEHEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06A9 },
  unicodeslot=0xFB91,
 },
 [0xFB92]={
  category="lo",
  description="ARABIC LETTER GAF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06AF },
  unicodeslot=0xFB92,
 },
 [0xFB93]={
  adobename="gaffinalarabic",
  category="lo",
  description="ARABIC LETTER GAF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06AF },
  unicodeslot=0xFB93,
 },
 [0xFB94]={
  adobename="gafinitialarabic",
  category="lo",
  description="ARABIC LETTER GAF INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06AF },
  unicodeslot=0xFB94,
 },
 [0xFB95]={
  adobename="gafmedialarabic",
  category="lo",
  description="ARABIC LETTER GAF MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06AF },
  unicodeslot=0xFB95,
 },
 [0xFB96]={
  category="lo",
  description="ARABIC LETTER GUEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06B3 },
  unicodeslot=0xFB96,
 },
 [0xFB97]={
  category="lo",
  description="ARABIC LETTER GUEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06B3 },
  unicodeslot=0xFB97,
 },
 [0xFB98]={
  category="lo",
  description="ARABIC LETTER GUEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06B3 },
  unicodeslot=0xFB98,
 },
 [0xFB99]={
  category="lo",
  description="ARABIC LETTER GUEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06B3 },
  unicodeslot=0xFB99,
 },
 [0xFB9A]={
  category="lo",
  description="ARABIC LETTER NGOEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06B1 },
  unicodeslot=0xFB9A,
 },
 [0xFB9B]={
  category="lo",
  description="ARABIC LETTER NGOEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06B1 },
  unicodeslot=0xFB9B,
 },
 [0xFB9C]={
  category="lo",
  description="ARABIC LETTER NGOEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06B1 },
  unicodeslot=0xFB9C,
 },
 [0xFB9D]={
  category="lo",
  description="ARABIC LETTER NGOEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06B1 },
  unicodeslot=0xFB9D,
 },
 [0xFB9E]={
  category="lo",
  description="ARABIC LETTER NOON GHUNNA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06BA },
  unicodeslot=0xFB9E,
 },
 [0xFB9F]={
  adobename="noonghunnafinalarabic",
  category="lo",
  description="ARABIC LETTER NOON GHUNNA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06BA },
  unicodeslot=0xFB9F,
 },
 [0xFBA0]={
  category="lo",
  description="ARABIC LETTER RNOON ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06BB },
  unicodeslot=0xFBA0,
 },
 [0xFBA1]={
  category="lo",
  description="ARABIC LETTER RNOON FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06BB },
  unicodeslot=0xFBA1,
 },
 [0xFBA2]={
  category="lo",
  description="ARABIC LETTER RNOON INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06BB },
  unicodeslot=0xFBA2,
 },
 [0xFBA3]={
  category="lo",
  description="ARABIC LETTER RNOON MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06BB },
  unicodeslot=0xFBA3,
 },
 [0xFBA4]={
  adobename="hehhamzaaboveisolatedarabic",
  category="lo",
  description="ARABIC LETTER HEH WITH YEH ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  shcode=0x0647,
  specials={ "isolated", 0x06C0 },
  unicodeslot=0xFBA4,
 },
 [0xFBA5]={
  adobename="hehhamzaabovefinalarabic",
  category="lo",
  description="ARABIC LETTER HEH WITH YEH ABOVE FINAL FORM",
  direction="al",
  linebreak="al",
  shcode=0x0647,
  specials={ "final", 0x06C0 },
  unicodeslot=0xFBA5,
 },
 [0xFBA6]={
  category="lo",
  description="ARABIC LETTER HEH GOAL ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06C1 },
  unicodeslot=0xFBA6,
 },
 [0xFBA7]={
  adobename="hehfinalaltonearabic",
  category="lo",
  description="ARABIC LETTER HEH GOAL FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06C1 },
  unicodeslot=0xFBA7,
 },
 [0xFBA8]={
  adobename="hehinitialaltonearabic",
  category="lo",
  description="ARABIC LETTER HEH GOAL INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06C1 },
  unicodeslot=0xFBA8,
 },
 [0xFBA9]={
  adobename="hehmedialaltonearabic",
  category="lo",
  description="ARABIC LETTER HEH GOAL MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06C1 },
  unicodeslot=0xFBA9,
 },
 [0xFBAA]={
  category="lo",
  description="ARABIC LETTER HEH DOACHASHMEE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06BE },
  unicodeslot=0xFBAA,
 },
 [0xFBAB]={
  category="lo",
  description="ARABIC LETTER HEH DOACHASHMEE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06BE },
  unicodeslot=0xFBAB,
 },
 [0xFBAC]={
  category="lo",
  description="ARABIC LETTER HEH DOACHASHMEE INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06BE },
  unicodeslot=0xFBAC,
 },
 [0xFBAD]={
  category="lo",
  description="ARABIC LETTER HEH DOACHASHMEE MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06BE },
  unicodeslot=0xFBAD,
 },
 [0xFBAE]={
  category="lo",
  description="ARABIC LETTER YEH BARREE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06D2 },
  unicodeslot=0xFBAE,
 },
 [0xFBAF]={
  adobename="yehbarreefinalarabic",
  category="lo",
  description="ARABIC LETTER YEH BARREE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06D2 },
  unicodeslot=0xFBAF,
 },
 [0xFBB0]={
  category="lo",
  description="ARABIC LETTER YEH BARREE WITH HAMZA ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06D3 },
  unicodeslot=0xFBB0,
 },
 [0xFBB1]={
  category="lo",
  description="ARABIC LETTER YEH BARREE WITH HAMZA ABOVE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06D3 },
  unicodeslot=0xFBB1,
 },
 [0xFBB2]={
  category="sk",
  description="ARABIC SYMBOL DOT ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBB2,
 },
 [0xFBB3]={
  category="sk",
  description="ARABIC SYMBOL DOT BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBB3,
 },
 [0xFBB4]={
  category="sk",
  description="ARABIC SYMBOL TWO DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBB4,
 },
 [0xFBB5]={
  category="sk",
  description="ARABIC SYMBOL TWO DOTS BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBB5,
 },
 [0xFBB6]={
  category="sk",
  description="ARABIC SYMBOL THREE DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBB6,
 },
 [0xFBB7]={
  category="sk",
  description="ARABIC SYMBOL THREE DOTS BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBB7,
 },
 [0xFBB8]={
  category="sk",
  description="ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBB8,
 },
 [0xFBB9]={
  category="sk",
  description="ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBB9,
 },
 [0xFBBA]={
  category="sk",
  description="ARABIC SYMBOL FOUR DOTS ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBBA,
 },
 [0xFBBB]={
  category="sk",
  description="ARABIC SYMBOL FOUR DOTS BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBBB,
 },
 [0xFBBC]={
  category="sk",
  description="ARABIC SYMBOL DOUBLE VERTICAL BAR BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBBC,
 },
 [0xFBBD]={
  category="sk",
  description="ARABIC SYMBOL TWO DOTS VERTICALLY ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBBD,
 },
 [0xFBBE]={
  category="sk",
  description="ARABIC SYMBOL TWO DOTS VERTICALLY BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBBE,
 },
 [0xFBBF]={
  category="sk",
  description="ARABIC SYMBOL RING",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBBF,
 },
 [0xFBC0]={
  category="sk",
  description="ARABIC SYMBOL SMALL TAH ABOVE",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBC0,
 },
 [0xFBC1]={
  category="sk",
  description="ARABIC SYMBOL SMALL TAH BELOW",
  direction="al",
  linebreak="al",
  unicodeslot=0xFBC1,
 },
 [0xFBD3]={
  category="lo",
  description="ARABIC LETTER NG ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06AD },
  unicodeslot=0xFBD3,
 },
 [0xFBD4]={
  category="lo",
  description="ARABIC LETTER NG FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06AD },
  unicodeslot=0xFBD4,
 },
 [0xFBD5]={
  category="lo",
  description="ARABIC LETTER NG INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06AD },
  unicodeslot=0xFBD5,
 },
 [0xFBD6]={
  category="lo",
  description="ARABIC LETTER NG MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06AD },
  unicodeslot=0xFBD6,
 },
 [0xFBD7]={
  category="lo",
  description="ARABIC LETTER U ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06C7 },
  unicodeslot=0xFBD7,
 },
 [0xFBD8]={
  category="lo",
  description="ARABIC LETTER U FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06C7 },
  unicodeslot=0xFBD8,
 },
 [0xFBD9]={
  category="lo",
  description="ARABIC LETTER OE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06C6 },
  unicodeslot=0xFBD9,
 },
 [0xFBDA]={
  category="lo",
  description="ARABIC LETTER OE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06C6 },
  unicodeslot=0xFBDA,
 },
 [0xFBDB]={
  category="lo",
  description="ARABIC LETTER YU ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06C8 },
  unicodeslot=0xFBDB,
 },
 [0xFBDC]={
  category="lo",
  description="ARABIC LETTER YU FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06C8 },
  unicodeslot=0xFBDC,
 },
 [0xFBDD]={
  category="lo",
  description="ARABIC LETTER U WITH HAMZA ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  shcode=0x06C7,
  specials={ "isolated", 0x0677 },
  unicodeslot=0xFBDD,
 },
 [0xFBDE]={
  category="lo",
  description="ARABIC LETTER VE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06CB },
  unicodeslot=0xFBDE,
 },
 [0xFBDF]={
  category="lo",
  description="ARABIC LETTER VE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06CB },
  unicodeslot=0xFBDF,
 },
 [0xFBE0]={
  category="lo",
  description="ARABIC LETTER KIRGHIZ OE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06C5 },
  unicodeslot=0xFBE0,
 },
 [0xFBE1]={
  category="lo",
  description="ARABIC LETTER KIRGHIZ OE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06C5 },
  unicodeslot=0xFBE1,
 },
 [0xFBE2]={
  category="lo",
  description="ARABIC LETTER KIRGHIZ YU ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06C9 },
  unicodeslot=0xFBE2,
 },
 [0xFBE3]={
  category="lo",
  description="ARABIC LETTER KIRGHIZ YU FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06C9 },
  unicodeslot=0xFBE3,
 },
 [0xFBE4]={
  category="lo",
  description="ARABIC LETTER E ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06D0 },
  unicodeslot=0xFBE4,
 },
 [0xFBE5]={
  category="lo",
  description="ARABIC LETTER E FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06D0 },
  unicodeslot=0xFBE5,
 },
 [0xFBE6]={
  category="lo",
  description="ARABIC LETTER E INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06D0 },
  unicodeslot=0xFBE6,
 },
 [0xFBE7]={
  category="lo",
  description="ARABIC LETTER E MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06D0 },
  unicodeslot=0xFBE7,
 },
 [0xFBE8]={
  category="lo",
  description="ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0649 },
  unicodeslot=0xFBE8,
 },
 [0xFBE9]={
  category="lo",
  description="ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0649 },
  unicodeslot=0xFBE9,
 },
 [0xFBEA]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x0627 },
  unicodeslot=0xFBEA,
 },
 [0xFBEB]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x0627 },
  unicodeslot=0xFBEB,
 },
 [0xFBEC]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x06D5 },
  unicodeslot=0xFBEC,
 },
 [0xFBED]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x06D5 },
  unicodeslot=0xFBED,
 },
 [0xFBEE]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x0648 },
  unicodeslot=0xFBEE,
 },
 [0xFBEF]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x0648 },
  unicodeslot=0xFBEF,
 },
 [0xFBF0]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x06C7 },
  unicodeslot=0xFBF0,
 },
 [0xFBF1]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x06C7 },
  unicodeslot=0xFBF1,
 },
 [0xFBF2]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x06C6 },
  unicodeslot=0xFBF2,
 },
 [0xFBF3]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x06C6 },
  unicodeslot=0xFBF3,
 },
 [0xFBF4]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x06C8 },
  unicodeslot=0xFBF4,
 },
 [0xFBF5]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x06C8 },
  unicodeslot=0xFBF5,
 },
 [0xFBF6]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x06D0 },
  unicodeslot=0xFBF6,
 },
 [0xFBF7]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x06D0 },
  unicodeslot=0xFBF7,
 },
 [0xFBF8]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0626, 0x06D0 },
  unicodeslot=0xFBF8,
 },
 [0xFBF9]={
  category="lo",
  description="ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x0649 },
  unicodeslot=0xFBF9,
 },
 [0xFBFA]={
  category="lo",
  description="ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x0649 },
  unicodeslot=0xFBFA,
 },
 [0xFBFB]={
  category="lo",
  description="ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0626, 0x0649 },
  unicodeslot=0xFBFB,
 },
 [0xFBFC]={
  category="lo",
  description="ARABIC LETTER FARSI YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x06CC },
  unicodeslot=0xFBFC,
 },
 [0xFBFD]={
  category="lo",
  description="ARABIC LETTER FARSI YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x06CC },
  unicodeslot=0xFBFD,
 },
 [0xFBFE]={
  category="lo",
  description="ARABIC LETTER FARSI YEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x06CC },
  unicodeslot=0xFBFE,
 },
 [0xFBFF]={
  category="lo",
  description="ARABIC LETTER FARSI YEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x06CC },
  unicodeslot=0xFBFF,
 },
 [0xFC00]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x062C },
  unicodeslot=0xFC00,
 },
 [0xFC01]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x062D },
  unicodeslot=0xFC01,
 },
 [0xFC02]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x0645 },
  unicodeslot=0xFC02,
 },
 [0xFC03]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x0649 },
  unicodeslot=0xFC03,
 },
 [0xFC04]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0626, 0x064A },
  unicodeslot=0xFC04,
 },
 [0xFC05]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0628, 0x062C },
  unicodeslot=0xFC05,
 },
 [0xFC06]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0628, 0x062D },
  unicodeslot=0xFC06,
 },
 [0xFC07]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0628, 0x062E },
  unicodeslot=0xFC07,
 },
 [0xFC08]={
  adobename="behmeemisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE BEH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0628, 0x0645 },
  unicodeslot=0xFC08,
 },
 [0xFC09]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0628, 0x0649 },
  unicodeslot=0xFC09,
 },
 [0xFC0A]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0628, 0x064A },
  unicodeslot=0xFC0A,
 },
 [0xFC0B]={
  adobename="tehjeemisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE TEH WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062A, 0x062C },
  unicodeslot=0xFC0B,
 },
 [0xFC0C]={
  adobename="tehhahisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE TEH WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062A, 0x062D },
  unicodeslot=0xFC0C,
 },
 [0xFC0D]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062A, 0x062E },
  unicodeslot=0xFC0D,
 },
 [0xFC0E]={
  adobename="tehmeemisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062A, 0x0645 },
  unicodeslot=0xFC0E,
 },
 [0xFC0F]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062A, 0x0649 },
  unicodeslot=0xFC0F,
 },
 [0xFC10]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062A, 0x064A },
  unicodeslot=0xFC10,
 },
 [0xFC11]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062B, 0x062C },
  unicodeslot=0xFC11,
 },
 [0xFC12]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062B, 0x0645 },
  unicodeslot=0xFC12,
 },
 [0xFC13]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062B, 0x0649 },
  unicodeslot=0xFC13,
 },
 [0xFC14]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062B, 0x064A },
  unicodeslot=0xFC14,
 },
 [0xFC15]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062C, 0x062D },
  unicodeslot=0xFC15,
 },
 [0xFC16]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062C, 0x0645 },
  unicodeslot=0xFC16,
 },
 [0xFC17]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062D, 0x062C },
  unicodeslot=0xFC17,
 },
 [0xFC18]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062D, 0x0645 },
  unicodeslot=0xFC18,
 },
 [0xFC19]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062E, 0x062C },
  unicodeslot=0xFC19,
 },
 [0xFC1A]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062E, 0x062D },
  unicodeslot=0xFC1A,
 },
 [0xFC1B]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062E, 0x0645 },
  unicodeslot=0xFC1B,
 },
 [0xFC1C]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0633, 0x062C },
  unicodeslot=0xFC1C,
 },
 [0xFC1D]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0633, 0x062D },
  unicodeslot=0xFC1D,
 },
 [0xFC1E]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0633, 0x062E },
  unicodeslot=0xFC1E,
 },
 [0xFC1F]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0633, 0x0645 },
  unicodeslot=0xFC1F,
 },
 [0xFC20]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x062D },
  unicodeslot=0xFC20,
 },
 [0xFC21]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x0645 },
  unicodeslot=0xFC21,
 },
 [0xFC22]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0636, 0x062C },
  unicodeslot=0xFC22,
 },
 [0xFC23]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0636, 0x062D },
  unicodeslot=0xFC23,
 },
 [0xFC24]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0636, 0x062E },
  unicodeslot=0xFC24,
 },
 [0xFC25]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0636, 0x0645 },
  unicodeslot=0xFC25,
 },
 [0xFC26]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0637, 0x062D },
  unicodeslot=0xFC26,
 },
 [0xFC27]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0637, 0x0645 },
  unicodeslot=0xFC27,
 },
 [0xFC28]={
  category="lo",
  description="ARABIC LIGATURE ZAH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0638, 0x0645 },
  unicodeslot=0xFC28,
 },
 [0xFC29]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0639, 0x062C },
  unicodeslot=0xFC29,
 },
 [0xFC2A]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0639, 0x0645 },
  unicodeslot=0xFC2A,
 },
 [0xFC2B]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x063A, 0x062C },
  unicodeslot=0xFC2B,
 },
 [0xFC2C]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x063A, 0x0645 },
  unicodeslot=0xFC2C,
 },
 [0xFC2D]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0641, 0x062C },
  unicodeslot=0xFC2D,
 },
 [0xFC2E]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0641, 0x062D },
  unicodeslot=0xFC2E,
 },
 [0xFC2F]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0641, 0x062E },
  unicodeslot=0xFC2F,
 },
 [0xFC30]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0641, 0x0645 },
  unicodeslot=0xFC30,
 },
 [0xFC31]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0641, 0x0649 },
  unicodeslot=0xFC31,
 },
 [0xFC32]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0641, 0x064A },
  unicodeslot=0xFC32,
 },
 [0xFC33]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0642, 0x062D },
  unicodeslot=0xFC33,
 },
 [0xFC34]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0642, 0x0645 },
  unicodeslot=0xFC34,
 },
 [0xFC35]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0642, 0x0649 },
  unicodeslot=0xFC35,
 },
 [0xFC36]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0642, 0x064A },
  unicodeslot=0xFC36,
 },
 [0xFC37]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH ALEF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643, 0x0627 },
  unicodeslot=0xFC37,
 },
 [0xFC38]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643, 0x062C },
  unicodeslot=0xFC38,
 },
 [0xFC39]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643, 0x062D },
  unicodeslot=0xFC39,
 },
 [0xFC3A]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643, 0x062E },
  unicodeslot=0xFC3A,
 },
 [0xFC3B]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH LAM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643, 0x0644 },
  unicodeslot=0xFC3B,
 },
 [0xFC3C]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643, 0x0645 },
  unicodeslot=0xFC3C,
 },
 [0xFC3D]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643, 0x0649 },
  unicodeslot=0xFC3D,
 },
 [0xFC3E]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643, 0x064A },
  unicodeslot=0xFC3E,
 },
 [0xFC3F]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x062C },
  unicodeslot=0xFC3F,
 },
 [0xFC40]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x062D },
  unicodeslot=0xFC40,
 },
 [0xFC41]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x062E },
  unicodeslot=0xFC41,
 },
 [0xFC42]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x0645 },
  unicodeslot=0xFC42,
 },
 [0xFC43]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x0649 },
  unicodeslot=0xFC43,
 },
 [0xFC44]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x064A },
  unicodeslot=0xFC44,
 },
 [0xFC45]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0645, 0x062C },
  unicodeslot=0xFC45,
 },
 [0xFC46]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0645, 0x062D },
  unicodeslot=0xFC46,
 },
 [0xFC47]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0645, 0x062E },
  unicodeslot=0xFC47,
 },
 [0xFC48]={
  adobename="meemmeemisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE MEEM WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0645, 0x0645 },
  unicodeslot=0xFC48,
 },
 [0xFC49]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0645, 0x0649 },
  unicodeslot=0xFC49,
 },
 [0xFC4A]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0645, 0x064A },
  unicodeslot=0xFC4A,
 },
 [0xFC4B]={
  adobename="noonjeemisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE NOON WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0646, 0x062C },
  unicodeslot=0xFC4B,
 },
 [0xFC4C]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0646, 0x062D },
  unicodeslot=0xFC4C,
 },
 [0xFC4D]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0646, 0x062E },
  unicodeslot=0xFC4D,
 },
 [0xFC4E]={
  adobename="noonmeemisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE NOON WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0646, 0x0645 },
  unicodeslot=0xFC4E,
 },
 [0xFC4F]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0646, 0x0649 },
  unicodeslot=0xFC4F,
 },
 [0xFC50]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0646, 0x064A },
  unicodeslot=0xFC50,
 },
 [0xFC51]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0647, 0x062C },
  unicodeslot=0xFC51,
 },
 [0xFC52]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0647, 0x0645 },
  unicodeslot=0xFC52,
 },
 [0xFC53]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0647, 0x0649 },
  unicodeslot=0xFC53,
 },
 [0xFC54]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0647, 0x064A },
  unicodeslot=0xFC54,
 },
 [0xFC55]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x064A, 0x062C },
  unicodeslot=0xFC55,
 },
 [0xFC56]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x064A, 0x062D },
  unicodeslot=0xFC56,
 },
 [0xFC57]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x064A, 0x062E },
  unicodeslot=0xFC57,
 },
 [0xFC58]={
  adobename="yehmeemisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE YEH WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x064A, 0x0645 },
  unicodeslot=0xFC58,
 },
 [0xFC59]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x064A, 0x0649 },
  unicodeslot=0xFC59,
 },
 [0xFC5A]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x064A, 0x064A },
  unicodeslot=0xFC5A,
 },
 [0xFC5B]={
  category="lo",
  description="ARABIC LIGATURE THAL WITH SUPERSCRIPT ALEF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0630, 0x0670 },
  unicodeslot=0xFC5B,
 },
 [0xFC5C]={
  category="lo",
  description="ARABIC LIGATURE REH WITH SUPERSCRIPT ALEF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0631, 0x0670 },
  unicodeslot=0xFC5C,
 },
 [0xFC5D]={
  category="lo",
  description="ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0649, 0x0670 },
  unicodeslot=0xFC5D,
 },
 [0xFC5E]={
  adobename="shaddadammatanarabic",
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH DAMMATAN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064C, 0x0651 },
  unicodeslot=0xFC5E,
 },
 [0xFC5F]={
  adobename="shaddakasratanarabic",
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH KASRATAN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064D, 0x0651 },
  unicodeslot=0xFC5F,
 },
 [0xFC60]={
  adobename="shaddafathaarabic",
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH FATHA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064E, 0x0651 },
  unicodeslot=0xFC60,
 },
 [0xFC61]={
  adobename="shaddadammaarabic",
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH DAMMA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064F, 0x0651 },
  unicodeslot=0xFC61,
 },
 [0xFC62]={
  adobename="shaddakasraarabic",
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH KASRA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x0650, 0x0651 },
  unicodeslot=0xFC62,
 },
 [0xFC63]={
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH SUPERSCRIPT ALEF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x0651, 0x0670 },
  unicodeslot=0xFC63,
 },
 [0xFC64]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x0631 },
  unicodeslot=0xFC64,
 },
 [0xFC65]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ZAIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x0632 },
  unicodeslot=0xFC65,
 },
 [0xFC66]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x0645 },
  unicodeslot=0xFC66,
 },
 [0xFC67]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH NOON FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x0646 },
  unicodeslot=0xFC67,
 },
 [0xFC68]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x0649 },
  unicodeslot=0xFC68,
 },
 [0xFC69]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0626, 0x064A },
  unicodeslot=0xFC69,
 },
 [0xFC6A]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628, 0x0631 },
  unicodeslot=0xFC6A,
 },
 [0xFC6B]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH ZAIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628, 0x0632 },
  unicodeslot=0xFC6B,
 },
 [0xFC6C]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628, 0x0645 },
  unicodeslot=0xFC6C,
 },
 [0xFC6D]={
  adobename="behnoonfinalarabic",
  category="lo",
  description="ARABIC LIGATURE BEH WITH NOON FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628, 0x0646 },
  unicodeslot=0xFC6D,
 },
 [0xFC6E]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628, 0x0649 },
  unicodeslot=0xFC6E,
 },
 [0xFC6F]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628, 0x064A },
  unicodeslot=0xFC6F,
 },
 [0xFC70]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x0631 },
  unicodeslot=0xFC70,
 },
 [0xFC71]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH ZAIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x0632 },
  unicodeslot=0xFC71,
 },
 [0xFC72]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x0645 },
  unicodeslot=0xFC72,
 },
 [0xFC73]={
  adobename="tehnoonfinalarabic",
  category="lo",
  description="ARABIC LIGATURE TEH WITH NOON FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x0646 },
  unicodeslot=0xFC73,
 },
 [0xFC74]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x0649 },
  unicodeslot=0xFC74,
 },
 [0xFC75]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x064A },
  unicodeslot=0xFC75,
 },
 [0xFC76]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062B, 0x0631 },
  unicodeslot=0xFC76,
 },
 [0xFC77]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH ZAIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062B, 0x0632 },
  unicodeslot=0xFC77,
 },
 [0xFC78]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062B, 0x0645 },
  unicodeslot=0xFC78,
 },
 [0xFC79]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH NOON FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062B, 0x0646 },
  unicodeslot=0xFC79,
 },
 [0xFC7A]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062B, 0x0649 },
  unicodeslot=0xFC7A,
 },
 [0xFC7B]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062B, 0x064A },
  unicodeslot=0xFC7B,
 },
 [0xFC7C]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0641, 0x0649 },
  unicodeslot=0xFC7C,
 },
 [0xFC7D]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0641, 0x064A },
  unicodeslot=0xFC7D,
 },
 [0xFC7E]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0642, 0x0649 },
  unicodeslot=0xFC7E,
 },
 [0xFC7F]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0642, 0x064A },
  unicodeslot=0xFC7F,
 },
 [0xFC80]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH ALEF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0643, 0x0627 },
  unicodeslot=0xFC80,
 },
 [0xFC81]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH LAM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0643, 0x0644 },
  unicodeslot=0xFC81,
 },
 [0xFC82]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0643, 0x0645 },
  unicodeslot=0xFC82,
 },
 [0xFC83]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0643, 0x0649 },
  unicodeslot=0xFC83,
 },
 [0xFC84]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0643, 0x064A },
  unicodeslot=0xFC84,
 },
 [0xFC85]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x0645 },
  unicodeslot=0xFC85,
 },
 [0xFC86]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x0649 },
  unicodeslot=0xFC86,
 },
 [0xFC87]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x064A },
  unicodeslot=0xFC87,
 },
 [0xFC88]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH ALEF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0645, 0x0627 },
  unicodeslot=0xFC88,
 },
 [0xFC89]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0645, 0x0645 },
  unicodeslot=0xFC89,
 },
 [0xFC8A]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x0631 },
  unicodeslot=0xFC8A,
 },
 [0xFC8B]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH ZAIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x0632 },
  unicodeslot=0xFC8B,
 },
 [0xFC8C]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x0645 },
  unicodeslot=0xFC8C,
 },
 [0xFC8D]={
  adobename="noonnoonfinalarabic",
  category="lo",
  description="ARABIC LIGATURE NOON WITH NOON FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x0646 },
  unicodeslot=0xFC8D,
 },
 [0xFC8E]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x0649 },
  unicodeslot=0xFC8E,
 },
 [0xFC8F]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x064A },
  unicodeslot=0xFC8F,
 },
 [0xFC90]={
  category="lo",
  description="ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0649, 0x0670 },
  unicodeslot=0xFC90,
 },
 [0xFC91]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x0631 },
  unicodeslot=0xFC91,
 },
 [0xFC92]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH ZAIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x0632 },
  unicodeslot=0xFC92,
 },
 [0xFC93]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x0645 },
  unicodeslot=0xFC93,
 },
 [0xFC94]={
  adobename="yehnoonfinalarabic",
  category="lo",
  description="ARABIC LIGATURE YEH WITH NOON FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x0646 },
  unicodeslot=0xFC94,
 },
 [0xFC95]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x0649 },
  unicodeslot=0xFC95,
 },
 [0xFC96]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x064A },
  unicodeslot=0xFC96,
 },
 [0xFC97]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0626, 0x062C },
  unicodeslot=0xFC97,
 },
 [0xFC98]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0626, 0x062D },
  unicodeslot=0xFC98,
 },
 [0xFC99]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0626, 0x062E },
  unicodeslot=0xFC99,
 },
 [0xFC9A]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0626, 0x0645 },
  unicodeslot=0xFC9A,
 },
 [0xFC9B]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0626, 0x0647 },
  unicodeslot=0xFC9B,
 },
 [0xFC9C]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0628, 0x062C },
  unicodeslot=0xFC9C,
 },
 [0xFC9D]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0628, 0x062D },
  unicodeslot=0xFC9D,
 },
 [0xFC9E]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0628, 0x062E },
  unicodeslot=0xFC9E,
 },
 [0xFC9F]={
  adobename="behmeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE BEH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0628, 0x0645 },
  unicodeslot=0xFC9F,
 },
 [0xFCA0]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0628, 0x0647 },
  unicodeslot=0xFCA0,
 },
 [0xFCA1]={
  adobename="tehjeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE TEH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x062C },
  unicodeslot=0xFCA1,
 },
 [0xFCA2]={
  adobename="tehhahinitialarabic",
  category="lo",
  description="ARABIC LIGATURE TEH WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x062D },
  unicodeslot=0xFCA2,
 },
 [0xFCA3]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x062E },
  unicodeslot=0xFCA3,
 },
 [0xFCA4]={
  adobename="tehmeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x0645 },
  unicodeslot=0xFCA4,
 },
 [0xFCA5]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x0647 },
  unicodeslot=0xFCA5,
 },
 [0xFCA6]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062B, 0x0645 },
  unicodeslot=0xFCA6,
 },
 [0xFCA7]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062C, 0x062D },
  unicodeslot=0xFCA7,
 },
 [0xFCA8]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062C, 0x0645 },
  unicodeslot=0xFCA8,
 },
 [0xFCA9]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062D, 0x062C },
  unicodeslot=0xFCA9,
 },
 [0xFCAA]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062D, 0x0645 },
  unicodeslot=0xFCAA,
 },
 [0xFCAB]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062E, 0x062C },
  unicodeslot=0xFCAB,
 },
 [0xFCAC]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062E, 0x0645 },
  unicodeslot=0xFCAC,
 },
 [0xFCAD]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x062C },
  unicodeslot=0xFCAD,
 },
 [0xFCAE]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x062D },
  unicodeslot=0xFCAE,
 },
 [0xFCAF]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x062E },
  unicodeslot=0xFCAF,
 },
 [0xFCB0]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x0645 },
  unicodeslot=0xFCB0,
 },
 [0xFCB1]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0635, 0x062D },
  unicodeslot=0xFCB1,
 },
 [0xFCB2]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0635, 0x062E },
  unicodeslot=0xFCB2,
 },
 [0xFCB3]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0635, 0x0645 },
  unicodeslot=0xFCB3,
 },
 [0xFCB4]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0636, 0x062C },
  unicodeslot=0xFCB4,
 },
 [0xFCB5]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0636, 0x062D },
  unicodeslot=0xFCB5,
 },
 [0xFCB6]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0636, 0x062E },
  unicodeslot=0xFCB6,
 },
 [0xFCB7]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0636, 0x0645 },
  unicodeslot=0xFCB7,
 },
 [0xFCB8]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0637, 0x062D },
  unicodeslot=0xFCB8,
 },
 [0xFCB9]={
  category="lo",
  description="ARABIC LIGATURE ZAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0638, 0x0645 },
  unicodeslot=0xFCB9,
 },
 [0xFCBA]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0639, 0x062C },
  unicodeslot=0xFCBA,
 },
 [0xFCBB]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0639, 0x0645 },
  unicodeslot=0xFCBB,
 },
 [0xFCBC]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x063A, 0x062C },
  unicodeslot=0xFCBC,
 },
 [0xFCBD]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x063A, 0x0645 },
  unicodeslot=0xFCBD,
 },
 [0xFCBE]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0641, 0x062C },
  unicodeslot=0xFCBE,
 },
 [0xFCBF]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0641, 0x062D },
  unicodeslot=0xFCBF,
 },
 [0xFCC0]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0641, 0x062E },
  unicodeslot=0xFCC0,
 },
 [0xFCC1]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0641, 0x0645 },
  unicodeslot=0xFCC1,
 },
 [0xFCC2]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0642, 0x062D },
  unicodeslot=0xFCC2,
 },
 [0xFCC3]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0642, 0x0645 },
  unicodeslot=0xFCC3,
 },
 [0xFCC4]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0643, 0x062C },
  unicodeslot=0xFCC4,
 },
 [0xFCC5]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0643, 0x062D },
  unicodeslot=0xFCC5,
 },
 [0xFCC6]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0643, 0x062E },
  unicodeslot=0xFCC6,
 },
 [0xFCC7]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH LAM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0643, 0x0644 },
  unicodeslot=0xFCC7,
 },
 [0xFCC8]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0643, 0x0645 },
  unicodeslot=0xFCC8,
 },
 [0xFCC9]={
  adobename="lamjeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x062C },
  unicodeslot=0xFCC9,
 },
 [0xFCCA]={
  adobename="lamhahinitialarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x062D },
  unicodeslot=0xFCCA,
 },
 [0xFCCB]={
  adobename="lamkhahinitialarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x062E },
  unicodeslot=0xFCCB,
 },
 [0xFCCC]={
  adobename="lammeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x0645 },
  unicodeslot=0xFCCC,
 },
 [0xFCCD]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x0647 },
  unicodeslot=0xFCCD,
 },
 [0xFCCE]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062C },
  unicodeslot=0xFCCE,
 },
 [0xFCCF]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062D },
  unicodeslot=0xFCCF,
 },
 [0xFCD0]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062E },
  unicodeslot=0xFCD0,
 },
 [0xFCD1]={
  adobename="meemmeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x0645 },
  unicodeslot=0xFCD1,
 },
 [0xFCD2]={
  adobename="noonjeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE NOON WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646, 0x062C },
  unicodeslot=0xFCD2,
 },
 [0xFCD3]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646, 0x062D },
  unicodeslot=0xFCD3,
 },
 [0xFCD4]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646, 0x062E },
  unicodeslot=0xFCD4,
 },
 [0xFCD5]={
  adobename="noonmeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE NOON WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646, 0x0645 },
  unicodeslot=0xFCD5,
 },
 [0xFCD6]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646, 0x0647 },
  unicodeslot=0xFCD6,
 },
 [0xFCD7]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0647, 0x062C },
  unicodeslot=0xFCD7,
 },
 [0xFCD8]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0647, 0x0645 },
  unicodeslot=0xFCD8,
 },
 [0xFCD9]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH SUPERSCRIPT ALEF INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0647, 0x0670 },
  unicodeslot=0xFCD9,
 },
 [0xFCDA]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x064A, 0x062C },
  unicodeslot=0xFCDA,
 },
 [0xFCDB]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x064A, 0x062D },
  unicodeslot=0xFCDB,
 },
 [0xFCDC]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x064A, 0x062E },
  unicodeslot=0xFCDC,
 },
 [0xFCDD]={
  adobename="yehmeeminitialarabic",
  category="lo",
  description="ARABIC LIGATURE YEH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x064A, 0x0645 },
  unicodeslot=0xFCDD,
 },
 [0xFCDE]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x064A, 0x0647 },
  unicodeslot=0xFCDE,
 },
 [0xFCDF]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0626, 0x0645 },
  unicodeslot=0xFCDF,
 },
 [0xFCE0]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0626, 0x0647 },
  unicodeslot=0xFCE0,
 },
 [0xFCE1]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0628, 0x0645 },
  unicodeslot=0xFCE1,
 },
 [0xFCE2]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0628, 0x0647 },
  unicodeslot=0xFCE2,
 },
 [0xFCE3]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062A, 0x0645 },
  unicodeslot=0xFCE3,
 },
 [0xFCE4]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062A, 0x0647 },
  unicodeslot=0xFCE4,
 },
 [0xFCE5]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062B, 0x0645 },
  unicodeslot=0xFCE5,
 },
 [0xFCE6]={
  category="lo",
  description="ARABIC LIGATURE THEH WITH HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062B, 0x0647 },
  unicodeslot=0xFCE6,
 },
 [0xFCE7]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0633, 0x0645 },
  unicodeslot=0xFCE7,
 },
 [0xFCE8]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0633, 0x0647 },
  unicodeslot=0xFCE8,
 },
 [0xFCE9]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0634, 0x0645 },
  unicodeslot=0xFCE9,
 },
 [0xFCEA]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0634, 0x0647 },
  unicodeslot=0xFCEA,
 },
 [0xFCEB]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH LAM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0643, 0x0644 },
  unicodeslot=0xFCEB,
 },
 [0xFCEC]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0643, 0x0645 },
  unicodeslot=0xFCEC,
 },
 [0xFCED]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0644, 0x0645 },
  unicodeslot=0xFCED,
 },
 [0xFCEE]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0646, 0x0645 },
  unicodeslot=0xFCEE,
 },
 [0xFCEF]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0646, 0x0647 },
  unicodeslot=0xFCEF,
 },
 [0xFCF0]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x064A, 0x0645 },
  unicodeslot=0xFCF0,
 },
 [0xFCF1]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x064A, 0x0647 },
  unicodeslot=0xFCF1,
 },
 [0xFCF2]={
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH FATHA MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x064E, 0x0651 },
  unicodeslot=0xFCF2,
 },
 [0xFCF3]={
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH DAMMA MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x064F, 0x0651 },
  unicodeslot=0xFCF3,
 },
 [0xFCF4]={
  category="lo",
  description="ARABIC LIGATURE SHADDA WITH KASRA MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x0650, 0x0651 },
  unicodeslot=0xFCF4,
 },
 [0xFCF5]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0637, 0x0649 },
  unicodeslot=0xFCF5,
 },
 [0xFCF6]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0637, 0x064A },
  unicodeslot=0xFCF6,
 },
 [0xFCF7]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0639, 0x0649 },
  unicodeslot=0xFCF7,
 },
 [0xFCF8]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0639, 0x064A },
  unicodeslot=0xFCF8,
 },
 [0xFCF9]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x063A, 0x0649 },
  unicodeslot=0xFCF9,
 },
 [0xFCFA]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x063A, 0x064A },
  unicodeslot=0xFCFA,
 },
 [0xFCFB]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0633, 0x0649 },
  unicodeslot=0xFCFB,
 },
 [0xFCFC]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0633, 0x064A },
  unicodeslot=0xFCFC,
 },
 [0xFCFD]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0634, 0x0649 },
  unicodeslot=0xFCFD,
 },
 [0xFCFE]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0634, 0x064A },
  unicodeslot=0xFCFE,
 },
 [0xFCFF]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062D, 0x0649 },
  unicodeslot=0xFCFF,
 },
 [0xFD00]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062D, 0x064A },
  unicodeslot=0xFD00,
 },
 [0xFD01]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062C, 0x0649 },
  unicodeslot=0xFD01,
 },
 [0xFD02]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062C, 0x064A },
  unicodeslot=0xFD02,
 },
 [0xFD03]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062E, 0x0649 },
  unicodeslot=0xFD03,
 },
 [0xFD04]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062E, 0x064A },
  unicodeslot=0xFD04,
 },
 [0xFD05]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x0649 },
  unicodeslot=0xFD05,
 },
 [0xFD06]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x064A },
  unicodeslot=0xFD06,
 },
 [0xFD07]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0636, 0x0649 },
  unicodeslot=0xFD07,
 },
 [0xFD08]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0636, 0x064A },
  unicodeslot=0xFD08,
 },
 [0xFD09]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0634, 0x062C },
  unicodeslot=0xFD09,
 },
 [0xFD0A]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0634, 0x062D },
  unicodeslot=0xFD0A,
 },
 [0xFD0B]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0634, 0x062E },
  unicodeslot=0xFD0B,
 },
 [0xFD0C]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0634, 0x0645 },
  unicodeslot=0xFD0C,
 },
 [0xFD0D]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH REH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0634, 0x0631 },
  unicodeslot=0xFD0D,
 },
 [0xFD0E]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH REH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0633, 0x0631 },
  unicodeslot=0xFD0E,
 },
 [0xFD0F]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH REH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x0631 },
  unicodeslot=0xFD0F,
 },
 [0xFD10]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH REH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0636, 0x0631 },
  unicodeslot=0xFD10,
 },
 [0xFD11]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0637, 0x0649 },
  unicodeslot=0xFD11,
 },
 [0xFD12]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0637, 0x064A },
  unicodeslot=0xFD12,
 },
 [0xFD13]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0639, 0x0649 },
  unicodeslot=0xFD13,
 },
 [0xFD14]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0639, 0x064A },
  unicodeslot=0xFD14,
 },
 [0xFD15]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x063A, 0x0649 },
  unicodeslot=0xFD15,
 },
 [0xFD16]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x063A, 0x064A },
  unicodeslot=0xFD16,
 },
 [0xFD17]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633, 0x0649 },
  unicodeslot=0xFD17,
 },
 [0xFD18]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633, 0x064A },
  unicodeslot=0xFD18,
 },
 [0xFD19]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x0649 },
  unicodeslot=0xFD19,
 },
 [0xFD1A]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x064A },
  unicodeslot=0xFD1A,
 },
 [0xFD1B]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062D, 0x0649 },
  unicodeslot=0xFD1B,
 },
 [0xFD1C]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062D, 0x064A },
  unicodeslot=0xFD1C,
 },
 [0xFD1D]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062C, 0x0649 },
  unicodeslot=0xFD1D,
 },
 [0xFD1E]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062C, 0x064A },
  unicodeslot=0xFD1E,
 },
 [0xFD1F]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062E, 0x0649 },
  unicodeslot=0xFD1F,
 },
 [0xFD20]={
  category="lo",
  description="ARABIC LIGATURE KHAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062E, 0x064A },
  unicodeslot=0xFD20,
 },
 [0xFD21]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0635, 0x0649 },
  unicodeslot=0xFD21,
 },
 [0xFD22]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0635, 0x064A },
  unicodeslot=0xFD22,
 },
 [0xFD23]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0636, 0x0649 },
  unicodeslot=0xFD23,
 },
 [0xFD24]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0636, 0x064A },
  unicodeslot=0xFD24,
 },
 [0xFD25]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH JEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x062C },
  unicodeslot=0xFD25,
 },
 [0xFD26]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x062D },
  unicodeslot=0xFD26,
 },
 [0xFD27]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH KHAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x062E },
  unicodeslot=0xFD27,
 },
 [0xFD28]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x0645 },
  unicodeslot=0xFD28,
 },
 [0xFD29]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x0631 },
  unicodeslot=0xFD29,
 },
 [0xFD2A]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633, 0x0631 },
  unicodeslot=0xFD2A,
 },
 [0xFD2B]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0635, 0x0631 },
  unicodeslot=0xFD2B,
 },
 [0xFD2C]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0636, 0x0631 },
  unicodeslot=0xFD2C,
 },
 [0xFD2D]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634, 0x062C },
  unicodeslot=0xFD2D,
 },
 [0xFD2E]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634, 0x062D },
  unicodeslot=0xFD2E,
 },
 [0xFD2F]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634, 0x062E },
  unicodeslot=0xFD2F,
 },
 [0xFD30]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634, 0x0645 },
  unicodeslot=0xFD30,
 },
 [0xFD31]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x0647 },
  unicodeslot=0xFD31,
 },
 [0xFD32]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634, 0x0647 },
  unicodeslot=0xFD32,
 },
 [0xFD33]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0637, 0x0645 },
  unicodeslot=0xFD33,
 },
 [0xFD34]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH JEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0633, 0x062C },
  unicodeslot=0xFD34,
 },
 [0xFD35]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH HAH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0633, 0x062D },
  unicodeslot=0xFD35,
 },
 [0xFD36]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH KHAH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0633, 0x062E },
  unicodeslot=0xFD36,
 },
 [0xFD37]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH JEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0634, 0x062C },
  unicodeslot=0xFD37,
 },
 [0xFD38]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HAH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0634, 0x062D },
  unicodeslot=0xFD38,
 },
 [0xFD39]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH KHAH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0634, 0x062E },
  unicodeslot=0xFD39,
 },
 [0xFD3A]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0637, 0x0645 },
  unicodeslot=0xFD3A,
 },
 [0xFD3B]={
  category="lo",
  description="ARABIC LIGATURE ZAH WITH MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0638, 0x0645 },
  unicodeslot=0xFD3B,
 },
 [0xFD3C]={
  category="lo",
  description="ARABIC LIGATURE ALEF WITH FATHATAN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0627, 0x064B },
  unicodeslot=0xFD3C,
 },
 [0xFD3D]={
  category="lo",
  description="ARABIC LIGATURE ALEF WITH FATHATAN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0627, 0x064B },
  unicodeslot=0xFD3D,
 },
 [0xFD3E]={
  adobename="parenleftaltonearabic",
  category="ps",
  description="ORNATE LEFT PARENTHESIS",
  direction="on",
  linebreak="op",
  unicodeslot=0xFD3E,
 },
 [0xFD3F]={
  adobename="parenrightaltonearabic",
  category="pe",
  description="ORNATE RIGHT PARENTHESIS",
  direction="on",
  linebreak="cl",
  unicodeslot=0xFD3F,
 },
 [0xFD50]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH JEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x062C, 0x0645 },
  unicodeslot=0xFD50,
 },
 [0xFD51]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH HAH WITH JEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x062D, 0x062C },
  unicodeslot=0xFD51,
 },
 [0xFD52]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH HAH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x062D, 0x062C },
  unicodeslot=0xFD52,
 },
 [0xFD53]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH HAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x062D, 0x0645 },
  unicodeslot=0xFD53,
 },
 [0xFD54]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH KHAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x062E, 0x0645 },
  unicodeslot=0xFD54,
 },
 [0xFD55]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x0645, 0x062C },
  unicodeslot=0xFD55,
 },
 [0xFD56]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x0645, 0x062D },
  unicodeslot=0xFD56,
 },
 [0xFD57]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A, 0x0645, 0x062E },
  unicodeslot=0xFD57,
 },
 [0xFD58]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH MEEM WITH HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062C, 0x0645, 0x062D },
  unicodeslot=0xFD58,
 },
 [0xFD59]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH MEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062C, 0x0645, 0x062D },
  unicodeslot=0xFD59,
 },
 [0xFD5A]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062D, 0x0645, 0x064A },
  unicodeslot=0xFD5A,
 },
 [0xFD5B]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH MEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062D, 0x0645, 0x0649 },
  unicodeslot=0xFD5B,
 },
 [0xFD5C]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH HAH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x062D, 0x062C },
  unicodeslot=0xFD5C,
 },
 [0xFD5D]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH JEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x062C, 0x062D },
  unicodeslot=0xFD5D,
 },
 [0xFD5E]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH JEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633, 0x062C, 0x0649 },
  unicodeslot=0xFD5E,
 },
 [0xFD5F]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH MEEM WITH HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633, 0x0645, 0x062D },
  unicodeslot=0xFD5F,
 },
 [0xFD60]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH MEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x0645, 0x062D },
  unicodeslot=0xFD60,
 },
 [0xFD61]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH MEEM WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x0645, 0x062C },
  unicodeslot=0xFD61,
 },
 [0xFD62]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633, 0x0645, 0x0645 },
  unicodeslot=0xFD62,
 },
 [0xFD63]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633, 0x0645, 0x0645 },
  unicodeslot=0xFD63,
 },
 [0xFD64]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH HAH WITH HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0635, 0x062D, 0x062D },
  unicodeslot=0xFD64,
 },
 [0xFD65]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH HAH WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0635, 0x062D, 0x062D },
  unicodeslot=0xFD65,
 },
 [0xFD66]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0635, 0x0645, 0x0645 },
  unicodeslot=0xFD66,
 },
 [0xFD67]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HAH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x062D, 0x0645 },
  unicodeslot=0xFD67,
 },
 [0xFD68]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634, 0x062D, 0x0645 },
  unicodeslot=0xFD68,
 },
 [0xFD69]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH JEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x062C, 0x064A },
  unicodeslot=0xFD69,
 },
 [0xFD6A]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x0645, 0x062E },
  unicodeslot=0xFD6A,
 },
 [0xFD6B]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634, 0x0645, 0x062E },
  unicodeslot=0xFD6B,
 },
 [0xFD6C]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x0645, 0x0645 },
  unicodeslot=0xFD6C,
 },
 [0xFD6D]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634, 0x0645, 0x0645 },
  unicodeslot=0xFD6D,
 },
 [0xFD6E]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH HAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0636, 0x062D, 0x0649 },
  unicodeslot=0xFD6E,
 },
 [0xFD6F]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH KHAH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0636, 0x062E, 0x0645 },
  unicodeslot=0xFD6F,
 },
 [0xFD70]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH KHAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0636, 0x062E, 0x0645 },
  unicodeslot=0xFD70,
 },
 [0xFD71]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH MEEM WITH HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0637, 0x0645, 0x062D },
  unicodeslot=0xFD71,
 },
 [0xFD72]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH MEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0637, 0x0645, 0x062D },
  unicodeslot=0xFD72,
 },
 [0xFD73]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0637, 0x0645, 0x0645 },
  unicodeslot=0xFD73,
 },
 [0xFD74]={
  category="lo",
  description="ARABIC LIGATURE TAH WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0637, 0x0645, 0x064A },
  unicodeslot=0xFD74,
 },
 [0xFD75]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH JEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0639, 0x062C, 0x0645 },
  unicodeslot=0xFD75,
 },
 [0xFD76]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0639, 0x0645, 0x0645 },
  unicodeslot=0xFD76,
 },
 [0xFD77]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0639, 0x0645, 0x0645 },
  unicodeslot=0xFD77,
 },
 [0xFD78]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH MEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0639, 0x0645, 0x0649 },
  unicodeslot=0xFD78,
 },
 [0xFD79]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x063A, 0x0645, 0x0645 },
  unicodeslot=0xFD79,
 },
 [0xFD7A]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x063A, 0x0645, 0x064A },
  unicodeslot=0xFD7A,
 },
 [0xFD7B]={
  category="lo",
  description="ARABIC LIGATURE GHAIN WITH MEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x063A, 0x0645, 0x0649 },
  unicodeslot=0xFD7B,
 },
 [0xFD7C]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH KHAH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0641, 0x062E, 0x0645 },
  unicodeslot=0xFD7C,
 },
 [0xFD7D]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH KHAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0641, 0x062E, 0x0645 },
  unicodeslot=0xFD7D,
 },
 [0xFD7E]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH MEEM WITH HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0642, 0x0645, 0x062D },
  unicodeslot=0xFD7E,
 },
 [0xFD7F]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0642, 0x0645, 0x0645 },
  unicodeslot=0xFD7F,
 },
 [0xFD80]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH HAH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x062D, 0x0645 },
  unicodeslot=0xFD80,
 },
 [0xFD81]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x062D, 0x064A },
  unicodeslot=0xFD81,
 },
 [0xFD82]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH HAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x062D, 0x0649 },
  unicodeslot=0xFD82,
 },
 [0xFD83]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH JEEM WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x062C, 0x062C },
  unicodeslot=0xFD83,
 },
 [0xFD84]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH JEEM WITH JEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x062C, 0x062C },
  unicodeslot=0xFD84,
 },
 [0xFD85]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH KHAH WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x062E, 0x0645 },
  unicodeslot=0xFD85,
 },
 [0xFD86]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH KHAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x062E, 0x0645 },
  unicodeslot=0xFD86,
 },
 [0xFD87]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH MEEM WITH HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x0645, 0x062D },
  unicodeslot=0xFD87,
 },
 [0xFD88]={
  adobename="lammeemhahinitialarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH MEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x0645, 0x062D },
  unicodeslot=0xFD88,
 },
 [0xFD89]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH HAH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062D, 0x062C },
  unicodeslot=0xFD89,
 },
 [0xFD8A]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH HAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062D, 0x0645 },
  unicodeslot=0xFD8A,
 },
 [0xFD8B]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0645, 0x062D, 0x064A },
  unicodeslot=0xFD8B,
 },
 [0xFD8C]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH JEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062C, 0x062D },
  unicodeslot=0xFD8C,
 },
 [0xFD8D]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH JEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062C, 0x0645 },
  unicodeslot=0xFD8D,
 },
 [0xFD8E]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH KHAH WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062E, 0x062C },
  unicodeslot=0xFD8E,
 },
 [0xFD8F]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH KHAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062E, 0x0645 },
  unicodeslot=0xFD8F,
 },
 [0xFD92]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH JEEM WITH KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645, 0x062C, 0x062E },
  unicodeslot=0xFD92,
 },
 [0xFD93]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH MEEM WITH JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0647, 0x0645, 0x062C },
  unicodeslot=0xFD93,
 },
 [0xFD94]={
  category="lo",
  description="ARABIC LIGATURE HEH WITH MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0647, 0x0645, 0x0645 },
  unicodeslot=0xFD94,
 },
 [0xFD95]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH HAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646, 0x062D, 0x0645 },
  unicodeslot=0xFD95,
 },
 [0xFD96]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH HAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x062D, 0x0649 },
  unicodeslot=0xFD96,
 },
 [0xFD97]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH JEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x062C, 0x0645 },
  unicodeslot=0xFD97,
 },
 [0xFD98]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH JEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646, 0x062C, 0x0645 },
  unicodeslot=0xFD98,
 },
 [0xFD99]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH JEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x062C, 0x0649 },
  unicodeslot=0xFD99,
 },
 [0xFD9A]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x0645, 0x064A },
  unicodeslot=0xFD9A,
 },
 [0xFD9B]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH MEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x0645, 0x0649 },
  unicodeslot=0xFD9B,
 },
 [0xFD9C]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x0645, 0x0645 },
  unicodeslot=0xFD9C,
 },
 [0xFD9D]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x064A, 0x0645, 0x0645 },
  unicodeslot=0xFD9D,
 },
 [0xFD9E]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH KHAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628, 0x062E, 0x064A },
  unicodeslot=0xFD9E,
 },
 [0xFD9F]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH JEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x062C, 0x064A },
  unicodeslot=0xFD9F,
 },
 [0xFDA0]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH JEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x062C, 0x0649 },
  unicodeslot=0xFDA0,
 },
 [0xFDA1]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH KHAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x062E, 0x064A },
  unicodeslot=0xFDA1,
 },
 [0xFDA2]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH KHAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x062E, 0x0649 },
  unicodeslot=0xFDA2,
 },
 [0xFDA3]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x0645, 0x064A },
  unicodeslot=0xFDA3,
 },
 [0xFDA4]={
  category="lo",
  description="ARABIC LIGATURE TEH WITH MEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A, 0x0645, 0x0649 },
  unicodeslot=0xFDA4,
 },
 [0xFDA5]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062C, 0x0645, 0x064A },
  unicodeslot=0xFDA5,
 },
 [0xFDA6]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH HAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062C, 0x062D, 0x0649 },
  unicodeslot=0xFDA6,
 },
 [0xFDA7]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH MEEM WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062C, 0x0645, 0x0649 },
  unicodeslot=0xFDA7,
 },
 [0xFDA8]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH KHAH WITH ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633, 0x062E, 0x0649 },
  unicodeslot=0xFDA8,
 },
 [0xFDA9]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0635, 0x062D, 0x064A },
  unicodeslot=0xFDA9,
 },
 [0xFDAA]={
  category="lo",
  description="ARABIC LIGATURE SHEEN WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634, 0x062D, 0x064A },
  unicodeslot=0xFDAA,
 },
 [0xFDAB]={
  category="lo",
  description="ARABIC LIGATURE DAD WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0636, 0x062D, 0x064A },
  unicodeslot=0xFDAB,
 },
 [0xFDAC]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH JEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x062C, 0x064A },
  unicodeslot=0xFDAC,
 },
 [0xFDAD]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x0645, 0x064A },
  unicodeslot=0xFDAD,
 },
 [0xFDAE]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x062D, 0x064A },
  unicodeslot=0xFDAE,
 },
 [0xFDAF]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH JEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x062C, 0x064A },
  unicodeslot=0xFDAF,
 },
 [0xFDB0]={
  category="lo",
  description="ARABIC LIGATURE YEH WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A, 0x0645, 0x064A },
  unicodeslot=0xFDB0,
 },
 [0xFDB1]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0645, 0x0645, 0x064A },
  unicodeslot=0xFDB1,
 },
 [0xFDB2]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0642, 0x0645, 0x064A },
  unicodeslot=0xFDB2,
 },
 [0xFDB3]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x062D, 0x064A },
  unicodeslot=0xFDB3,
 },
 [0xFDB4]={
  category="lo",
  description="ARABIC LIGATURE QAF WITH MEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0642, 0x0645, 0x062D },
  unicodeslot=0xFDB4,
 },
 [0xFDB5]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH HAH WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x062D, 0x0645 },
  unicodeslot=0xFDB5,
 },
 [0xFDB6]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0639, 0x0645, 0x064A },
  unicodeslot=0xFDB6,
 },
 [0xFDB7]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0643, 0x0645, 0x064A },
  unicodeslot=0xFDB7,
 },
 [0xFDB8]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH JEEM WITH HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646, 0x062C, 0x062D },
  unicodeslot=0xFDB8,
 },
 [0xFDB9]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH KHAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0645, 0x062E, 0x064A },
  unicodeslot=0xFDB9,
 },
 [0xFDBA]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH JEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644, 0x062C, 0x0645 },
  unicodeslot=0xFDBA,
 },
 [0xFDBB]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH MEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0643, 0x0645, 0x0645 },
  unicodeslot=0xFDBB,
 },
 [0xFDBC]={
  category="lo",
  description="ARABIC LIGATURE LAM WITH JEEM WITH MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x062C, 0x0645 },
  unicodeslot=0xFDBC,
 },
 [0xFDBD]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH JEEM WITH HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x062C, 0x062D },
  unicodeslot=0xFDBD,
 },
 [0xFDBE]={
  category="lo",
  description="ARABIC LIGATURE JEEM WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062C, 0x062D, 0x064A },
  unicodeslot=0xFDBE,
 },
 [0xFDBF]={
  category="lo",
  description="ARABIC LIGATURE HAH WITH JEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062D, 0x062C, 0x064A },
  unicodeslot=0xFDBF,
 },
 [0xFDC0]={
  category="lo",
  description="ARABIC LIGATURE MEEM WITH JEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0645, 0x062C, 0x064A },
  unicodeslot=0xFDC0,
 },
 [0xFDC1]={
  category="lo",
  description="ARABIC LIGATURE FEH WITH MEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0641, 0x0645, 0x064A },
  unicodeslot=0xFDC1,
 },
 [0xFDC2]={
  category="lo",
  description="ARABIC LIGATURE BEH WITH HAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628, 0x062D, 0x064A },
  unicodeslot=0xFDC2,
 },
 [0xFDC3]={
  category="lo",
  description="ARABIC LIGATURE KAF WITH MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0643, 0x0645, 0x0645 },
  unicodeslot=0xFDC3,
 },
 [0xFDC4]={
  category="lo",
  description="ARABIC LIGATURE AIN WITH JEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0639, 0x062C, 0x0645 },
  unicodeslot=0xFDC4,
 },
 [0xFDC5]={
  category="lo",
  description="ARABIC LIGATURE SAD WITH MEEM WITH MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0635, 0x0645, 0x0645 },
  unicodeslot=0xFDC5,
 },
 [0xFDC6]={
  category="lo",
  description="ARABIC LIGATURE SEEN WITH KHAH WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633, 0x062E, 0x064A },
  unicodeslot=0xFDC6,
 },
 [0xFDC7]={
  category="lo",
  description="ARABIC LIGATURE NOON WITH JEEM WITH YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646, 0x062C, 0x064A },
  unicodeslot=0xFDC7,
 },
 [0xFDF0]={
  category="lo",
  description="ARABIC LIGATURE SALLA USED AS KORANIC STOP SIGN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x0644, 0x06D2 },
  unicodeslot=0xFDF0,
 },
 [0xFDF1]={
  category="lo",
  description="ARABIC LIGATURE QALA USED AS KORANIC STOP SIGN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0642, 0x0644, 0x06D2 },
  unicodeslot=0xFDF1,
 },
 [0xFDF2]={
  adobename="lamlamhehisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE ALLAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0627, 0x0644, 0x0644, 0x0647 },
  unicodeslot=0xFDF2,
 },
 [0xFDF3]={
  category="lo",
  description="ARABIC LIGATURE AKBAR ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0627, 0x0643, 0x0628, 0x0631 },
  unicodeslot=0xFDF3,
 },
 [0xFDF4]={
  category="lo",
  description="ARABIC LIGATURE MOHAMMAD ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0645, 0x062D, 0x0645, 0x062F },
  unicodeslot=0xFDF4,
 },
 [0xFDF5]={
  category="lo",
  description="ARABIC LIGATURE SALAM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x0644, 0x0639, 0x0645 },
  unicodeslot=0xFDF5,
 },
 [0xFDF6]={
  category="lo",
  description="ARABIC LIGATURE RASOUL ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0631, 0x0633, 0x0648, 0x0644 },
  unicodeslot=0xFDF6,
 },
 [0xFDF7]={
  category="lo",
  description="ARABIC LIGATURE ALAYHE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0639, 0x0644, 0x064A, 0x0647 },
  unicodeslot=0xFDF7,
 },
 [0xFDF8]={
  category="lo",
  description="ARABIC LIGATURE WASALLAM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0648, 0x0633, 0x0644, 0x0645 },
  unicodeslot=0xFDF8,
 },
 [0xFDF9]={
  category="lo",
  description="ARABIC LIGATURE SALLA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x0644, 0x0649 },
  unicodeslot=0xFDF9,
 },
 [0xFDFA]={
  adobename="sallallahoualayhewasallamarabic",
  category="lo",
  description="ARABIC LIGATURE SALLALLAHOU ALAYHE WASALLAM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635, 0x0644, 0x0649, 0x0020, 0x0627, 0x0644, 0x0644, 0x0647, 0x0020, 0x0639, 0x0644, 0x064A, 0x0647, 0x0020, 0x0648, 0x0633, 0x0644, 0x0645 },
  unicodeslot=0xFDFA,
 },
 [0xFDFB]={
  category="lo",
  description="ARABIC LIGATURE JALLAJALALOUHOU",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062C, 0x0644, 0x0020, 0x062C, 0x0644, 0x0627, 0x0644, 0x0647 },
  unicodeslot=0xFDFB,
 },
 [0xFDFC]={
  category="sc",
  description="RIAL SIGN",
  direction="al",
  linebreak="po",
  specials={ "isolated", 0x0631, 0x06CC, 0x0627, 0x0644 },
  unicodeslot=0xFDFC,
 },
 [0xFDFD]={
  category="so",
  description="ARABIC LIGATURE BISMILLAH AR-RAHMAN AR-RAHEEM",
  direction="on",
  linebreak="al",
  unicodeslot=0xFDFD,
 },
 [0xFE00]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0001",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE00,
 },
 [0xFE01]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0002",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE01,
 },
 [0xFE02]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0003",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE02,
 },
 [0xFE03]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0004",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE03,
 },
 [0xFE04]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0005",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE04,
 },
 [0xFE05]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0006",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE05,
 },
 [0xFE06]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0007",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE06,
 },
 [0xFE07]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0008",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE07,
 },
 [0xFE08]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0009",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE08,
 },
 [0xFE09]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x000A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE09,
 },
 [0xFE0A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x000B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE0A,
 },
 [0xFE0B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x000C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE0B,
 },
 [0xFE0C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x000D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE0C,
 },
 [0xFE0D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x000E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE0D,
 },
 [0xFE0E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x000F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE0E,
 },
 [0xFE0F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0010",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE0F,
 },
 [0xFE10]={
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL COMMA",
  direction="on",
  linebreak="is",
  specials={ "vertical", 0x002C },
  unicodeslot=0xFE10,
 },
 [0xFE11]={
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC COMMA",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x3001 },
  unicodeslot=0xFE11,
 },
 [0xFE12]={
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC FULL STOP",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x3002 },
  unicodeslot=0xFE12,
 },
 [0xFE13]={
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL COLON",
  direction="on",
  linebreak="is",
  specials={ "vertical", 0x003A },
  unicodeslot=0xFE13,
 },
 [0xFE14]={
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL SEMICOLON",
  direction="on",
  linebreak="is",
  specials={ "vertical", 0x003B },
  unicodeslot=0xFE14,
 },
 [0xFE15]={
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL EXCLAMATION MARK",
  direction="on",
  linebreak="ex",
  specials={ "vertical", 0x0021 },
  unicodeslot=0xFE15,
 },
 [0xFE16]={
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL QUESTION MARK",
  direction="on",
  linebreak="ex",
  specials={ "vertical", 0x003F },
  unicodeslot=0xFE16,
 },
 [0xFE17]={
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT WHITE LENTICULAR BRACKET",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x3016 },
  unicodeslot=0xFE17,
 },
 [0xFE18]={
  category="pe",
  cjkwd="w",
  comment="corrected description: brakcet",
  description="PRESENTATION FORM FOR VERTICAL RIGHT WHITE LENTICULAR BRACKET",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x3017 },
  unicodeslot=0xFE18,
 },
 [0xFE19]={
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL HORIZONTAL ELLIPSIS",
  direction="on",
  linebreak="in",
  specials={ "vertical", 0x2026 },
  unicodeslot=0xFE19,
 },
 [0xFE20]={
  category="mn",
  description="COMBINING LIGATURE LEFT HALF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE20,
 },
 [0xFE21]={
  category="mn",
  description="COMBINING LIGATURE RIGHT HALF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE21,
 },
 [0xFE22]={
  category="mn",
  description="COMBINING DOUBLE TILDE LEFT HALF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE22,
 },
 [0xFE23]={
  category="mn",
  description="COMBINING DOUBLE TILDE RIGHT HALF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE23,
 },
 [0xFE24]={
  category="mn",
  description="COMBINING MACRON LEFT HALF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE24,
 },
 [0xFE25]={
  category="mn",
  description="COMBINING MACRON RIGHT HALF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE25,
 },
 [0xFE26]={
  category="mn",
  description="COMBINING CONJOINING MACRON",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xFE26,
 },
 [0xFE30]={
  adobename="twodotleadervertical",
  category="po",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL TWO DOT LEADER",
  direction="on",
  linebreak="id",
  specials={ "vertical", 0x2025 },
  unicodeslot=0xFE30,
 },
 [0xFE31]={
  adobename="emdashvertical",
  category="pd",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL EM DASH",
  direction="on",
  linebreak="id",
  specials={ "vertical", 0x2014 },
  unicodeslot=0xFE31,
 },
 [0xFE32]={
  adobename="endashvertical",
  category="pd",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL EN DASH",
  direction="on",
  linebreak="id",
  specials={ "vertical", 0x2013 },
  unicodeslot=0xFE32,
 },
 [0xFE33]={
  adobename="underscorevertical",
  category="pc",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LOW LINE",
  direction="on",
  linebreak="id",
  specials={ "vertical", 0x005F },
  unicodeslot=0xFE33,
 },
 [0xFE34]={
  adobename="wavyunderscorevertical",
  category="pc",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL WAVY LOW LINE",
  direction="on",
  linebreak="id",
  specials={ "vertical", 0x005F },
  unicodeslot=0xFE34,
 },
 [0xFE35]={
  adobename="parenleftvertical",
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT PARENTHESIS",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x0028 },
  unicodeslot=0xFE35,
 },
 [0xFE36]={
  adobename="parenrightvertical",
  category="pe",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL RIGHT PARENTHESIS",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x0029 },
  unicodeslot=0xFE36,
 },
 [0xFE37]={
  adobename="braceleftvertical",
  category="ps",
  cjkwd="w",
  comment="weird math needed for mathml",
  description="PRESENTATION FORM FOR VERTICAL LEFT CURLY BRACKET",
  direction="on",
  linebreak="op",
  mathfiller="downbracefill",
  specials={ "vertical", 0x007B },
  unicodeslot=0xFE37,
 },
 [0xFE38]={
  adobename="bracerightvertical",
  category="pe",
  cjkwd="w",
  comment="weird math needed for mathml",
  description="PRESENTATION FORM FOR VERTICAL RIGHT CURLY BRACKET",
  direction="on",
  linebreak="cl",
  mathfiller="upbracefill",
  specials={ "vertical", 0x007D },
  unicodeslot=0xFE38,
 },
 [0xFE39]={
  adobename="tortoiseshellbracketleftvertical",
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x3014 },
  unicodeslot=0xFE39,
 },
 [0xFE3A]={
  adobename="tortoiseshellbracketrightvertical",
  category="pe",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL RIGHT TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x3015 },
  unicodeslot=0xFE3A,
 },
 [0xFE3B]={
  adobename="blacklenticularbracketleftvertical",
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT BLACK LENTICULAR BRACKET",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x3010 },
  unicodeslot=0xFE3B,
 },
 [0xFE3C]={
  adobename="blacklenticularbracketrightvertical",
  category="pe",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL RIGHT BLACK LENTICULAR BRACKET",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x3011 },
  unicodeslot=0xFE3C,
 },
 [0xFE3D]={
  adobename="dblanglebracketleftvertical",
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT DOUBLE ANGLE BRACKET",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x300A },
  unicodeslot=0xFE3D,
 },
 [0xFE3E]={
  adobename="dblanglebracketrightvertical",
  category="pe",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL RIGHT DOUBLE ANGLE BRACKET",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x300B },
  unicodeslot=0xFE3E,
 },
 [0xFE3F]={
  adobename="anglebracketleftvertical",
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT ANGLE BRACKET",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x3008 },
  unicodeslot=0xFE3F,
 },
 [0xFE40]={
  adobename="anglebracketrightvertical",
  category="pe",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL RIGHT ANGLE BRACKET",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x3009 },
  unicodeslot=0xFE40,
 },
 [0xFE41]={
  adobename="cornerbracketleftvertical",
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT CORNER BRACKET",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x300C },
  unicodeslot=0xFE41,
 },
 [0xFE42]={
  adobename="cornerbracketrightvertical",
  category="pe",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL RIGHT CORNER BRACKET",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x300D },
  unicodeslot=0xFE42,
 },
 [0xFE43]={
  adobename="whitecornerbracketleftvertical",
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT WHITE CORNER BRACKET",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x300E },
  unicodeslot=0xFE43,
 },
 [0xFE44]={
  adobename="whitecornerbracketrightvertical",
  category="pe",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL RIGHT WHITE CORNER BRACKET",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x300F },
  unicodeslot=0xFE44,
 },
 [0xFE45]={
  category="po",
  cjkwd="w",
  description="SESAME DOT",
  direction="on",
  linebreak="id",
  unicodeslot=0xFE45,
 },
 [0xFE46]={
  category="po",
  cjkwd="w",
  description="WHITE SESAME DOT",
  direction="on",
  linebreak="id",
  unicodeslot=0xFE46,
 },
 [0xFE47]={
  category="ps",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL LEFT SQUARE BRACKET",
  direction="on",
  linebreak="op",
  specials={ "vertical", 0x005B },
  unicodeslot=0xFE47,
 },
 [0xFE48]={
  category="pe",
  cjkwd="w",
  description="PRESENTATION FORM FOR VERTICAL RIGHT SQUARE BRACKET",
  direction="on",
  linebreak="cl",
  specials={ "vertical", 0x005D },
  unicodeslot=0xFE48,
 },
 [0xFE49]={
  adobename="overlinedashed",
  category="po",
  cjkwd="w",
  description="DASHED OVERLINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x203E },
  unicodeslot=0xFE49,
 },
 [0xFE4A]={
  adobename="overlinecenterline",
  category="po",
  cjkwd="w",
  description="CENTRELINE OVERLINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x203E },
  unicodeslot=0xFE4A,
 },
 [0xFE4B]={
  adobename="overlinewavy",
  category="po",
  cjkwd="w",
  description="WAVY OVERLINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x203E },
  unicodeslot=0xFE4B,
 },
 [0xFE4C]={
  adobename="overlinedblwavy",
  category="po",
  cjkwd="w",
  description="DOUBLE WAVY OVERLINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x203E },
  unicodeslot=0xFE4C,
 },
 [0xFE4D]={
  adobename="lowlinedashed",
  category="pc",
  cjkwd="w",
  description="DASHED LOW LINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x005F },
  unicodeslot=0xFE4D,
 },
 [0xFE4E]={
  adobename="lowlinecenterline",
  category="pc",
  cjkwd="w",
  description="CENTRELINE LOW LINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x005F },
  unicodeslot=0xFE4E,
 },
 [0xFE4F]={
  adobename="underscorewavy",
  category="pc",
  cjkwd="w",
  description="WAVY LOW LINE",
  direction="on",
  linebreak="id",
  specials={ "compat", 0x005F },
  unicodeslot=0xFE4F,
 },
 [0xFE50]={
  adobename="commasmall",
  category="po",
  cjkwd="w",
  description="SMALL COMMA",
  direction="cs",
  linebreak="cl",
  specials={ "small", 0x002C },
  unicodeslot=0xFE50,
 },
 [0xFE51]={
  category="po",
  cjkwd="w",
  description="SMALL IDEOGRAPHIC COMMA",
  direction="on",
  linebreak="id",
  specials={ "small", 0x3001 },
  unicodeslot=0xFE51,
 },
 [0xFE52]={
  adobename="periodsmall",
  category="po",
  cjkwd="w",
  description="SMALL FULL STOP",
  direction="cs",
  linebreak="cl",
  specials={ "small", 0x002E },
  unicodeslot=0xFE52,
 },
 [0xFE54]={
  adobename="semicolonsmall",
  category="po",
  cjkwd="w",
  description="SMALL SEMICOLON",
  direction="on",
  linebreak="ns",
  specials={ "small", 0x003B },
  unicodeslot=0xFE54,
 },
 [0xFE55]={
  adobename="colonsmall",
  category="po",
  cjkwd="w",
  description="SMALL COLON",
  direction="cs",
  linebreak="ns",
  specials={ "small", 0x003A },
  unicodeslot=0xFE55,
 },
 [0xFE56]={
  category="po",
  cjkwd="w",
  description="SMALL QUESTION MARK",
  direction="on",
  linebreak="ex",
  specials={ "small", 0x003F },
  unicodeslot=0xFE56,
 },
 [0xFE57]={
  category="po",
  cjkwd="w",
  description="SMALL EXCLAMATION MARK",
  direction="on",
  linebreak="ex",
  specials={ "small", 0x0021 },
  unicodeslot=0xFE57,
 },
 [0xFE58]={
  category="pd",
  cjkwd="w",
  description="SMALL EM DASH",
  direction="on",
  linebreak="id",
  specials={ "small", 0x2014 },
  unicodeslot=0xFE58,
 },
 [0xFE59]={
  adobename="parenleftsmall",
  category="ps",
  cjkwd="w",
  description="SMALL LEFT PARENTHESIS",
  direction="on",
  linebreak="op",
  mirror=0xFE5A,
  textclass="open",
  specials={ "small", 0x0028 },
  unicodeslot=0xFE59,
 },
 [0xFE5A]={
  adobename="parenrightsmall",
  category="pe",
  cjkwd="w",
  description="SMALL RIGHT PARENTHESIS",
  direction="on",
  linebreak="cl",
  mirror=0xFE59,
  textclass="close",
  specials={ "small", 0x0029 },
  unicodeslot=0xFE5A,
 },
 [0xFE5B]={
  adobename="braceleftsmall",
  category="ps",
  cjkwd="w",
  description="SMALL LEFT CURLY BRACKET",
  direction="on",
  linebreak="op",
  mirror=0xFE5C,
  textclass="open",
  specials={ "small", 0x007B },
  unicodeslot=0xFE5B,
 },
 [0xFE5C]={
  adobename="bracerightsmall",
  category="pe",
  cjkwd="w",
  description="SMALL RIGHT CURLY BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0xFE5B,
  textclass="close",
  specials={ "small", 0x007D },
  unicodeslot=0xFE5C,
 },
 [0xFE5D]={
  adobename="tortoiseshellbracketleftsmall",
  category="ps",
  cjkwd="w",
  description="SMALL LEFT TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="op",
  mirror=0xFE5E,
  textclass="open",
  specials={ "small", 0x3014 },
  unicodeslot=0xFE5D,
 },
 [0xFE5E]={
  adobename="tortoiseshellbracketrightsmall",
  category="pe",
  cjkwd="w",
  description="SMALL RIGHT TORTOISE SHELL BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0xFE5D,
  textclass="close",
  specials={ "small", 0x3015 },
  unicodeslot=0xFE5E,
 },
 [0xFE5F]={
  adobename="numbersignsmall",
  category="po",
  cjkwd="w",
  description="SMALL NUMBER SIGN",
  direction="et",
  linebreak="id",
  specials={ "small", 0x0023 },
  unicodeslot=0xFE5F,
 },
 [0xFE60]={
  category="po",
  cjkwd="w",
  description="SMALL AMPERSAND",
  direction="on",
  linebreak="id",
  specials={ "small", 0x0026 },
  unicodeslot=0xFE60,
 },
 [0xFE61]={
  adobename="asterisksmall",
  category="po",
  cjkwd="w",
  description="SMALL ASTERISK",
  direction="on",
  linebreak="id",
  specials={ "small", 0x002A },
  unicodeslot=0xFE61,
 },
 [0xFE62]={
  adobename="plussmall",
  category="sm",
  cjkwd="w",
  description="SMALL PLUS SIGN",
  direction="es",
  linebreak="id",
  specials={ "small", 0x002B },
  unicodeslot=0xFE62,
 },
 [0xFE63]={
  adobename="hyphensmall",
  category="pd",
  cjkwd="w",
  description="SMALL HYPHEN-MINUS",
  direction="es",
  linebreak="id",
  specials={ "small", 0x002D },
  unicodeslot=0xFE63,
 },
 [0xFE64]={
  adobename="lesssmall",
  category="sm",
  cjkwd="w",
  description="SMALL LESS-THAN SIGN",
  direction="on",
  linebreak="id",
  mirror=0xFE65,
  textclass="open",
  specials={ "small", 0x003C },
  unicodeslot=0xFE64,
 },
 [0xFE65]={
  adobename="greatersmall",
  category="sm",
  cjkwd="w",
  description="SMALL GREATER-THAN SIGN",
  direction="on",
  linebreak="id",
  mirror=0xFE64,
  textclass="close",
  specials={ "small", 0x003E },
  unicodeslot=0xFE65,
 },
 [0xFE66]={
  adobename="equalsmall",
  category="sm",
  cjkwd="w",
  description="SMALL EQUALS SIGN",
  direction="on",
  linebreak="id",
  specials={ "small", 0x003D },
  unicodeslot=0xFE66,
 },
 [0xFE68]={
  category="po",
  cjkwd="w",
  description="SMALL REVERSE SOLIDUS",
  direction="on",
  linebreak="id",
  specials={ "small", 0x005C },
  unicodeslot=0xFE68,
 },
 [0xFE69]={
  adobename="dollarsmall",
  category="sc",
  cjkwd="w",
  description="SMALL DOLLAR SIGN",
  direction="et",
  linebreak="pr",
  specials={ "small", 0x0024 },
  unicodeslot=0xFE69,
 },
 [0xFE6A]={
  adobename="percentsmall",
  category="po",
  cjkwd="w",
  description="SMALL PERCENT SIGN",
  direction="et",
  linebreak="po",
  specials={ "small", 0x0025 },
  unicodeslot=0xFE6A,
 },
 [0xFE6B]={
  adobename="atsmall",
  category="po",
  cjkwd="w",
  description="SMALL COMMERCIAL AT",
  direction="on",
  linebreak="id",
  specials={ "small", 0x0040 },
  unicodeslot=0xFE6B,
 },
 [0xFE70]={
  category="lo",
  description="ARABIC FATHATAN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064B },
  unicodeslot=0xFE70,
 },
 [0xFE71]={
  category="lo",
  description="ARABIC TATWEEL WITH FATHATAN ABOVE",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x064B },
  unicodeslot=0xFE71,
 },
 [0xFE72]={
  category="lo",
  description="ARABIC DAMMATAN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064C },
  unicodeslot=0xFE72,
 },
 [0xFE73]={
  category="lo",
  description="ARABIC TAIL FRAGMENT",
  direction="al",
  linebreak="al",
  unicodeslot=0xFE73,
 },
 [0xFE74]={
  category="lo",
  description="ARABIC KASRATAN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064D },
  unicodeslot=0xFE74,
 },
 [0xFE76]={
  category="lo",
  description="ARABIC FATHA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064E },
  unicodeslot=0xFE76,
 },
 [0xFE77]={
  category="lo",
  description="ARABIC FATHA MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x064E },
  unicodeslot=0xFE77,
 },
 [0xFE78]={
  category="lo",
  description="ARABIC DAMMA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x064F },
  unicodeslot=0xFE78,
 },
 [0xFE79]={
  category="lo",
  description="ARABIC DAMMA MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x064F },
  unicodeslot=0xFE79,
 },
 [0xFE7A]={
  category="lo",
  description="ARABIC KASRA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x0650 },
  unicodeslot=0xFE7A,
 },
 [0xFE7B]={
  category="lo",
  description="ARABIC KASRA MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x0650 },
  unicodeslot=0xFE7B,
 },
 [0xFE7C]={
  category="lo",
  description="ARABIC SHADDA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x0651 },
  unicodeslot=0xFE7C,
 },
 [0xFE7D]={
  category="lo",
  description="ARABIC SHADDA MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x0651 },
  unicodeslot=0xFE7D,
 },
 [0xFE7E]={
  category="lo",
  description="ARABIC SUKUN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0020, 0x0652 },
  unicodeslot=0xFE7E,
 },
 [0xFE7F]={
  category="lo",
  description="ARABIC SUKUN MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0640, 0x0652 },
  unicodeslot=0xFE7F,
 },
 [0xFE80]={
  category="lo",
  description="ARABIC LETTER HAMZA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0621 },
  unicodeslot=0xFE80,
 },
 [0xFE81]={
  category="lo",
  description="ARABIC LETTER ALEF WITH MADDA ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "isolated", 0x0622 },
  unicodeslot=0xFE81,
 },
 [0xFE82]={
  adobename="alefmaddaabovefinalarabic",
  category="lo",
  description="ARABIC LETTER ALEF WITH MADDA ABOVE FINAL FORM",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "final", 0x0622 },
  unicodeslot=0xFE82,
 },
 [0xFE83]={
  category="lo",
  description="ARABIC LETTER ALEF WITH HAMZA ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "isolated", 0x0623 },
  unicodeslot=0xFE83,
 },
 [0xFE84]={
  adobename="alefhamzaabovefinalarabic",
  category="lo",
  description="ARABIC LETTER ALEF WITH HAMZA ABOVE FINAL FORM",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "final", 0x0623 },
  unicodeslot=0xFE84,
 },
 [0xFE85]={
  category="lo",
  description="ARABIC LETTER WAW WITH HAMZA ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  shcode=0x0648,
  specials={ "isolated", 0x0624 },
  unicodeslot=0xFE85,
 },
 [0xFE86]={
  adobename="wawhamzaabovefinalarabic",
  category="lo",
  description="ARABIC LETTER WAW WITH HAMZA ABOVE FINAL FORM",
  direction="al",
  linebreak="al",
  shcode=0x0648,
  specials={ "final", 0x0624 },
  unicodeslot=0xFE86,
 },
 [0xFE87]={
  category="lo",
  description="ARABIC LETTER ALEF WITH HAMZA BELOW ISOLATED FORM",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "isolated", 0x0625 },
  unicodeslot=0xFE87,
 },
 [0xFE88]={
  adobename="alefhamzabelowfinalarabic",
  category="lo",
  description="ARABIC LETTER ALEF WITH HAMZA BELOW FINAL FORM",
  direction="al",
  linebreak="al",
  shcode=0x0627,
  specials={ "final", 0x0625 },
  unicodeslot=0xFE88,
 },
 [0xFE89]={
  category="lo",
  description="ARABIC LETTER YEH WITH HAMZA ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  shcode=0x064A,
  specials={ "isolated", 0x0626 },
  unicodeslot=0xFE89,
 },
 [0xFE8A]={
  adobename="yehhamzaabovefinalarabic",
  category="lo",
  description="ARABIC LETTER YEH WITH HAMZA ABOVE FINAL FORM",
  direction="al",
  linebreak="al",
  shcode=0x064A,
  specials={ "final", 0x0626 },
  unicodeslot=0xFE8A,
 },
 [0xFE8B]={
  adobename="yehhamzaaboveinitialarabic",
  category="lo",
  description="ARABIC LETTER YEH WITH HAMZA ABOVE INITIAL FORM",
  direction="al",
  linebreak="al",
  shcode=0x064A,
  specials={ "initial", 0x0626 },
  unicodeslot=0xFE8B,
 },
 [0xFE8C]={
  adobename="yehhamzaabovemedialarabic",
  category="lo",
  description="ARABIC LETTER YEH WITH HAMZA ABOVE MEDIAL FORM",
  direction="al",
  linebreak="al",
  shcode=0x064A,
  specials={ "medial", 0x0626 },
  unicodeslot=0xFE8C,
 },
 [0xFE8D]={
  category="lo",
  description="ARABIC LETTER ALEF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0627 },
  unicodeslot=0xFE8D,
 },
 [0xFE8E]={
  adobename="aleffinalarabic",
  category="lo",
  description="ARABIC LETTER ALEF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0627 },
  unicodeslot=0xFE8E,
 },
 [0xFE8F]={
  category="lo",
  description="ARABIC LETTER BEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0628 },
  unicodeslot=0xFE8F,
 },
 [0xFE90]={
  adobename="behfinalarabic",
  category="lo",
  description="ARABIC LETTER BEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0628 },
  unicodeslot=0xFE90,
 },
 [0xFE91]={
  adobename="behinitialarabic",
  category="lo",
  description="ARABIC LETTER BEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0628 },
  unicodeslot=0xFE91,
 },
 [0xFE92]={
  adobename="behmedialarabic",
  category="lo",
  description="ARABIC LETTER BEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0628 },
  unicodeslot=0xFE92,
 },
 [0xFE93]={
  category="lo",
  description="ARABIC LETTER TEH MARBUTA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0629 },
  unicodeslot=0xFE93,
 },
 [0xFE94]={
  adobename="tehmarbutafinalarabic",
  category="lo",
  description="ARABIC LETTER TEH MARBUTA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0629 },
  unicodeslot=0xFE94,
 },
 [0xFE95]={
  category="lo",
  description="ARABIC LETTER TEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062A },
  unicodeslot=0xFE95,
 },
 [0xFE96]={
  adobename="tehfinalarabic",
  category="lo",
  description="ARABIC LETTER TEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062A },
  unicodeslot=0xFE96,
 },
 [0xFE97]={
  adobename="tehinitialarabic",
  category="lo",
  description="ARABIC LETTER TEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062A },
  unicodeslot=0xFE97,
 },
 [0xFE98]={
  adobename="tehmedialarabic",
  category="lo",
  description="ARABIC LETTER TEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062A },
  unicodeslot=0xFE98,
 },
 [0xFE99]={
  category="lo",
  description="ARABIC LETTER THEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062B },
  unicodeslot=0xFE99,
 },
 [0xFE9A]={
  adobename="thehfinalarabic",
  category="lo",
  description="ARABIC LETTER THEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062B },
  unicodeslot=0xFE9A,
 },
 [0xFE9B]={
  adobename="thehinitialarabic",
  category="lo",
  description="ARABIC LETTER THEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062B },
  unicodeslot=0xFE9B,
 },
 [0xFE9C]={
  adobename="thehmedialarabic",
  category="lo",
  description="ARABIC LETTER THEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062B },
  unicodeslot=0xFE9C,
 },
 [0xFE9D]={
  category="lo",
  description="ARABIC LETTER JEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062C },
  unicodeslot=0xFE9D,
 },
 [0xFE9E]={
  adobename="jeemfinalarabic",
  category="lo",
  description="ARABIC LETTER JEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062C },
  unicodeslot=0xFE9E,
 },
 [0xFE9F]={
  adobename="jeeminitialarabic",
  category="lo",
  description="ARABIC LETTER JEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062C },
  unicodeslot=0xFE9F,
 },
 [0xFEA0]={
  adobename="jeemmedialarabic",
  category="lo",
  description="ARABIC LETTER JEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062C },
  unicodeslot=0xFEA0,
 },
 [0xFEA1]={
  category="lo",
  description="ARABIC LETTER HAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062D },
  unicodeslot=0xFEA1,
 },
 [0xFEA2]={
  adobename="hahfinalarabic",
  category="lo",
  description="ARABIC LETTER HAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062D },
  unicodeslot=0xFEA2,
 },
 [0xFEA3]={
  adobename="hahinitialarabic",
  category="lo",
  description="ARABIC LETTER HAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062D },
  unicodeslot=0xFEA3,
 },
 [0xFEA4]={
  adobename="hahmedialarabic",
  category="lo",
  description="ARABIC LETTER HAH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062D },
  unicodeslot=0xFEA4,
 },
 [0xFEA5]={
  category="lo",
  description="ARABIC LETTER KHAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062E },
  unicodeslot=0xFEA5,
 },
 [0xFEA6]={
  adobename="khahfinalarabic",
  category="lo",
  description="ARABIC LETTER KHAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062E },
  unicodeslot=0xFEA6,
 },
 [0xFEA7]={
  adobename="khahinitialarabic",
  category="lo",
  description="ARABIC LETTER KHAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x062E },
  unicodeslot=0xFEA7,
 },
 [0xFEA8]={
  adobename="khahmedialarabic",
  category="lo",
  description="ARABIC LETTER KHAH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x062E },
  unicodeslot=0xFEA8,
 },
 [0xFEA9]={
  category="lo",
  description="ARABIC LETTER DAL ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x062F },
  unicodeslot=0xFEA9,
 },
 [0xFEAA]={
  adobename="dalfinalarabic",
  category="lo",
  description="ARABIC LETTER DAL FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x062F },
  unicodeslot=0xFEAA,
 },
 [0xFEAB]={
  category="lo",
  description="ARABIC LETTER THAL ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0630 },
  unicodeslot=0xFEAB,
 },
 [0xFEAC]={
  adobename="thalfinalarabic",
  category="lo",
  description="ARABIC LETTER THAL FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0630 },
  unicodeslot=0xFEAC,
 },
 [0xFEAD]={
  category="lo",
  description="ARABIC LETTER REH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0631 },
  unicodeslot=0xFEAD,
 },
 [0xFEAE]={
  adobename="rehfinalarabic",
  category="lo",
  description="ARABIC LETTER REH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0631 },
  unicodeslot=0xFEAE,
 },
 [0xFEAF]={
  category="lo",
  description="ARABIC LETTER ZAIN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0632 },
  unicodeslot=0xFEAF,
 },
 [0xFEB0]={
  adobename="zainfinalarabic",
  category="lo",
  description="ARABIC LETTER ZAIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0632 },
  unicodeslot=0xFEB0,
 },
 [0xFEB1]={
  category="lo",
  description="ARABIC LETTER SEEN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0633 },
  unicodeslot=0xFEB1,
 },
 [0xFEB2]={
  adobename="seenfinalarabic",
  category="lo",
  description="ARABIC LETTER SEEN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0633 },
  unicodeslot=0xFEB2,
 },
 [0xFEB3]={
  adobename="seeninitialarabic",
  category="lo",
  description="ARABIC LETTER SEEN INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0633 },
  unicodeslot=0xFEB3,
 },
 [0xFEB4]={
  adobename="seenmedialarabic",
  category="lo",
  description="ARABIC LETTER SEEN MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0633 },
  unicodeslot=0xFEB4,
 },
 [0xFEB5]={
  category="lo",
  description="ARABIC LETTER SHEEN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0634 },
  unicodeslot=0xFEB5,
 },
 [0xFEB6]={
  adobename="sheenfinalarabic",
  category="lo",
  description="ARABIC LETTER SHEEN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0634 },
  unicodeslot=0xFEB6,
 },
 [0xFEB7]={
  adobename="sheeninitialarabic",
  category="lo",
  description="ARABIC LETTER SHEEN INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0634 },
  unicodeslot=0xFEB7,
 },
 [0xFEB8]={
  adobename="sheenmedialarabic",
  category="lo",
  description="ARABIC LETTER SHEEN MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0634 },
  unicodeslot=0xFEB8,
 },
 [0xFEB9]={
  category="lo",
  description="ARABIC LETTER SAD ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0635 },
  unicodeslot=0xFEB9,
 },
 [0xFEBA]={
  adobename="sadfinalarabic",
  category="lo",
  description="ARABIC LETTER SAD FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0635 },
  unicodeslot=0xFEBA,
 },
 [0xFEBB]={
  adobename="sadinitialarabic",
  category="lo",
  description="ARABIC LETTER SAD INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0635 },
  unicodeslot=0xFEBB,
 },
 [0xFEBC]={
  adobename="sadmedialarabic",
  category="lo",
  description="ARABIC LETTER SAD MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0635 },
  unicodeslot=0xFEBC,
 },
 [0xFEBD]={
  category="lo",
  description="ARABIC LETTER DAD ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0636 },
  unicodeslot=0xFEBD,
 },
 [0xFEBE]={
  adobename="dadfinalarabic",
  category="lo",
  description="ARABIC LETTER DAD FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0636 },
  unicodeslot=0xFEBE,
 },
 [0xFEBF]={
  adobename="dadinitialarabic",
  category="lo",
  description="ARABIC LETTER DAD INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0636 },
  unicodeslot=0xFEBF,
 },
 [0xFEC0]={
  adobename="dadmedialarabic",
  category="lo",
  description="ARABIC LETTER DAD MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0636 },
  unicodeslot=0xFEC0,
 },
 [0xFEC1]={
  category="lo",
  description="ARABIC LETTER TAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0637 },
  unicodeslot=0xFEC1,
 },
 [0xFEC2]={
  adobename="tahfinalarabic",
  category="lo",
  description="ARABIC LETTER TAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0637 },
  unicodeslot=0xFEC2,
 },
 [0xFEC3]={
  adobename="tahinitialarabic",
  category="lo",
  description="ARABIC LETTER TAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0637 },
  unicodeslot=0xFEC3,
 },
 [0xFEC4]={
  adobename="tahmedialarabic",
  category="lo",
  description="ARABIC LETTER TAH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0637 },
  unicodeslot=0xFEC4,
 },
 [0xFEC5]={
  category="lo",
  description="ARABIC LETTER ZAH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0638 },
  unicodeslot=0xFEC5,
 },
 [0xFEC6]={
  adobename="zahfinalarabic",
  category="lo",
  description="ARABIC LETTER ZAH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0638 },
  unicodeslot=0xFEC6,
 },
 [0xFEC7]={
  adobename="zahinitialarabic",
  category="lo",
  description="ARABIC LETTER ZAH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0638 },
  unicodeslot=0xFEC7,
 },
 [0xFEC8]={
  adobename="zahmedialarabic",
  category="lo",
  description="ARABIC LETTER ZAH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0638 },
  unicodeslot=0xFEC8,
 },
 [0xFEC9]={
  category="lo",
  description="ARABIC LETTER AIN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0639 },
  unicodeslot=0xFEC9,
 },
 [0xFECA]={
  adobename="ainfinalarabic",
  category="lo",
  description="ARABIC LETTER AIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0639 },
  unicodeslot=0xFECA,
 },
 [0xFECB]={
  adobename="aininitialarabic",
  category="lo",
  description="ARABIC LETTER AIN INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0639 },
  unicodeslot=0xFECB,
 },
 [0xFECC]={
  adobename="ainmedialarabic",
  category="lo",
  description="ARABIC LETTER AIN MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0639 },
  unicodeslot=0xFECC,
 },
 [0xFECD]={
  category="lo",
  description="ARABIC LETTER GHAIN ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x063A },
  unicodeslot=0xFECD,
 },
 [0xFECE]={
  adobename="ghainfinalarabic",
  category="lo",
  description="ARABIC LETTER GHAIN FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x063A },
  unicodeslot=0xFECE,
 },
 [0xFECF]={
  adobename="ghaininitialarabic",
  category="lo",
  description="ARABIC LETTER GHAIN INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x063A },
  unicodeslot=0xFECF,
 },
 [0xFED0]={
  adobename="ghainmedialarabic",
  category="lo",
  description="ARABIC LETTER GHAIN MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x063A },
  unicodeslot=0xFED0,
 },
 [0xFED1]={
  category="lo",
  description="ARABIC LETTER FEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0641 },
  unicodeslot=0xFED1,
 },
 [0xFED2]={
  adobename="fehfinalarabic",
  category="lo",
  description="ARABIC LETTER FEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0641 },
  unicodeslot=0xFED2,
 },
 [0xFED3]={
  adobename="fehinitialarabic",
  category="lo",
  description="ARABIC LETTER FEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0641 },
  unicodeslot=0xFED3,
 },
 [0xFED4]={
  adobename="fehmedialarabic",
  category="lo",
  description="ARABIC LETTER FEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0641 },
  unicodeslot=0xFED4,
 },
 [0xFED5]={
  category="lo",
  description="ARABIC LETTER QAF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0642 },
  unicodeslot=0xFED5,
 },
 [0xFED6]={
  adobename="qaffinalarabic",
  category="lo",
  description="ARABIC LETTER QAF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0642 },
  unicodeslot=0xFED6,
 },
 [0xFED7]={
  adobename="qafinitialarabic",
  category="lo",
  description="ARABIC LETTER QAF INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0642 },
  unicodeslot=0xFED7,
 },
 [0xFED8]={
  adobename="qafmedialarabic",
  category="lo",
  description="ARABIC LETTER QAF MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0642 },
  unicodeslot=0xFED8,
 },
 [0xFED9]={
  category="lo",
  description="ARABIC LETTER KAF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0643 },
  unicodeslot=0xFED9,
 },
 [0xFEDA]={
  adobename="kaffinalarabic",
  category="lo",
  description="ARABIC LETTER KAF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0643 },
  unicodeslot=0xFEDA,
 },
 [0xFEDB]={
  adobename="kafinitialarabic",
  category="lo",
  description="ARABIC LETTER KAF INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0643 },
  unicodeslot=0xFEDB,
 },
 [0xFEDC]={
  adobename="kafmedialarabic",
  category="lo",
  description="ARABIC LETTER KAF MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0643 },
  unicodeslot=0xFEDC,
 },
 [0xFEDD]={
  category="lo",
  description="ARABIC LETTER LAM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644 },
  unicodeslot=0xFEDD,
 },
 [0xFEDE]={
  adobename="lamfinalarabic",
  category="lo",
  description="ARABIC LETTER LAM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644 },
  unicodeslot=0xFEDE,
 },
 [0xFEDF]={
  adobename="lammeemkhahinitialarabic",
  category="lo",
  description="ARABIC LETTER LAM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0644 },
  unicodeslot=0xFEDF,
 },
 [0xFEE0]={
  adobename="lammedialarabic",
  category="lo",
  description="ARABIC LETTER LAM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0644 },
  unicodeslot=0xFEE0,
 },
 [0xFEE1]={
  category="lo",
  description="ARABIC LETTER MEEM ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0645 },
  unicodeslot=0xFEE1,
 },
 [0xFEE2]={
  adobename="meemfinalarabic",
  category="lo",
  description="ARABIC LETTER MEEM FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0645 },
  unicodeslot=0xFEE2,
 },
 [0xFEE3]={
  adobename="meeminitialarabic",
  category="lo",
  description="ARABIC LETTER MEEM INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0645 },
  unicodeslot=0xFEE3,
 },
 [0xFEE4]={
  adobename="meemmedialarabic",
  category="lo",
  description="ARABIC LETTER MEEM MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0645 },
  unicodeslot=0xFEE4,
 },
 [0xFEE5]={
  category="lo",
  description="ARABIC LETTER NOON ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0646 },
  unicodeslot=0xFEE5,
 },
 [0xFEE6]={
  adobename="noonfinalarabic",
  category="lo",
  description="ARABIC LETTER NOON FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0646 },
  unicodeslot=0xFEE6,
 },
 [0xFEE7]={
  adobename="nooninitialarabic",
  category="lo",
  description="ARABIC LETTER NOON INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0646 },
  unicodeslot=0xFEE7,
 },
 [0xFEE8]={
  adobename="noonmedialarabic",
  category="lo",
  description="ARABIC LETTER NOON MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0646 },
  unicodeslot=0xFEE8,
 },
 [0xFEE9]={
  category="lo",
  description="ARABIC LETTER HEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0647 },
  unicodeslot=0xFEE9,
 },
 [0xFEEA]={
  adobename="hehfinalarabic",
  category="lo",
  description="ARABIC LETTER HEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0647 },
  unicodeslot=0xFEEA,
 },
 [0xFEEB]={
  adobename="hehinitialarabic",
  category="lo",
  description="ARABIC LETTER HEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x0647 },
  unicodeslot=0xFEEB,
 },
 [0xFEEC]={
  adobename="hehmedialarabic",
  category="lo",
  description="ARABIC LETTER HEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x0647 },
  unicodeslot=0xFEEC,
 },
 [0xFEED]={
  category="lo",
  description="ARABIC LETTER WAW ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0648 },
  unicodeslot=0xFEED,
 },
 [0xFEEE]={
  adobename="wawfinalarabic",
  category="lo",
  description="ARABIC LETTER WAW FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0648 },
  unicodeslot=0xFEEE,
 },
 [0xFEEF]={
  category="lo",
  description="ARABIC LETTER ALEF MAKSURA ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0649 },
  unicodeslot=0xFEEF,
 },
 [0xFEF0]={
  adobename="alefmaksurafinalarabic",
  category="lo",
  description="ARABIC LETTER ALEF MAKSURA FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0649 },
  unicodeslot=0xFEF0,
 },
 [0xFEF1]={
  category="lo",
  description="ARABIC LETTER YEH ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x064A },
  unicodeslot=0xFEF1,
 },
 [0xFEF2]={
  adobename="yehfinalarabic",
  category="lo",
  description="ARABIC LETTER YEH FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x064A },
  unicodeslot=0xFEF2,
 },
 [0xFEF3]={
  adobename="yehinitialarabic",
  category="lo",
  description="ARABIC LETTER YEH INITIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "initial", 0x064A },
  unicodeslot=0xFEF3,
 },
 [0xFEF4]={
  adobename="yehmedialarabic",
  category="lo",
  description="ARABIC LETTER YEH MEDIAL FORM",
  direction="al",
  linebreak="al",
  specials={ "medial", 0x064A },
  unicodeslot=0xFEF4,
 },
 [0xFEF5]={
  adobename="lamalefmaddaaboveisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x0622 },
  unicodeslot=0xFEF5,
 },
 [0xFEF6]={
  adobename="lamalefmaddaabovefinalarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x0622 },
  unicodeslot=0xFEF6,
 },
 [0xFEF7]={
  adobename="lamalefhamzaaboveisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x0623 },
  unicodeslot=0xFEF7,
 },
 [0xFEF8]={
  adobename="lamalefhamzaabovefinalarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x0623 },
  unicodeslot=0xFEF8,
 },
 [0xFEF9]={
  adobename="lamalefhamzabelowisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x0625 },
  unicodeslot=0xFEF9,
 },
 [0xFEFA]={
  adobename="lamalefhamzabelowfinalarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x0625 },
  unicodeslot=0xFEFA,
 },
 [0xFEFB]={
  adobename="lamalefisolatedarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF ISOLATED FORM",
  direction="al",
  linebreak="al",
  specials={ "isolated", 0x0644, 0x0627 },
  unicodeslot=0xFEFB,
 },
 [0xFEFC]={
  adobename="lamaleffinalarabic",
  category="lo",
  description="ARABIC LIGATURE LAM WITH ALEF FINAL FORM",
  direction="al",
  linebreak="al",
  specials={ "final", 0x0644, 0x0627 },
  unicodeslot=0xFEFC,
 },
 [0xFEFF]={
  adobename="zerowidthjoiner",
  category="cf",
  contextname="zerowidthnobreakspace",
  description="ZERO WIDTH NO-BREAK SPACE",
  direction="bn",
  linebreak="wj",
  unicodeslot=0xFEFF,
 },
 [0xFF01]={
  adobename="exclammonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH EXCLAMATION MARK",
  direction="on",
  linebreak="ex",
  specials={ "wide", 0x0021 },
  unicodeslot=0xFF01,
 },
 [0xFF02]={
  adobename="quotedblmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH QUOTATION MARK",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x0022 },
  unicodeslot=0xFF02,
 },
 [0xFF03]={
  adobename="numbersignmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH NUMBER SIGN",
  direction="et",
  linebreak="id",
  specials={ "wide", 0x0023 },
  unicodeslot=0xFF03,
 },
 [0xFF04]={
  adobename="dollarmonospace",
  category="sc",
  cjkwd="f",
  description="FULLWIDTH DOLLAR SIGN",
  direction="et",
  linebreak="pr",
  specials={ "wide", 0x0024 },
  unicodeslot=0xFF04,
 },
 [0xFF05]={
  adobename="percentmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH PERCENT SIGN",
  direction="et",
  linebreak="po",
  specials={ "wide", 0x0025 },
  unicodeslot=0xFF05,
 },
 [0xFF06]={
  adobename="ampersandmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH AMPERSAND",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x0026 },
  unicodeslot=0xFF06,
 },
 [0xFF07]={
  adobename="quotesinglemonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH APOSTROPHE",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x0027 },
  unicodeslot=0xFF07,
 },
 [0xFF08]={
  adobename="parenleftmonospace",
  category="ps",
  cjkwd="f",
  description="FULLWIDTH LEFT PARENTHESIS",
  direction="on",
  linebreak="op",
  mirror=0xFF09,
  textclass="open",
  specials={ "wide", 0x0028 },
  unicodeslot=0xFF08,
 },
 [0xFF09]={
  adobename="parenrightmonospace",
  category="pe",
  cjkwd="f",
  description="FULLWIDTH RIGHT PARENTHESIS",
  direction="on",
  linebreak="cl",
  mirror=0xFF08,
  textclass="close",
  specials={ "wide", 0x0029 },
  unicodeslot=0xFF09,
 },
 [0xFF0A]={
  adobename="asteriskmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH ASTERISK",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x002A },
  unicodeslot=0xFF0A,
 },
 [0xFF0B]={
  adobename="plusmonospace",
  category="sm",
  cjkwd="f",
  description="FULLWIDTH PLUS SIGN",
  direction="es",
  linebreak="id",
  specials={ "wide", 0x002B },
  unicodeslot=0xFF0B,
 },
 [0xFF0C]={
  adobename="commamonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH COMMA",
  direction="cs",
  linebreak="cl",
  specials={ "wide", 0x002C },
  unicodeslot=0xFF0C,
 },
 [0xFF0D]={
  adobename="hyphenmonospace",
  category="pd",
  cjkwd="f",
  description="FULLWIDTH HYPHEN-MINUS",
  direction="es",
  linebreak="id",
  specials={ "wide", 0x002D },
  unicodeslot=0xFF0D,
 },
 [0xFF0E]={
  adobename="periodmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH FULL STOP",
  direction="cs",
  linebreak="cl",
  specials={ "wide", 0x002E },
  unicodeslot=0xFF0E,
 },
 [0xFF0F]={
  adobename="slashmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH SOLIDUS",
  direction="cs",
  linebreak="id",
  specials={ "wide", 0x002F },
  unicodeslot=0xFF0F,
 },
 [0xFF10]={
  adobename="zeromonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT ZERO",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0030 },
  unicodeslot=0xFF10,
 },
 [0xFF11]={
  adobename="onemonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT ONE",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0031 },
  unicodeslot=0xFF11,
 },
 [0xFF12]={
  adobename="twomonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT TWO",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0032 },
  unicodeslot=0xFF12,
 },
 [0xFF13]={
  adobename="threemonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT THREE",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0033 },
  unicodeslot=0xFF13,
 },
 [0xFF14]={
  adobename="fourmonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT FOUR",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0034 },
  unicodeslot=0xFF14,
 },
 [0xFF15]={
  adobename="fivemonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT FIVE",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0035 },
  unicodeslot=0xFF15,
 },
 [0xFF16]={
  adobename="sixmonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT SIX",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0036 },
  unicodeslot=0xFF16,
 },
 [0xFF17]={
  adobename="sevenmonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT SEVEN",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0037 },
  unicodeslot=0xFF17,
 },
 [0xFF18]={
  adobename="eightmonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT EIGHT",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0038 },
  unicodeslot=0xFF18,
 },
 [0xFF19]={
  adobename="ninemonospace",
  category="nd",
  cjkwd="f",
  description="FULLWIDTH DIGIT NINE",
  direction="en",
  linebreak="id",
  specials={ "wide", 0x0039 },
  unicodeslot=0xFF19,
 },
 [0xFF1A]={
  adobename="colonmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH COLON",
  direction="cs",
  linebreak="ns",
  specials={ "wide", 0x003A },
  unicodeslot=0xFF1A,
 },
 [0xFF1B]={
  adobename="semicolonmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH SEMICOLON",
  direction="on",
  linebreak="ns",
  specials={ "wide", 0x003B },
  unicodeslot=0xFF1B,
 },
 [0xFF1C]={
  adobename="lessmonospace",
  category="sm",
  cjkwd="f",
  description="FULLWIDTH LESS-THAN SIGN",
  direction="on",
  linebreak="id",
  mirror=0xFF1E,
  textclass="open",
  specials={ "wide", 0x003C },
  unicodeslot=0xFF1C,
 },
 [0xFF1D]={
  adobename="equalmonospace",
  category="sm",
  cjkwd="f",
  description="FULLWIDTH EQUALS SIGN",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x003D },
  unicodeslot=0xFF1D,
 },
 [0xFF1E]={
  adobename="greatermonospace",
  category="sm",
  cjkwd="f",
  description="FULLWIDTH GREATER-THAN SIGN",
  direction="on",
  linebreak="id",
  mirror=0xFF1C,
  textclass="close",
  specials={ "wide", 0x003E },
  unicodeslot=0xFF1E,
 },
 [0xFF1F]={
  adobename="questionmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH QUESTION MARK",
  direction="on",
  linebreak="ex",
  specials={ "wide", 0x003F },
  unicodeslot=0xFF1F,
 },
 [0xFF20]={
  adobename="atmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH COMMERCIAL AT",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x0040 },
  unicodeslot=0xFF20,
 },
 [0xFF21]={
  adobename="Amonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER A",
  direction="l",
  lccode=0xFF41,
  linebreak="id",
  specials={ "wide", 0x0041 },
  unicodeslot=0xFF21,
 },
 [0xFF22]={
  adobename="Bmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER B",
  direction="l",
  lccode=0xFF42,
  linebreak="id",
  specials={ "wide", 0x0042 },
  unicodeslot=0xFF22,
 },
 [0xFF23]={
  adobename="Cmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER C",
  direction="l",
  lccode=0xFF43,
  linebreak="id",
  specials={ "wide", 0x0043 },
  unicodeslot=0xFF23,
 },
 [0xFF24]={
  adobename="Dmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER D",
  direction="l",
  lccode=0xFF44,
  linebreak="id",
  specials={ "wide", 0x0044 },
  unicodeslot=0xFF24,
 },
 [0xFF25]={
  adobename="Emonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER E",
  direction="l",
  lccode=0xFF45,
  linebreak="id",
  specials={ "wide", 0x0045 },
  unicodeslot=0xFF25,
 },
 [0xFF26]={
  adobename="Fmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER F",
  direction="l",
  lccode=0xFF46,
  linebreak="id",
  specials={ "wide", 0x0046 },
  unicodeslot=0xFF26,
 },
 [0xFF27]={
  adobename="Gmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER G",
  direction="l",
  lccode=0xFF47,
  linebreak="id",
  specials={ "wide", 0x0047 },
  unicodeslot=0xFF27,
 },
 [0xFF28]={
  adobename="Hmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER H",
  direction="l",
  lccode=0xFF48,
  linebreak="id",
  specials={ "wide", 0x0048 },
  unicodeslot=0xFF28,
 },
 [0xFF29]={
  adobename="Imonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER I",
  direction="l",
  lccode=0xFF49,
  linebreak="id",
  specials={ "wide", 0x0049 },
  unicodeslot=0xFF29,
 },
 [0xFF2A]={
  adobename="Jmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER J",
  direction="l",
  lccode=0xFF4A,
  linebreak="id",
  specials={ "wide", 0x004A },
  unicodeslot=0xFF2A,
 },
 [0xFF2B]={
  adobename="Kmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER K",
  direction="l",
  lccode=0xFF4B,
  linebreak="id",
  specials={ "wide", 0x004B },
  unicodeslot=0xFF2B,
 },
 [0xFF2C]={
  adobename="Lmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER L",
  direction="l",
  lccode=0xFF4C,
  linebreak="id",
  specials={ "wide", 0x004C },
  unicodeslot=0xFF2C,
 },
 [0xFF2D]={
  adobename="Mmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER M",
  direction="l",
  lccode=0xFF4D,
  linebreak="id",
  specials={ "wide", 0x004D },
  unicodeslot=0xFF2D,
 },
 [0xFF2E]={
  adobename="Nmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER N",
  direction="l",
  lccode=0xFF4E,
  linebreak="id",
  specials={ "wide", 0x004E },
  unicodeslot=0xFF2E,
 },
 [0xFF2F]={
  adobename="Omonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER O",
  direction="l",
  lccode=0xFF4F,
  linebreak="id",
  specials={ "wide", 0x004F },
  unicodeslot=0xFF2F,
 },
 [0xFF30]={
  adobename="Pmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER P",
  direction="l",
  lccode=0xFF50,
  linebreak="id",
  specials={ "wide", 0x0050 },
  unicodeslot=0xFF30,
 },
 [0xFF31]={
  adobename="Qmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER Q",
  direction="l",
  lccode=0xFF51,
  linebreak="id",
  specials={ "wide", 0x0051 },
  unicodeslot=0xFF31,
 },
 [0xFF32]={
  adobename="Rmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER R",
  direction="l",
  lccode=0xFF52,
  linebreak="id",
  specials={ "wide", 0x0052 },
  unicodeslot=0xFF32,
 },
 [0xFF33]={
  adobename="Smonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER S",
  direction="l",
  lccode=0xFF53,
  linebreak="id",
  specials={ "wide", 0x0053 },
  unicodeslot=0xFF33,
 },
 [0xFF34]={
  adobename="Tmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER T",
  direction="l",
  lccode=0xFF54,
  linebreak="id",
  specials={ "wide", 0x0054 },
  unicodeslot=0xFF34,
 },
 [0xFF35]={
  adobename="Umonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER U",
  direction="l",
  lccode=0xFF55,
  linebreak="id",
  specials={ "wide", 0x0055 },
  unicodeslot=0xFF35,
 },
 [0xFF36]={
  adobename="Vmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER V",
  direction="l",
  lccode=0xFF56,
  linebreak="id",
  specials={ "wide", 0x0056 },
  unicodeslot=0xFF36,
 },
 [0xFF37]={
  adobename="Wmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER W",
  direction="l",
  lccode=0xFF57,
  linebreak="id",
  specials={ "wide", 0x0057 },
  unicodeslot=0xFF37,
 },
 [0xFF38]={
  adobename="Xmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER X",
  direction="l",
  lccode=0xFF58,
  linebreak="id",
  specials={ "wide", 0x0058 },
  unicodeslot=0xFF38,
 },
 [0xFF39]={
  adobename="Ymonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER Y",
  direction="l",
  lccode=0xFF59,
  linebreak="id",
  specials={ "wide", 0x0059 },
  unicodeslot=0xFF39,
 },
 [0xFF3A]={
  adobename="Zmonospace",
  category="lu",
  cjkwd="f",
  description="FULLWIDTH LATIN CAPITAL LETTER Z",
  direction="l",
  lccode=0xFF5A,
  linebreak="id",
  specials={ "wide", 0x005A },
  unicodeslot=0xFF3A,
 },
 [0xFF3B]={
  adobename="bracketleftmonospace",
  category="ps",
  cjkwd="f",
  description="FULLWIDTH LEFT SQUARE BRACKET",
  direction="on",
  linebreak="op",
  mirror=0xFF3D,
  textclass="open",
  specials={ "wide", 0x005B },
  unicodeslot=0xFF3B,
 },
 [0xFF3C]={
  adobename="backslashmonospace",
  category="po",
  cjkwd="f",
  description="FULLWIDTH REVERSE SOLIDUS",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x005C },
  unicodeslot=0xFF3C,
 },
 [0xFF3D]={
  adobename="bracketrightmonospace",
  category="pe",
  cjkwd="f",
  description="FULLWIDTH RIGHT SQUARE BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0xFF3B,
  textclass="close",
  specials={ "wide", 0x005D },
  unicodeslot=0xFF3D,
 },
 [0xFF3E]={
  adobename="asciicircummonospace",
  category="sk",
  cjkwd="f",
  description="FULLWIDTH CIRCUMFLEX ACCENT",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x005E },
  unicodeslot=0xFF3E,
 },
 [0xFF3F]={
  adobename="underscoremonospace",
  category="pc",
  cjkwd="f",
  description="FULLWIDTH LOW LINE",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x005F },
  unicodeslot=0xFF3F,
 },
 [0xFF40]={
  adobename="gravemonospace",
  category="sk",
  cjkwd="f",
  description="FULLWIDTH GRAVE ACCENT",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x0060 },
  unicodeslot=0xFF40,
 },
 [0xFF41]={
  adobename="amonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER A",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0061 },
  uccode=0xFF21,
  unicodeslot=0xFF41,
 },
 [0xFF42]={
  adobename="bmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER B",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0062 },
  uccode=0xFF22,
  unicodeslot=0xFF42,
 },
 [0xFF43]={
  adobename="cmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER C",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0063 },
  uccode=0xFF23,
  unicodeslot=0xFF43,
 },
 [0xFF44]={
  adobename="dmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER D",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0064 },
  uccode=0xFF24,
  unicodeslot=0xFF44,
 },
 [0xFF45]={
  adobename="emonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER E",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0065 },
  uccode=0xFF25,
  unicodeslot=0xFF45,
 },
 [0xFF46]={
  adobename="fmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER F",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0066 },
  uccode=0xFF26,
  unicodeslot=0xFF46,
 },
 [0xFF47]={
  adobename="gmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER G",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0067 },
  uccode=0xFF27,
  unicodeslot=0xFF47,
 },
 [0xFF48]={
  adobename="hmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER H",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0068 },
  uccode=0xFF28,
  unicodeslot=0xFF48,
 },
 [0xFF49]={
  adobename="imonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER I",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0069 },
  uccode=0xFF29,
  unicodeslot=0xFF49,
 },
 [0xFF4A]={
  adobename="jmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER J",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x006A },
  uccode=0xFF2A,
  unicodeslot=0xFF4A,
 },
 [0xFF4B]={
  adobename="kmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER K",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x006B },
  uccode=0xFF2B,
  unicodeslot=0xFF4B,
 },
 [0xFF4C]={
  adobename="lmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER L",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x006C },
  uccode=0xFF2C,
  unicodeslot=0xFF4C,
 },
 [0xFF4D]={
  adobename="mmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER M",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x006D },
  uccode=0xFF2D,
  unicodeslot=0xFF4D,
 },
 [0xFF4E]={
  adobename="nmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER N",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x006E },
  uccode=0xFF2E,
  unicodeslot=0xFF4E,
 },
 [0xFF4F]={
  adobename="omonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER O",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x006F },
  uccode=0xFF2F,
  unicodeslot=0xFF4F,
 },
 [0xFF50]={
  adobename="pmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER P",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0070 },
  uccode=0xFF30,
  unicodeslot=0xFF50,
 },
 [0xFF51]={
  adobename="qmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER Q",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0071 },
  uccode=0xFF31,
  unicodeslot=0xFF51,
 },
 [0xFF52]={
  adobename="rmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER R",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0072 },
  uccode=0xFF32,
  unicodeslot=0xFF52,
 },
 [0xFF53]={
  adobename="smonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER S",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0073 },
  uccode=0xFF33,
  unicodeslot=0xFF53,
 },
 [0xFF54]={
  adobename="tmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER T",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0074 },
  uccode=0xFF34,
  unicodeslot=0xFF54,
 },
 [0xFF55]={
  adobename="umonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER U",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0075 },
  uccode=0xFF35,
  unicodeslot=0xFF55,
 },
 [0xFF56]={
  adobename="vmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER V",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0076 },
  uccode=0xFF36,
  unicodeslot=0xFF56,
 },
 [0xFF57]={
  adobename="wmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER W",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0077 },
  uccode=0xFF37,
  unicodeslot=0xFF57,
 },
 [0xFF58]={
  adobename="xmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER X",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0078 },
  uccode=0xFF38,
  unicodeslot=0xFF58,
 },
 [0xFF59]={
  adobename="ymonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER Y",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x0079 },
  uccode=0xFF39,
  unicodeslot=0xFF59,
 },
 [0xFF5A]={
  adobename="zmonospace",
  category="ll",
  cjkwd="f",
  description="FULLWIDTH LATIN SMALL LETTER Z",
  direction="l",
  linebreak="id",
  specials={ "wide", 0x007A },
  uccode=0xFF3A,
  unicodeslot=0xFF5A,
 },
 [0xFF5B]={
  adobename="braceleftmonospace",
  category="ps",
  cjkwd="f",
  description="FULLWIDTH LEFT CURLY BRACKET",
  direction="on",
  linebreak="op",
  mirror=0xFF5D,
  textclass="open",
  specials={ "wide", 0x007B },
  unicodeslot=0xFF5B,
 },
 [0xFF5C]={
  adobename="barmonospace",
  category="sm",
  cjkwd="f",
  description="FULLWIDTH VERTICAL LINE",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x007C },
  unicodeslot=0xFF5C,
 },
 [0xFF5D]={
  adobename="bracerightmonospace",
  category="pe",
  cjkwd="f",
  description="FULLWIDTH RIGHT CURLY BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0xFF5B,
  textclass="close",
  specials={ "wide", 0x007D },
  unicodeslot=0xFF5D,
 },
 [0xFF5E]={
  adobename="asciitildemonospace",
  category="sm",
  cjkwd="f",
  description="FULLWIDTH TILDE",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x007E },
  unicodeslot=0xFF5E,
 },
 [0xFF5F]={
  category="ps",
  cjkwd="f",
  description="FULLWIDTH LEFT WHITE PARENTHESIS",
  direction="on",
  linebreak="op",
  mirror=0xFF60,
  textclass="open",
  specials={ "wide", 0x2985 },
  unicodeslot=0xFF5F,
 },
 [0xFF60]={
  category="pe",
  cjkwd="f",
  description="FULLWIDTH RIGHT WHITE PARENTHESIS",
  direction="on",
  linebreak="cl",
  mirror=0xFF5F,
  textclass="close",
  specials={ "wide", 0x2986 },
  unicodeslot=0xFF60,
 },
 [0xFF61]={
  adobename="periodhalfwidth",
  category="po",
  cjkwd="h",
  description="HALFWIDTH IDEOGRAPHIC FULL STOP",
  direction="on",
  linebreak="cl",
  specials={ "narrow", 0x3002 },
  unicodeslot=0xFF61,
 },
 [0xFF62]={
  adobename="cornerbracketlefthalfwidth",
  category="ps",
  cjkwd="h",
  description="HALFWIDTH LEFT CORNER BRACKET",
  direction="on",
  linebreak="op",
  mirror=0xFF63,
  textclass="open",
  specials={ "narrow", 0x300C },
  unicodeslot=0xFF62,
 },
 [0xFF63]={
  adobename="cornerbracketrighthalfwidth",
  category="pe",
  cjkwd="h",
  description="HALFWIDTH RIGHT CORNER BRACKET",
  direction="on",
  linebreak="cl",
  mirror=0xFF62,
  textclass="close",
  specials={ "narrow", 0x300D },
  unicodeslot=0xFF63,
 },
 [0xFF64]={
  adobename="ideographiccommaleft",
  category="po",
  cjkwd="h",
  description="HALFWIDTH IDEOGRAPHIC COMMA",
  direction="on",
  linebreak="cl",
  specials={ "narrow", 0x3001 },
  unicodeslot=0xFF64,
 },
 [0xFF65]={
  adobename="middledotkatakanahalfwidth",
  category="po",
  cjkwd="h",
  description="HALFWIDTH KATAKANA MIDDLE DOT",
  direction="on",
  linebreak="ns",
  specials={ "narrow", 0x30FB },
  unicodeslot=0xFF65,
 },
 [0xFF66]={
  adobename="wokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER WO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30F2 },
  unicodeslot=0xFF66,
 },
 [0xFF67]={
  adobename="asmallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL A",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30A1 },
  unicodeslot=0xFF67,
 },
 [0xFF68]={
  adobename="ismallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL I",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30A3 },
  unicodeslot=0xFF68,
 },
 [0xFF69]={
  adobename="usmallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL U",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30A5 },
  unicodeslot=0xFF69,
 },
 [0xFF6A]={
  adobename="esmallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL E",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30A7 },
  unicodeslot=0xFF6A,
 },
 [0xFF6B]={
  adobename="osmallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL O",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30A9 },
  unicodeslot=0xFF6B,
 },
 [0xFF6C]={
  adobename="yasmallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL YA",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30E3 },
  unicodeslot=0xFF6C,
 },
 [0xFF6D]={
  adobename="yusmallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL YU",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30E5 },
  unicodeslot=0xFF6D,
 },
 [0xFF6E]={
  adobename="yosmallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL YO",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30E7 },
  unicodeslot=0xFF6E,
 },
 [0xFF6F]={
  adobename="tusmallkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SMALL TU",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30C3 },
  unicodeslot=0xFF6F,
 },
 [0xFF70]={
  adobename="katahiraprolongmarkhalfwidth",
  category="lm",
  cjkwd="h",
  description="HALFWIDTH KATAKANA-HIRAGANA PROLONGED SOUND MARK",
  direction="l",
  linebreak="cj",
  specials={ "narrow", 0x30FC },
  unicodeslot=0xFF70,
 },
 [0xFF71]={
  adobename="akatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER A",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30A2 },
  unicodeslot=0xFF71,
 },
 [0xFF72]={
  adobename="ikatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER I",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30A4 },
  unicodeslot=0xFF72,
 },
 [0xFF73]={
  adobename="ukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER U",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30A6 },
  unicodeslot=0xFF73,
 },
 [0xFF74]={
  adobename="ekatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER E",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30A8 },
  unicodeslot=0xFF74,
 },
 [0xFF75]={
  adobename="okatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER O",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30AA },
  unicodeslot=0xFF75,
 },
 [0xFF76]={
  adobename="kakatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER KA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30AB },
  unicodeslot=0xFF76,
 },
 [0xFF77]={
  adobename="kikatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER KI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30AD },
  unicodeslot=0xFF77,
 },
 [0xFF78]={
  adobename="kukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER KU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30AF },
  unicodeslot=0xFF78,
 },
 [0xFF79]={
  adobename="kekatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER KE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30B1 },
  unicodeslot=0xFF79,
 },
 [0xFF7A]={
  adobename="kokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER KO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30B3 },
  unicodeslot=0xFF7A,
 },
 [0xFF7B]={
  adobename="sakatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30B5 },
  unicodeslot=0xFF7B,
 },
 [0xFF7C]={
  adobename="sikatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30B7 },
  unicodeslot=0xFF7C,
 },
 [0xFF7D]={
  adobename="sukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30B9 },
  unicodeslot=0xFF7D,
 },
 [0xFF7E]={
  adobename="sekatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30BB },
  unicodeslot=0xFF7E,
 },
 [0xFF7F]={
  adobename="sokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER SO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30BD },
  unicodeslot=0xFF7F,
 },
 [0xFF80]={
  adobename="takatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER TA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30BF },
  unicodeslot=0xFF80,
 },
 [0xFF81]={
  adobename="tikatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER TI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30C1 },
  unicodeslot=0xFF81,
 },
 [0xFF82]={
  adobename="tukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER TU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30C4 },
  unicodeslot=0xFF82,
 },
 [0xFF83]={
  adobename="tekatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER TE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30C6 },
  unicodeslot=0xFF83,
 },
 [0xFF84]={
  adobename="tokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER TO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30C8 },
  unicodeslot=0xFF84,
 },
 [0xFF85]={
  adobename="nakatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER NA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30CA },
  unicodeslot=0xFF85,
 },
 [0xFF86]={
  adobename="nikatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER NI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30CB },
  unicodeslot=0xFF86,
 },
 [0xFF87]={
  adobename="nukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER NU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30CC },
  unicodeslot=0xFF87,
 },
 [0xFF88]={
  adobename="nekatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER NE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30CD },
  unicodeslot=0xFF88,
 },
 [0xFF89]={
  adobename="nokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER NO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30CE },
  unicodeslot=0xFF89,
 },
 [0xFF8A]={
  adobename="hakatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER HA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30CF },
  unicodeslot=0xFF8A,
 },
 [0xFF8B]={
  adobename="hikatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER HI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30D2 },
  unicodeslot=0xFF8B,
 },
 [0xFF8C]={
  adobename="hukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER HU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30D5 },
  unicodeslot=0xFF8C,
 },
 [0xFF8D]={
  adobename="hekatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER HE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30D8 },
  unicodeslot=0xFF8D,
 },
 [0xFF8E]={
  adobename="hokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER HO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30DB },
  unicodeslot=0xFF8E,
 },
 [0xFF8F]={
  adobename="makatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER MA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30DE },
  unicodeslot=0xFF8F,
 },
 [0xFF90]={
  adobename="mikatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER MI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30DF },
  unicodeslot=0xFF90,
 },
 [0xFF91]={
  adobename="mukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER MU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30E0 },
  unicodeslot=0xFF91,
 },
 [0xFF92]={
  adobename="mekatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER ME",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30E1 },
  unicodeslot=0xFF92,
 },
 [0xFF93]={
  adobename="mokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER MO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30E2 },
  unicodeslot=0xFF93,
 },
 [0xFF94]={
  adobename="yakatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER YA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30E4 },
  unicodeslot=0xFF94,
 },
 [0xFF95]={
  adobename="yukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER YU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30E6 },
  unicodeslot=0xFF95,
 },
 [0xFF96]={
  adobename="yokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER YO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30E8 },
  unicodeslot=0xFF96,
 },
 [0xFF97]={
  adobename="rakatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER RA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30E9 },
  unicodeslot=0xFF97,
 },
 [0xFF98]={
  adobename="rikatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER RI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30EA },
  unicodeslot=0xFF98,
 },
 [0xFF99]={
  adobename="rukatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER RU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30EB },
  unicodeslot=0xFF99,
 },
 [0xFF9A]={
  adobename="rekatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER RE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30EC },
  unicodeslot=0xFF9A,
 },
 [0xFF9B]={
  adobename="rokatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER RO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30ED },
  unicodeslot=0xFF9B,
 },
 [0xFF9C]={
  adobename="wakatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER WA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30EF },
  unicodeslot=0xFF9C,
 },
 [0xFF9D]={
  adobename="nkatakanahalfwidth",
  category="lo",
  cjkwd="h",
  description="HALFWIDTH KATAKANA LETTER N",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x30F3 },
  unicodeslot=0xFF9D,
 },
 [0xFF9E]={
  adobename="voicedmarkkanahalfwidth",
  category="lm",
  cjkwd="h",
  description="HALFWIDTH KATAKANA VOICED SOUND MARK",
  direction="l",
  linebreak="ns",
  specials={ "narrow", 0x3099 },
  unicodeslot=0xFF9E,
 },
 [0xFF9F]={
  adobename="semivoicedmarkkanahalfwidth",
  category="lm",
  cjkwd="h",
  description="HALFWIDTH KATAKANA SEMI-VOICED SOUND MARK",
  direction="l",
  linebreak="ns",
  specials={ "narrow", 0x309A },
  unicodeslot=0xFF9F,
 },
 [0xFFA0]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL FILLER",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3164 },
  unicodeslot=0xFFA0,
 },
 [0xFFA1]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER KIYEOK",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3131 },
  unicodeslot=0xFFA1,
 },
 [0xFFA2]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER SSANGKIYEOK",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3132 },
  unicodeslot=0xFFA2,
 },
 [0xFFA3]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER KIYEOK-SIOS",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3133 },
  unicodeslot=0xFFA3,
 },
 [0xFFA4]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER NIEUN",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3134 },
  unicodeslot=0xFFA4,
 },
 [0xFFA5]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER NIEUN-CIEUC",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3135 },
  unicodeslot=0xFFA5,
 },
 [0xFFA6]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER NIEUN-HIEUH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3136 },
  unicodeslot=0xFFA6,
 },
 [0xFFA7]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER TIKEUT",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3137 },
  unicodeslot=0xFFA7,
 },
 [0xFFA8]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER SSANGTIKEUT",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3138 },
  unicodeslot=0xFFA8,
 },
 [0xFFA9]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER RIEUL",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3139 },
  unicodeslot=0xFFA9,
 },
 [0xFFAA]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER RIEUL-KIYEOK",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x313A },
  unicodeslot=0xFFAA,
 },
 [0xFFAB]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER RIEUL-MIEUM",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x313B },
  unicodeslot=0xFFAB,
 },
 [0xFFAC]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER RIEUL-PIEUP",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x313C },
  unicodeslot=0xFFAC,
 },
 [0xFFAD]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER RIEUL-SIOS",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x313D },
  unicodeslot=0xFFAD,
 },
 [0xFFAE]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER RIEUL-THIEUTH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x313E },
  unicodeslot=0xFFAE,
 },
 [0xFFAF]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER RIEUL-PHIEUPH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x313F },
  unicodeslot=0xFFAF,
 },
 [0xFFB0]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER RIEUL-HIEUH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3140 },
  unicodeslot=0xFFB0,
 },
 [0xFFB1]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER MIEUM",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3141 },
  unicodeslot=0xFFB1,
 },
 [0xFFB2]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER PIEUP",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3142 },
  unicodeslot=0xFFB2,
 },
 [0xFFB3]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER SSANGPIEUP",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3143 },
  unicodeslot=0xFFB3,
 },
 [0xFFB4]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER PIEUP-SIOS",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3144 },
  unicodeslot=0xFFB4,
 },
 [0xFFB5]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER SIOS",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3145 },
  unicodeslot=0xFFB5,
 },
 [0xFFB6]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER SSANGSIOS",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3146 },
  unicodeslot=0xFFB6,
 },
 [0xFFB7]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER IEUNG",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3147 },
  unicodeslot=0xFFB7,
 },
 [0xFFB8]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER CIEUC",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3148 },
  unicodeslot=0xFFB8,
 },
 [0xFFB9]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER SSANGCIEUC",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3149 },
  unicodeslot=0xFFB9,
 },
 [0xFFBA]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER CHIEUCH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x314A },
  unicodeslot=0xFFBA,
 },
 [0xFFBB]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER KHIEUKH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x314B },
  unicodeslot=0xFFBB,
 },
 [0xFFBC]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER THIEUTH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x314C },
  unicodeslot=0xFFBC,
 },
 [0xFFBD]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER PHIEUPH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x314D },
  unicodeslot=0xFFBD,
 },
 [0xFFBE]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER HIEUH",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x314E },
  unicodeslot=0xFFBE,
 },
 [0xFFC2]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER A",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x314F },
  unicodeslot=0xFFC2,
 },
 [0xFFC3]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER AE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3150 },
  unicodeslot=0xFFC3,
 },
 [0xFFC4]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER YA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3151 },
  unicodeslot=0xFFC4,
 },
 [0xFFC5]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER YAE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3152 },
  unicodeslot=0xFFC5,
 },
 [0xFFC6]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER EO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3153 },
  unicodeslot=0xFFC6,
 },
 [0xFFC7]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER E",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3154 },
  unicodeslot=0xFFC7,
 },
 [0xFFCA]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER YEO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3155 },
  unicodeslot=0xFFCA,
 },
 [0xFFCB]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER YE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3156 },
  unicodeslot=0xFFCB,
 },
 [0xFFCC]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER O",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3157 },
  unicodeslot=0xFFCC,
 },
 [0xFFCD]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER WA",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3158 },
  unicodeslot=0xFFCD,
 },
 [0xFFCE]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER WAE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3159 },
  unicodeslot=0xFFCE,
 },
 [0xFFCF]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER OE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x315A },
  unicodeslot=0xFFCF,
 },
 [0xFFD2]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER YO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x315B },
  unicodeslot=0xFFD2,
 },
 [0xFFD3]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER U",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x315C },
  unicodeslot=0xFFD3,
 },
 [0xFFD4]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER WEO",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x315D },
  unicodeslot=0xFFD4,
 },
 [0xFFD5]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER WE",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x315E },
  unicodeslot=0xFFD5,
 },
 [0xFFD6]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER WI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x315F },
  unicodeslot=0xFFD6,
 },
 [0xFFD7]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER YU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3160 },
  unicodeslot=0xFFD7,
 },
 [0xFFDA]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER EU",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3161 },
  unicodeslot=0xFFDA,
 },
 [0xFFDB]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER YI",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3162 },
  unicodeslot=0xFFDB,
 },
 [0xFFDC]={
  category="lo",
  cjkwd="h",
  description="HALFWIDTH HANGUL LETTER I",
  direction="l",
  linebreak="al",
  specials={ "narrow", 0x3163 },
  unicodeslot=0xFFDC,
 },
 [0xFFE0]={
  adobename="centmonospace",
  category="sc",
  cjkwd="f",
  description="FULLWIDTH CENT SIGN",
  direction="et",
  linebreak="po",
  specials={ "wide", 0x00A2 },
  unicodeslot=0xFFE0,
 },
 [0xFFE1]={
  adobename="sterlingmonospace",
  category="sc",
  cjkwd="f",
  description="FULLWIDTH POUND SIGN",
  direction="et",
  linebreak="pr",
  specials={ "wide", 0x00A3 },
  unicodeslot=0xFFE1,
 },
 [0xFFE2]={
  category="sm",
  cjkwd="f",
  description="FULLWIDTH NOT SIGN",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x00AC },
  unicodeslot=0xFFE2,
 },
 [0xFFE3]={
  adobename="macronmonospace",
  category="sk",
  cjkwd="f",
  description="FULLWIDTH MACRON",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x00AF },
  unicodeslot=0xFFE3,
 },
 [0xFFE4]={
  category="so",
  cjkwd="f",
  description="FULLWIDTH BROKEN BAR",
  direction="on",
  linebreak="id",
  specials={ "wide", 0x00A6 },
  unicodeslot=0xFFE4,
 },
 [0xFFE5]={
  adobename="yenmonospace",
  category="sc",
  cjkwd="f",
  description="FULLWIDTH YEN SIGN",
  direction="et",
  linebreak="pr",
  specials={ "wide", 0x00A5 },
  unicodeslot=0xFFE5,
 },
 [0xFFE6]={
  adobename="wonmonospace",
  category="sc",
  cjkwd="f",
  description="FULLWIDTH WON SIGN",
  direction="et",
  linebreak="pr",
  specials={ "wide", 0x20A9 },
  unicodeslot=0xFFE6,
 },
 [0xFFE8]={
  category="so",
  cjkwd="h",
  description="HALFWIDTH FORMS LIGHT VERTICAL",
  direction="on",
  linebreak="al",
  specials={ "narrow", 0x2502 },
  unicodeslot=0xFFE8,
 },
 [0xFFE9]={
  category="sm",
  cjkwd="h",
  description="HALFWIDTH LEFTWARDS ARROW",
  direction="on",
  linebreak="al",
  specials={ "narrow", 0x2190 },
  unicodeslot=0xFFE9,
 },
 [0xFFEA]={
  category="sm",
  cjkwd="h",
  description="HALFWIDTH UPWARDS ARROW",
  direction="on",
  linebreak="al",
  specials={ "narrow", 0x2191 },
  unicodeslot=0xFFEA,
 },
 [0xFFEB]={
  category="sm",
  cjkwd="h",
  description="HALFWIDTH RIGHTWARDS ARROW",
  direction="on",
  linebreak="al",
  specials={ "narrow", 0x2192 },
  unicodeslot=0xFFEB,
 },
 [0xFFEC]={
  category="sm",
  cjkwd="h",
  description="HALFWIDTH DOWNWARDS ARROW",
  direction="on",
  linebreak="al",
  specials={ "narrow", 0x2193 },
  unicodeslot=0xFFEC,
 },
 [0xFFED]={
  category="so",
  cjkwd="h",
  description="HALFWIDTH BLACK SQUARE",
  direction="on",
  linebreak="al",
  specials={ "narrow", 0x25A0 },
  unicodeslot=0xFFED,
 },
 [0xFFEE]={
  category="so",
  cjkwd="h",
  description="HALFWIDTH WHITE CIRCLE",
  direction="on",
  linebreak="al",
  specials={ "narrow", 0x25CB },
  unicodeslot=0xFFEE,
 },
 [0xFFF9]={
  category="cf",
  description="INTERLINEAR ANNOTATION ANCHOR",
  direction="on",
  linebreak="cm",
  unicodeslot=0xFFF9,
  visible="yes",
 },
 [0xFFFA]={
  category="cf",
  description="INTERLINEAR ANNOTATION SEPARATOR",
  direction="on",
  linebreak="cm",
  unicodeslot=0xFFFA,
  visible="yes",
 },
 [0xFFFB]={
  category="cf",
  description="INTERLINEAR ANNOTATION TERMINATOR",
  direction="on",
  linebreak="cm",
  unicodeslot=0xFFFB,
  visible="yes",
 },
 [0xFFFC]={
  category="so",
  description="OBJECT REPLACEMENT CHARACTER",
  direction="on",
  linebreak="cb",
  unicodeslot=0xFFFC,
 },
 [0xFFFD]={
  category="so",
  cjkwd="a",
  description="REPLACEMENT CHARACTER",
  direction="on",
  linebreak="ai",
  unicodeslot=0xFFFD,
 },
 [0x10000]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0008 A",
  direction="l",
  linebreak="al",
  unicodeslot=0x10000,
 },
 [0x10001]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0026 E",
  direction="l",
  linebreak="al",
  unicodeslot=0x10001,
 },
 [0x10002]={
  category="lo",
  description="LINEAR B SYLLABLE B0x001C I",
  direction="l",
  linebreak="al",
  unicodeslot=0x10002,
 },
 [0x10003]={
  category="lo",
  description="LINEAR B SYLLABLE B0x003D O",
  direction="l",
  linebreak="al",
  unicodeslot=0x10003,
 },
 [0x10004]={
  category="lo",
  description="LINEAR B SYLLABLE B0x000A U",
  direction="l",
  linebreak="al",
  unicodeslot=0x10004,
 },
 [0x10005]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0001 DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10005,
 },
 [0x10006]={
  category="lo",
  description="LINEAR B SYLLABLE B0x002D DE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10006,
 },
 [0x10007]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0007 DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10007,
 },
 [0x10008]={
  category="lo",
  description="LINEAR B SYLLABLE B0x000E DO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10008,
 },
 [0x10009]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0033 DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10009,
 },
 [0x1000A]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0039 JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1000A,
 },
 [0x1000B]={
  category="lo",
  description="LINEAR B SYLLABLE B0x002E JE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1000B,
 },
 [0x1000D]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0024 JO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1000D,
 },
 [0x1000E]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0041 JU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1000E,
 },
 [0x1000F]={
  category="lo",
  description="LINEAR B SYLLABLE B0x004D KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1000F,
 },
 [0x10010]={
  category="lo",
  description="LINEAR B SYLLABLE B0x002C KE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10010,
 },
 [0x10011]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0043 KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10011,
 },
 [0x10012]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0046 KO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10012,
 },
 [0x10013]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0051 KU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10013,
 },
 [0x10014]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0050 MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10014,
 },
 [0x10015]={
  category="lo",
  description="LINEAR B SYLLABLE B0x000D ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x10015,
 },
 [0x10016]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0049 MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10016,
 },
 [0x10017]={
  category="lo",
  description="LINEAR B SYLLABLE B0x000F MO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10017,
 },
 [0x10018]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0017 MU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10018,
 },
 [0x10019]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0006 NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10019,
 },
 [0x1001A]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0018 NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1001A,
 },
 [0x1001B]={
  category="lo",
  description="LINEAR B SYLLABLE B0x001E NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1001B,
 },
 [0x1001C]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0034 NO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1001C,
 },
 [0x1001D]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0037 NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1001D,
 },
 [0x1001E]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0003 PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1001E,
 },
 [0x1001F]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0048 PE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1001F,
 },
 [0x10020]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0027 PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10020,
 },
 [0x10021]={
  category="lo",
  description="LINEAR B SYLLABLE B0x000B PO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10021,
 },
 [0x10022]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0032 PU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10022,
 },
 [0x10023]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0010 QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10023,
 },
 [0x10024]={
  category="lo",
  description="LINEAR B SYLLABLE B0x004E QE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10024,
 },
 [0x10025]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0015 QI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10025,
 },
 [0x10026]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0020 QO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10026,
 },
 [0x10028]={
  category="lo",
  description="LINEAR B SYLLABLE B0x003C RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10028,
 },
 [0x10029]={
  category="lo",
  description="LINEAR B SYLLABLE B0x001B RE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10029,
 },
 [0x1002A]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0035 RI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1002A,
 },
 [0x1002B]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0002 RO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1002B,
 },
 [0x1002C]={
  category="lo",
  description="LINEAR B SYLLABLE B0x001A RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1002C,
 },
 [0x1002D]={
  category="lo",
  description="LINEAR B SYLLABLE B0x001F SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1002D,
 },
 [0x1002E]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0009 SE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1002E,
 },
 [0x1002F]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0029 SI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1002F,
 },
 [0x10030]={
  category="lo",
  description="LINEAR B SYLLABLE B0x000C SO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10030,
 },
 [0x10031]={
  category="lo",
  description="LINEAR B SYLLABLE B0x003A SU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10031,
 },
 [0x10032]={
  category="lo",
  description="LINEAR B SYLLABLE B0x003B TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10032,
 },
 [0x10033]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0004 TE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10033,
 },
 [0x10034]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0025 TI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10034,
 },
 [0x10035]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0005 TO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10035,
 },
 [0x10036]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0045 TU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10036,
 },
 [0x10037]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0036 WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10037,
 },
 [0x10038]={
  category="lo",
  description="LINEAR B SYLLABLE B0x004B WE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10038,
 },
 [0x10039]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0028 WI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10039,
 },
 [0x1003A]={
  category="lo",
  description="LINEAR B SYLLABLE B0x002A WO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1003A,
 },
 [0x1003C]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0011 ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1003C,
 },
 [0x1003D]={
  category="lo",
  description="LINEAR B SYLLABLE B0x004A ZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1003D,
 },
 [0x1003F]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0014 ZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1003F,
 },
 [0x10040]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0019 A0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x10040,
 },
 [0x10041]={
  category="lo",
  description="LINEAR B SYLLABLE B0x002B A0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x10041,
 },
 [0x10042]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0055 AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10042,
 },
 [0x10043]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0047 DWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10043,
 },
 [0x10044]={
  category="lo",
  description="LINEAR B SYLLABLE B0x005A DWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10044,
 },
 [0x10045]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0030 NWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10045,
 },
 [0x10046]={
  category="lo",
  description="LINEAR B SYLLABLE B0x001D PU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x10046,
 },
 [0x10047]={
  category="lo",
  description="LINEAR B SYLLABLE B0x003E PTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10047,
 },
 [0x10048]={
  category="lo",
  description="LINEAR B SYLLABLE B0x004C RA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x10048,
 },
 [0x10049]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0021 RA0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x10049,
 },
 [0x1004A]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0044 RO0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1004A,
 },
 [0x1004B]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0042 TA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1004B,
 },
 [0x1004C]={
  category="lo",
  description="LINEAR B SYLLABLE B0x0057 TWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1004C,
 },
 [0x1004D]={
  category="lo",
  description="LINEAR B SYLLABLE B0x005B TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1004D,
 },
 [0x10050]={
  category="lo",
  description="LINEAR B SYMBOL B0x0012",
  direction="l",
  linebreak="al",
  unicodeslot=0x10050,
 },
 [0x10051]={
  category="lo",
  description="LINEAR B SYMBOL B0x0013",
  direction="l",
  linebreak="al",
  unicodeslot=0x10051,
 },
 [0x10052]={
  category="lo",
  description="LINEAR B SYMBOL B0x0016",
  direction="l",
  linebreak="al",
  unicodeslot=0x10052,
 },
 [0x10053]={
  category="lo",
  description="LINEAR B SYMBOL B0x0022",
  direction="l",
  linebreak="al",
  unicodeslot=0x10053,
 },
 [0x10054]={
  category="lo",
  description="LINEAR B SYMBOL B0x002F",
  direction="l",
  linebreak="al",
  unicodeslot=0x10054,
 },
 [0x10055]={
  category="lo",
  description="LINEAR B SYMBOL B0x0031",
  direction="l",
  linebreak="al",
  unicodeslot=0x10055,
 },
 [0x10056]={
  category="lo",
  description="LINEAR B SYMBOL B0x0038",
  direction="l",
  linebreak="al",
  unicodeslot=0x10056,
 },
 [0x10057]={
  category="lo",
  description="LINEAR B SYMBOL B0x003F",
  direction="l",
  linebreak="al",
  unicodeslot=0x10057,
 },
 [0x10058]={
  category="lo",
  description="LINEAR B SYMBOL B0x0040",
  direction="l",
  linebreak="al",
  unicodeslot=0x10058,
 },
 [0x10059]={
  category="lo",
  description="LINEAR B SYMBOL B0x004F",
  direction="l",
  linebreak="al",
  unicodeslot=0x10059,
 },
 [0x1005A]={
  category="lo",
  description="LINEAR B SYMBOL B0x0052",
  direction="l",
  linebreak="al",
  unicodeslot=0x1005A,
 },
 [0x1005B]={
  category="lo",
  description="LINEAR B SYMBOL B0x0053",
  direction="l",
  linebreak="al",
  unicodeslot=0x1005B,
 },
 [0x1005C]={
  category="lo",
  description="LINEAR B SYMBOL B0x0056",
  direction="l",
  linebreak="al",
  unicodeslot=0x1005C,
 },
 [0x1005D]={
  category="lo",
  description="LINEAR B SYMBOL B0x0059",
  direction="l",
  linebreak="al",
  unicodeslot=0x1005D,
 },
 [0x10080]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0064 MAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10080,
 },
 [0x10081]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0066 WOMAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10081,
 },
 [0x10082]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0068 DEER",
  direction="l",
  linebreak="al",
  unicodeslot=0x10082,
 },
 [0x10083]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0069 EQUID",
  direction="l",
  linebreak="al",
  unicodeslot=0x10083,
 },
 [0x10084]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0069F MARE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10084,
 },
 [0x10085]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0069M STALLION",
  direction="l",
  linebreak="al",
  unicodeslot=0x10085,
 },
 [0x10086]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x006AF EWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10086,
 },
 [0x10087]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x006AM RAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x10087,
 },
 [0x10088]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x006BF SHE-GOAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x10088,
 },
 [0x10089]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x006BM HE-GOAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x10089,
 },
 [0x1008A]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x006CF SOW",
  direction="l",
  linebreak="al",
  unicodeslot=0x1008A,
 },
 [0x1008B]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x006CM BOAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1008B,
 },
 [0x1008C]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x006DF COW",
  direction="l",
  linebreak="al",
  unicodeslot=0x1008C,
 },
 [0x1008D]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x006DM BULL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1008D,
 },
 [0x1008E]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0078 WHEAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1008E,
 },
 [0x1008F]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0079 BARLEY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1008F,
 },
 [0x10090]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x007A OLIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10090,
 },
 [0x10091]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x007B SPICE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10091,
 },
 [0x10092]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x007D CYPERUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x10092,
 },
 [0x10093]={
  category="lo",
  description="LINEAR B MONOGRAM B0x007F KAPO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10093,
 },
 [0x10094]={
  category="lo",
  description="LINEAR B MONOGRAM B0x0080 KANAKO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10094,
 },
 [0x10095]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0082 OIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10095,
 },
 [0x10096]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0083 WINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10096,
 },
 [0x10097]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0084",
  direction="l",
  linebreak="al",
  unicodeslot=0x10097,
 },
 [0x10098]={
  category="lo",
  description="LINEAR B MONOGRAM B0x0085 AREPA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10098,
 },
 [0x10099]={
  category="lo",
  description="LINEAR B MONOGRAM B0x0087 MERI",
  direction="l",
  linebreak="al",
  unicodeslot=0x10099,
 },
 [0x1009A]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x008C BRONZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1009A,
 },
 [0x1009B]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x008D GOLD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1009B,
 },
 [0x1009C]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x008E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1009C,
 },
 [0x1009D]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0091 WOOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1009D,
 },
 [0x1009E]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0092",
  direction="l",
  linebreak="al",
  unicodeslot=0x1009E,
 },
 [0x1009F]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0096",
  direction="l",
  linebreak="al",
  unicodeslot=0x1009F,
 },
 [0x100A0]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0097 HORN",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A0,
 },
 [0x100A1]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0098",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A1,
 },
 [0x100A2]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0099",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A2,
 },
 [0x100A3]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x009A",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A3,
 },
 [0x100A4]={
  category="lo",
  description="LINEAR B MONOGRAM B0x009C TURO0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A4,
 },
 [0x100A5]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x009D",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A5,
 },
 [0x100A6]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x009E",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A6,
 },
 [0x100A7]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x009F CLOTH",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A7,
 },
 [0x100A8]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A0",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A8,
 },
 [0x100A9]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A1",
  direction="l",
  linebreak="al",
  unicodeslot=0x100A9,
 },
 [0x100AA]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A2 GARMENT",
  direction="l",
  linebreak="al",
  unicodeslot=0x100AA,
 },
 [0x100AB]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A3 ARMOUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x100AB,
 },
 [0x100AC]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A4",
  direction="l",
  linebreak="al",
  unicodeslot=0x100AC,
 },
 [0x100AD]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A5",
  direction="l",
  linebreak="al",
  unicodeslot=0x100AD,
 },
 [0x100AE]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A6",
  direction="l",
  linebreak="al",
  unicodeslot=0x100AE,
 },
 [0x100AF]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A7",
  direction="l",
  linebreak="al",
  unicodeslot=0x100AF,
 },
 [0x100B0]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A8",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B0,
 },
 [0x100B1]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00A9",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B1,
 },
 [0x100B2]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B2,
 },
 [0x100B3]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00AB",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B3,
 },
 [0x100B4]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00AC",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B4,
 },
 [0x100B5]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00AD MONTH",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B5,
 },
 [0x100B6]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00AE",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B6,
 },
 [0x100B7]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B0 TREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B7,
 },
 [0x100B8]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B1",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B8,
 },
 [0x100B9]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B2",
  direction="l",
  linebreak="al",
  unicodeslot=0x100B9,
 },
 [0x100BA]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B3",
  direction="l",
  linebreak="al",
  unicodeslot=0x100BA,
 },
 [0x100BB]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B4",
  direction="l",
  linebreak="al",
  unicodeslot=0x100BB,
 },
 [0x100BC]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B5",
  direction="l",
  linebreak="al",
  unicodeslot=0x100BC,
 },
 [0x100BD]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B6",
  direction="l",
  linebreak="al",
  unicodeslot=0x100BD,
 },
 [0x100BE]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B7",
  direction="l",
  linebreak="al",
  unicodeslot=0x100BE,
 },
 [0x100BF]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B8",
  direction="l",
  linebreak="al",
  unicodeslot=0x100BF,
 },
 [0x100C0]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00B9",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C0,
 },
 [0x100C1]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00BD",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C1,
 },
 [0x100C2]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00BE",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C2,
 },
 [0x100C3]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00BF HELMET",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C3,
 },
 [0x100C4]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00DC FOOTSTOOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C4,
 },
 [0x100C5]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00E1 BATHTUB",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C5,
 },
 [0x100C6]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00E6 SPEAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C6,
 },
 [0x100C7]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00E7 ARROW",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C7,
 },
 [0x100C8]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00E8",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C8,
 },
 [0x100C9]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00E9 SWORD",
  direction="l",
  linebreak="al",
  unicodeslot=0x100C9,
 },
 [0x100CA]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00EA",
  direction="l",
  linebreak="al",
  unicodeslot=0x100CA,
 },
 [0x100CB]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00EC",
  direction="l",
  linebreak="al",
  unicodeslot=0x100CB,
 },
 [0x100CC]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00F0 WHEELED CHARIOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x100CC,
 },
 [0x100CD]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00F1 CHARIOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x100CD,
 },
 [0x100CE]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00F2 CHARIOT FRAME",
  direction="l",
  linebreak="al",
  unicodeslot=0x100CE,
 },
 [0x100CF]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00F3 WHEEL",
  direction="l",
  linebreak="al",
  unicodeslot=0x100CF,
 },
 [0x100D0]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00F5",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D0,
 },
 [0x100D1]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00F6",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D1,
 },
 [0x100D2]={
  category="lo",
  description="LINEAR B MONOGRAM B0x00F7 DIPTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D2,
 },
 [0x100D3]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00F8",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D3,
 },
 [0x100D4]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00F9",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D4,
 },
 [0x100D5]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00FB",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D5,
 },
 [0x100D6]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00FC",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D6,
 },
 [0x100D7]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00FD",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D7,
 },
 [0x100D8]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00FE DART",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D8,
 },
 [0x100D9]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x00FF",
  direction="l",
  linebreak="al",
  unicodeslot=0x100D9,
 },
 [0x100DA]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0100",
  direction="l",
  linebreak="al",
  unicodeslot=0x100DA,
 },
 [0x100DB]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0101",
  direction="l",
  linebreak="al",
  unicodeslot=0x100DB,
 },
 [0x100DC]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0102",
  direction="l",
  linebreak="al",
  unicodeslot=0x100DC,
 },
 [0x100DD]={
  category="lo",
  description="LINEAR B IDEOGRAM B0x0103",
  direction="l",
  linebreak="al",
  unicodeslot=0x100DD,
 },
 [0x100DE]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x009B",
  direction="l",
  linebreak="al",
  unicodeslot=0x100DE,
 },
 [0x100DF]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00C8",
  direction="l",
  linebreak="al",
  unicodeslot=0x100DF,
 },
 [0x100E0]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00C9",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E0,
 },
 [0x100E1]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E1,
 },
 [0x100E2]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00CB",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E2,
 },
 [0x100E3]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00CC",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E3,
 },
 [0x100E4]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00CD",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E4,
 },
 [0x100E5]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00CE",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E5,
 },
 [0x100E6]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00CF",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E6,
 },
 [0x100E7]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D0",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E7,
 },
 [0x100E8]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D1",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E8,
 },
 [0x100E9]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D2",
  direction="l",
  linebreak="al",
  unicodeslot=0x100E9,
 },
 [0x100EA]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D3",
  direction="l",
  linebreak="al",
  unicodeslot=0x100EA,
 },
 [0x100EB]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D4",
  direction="l",
  linebreak="al",
  unicodeslot=0x100EB,
 },
 [0x100EC]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D5",
  direction="l",
  linebreak="al",
  unicodeslot=0x100EC,
 },
 [0x100ED]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D6",
  direction="l",
  linebreak="al",
  unicodeslot=0x100ED,
 },
 [0x100EE]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D7",
  direction="l",
  linebreak="al",
  unicodeslot=0x100EE,
 },
 [0x100EF]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D8",
  direction="l",
  linebreak="al",
  unicodeslot=0x100EF,
 },
 [0x100F0]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00D9",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F0,
 },
 [0x100F1]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F1,
 },
 [0x100F2]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00DB",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F2,
 },
 [0x100F3]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00DD",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F3,
 },
 [0x100F4]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00DE",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F4,
 },
 [0x100F5]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00E2",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F5,
 },
 [0x100F6]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00E3",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F6,
 },
 [0x100F7]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00E4",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F7,
 },
 [0x100F8]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00E5",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F8,
 },
 [0x100F9]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x00FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x100F9,
 },
 [0x100FA]={
  category="lo",
  description="LINEAR B IDEOGRAM VESSEL B0x0131",
  direction="l",
  linebreak="al",
  unicodeslot=0x100FA,
 },
 [0x10100]={
  category="po",
  description="AEGEAN WORD SEPARATOR LINE",
  direction="l",
  linebreak="ba",
  unicodeslot=0x10100,
 },
 [0x10101]={
  category="po",
  description="AEGEAN WORD SEPARATOR DOT",
  direction="on",
  linebreak="ba",
  unicodeslot=0x10101,
 },
 [0x10102]={
  category="so",
  description="AEGEAN CHECK MARK",
  direction="l",
  linebreak="ba",
  unicodeslot=0x10102,
 },
 [0x10107]={
  category="no",
  description="AEGEAN NUMBER ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10107,
 },
 [0x10108]={
  category="no",
  description="AEGEAN NUMBER TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10108,
 },
 [0x10109]={
  category="no",
  description="AEGEAN NUMBER THREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10109,
 },
 [0x1010A]={
  category="no",
  description="AEGEAN NUMBER FOUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1010A,
 },
 [0x1010B]={
  category="no",
  description="AEGEAN NUMBER FIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1010B,
 },
 [0x1010C]={
  category="no",
  description="AEGEAN NUMBER SIX",
  direction="l",
  linebreak="al",
  unicodeslot=0x1010C,
 },
 [0x1010D]={
  category="no",
  description="AEGEAN NUMBER SEVEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1010D,
 },
 [0x1010E]={
  category="no",
  description="AEGEAN NUMBER EIGHT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1010E,
 },
 [0x1010F]={
  category="no",
  description="AEGEAN NUMBER NINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1010F,
 },
 [0x10110]={
  category="no",
  description="AEGEAN NUMBER TEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10110,
 },
 [0x10111]={
  category="no",
  description="AEGEAN NUMBER TWENTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10111,
 },
 [0x10112]={
  category="no",
  description="AEGEAN NUMBER THIRTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10112,
 },
 [0x10113]={
  category="no",
  description="AEGEAN NUMBER FORTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10113,
 },
 [0x10114]={
  category="no",
  description="AEGEAN NUMBER FIFTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10114,
 },
 [0x10115]={
  category="no",
  description="AEGEAN NUMBER SIXTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10115,
 },
 [0x10116]={
  category="no",
  description="AEGEAN NUMBER SEVENTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10116,
 },
 [0x10117]={
  category="no",
  description="AEGEAN NUMBER EIGHTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10117,
 },
 [0x10118]={
  category="no",
  description="AEGEAN NUMBER NINETY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10118,
 },
 [0x10119]={
  category="no",
  description="AEGEAN NUMBER ONE HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x10119,
 },
 [0x1011A]={
  category="no",
  description="AEGEAN NUMBER TWO HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x1011A,
 },
 [0x1011B]={
  category="no",
  description="AEGEAN NUMBER THREE HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x1011B,
 },
 [0x1011C]={
  category="no",
  description="AEGEAN NUMBER FOUR HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x1011C,
 },
 [0x1011D]={
  category="no",
  description="AEGEAN NUMBER FIVE HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x1011D,
 },
 [0x1011E]={
  category="no",
  description="AEGEAN NUMBER SIX HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x1011E,
 },
 [0x1011F]={
  category="no",
  description="AEGEAN NUMBER SEVEN HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x1011F,
 },
 [0x10120]={
  category="no",
  description="AEGEAN NUMBER EIGHT HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x10120,
 },
 [0x10121]={
  category="no",
  description="AEGEAN NUMBER NINE HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x10121,
 },
 [0x10122]={
  category="no",
  description="AEGEAN NUMBER ONE THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10122,
 },
 [0x10123]={
  category="no",
  description="AEGEAN NUMBER TWO THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10123,
 },
 [0x10124]={
  category="no",
  description="AEGEAN NUMBER THREE THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10124,
 },
 [0x10125]={
  category="no",
  description="AEGEAN NUMBER FOUR THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10125,
 },
 [0x10126]={
  category="no",
  description="AEGEAN NUMBER FIVE THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10126,
 },
 [0x10127]={
  category="no",
  description="AEGEAN NUMBER SIX THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10127,
 },
 [0x10128]={
  category="no",
  description="AEGEAN NUMBER SEVEN THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10128,
 },
 [0x10129]={
  category="no",
  description="AEGEAN NUMBER EIGHT THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10129,
 },
 [0x1012A]={
  category="no",
  description="AEGEAN NUMBER NINE THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x1012A,
 },
 [0x1012B]={
  category="no",
  description="AEGEAN NUMBER TEN THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x1012B,
 },
 [0x1012C]={
  category="no",
  description="AEGEAN NUMBER TWENTY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x1012C,
 },
 [0x1012D]={
  category="no",
  description="AEGEAN NUMBER THIRTY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x1012D,
 },
 [0x1012E]={
  category="no",
  description="AEGEAN NUMBER FORTY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x1012E,
 },
 [0x1012F]={
  category="no",
  description="AEGEAN NUMBER FIFTY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x1012F,
 },
 [0x10130]={
  category="no",
  description="AEGEAN NUMBER SIXTY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10130,
 },
 [0x10131]={
  category="no",
  description="AEGEAN NUMBER SEVENTY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10131,
 },
 [0x10132]={
  category="no",
  description="AEGEAN NUMBER EIGHTY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10132,
 },
 [0x10133]={
  category="no",
  description="AEGEAN NUMBER NINETY THOUSAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x10133,
 },
 [0x10137]={
  category="so",
  description="AEGEAN WEIGHT BASE UNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x10137,
 },
 [0x10138]={
  category="so",
  description="AEGEAN WEIGHT FIRST SUBUNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x10138,
 },
 [0x10139]={
  category="so",
  description="AEGEAN WEIGHT SECOND SUBUNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x10139,
 },
 [0x1013A]={
  category="so",
  description="AEGEAN WEIGHT THIRD SUBUNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1013A,
 },
 [0x1013B]={
  category="so",
  description="AEGEAN WEIGHT FOURTH SUBUNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1013B,
 },
 [0x1013C]={
  category="so",
  description="AEGEAN DRY MEASURE FIRST SUBUNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1013C,
 },
 [0x1013D]={
  category="so",
  description="AEGEAN LIQUID MEASURE FIRST SUBUNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1013D,
 },
 [0x1013E]={
  category="so",
  description="AEGEAN MEASURE SECOND SUBUNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1013E,
 },
 [0x1013F]={
  category="so",
  description="AEGEAN MEASURE THIRD SUBUNIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1013F,
 },
 [0x10140]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC ONE QUARTER",
  direction="on",
  linebreak="al",
  unicodeslot=0x10140,
 },
 [0x10141]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC ONE HALF",
  direction="on",
  linebreak="al",
  unicodeslot=0x10141,
 },
 [0x10142]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC ONE DRACHMA",
  direction="on",
  linebreak="al",
  unicodeslot=0x10142,
 },
 [0x10143]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x10143,
 },
 [0x10144]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIFTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x10144,
 },
 [0x10145]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIVE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x10145,
 },
 [0x10146]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIVE THOUSAND",
  direction="on",
  linebreak="al",
  unicodeslot=0x10146,
 },
 [0x10147]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIFTY THOUSAND",
  direction="on",
  linebreak="al",
  unicodeslot=0x10147,
 },
 [0x10148]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIVE TALENTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10148,
 },
 [0x10149]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC TEN TALENTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10149,
 },
 [0x1014A]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIFTY TALENTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1014A,
 },
 [0x1014B]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC ONE HUNDRED TALENTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1014B,
 },
 [0x1014C]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIVE HUNDRED TALENTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1014C,
 },
 [0x1014D]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC ONE THOUSAND TALENTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1014D,
 },
 [0x1014E]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIVE THOUSAND TALENTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1014E,
 },
 [0x1014F]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIVE STATERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1014F,
 },
 [0x10150]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC TEN STATERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10150,
 },
 [0x10151]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIFTY STATERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10151,
 },
 [0x10152]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC ONE HUNDRED STATERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10152,
 },
 [0x10153]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIVE HUNDRED STATERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10153,
 },
 [0x10154]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC ONE THOUSAND STATERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10154,
 },
 [0x10155]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC TEN THOUSAND STATERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10155,
 },
 [0x10156]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC FIFTY THOUSAND STATERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10156,
 },
 [0x10157]={
  category="nl",
  description="GREEK ACROPHONIC ATTIC TEN MNAS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10157,
 },
 [0x10158]={
  category="nl",
  description="GREEK ACROPHONIC HERAEUM ONE PLETHRON",
  direction="on",
  linebreak="al",
  unicodeslot=0x10158,
 },
 [0x10159]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN ONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x10159,
 },
 [0x1015A]={
  category="nl",
  description="GREEK ACROPHONIC HERMIONIAN ONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1015A,
 },
 [0x1015B]={
  category="nl",
  description="GREEK ACROPHONIC EPIDAUREAN TWO",
  direction="on",
  linebreak="al",
  unicodeslot=0x1015B,
 },
 [0x1015C]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN TWO",
  direction="on",
  linebreak="al",
  unicodeslot=0x1015C,
 },
 [0x1015D]={
  category="nl",
  description="GREEK ACROPHONIC CYRENAIC TWO DRACHMAS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1015D,
 },
 [0x1015E]={
  category="nl",
  description="GREEK ACROPHONIC EPIDAUREAN TWO DRACHMAS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1015E,
 },
 [0x1015F]={
  category="nl",
  description="GREEK ACROPHONIC TROEZENIAN FIVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1015F,
 },
 [0x10160]={
  category="nl",
  description="GREEK ACROPHONIC TROEZENIAN TEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10160,
 },
 [0x10161]={
  category="nl",
  description="GREEK ACROPHONIC TROEZENIAN TEN ALTERNATE FORM",
  direction="on",
  linebreak="al",
  unicodeslot=0x10161,
 },
 [0x10162]={
  category="nl",
  description="GREEK ACROPHONIC HERMIONIAN TEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10162,
 },
 [0x10163]={
  category="nl",
  description="GREEK ACROPHONIC MESSENIAN TEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10163,
 },
 [0x10164]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN TEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10164,
 },
 [0x10165]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN THIRTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x10165,
 },
 [0x10166]={
  category="nl",
  description="GREEK ACROPHONIC TROEZENIAN FIFTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x10166,
 },
 [0x10167]={
  category="nl",
  description="GREEK ACROPHONIC TROEZENIAN FIFTY ALTERNATE FORM",
  direction="on",
  linebreak="al",
  unicodeslot=0x10167,
 },
 [0x10168]={
  category="nl",
  description="GREEK ACROPHONIC HERMIONIAN FIFTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x10168,
 },
 [0x10169]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN FIFTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x10169,
 },
 [0x1016A]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN ONE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x1016A,
 },
 [0x1016B]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN THREE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x1016B,
 },
 [0x1016C]={
  category="nl",
  description="GREEK ACROPHONIC EPIDAUREAN FIVE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x1016C,
 },
 [0x1016D]={
  category="nl",
  description="GREEK ACROPHONIC TROEZENIAN FIVE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x1016D,
 },
 [0x1016E]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN FIVE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x1016E,
 },
 [0x1016F]={
  category="nl",
  description="GREEK ACROPHONIC CARYSTIAN FIVE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x1016F,
 },
 [0x10170]={
  category="nl",
  description="GREEK ACROPHONIC NAXIAN FIVE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x10170,
 },
 [0x10171]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN ONE THOUSAND",
  direction="on",
  linebreak="al",
  unicodeslot=0x10171,
 },
 [0x10172]={
  category="nl",
  description="GREEK ACROPHONIC THESPIAN FIVE THOUSAND",
  direction="on",
  linebreak="al",
  unicodeslot=0x10172,
 },
 [0x10173]={
  category="nl",
  description="GREEK ACROPHONIC DELPHIC FIVE MNAS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10173,
 },
 [0x10174]={
  category="nl",
  description="GREEK ACROPHONIC STRATIAN FIFTY MNAS",
  direction="on",
  linebreak="al",
  unicodeslot=0x10174,
 },
 [0x10175]={
  category="no",
  description="GREEK ONE HALF SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10175,
 },
 [0x10176]={
  category="no",
  description="GREEK ONE HALF SIGN ALTERNATE FORM",
  direction="on",
  linebreak="al",
  unicodeslot=0x10176,
 },
 [0x10177]={
  category="no",
  description="GREEK TWO THIRDS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10177,
 },
 [0x10178]={
  category="no",
  description="GREEK THREE QUARTERS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10178,
 },
 [0x10179]={
  category="so",
  description="GREEK YEAR SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10179,
 },
 [0x1017A]={
  category="so",
  description="GREEK TALENT SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1017A,
 },
 [0x1017B]={
  category="so",
  description="GREEK DRACHMA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1017B,
 },
 [0x1017C]={
  category="so",
  description="GREEK OBOL SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1017C,
 },
 [0x1017D]={
  category="so",
  description="GREEK TWO OBOLS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1017D,
 },
 [0x1017E]={
  category="so",
  description="GREEK THREE OBOLS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1017E,
 },
 [0x1017F]={
  category="so",
  description="GREEK FOUR OBOLS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1017F,
 },
 [0x10180]={
  category="so",
  description="GREEK FIVE OBOLS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10180,
 },
 [0x10181]={
  category="so",
  description="GREEK METRETES SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10181,
 },
 [0x10182]={
  category="so",
  description="GREEK KYATHOS BASE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10182,
 },
 [0x10183]={
  category="so",
  description="GREEK LITRA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10183,
 },
 [0x10184]={
  category="so",
  description="GREEK OUNKIA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10184,
 },
 [0x10185]={
  category="so",
  description="GREEK XESTES SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10185,
 },
 [0x10186]={
  category="so",
  description="GREEK ARTABE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10186,
 },
 [0x10187]={
  category="so",
  description="GREEK AROURA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10187,
 },
 [0x10188]={
  category="so",
  description="GREEK GRAMMA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10188,
 },
 [0x10189]={
  category="so",
  description="GREEK TRYBLION BASE SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10189,
 },
 [0x1018A]={
  category="no",
  description="GREEK ZERO SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1018A,
 },
 [0x10190]={
  category="so",
  description="ROMAN SEXTANS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10190,
 },
 [0x10191]={
  category="so",
  description="ROMAN UNCIA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10191,
 },
 [0x10192]={
  category="so",
  description="ROMAN SEMUNCIA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10192,
 },
 [0x10193]={
  category="so",
  description="ROMAN SEXTULA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10193,
 },
 [0x10194]={
  category="so",
  description="ROMAN DIMIDIA SEXTULA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10194,
 },
 [0x10195]={
  category="so",
  description="ROMAN SILIQUA SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10195,
 },
 [0x10196]={
  category="so",
  description="ROMAN DENARIUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10196,
 },
 [0x10197]={
  category="so",
  description="ROMAN QUINARIUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10197,
 },
 [0x10198]={
  category="so",
  description="ROMAN SESTERTIUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10198,
 },
 [0x10199]={
  category="so",
  description="ROMAN DUPONDIUS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x10199,
 },
 [0x1019A]={
  category="so",
  description="ROMAN AS SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1019A,
 },
 [0x1019B]={
  category="so",
  description="ROMAN CENTURIAL SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1019B,
 },
 [0x101D0]={
  category="so",
  description="PHAISTOS DISC SIGN PEDESTRIAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D0,
 },
 [0x101D1]={
  category="so",
  description="PHAISTOS DISC SIGN PLUMED HEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D1,
 },
 [0x101D2]={
  category="so",
  description="PHAISTOS DISC SIGN TATTOOED HEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D2,
 },
 [0x101D3]={
  category="so",
  description="PHAISTOS DISC SIGN CAPTIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D3,
 },
 [0x101D4]={
  category="so",
  description="PHAISTOS DISC SIGN CHILD",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D4,
 },
 [0x101D5]={
  category="so",
  description="PHAISTOS DISC SIGN WOMAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D5,
 },
 [0x101D6]={
  category="so",
  description="PHAISTOS DISC SIGN HELMET",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D6,
 },
 [0x101D7]={
  category="so",
  description="PHAISTOS DISC SIGN GAUNTLET",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D7,
 },
 [0x101D8]={
  category="so",
  description="PHAISTOS DISC SIGN TIARA",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D8,
 },
 [0x101D9]={
  category="so",
  description="PHAISTOS DISC SIGN ARROW",
  direction="l",
  linebreak="al",
  unicodeslot=0x101D9,
 },
 [0x101DA]={
  category="so",
  description="PHAISTOS DISC SIGN BOW",
  direction="l",
  linebreak="al",
  unicodeslot=0x101DA,
 },
 [0x101DB]={
  category="so",
  description="PHAISTOS DISC SIGN SHIELD",
  direction="l",
  linebreak="al",
  unicodeslot=0x101DB,
 },
 [0x101DC]={
  category="so",
  description="PHAISTOS DISC SIGN CLUB",
  direction="l",
  linebreak="al",
  unicodeslot=0x101DC,
 },
 [0x101DD]={
  category="so",
  description="PHAISTOS DISC SIGN MANACLES",
  direction="l",
  linebreak="al",
  unicodeslot=0x101DD,
 },
 [0x101DE]={
  category="so",
  description="PHAISTOS DISC SIGN MATTOCK",
  direction="l",
  linebreak="al",
  unicodeslot=0x101DE,
 },
 [0x101DF]={
  category="so",
  description="PHAISTOS DISC SIGN SAW",
  direction="l",
  linebreak="al",
  unicodeslot=0x101DF,
 },
 [0x101E0]={
  category="so",
  description="PHAISTOS DISC SIGN LID",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E0,
 },
 [0x101E1]={
  category="so",
  description="PHAISTOS DISC SIGN BOOMERANG",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E1,
 },
 [0x101E2]={
  category="so",
  description="PHAISTOS DISC SIGN CARPENTRY PLANE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E2,
 },
 [0x101E3]={
  category="so",
  description="PHAISTOS DISC SIGN DOLIUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E3,
 },
 [0x101E4]={
  category="so",
  description="PHAISTOS DISC SIGN COMB",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E4,
 },
 [0x101E5]={
  category="so",
  description="PHAISTOS DISC SIGN SLING",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E5,
 },
 [0x101E6]={
  category="so",
  description="PHAISTOS DISC SIGN COLUMN",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E6,
 },
 [0x101E7]={
  category="so",
  description="PHAISTOS DISC SIGN BEEHIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E7,
 },
 [0x101E8]={
  category="so",
  description="PHAISTOS DISC SIGN SHIP",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E8,
 },
 [0x101E9]={
  category="so",
  description="PHAISTOS DISC SIGN HORN",
  direction="l",
  linebreak="al",
  unicodeslot=0x101E9,
 },
 [0x101EA]={
  category="so",
  description="PHAISTOS DISC SIGN HIDE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101EA,
 },
 [0x101EB]={
  category="so",
  description="PHAISTOS DISC SIGN BULLS LEG",
  direction="l",
  linebreak="al",
  unicodeslot=0x101EB,
 },
 [0x101EC]={
  category="so",
  description="PHAISTOS DISC SIGN CAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x101EC,
 },
 [0x101ED]={
  category="so",
  description="PHAISTOS DISC SIGN RAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x101ED,
 },
 [0x101EE]={
  category="so",
  description="PHAISTOS DISC SIGN EAGLE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101EE,
 },
 [0x101EF]={
  category="so",
  description="PHAISTOS DISC SIGN DOVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101EF,
 },
 [0x101F0]={
  category="so",
  description="PHAISTOS DISC SIGN TUNNY",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F0,
 },
 [0x101F1]={
  category="so",
  description="PHAISTOS DISC SIGN BEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F1,
 },
 [0x101F2]={
  category="so",
  description="PHAISTOS DISC SIGN PLANE TREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F2,
 },
 [0x101F3]={
  category="so",
  description="PHAISTOS DISC SIGN VINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F3,
 },
 [0x101F4]={
  category="so",
  description="PHAISTOS DISC SIGN PAPYRUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F4,
 },
 [0x101F5]={
  category="so",
  description="PHAISTOS DISC SIGN ROSETTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F5,
 },
 [0x101F6]={
  category="so",
  description="PHAISTOS DISC SIGN LILY",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F6,
 },
 [0x101F7]={
  category="so",
  description="PHAISTOS DISC SIGN OX BACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F7,
 },
 [0x101F8]={
  category="so",
  description="PHAISTOS DISC SIGN FLUTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F8,
 },
 [0x101F9]={
  category="so",
  description="PHAISTOS DISC SIGN GRATER",
  direction="l",
  linebreak="al",
  unicodeslot=0x101F9,
 },
 [0x101FA]={
  category="so",
  description="PHAISTOS DISC SIGN STRAINER",
  direction="l",
  linebreak="al",
  unicodeslot=0x101FA,
 },
 [0x101FB]={
  category="so",
  description="PHAISTOS DISC SIGN SMALL AXE",
  direction="l",
  linebreak="al",
  unicodeslot=0x101FB,
 },
 [0x101FC]={
  category="so",
  description="PHAISTOS DISC SIGN WAVY BAND",
  direction="l",
  linebreak="al",
  unicodeslot=0x101FC,
 },
 [0x101FD]={
  category="mn",
  description="PHAISTOS DISC SIGN COMBINING OBLIQUE STROKE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x101FD,
 },
 [0x10280]={
  category="lo",
  description="LYCIAN LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x10280,
 },
 [0x10281]={
  category="lo",
  description="LYCIAN LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x10281,
 },
 [0x10282]={
  category="lo",
  description="LYCIAN LETTER B",
  direction="l",
  linebreak="al",
  unicodeslot=0x10282,
 },
 [0x10283]={
  category="lo",
  description="LYCIAN LETTER BH",
  direction="l",
  linebreak="al",
  unicodeslot=0x10283,
 },
 [0x10284]={
  category="lo",
  description="LYCIAN LETTER G",
  direction="l",
  linebreak="al",
  unicodeslot=0x10284,
 },
 [0x10285]={
  category="lo",
  description="LYCIAN LETTER D",
  direction="l",
  linebreak="al",
  unicodeslot=0x10285,
 },
 [0x10286]={
  category="lo",
  description="LYCIAN LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x10286,
 },
 [0x10287]={
  category="lo",
  description="LYCIAN LETTER W",
  direction="l",
  linebreak="al",
  unicodeslot=0x10287,
 },
 [0x10288]={
  category="lo",
  description="LYCIAN LETTER Z",
  direction="l",
  linebreak="al",
  unicodeslot=0x10288,
 },
 [0x10289]={
  category="lo",
  description="LYCIAN LETTER TH",
  direction="l",
  linebreak="al",
  unicodeslot=0x10289,
 },
 [0x1028A]={
  category="lo",
  description="LYCIAN LETTER J",
  direction="l",
  linebreak="al",
  unicodeslot=0x1028A,
 },
 [0x1028B]={
  category="lo",
  description="LYCIAN LETTER K",
  direction="l",
  linebreak="al",
  unicodeslot=0x1028B,
 },
 [0x1028C]={
  category="lo",
  description="LYCIAN LETTER Q",
  direction="l",
  linebreak="al",
  unicodeslot=0x1028C,
 },
 [0x1028D]={
  category="lo",
  description="LYCIAN LETTER L",
  direction="l",
  linebreak="al",
  unicodeslot=0x1028D,
 },
 [0x1028E]={
  category="lo",
  description="LYCIAN LETTER M",
  direction="l",
  linebreak="al",
  unicodeslot=0x1028E,
 },
 [0x1028F]={
  category="lo",
  description="LYCIAN LETTER N",
  direction="l",
  linebreak="al",
  unicodeslot=0x1028F,
 },
 [0x10290]={
  category="lo",
  description="LYCIAN LETTER MM",
  direction="l",
  linebreak="al",
  unicodeslot=0x10290,
 },
 [0x10291]={
  category="lo",
  description="LYCIAN LETTER NN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10291,
 },
 [0x10292]={
  category="lo",
  description="LYCIAN LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x10292,
 },
 [0x10293]={
  category="lo",
  description="LYCIAN LETTER P",
  direction="l",
  linebreak="al",
  unicodeslot=0x10293,
 },
 [0x10294]={
  category="lo",
  description="LYCIAN LETTER KK",
  direction="l",
  linebreak="al",
  unicodeslot=0x10294,
 },
 [0x10295]={
  category="lo",
  description="LYCIAN LETTER R",
  direction="l",
  linebreak="al",
  unicodeslot=0x10295,
 },
 [0x10296]={
  category="lo",
  description="LYCIAN LETTER S",
  direction="l",
  linebreak="al",
  unicodeslot=0x10296,
 },
 [0x10297]={
  category="lo",
  description="LYCIAN LETTER T",
  direction="l",
  linebreak="al",
  unicodeslot=0x10297,
 },
 [0x10298]={
  category="lo",
  description="LYCIAN LETTER TT",
  direction="l",
  linebreak="al",
  unicodeslot=0x10298,
 },
 [0x10299]={
  category="lo",
  description="LYCIAN LETTER AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10299,
 },
 [0x1029A]={
  category="lo",
  description="LYCIAN LETTER EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1029A,
 },
 [0x1029B]={
  category="lo",
  description="LYCIAN LETTER H",
  direction="l",
  linebreak="al",
  unicodeslot=0x1029B,
 },
 [0x1029C]={
  category="lo",
  description="LYCIAN LETTER X",
  direction="l",
  linebreak="al",
  unicodeslot=0x1029C,
 },
 [0x102A0]={
  category="lo",
  description="CARIAN LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A0,
 },
 [0x102A1]={
  category="lo",
  description="CARIAN LETTER P2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A1,
 },
 [0x102A2]={
  category="lo",
  description="CARIAN LETTER D",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A2,
 },
 [0x102A3]={
  category="lo",
  description="CARIAN LETTER L",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A3,
 },
 [0x102A4]={
  category="lo",
  description="CARIAN LETTER UUU",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A4,
 },
 [0x102A5]={
  category="lo",
  description="CARIAN LETTER R",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A5,
 },
 [0x102A6]={
  category="lo",
  description="CARIAN LETTER LD",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A6,
 },
 [0x102A7]={
  category="lo",
  description="CARIAN LETTER A2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A7,
 },
 [0x102A8]={
  category="lo",
  description="CARIAN LETTER Q",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A8,
 },
 [0x102A9]={
  category="lo",
  description="CARIAN LETTER B",
  direction="l",
  linebreak="al",
  unicodeslot=0x102A9,
 },
 [0x102AA]={
  category="lo",
  description="CARIAN LETTER M",
  direction="l",
  linebreak="al",
  unicodeslot=0x102AA,
 },
 [0x102AB]={
  category="lo",
  description="CARIAN LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x102AB,
 },
 [0x102AC]={
  category="lo",
  description="CARIAN LETTER D2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102AC,
 },
 [0x102AD]={
  category="lo",
  description="CARIAN LETTER T",
  direction="l",
  linebreak="al",
  unicodeslot=0x102AD,
 },
 [0x102AE]={
  category="lo",
  description="CARIAN LETTER SH",
  direction="l",
  linebreak="al",
  unicodeslot=0x102AE,
 },
 [0x102AF]={
  category="lo",
  description="CARIAN LETTER SH2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102AF,
 },
 [0x102B0]={
  category="lo",
  description="CARIAN LETTER S",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B0,
 },
 [0x102B1]={
  category="lo",
  description="CARIAN LETTER C-18",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B1,
 },
 [0x102B2]={
  category="lo",
  description="CARIAN LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B2,
 },
 [0x102B3]={
  category="lo",
  description="CARIAN LETTER NN",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B3,
 },
 [0x102B4]={
  category="lo",
  description="CARIAN LETTER X",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B4,
 },
 [0x102B5]={
  category="lo",
  description="CARIAN LETTER N",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B5,
 },
 [0x102B6]={
  category="lo",
  description="CARIAN LETTER TT2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B6,
 },
 [0x102B7]={
  category="lo",
  description="CARIAN LETTER P",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B7,
 },
 [0x102B8]={
  category="lo",
  description="CARIAN LETTER SS",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B8,
 },
 [0x102B9]={
  category="lo",
  description="CARIAN LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x102B9,
 },
 [0x102BA]={
  category="lo",
  description="CARIAN LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x102BA,
 },
 [0x102BB]={
  category="lo",
  description="CARIAN LETTER UUUU",
  direction="l",
  linebreak="al",
  unicodeslot=0x102BB,
 },
 [0x102BC]={
  category="lo",
  description="CARIAN LETTER K",
  direction="l",
  linebreak="al",
  unicodeslot=0x102BC,
 },
 [0x102BD]={
  category="lo",
  description="CARIAN LETTER K2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102BD,
 },
 [0x102BE]={
  category="lo",
  description="CARIAN LETTER ND",
  direction="l",
  linebreak="al",
  unicodeslot=0x102BE,
 },
 [0x102BF]={
  category="lo",
  description="CARIAN LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x102BF,
 },
 [0x102C0]={
  category="lo",
  description="CARIAN LETTER G",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C0,
 },
 [0x102C1]={
  category="lo",
  description="CARIAN LETTER G2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C1,
 },
 [0x102C2]={
  category="lo",
  description="CARIAN LETTER ST",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C2,
 },
 [0x102C3]={
  category="lo",
  description="CARIAN LETTER ST2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C3,
 },
 [0x102C4]={
  category="lo",
  description="CARIAN LETTER NG",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C4,
 },
 [0x102C5]={
  category="lo",
  description="CARIAN LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C5,
 },
 [0x102C6]={
  category="lo",
  description="CARIAN LETTER C-39",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C6,
 },
 [0x102C7]={
  category="lo",
  description="CARIAN LETTER TT",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C7,
 },
 [0x102C8]={
  category="lo",
  description="CARIAN LETTER UUU2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C8,
 },
 [0x102C9]={
  category="lo",
  description="CARIAN LETTER RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x102C9,
 },
 [0x102CA]={
  category="lo",
  description="CARIAN LETTER MB",
  direction="l",
  linebreak="al",
  unicodeslot=0x102CA,
 },
 [0x102CB]={
  category="lo",
  description="CARIAN LETTER MB2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102CB,
 },
 [0x102CC]={
  category="lo",
  description="CARIAN LETTER MB3",
  direction="l",
  linebreak="al",
  unicodeslot=0x102CC,
 },
 [0x102CD]={
  category="lo",
  description="CARIAN LETTER MB4",
  direction="l",
  linebreak="al",
  unicodeslot=0x102CD,
 },
 [0x102CE]={
  category="lo",
  description="CARIAN LETTER LD2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102CE,
 },
 [0x102CF]={
  category="lo",
  description="CARIAN LETTER E2",
  direction="l",
  linebreak="al",
  unicodeslot=0x102CF,
 },
 [0x102D0]={
  category="lo",
  description="CARIAN LETTER UUU3",
  direction="l",
  linebreak="al",
  unicodeslot=0x102D0,
 },
 [0x10300]={
  category="lo",
  description="OLD ITALIC LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x10300,
 },
 [0x10301]={
  category="lo",
  description="OLD ITALIC LETTER BE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10301,
 },
 [0x10302]={
  category="lo",
  description="OLD ITALIC LETTER KE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10302,
 },
 [0x10303]={
  category="lo",
  description="OLD ITALIC LETTER DE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10303,
 },
 [0x10304]={
  category="lo",
  description="OLD ITALIC LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x10304,
 },
 [0x10305]={
  category="lo",
  description="OLD ITALIC LETTER VE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10305,
 },
 [0x10306]={
  category="lo",
  description="OLD ITALIC LETTER ZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10306,
 },
 [0x10307]={
  category="lo",
  description="OLD ITALIC LETTER HE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10307,
 },
 [0x10308]={
  category="lo",
  description="OLD ITALIC LETTER THE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10308,
 },
 [0x10309]={
  category="lo",
  description="OLD ITALIC LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x10309,
 },
 [0x1030A]={
  category="lo",
  description="OLD ITALIC LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1030A,
 },
 [0x1030B]={
  category="lo",
  description="OLD ITALIC LETTER EL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1030B,
 },
 [0x1030C]={
  category="lo",
  description="OLD ITALIC LETTER EM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1030C,
 },
 [0x1030D]={
  category="lo",
  description="OLD ITALIC LETTER EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1030D,
 },
 [0x1030E]={
  category="lo",
  description="OLD ITALIC LETTER ESH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1030E,
 },
 [0x1030F]={
  category="lo",
  description="OLD ITALIC LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1030F,
 },
 [0x10310]={
  category="lo",
  description="OLD ITALIC LETTER PE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10310,
 },
 [0x10311]={
  category="lo",
  description="OLD ITALIC LETTER SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10311,
 },
 [0x10312]={
  category="lo",
  description="OLD ITALIC LETTER KU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10312,
 },
 [0x10313]={
  category="lo",
  description="OLD ITALIC LETTER ER",
  direction="l",
  linebreak="al",
  unicodeslot=0x10313,
 },
 [0x10314]={
  category="lo",
  description="OLD ITALIC LETTER ES",
  direction="l",
  linebreak="al",
  unicodeslot=0x10314,
 },
 [0x10315]={
  category="lo",
  description="OLD ITALIC LETTER TE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10315,
 },
 [0x10316]={
  category="lo",
  description="OLD ITALIC LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x10316,
 },
 [0x10317]={
  category="lo",
  description="OLD ITALIC LETTER EKS",
  direction="l",
  linebreak="al",
  unicodeslot=0x10317,
 },
 [0x10318]={
  category="lo",
  description="OLD ITALIC LETTER PHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10318,
 },
 [0x10319]={
  category="lo",
  description="OLD ITALIC LETTER KHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10319,
 },
 [0x1031A]={
  category="lo",
  description="OLD ITALIC LETTER EF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1031A,
 },
 [0x1031B]={
  category="lo",
  description="OLD ITALIC LETTER ERS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1031B,
 },
 [0x1031C]={
  category="lo",
  description="OLD ITALIC LETTER CHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1031C,
 },
 [0x1031D]={
  category="lo",
  description="OLD ITALIC LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x1031D,
 },
 [0x1031E]={
  category="lo",
  description="OLD ITALIC LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1031E,
 },
 [0x10320]={
  category="no",
  description="OLD ITALIC NUMERAL ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10320,
 },
 [0x10321]={
  category="no",
  description="OLD ITALIC NUMERAL FIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10321,
 },
 [0x10322]={
  category="no",
  description="OLD ITALIC NUMERAL TEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10322,
 },
 [0x10323]={
  category="no",
  description="OLD ITALIC NUMERAL FIFTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10323,
 },
 [0x10330]={
  category="lo",
  description="GOTHIC LETTER AHSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10330,
 },
 [0x10331]={
  category="lo",
  description="GOTHIC LETTER BAIRKAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10331,
 },
 [0x10332]={
  category="lo",
  description="GOTHIC LETTER GIBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10332,
 },
 [0x10333]={
  category="lo",
  description="GOTHIC LETTER DAGS",
  direction="l",
  linebreak="al",
  unicodeslot=0x10333,
 },
 [0x10334]={
  category="lo",
  description="GOTHIC LETTER AIHVUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x10334,
 },
 [0x10335]={
  category="lo",
  description="GOTHIC LETTER QAIRTHRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10335,
 },
 [0x10336]={
  category="lo",
  description="GOTHIC LETTER IUJA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10336,
 },
 [0x10337]={
  category="lo",
  description="GOTHIC LETTER HAGL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10337,
 },
 [0x10338]={
  category="lo",
  description="GOTHIC LETTER THIUTH",
  direction="l",
  linebreak="al",
  unicodeslot=0x10338,
 },
 [0x10339]={
  category="lo",
  description="GOTHIC LETTER EIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x10339,
 },
 [0x1033A]={
  category="lo",
  description="GOTHIC LETTER KUSMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1033A,
 },
 [0x1033B]={
  category="lo",
  description="GOTHIC LETTER LAGUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1033B,
 },
 [0x1033C]={
  category="lo",
  description="GOTHIC LETTER MANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1033C,
 },
 [0x1033D]={
  category="lo",
  description="GOTHIC LETTER NAUTHS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1033D,
 },
 [0x1033E]={
  category="lo",
  description="GOTHIC LETTER JER",
  direction="l",
  linebreak="al",
  unicodeslot=0x1033E,
 },
 [0x1033F]={
  category="lo",
  description="GOTHIC LETTER URUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1033F,
 },
 [0x10340]={
  category="lo",
  description="GOTHIC LETTER PAIRTHRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10340,
 },
 [0x10341]={
  category="nl",
  description="GOTHIC LETTER NINETY",
  direction="l",
  linebreak="al",
  unicodeslot=0x10341,
 },
 [0x10342]={
  category="lo",
  description="GOTHIC LETTER RAIDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10342,
 },
 [0x10343]={
  category="lo",
  description="GOTHIC LETTER SAUIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10343,
 },
 [0x10344]={
  category="lo",
  description="GOTHIC LETTER TEIWS",
  direction="l",
  linebreak="al",
  unicodeslot=0x10344,
 },
 [0x10345]={
  category="lo",
  description="GOTHIC LETTER WINJA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10345,
 },
 [0x10346]={
  category="lo",
  description="GOTHIC LETTER FAIHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10346,
 },
 [0x10347]={
  category="lo",
  description="GOTHIC LETTER IGGWS",
  direction="l",
  linebreak="al",
  unicodeslot=0x10347,
 },
 [0x10348]={
  category="lo",
  description="GOTHIC LETTER HWAIR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10348,
 },
 [0x10349]={
  category="lo",
  description="GOTHIC LETTER OTHAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10349,
 },
 [0x1034A]={
  category="nl",
  description="GOTHIC LETTER NINE HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x1034A,
 },
 [0x10380]={
  category="lo",
  description="UGARITIC LETTER ALPA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10380,
 },
 [0x10381]={
  category="lo",
  description="UGARITIC LETTER BETA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10381,
 },
 [0x10382]={
  category="lo",
  description="UGARITIC LETTER GAMLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10382,
 },
 [0x10383]={
  category="lo",
  description="UGARITIC LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10383,
 },
 [0x10384]={
  category="lo",
  description="UGARITIC LETTER DELTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10384,
 },
 [0x10385]={
  category="lo",
  description="UGARITIC LETTER HO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10385,
 },
 [0x10386]={
  category="lo",
  description="UGARITIC LETTER WO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10386,
 },
 [0x10387]={
  category="lo",
  description="UGARITIC LETTER ZETA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10387,
 },
 [0x10388]={
  category="lo",
  description="UGARITIC LETTER HOTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10388,
 },
 [0x10389]={
  category="lo",
  description="UGARITIC LETTER TET",
  direction="l",
  linebreak="al",
  unicodeslot=0x10389,
 },
 [0x1038A]={
  category="lo",
  description="UGARITIC LETTER YOD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1038A,
 },
 [0x1038B]={
  category="lo",
  description="UGARITIC LETTER KAF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1038B,
 },
 [0x1038C]={
  category="lo",
  description="UGARITIC LETTER SHIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1038C,
 },
 [0x1038D]={
  category="lo",
  description="UGARITIC LETTER LAMDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1038D,
 },
 [0x1038E]={
  category="lo",
  description="UGARITIC LETTER MEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1038E,
 },
 [0x1038F]={
  category="lo",
  description="UGARITIC LETTER DHAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1038F,
 },
 [0x10390]={
  category="lo",
  description="UGARITIC LETTER NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10390,
 },
 [0x10391]={
  category="lo",
  description="UGARITIC LETTER ZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10391,
 },
 [0x10392]={
  category="lo",
  description="UGARITIC LETTER SAMKA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10392,
 },
 [0x10393]={
  category="lo",
  description="UGARITIC LETTER AIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10393,
 },
 [0x10394]={
  category="lo",
  description="UGARITIC LETTER PU",
  direction="l",
  linebreak="al",
  unicodeslot=0x10394,
 },
 [0x10395]={
  category="lo",
  description="UGARITIC LETTER SADE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10395,
 },
 [0x10396]={
  category="lo",
  description="UGARITIC LETTER QOPA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10396,
 },
 [0x10397]={
  category="lo",
  description="UGARITIC LETTER RASHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10397,
 },
 [0x10398]={
  category="lo",
  description="UGARITIC LETTER THANNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10398,
 },
 [0x10399]={
  category="lo",
  description="UGARITIC LETTER GHAIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10399,
 },
 [0x1039A]={
  category="lo",
  description="UGARITIC LETTER TO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1039A,
 },
 [0x1039B]={
  category="lo",
  description="UGARITIC LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1039B,
 },
 [0x1039C]={
  category="lo",
  description="UGARITIC LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1039C,
 },
 [0x1039D]={
  category="lo",
  description="UGARITIC LETTER SSU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1039D,
 },
 [0x1039F]={
  category="po",
  description="UGARITIC WORD DIVIDER",
  direction="l",
  linebreak="ba",
  unicodeslot=0x1039F,
 },
 [0x103A0]={
  category="lo",
  description="OLD PERSIAN SIGN A",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A0,
 },
 [0x103A1]={
  category="lo",
  description="OLD PERSIAN SIGN I",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A1,
 },
 [0x103A2]={
  category="lo",
  description="OLD PERSIAN SIGN U",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A2,
 },
 [0x103A3]={
  category="lo",
  description="OLD PERSIAN SIGN KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A3,
 },
 [0x103A4]={
  category="lo",
  description="OLD PERSIAN SIGN KU",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A4,
 },
 [0x103A5]={
  category="lo",
  description="OLD PERSIAN SIGN GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A5,
 },
 [0x103A6]={
  category="lo",
  description="OLD PERSIAN SIGN GU",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A6,
 },
 [0x103A7]={
  category="lo",
  description="OLD PERSIAN SIGN XA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A7,
 },
 [0x103A8]={
  category="lo",
  description="OLD PERSIAN SIGN CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A8,
 },
 [0x103A9]={
  category="lo",
  description="OLD PERSIAN SIGN JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103A9,
 },
 [0x103AA]={
  category="lo",
  description="OLD PERSIAN SIGN JI",
  direction="l",
  linebreak="al",
  unicodeslot=0x103AA,
 },
 [0x103AB]={
  category="lo",
  description="OLD PERSIAN SIGN TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103AB,
 },
 [0x103AC]={
  category="lo",
  description="OLD PERSIAN SIGN TU",
  direction="l",
  linebreak="al",
  unicodeslot=0x103AC,
 },
 [0x103AD]={
  category="lo",
  description="OLD PERSIAN SIGN DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103AD,
 },
 [0x103AE]={
  category="lo",
  description="OLD PERSIAN SIGN DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x103AE,
 },
 [0x103AF]={
  category="lo",
  description="OLD PERSIAN SIGN DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x103AF,
 },
 [0x103B0]={
  category="lo",
  description="OLD PERSIAN SIGN THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B0,
 },
 [0x103B1]={
  category="lo",
  description="OLD PERSIAN SIGN PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B1,
 },
 [0x103B2]={
  category="lo",
  description="OLD PERSIAN SIGN BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B2,
 },
 [0x103B3]={
  category="lo",
  description="OLD PERSIAN SIGN FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B3,
 },
 [0x103B4]={
  category="lo",
  description="OLD PERSIAN SIGN NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B4,
 },
 [0x103B5]={
  category="lo",
  description="OLD PERSIAN SIGN NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B5,
 },
 [0x103B6]={
  category="lo",
  description="OLD PERSIAN SIGN MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B6,
 },
 [0x103B7]={
  category="lo",
  description="OLD PERSIAN SIGN MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B7,
 },
 [0x103B8]={
  category="lo",
  description="OLD PERSIAN SIGN MU",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B8,
 },
 [0x103B9]={
  category="lo",
  description="OLD PERSIAN SIGN YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103B9,
 },
 [0x103BA]={
  category="lo",
  description="OLD PERSIAN SIGN VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103BA,
 },
 [0x103BB]={
  category="lo",
  description="OLD PERSIAN SIGN VI",
  direction="l",
  linebreak="al",
  unicodeslot=0x103BB,
 },
 [0x103BC]={
  category="lo",
  description="OLD PERSIAN SIGN RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103BC,
 },
 [0x103BD]={
  category="lo",
  description="OLD PERSIAN SIGN RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x103BD,
 },
 [0x103BE]={
  category="lo",
  description="OLD PERSIAN SIGN LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103BE,
 },
 [0x103BF]={
  category="lo",
  description="OLD PERSIAN SIGN SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103BF,
 },
 [0x103C0]={
  category="lo",
  description="OLD PERSIAN SIGN ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103C0,
 },
 [0x103C1]={
  category="lo",
  description="OLD PERSIAN SIGN SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103C1,
 },
 [0x103C2]={
  category="lo",
  description="OLD PERSIAN SIGN SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103C2,
 },
 [0x103C3]={
  category="lo",
  description="OLD PERSIAN SIGN HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103C3,
 },
 [0x103C8]={
  category="lo",
  description="OLD PERSIAN SIGN AURAMAZDAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103C8,
 },
 [0x103C9]={
  category="lo",
  description="OLD PERSIAN SIGN AURAMAZDAA-0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x103C9,
 },
 [0x103CA]={
  category="lo",
  description="OLD PERSIAN SIGN AURAMAZDAAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103CA,
 },
 [0x103CB]={
  category="lo",
  description="OLD PERSIAN SIGN XSHAAYATHIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103CB,
 },
 [0x103CC]={
  category="lo",
  description="OLD PERSIAN SIGN DAHYAAUSH",
  direction="l",
  linebreak="al",
  unicodeslot=0x103CC,
 },
 [0x103CD]={
  category="lo",
  description="OLD PERSIAN SIGN DAHYAAUSH-0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x103CD,
 },
 [0x103CE]={
  category="lo",
  description="OLD PERSIAN SIGN BAGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x103CE,
 },
 [0x103CF]={
  category="lo",
  description="OLD PERSIAN SIGN BUUMISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x103CF,
 },
 [0x103D0]={
  category="po",
  description="OLD PERSIAN WORD DIVIDER",
  direction="l",
  linebreak="ba",
  unicodeslot=0x103D0,
 },
 [0x103D1]={
  category="nl",
  description="OLD PERSIAN NUMBER ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x103D1,
 },
 [0x103D2]={
  category="nl",
  description="OLD PERSIAN NUMBER TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x103D2,
 },
 [0x103D3]={
  category="nl",
  description="OLD PERSIAN NUMBER TEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x103D3,
 },
 [0x103D4]={
  category="nl",
  description="OLD PERSIAN NUMBER TWENTY",
  direction="l",
  linebreak="al",
  unicodeslot=0x103D4,
 },
 [0x103D5]={
  category="nl",
  description="OLD PERSIAN NUMBER HUNDRED",
  direction="l",
  linebreak="al",
  unicodeslot=0x103D5,
 },
 [0x10400]={
  category="lu",
  description="DESERET CAPITAL LETTER LONG I",
  direction="l",
  lccode=0x10428,
  linebreak="al",
  unicodeslot=0x10400,
 },
 [0x10401]={
  category="lu",
  description="DESERET CAPITAL LETTER LONG E",
  direction="l",
  lccode=0x10429,
  linebreak="al",
  unicodeslot=0x10401,
 },
 [0x10402]={
  category="lu",
  description="DESERET CAPITAL LETTER LONG A",
  direction="l",
  lccode=0x1042A,
  linebreak="al",
  unicodeslot=0x10402,
 },
 [0x10403]={
  category="lu",
  description="DESERET CAPITAL LETTER LONG AH",
  direction="l",
  lccode=0x1042B,
  linebreak="al",
  unicodeslot=0x10403,
 },
 [0x10404]={
  category="lu",
  description="DESERET CAPITAL LETTER LONG O",
  direction="l",
  lccode=0x1042C,
  linebreak="al",
  unicodeslot=0x10404,
 },
 [0x10405]={
  category="lu",
  description="DESERET CAPITAL LETTER LONG OO",
  direction="l",
  lccode=0x1042D,
  linebreak="al",
  unicodeslot=0x10405,
 },
 [0x10406]={
  category="lu",
  description="DESERET CAPITAL LETTER SHORT I",
  direction="l",
  lccode=0x1042E,
  linebreak="al",
  unicodeslot=0x10406,
 },
 [0x10407]={
  category="lu",
  description="DESERET CAPITAL LETTER SHORT E",
  direction="l",
  lccode=0x1042F,
  linebreak="al",
  unicodeslot=0x10407,
 },
 [0x10408]={
  category="lu",
  description="DESERET CAPITAL LETTER SHORT A",
  direction="l",
  lccode=0x10430,
  linebreak="al",
  unicodeslot=0x10408,
 },
 [0x10409]={
  category="lu",
  description="DESERET CAPITAL LETTER SHORT AH",
  direction="l",
  lccode=0x10431,
  linebreak="al",
  unicodeslot=0x10409,
 },
 [0x1040A]={
  category="lu",
  description="DESERET CAPITAL LETTER SHORT O",
  direction="l",
  lccode=0x10432,
  linebreak="al",
  unicodeslot=0x1040A,
 },
 [0x1040B]={
  category="lu",
  description="DESERET CAPITAL LETTER SHORT OO",
  direction="l",
  lccode=0x10433,
  linebreak="al",
  unicodeslot=0x1040B,
 },
 [0x1040C]={
  category="lu",
  description="DESERET CAPITAL LETTER AY",
  direction="l",
  lccode=0x10434,
  linebreak="al",
  unicodeslot=0x1040C,
 },
 [0x1040D]={
  category="lu",
  description="DESERET CAPITAL LETTER OW",
  direction="l",
  lccode=0x10435,
  linebreak="al",
  unicodeslot=0x1040D,
 },
 [0x1040E]={
  category="lu",
  description="DESERET CAPITAL LETTER WU",
  direction="l",
  lccode=0x10436,
  linebreak="al",
  unicodeslot=0x1040E,
 },
 [0x1040F]={
  category="lu",
  description="DESERET CAPITAL LETTER YEE",
  direction="l",
  lccode=0x10437,
  linebreak="al",
  unicodeslot=0x1040F,
 },
 [0x10410]={
  category="lu",
  description="DESERET CAPITAL LETTER H",
  direction="l",
  lccode=0x10438,
  linebreak="al",
  unicodeslot=0x10410,
 },
 [0x10411]={
  category="lu",
  description="DESERET CAPITAL LETTER PEE",
  direction="l",
  lccode=0x10439,
  linebreak="al",
  unicodeslot=0x10411,
 },
 [0x10412]={
  category="lu",
  description="DESERET CAPITAL LETTER BEE",
  direction="l",
  lccode=0x1043A,
  linebreak="al",
  unicodeslot=0x10412,
 },
 [0x10413]={
  category="lu",
  description="DESERET CAPITAL LETTER TEE",
  direction="l",
  lccode=0x1043B,
  linebreak="al",
  unicodeslot=0x10413,
 },
 [0x10414]={
  category="lu",
  description="DESERET CAPITAL LETTER DEE",
  direction="l",
  lccode=0x1043C,
  linebreak="al",
  unicodeslot=0x10414,
 },
 [0x10415]={
  category="lu",
  description="DESERET CAPITAL LETTER CHEE",
  direction="l",
  lccode=0x1043D,
  linebreak="al",
  unicodeslot=0x10415,
 },
 [0x10416]={
  category="lu",
  description="DESERET CAPITAL LETTER JEE",
  direction="l",
  lccode=0x1043E,
  linebreak="al",
  unicodeslot=0x10416,
 },
 [0x10417]={
  category="lu",
  description="DESERET CAPITAL LETTER KAY",
  direction="l",
  lccode=0x1043F,
  linebreak="al",
  unicodeslot=0x10417,
 },
 [0x10418]={
  category="lu",
  description="DESERET CAPITAL LETTER GAY",
  direction="l",
  lccode=0x10440,
  linebreak="al",
  unicodeslot=0x10418,
 },
 [0x10419]={
  category="lu",
  description="DESERET CAPITAL LETTER EF",
  direction="l",
  lccode=0x10441,
  linebreak="al",
  unicodeslot=0x10419,
 },
 [0x1041A]={
  category="lu",
  description="DESERET CAPITAL LETTER VEE",
  direction="l",
  lccode=0x10442,
  linebreak="al",
  unicodeslot=0x1041A,
 },
 [0x1041B]={
  category="lu",
  description="DESERET CAPITAL LETTER ETH",
  direction="l",
  lccode=0x10443,
  linebreak="al",
  unicodeslot=0x1041B,
 },
 [0x1041C]={
  category="lu",
  description="DESERET CAPITAL LETTER THEE",
  direction="l",
  lccode=0x10444,
  linebreak="al",
  unicodeslot=0x1041C,
 },
 [0x1041D]={
  category="lu",
  description="DESERET CAPITAL LETTER ES",
  direction="l",
  lccode=0x10445,
  linebreak="al",
  unicodeslot=0x1041D,
 },
 [0x1041E]={
  category="lu",
  description="DESERET CAPITAL LETTER ZEE",
  direction="l",
  lccode=0x10446,
  linebreak="al",
  unicodeslot=0x1041E,
 },
 [0x1041F]={
  category="lu",
  description="DESERET CAPITAL LETTER ESH",
  direction="l",
  lccode=0x10447,
  linebreak="al",
  unicodeslot=0x1041F,
 },
 [0x10420]={
  category="lu",
  description="DESERET CAPITAL LETTER ZHEE",
  direction="l",
  lccode=0x10448,
  linebreak="al",
  unicodeslot=0x10420,
 },
 [0x10421]={
  category="lu",
  description="DESERET CAPITAL LETTER ER",
  direction="l",
  lccode=0x10449,
  linebreak="al",
  unicodeslot=0x10421,
 },
 [0x10422]={
  category="lu",
  description="DESERET CAPITAL LETTER EL",
  direction="l",
  lccode=0x1044A,
  linebreak="al",
  unicodeslot=0x10422,
 },
 [0x10423]={
  category="lu",
  description="DESERET CAPITAL LETTER EM",
  direction="l",
  lccode=0x1044B,
  linebreak="al",
  unicodeslot=0x10423,
 },
 [0x10424]={
  category="lu",
  description="DESERET CAPITAL LETTER EN",
  direction="l",
  lccode=0x1044C,
  linebreak="al",
  unicodeslot=0x10424,
 },
 [0x10425]={
  category="lu",
  description="DESERET CAPITAL LETTER ENG",
  direction="l",
  lccode=0x1044D,
  linebreak="al",
  unicodeslot=0x10425,
 },
 [0x10426]={
  category="lu",
  description="DESERET CAPITAL LETTER OI",
  direction="l",
  lccode=0x1044E,
  linebreak="al",
  unicodeslot=0x10426,
 },
 [0x10427]={
  category="lu",
  description="DESERET CAPITAL LETTER EW",
  direction="l",
  lccode=0x1044F,
  linebreak="al",
  unicodeslot=0x10427,
 },
 [0x10428]={
  category="ll",
  description="DESERET SMALL LETTER LONG I",
  direction="l",
  linebreak="al",
  uccode=0x10400,
  unicodeslot=0x10428,
 },
 [0x10429]={
  category="ll",
  description="DESERET SMALL LETTER LONG E",
  direction="l",
  linebreak="al",
  uccode=0x10401,
  unicodeslot=0x10429,
 },
 [0x1042A]={
  category="ll",
  description="DESERET SMALL LETTER LONG A",
  direction="l",
  linebreak="al",
  uccode=0x10402,
  unicodeslot=0x1042A,
 },
 [0x1042B]={
  category="ll",
  description="DESERET SMALL LETTER LONG AH",
  direction="l",
  linebreak="al",
  uccode=0x10403,
  unicodeslot=0x1042B,
 },
 [0x1042C]={
  category="ll",
  description="DESERET SMALL LETTER LONG O",
  direction="l",
  linebreak="al",
  uccode=0x10404,
  unicodeslot=0x1042C,
 },
 [0x1042D]={
  category="ll",
  description="DESERET SMALL LETTER LONG OO",
  direction="l",
  linebreak="al",
  uccode=0x10405,
  unicodeslot=0x1042D,
 },
 [0x1042E]={
  category="ll",
  description="DESERET SMALL LETTER SHORT I",
  direction="l",
  linebreak="al",
  uccode=0x10406,
  unicodeslot=0x1042E,
 },
 [0x1042F]={
  category="ll",
  description="DESERET SMALL LETTER SHORT E",
  direction="l",
  linebreak="al",
  uccode=0x10407,
  unicodeslot=0x1042F,
 },
 [0x10430]={
  category="ll",
  description="DESERET SMALL LETTER SHORT A",
  direction="l",
  linebreak="al",
  uccode=0x10408,
  unicodeslot=0x10430,
 },
 [0x10431]={
  category="ll",
  description="DESERET SMALL LETTER SHORT AH",
  direction="l",
  linebreak="al",
  uccode=0x10409,
  unicodeslot=0x10431,
 },
 [0x10432]={
  category="ll",
  description="DESERET SMALL LETTER SHORT O",
  direction="l",
  linebreak="al",
  uccode=0x1040A,
  unicodeslot=0x10432,
 },
 [0x10433]={
  category="ll",
  description="DESERET SMALL LETTER SHORT OO",
  direction="l",
  linebreak="al",
  uccode=0x1040B,
  unicodeslot=0x10433,
 },
 [0x10434]={
  category="ll",
  description="DESERET SMALL LETTER AY",
  direction="l",
  linebreak="al",
  uccode=0x1040C,
  unicodeslot=0x10434,
 },
 [0x10435]={
  category="ll",
  description="DESERET SMALL LETTER OW",
  direction="l",
  linebreak="al",
  uccode=0x1040D,
  unicodeslot=0x10435,
 },
 [0x10436]={
  category="ll",
  description="DESERET SMALL LETTER WU",
  direction="l",
  linebreak="al",
  uccode=0x1040E,
  unicodeslot=0x10436,
 },
 [0x10437]={
  category="ll",
  description="DESERET SMALL LETTER YEE",
  direction="l",
  linebreak="al",
  uccode=0x1040F,
  unicodeslot=0x10437,
 },
 [0x10438]={
  category="ll",
  description="DESERET SMALL LETTER H",
  direction="l",
  linebreak="al",
  uccode=0x10410,
  unicodeslot=0x10438,
 },
 [0x10439]={
  category="ll",
  description="DESERET SMALL LETTER PEE",
  direction="l",
  linebreak="al",
  uccode=0x10411,
  unicodeslot=0x10439,
 },
 [0x1043A]={
  category="ll",
  description="DESERET SMALL LETTER BEE",
  direction="l",
  linebreak="al",
  uccode=0x10412,
  unicodeslot=0x1043A,
 },
 [0x1043B]={
  category="ll",
  description="DESERET SMALL LETTER TEE",
  direction="l",
  linebreak="al",
  uccode=0x10413,
  unicodeslot=0x1043B,
 },
 [0x1043C]={
  category="ll",
  description="DESERET SMALL LETTER DEE",
  direction="l",
  linebreak="al",
  uccode=0x10414,
  unicodeslot=0x1043C,
 },
 [0x1043D]={
  category="ll",
  description="DESERET SMALL LETTER CHEE",
  direction="l",
  linebreak="al",
  uccode=0x10415,
  unicodeslot=0x1043D,
 },
 [0x1043E]={
  category="ll",
  description="DESERET SMALL LETTER JEE",
  direction="l",
  linebreak="al",
  uccode=0x10416,
  unicodeslot=0x1043E,
 },
 [0x1043F]={
  category="ll",
  description="DESERET SMALL LETTER KAY",
  direction="l",
  linebreak="al",
  uccode=0x10417,
  unicodeslot=0x1043F,
 },
 [0x10440]={
  category="ll",
  description="DESERET SMALL LETTER GAY",
  direction="l",
  linebreak="al",
  uccode=0x10418,
  unicodeslot=0x10440,
 },
 [0x10441]={
  category="ll",
  description="DESERET SMALL LETTER EF",
  direction="l",
  linebreak="al",
  uccode=0x10419,
  unicodeslot=0x10441,
 },
 [0x10442]={
  category="ll",
  description="DESERET SMALL LETTER VEE",
  direction="l",
  linebreak="al",
  uccode=0x1041A,
  unicodeslot=0x10442,
 },
 [0x10443]={
  category="ll",
  description="DESERET SMALL LETTER ETH",
  direction="l",
  linebreak="al",
  uccode=0x1041B,
  unicodeslot=0x10443,
 },
 [0x10444]={
  category="ll",
  description="DESERET SMALL LETTER THEE",
  direction="l",
  linebreak="al",
  uccode=0x1041C,
  unicodeslot=0x10444,
 },
 [0x10445]={
  category="ll",
  description="DESERET SMALL LETTER ES",
  direction="l",
  linebreak="al",
  uccode=0x1041D,
  unicodeslot=0x10445,
 },
 [0x10446]={
  category="ll",
  description="DESERET SMALL LETTER ZEE",
  direction="l",
  linebreak="al",
  uccode=0x1041E,
  unicodeslot=0x10446,
 },
 [0x10447]={
  category="ll",
  description="DESERET SMALL LETTER ESH",
  direction="l",
  linebreak="al",
  uccode=0x1041F,
  unicodeslot=0x10447,
 },
 [0x10448]={
  category="ll",
  description="DESERET SMALL LETTER ZHEE",
  direction="l",
  linebreak="al",
  uccode=0x10420,
  unicodeslot=0x10448,
 },
 [0x10449]={
  category="ll",
  description="DESERET SMALL LETTER ER",
  direction="l",
  linebreak="al",
  uccode=0x10421,
  unicodeslot=0x10449,
 },
 [0x1044A]={
  category="ll",
  description="DESERET SMALL LETTER EL",
  direction="l",
  linebreak="al",
  uccode=0x10422,
  unicodeslot=0x1044A,
 },
 [0x1044B]={
  category="ll",
  description="DESERET SMALL LETTER EM",
  direction="l",
  linebreak="al",
  uccode=0x10423,
  unicodeslot=0x1044B,
 },
 [0x1044C]={
  category="ll",
  description="DESERET SMALL LETTER EN",
  direction="l",
  linebreak="al",
  uccode=0x10424,
  unicodeslot=0x1044C,
 },
 [0x1044D]={
  category="ll",
  description="DESERET SMALL LETTER ENG",
  direction="l",
  linebreak="al",
  uccode=0x10425,
  unicodeslot=0x1044D,
 },
 [0x1044E]={
  category="ll",
  description="DESERET SMALL LETTER OI",
  direction="l",
  linebreak="al",
  uccode=0x10426,
  unicodeslot=0x1044E,
 },
 [0x1044F]={
  category="ll",
  description="DESERET SMALL LETTER EW",
  direction="l",
  linebreak="al",
  uccode=0x10427,
  unicodeslot=0x1044F,
 },
 [0x10450]={
  category="lo",
  description="SHAVIAN LETTER PEEP",
  direction="l",
  linebreak="al",
  unicodeslot=0x10450,
 },
 [0x10451]={
  category="lo",
  description="SHAVIAN LETTER TOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x10451,
 },
 [0x10452]={
  category="lo",
  description="SHAVIAN LETTER KICK",
  direction="l",
  linebreak="al",
  unicodeslot=0x10452,
 },
 [0x10453]={
  category="lo",
  description="SHAVIAN LETTER FEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10453,
 },
 [0x10454]={
  category="lo",
  description="SHAVIAN LETTER THIGH",
  direction="l",
  linebreak="al",
  unicodeslot=0x10454,
 },
 [0x10455]={
  category="lo",
  description="SHAVIAN LETTER SO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10455,
 },
 [0x10456]={
  category="lo",
  description="SHAVIAN LETTER SURE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10456,
 },
 [0x10457]={
  category="lo",
  description="SHAVIAN LETTER CHURCH",
  direction="l",
  linebreak="al",
  unicodeslot=0x10457,
 },
 [0x10458]={
  category="lo",
  description="SHAVIAN LETTER YEA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10458,
 },
 [0x10459]={
  category="lo",
  description="SHAVIAN LETTER HUNG",
  direction="l",
  linebreak="al",
  unicodeslot=0x10459,
 },
 [0x1045A]={
  category="lo",
  description="SHAVIAN LETTER BIB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1045A,
 },
 [0x1045B]={
  category="lo",
  description="SHAVIAN LETTER DEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1045B,
 },
 [0x1045C]={
  category="lo",
  description="SHAVIAN LETTER GAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1045C,
 },
 [0x1045D]={
  category="lo",
  description="SHAVIAN LETTER VOW",
  direction="l",
  linebreak="al",
  unicodeslot=0x1045D,
 },
 [0x1045E]={
  category="lo",
  description="SHAVIAN LETTER THEY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1045E,
 },
 [0x1045F]={
  category="lo",
  description="SHAVIAN LETTER ZOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1045F,
 },
 [0x10460]={
  category="lo",
  description="SHAVIAN LETTER MEASURE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10460,
 },
 [0x10461]={
  category="lo",
  description="SHAVIAN LETTER JUDGE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10461,
 },
 [0x10462]={
  category="lo",
  description="SHAVIAN LETTER WOE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10462,
 },
 [0x10463]={
  category="lo",
  description="SHAVIAN LETTER HA-HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10463,
 },
 [0x10464]={
  category="lo",
  description="SHAVIAN LETTER LOLL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10464,
 },
 [0x10465]={
  category="lo",
  description="SHAVIAN LETTER MIME",
  direction="l",
  linebreak="al",
  unicodeslot=0x10465,
 },
 [0x10466]={
  category="lo",
  description="SHAVIAN LETTER IF",
  direction="l",
  linebreak="al",
  unicodeslot=0x10466,
 },
 [0x10467]={
  category="lo",
  description="SHAVIAN LETTER EGG",
  direction="l",
  linebreak="al",
  unicodeslot=0x10467,
 },
 [0x10468]={
  category="lo",
  description="SHAVIAN LETTER ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x10468,
 },
 [0x10469]={
  category="lo",
  description="SHAVIAN LETTER ADO",
  direction="l",
  linebreak="al",
  unicodeslot=0x10469,
 },
 [0x1046A]={
  category="lo",
  description="SHAVIAN LETTER ON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1046A,
 },
 [0x1046B]={
  category="lo",
  description="SHAVIAN LETTER WOOL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1046B,
 },
 [0x1046C]={
  category="lo",
  description="SHAVIAN LETTER OUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1046C,
 },
 [0x1046D]={
  category="lo",
  description="SHAVIAN LETTER AH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1046D,
 },
 [0x1046E]={
  category="lo",
  description="SHAVIAN LETTER ROAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1046E,
 },
 [0x1046F]={
  category="lo",
  description="SHAVIAN LETTER NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1046F,
 },
 [0x10470]={
  category="lo",
  description="SHAVIAN LETTER EAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x10470,
 },
 [0x10471]={
  category="lo",
  description="SHAVIAN LETTER AGE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10471,
 },
 [0x10472]={
  category="lo",
  description="SHAVIAN LETTER ICE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10472,
 },
 [0x10473]={
  category="lo",
  description="SHAVIAN LETTER UP",
  direction="l",
  linebreak="al",
  unicodeslot=0x10473,
 },
 [0x10474]={
  category="lo",
  description="SHAVIAN LETTER OAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x10474,
 },
 [0x10475]={
  category="lo",
  description="SHAVIAN LETTER OOZE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10475,
 },
 [0x10476]={
  category="lo",
  description="SHAVIAN LETTER OIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10476,
 },
 [0x10477]={
  category="lo",
  description="SHAVIAN LETTER AWE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10477,
 },
 [0x10478]={
  category="lo",
  description="SHAVIAN LETTER ARE",
  direction="l",
  linebreak="al",
  unicodeslot=0x10478,
 },
 [0x10479]={
  category="lo",
  description="SHAVIAN LETTER OR",
  direction="l",
  linebreak="al",
  unicodeslot=0x10479,
 },
 [0x1047A]={
  category="lo",
  description="SHAVIAN LETTER AIR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1047A,
 },
 [0x1047B]={
  category="lo",
  description="SHAVIAN LETTER ERR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1047B,
 },
 [0x1047C]={
  category="lo",
  description="SHAVIAN LETTER ARRAY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1047C,
 },
 [0x1047D]={
  category="lo",
  description="SHAVIAN LETTER EAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1047D,
 },
 [0x1047E]={
  category="lo",
  description="SHAVIAN LETTER IAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1047E,
 },
 [0x1047F]={
  category="lo",
  description="SHAVIAN LETTER YEW",
  direction="l",
  linebreak="al",
  unicodeslot=0x1047F,
 },
 [0x10480]={
  category="lo",
  description="OSMANYA LETTER ALEF",
  direction="l",
  linebreak="al",
  unicodeslot=0x10480,
 },
 [0x10481]={
  category="lo",
  description="OSMANYA LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10481,
 },
 [0x10482]={
  category="lo",
  description="OSMANYA LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10482,
 },
 [0x10483]={
  category="lo",
  description="OSMANYA LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10483,
 },
 [0x10484]={
  category="lo",
  description="OSMANYA LETTER XA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10484,
 },
 [0x10485]={
  category="lo",
  description="OSMANYA LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10485,
 },
 [0x10486]={
  category="lo",
  description="OSMANYA LETTER DEEL",
  direction="l",
  linebreak="al",
  unicodeslot=0x10486,
 },
 [0x10487]={
  category="lo",
  description="OSMANYA LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10487,
 },
 [0x10488]={
  category="lo",
  description="OSMANYA LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10488,
 },
 [0x10489]={
  category="lo",
  description="OSMANYA LETTER SHIIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10489,
 },
 [0x1048A]={
  category="lo",
  description="OSMANYA LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1048A,
 },
 [0x1048B]={
  category="lo",
  description="OSMANYA LETTER CAYN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1048B,
 },
 [0x1048C]={
  category="lo",
  description="OSMANYA LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1048C,
 },
 [0x1048D]={
  category="lo",
  description="OSMANYA LETTER FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1048D,
 },
 [0x1048E]={
  category="lo",
  description="OSMANYA LETTER QAAF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1048E,
 },
 [0x1048F]={
  category="lo",
  description="OSMANYA LETTER KAAF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1048F,
 },
 [0x10490]={
  category="lo",
  description="OSMANYA LETTER LAAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10490,
 },
 [0x10491]={
  category="lo",
  description="OSMANYA LETTER MIIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10491,
 },
 [0x10492]={
  category="lo",
  description="OSMANYA LETTER NUUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x10492,
 },
 [0x10493]={
  category="lo",
  description="OSMANYA LETTER WAW",
  direction="l",
  linebreak="al",
  unicodeslot=0x10493,
 },
 [0x10494]={
  category="lo",
  description="OSMANYA LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10494,
 },
 [0x10495]={
  category="lo",
  description="OSMANYA LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x10495,
 },
 [0x10496]={
  category="lo",
  description="OSMANYA LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x10496,
 },
 [0x10497]={
  category="lo",
  description="OSMANYA LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x10497,
 },
 [0x10498]={
  category="lo",
  description="OSMANYA LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x10498,
 },
 [0x10499]={
  category="lo",
  description="OSMANYA LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x10499,
 },
 [0x1049A]={
  category="lo",
  description="OSMANYA LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1049A,
 },
 [0x1049B]={
  category="lo",
  description="OSMANYA LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1049B,
 },
 [0x1049C]={
  category="lo",
  description="OSMANYA LETTER EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1049C,
 },
 [0x1049D]={
  category="lo",
  description="OSMANYA LETTER OO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1049D,
 },
 [0x104A0]={
  category="nd",
  description="OSMANYA DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A0,
 },
 [0x104A1]={
  category="nd",
  description="OSMANYA DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A1,
 },
 [0x104A2]={
  category="nd",
  description="OSMANYA DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A2,
 },
 [0x104A3]={
  category="nd",
  description="OSMANYA DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A3,
 },
 [0x104A4]={
  category="nd",
  description="OSMANYA DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A4,
 },
 [0x104A5]={
  category="nd",
  description="OSMANYA DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A5,
 },
 [0x104A6]={
  category="nd",
  description="OSMANYA DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A6,
 },
 [0x104A7]={
  category="nd",
  description="OSMANYA DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A7,
 },
 [0x104A8]={
  category="nd",
  description="OSMANYA DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A8,
 },
 [0x104A9]={
  category="nd",
  description="OSMANYA DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x104A9,
 },
 [0x10800]={
  category="lo",
  description="CYPRIOT SYLLABLE A",
  direction="r",
  linebreak="al",
  unicodeslot=0x10800,
 },
 [0x10801]={
  category="lo",
  description="CYPRIOT SYLLABLE E",
  direction="r",
  linebreak="al",
  unicodeslot=0x10801,
 },
 [0x10802]={
  category="lo",
  description="CYPRIOT SYLLABLE I",
  direction="r",
  linebreak="al",
  unicodeslot=0x10802,
 },
 [0x10803]={
  category="lo",
  description="CYPRIOT SYLLABLE O",
  direction="r",
  linebreak="al",
  unicodeslot=0x10803,
 },
 [0x10804]={
  category="lo",
  description="CYPRIOT SYLLABLE U",
  direction="r",
  linebreak="al",
  unicodeslot=0x10804,
 },
 [0x10805]={
  category="lo",
  description="CYPRIOT SYLLABLE JA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10805,
 },
 [0x10808]={
  category="lo",
  description="CYPRIOT SYLLABLE JO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10808,
 },
 [0x1080A]={
  category="lo",
  description="CYPRIOT SYLLABLE KA",
  direction="r",
  linebreak="al",
  unicodeslot=0x1080A,
 },
 [0x1080B]={
  category="lo",
  description="CYPRIOT SYLLABLE KE",
  direction="r",
  linebreak="al",
  unicodeslot=0x1080B,
 },
 [0x1080C]={
  category="lo",
  description="CYPRIOT SYLLABLE KI",
  direction="r",
  linebreak="al",
  unicodeslot=0x1080C,
 },
 [0x1080D]={
  category="lo",
  description="CYPRIOT SYLLABLE KO",
  direction="r",
  linebreak="al",
  unicodeslot=0x1080D,
 },
 [0x1080E]={
  category="lo",
  description="CYPRIOT SYLLABLE KU",
  direction="r",
  linebreak="al",
  unicodeslot=0x1080E,
 },
 [0x1080F]={
  category="lo",
  description="CYPRIOT SYLLABLE LA",
  direction="r",
  linebreak="al",
  unicodeslot=0x1080F,
 },
 [0x10810]={
  category="lo",
  description="CYPRIOT SYLLABLE LE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10810,
 },
 [0x10811]={
  category="lo",
  description="CYPRIOT SYLLABLE LI",
  direction="r",
  linebreak="al",
  unicodeslot=0x10811,
 },
 [0x10812]={
  category="lo",
  description="CYPRIOT SYLLABLE LO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10812,
 },
 [0x10813]={
  category="lo",
  description="CYPRIOT SYLLABLE LU",
  direction="r",
  linebreak="al",
  unicodeslot=0x10813,
 },
 [0x10814]={
  category="lo",
  description="CYPRIOT SYLLABLE MA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10814,
 },
 [0x10815]={
  category="lo",
  description="CYPRIOT SYLLABLE ME",
  direction="r",
  linebreak="al",
  unicodeslot=0x10815,
 },
 [0x10816]={
  category="lo",
  description="CYPRIOT SYLLABLE MI",
  direction="r",
  linebreak="al",
  unicodeslot=0x10816,
 },
 [0x10817]={
  category="lo",
  description="CYPRIOT SYLLABLE MO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10817,
 },
 [0x10818]={
  category="lo",
  description="CYPRIOT SYLLABLE MU",
  direction="r",
  linebreak="al",
  unicodeslot=0x10818,
 },
 [0x10819]={
  category="lo",
  description="CYPRIOT SYLLABLE NA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10819,
 },
 [0x1081A]={
  category="lo",
  description="CYPRIOT SYLLABLE NE",
  direction="r",
  linebreak="al",
  unicodeslot=0x1081A,
 },
 [0x1081B]={
  category="lo",
  description="CYPRIOT SYLLABLE NI",
  direction="r",
  linebreak="al",
  unicodeslot=0x1081B,
 },
 [0x1081C]={
  category="lo",
  description="CYPRIOT SYLLABLE NO",
  direction="r",
  linebreak="al",
  unicodeslot=0x1081C,
 },
 [0x1081D]={
  category="lo",
  description="CYPRIOT SYLLABLE NU",
  direction="r",
  linebreak="al",
  unicodeslot=0x1081D,
 },
 [0x1081E]={
  category="lo",
  description="CYPRIOT SYLLABLE PA",
  direction="r",
  linebreak="al",
  unicodeslot=0x1081E,
 },
 [0x1081F]={
  category="lo",
  description="CYPRIOT SYLLABLE PE",
  direction="r",
  linebreak="al",
  unicodeslot=0x1081F,
 },
 [0x10820]={
  category="lo",
  description="CYPRIOT SYLLABLE PI",
  direction="r",
  linebreak="al",
  unicodeslot=0x10820,
 },
 [0x10821]={
  category="lo",
  description="CYPRIOT SYLLABLE PO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10821,
 },
 [0x10822]={
  category="lo",
  description="CYPRIOT SYLLABLE PU",
  direction="r",
  linebreak="al",
  unicodeslot=0x10822,
 },
 [0x10823]={
  category="lo",
  description="CYPRIOT SYLLABLE RA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10823,
 },
 [0x10824]={
  category="lo",
  description="CYPRIOT SYLLABLE RE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10824,
 },
 [0x10825]={
  category="lo",
  description="CYPRIOT SYLLABLE RI",
  direction="r",
  linebreak="al",
  unicodeslot=0x10825,
 },
 [0x10826]={
  category="lo",
  description="CYPRIOT SYLLABLE RO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10826,
 },
 [0x10827]={
  category="lo",
  description="CYPRIOT SYLLABLE RU",
  direction="r",
  linebreak="al",
  unicodeslot=0x10827,
 },
 [0x10828]={
  category="lo",
  description="CYPRIOT SYLLABLE SA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10828,
 },
 [0x10829]={
  category="lo",
  description="CYPRIOT SYLLABLE SE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10829,
 },
 [0x1082A]={
  category="lo",
  description="CYPRIOT SYLLABLE SI",
  direction="r",
  linebreak="al",
  unicodeslot=0x1082A,
 },
 [0x1082B]={
  category="lo",
  description="CYPRIOT SYLLABLE SO",
  direction="r",
  linebreak="al",
  unicodeslot=0x1082B,
 },
 [0x1082C]={
  category="lo",
  description="CYPRIOT SYLLABLE SU",
  direction="r",
  linebreak="al",
  unicodeslot=0x1082C,
 },
 [0x1082D]={
  category="lo",
  description="CYPRIOT SYLLABLE TA",
  direction="r",
  linebreak="al",
  unicodeslot=0x1082D,
 },
 [0x1082E]={
  category="lo",
  description="CYPRIOT SYLLABLE TE",
  direction="r",
  linebreak="al",
  unicodeslot=0x1082E,
 },
 [0x1082F]={
  category="lo",
  description="CYPRIOT SYLLABLE TI",
  direction="r",
  linebreak="al",
  unicodeslot=0x1082F,
 },
 [0x10830]={
  category="lo",
  description="CYPRIOT SYLLABLE TO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10830,
 },
 [0x10831]={
  category="lo",
  description="CYPRIOT SYLLABLE TU",
  direction="r",
  linebreak="al",
  unicodeslot=0x10831,
 },
 [0x10832]={
  category="lo",
  description="CYPRIOT SYLLABLE WA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10832,
 },
 [0x10833]={
  category="lo",
  description="CYPRIOT SYLLABLE WE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10833,
 },
 [0x10834]={
  category="lo",
  description="CYPRIOT SYLLABLE WI",
  direction="r",
  linebreak="al",
  unicodeslot=0x10834,
 },
 [0x10835]={
  category="lo",
  description="CYPRIOT SYLLABLE WO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10835,
 },
 [0x10837]={
  category="lo",
  description="CYPRIOT SYLLABLE XA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10837,
 },
 [0x10838]={
  category="lo",
  description="CYPRIOT SYLLABLE XE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10838,
 },
 [0x1083C]={
  category="lo",
  description="CYPRIOT SYLLABLE ZA",
  direction="r",
  linebreak="al",
  unicodeslot=0x1083C,
 },
 [0x1083F]={
  category="lo",
  description="CYPRIOT SYLLABLE ZO",
  direction="r",
  linebreak="al",
  unicodeslot=0x1083F,
 },
 [0x10840]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER ALEPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10840,
 },
 [0x10841]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER BETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10841,
 },
 [0x10842]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER GIMEL",
  direction="r",
  linebreak="al",
  unicodeslot=0x10842,
 },
 [0x10843]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER DALETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10843,
 },
 [0x10844]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER HE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10844,
 },
 [0x10845]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER WAW",
  direction="r",
  linebreak="al",
  unicodeslot=0x10845,
 },
 [0x10846]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER ZAYIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10846,
 },
 [0x10847]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER HETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10847,
 },
 [0x10848]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER TETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10848,
 },
 [0x10849]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER YODH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10849,
 },
 [0x1084A]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER KAPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x1084A,
 },
 [0x1084B]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER LAMEDH",
  direction="r",
  linebreak="al",
  unicodeslot=0x1084B,
 },
 [0x1084C]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER MEM",
  direction="r",
  linebreak="al",
  unicodeslot=0x1084C,
 },
 [0x1084D]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER NUN",
  direction="r",
  linebreak="al",
  unicodeslot=0x1084D,
 },
 [0x1084E]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER SAMEKH",
  direction="r",
  linebreak="al",
  unicodeslot=0x1084E,
 },
 [0x1084F]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER AYIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x1084F,
 },
 [0x10850]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER PE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10850,
 },
 [0x10851]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER SADHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10851,
 },
 [0x10852]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER QOPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10852,
 },
 [0x10853]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER RESH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10853,
 },
 [0x10854]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER SHIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10854,
 },
 [0x10855]={
  category="lo",
  description="IMPERIAL ARAMAIC LETTER TAW",
  direction="r",
  linebreak="al",
  unicodeslot=0x10855,
 },
 [0x10857]={
  category="po",
  description="IMPERIAL ARAMAIC SECTION SIGN",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10857,
 },
 [0x10858]={
  category="no",
  description="IMPERIAL ARAMAIC NUMBER ONE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10858,
 },
 [0x10859]={
  category="no",
  description="IMPERIAL ARAMAIC NUMBER TWO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10859,
 },
 [0x1085A]={
  category="no",
  description="IMPERIAL ARAMAIC NUMBER THREE",
  direction="r",
  linebreak="al",
  unicodeslot=0x1085A,
 },
 [0x1085B]={
  category="no",
  description="IMPERIAL ARAMAIC NUMBER TEN",
  direction="r",
  linebreak="al",
  unicodeslot=0x1085B,
 },
 [0x1085C]={
  category="no",
  description="IMPERIAL ARAMAIC NUMBER TWENTY",
  direction="r",
  linebreak="al",
  unicodeslot=0x1085C,
 },
 [0x1085D]={
  category="no",
  description="IMPERIAL ARAMAIC NUMBER ONE HUNDRED",
  direction="r",
  linebreak="al",
  unicodeslot=0x1085D,
 },
 [0x1085E]={
  category="no",
  description="IMPERIAL ARAMAIC NUMBER ONE THOUSAND",
  direction="r",
  linebreak="al",
  unicodeslot=0x1085E,
 },
 [0x1085F]={
  category="no",
  description="IMPERIAL ARAMAIC NUMBER TEN THOUSAND",
  direction="r",
  linebreak="al",
  unicodeslot=0x1085F,
 },
 [0x10900]={
  category="lo",
  description="PHOENICIAN LETTER ALF",
  direction="r",
  linebreak="al",
  unicodeslot=0x10900,
 },
 [0x10901]={
  category="lo",
  description="PHOENICIAN LETTER BET",
  direction="r",
  linebreak="al",
  unicodeslot=0x10901,
 },
 [0x10902]={
  category="lo",
  description="PHOENICIAN LETTER GAML",
  direction="r",
  linebreak="al",
  unicodeslot=0x10902,
 },
 [0x10903]={
  category="lo",
  description="PHOENICIAN LETTER DELT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10903,
 },
 [0x10904]={
  category="lo",
  description="PHOENICIAN LETTER HE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10904,
 },
 [0x10905]={
  category="lo",
  description="PHOENICIAN LETTER WAU",
  direction="r",
  linebreak="al",
  unicodeslot=0x10905,
 },
 [0x10906]={
  category="lo",
  description="PHOENICIAN LETTER ZAI",
  direction="r",
  linebreak="al",
  unicodeslot=0x10906,
 },
 [0x10907]={
  category="lo",
  description="PHOENICIAN LETTER HET",
  direction="r",
  linebreak="al",
  unicodeslot=0x10907,
 },
 [0x10908]={
  category="lo",
  description="PHOENICIAN LETTER TET",
  direction="r",
  linebreak="al",
  unicodeslot=0x10908,
 },
 [0x10909]={
  category="lo",
  description="PHOENICIAN LETTER YOD",
  direction="r",
  linebreak="al",
  unicodeslot=0x10909,
 },
 [0x1090A]={
  category="lo",
  description="PHOENICIAN LETTER KAF",
  direction="r",
  linebreak="al",
  unicodeslot=0x1090A,
 },
 [0x1090B]={
  category="lo",
  description="PHOENICIAN LETTER LAMD",
  direction="r",
  linebreak="al",
  unicodeslot=0x1090B,
 },
 [0x1090C]={
  category="lo",
  description="PHOENICIAN LETTER MEM",
  direction="r",
  linebreak="al",
  unicodeslot=0x1090C,
 },
 [0x1090D]={
  category="lo",
  description="PHOENICIAN LETTER NUN",
  direction="r",
  linebreak="al",
  unicodeslot=0x1090D,
 },
 [0x1090E]={
  category="lo",
  description="PHOENICIAN LETTER SEMK",
  direction="r",
  linebreak="al",
  unicodeslot=0x1090E,
 },
 [0x1090F]={
  category="lo",
  description="PHOENICIAN LETTER AIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x1090F,
 },
 [0x10910]={
  category="lo",
  description="PHOENICIAN LETTER PE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10910,
 },
 [0x10911]={
  category="lo",
  description="PHOENICIAN LETTER SADE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10911,
 },
 [0x10912]={
  category="lo",
  description="PHOENICIAN LETTER QOF",
  direction="r",
  linebreak="al",
  unicodeslot=0x10912,
 },
 [0x10913]={
  category="lo",
  description="PHOENICIAN LETTER ROSH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10913,
 },
 [0x10914]={
  category="lo",
  description="PHOENICIAN LETTER SHIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10914,
 },
 [0x10915]={
  category="lo",
  description="PHOENICIAN LETTER TAU",
  direction="r",
  linebreak="al",
  unicodeslot=0x10915,
 },
 [0x10916]={
  category="no",
  description="PHOENICIAN NUMBER ONE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10916,
 },
 [0x10917]={
  category="no",
  description="PHOENICIAN NUMBER TEN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10917,
 },
 [0x10918]={
  category="no",
  description="PHOENICIAN NUMBER TWENTY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10918,
 },
 [0x10919]={
  category="no",
  description="PHOENICIAN NUMBER ONE HUNDRED",
  direction="r",
  linebreak="al",
  unicodeslot=0x10919,
 },
 [0x1091A]={
  category="no",
  description="PHOENICIAN NUMBER TWO",
  direction="r",
  linebreak="al",
  unicodeslot=0x1091A,
 },
 [0x1091B]={
  category="no",
  description="PHOENICIAN NUMBER THREE",
  direction="r",
  linebreak="al",
  unicodeslot=0x1091B,
 },
 [0x1091F]={
  category="po",
  description="PHOENICIAN WORD SEPARATOR",
  direction="on",
  linebreak="ba",
  unicodeslot=0x1091F,
 },
 [0x10920]={
  category="lo",
  description="LYDIAN LETTER A",
  direction="r",
  linebreak="al",
  unicodeslot=0x10920,
 },
 [0x10921]={
  category="lo",
  description="LYDIAN LETTER B",
  direction="r",
  linebreak="al",
  unicodeslot=0x10921,
 },
 [0x10922]={
  category="lo",
  description="LYDIAN LETTER G",
  direction="r",
  linebreak="al",
  unicodeslot=0x10922,
 },
 [0x10923]={
  category="lo",
  description="LYDIAN LETTER D",
  direction="r",
  linebreak="al",
  unicodeslot=0x10923,
 },
 [0x10924]={
  category="lo",
  description="LYDIAN LETTER E",
  direction="r",
  linebreak="al",
  unicodeslot=0x10924,
 },
 [0x10925]={
  category="lo",
  description="LYDIAN LETTER V",
  direction="r",
  linebreak="al",
  unicodeslot=0x10925,
 },
 [0x10926]={
  category="lo",
  description="LYDIAN LETTER I",
  direction="r",
  linebreak="al",
  unicodeslot=0x10926,
 },
 [0x10927]={
  category="lo",
  description="LYDIAN LETTER Y",
  direction="r",
  linebreak="al",
  unicodeslot=0x10927,
 },
 [0x10928]={
  category="lo",
  description="LYDIAN LETTER K",
  direction="r",
  linebreak="al",
  unicodeslot=0x10928,
 },
 [0x10929]={
  category="lo",
  description="LYDIAN LETTER L",
  direction="r",
  linebreak="al",
  unicodeslot=0x10929,
 },
 [0x1092A]={
  category="lo",
  description="LYDIAN LETTER M",
  direction="r",
  linebreak="al",
  unicodeslot=0x1092A,
 },
 [0x1092B]={
  category="lo",
  description="LYDIAN LETTER N",
  direction="r",
  linebreak="al",
  unicodeslot=0x1092B,
 },
 [0x1092C]={
  category="lo",
  description="LYDIAN LETTER O",
  direction="r",
  linebreak="al",
  unicodeslot=0x1092C,
 },
 [0x1092D]={
  category="lo",
  description="LYDIAN LETTER R",
  direction="r",
  linebreak="al",
  unicodeslot=0x1092D,
 },
 [0x1092E]={
  category="lo",
  description="LYDIAN LETTER SS",
  direction="r",
  linebreak="al",
  unicodeslot=0x1092E,
 },
 [0x1092F]={
  category="lo",
  description="LYDIAN LETTER T",
  direction="r",
  linebreak="al",
  unicodeslot=0x1092F,
 },
 [0x10930]={
  category="lo",
  description="LYDIAN LETTER U",
  direction="r",
  linebreak="al",
  unicodeslot=0x10930,
 },
 [0x10931]={
  category="lo",
  description="LYDIAN LETTER F",
  direction="r",
  linebreak="al",
  unicodeslot=0x10931,
 },
 [0x10932]={
  category="lo",
  description="LYDIAN LETTER Q",
  direction="r",
  linebreak="al",
  unicodeslot=0x10932,
 },
 [0x10933]={
  category="lo",
  description="LYDIAN LETTER S",
  direction="r",
  linebreak="al",
  unicodeslot=0x10933,
 },
 [0x10934]={
  category="lo",
  description="LYDIAN LETTER TT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10934,
 },
 [0x10935]={
  category="lo",
  description="LYDIAN LETTER AN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10935,
 },
 [0x10936]={
  category="lo",
  description="LYDIAN LETTER EN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10936,
 },
 [0x10937]={
  category="lo",
  description="LYDIAN LETTER LY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10937,
 },
 [0x10938]={
  category="lo",
  description="LYDIAN LETTER NN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10938,
 },
 [0x10939]={
  category="lo",
  description="LYDIAN LETTER C",
  direction="r",
  linebreak="al",
  unicodeslot=0x10939,
 },
 [0x1093F]={
  category="po",
  description="LYDIAN TRIANGULAR MARK",
  direction="r",
  linebreak="al",
  unicodeslot=0x1093F,
 },
 [0x10980]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER A",
  direction="r",
  linebreak="al",
  unicodeslot=0x10980,
 },
 [0x10981]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER E",
  direction="r",
  linebreak="al",
  unicodeslot=0x10981,
 },
 [0x10982]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER I",
  direction="r",
  linebreak="al",
  unicodeslot=0x10982,
 },
 [0x10983]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER O",
  direction="r",
  linebreak="al",
  unicodeslot=0x10983,
 },
 [0x10984]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER YA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10984,
 },
 [0x10985]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER WA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10985,
 },
 [0x10986]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER BA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10986,
 },
 [0x10987]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER BA-2",
  direction="r",
  linebreak="al",
  unicodeslot=0x10987,
 },
 [0x10988]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER PA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10988,
 },
 [0x10989]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER MA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10989,
 },
 [0x1098A]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER NA",
  direction="r",
  linebreak="al",
  unicodeslot=0x1098A,
 },
 [0x1098B]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER NA-2",
  direction="r",
  linebreak="al",
  unicodeslot=0x1098B,
 },
 [0x1098C]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER NE",
  direction="r",
  linebreak="al",
  unicodeslot=0x1098C,
 },
 [0x1098D]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER NE-2",
  direction="r",
  linebreak="al",
  unicodeslot=0x1098D,
 },
 [0x1098E]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER RA",
  direction="r",
  linebreak="al",
  unicodeslot=0x1098E,
 },
 [0x1098F]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER RA-2",
  direction="r",
  linebreak="al",
  unicodeslot=0x1098F,
 },
 [0x10990]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER LA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10990,
 },
 [0x10991]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER KHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10991,
 },
 [0x10992]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER HHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10992,
 },
 [0x10993]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER SA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10993,
 },
 [0x10994]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER SA-2",
  direction="r",
  linebreak="al",
  unicodeslot=0x10994,
 },
 [0x10995]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER SE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10995,
 },
 [0x10996]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER KA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10996,
 },
 [0x10997]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER QA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10997,
 },
 [0x10998]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER TA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10998,
 },
 [0x10999]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER TA-2",
  direction="r",
  linebreak="al",
  unicodeslot=0x10999,
 },
 [0x1099A]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER TE",
  direction="r",
  linebreak="al",
  unicodeslot=0x1099A,
 },
 [0x1099B]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER TE-2",
  direction="r",
  linebreak="al",
  unicodeslot=0x1099B,
 },
 [0x1099C]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER TO",
  direction="r",
  linebreak="al",
  unicodeslot=0x1099C,
 },
 [0x1099D]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC LETTER DA",
  direction="r",
  linebreak="al",
  unicodeslot=0x1099D,
 },
 [0x1099E]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC SYMBOL VIDJ",
  direction="r",
  linebreak="al",
  unicodeslot=0x1099E,
 },
 [0x1099F]={
  category="lo",
  description="MEROITIC HIEROGLYPHIC SYMBOL VIDJ-2",
  direction="r",
  linebreak="al",
  unicodeslot=0x1099F,
 },
 [0x109A0]={
  category="lo",
  description="MEROITIC CURSIVE LETTER A",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A0,
 },
 [0x109A1]={
  category="lo",
  description="MEROITIC CURSIVE LETTER E",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A1,
 },
 [0x109A2]={
  category="lo",
  description="MEROITIC CURSIVE LETTER I",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A2,
 },
 [0x109A3]={
  category="lo",
  description="MEROITIC CURSIVE LETTER O",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A3,
 },
 [0x109A4]={
  category="lo",
  description="MEROITIC CURSIVE LETTER YA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A4,
 },
 [0x109A5]={
  category="lo",
  description="MEROITIC CURSIVE LETTER WA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A5,
 },
 [0x109A6]={
  category="lo",
  description="MEROITIC CURSIVE LETTER BA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A6,
 },
 [0x109A7]={
  category="lo",
  description="MEROITIC CURSIVE LETTER PA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A7,
 },
 [0x109A8]={
  category="lo",
  description="MEROITIC CURSIVE LETTER MA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A8,
 },
 [0x109A9]={
  category="lo",
  description="MEROITIC CURSIVE LETTER NA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109A9,
 },
 [0x109AA]={
  category="lo",
  description="MEROITIC CURSIVE LETTER NE",
  direction="r",
  linebreak="al",
  unicodeslot=0x109AA,
 },
 [0x109AB]={
  category="lo",
  description="MEROITIC CURSIVE LETTER RA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109AB,
 },
 [0x109AC]={
  category="lo",
  description="MEROITIC CURSIVE LETTER LA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109AC,
 },
 [0x109AD]={
  category="lo",
  description="MEROITIC CURSIVE LETTER KHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109AD,
 },
 [0x109AE]={
  category="lo",
  description="MEROITIC CURSIVE LETTER HHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109AE,
 },
 [0x109AF]={
  category="lo",
  description="MEROITIC CURSIVE LETTER SA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109AF,
 },
 [0x109B0]={
  category="lo",
  description="MEROITIC CURSIVE LETTER ARCHAIC SA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109B0,
 },
 [0x109B1]={
  category="lo",
  description="MEROITIC CURSIVE LETTER SE",
  direction="r",
  linebreak="al",
  unicodeslot=0x109B1,
 },
 [0x109B2]={
  category="lo",
  description="MEROITIC CURSIVE LETTER KA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109B2,
 },
 [0x109B3]={
  category="lo",
  description="MEROITIC CURSIVE LETTER QA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109B3,
 },
 [0x109B4]={
  category="lo",
  description="MEROITIC CURSIVE LETTER TA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109B4,
 },
 [0x109B5]={
  category="lo",
  description="MEROITIC CURSIVE LETTER TE",
  direction="r",
  linebreak="al",
  unicodeslot=0x109B5,
 },
 [0x109B6]={
  category="lo",
  description="MEROITIC CURSIVE LETTER TO",
  direction="r",
  linebreak="al",
  unicodeslot=0x109B6,
 },
 [0x109B7]={
  category="lo",
  description="MEROITIC CURSIVE LETTER DA",
  direction="r",
  linebreak="al",
  unicodeslot=0x109B7,
 },
 [0x109BE]={
  category="lo",
  description="MEROITIC CURSIVE LOGOGRAM RMT",
  direction="r",
  linebreak="al",
  unicodeslot=0x109BE,
 },
 [0x109BF]={
  category="lo",
  description="MEROITIC CURSIVE LOGOGRAM IMN",
  direction="r",
  linebreak="al",
  unicodeslot=0x109BF,
 },
 [0x10A00]={
  category="lo",
  description="KHAROSHTHI LETTER A",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A00,
 },
 [0x10A01]={
  category="mn",
  description="KHAROSHTHI VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A01,
 },
 [0x10A02]={
  category="mn",
  description="KHAROSHTHI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A02,
 },
 [0x10A03]={
  category="mn",
  description="KHAROSHTHI VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A03,
 },
 [0x10A05]={
  category="mn",
  description="KHAROSHTHI VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A05,
 },
 [0x10A06]={
  category="mn",
  description="KHAROSHTHI VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A06,
 },
 [0x10A0C]={
  category="mn",
  description="KHAROSHTHI VOWEL LENGTH MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A0C,
 },
 [0x10A0D]={
  category="mn",
  description="KHAROSHTHI SIGN DOUBLE RING BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A0D,
 },
 [0x10A0E]={
  category="mn",
  description="KHAROSHTHI SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A0E,
 },
 [0x10A0F]={
  category="mn",
  description="KHAROSHTHI SIGN VISARGA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A0F,
 },
 [0x10A10]={
  category="lo",
  description="KHAROSHTHI LETTER KA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A10,
 },
 [0x10A11]={
  category="lo",
  description="KHAROSHTHI LETTER KHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A11,
 },
 [0x10A12]={
  category="lo",
  description="KHAROSHTHI LETTER GA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A12,
 },
 [0x10A13]={
  category="lo",
  description="KHAROSHTHI LETTER GHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A13,
 },
 [0x10A15]={
  category="lo",
  description="KHAROSHTHI LETTER CA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A15,
 },
 [0x10A16]={
  category="lo",
  description="KHAROSHTHI LETTER CHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A16,
 },
 [0x10A17]={
  category="lo",
  description="KHAROSHTHI LETTER JA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A17,
 },
 [0x10A19]={
  category="lo",
  description="KHAROSHTHI LETTER NYA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A19,
 },
 [0x10A1A]={
  category="lo",
  description="KHAROSHTHI LETTER TTA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A1A,
 },
 [0x10A1B]={
  category="lo",
  description="KHAROSHTHI LETTER TTHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A1B,
 },
 [0x10A1C]={
  category="lo",
  description="KHAROSHTHI LETTER DDA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A1C,
 },
 [0x10A1D]={
  category="lo",
  description="KHAROSHTHI LETTER DDHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A1D,
 },
 [0x10A1E]={
  category="lo",
  description="KHAROSHTHI LETTER NNA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A1E,
 },
 [0x10A1F]={
  category="lo",
  description="KHAROSHTHI LETTER TA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A1F,
 },
 [0x10A20]={
  category="lo",
  description="KHAROSHTHI LETTER THA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A20,
 },
 [0x10A21]={
  category="lo",
  description="KHAROSHTHI LETTER DA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A21,
 },
 [0x10A22]={
  category="lo",
  description="KHAROSHTHI LETTER DHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A22,
 },
 [0x10A23]={
  category="lo",
  description="KHAROSHTHI LETTER NA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A23,
 },
 [0x10A24]={
  category="lo",
  description="KHAROSHTHI LETTER PA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A24,
 },
 [0x10A25]={
  category="lo",
  description="KHAROSHTHI LETTER PHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A25,
 },
 [0x10A26]={
  category="lo",
  description="KHAROSHTHI LETTER BA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A26,
 },
 [0x10A27]={
  category="lo",
  description="KHAROSHTHI LETTER BHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A27,
 },
 [0x10A28]={
  category="lo",
  description="KHAROSHTHI LETTER MA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A28,
 },
 [0x10A29]={
  category="lo",
  description="KHAROSHTHI LETTER YA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A29,
 },
 [0x10A2A]={
  category="lo",
  description="KHAROSHTHI LETTER RA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A2A,
 },
 [0x10A2B]={
  category="lo",
  description="KHAROSHTHI LETTER LA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A2B,
 },
 [0x10A2C]={
  category="lo",
  description="KHAROSHTHI LETTER VA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A2C,
 },
 [0x10A2D]={
  category="lo",
  description="KHAROSHTHI LETTER SHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A2D,
 },
 [0x10A2E]={
  category="lo",
  description="KHAROSHTHI LETTER SSA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A2E,
 },
 [0x10A2F]={
  category="lo",
  description="KHAROSHTHI LETTER SA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A2F,
 },
 [0x10A30]={
  category="lo",
  description="KHAROSHTHI LETTER ZA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A30,
 },
 [0x10A31]={
  category="lo",
  description="KHAROSHTHI LETTER HA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A31,
 },
 [0x10A32]={
  category="lo",
  description="KHAROSHTHI LETTER KKA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A32,
 },
 [0x10A33]={
  category="lo",
  description="KHAROSHTHI LETTER TTTHA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A33,
 },
 [0x10A38]={
  category="mn",
  description="KHAROSHTHI SIGN BAR ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A38,
 },
 [0x10A39]={
  category="mn",
  description="KHAROSHTHI SIGN CAUDA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A39,
 },
 [0x10A3A]={
  category="mn",
  description="KHAROSHTHI SIGN DOT BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A3A,
 },
 [0x10A3F]={
  category="mn",
  description="KHAROSHTHI VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x10A3F,
 },
 [0x10A40]={
  category="no",
  description="KHAROSHTHI DIGIT ONE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A40,
 },
 [0x10A41]={
  category="no",
  description="KHAROSHTHI DIGIT TWO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A41,
 },
 [0x10A42]={
  category="no",
  description="KHAROSHTHI DIGIT THREE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A42,
 },
 [0x10A43]={
  category="no",
  description="KHAROSHTHI DIGIT FOUR",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A43,
 },
 [0x10A44]={
  category="no",
  description="KHAROSHTHI NUMBER TEN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A44,
 },
 [0x10A45]={
  category="no",
  description="KHAROSHTHI NUMBER TWENTY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A45,
 },
 [0x10A46]={
  category="no",
  description="KHAROSHTHI NUMBER ONE HUNDRED",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A46,
 },
 [0x10A47]={
  category="no",
  description="KHAROSHTHI NUMBER ONE THOUSAND",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A47,
 },
 [0x10A50]={
  category="po",
  description="KHAROSHTHI PUNCTUATION DOT",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10A50,
 },
 [0x10A51]={
  category="po",
  description="KHAROSHTHI PUNCTUATION SMALL CIRCLE",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10A51,
 },
 [0x10A52]={
  category="po",
  description="KHAROSHTHI PUNCTUATION CIRCLE",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10A52,
 },
 [0x10A53]={
  category="po",
  description="KHAROSHTHI PUNCTUATION CRESCENT BAR",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10A53,
 },
 [0x10A54]={
  category="po",
  description="KHAROSHTHI PUNCTUATION MANGALAM",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10A54,
 },
 [0x10A55]={
  category="po",
  description="KHAROSHTHI PUNCTUATION LOTUS",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10A55,
 },
 [0x10A56]={
  category="po",
  description="KHAROSHTHI PUNCTUATION DANDA",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10A56,
 },
 [0x10A57]={
  category="po",
  description="KHAROSHTHI PUNCTUATION DOUBLE DANDA",
  direction="r",
  linebreak="ba",
  unicodeslot=0x10A57,
 },
 [0x10A58]={
  category="po",
  description="KHAROSHTHI PUNCTUATION LINES",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A58,
 },
 [0x10A60]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER HE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A60,
 },
 [0x10A61]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER LAMEDH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A61,
 },
 [0x10A62]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER HETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A62,
 },
 [0x10A63]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER MEM",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A63,
 },
 [0x10A64]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER QOPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A64,
 },
 [0x10A65]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER WAW",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A65,
 },
 [0x10A66]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER SHIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A66,
 },
 [0x10A67]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER RESH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A67,
 },
 [0x10A68]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER BETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A68,
 },
 [0x10A69]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER TAW",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A69,
 },
 [0x10A6A]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER SAT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A6A,
 },
 [0x10A6B]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER KAPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A6B,
 },
 [0x10A6C]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER NUN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A6C,
 },
 [0x10A6D]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER KHETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A6D,
 },
 [0x10A6E]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER SADHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A6E,
 },
 [0x10A6F]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER SAMEKH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A6F,
 },
 [0x10A70]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER FE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A70,
 },
 [0x10A71]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER ALEF",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A71,
 },
 [0x10A72]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER AYN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A72,
 },
 [0x10A73]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER DHADHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A73,
 },
 [0x10A74]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER GIMEL",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A74,
 },
 [0x10A75]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER DALETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A75,
 },
 [0x10A76]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER GHAYN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A76,
 },
 [0x10A77]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER TETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A77,
 },
 [0x10A78]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER ZAYN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A78,
 },
 [0x10A79]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER DHALETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A79,
 },
 [0x10A7A]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER YODH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A7A,
 },
 [0x10A7B]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER THAW",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A7B,
 },
 [0x10A7C]={
  category="lo",
  description="OLD SOUTH ARABIAN LETTER THETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A7C,
 },
 [0x10A7D]={
  category="no",
  description="OLD SOUTH ARABIAN NUMBER ONE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A7D,
 },
 [0x10A7E]={
  category="no",
  description="OLD SOUTH ARABIAN NUMBER FIFTY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A7E,
 },
 [0x10A7F]={
  category="po",
  description="OLD SOUTH ARABIAN NUMERIC INDICATOR",
  direction="r",
  linebreak="al",
  unicodeslot=0x10A7F,
 },
 [0x10B00]={
  category="lo",
  description="AVESTAN LETTER A",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B00,
 },
 [0x10B01]={
  category="lo",
  description="AVESTAN LETTER AA",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B01,
 },
 [0x10B02]={
  category="lo",
  description="AVESTAN LETTER AO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B02,
 },
 [0x10B03]={
  category="lo",
  description="AVESTAN LETTER AAO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B03,
 },
 [0x10B04]={
  category="lo",
  description="AVESTAN LETTER AN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B04,
 },
 [0x10B05]={
  category="lo",
  description="AVESTAN LETTER AAN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B05,
 },
 [0x10B06]={
  category="lo",
  description="AVESTAN LETTER AE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B06,
 },
 [0x10B07]={
  category="lo",
  description="AVESTAN LETTER AEE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B07,
 },
 [0x10B08]={
  category="lo",
  description="AVESTAN LETTER E",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B08,
 },
 [0x10B09]={
  category="lo",
  description="AVESTAN LETTER EE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B09,
 },
 [0x10B0A]={
  category="lo",
  description="AVESTAN LETTER O",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B0A,
 },
 [0x10B0B]={
  category="lo",
  description="AVESTAN LETTER OO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B0B,
 },
 [0x10B0C]={
  category="lo",
  description="AVESTAN LETTER I",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B0C,
 },
 [0x10B0D]={
  category="lo",
  description="AVESTAN LETTER II",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B0D,
 },
 [0x10B0E]={
  category="lo",
  description="AVESTAN LETTER U",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B0E,
 },
 [0x10B0F]={
  category="lo",
  description="AVESTAN LETTER UU",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B0F,
 },
 [0x10B10]={
  category="lo",
  description="AVESTAN LETTER KE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B10,
 },
 [0x10B11]={
  category="lo",
  description="AVESTAN LETTER XE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B11,
 },
 [0x10B12]={
  category="lo",
  description="AVESTAN LETTER XYE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B12,
 },
 [0x10B13]={
  category="lo",
  description="AVESTAN LETTER XVE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B13,
 },
 [0x10B14]={
  category="lo",
  description="AVESTAN LETTER GE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B14,
 },
 [0x10B15]={
  category="lo",
  description="AVESTAN LETTER GGE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B15,
 },
 [0x10B16]={
  category="lo",
  description="AVESTAN LETTER GHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B16,
 },
 [0x10B17]={
  category="lo",
  description="AVESTAN LETTER CE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B17,
 },
 [0x10B18]={
  category="lo",
  description="AVESTAN LETTER JE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B18,
 },
 [0x10B19]={
  category="lo",
  description="AVESTAN LETTER TE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B19,
 },
 [0x10B1A]={
  category="lo",
  description="AVESTAN LETTER THE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B1A,
 },
 [0x10B1B]={
  category="lo",
  description="AVESTAN LETTER DE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B1B,
 },
 [0x10B1C]={
  category="lo",
  description="AVESTAN LETTER DHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B1C,
 },
 [0x10B1D]={
  category="lo",
  description="AVESTAN LETTER TTE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B1D,
 },
 [0x10B1E]={
  category="lo",
  description="AVESTAN LETTER PE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B1E,
 },
 [0x10B1F]={
  category="lo",
  description="AVESTAN LETTER FE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B1F,
 },
 [0x10B20]={
  category="lo",
  description="AVESTAN LETTER BE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B20,
 },
 [0x10B21]={
  category="lo",
  description="AVESTAN LETTER BHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B21,
 },
 [0x10B22]={
  category="lo",
  description="AVESTAN LETTER NGE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B22,
 },
 [0x10B23]={
  category="lo",
  description="AVESTAN LETTER NGYE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B23,
 },
 [0x10B24]={
  category="lo",
  description="AVESTAN LETTER NGVE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B24,
 },
 [0x10B25]={
  category="lo",
  description="AVESTAN LETTER NE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B25,
 },
 [0x10B26]={
  category="lo",
  description="AVESTAN LETTER NYE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B26,
 },
 [0x10B27]={
  category="lo",
  description="AVESTAN LETTER NNE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B27,
 },
 [0x10B28]={
  category="lo",
  description="AVESTAN LETTER ME",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B28,
 },
 [0x10B29]={
  category="lo",
  description="AVESTAN LETTER HME",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B29,
 },
 [0x10B2A]={
  category="lo",
  description="AVESTAN LETTER YYE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B2A,
 },
 [0x10B2B]={
  category="lo",
  description="AVESTAN LETTER YE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B2B,
 },
 [0x10B2C]={
  category="lo",
  description="AVESTAN LETTER VE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B2C,
 },
 [0x10B2D]={
  category="lo",
  description="AVESTAN LETTER RE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B2D,
 },
 [0x10B2E]={
  category="lo",
  description="AVESTAN LETTER LE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B2E,
 },
 [0x10B2F]={
  category="lo",
  description="AVESTAN LETTER SE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B2F,
 },
 [0x10B30]={
  category="lo",
  description="AVESTAN LETTER ZE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B30,
 },
 [0x10B31]={
  category="lo",
  description="AVESTAN LETTER SHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B31,
 },
 [0x10B32]={
  category="lo",
  description="AVESTAN LETTER ZHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B32,
 },
 [0x10B33]={
  category="lo",
  description="AVESTAN LETTER SHYE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B33,
 },
 [0x10B34]={
  category="lo",
  description="AVESTAN LETTER SSHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B34,
 },
 [0x10B35]={
  category="lo",
  description="AVESTAN LETTER HE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B35,
 },
 [0x10B39]={
  category="po",
  description="AVESTAN ABBREVIATION MARK",
  direction="on",
  linebreak="ba",
  unicodeslot=0x10B39,
 },
 [0x10B3A]={
  category="po",
  description="TINY TWO DOTS OVER ONE DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x10B3A,
 },
 [0x10B3B]={
  category="po",
  description="SMALL TWO DOTS OVER ONE DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x10B3B,
 },
 [0x10B3C]={
  category="po",
  description="LARGE TWO DOTS OVER ONE DOT PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x10B3C,
 },
 [0x10B3D]={
  category="po",
  description="LARGE ONE DOT OVER TWO DOTS PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x10B3D,
 },
 [0x10B3E]={
  category="po",
  description="LARGE TWO RINGS OVER ONE RING PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x10B3E,
 },
 [0x10B3F]={
  category="po",
  description="LARGE ONE RING OVER TWO RINGS PUNCTUATION",
  direction="on",
  linebreak="ba",
  unicodeslot=0x10B3F,
 },
 [0x10B40]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER ALEPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B40,
 },
 [0x10B41]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER BETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B41,
 },
 [0x10B42]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER GIMEL",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B42,
 },
 [0x10B43]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER DALETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B43,
 },
 [0x10B44]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER HE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B44,
 },
 [0x10B45]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER WAW",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B45,
 },
 [0x10B46]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER ZAYIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B46,
 },
 [0x10B47]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER HETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B47,
 },
 [0x10B48]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER TETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B48,
 },
 [0x10B49]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER YODH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B49,
 },
 [0x10B4A]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER KAPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B4A,
 },
 [0x10B4B]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER LAMEDH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B4B,
 },
 [0x10B4C]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER MEM",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B4C,
 },
 [0x10B4D]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER NUN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B4D,
 },
 [0x10B4E]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER SAMEKH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B4E,
 },
 [0x10B4F]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER AYIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B4F,
 },
 [0x10B50]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER PE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B50,
 },
 [0x10B51]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER SADHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B51,
 },
 [0x10B52]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER QOPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B52,
 },
 [0x10B53]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER RESH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B53,
 },
 [0x10B54]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER SHIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B54,
 },
 [0x10B55]={
  category="lo",
  description="INSCRIPTIONAL PARTHIAN LETTER TAW",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B55,
 },
 [0x10B58]={
  category="no",
  description="INSCRIPTIONAL PARTHIAN NUMBER ONE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B58,
 },
 [0x10B59]={
  category="no",
  description="INSCRIPTIONAL PARTHIAN NUMBER TWO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B59,
 },
 [0x10B5A]={
  category="no",
  description="INSCRIPTIONAL PARTHIAN NUMBER THREE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B5A,
 },
 [0x10B5B]={
  category="no",
  description="INSCRIPTIONAL PARTHIAN NUMBER FOUR",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B5B,
 },
 [0x10B5C]={
  category="no",
  description="INSCRIPTIONAL PARTHIAN NUMBER TEN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B5C,
 },
 [0x10B5D]={
  category="no",
  description="INSCRIPTIONAL PARTHIAN NUMBER TWENTY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B5D,
 },
 [0x10B5E]={
  category="no",
  description="INSCRIPTIONAL PARTHIAN NUMBER ONE HUNDRED",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B5E,
 },
 [0x10B5F]={
  category="no",
  description="INSCRIPTIONAL PARTHIAN NUMBER ONE THOUSAND",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B5F,
 },
 [0x10B60]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER ALEPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B60,
 },
 [0x10B61]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER BETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B61,
 },
 [0x10B62]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER GIMEL",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B62,
 },
 [0x10B63]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER DALETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B63,
 },
 [0x10B64]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER HE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B64,
 },
 [0x10B65]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER WAW-AYIN-RESH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B65,
 },
 [0x10B66]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER ZAYIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B66,
 },
 [0x10B67]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER HETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B67,
 },
 [0x10B68]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER TETH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B68,
 },
 [0x10B69]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER YODH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B69,
 },
 [0x10B6A]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER KAPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B6A,
 },
 [0x10B6B]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER LAMEDH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B6B,
 },
 [0x10B6C]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER MEM-QOPH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B6C,
 },
 [0x10B6D]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER NUN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B6D,
 },
 [0x10B6E]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER SAMEKH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B6E,
 },
 [0x10B6F]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER PE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B6F,
 },
 [0x10B70]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER SADHE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B70,
 },
 [0x10B71]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER SHIN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B71,
 },
 [0x10B72]={
  category="lo",
  description="INSCRIPTIONAL PAHLAVI LETTER TAW",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B72,
 },
 [0x10B78]={
  category="no",
  description="INSCRIPTIONAL PAHLAVI NUMBER ONE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B78,
 },
 [0x10B79]={
  category="no",
  description="INSCRIPTIONAL PAHLAVI NUMBER TWO",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B79,
 },
 [0x10B7A]={
  category="no",
  description="INSCRIPTIONAL PAHLAVI NUMBER THREE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B7A,
 },
 [0x10B7B]={
  category="no",
  description="INSCRIPTIONAL PAHLAVI NUMBER FOUR",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B7B,
 },
 [0x10B7C]={
  category="no",
  description="INSCRIPTIONAL PAHLAVI NUMBER TEN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B7C,
 },
 [0x10B7D]={
  category="no",
  description="INSCRIPTIONAL PAHLAVI NUMBER TWENTY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B7D,
 },
 [0x10B7E]={
  category="no",
  description="INSCRIPTIONAL PAHLAVI NUMBER ONE HUNDRED",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B7E,
 },
 [0x10B7F]={
  category="no",
  description="INSCRIPTIONAL PAHLAVI NUMBER ONE THOUSAND",
  direction="r",
  linebreak="al",
  unicodeslot=0x10B7F,
 },
 [0x10C00]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON A",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C00,
 },
 [0x10C01]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI A",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C01,
 },
 [0x10C02]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C02,
 },
 [0x10C03]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON I",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C03,
 },
 [0x10C04]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI I",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C04,
 },
 [0x10C05]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI E",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C05,
 },
 [0x10C06]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON O",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C06,
 },
 [0x10C07]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON OE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C07,
 },
 [0x10C08]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI OE",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C08,
 },
 [0x10C09]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AB",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C09,
 },
 [0x10C0A]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AB",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C0A,
 },
 [0x10C0B]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AEB",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C0B,
 },
 [0x10C0C]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AEB",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C0C,
 },
 [0x10C0D]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AG",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C0D,
 },
 [0x10C0E]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AG",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C0E,
 },
 [0x10C0F]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AEG",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C0F,
 },
 [0x10C10]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AEG",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C10,
 },
 [0x10C11]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AD",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C11,
 },
 [0x10C12]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AD",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C12,
 },
 [0x10C13]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AED",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C13,
 },
 [0x10C14]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON EZ",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C14,
 },
 [0x10C15]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI EZ",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C15,
 },
 [0x10C16]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C16,
 },
 [0x10C17]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C17,
 },
 [0x10C18]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AEY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C18,
 },
 [0x10C19]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AEY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C19,
 },
 [0x10C1A]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AEK",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C1A,
 },
 [0x10C1B]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AEK",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C1B,
 },
 [0x10C1C]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON OEK",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C1C,
 },
 [0x10C1D]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI OEK",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C1D,
 },
 [0x10C1E]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AL",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C1E,
 },
 [0x10C1F]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AL",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C1F,
 },
 [0x10C20]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AEL",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C20,
 },
 [0x10C21]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON ELT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C21,
 },
 [0x10C22]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON EM",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C22,
 },
 [0x10C23]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C23,
 },
 [0x10C24]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AEN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C24,
 },
 [0x10C25]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AEN",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C25,
 },
 [0x10C26]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON ENT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C26,
 },
 [0x10C27]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI ENT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C27,
 },
 [0x10C28]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON ENC",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C28,
 },
 [0x10C29]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI ENC",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C29,
 },
 [0x10C2A]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON ENY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C2A,
 },
 [0x10C2B]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI ENY",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C2B,
 },
 [0x10C2C]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI ANG",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C2C,
 },
 [0x10C2D]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON ENG",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C2D,
 },
 [0x10C2E]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AENG",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C2E,
 },
 [0x10C2F]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON EP",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C2F,
 },
 [0x10C30]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON OP",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C30,
 },
 [0x10C31]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON IC",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C31,
 },
 [0x10C32]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON EC",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C32,
 },
 [0x10C33]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI EC",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C33,
 },
 [0x10C34]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C34,
 },
 [0x10C35]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C35,
 },
 [0x10C36]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON IQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C36,
 },
 [0x10C37]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI IQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C37,
 },
 [0x10C38]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON OQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C38,
 },
 [0x10C39]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI OQ",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C39,
 },
 [0x10C3A]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AR",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C3A,
 },
 [0x10C3B]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AR",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C3B,
 },
 [0x10C3C]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AER",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C3C,
 },
 [0x10C3D]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AS",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C3D,
 },
 [0x10C3E]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AES",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C3E,
 },
 [0x10C3F]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON ASH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C3F,
 },
 [0x10C40]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI ASH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C40,
 },
 [0x10C41]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON ESH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C41,
 },
 [0x10C42]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI ESH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C42,
 },
 [0x10C43]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C43,
 },
 [0x10C44]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C44,
 },
 [0x10C45]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON AET",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C45,
 },
 [0x10C46]={
  category="lo",
  description="OLD TURKIC LETTER YENISEI AET",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C46,
 },
 [0x10C47]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON OT",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C47,
 },
 [0x10C48]={
  category="lo",
  description="OLD TURKIC LETTER ORKHON BASH",
  direction="r",
  linebreak="al",
  unicodeslot=0x10C48,
 },
 [0x10E60]={
  category="no",
  description="RUMI DIGIT ONE",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E60,
 },
 [0x10E61]={
  category="no",
  description="RUMI DIGIT TWO",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E61,
 },
 [0x10E62]={
  category="no",
  description="RUMI DIGIT THREE",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E62,
 },
 [0x10E63]={
  category="no",
  description="RUMI DIGIT FOUR",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E63,
 },
 [0x10E64]={
  category="no",
  description="RUMI DIGIT FIVE",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E64,
 },
 [0x10E65]={
  category="no",
  description="RUMI DIGIT SIX",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E65,
 },
 [0x10E66]={
  category="no",
  description="RUMI DIGIT SEVEN",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E66,
 },
 [0x10E67]={
  category="no",
  description="RUMI DIGIT EIGHT",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E67,
 },
 [0x10E68]={
  category="no",
  description="RUMI DIGIT NINE",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E68,
 },
 [0x10E69]={
  category="no",
  description="RUMI NUMBER TEN",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E69,
 },
 [0x10E6A]={
  category="no",
  description="RUMI NUMBER TWENTY",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E6A,
 },
 [0x10E6B]={
  category="no",
  description="RUMI NUMBER THIRTY",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E6B,
 },
 [0x10E6C]={
  category="no",
  description="RUMI NUMBER FORTY",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E6C,
 },
 [0x10E6D]={
  category="no",
  description="RUMI NUMBER FIFTY",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E6D,
 },
 [0x10E6E]={
  category="no",
  description="RUMI NUMBER SIXTY",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E6E,
 },
 [0x10E6F]={
  category="no",
  description="RUMI NUMBER SEVENTY",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E6F,
 },
 [0x10E70]={
  category="no",
  description="RUMI NUMBER EIGHTY",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E70,
 },
 [0x10E71]={
  category="no",
  description="RUMI NUMBER NINETY",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E71,
 },
 [0x10E72]={
  category="no",
  description="RUMI NUMBER ONE HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E72,
 },
 [0x10E73]={
  category="no",
  description="RUMI NUMBER TWO HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E73,
 },
 [0x10E74]={
  category="no",
  description="RUMI NUMBER THREE HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E74,
 },
 [0x10E75]={
  category="no",
  description="RUMI NUMBER FOUR HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E75,
 },
 [0x10E76]={
  category="no",
  description="RUMI NUMBER FIVE HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E76,
 },
 [0x10E77]={
  category="no",
  description="RUMI NUMBER SIX HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E77,
 },
 [0x10E78]={
  category="no",
  description="RUMI NUMBER SEVEN HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E78,
 },
 [0x10E79]={
  category="no",
  description="RUMI NUMBER EIGHT HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E79,
 },
 [0x10E7A]={
  category="no",
  description="RUMI NUMBER NINE HUNDRED",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E7A,
 },
 [0x10E7B]={
  category="no",
  description="RUMI FRACTION ONE HALF",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E7B,
 },
 [0x10E7C]={
  category="no",
  description="RUMI FRACTION ONE QUARTER",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E7C,
 },
 [0x10E7D]={
  category="no",
  description="RUMI FRACTION ONE THIRD",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E7D,
 },
 [0x10E7E]={
  category="no",
  description="RUMI FRACTION TWO THIRDS",
  direction="an",
  linebreak="al",
  unicodeslot=0x10E7E,
 },
 [0x11000]={
  category="mc",
  description="BRAHMI SIGN CANDRABINDU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x11000,
 },
 [0x11001]={
  category="mn",
  description="BRAHMI SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11001,
 },
 [0x11002]={
  category="mc",
  description="BRAHMI SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x11002,
 },
 [0x11003]={
  category="lo",
  description="BRAHMI SIGN JIHVAMULIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11003,
 },
 [0x11004]={
  category="lo",
  description="BRAHMI SIGN UPADHMANIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11004,
 },
 [0x11005]={
  category="lo",
  description="BRAHMI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x11005,
 },
 [0x11006]={
  category="lo",
  description="BRAHMI LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11006,
 },
 [0x11007]={
  category="lo",
  description="BRAHMI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x11007,
 },
 [0x11008]={
  category="lo",
  description="BRAHMI LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x11008,
 },
 [0x11009]={
  category="lo",
  description="BRAHMI LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x11009,
 },
 [0x1100A]={
  category="lo",
  description="BRAHMI LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1100A,
 },
 [0x1100B]={
  category="lo",
  description="BRAHMI LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x1100B,
 },
 [0x1100C]={
  category="lo",
  description="BRAHMI LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1100C,
 },
 [0x1100D]={
  category="lo",
  description="BRAHMI LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x1100D,
 },
 [0x1100E]={
  category="lo",
  description="BRAHMI LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1100E,
 },
 [0x1100F]={
  category="lo",
  description="BRAHMI LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1100F,
 },
 [0x11010]={
  category="lo",
  description="BRAHMI LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x11010,
 },
 [0x11011]={
  category="lo",
  description="BRAHMI LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x11011,
 },
 [0x11012]={
  category="lo",
  description="BRAHMI LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x11012,
 },
 [0x11013]={
  category="lo",
  description="BRAHMI LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11013,
 },
 [0x11014]={
  category="lo",
  description="BRAHMI LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11014,
 },
 [0x11015]={
  category="lo",
  description="BRAHMI LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11015,
 },
 [0x11016]={
  category="lo",
  description="BRAHMI LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11016,
 },
 [0x11017]={
  category="lo",
  description="BRAHMI LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11017,
 },
 [0x11018]={
  category="lo",
  description="BRAHMI LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11018,
 },
 [0x11019]={
  category="lo",
  description="BRAHMI LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11019,
 },
 [0x1101A]={
  category="lo",
  description="BRAHMI LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1101A,
 },
 [0x1101B]={
  category="lo",
  description="BRAHMI LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1101B,
 },
 [0x1101C]={
  category="lo",
  description="BRAHMI LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1101C,
 },
 [0x1101D]={
  category="lo",
  description="BRAHMI LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1101D,
 },
 [0x1101E]={
  category="lo",
  description="BRAHMI LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1101E,
 },
 [0x1101F]={
  category="lo",
  description="BRAHMI LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1101F,
 },
 [0x11020]={
  category="lo",
  description="BRAHMI LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11020,
 },
 [0x11021]={
  category="lo",
  description="BRAHMI LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11021,
 },
 [0x11022]={
  category="lo",
  description="BRAHMI LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11022,
 },
 [0x11023]={
  category="lo",
  description="BRAHMI LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11023,
 },
 [0x11024]={
  category="lo",
  description="BRAHMI LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11024,
 },
 [0x11025]={
  category="lo",
  description="BRAHMI LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11025,
 },
 [0x11026]={
  category="lo",
  description="BRAHMI LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11026,
 },
 [0x11027]={
  category="lo",
  description="BRAHMI LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11027,
 },
 [0x11028]={
  category="lo",
  description="BRAHMI LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11028,
 },
 [0x11029]={
  category="lo",
  description="BRAHMI LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11029,
 },
 [0x1102A]={
  category="lo",
  description="BRAHMI LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1102A,
 },
 [0x1102B]={
  category="lo",
  description="BRAHMI LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1102B,
 },
 [0x1102C]={
  category="lo",
  description="BRAHMI LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1102C,
 },
 [0x1102D]={
  category="lo",
  description="BRAHMI LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1102D,
 },
 [0x1102E]={
  category="lo",
  description="BRAHMI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1102E,
 },
 [0x1102F]={
  category="lo",
  description="BRAHMI LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1102F,
 },
 [0x11030]={
  category="lo",
  description="BRAHMI LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11030,
 },
 [0x11031]={
  category="lo",
  description="BRAHMI LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11031,
 },
 [0x11032]={
  category="lo",
  description="BRAHMI LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11032,
 },
 [0x11033]={
  category="lo",
  description="BRAHMI LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11033,
 },
 [0x11034]={
  category="lo",
  description="BRAHMI LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11034,
 },
 [0x11035]={
  category="lo",
  description="BRAHMI LETTER OLD TAMIL LLLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11035,
 },
 [0x11036]={
  category="lo",
  description="BRAHMI LETTER OLD TAMIL RRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11036,
 },
 [0x11037]={
  category="lo",
  description="BRAHMI LETTER OLD TAMIL NNNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11037,
 },
 [0x11038]={
  category="mn",
  description="BRAHMI VOWEL SIGN AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11038,
 },
 [0x11039]={
  category="mn",
  description="BRAHMI VOWEL SIGN BHATTIPROLU AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11039,
 },
 [0x1103A]={
  category="mn",
  description="BRAHMI VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1103A,
 },
 [0x1103B]={
  category="mn",
  description="BRAHMI VOWEL SIGN II",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1103B,
 },
 [0x1103C]={
  category="mn",
  description="BRAHMI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1103C,
 },
 [0x1103D]={
  category="mn",
  description="BRAHMI VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1103D,
 },
 [0x1103E]={
  category="mn",
  description="BRAHMI VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1103E,
 },
 [0x1103F]={
  category="mn",
  description="BRAHMI VOWEL SIGN VOCALIC RR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1103F,
 },
 [0x11040]={
  category="mn",
  description="BRAHMI VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11040,
 },
 [0x11041]={
  category="mn",
  description="BRAHMI VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11041,
 },
 [0x11042]={
  category="mn",
  description="BRAHMI VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11042,
 },
 [0x11043]={
  category="mn",
  description="BRAHMI VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11043,
 },
 [0x11044]={
  category="mn",
  description="BRAHMI VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11044,
 },
 [0x11045]={
  category="mn",
  description="BRAHMI VOWEL SIGN AU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11045,
 },
 [0x11046]={
  category="mn",
  description="BRAHMI VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11046,
 },
 [0x11047]={
  category="po",
  description="BRAHMI DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x11047,
 },
 [0x11048]={
  category="po",
  description="BRAHMI DOUBLE DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x11048,
 },
 [0x11049]={
  category="po",
  description="BRAHMI PUNCTUATION DOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x11049,
 },
 [0x1104A]={
  category="po",
  description="BRAHMI PUNCTUATION DOUBLE DOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1104A,
 },
 [0x1104B]={
  category="po",
  description="BRAHMI PUNCTUATION LINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1104B,
 },
 [0x1104C]={
  category="po",
  description="BRAHMI PUNCTUATION CRESCENT BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1104C,
 },
 [0x1104D]={
  category="po",
  description="BRAHMI PUNCTUATION LOTUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1104D,
 },
 [0x11052]={
  category="no",
  description="BRAHMI NUMBER ONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x11052,
 },
 [0x11053]={
  category="no",
  description="BRAHMI NUMBER TWO",
  direction="on",
  linebreak="al",
  unicodeslot=0x11053,
 },
 [0x11054]={
  category="no",
  description="BRAHMI NUMBER THREE",
  direction="on",
  linebreak="al",
  unicodeslot=0x11054,
 },
 [0x11055]={
  category="no",
  description="BRAHMI NUMBER FOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x11055,
 },
 [0x11056]={
  category="no",
  description="BRAHMI NUMBER FIVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x11056,
 },
 [0x11057]={
  category="no",
  description="BRAHMI NUMBER SIX",
  direction="on",
  linebreak="al",
  unicodeslot=0x11057,
 },
 [0x11058]={
  category="no",
  description="BRAHMI NUMBER SEVEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x11058,
 },
 [0x11059]={
  category="no",
  description="BRAHMI NUMBER EIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x11059,
 },
 [0x1105A]={
  category="no",
  description="BRAHMI NUMBER NINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1105A,
 },
 [0x1105B]={
  category="no",
  description="BRAHMI NUMBER TEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1105B,
 },
 [0x1105C]={
  category="no",
  description="BRAHMI NUMBER TWENTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1105C,
 },
 [0x1105D]={
  category="no",
  description="BRAHMI NUMBER THIRTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1105D,
 },
 [0x1105E]={
  category="no",
  description="BRAHMI NUMBER FORTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1105E,
 },
 [0x1105F]={
  category="no",
  description="BRAHMI NUMBER FIFTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1105F,
 },
 [0x11060]={
  category="no",
  description="BRAHMI NUMBER SIXTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x11060,
 },
 [0x11061]={
  category="no",
  description="BRAHMI NUMBER SEVENTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x11061,
 },
 [0x11062]={
  category="no",
  description="BRAHMI NUMBER EIGHTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x11062,
 },
 [0x11063]={
  category="no",
  description="BRAHMI NUMBER NINETY",
  direction="on",
  linebreak="al",
  unicodeslot=0x11063,
 },
 [0x11064]={
  category="no",
  description="BRAHMI NUMBER ONE HUNDRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x11064,
 },
 [0x11065]={
  category="no",
  description="BRAHMI NUMBER ONE THOUSAND",
  direction="on",
  linebreak="al",
  unicodeslot=0x11065,
 },
 [0x11066]={
  category="nd",
  description="BRAHMI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x11066,
 },
 [0x11067]={
  category="nd",
  description="BRAHMI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x11067,
 },
 [0x11068]={
  category="nd",
  description="BRAHMI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x11068,
 },
 [0x11069]={
  category="nd",
  description="BRAHMI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x11069,
 },
 [0x1106A]={
  category="nd",
  description="BRAHMI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1106A,
 },
 [0x1106B]={
  category="nd",
  description="BRAHMI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1106B,
 },
 [0x1106C]={
  category="nd",
  description="BRAHMI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1106C,
 },
 [0x1106D]={
  category="nd",
  description="BRAHMI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1106D,
 },
 [0x1106E]={
  category="nd",
  description="BRAHMI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1106E,
 },
 [0x1106F]={
  category="nd",
  description="BRAHMI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1106F,
 },
 [0x11080]={
  category="mn",
  description="KAITHI SIGN CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11080,
 },
 [0x11081]={
  category="mn",
  description="KAITHI SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11081,
 },
 [0x11082]={
  category="mc",
  description="KAITHI SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x11082,
 },
 [0x11083]={
  category="lo",
  description="KAITHI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x11083,
 },
 [0x11084]={
  category="lo",
  description="KAITHI LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11084,
 },
 [0x11085]={
  category="lo",
  description="KAITHI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x11085,
 },
 [0x11086]={
  category="lo",
  description="KAITHI LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x11086,
 },
 [0x11087]={
  category="lo",
  description="KAITHI LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x11087,
 },
 [0x11088]={
  category="lo",
  description="KAITHI LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x11088,
 },
 [0x11089]={
  category="lo",
  description="KAITHI LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x11089,
 },
 [0x1108A]={
  category="lo",
  description="KAITHI LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1108A,
 },
 [0x1108B]={
  category="lo",
  description="KAITHI LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1108B,
 },
 [0x1108C]={
  category="lo",
  description="KAITHI LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1108C,
 },
 [0x1108D]={
  category="lo",
  description="KAITHI LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1108D,
 },
 [0x1108E]={
  category="lo",
  description="KAITHI LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1108E,
 },
 [0x1108F]={
  category="lo",
  description="KAITHI LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1108F,
 },
 [0x11090]={
  category="lo",
  description="KAITHI LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11090,
 },
 [0x11091]={
  category="lo",
  description="KAITHI LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11091,
 },
 [0x11092]={
  category="lo",
  description="KAITHI LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11092,
 },
 [0x11093]={
  category="lo",
  description="KAITHI LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11093,
 },
 [0x11094]={
  category="lo",
  description="KAITHI LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11094,
 },
 [0x11095]={
  category="lo",
  description="KAITHI LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11095,
 },
 [0x11096]={
  category="lo",
  description="KAITHI LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11096,
 },
 [0x11097]={
  category="lo",
  description="KAITHI LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11097,
 },
 [0x11098]={
  category="lo",
  description="KAITHI LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11098,
 },
 [0x11099]={
  category="lo",
  description="KAITHI LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11099,
 },
 [0x1109A]={
  category="lo",
  description="KAITHI LETTER DDDHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x11099, 0x110BA },
  unicodeslot=0x1109A,
 },
 [0x1109B]={
  category="lo",
  description="KAITHI LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1109B,
 },
 [0x1109C]={
  category="lo",
  description="KAITHI LETTER RHA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1109B, 0x110BA },
  unicodeslot=0x1109C,
 },
 [0x1109D]={
  category="lo",
  description="KAITHI LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1109D,
 },
 [0x1109E]={
  category="lo",
  description="KAITHI LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1109E,
 },
 [0x1109F]={
  category="lo",
  description="KAITHI LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1109F,
 },
 [0x110A0]={
  category="lo",
  description="KAITHI LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A0,
 },
 [0x110A1]={
  category="lo",
  description="KAITHI LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A1,
 },
 [0x110A2]={
  category="lo",
  description="KAITHI LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A2,
 },
 [0x110A3]={
  category="lo",
  description="KAITHI LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A3,
 },
 [0x110A4]={
  category="lo",
  description="KAITHI LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A4,
 },
 [0x110A5]={
  category="lo",
  description="KAITHI LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A5,
 },
 [0x110A6]={
  category="lo",
  description="KAITHI LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A6,
 },
 [0x110A7]={
  category="lo",
  description="KAITHI LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A7,
 },
 [0x110A8]={
  category="lo",
  description="KAITHI LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A8,
 },
 [0x110A9]={
  category="lo",
  description="KAITHI LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110A9,
 },
 [0x110AA]={
  category="lo",
  description="KAITHI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110AA,
 },
 [0x110AB]={
  category="lo",
  description="KAITHI LETTER VA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x110A5, 0x110BA },
  unicodeslot=0x110AB,
 },
 [0x110AC]={
  category="lo",
  description="KAITHI LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110AC,
 },
 [0x110AD]={
  category="lo",
  description="KAITHI LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110AD,
 },
 [0x110AE]={
  category="lo",
  description="KAITHI LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110AE,
 },
 [0x110AF]={
  category="lo",
  description="KAITHI LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x110AF,
 },
 [0x110B0]={
  category="mc",
  description="KAITHI VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x110B0,
 },
 [0x110B1]={
  category="mc",
  description="KAITHI VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x110B1,
 },
 [0x110B2]={
  category="mc",
  description="KAITHI VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x110B2,
 },
 [0x110B3]={
  category="mn",
  description="KAITHI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x110B3,
 },
 [0x110B4]={
  category="mn",
  description="KAITHI VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x110B4,
 },
 [0x110B5]={
  category="mn",
  description="KAITHI VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x110B5,
 },
 [0x110B6]={
  category="mn",
  description="KAITHI VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x110B6,
 },
 [0x110B7]={
  category="mc",
  description="KAITHI VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x110B7,
 },
 [0x110B8]={
  category="mc",
  description="KAITHI VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x110B8,
 },
 [0x110B9]={
  category="mn",
  description="KAITHI SIGN VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x110B9,
 },
 [0x110BA]={
  category="mn",
  description="KAITHI SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x110BA,
 },
 [0x110BB]={
  category="po",
  description="KAITHI ABBREVIATION SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x110BB,
 },
 [0x110BC]={
  category="po",
  description="KAITHI ENUMERATION SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x110BC,
 },
 [0x110BD]={
  category="cf",
  description="KAITHI NUMBER SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x110BD,
 },
 [0x110BE]={
  category="po",
  description="KAITHI SECTION MARK",
  direction="l",
  linebreak="ba",
  unicodeslot=0x110BE,
 },
 [0x110BF]={
  category="po",
  description="KAITHI DOUBLE SECTION MARK",
  direction="l",
  linebreak="ba",
  unicodeslot=0x110BF,
 },
 [0x110C0]={
  category="po",
  description="KAITHI DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x110C0,
 },
 [0x110C1]={
  category="po",
  description="KAITHI DOUBLE DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x110C1,
 },
 [0x110D0]={
  category="lo",
  description="SORA SOMPENG LETTER SAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D0,
 },
 [0x110D1]={
  category="lo",
  description="SORA SOMPENG LETTER TAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D1,
 },
 [0x110D2]={
  category="lo",
  description="SORA SOMPENG LETTER BAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D2,
 },
 [0x110D3]={
  category="lo",
  description="SORA SOMPENG LETTER CAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D3,
 },
 [0x110D4]={
  category="lo",
  description="SORA SOMPENG LETTER DAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D4,
 },
 [0x110D5]={
  category="lo",
  description="SORA SOMPENG LETTER GAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D5,
 },
 [0x110D6]={
  category="lo",
  description="SORA SOMPENG LETTER MAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D6,
 },
 [0x110D7]={
  category="lo",
  description="SORA SOMPENG LETTER NGAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D7,
 },
 [0x110D8]={
  category="lo",
  description="SORA SOMPENG LETTER LAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D8,
 },
 [0x110D9]={
  category="lo",
  description="SORA SOMPENG LETTER NAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110D9,
 },
 [0x110DA]={
  category="lo",
  description="SORA SOMPENG LETTER VAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110DA,
 },
 [0x110DB]={
  category="lo",
  description="SORA SOMPENG LETTER PAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110DB,
 },
 [0x110DC]={
  category="lo",
  description="SORA SOMPENG LETTER YAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110DC,
 },
 [0x110DD]={
  category="lo",
  description="SORA SOMPENG LETTER RAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110DD,
 },
 [0x110DE]={
  category="lo",
  description="SORA SOMPENG LETTER HAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110DE,
 },
 [0x110DF]={
  category="lo",
  description="SORA SOMPENG LETTER KAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110DF,
 },
 [0x110E0]={
  category="lo",
  description="SORA SOMPENG LETTER JAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E0,
 },
 [0x110E1]={
  category="lo",
  description="SORA SOMPENG LETTER NYAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E1,
 },
 [0x110E2]={
  category="lo",
  description="SORA SOMPENG LETTER AH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E2,
 },
 [0x110E3]={
  category="lo",
  description="SORA SOMPENG LETTER EEH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E3,
 },
 [0x110E4]={
  category="lo",
  description="SORA SOMPENG LETTER IH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E4,
 },
 [0x110E5]={
  category="lo",
  description="SORA SOMPENG LETTER UH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E5,
 },
 [0x110E6]={
  category="lo",
  description="SORA SOMPENG LETTER OH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E6,
 },
 [0x110E7]={
  category="lo",
  description="SORA SOMPENG LETTER EH",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E7,
 },
 [0x110E8]={
  category="lo",
  description="SORA SOMPENG LETTER MAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x110E8,
 },
 [0x110F0]={
  category="nd",
  description="SORA SOMPENG DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F0,
 },
 [0x110F1]={
  category="nd",
  description="SORA SOMPENG DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F1,
 },
 [0x110F2]={
  category="nd",
  description="SORA SOMPENG DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F2,
 },
 [0x110F3]={
  category="nd",
  description="SORA SOMPENG DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F3,
 },
 [0x110F4]={
  category="nd",
  description="SORA SOMPENG DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F4,
 },
 [0x110F5]={
  category="nd",
  description="SORA SOMPENG DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F5,
 },
 [0x110F6]={
  category="nd",
  description="SORA SOMPENG DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F6,
 },
 [0x110F7]={
  category="nd",
  description="SORA SOMPENG DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F7,
 },
 [0x110F8]={
  category="nd",
  description="SORA SOMPENG DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F8,
 },
 [0x110F9]={
  category="nd",
  description="SORA SOMPENG DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x110F9,
 },
 [0x11100]={
  category="mn",
  description="CHAKMA SIGN CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11100,
 },
 [0x11101]={
  category="mn",
  description="CHAKMA SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11101,
 },
 [0x11102]={
  category="mn",
  description="CHAKMA SIGN VISARGA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11102,
 },
 [0x11103]={
  category="lo",
  description="CHAKMA LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11103,
 },
 [0x11104]={
  category="lo",
  description="CHAKMA LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x11104,
 },
 [0x11105]={
  category="lo",
  description="CHAKMA LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x11105,
 },
 [0x11106]={
  category="lo",
  description="CHAKMA LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x11106,
 },
 [0x11107]={
  category="lo",
  description="CHAKMA LETTER KAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11107,
 },
 [0x11108]={
  category="lo",
  description="CHAKMA LETTER KHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11108,
 },
 [0x11109]={
  category="lo",
  description="CHAKMA LETTER GAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11109,
 },
 [0x1110A]={
  category="lo",
  description="CHAKMA LETTER GHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1110A,
 },
 [0x1110B]={
  category="lo",
  description="CHAKMA LETTER NGAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1110B,
 },
 [0x1110C]={
  category="lo",
  description="CHAKMA LETTER CAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1110C,
 },
 [0x1110D]={
  category="lo",
  description="CHAKMA LETTER CHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1110D,
 },
 [0x1110E]={
  category="lo",
  description="CHAKMA LETTER JAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1110E,
 },
 [0x1110F]={
  category="lo",
  description="CHAKMA LETTER JHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1110F,
 },
 [0x11110]={
  category="lo",
  description="CHAKMA LETTER NYAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11110,
 },
 [0x11111]={
  category="lo",
  description="CHAKMA LETTER TTAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11111,
 },
 [0x11112]={
  category="lo",
  description="CHAKMA LETTER TTHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11112,
 },
 [0x11113]={
  category="lo",
  description="CHAKMA LETTER DDAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11113,
 },
 [0x11114]={
  category="lo",
  description="CHAKMA LETTER DDHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11114,
 },
 [0x11115]={
  category="lo",
  description="CHAKMA LETTER NNAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11115,
 },
 [0x11116]={
  category="lo",
  description="CHAKMA LETTER TAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11116,
 },
 [0x11117]={
  category="lo",
  description="CHAKMA LETTER THAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11117,
 },
 [0x11118]={
  category="lo",
  description="CHAKMA LETTER DAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11118,
 },
 [0x11119]={
  category="lo",
  description="CHAKMA LETTER DHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11119,
 },
 [0x1111A]={
  category="lo",
  description="CHAKMA LETTER NAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1111A,
 },
 [0x1111B]={
  category="lo",
  description="CHAKMA LETTER PAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1111B,
 },
 [0x1111C]={
  category="lo",
  description="CHAKMA LETTER PHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1111C,
 },
 [0x1111D]={
  category="lo",
  description="CHAKMA LETTER BAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1111D,
 },
 [0x1111E]={
  category="lo",
  description="CHAKMA LETTER BHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1111E,
 },
 [0x1111F]={
  category="lo",
  description="CHAKMA LETTER MAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1111F,
 },
 [0x11120]={
  category="lo",
  description="CHAKMA LETTER YYAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11120,
 },
 [0x11121]={
  category="lo",
  description="CHAKMA LETTER YAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11121,
 },
 [0x11122]={
  category="lo",
  description="CHAKMA LETTER RAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11122,
 },
 [0x11123]={
  category="lo",
  description="CHAKMA LETTER LAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11123,
 },
 [0x11124]={
  category="lo",
  description="CHAKMA LETTER WAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11124,
 },
 [0x11125]={
  category="lo",
  description="CHAKMA LETTER SAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11125,
 },
 [0x11126]={
  category="lo",
  description="CHAKMA LETTER HAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11126,
 },
 [0x11127]={
  category="mn",
  description="CHAKMA VOWEL SIGN A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11127,
 },
 [0x11128]={
  category="mn",
  description="CHAKMA VOWEL SIGN I",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11128,
 },
 [0x11129]={
  category="mn",
  description="CHAKMA VOWEL SIGN II",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11129,
 },
 [0x1112A]={
  category="mn",
  description="CHAKMA VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1112A,
 },
 [0x1112B]={
  category="mn",
  description="CHAKMA VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1112B,
 },
 [0x1112C]={
  category="mc",
  description="CHAKMA VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1112C,
 },
 [0x1112D]={
  category="mn",
  description="CHAKMA VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1112D,
 },
 [0x1112E]={
  category="mn",
  description="CHAKMA VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x11131, 0x11127 },
  unicodeslot=0x1112E,
 },
 [0x1112F]={
  category="mn",
  description="CHAKMA VOWEL SIGN AU",
  direction="nsm",
  linebreak="cm",
  specials={ "char", 0x11132, 0x11127 },
  unicodeslot=0x1112F,
 },
 [0x11130]={
  category="mn",
  description="CHAKMA VOWEL SIGN OI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11130,
 },
 [0x11131]={
  category="mn",
  description="CHAKMA O MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11131,
 },
 [0x11132]={
  category="mn",
  description="CHAKMA AU MARK",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11132,
 },
 [0x11133]={
  category="mn",
  description="CHAKMA VIRAMA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11133,
 },
 [0x11134]={
  category="mn",
  description="CHAKMA MAAYYAA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11134,
 },
 [0x11136]={
  category="nd",
  description="CHAKMA DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x11136,
 },
 [0x11137]={
  category="nd",
  description="CHAKMA DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x11137,
 },
 [0x11138]={
  category="nd",
  description="CHAKMA DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x11138,
 },
 [0x11139]={
  category="nd",
  description="CHAKMA DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x11139,
 },
 [0x1113A]={
  category="nd",
  description="CHAKMA DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1113A,
 },
 [0x1113B]={
  category="nd",
  description="CHAKMA DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1113B,
 },
 [0x1113C]={
  category="nd",
  description="CHAKMA DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1113C,
 },
 [0x1113D]={
  category="nd",
  description="CHAKMA DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1113D,
 },
 [0x1113E]={
  category="nd",
  description="CHAKMA DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1113E,
 },
 [0x1113F]={
  category="nd",
  description="CHAKMA DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x1113F,
 },
 [0x11140]={
  category="po",
  description="CHAKMA SECTION MARK",
  direction="l",
  linebreak="ba",
  unicodeslot=0x11140,
 },
 [0x11141]={
  category="po",
  description="CHAKMA DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x11141,
 },
 [0x11142]={
  category="po",
  description="CHAKMA DOUBLE DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x11142,
 },
 [0x11143]={
  category="po",
  description="CHAKMA QUESTION MARK",
  direction="l",
  linebreak="ba",
  unicodeslot=0x11143,
 },
 [0x11180]={
  category="mn",
  description="SHARADA SIGN CANDRABINDU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11180,
 },
 [0x11181]={
  category="mn",
  description="SHARADA SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x11181,
 },
 [0x11182]={
  category="mc",
  description="SHARADA SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x11182,
 },
 [0x11183]={
  category="lo",
  description="SHARADA LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x11183,
 },
 [0x11184]={
  category="lo",
  description="SHARADA LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11184,
 },
 [0x11185]={
  category="lo",
  description="SHARADA LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x11185,
 },
 [0x11186]={
  category="lo",
  description="SHARADA LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x11186,
 },
 [0x11187]={
  category="lo",
  description="SHARADA LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x11187,
 },
 [0x11188]={
  category="lo",
  description="SHARADA LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x11188,
 },
 [0x11189]={
  category="lo",
  description="SHARADA LETTER VOCALIC R",
  direction="l",
  linebreak="al",
  unicodeslot=0x11189,
 },
 [0x1118A]={
  category="lo",
  description="SHARADA LETTER VOCALIC RR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1118A,
 },
 [0x1118B]={
  category="lo",
  description="SHARADA LETTER VOCALIC L",
  direction="l",
  linebreak="al",
  unicodeslot=0x1118B,
 },
 [0x1118C]={
  category="lo",
  description="SHARADA LETTER VOCALIC LL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1118C,
 },
 [0x1118D]={
  category="lo",
  description="SHARADA LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1118D,
 },
 [0x1118E]={
  category="lo",
  description="SHARADA LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1118E,
 },
 [0x1118F]={
  category="lo",
  description="SHARADA LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x1118F,
 },
 [0x11190]={
  category="lo",
  description="SHARADA LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x11190,
 },
 [0x11191]={
  category="lo",
  description="SHARADA LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11191,
 },
 [0x11192]={
  category="lo",
  description="SHARADA LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11192,
 },
 [0x11193]={
  category="lo",
  description="SHARADA LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11193,
 },
 [0x11194]={
  category="lo",
  description="SHARADA LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11194,
 },
 [0x11195]={
  category="lo",
  description="SHARADA LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11195,
 },
 [0x11196]={
  category="lo",
  description="SHARADA LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11196,
 },
 [0x11197]={
  category="lo",
  description="SHARADA LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11197,
 },
 [0x11198]={
  category="lo",
  description="SHARADA LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11198,
 },
 [0x11199]={
  category="lo",
  description="SHARADA LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11199,
 },
 [0x1119A]={
  category="lo",
  description="SHARADA LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1119A,
 },
 [0x1119B]={
  category="lo",
  description="SHARADA LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1119B,
 },
 [0x1119C]={
  category="lo",
  description="SHARADA LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1119C,
 },
 [0x1119D]={
  category="lo",
  description="SHARADA LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1119D,
 },
 [0x1119E]={
  category="lo",
  description="SHARADA LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1119E,
 },
 [0x1119F]={
  category="lo",
  description="SHARADA LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1119F,
 },
 [0x111A0]={
  category="lo",
  description="SHARADA LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A0,
 },
 [0x111A1]={
  category="lo",
  description="SHARADA LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A1,
 },
 [0x111A2]={
  category="lo",
  description="SHARADA LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A2,
 },
 [0x111A3]={
  category="lo",
  description="SHARADA LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A3,
 },
 [0x111A4]={
  category="lo",
  description="SHARADA LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A4,
 },
 [0x111A5]={
  category="lo",
  description="SHARADA LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A5,
 },
 [0x111A6]={
  category="lo",
  description="SHARADA LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A6,
 },
 [0x111A7]={
  category="lo",
  description="SHARADA LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A7,
 },
 [0x111A8]={
  category="lo",
  description="SHARADA LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A8,
 },
 [0x111A9]={
  category="lo",
  description="SHARADA LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111A9,
 },
 [0x111AA]={
  category="lo",
  description="SHARADA LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111AA,
 },
 [0x111AB]={
  category="lo",
  description="SHARADA LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111AB,
 },
 [0x111AC]={
  category="lo",
  description="SHARADA LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111AC,
 },
 [0x111AD]={
  category="lo",
  description="SHARADA LETTER LLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111AD,
 },
 [0x111AE]={
  category="lo",
  description="SHARADA LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111AE,
 },
 [0x111AF]={
  category="lo",
  description="SHARADA LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111AF,
 },
 [0x111B0]={
  category="lo",
  description="SHARADA LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111B0,
 },
 [0x111B1]={
  category="lo",
  description="SHARADA LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111B1,
 },
 [0x111B2]={
  category="lo",
  description="SHARADA LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111B2,
 },
 [0x111B3]={
  category="mc",
  description="SHARADA VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x111B3,
 },
 [0x111B4]={
  category="mc",
  description="SHARADA VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x111B4,
 },
 [0x111B5]={
  category="mc",
  description="SHARADA VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x111B5,
 },
 [0x111B6]={
  category="mn",
  description="SHARADA VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111B6,
 },
 [0x111B7]={
  category="mn",
  description="SHARADA VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111B7,
 },
 [0x111B8]={
  category="mn",
  description="SHARADA VOWEL SIGN VOCALIC R",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111B8,
 },
 [0x111B9]={
  category="mn",
  description="SHARADA VOWEL SIGN VOCALIC RR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111B9,
 },
 [0x111BA]={
  category="mn",
  description="SHARADA VOWEL SIGN VOCALIC L",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111BA,
 },
 [0x111BB]={
  category="mn",
  description="SHARADA VOWEL SIGN VOCALIC LL",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111BB,
 },
 [0x111BC]={
  category="mn",
  description="SHARADA VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111BC,
 },
 [0x111BD]={
  category="mn",
  description="SHARADA VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111BD,
 },
 [0x111BE]={
  category="mn",
  description="SHARADA VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x111BE,
 },
 [0x111BF]={
  category="mc",
  description="SHARADA VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x111BF,
 },
 [0x111C0]={
  category="mc",
  description="SHARADA SIGN VIRAMA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x111C0,
 },
 [0x111C1]={
  category="lo",
  description="SHARADA SIGN AVAGRAHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111C1,
 },
 [0x111C2]={
  category="lo",
  description="SHARADA SIGN JIHVAMULIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111C2,
 },
 [0x111C3]={
  category="lo",
  description="SHARADA SIGN UPADHMANIYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x111C3,
 },
 [0x111C4]={
  category="lo",
  description="SHARADA OM",
  direction="l",
  linebreak="al",
  unicodeslot=0x111C4,
 },
 [0x111C5]={
  category="po",
  description="SHARADA DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x111C5,
 },
 [0x111C6]={
  category="po",
  description="SHARADA DOUBLE DANDA",
  direction="l",
  linebreak="ba",
  unicodeslot=0x111C6,
 },
 [0x111C7]={
  category="po",
  description="SHARADA ABBREVIATION SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x111C7,
 },
 [0x111C8]={
  category="po",
  description="SHARADA SEPARATOR",
  direction="l",
  linebreak="ba",
  unicodeslot=0x111C8,
 },
 [0x111D0]={
  category="nd",
  description="SHARADA DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D0,
 },
 [0x111D1]={
  category="nd",
  description="SHARADA DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D1,
 },
 [0x111D2]={
  category="nd",
  description="SHARADA DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D2,
 },
 [0x111D3]={
  category="nd",
  description="SHARADA DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D3,
 },
 [0x111D4]={
  category="nd",
  description="SHARADA DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D4,
 },
 [0x111D5]={
  category="nd",
  description="SHARADA DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D5,
 },
 [0x111D6]={
  category="nd",
  description="SHARADA DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D6,
 },
 [0x111D7]={
  category="nd",
  description="SHARADA DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D7,
 },
 [0x111D8]={
  category="nd",
  description="SHARADA DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D8,
 },
 [0x111D9]={
  category="nd",
  description="SHARADA DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x111D9,
 },
 [0x11680]={
  category="lo",
  description="TAKRI LETTER A",
  direction="l",
  linebreak="al",
  unicodeslot=0x11680,
 },
 [0x11681]={
  category="lo",
  description="TAKRI LETTER AA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11681,
 },
 [0x11682]={
  category="lo",
  description="TAKRI LETTER I",
  direction="l",
  linebreak="al",
  unicodeslot=0x11682,
 },
 [0x11683]={
  category="lo",
  description="TAKRI LETTER II",
  direction="l",
  linebreak="al",
  unicodeslot=0x11683,
 },
 [0x11684]={
  category="lo",
  description="TAKRI LETTER U",
  direction="l",
  linebreak="al",
  unicodeslot=0x11684,
 },
 [0x11685]={
  category="lo",
  description="TAKRI LETTER UU",
  direction="l",
  linebreak="al",
  unicodeslot=0x11685,
 },
 [0x11686]={
  category="lo",
  description="TAKRI LETTER E",
  direction="l",
  linebreak="al",
  unicodeslot=0x11686,
 },
 [0x11687]={
  category="lo",
  description="TAKRI LETTER AI",
  direction="l",
  linebreak="al",
  unicodeslot=0x11687,
 },
 [0x11688]={
  category="lo",
  description="TAKRI LETTER O",
  direction="l",
  linebreak="al",
  unicodeslot=0x11688,
 },
 [0x11689]={
  category="lo",
  description="TAKRI LETTER AU",
  direction="l",
  linebreak="al",
  unicodeslot=0x11689,
 },
 [0x1168A]={
  category="lo",
  description="TAKRI LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1168A,
 },
 [0x1168B]={
  category="lo",
  description="TAKRI LETTER KHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1168B,
 },
 [0x1168C]={
  category="lo",
  description="TAKRI LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1168C,
 },
 [0x1168D]={
  category="lo",
  description="TAKRI LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1168D,
 },
 [0x1168E]={
  category="lo",
  description="TAKRI LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1168E,
 },
 [0x1168F]={
  category="lo",
  description="TAKRI LETTER CA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1168F,
 },
 [0x11690]={
  category="lo",
  description="TAKRI LETTER CHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11690,
 },
 [0x11691]={
  category="lo",
  description="TAKRI LETTER JA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11691,
 },
 [0x11692]={
  category="lo",
  description="TAKRI LETTER JHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11692,
 },
 [0x11693]={
  category="lo",
  description="TAKRI LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11693,
 },
 [0x11694]={
  category="lo",
  description="TAKRI LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11694,
 },
 [0x11695]={
  category="lo",
  description="TAKRI LETTER TTHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11695,
 },
 [0x11696]={
  category="lo",
  description="TAKRI LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11696,
 },
 [0x11697]={
  category="lo",
  description="TAKRI LETTER DDHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11697,
 },
 [0x11698]={
  category="lo",
  description="TAKRI LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11698,
 },
 [0x11699]={
  category="lo",
  description="TAKRI LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x11699,
 },
 [0x1169A]={
  category="lo",
  description="TAKRI LETTER THA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1169A,
 },
 [0x1169B]={
  category="lo",
  description="TAKRI LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1169B,
 },
 [0x1169C]={
  category="lo",
  description="TAKRI LETTER DHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1169C,
 },
 [0x1169D]={
  category="lo",
  description="TAKRI LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1169D,
 },
 [0x1169E]={
  category="lo",
  description="TAKRI LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1169E,
 },
 [0x1169F]={
  category="lo",
  description="TAKRI LETTER PHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1169F,
 },
 [0x116A0]={
  category="lo",
  description="TAKRI LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A0,
 },
 [0x116A1]={
  category="lo",
  description="TAKRI LETTER BHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A1,
 },
 [0x116A2]={
  category="lo",
  description="TAKRI LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A2,
 },
 [0x116A3]={
  category="lo",
  description="TAKRI LETTER YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A3,
 },
 [0x116A4]={
  category="lo",
  description="TAKRI LETTER RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A4,
 },
 [0x116A5]={
  category="lo",
  description="TAKRI LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A5,
 },
 [0x116A6]={
  category="lo",
  description="TAKRI LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A6,
 },
 [0x116A7]={
  category="lo",
  description="TAKRI LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A7,
 },
 [0x116A8]={
  category="lo",
  description="TAKRI LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A8,
 },
 [0x116A9]={
  category="lo",
  description="TAKRI LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116A9,
 },
 [0x116AA]={
  category="lo",
  description="TAKRI LETTER RRA",
  direction="l",
  linebreak="al",
  unicodeslot=0x116AA,
 },
 [0x116AB]={
  category="mn",
  description="TAKRI SIGN ANUSVARA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116AB,
 },
 [0x116AC]={
  category="mc",
  description="TAKRI SIGN VISARGA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x116AC,
 },
 [0x116AD]={
  category="mn",
  description="TAKRI VOWEL SIGN AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116AD,
 },
 [0x116AE]={
  category="mc",
  description="TAKRI VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x116AE,
 },
 [0x116AF]={
  category="mc",
  description="TAKRI VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x116AF,
 },
 [0x116B0]={
  category="mn",
  description="TAKRI VOWEL SIGN U",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116B0,
 },
 [0x116B1]={
  category="mn",
  description="TAKRI VOWEL SIGN UU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116B1,
 },
 [0x116B2]={
  category="mn",
  description="TAKRI VOWEL SIGN E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116B2,
 },
 [0x116B3]={
  category="mn",
  description="TAKRI VOWEL SIGN AI",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116B3,
 },
 [0x116B4]={
  category="mn",
  description="TAKRI VOWEL SIGN O",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116B4,
 },
 [0x116B5]={
  category="mn",
  description="TAKRI VOWEL SIGN AU",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116B5,
 },
 [0x116B6]={
  category="mc",
  description="TAKRI SIGN VIRAMA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x116B6,
 },
 [0x116B7]={
  category="mn",
  description="TAKRI SIGN NUKTA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x116B7,
 },
 [0x116C0]={
  category="nd",
  description="TAKRI DIGIT ZERO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C0,
 },
 [0x116C1]={
  category="nd",
  description="TAKRI DIGIT ONE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C1,
 },
 [0x116C2]={
  category="nd",
  description="TAKRI DIGIT TWO",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C2,
 },
 [0x116C3]={
  category="nd",
  description="TAKRI DIGIT THREE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C3,
 },
 [0x116C4]={
  category="nd",
  description="TAKRI DIGIT FOUR",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C4,
 },
 [0x116C5]={
  category="nd",
  description="TAKRI DIGIT FIVE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C5,
 },
 [0x116C6]={
  category="nd",
  description="TAKRI DIGIT SIX",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C6,
 },
 [0x116C7]={
  category="nd",
  description="TAKRI DIGIT SEVEN",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C7,
 },
 [0x116C8]={
  category="nd",
  description="TAKRI DIGIT EIGHT",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C8,
 },
 [0x116C9]={
  category="nd",
  description="TAKRI DIGIT NINE",
  direction="l",
  linebreak="nu",
  unicodeslot=0x116C9,
 },
 [0x12000]={
  category="lo",
  description="CUNEIFORM SIGN A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12000,
 },
 [0x12001]={
  category="lo",
  description="CUNEIFORM SIGN A TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12001,
 },
 [0x12002]={
  category="lo",
  description="CUNEIFORM SIGN A TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12002,
 },
 [0x12003]={
  category="lo",
  description="CUNEIFORM SIGN A TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12003,
 },
 [0x12004]={
  category="lo",
  description="CUNEIFORM SIGN A TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12004,
 },
 [0x12005]={
  category="lo",
  description="CUNEIFORM SIGN A TIMES IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12005,
 },
 [0x12006]={
  category="lo",
  description="CUNEIFORM SIGN A TIMES LAGAR GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12006,
 },
 [0x12007]={
  category="lo",
  description="CUNEIFORM SIGN A TIMES MUSH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12007,
 },
 [0x12008]={
  category="lo",
  description="CUNEIFORM SIGN A TIMES SAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12008,
 },
 [0x12009]={
  category="lo",
  description="CUNEIFORM SIGN A0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12009,
 },
 [0x1200A]={
  category="lo",
  description="CUNEIFORM SIGN AB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1200A,
 },
 [0x1200B]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES ASH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1200B,
 },
 [0x1200C]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES DUN0x0003 GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1200C,
 },
 [0x1200D]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES GAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1200D,
 },
 [0x1200E]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1200E,
 },
 [0x1200F]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1200F,
 },
 [0x12010]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12010,
 },
 [0x12011]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES IMIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12011,
 },
 [0x12012]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES LAGAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12012,
 },
 [0x12013]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES SHESH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12013,
 },
 [0x12014]={
  category="lo",
  description="CUNEIFORM SIGN AB TIMES U PLUS U PLUS U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12014,
 },
 [0x12015]={
  category="lo",
  description="CUNEIFORM SIGN AB GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12015,
 },
 [0x12016]={
  category="lo",
  description="CUNEIFORM SIGN AB0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12016,
 },
 [0x12017]={
  category="lo",
  description="CUNEIFORM SIGN AB0x0002 TIMES BALAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12017,
 },
 [0x12018]={
  category="lo",
  description="CUNEIFORM SIGN AB0x0002 TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12018,
 },
 [0x12019]={
  category="lo",
  description="CUNEIFORM SIGN AB0x0002 TIMES ME PLUS EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12019,
 },
 [0x1201A]={
  category="lo",
  description="CUNEIFORM SIGN AB0x0002 TIMES SHA0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1201A,
 },
 [0x1201B]={
  category="lo",
  description="CUNEIFORM SIGN AB0x0002 TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1201B,
 },
 [0x1201C]={
  category="lo",
  description="CUNEIFORM SIGN AD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1201C,
 },
 [0x1201D]={
  category="lo",
  description="CUNEIFORM SIGN AK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1201D,
 },
 [0x1201E]={
  category="lo",
  description="CUNEIFORM SIGN AK TIMES ERIN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1201E,
 },
 [0x1201F]={
  category="lo",
  description="CUNEIFORM SIGN AK TIMES SHITA PLUS GISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1201F,
 },
 [0x12020]={
  category="lo",
  description="CUNEIFORM SIGN AL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12020,
 },
 [0x12021]={
  category="lo",
  description="CUNEIFORM SIGN AL TIMES AL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12021,
 },
 [0x12022]={
  category="lo",
  description="CUNEIFORM SIGN AL TIMES DIM0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12022,
 },
 [0x12023]={
  category="lo",
  description="CUNEIFORM SIGN AL TIMES GISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12023,
 },
 [0x12024]={
  category="lo",
  description="CUNEIFORM SIGN AL TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12024,
 },
 [0x12025]={
  category="lo",
  description="CUNEIFORM SIGN AL TIMES KAD0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12025,
 },
 [0x12026]={
  category="lo",
  description="CUNEIFORM SIGN AL TIMES KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12026,
 },
 [0x12027]={
  category="lo",
  description="CUNEIFORM SIGN AL TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12027,
 },
 [0x12028]={
  category="lo",
  description="CUNEIFORM SIGN AL TIMES USH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12028,
 },
 [0x12029]={
  category="lo",
  description="CUNEIFORM SIGN ALAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12029,
 },
 [0x1202A]={
  category="lo",
  description="CUNEIFORM SIGN ALEPH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1202A,
 },
 [0x1202B]={
  category="lo",
  description="CUNEIFORM SIGN AMAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1202B,
 },
 [0x1202C]={
  category="lo",
  description="CUNEIFORM SIGN AMAR TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1202C,
 },
 [0x1202D]={
  category="lo",
  description="CUNEIFORM SIGN AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1202D,
 },
 [0x1202E]={
  category="lo",
  description="CUNEIFORM SIGN AN OVER AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1202E,
 },
 [0x1202F]={
  category="lo",
  description="CUNEIFORM SIGN AN THREE TIMES",
  direction="l",
  linebreak="al",
  unicodeslot=0x1202F,
 },
 [0x12030]={
  category="lo",
  description="CUNEIFORM SIGN AN PLUS NAGA OPPOSING AN PLUS NAGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12030,
 },
 [0x12031]={
  category="lo",
  description="CUNEIFORM SIGN AN PLUS NAGA SQUARED",
  direction="l",
  linebreak="al",
  unicodeslot=0x12031,
 },
 [0x12032]={
  category="lo",
  description="CUNEIFORM SIGN ANSHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12032,
 },
 [0x12033]={
  category="lo",
  description="CUNEIFORM SIGN APIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12033,
 },
 [0x12034]={
  category="lo",
  description="CUNEIFORM SIGN ARAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12034,
 },
 [0x12035]={
  category="lo",
  description="CUNEIFORM SIGN ARAD TIMES KUR",
  direction="l",
  linebreak="al",
  mathclass="ordinary",
  mathname="backprime",
  unicodeslot=0x12035,
 },
 [0x12036]={
  category="lo",
  description="CUNEIFORM SIGN ARKAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12036,
 },
 [0x12037]={
  category="lo",
  description="CUNEIFORM SIGN ASAL0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12037,
 },
 [0x12038]={
  category="lo",
  description="CUNEIFORM SIGN ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12038,
 },
 [0x12039]={
  category="lo",
  description="CUNEIFORM SIGN ASH ZIDA TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12039,
 },
 [0x1203A]={
  category="lo",
  description="CUNEIFORM SIGN ASH KABA TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1203A,
 },
 [0x1203B]={
  category="lo",
  description="CUNEIFORM SIGN ASH OVER ASH TUG0x0002 OVER TUG0x0002 TUG0x0002 OVER TUG0x0002 PAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1203B,
 },
 [0x1203C]={
  category="lo",
  description="CUNEIFORM SIGN ASH OVER ASH OVER ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1203C,
 },
 [0x1203D]={
  category="lo",
  description="CUNEIFORM SIGN ASH OVER ASH OVER ASH CROSSING ASH OVER ASH OVER ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1203D,
 },
 [0x1203E]={
  category="lo",
  description="CUNEIFORM SIGN ASH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1203E,
 },
 [0x1203F]={
  category="lo",
  description="CUNEIFORM SIGN ASHGAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1203F,
 },
 [0x12040]={
  category="lo",
  description="CUNEIFORM SIGN BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12040,
 },
 [0x12041]={
  category="lo",
  description="CUNEIFORM SIGN BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12041,
 },
 [0x12042]={
  category="lo",
  description="CUNEIFORM SIGN BAG0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12042,
 },
 [0x12043]={
  category="lo",
  description="CUNEIFORM SIGN BAHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12043,
 },
 [0x12044]={
  category="lo",
  description="CUNEIFORM SIGN BAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12044,
 },
 [0x12045]={
  category="lo",
  description="CUNEIFORM SIGN BAL OVER BAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12045,
 },
 [0x12046]={
  category="lo",
  description="CUNEIFORM SIGN BALAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12046,
 },
 [0x12047]={
  category="lo",
  description="CUNEIFORM SIGN BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12047,
 },
 [0x12048]={
  category="lo",
  description="CUNEIFORM SIGN BARA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12048,
 },
 [0x12049]={
  category="lo",
  description="CUNEIFORM SIGN BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12049,
 },
 [0x1204A]={
  category="lo",
  description="CUNEIFORM SIGN BI TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1204A,
 },
 [0x1204B]={
  category="lo",
  description="CUNEIFORM SIGN BI TIMES GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1204B,
 },
 [0x1204C]={
  category="lo",
  description="CUNEIFORM SIGN BI TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1204C,
 },
 [0x1204D]={
  category="lo",
  description="CUNEIFORM SIGN BU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1204D,
 },
 [0x1204E]={
  category="lo",
  description="CUNEIFORM SIGN BU OVER BU AB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1204E,
 },
 [0x1204F]={
  category="lo",
  description="CUNEIFORM SIGN BU OVER BU UN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1204F,
 },
 [0x12050]={
  category="lo",
  description="CUNEIFORM SIGN BU CROSSING BU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12050,
 },
 [0x12051]={
  category="lo",
  description="CUNEIFORM SIGN BULUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12051,
 },
 [0x12052]={
  category="lo",
  description="CUNEIFORM SIGN BULUG OVER BULUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12052,
 },
 [0x12053]={
  category="lo",
  description="CUNEIFORM SIGN BUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12053,
 },
 [0x12054]={
  category="lo",
  description="CUNEIFORM SIGN BUR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12054,
 },
 [0x12055]={
  category="lo",
  description="CUNEIFORM SIGN DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12055,
 },
 [0x12056]={
  category="lo",
  description="CUNEIFORM SIGN DAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12056,
 },
 [0x12057]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES A PLUS MASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12057,
 },
 [0x12058]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES AMAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12058,
 },
 [0x12059]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES BALAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12059,
 },
 [0x1205A]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1205A,
 },
 [0x1205B]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1205B,
 },
 [0x1205C]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES GA PLUS MASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1205C,
 },
 [0x1205D]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1205D,
 },
 [0x1205E]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES GIR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1205E,
 },
 [0x1205F]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1205F,
 },
 [0x12060]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12060,
 },
 [0x12061]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES IR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12061,
 },
 [0x12062]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES IR PLUS LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12062,
 },
 [0x12063]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES KAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x12063,
 },
 [0x12064]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12064,
 },
 [0x12065]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12065,
 },
 [0x12066]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES LU PLUS MASH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12066,
 },
 [0x12067]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES LUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12067,
 },
 [0x12068]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12068,
 },
 [0x12069]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES PAP PLUS PAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x12069,
 },
 [0x1206A]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES SI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1206A,
 },
 [0x1206B]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1206B,
 },
 [0x1206C]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES U0x0002 PLUS GIR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1206C,
 },
 [0x1206D]={
  category="lo",
  description="CUNEIFORM SIGN DAG KISIM0x0005 TIMES USH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1206D,
 },
 [0x1206E]={
  category="lo",
  description="CUNEIFORM SIGN DAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1206E,
 },
 [0x1206F]={
  category="lo",
  description="CUNEIFORM SIGN DAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1206F,
 },
 [0x12070]={
  category="lo",
  description="CUNEIFORM SIGN DARA0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12070,
 },
 [0x12071]={
  category="lo",
  description="CUNEIFORM SIGN DARA0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12071,
 },
 [0x12072]={
  category="lo",
  description="CUNEIFORM SIGN DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12072,
 },
 [0x12073]={
  category="lo",
  description="CUNEIFORM SIGN DIB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12073,
 },
 [0x12074]={
  category="lo",
  description="CUNEIFORM SIGN DIM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12074,
 },
 [0x12075]={
  category="lo",
  description="CUNEIFORM SIGN DIM TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12075,
 },
 [0x12076]={
  category="lo",
  description="CUNEIFORM SIGN DIM0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12076,
 },
 [0x12077]={
  category="lo",
  description="CUNEIFORM SIGN DIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12077,
 },
 [0x12078]={
  category="lo",
  description="CUNEIFORM SIGN DIN KASKAL U GUNU DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12078,
 },
 [0x12079]={
  category="lo",
  description="CUNEIFORM SIGN DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12079,
 },
 [0x1207A]={
  category="lo",
  description="CUNEIFORM SIGN DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1207A,
 },
 [0x1207B]={
  category="lo",
  description="CUNEIFORM SIGN DU OVER DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1207B,
 },
 [0x1207C]={
  category="lo",
  description="CUNEIFORM SIGN DU GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1207C,
 },
 [0x1207D]={
  category="lo",
  description="CUNEIFORM SIGN DU SHESHIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1207D,
 },
 [0x1207E]={
  category="lo",
  description="CUNEIFORM SIGN DUB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1207E,
 },
 [0x1207F]={
  category="lo",
  description="CUNEIFORM SIGN DUB TIMES ESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1207F,
 },
 [0x12080]={
  category="lo",
  description="CUNEIFORM SIGN DUB0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12080,
 },
 [0x12081]={
  category="lo",
  description="CUNEIFORM SIGN DUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12081,
 },
 [0x12082]={
  category="lo",
  description="CUNEIFORM SIGN DUGUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12082,
 },
 [0x12083]={
  category="lo",
  description="CUNEIFORM SIGN DUH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12083,
 },
 [0x12084]={
  category="lo",
  description="CUNEIFORM SIGN DUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12084,
 },
 [0x12085]={
  category="lo",
  description="CUNEIFORM SIGN DUN0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12085,
 },
 [0x12086]={
  category="lo",
  description="CUNEIFORM SIGN DUN0x0003 GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12086,
 },
 [0x12087]={
  category="lo",
  description="CUNEIFORM SIGN DUN0x0003 GUNU GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12087,
 },
 [0x12088]={
  category="lo",
  description="CUNEIFORM SIGN DUN0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12088,
 },
 [0x12089]={
  category="lo",
  description="CUNEIFORM SIGN DUR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12089,
 },
 [0x1208A]={
  category="lo",
  description="CUNEIFORM SIGN E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1208A,
 },
 [0x1208B]={
  category="lo",
  description="CUNEIFORM SIGN E TIMES PAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1208B,
 },
 [0x1208C]={
  category="lo",
  description="CUNEIFORM SIGN E OVER E NUN OVER NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1208C,
 },
 [0x1208D]={
  category="lo",
  description="CUNEIFORM SIGN E0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1208D,
 },
 [0x1208E]={
  category="lo",
  description="CUNEIFORM SIGN E0x0002 TIMES A PLUS HA PLUS DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1208E,
 },
 [0x1208F]={
  category="lo",
  description="CUNEIFORM SIGN E0x0002 TIMES GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1208F,
 },
 [0x12090]={
  category="lo",
  description="CUNEIFORM SIGN E0x0002 TIMES MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12090,
 },
 [0x12091]={
  category="lo",
  description="CUNEIFORM SIGN E0x0002 TIMES SAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12091,
 },
 [0x12092]={
  category="lo",
  description="CUNEIFORM SIGN E0x0002 TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12092,
 },
 [0x12093]={
  category="lo",
  description="CUNEIFORM SIGN E0x0002 TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12093,
 },
 [0x12094]={
  category="lo",
  description="CUNEIFORM SIGN EDIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12094,
 },
 [0x12095]={
  category="lo",
  description="CUNEIFORM SIGN EGIR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12095,
 },
 [0x12096]={
  category="lo",
  description="CUNEIFORM SIGN EL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12096,
 },
 [0x12097]={
  category="lo",
  description="CUNEIFORM SIGN EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12097,
 },
 [0x12098]={
  category="lo",
  description="CUNEIFORM SIGN EN TIMES GAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12098,
 },
 [0x12099]={
  category="lo",
  description="CUNEIFORM SIGN EN TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12099,
 },
 [0x1209A]={
  category="lo",
  description="CUNEIFORM SIGN EN TIMES ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x1209A,
 },
 [0x1209B]={
  category="lo",
  description="CUNEIFORM SIGN EN CROSSING EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1209B,
 },
 [0x1209C]={
  category="lo",
  description="CUNEIFORM SIGN EN OPPOSING EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1209C,
 },
 [0x1209D]={
  category="lo",
  description="CUNEIFORM SIGN EN SQUARED",
  direction="l",
  linebreak="al",
  unicodeslot=0x1209D,
 },
 [0x1209E]={
  category="lo",
  description="CUNEIFORM SIGN EREN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1209E,
 },
 [0x1209F]={
  category="lo",
  description="CUNEIFORM SIGN ERIN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1209F,
 },
 [0x120A0]={
  category="lo",
  description="CUNEIFORM SIGN ESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A0,
 },
 [0x120A1]={
  category="lo",
  description="CUNEIFORM SIGN EZEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A1,
 },
 [0x120A2]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A2,
 },
 [0x120A3]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES A PLUS LAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A3,
 },
 [0x120A4]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES A PLUS LAL TIMES LAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A4,
 },
 [0x120A5]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A5,
 },
 [0x120A6]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A6,
 },
 [0x120A7]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES DUN0x0003 GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A7,
 },
 [0x120A8]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES DUN0x0003 GUNU GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A8,
 },
 [0x120A9]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120A9,
 },
 [0x120AA]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES HA GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120AA,
 },
 [0x120AB]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120AB,
 },
 [0x120AC]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES KASKAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120AC,
 },
 [0x120AD]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES KASKAL SQUARED",
  direction="l",
  linebreak="al",
  unicodeslot=0x120AD,
 },
 [0x120AE]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES KU0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x120AE,
 },
 [0x120AF]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120AF,
 },
 [0x120B0]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES LAL TIMES LAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B0,
 },
 [0x120B1]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B1,
 },
 [0x120B2]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B2,
 },
 [0x120B3]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES U0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B3,
 },
 [0x120B4]={
  category="lo",
  description="CUNEIFORM SIGN EZEN TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B4,
 },
 [0x120B5]={
  category="lo",
  description="CUNEIFORM SIGN GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B5,
 },
 [0x120B6]={
  category="lo",
  description="CUNEIFORM SIGN GA GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B6,
 },
 [0x120B7]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B7,
 },
 [0x120B8]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES A PLUS DA PLUS HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B8,
 },
 [0x120B9]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES A PLUS HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120B9,
 },
 [0x120BA]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES A PLUS IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x120BA,
 },
 [0x120BB]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES AB0x0002 TENU PLUS TAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x120BB,
 },
 [0x120BC]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120BC,
 },
 [0x120BD]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x120BD,
 },
 [0x120BE]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES ASH0x0002 PLUS GAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120BE,
 },
 [0x120BF]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x120BF,
 },
 [0x120C0]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES BAR PLUS RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C0,
 },
 [0x120C1]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES BUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C1,
 },
 [0x120C2]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES BUR PLUS RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C2,
 },
 [0x120C3]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C3,
 },
 [0x120C4]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C4,
 },
 [0x120C5]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES DIM TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C5,
 },
 [0x120C6]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES DUB",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C6,
 },
 [0x120C7]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES EL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C7,
 },
 [0x120C8]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES EL PLUS LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C8,
 },
 [0x120C9]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120C9,
 },
 [0x120CA]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES EN TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120CA,
 },
 [0x120CB]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120CB,
 },
 [0x120CC]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x120CC,
 },
 [0x120CD]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x120CD,
 },
 [0x120CE]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES GI0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x120CE,
 },
 [0x120CF]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES GI0x0004 PLUS A",
  direction="l",
  linebreak="al",
  unicodeslot=0x120CF,
 },
 [0x120D0]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES GIR0x0002 PLUS SU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D0,
 },
 [0x120D1]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES HA PLUS LU PLUS ESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D1,
 },
 [0x120D2]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES HAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D2,
 },
 [0x120D3]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES HAL PLUS LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D3,
 },
 [0x120D4]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES HI PLUS LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D4,
 },
 [0x120D5]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES HUB0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D5,
 },
 [0x120D6]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D6,
 },
 [0x120D7]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES ISH PLUS HU PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D7,
 },
 [0x120D8]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES KAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D8,
 },
 [0x120D9]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES KASKAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120D9,
 },
 [0x120DA]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES KID",
  direction="l",
  linebreak="al",
  unicodeslot=0x120DA,
 },
 [0x120DB]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES KID PLUS LAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120DB,
 },
 [0x120DC]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES KU0x0003 PLUS AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120DC,
 },
 [0x120DD]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120DD,
 },
 [0x120DE]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES ME PLUS EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120DE,
 },
 [0x120DF]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x120DF,
 },
 [0x120E0]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E0,
 },
 [0x120E1]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES NUN OVER NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E1,
 },
 [0x120E2]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E2,
 },
 [0x120E3]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES SAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E3,
 },
 [0x120E4]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES SAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E4,
 },
 [0x120E5]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E5,
 },
 [0x120E6]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES SHE PLUS TUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E6,
 },
 [0x120E7]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES SHID",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E7,
 },
 [0x120E8]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES SUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E8,
 },
 [0x120E9]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x120E9,
 },
 [0x120EA]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x120EA,
 },
 [0x120EB]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x120EB,
 },
 [0x120EC]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 TIMES UD PLUS DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120EC,
 },
 [0x120ED]={
  category="lo",
  description="CUNEIFORM SIGN GA0x0002 OVER GA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120ED,
 },
 [0x120EE]={
  category="lo",
  description="CUNEIFORM SIGN GABA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120EE,
 },
 [0x120EF]={
  category="lo",
  description="CUNEIFORM SIGN GABA CROSSING GABA",
  direction="l",
  linebreak="al",
  unicodeslot=0x120EF,
 },
 [0x120F0]={
  category="lo",
  description="CUNEIFORM SIGN GAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F0,
 },
 [0x120F1]={
  category="lo",
  description="CUNEIFORM SIGN GAD OVER GAD GAR OVER GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F1,
 },
 [0x120F2]={
  category="lo",
  description="CUNEIFORM SIGN GAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F2,
 },
 [0x120F3]={
  category="lo",
  description="CUNEIFORM SIGN GAL GAD OVER GAD GAR OVER GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F3,
 },
 [0x120F4]={
  category="lo",
  description="CUNEIFORM SIGN GALAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F4,
 },
 [0x120F5]={
  category="lo",
  description="CUNEIFORM SIGN GAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F5,
 },
 [0x120F6]={
  category="lo",
  description="CUNEIFORM SIGN GAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F6,
 },
 [0x120F7]={
  category="lo",
  description="CUNEIFORM SIGN GAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F7,
 },
 [0x120F8]={
  category="lo",
  description="CUNEIFORM SIGN GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F8,
 },
 [0x120F9]={
  category="lo",
  description="CUNEIFORM SIGN GAN0x0002 OVER GAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120F9,
 },
 [0x120FA]={
  category="lo",
  description="CUNEIFORM SIGN GAN0x0002 CROSSING GAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x120FA,
 },
 [0x120FB]={
  category="lo",
  description="CUNEIFORM SIGN GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x120FB,
 },
 [0x120FC]={
  category="lo",
  description="CUNEIFORM SIGN GAR0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x120FC,
 },
 [0x120FD]={
  category="lo",
  description="CUNEIFORM SIGN GASHAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120FD,
 },
 [0x120FE]={
  category="lo",
  description="CUNEIFORM SIGN GESHTIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x120FE,
 },
 [0x120FF]={
  category="lo",
  description="CUNEIFORM SIGN GESHTIN TIMES KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x120FF,
 },
 [0x12100]={
  category="lo",
  description="CUNEIFORM SIGN GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12100,
 },
 [0x12101]={
  category="lo",
  description="CUNEIFORM SIGN GI TIMES E",
  direction="l",
  linebreak="al",
  unicodeslot=0x12101,
 },
 [0x12102]={
  category="lo",
  description="CUNEIFORM SIGN GI TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12102,
 },
 [0x12103]={
  category="lo",
  description="CUNEIFORM SIGN GI CROSSING GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12103,
 },
 [0x12104]={
  category="lo",
  description="CUNEIFORM SIGN GI0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12104,
 },
 [0x12105]={
  category="lo",
  description="CUNEIFORM SIGN GI0x0004 OVER GI0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12105,
 },
 [0x12106]={
  category="lo",
  description="CUNEIFORM SIGN GI0x0004 CROSSING GI0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12106,
 },
 [0x12107]={
  category="lo",
  description="CUNEIFORM SIGN GIDIM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12107,
 },
 [0x12108]={
  category="lo",
  description="CUNEIFORM SIGN GIR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12108,
 },
 [0x12109]={
  category="lo",
  description="CUNEIFORM SIGN GIR0x0002 GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12109,
 },
 [0x1210A]={
  category="lo",
  description="CUNEIFORM SIGN GIR0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1210A,
 },
 [0x1210B]={
  category="lo",
  description="CUNEIFORM SIGN GIR0x0003 TIMES A PLUS IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1210B,
 },
 [0x1210C]={
  category="lo",
  description="CUNEIFORM SIGN GIR0x0003 TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1210C,
 },
 [0x1210D]={
  category="lo",
  description="CUNEIFORM SIGN GIR0x0003 TIMES IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1210D,
 },
 [0x1210E]={
  category="lo",
  description="CUNEIFORM SIGN GIR0x0003 TIMES LU PLUS IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1210E,
 },
 [0x1210F]={
  category="lo",
  description="CUNEIFORM SIGN GIR0x0003 TIMES PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1210F,
 },
 [0x12110]={
  category="lo",
  description="CUNEIFORM SIGN GISAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12110,
 },
 [0x12111]={
  category="lo",
  description="CUNEIFORM SIGN GISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12111,
 },
 [0x12112]={
  category="lo",
  description="CUNEIFORM SIGN GISH CROSSING GISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12112,
 },
 [0x12113]={
  category="lo",
  description="CUNEIFORM SIGN GISH TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12113,
 },
 [0x12114]={
  category="lo",
  description="CUNEIFORM SIGN GISH TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12114,
 },
 [0x12115]={
  category="lo",
  description="CUNEIFORM SIGN GISH TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12115,
 },
 [0x12116]={
  category="lo",
  description="CUNEIFORM SIGN GU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12116,
 },
 [0x12117]={
  category="lo",
  description="CUNEIFORM SIGN GU CROSSING GU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12117,
 },
 [0x12118]={
  category="lo",
  description="CUNEIFORM SIGN GU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12118,
 },
 [0x12119]={
  category="lo",
  description="CUNEIFORM SIGN GU0x0002 TIMES KAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x12119,
 },
 [0x1211A]={
  category="lo",
  description="CUNEIFORM SIGN GU0x0002 TIMES KAK TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1211A,
 },
 [0x1211B]={
  category="lo",
  description="CUNEIFORM SIGN GU0x0002 TIMES NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1211B,
 },
 [0x1211C]={
  category="lo",
  description="CUNEIFORM SIGN GU0x0002 TIMES SAL PLUS TUG0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1211C,
 },
 [0x1211D]={
  category="lo",
  description="CUNEIFORM SIGN GU0x0002 GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1211D,
 },
 [0x1211E]={
  category="lo",
  description="CUNEIFORM SIGN GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1211E,
 },
 [0x1211F]={
  category="lo",
  description="CUNEIFORM SIGN GUD TIMES A PLUS KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1211F,
 },
 [0x12120]={
  category="lo",
  description="CUNEIFORM SIGN GUD TIMES KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12120,
 },
 [0x12121]={
  category="lo",
  description="CUNEIFORM SIGN GUD OVER GUD LUGAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12121,
 },
 [0x12122]={
  category="lo",
  description="CUNEIFORM SIGN GUL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12122,
 },
 [0x12123]={
  category="lo",
  description="CUNEIFORM SIGN GUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12123,
 },
 [0x12124]={
  category="lo",
  description="CUNEIFORM SIGN GUM TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12124,
 },
 [0x12125]={
  category="lo",
  description="CUNEIFORM SIGN GUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12125,
 },
 [0x12126]={
  category="lo",
  description="CUNEIFORM SIGN GUR0x0007",
  direction="l",
  linebreak="al",
  unicodeslot=0x12126,
 },
 [0x12127]={
  category="lo",
  description="CUNEIFORM SIGN GURUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12127,
 },
 [0x12128]={
  category="lo",
  description="CUNEIFORM SIGN GURUSH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12128,
 },
 [0x12129]={
  category="lo",
  description="CUNEIFORM SIGN HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12129,
 },
 [0x1212A]={
  category="lo",
  description="CUNEIFORM SIGN HA TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1212A,
 },
 [0x1212B]={
  category="lo",
  description="CUNEIFORM SIGN HA GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1212B,
 },
 [0x1212C]={
  category="lo",
  description="CUNEIFORM SIGN HAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1212C,
 },
 [0x1212D]={
  category="lo",
  description="CUNEIFORM SIGN HI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1212D,
 },
 [0x1212E]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1212E,
 },
 [0x1212F]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES ASH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1212F,
 },
 [0x12130]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12130,
 },
 [0x12131]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12131,
 },
 [0x12132]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES GAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12132,
 },
 [0x12133]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES KIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12133,
 },
 [0x12134]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12134,
 },
 [0x12135]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12135,
 },
 [0x12136]={
  category="lo",
  description="CUNEIFORM SIGN HI TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12136,
 },
 [0x12137]={
  category="lo",
  description="CUNEIFORM SIGN HU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12137,
 },
 [0x12138]={
  category="lo",
  description="CUNEIFORM SIGN HUB0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12138,
 },
 [0x12139]={
  category="lo",
  description="CUNEIFORM SIGN HUB0x0002 TIMES AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12139,
 },
 [0x1213A]={
  category="lo",
  description="CUNEIFORM SIGN HUB0x0002 TIMES HAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1213A,
 },
 [0x1213B]={
  category="lo",
  description="CUNEIFORM SIGN HUB0x0002 TIMES KASKAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1213B,
 },
 [0x1213C]={
  category="lo",
  description="CUNEIFORM SIGN HUB0x0002 TIMES LISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1213C,
 },
 [0x1213D]={
  category="lo",
  description="CUNEIFORM SIGN HUB0x0002 TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1213D,
 },
 [0x1213E]={
  category="lo",
  description="CUNEIFORM SIGN HUL0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1213E,
 },
 [0x1213F]={
  category="lo",
  description="CUNEIFORM SIGN I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1213F,
 },
 [0x12140]={
  category="lo",
  description="CUNEIFORM SIGN I A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12140,
 },
 [0x12141]={
  category="lo",
  description="CUNEIFORM SIGN IB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12141,
 },
 [0x12142]={
  category="lo",
  description="CUNEIFORM SIGN IDIM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12142,
 },
 [0x12143]={
  category="lo",
  description="CUNEIFORM SIGN IDIM OVER IDIM BUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12143,
 },
 [0x12144]={
  category="lo",
  description="CUNEIFORM SIGN IDIM OVER IDIM SQUARED",
  direction="l",
  linebreak="al",
  unicodeslot=0x12144,
 },
 [0x12145]={
  category="lo",
  description="CUNEIFORM SIGN IG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12145,
 },
 [0x12146]={
  category="lo",
  description="CUNEIFORM SIGN IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12146,
 },
 [0x12147]={
  category="lo",
  description="CUNEIFORM SIGN IGI DIB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12147,
 },
 [0x12148]={
  category="lo",
  description="CUNEIFORM SIGN IGI RI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12148,
 },
 [0x12149]={
  category="lo",
  description="CUNEIFORM SIGN IGI OVER IGI SHIR OVER SHIR UD OVER UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12149,
 },
 [0x1214A]={
  category="lo",
  description="CUNEIFORM SIGN IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1214A,
 },
 [0x1214B]={
  category="lo",
  description="CUNEIFORM SIGN IL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1214B,
 },
 [0x1214C]={
  category="lo",
  description="CUNEIFORM SIGN IL TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1214C,
 },
 [0x1214D]={
  category="lo",
  description="CUNEIFORM SIGN IL0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1214D,
 },
 [0x1214E]={
  category="lo",
  description="CUNEIFORM SIGN IM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1214E,
 },
 [0x1214F]={
  category="lo",
  description="CUNEIFORM SIGN IM TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1214F,
 },
 [0x12150]={
  category="lo",
  description="CUNEIFORM SIGN IM CROSSING IM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12150,
 },
 [0x12151]={
  category="lo",
  description="CUNEIFORM SIGN IM OPPOSING IM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12151,
 },
 [0x12152]={
  category="lo",
  description="CUNEIFORM SIGN IM SQUARED",
  direction="l",
  linebreak="al",
  unicodeslot=0x12152,
 },
 [0x12153]={
  category="lo",
  description="CUNEIFORM SIGN IMIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12153,
 },
 [0x12154]={
  category="lo",
  description="CUNEIFORM SIGN IN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12154,
 },
 [0x12155]={
  category="lo",
  description="CUNEIFORM SIGN IR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12155,
 },
 [0x12156]={
  category="lo",
  description="CUNEIFORM SIGN ISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12156,
 },
 [0x12157]={
  category="lo",
  description="CUNEIFORM SIGN KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12157,
 },
 [0x12158]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12158,
 },
 [0x12159]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES AD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12159,
 },
 [0x1215A]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES AD PLUS KU0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1215A,
 },
 [0x1215B]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES ASH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1215B,
 },
 [0x1215C]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1215C,
 },
 [0x1215D]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES BALAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1215D,
 },
 [0x1215E]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1215E,
 },
 [0x1215F]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1215F,
 },
 [0x12160]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES ERIN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12160,
 },
 [0x12161]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES ESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12161,
 },
 [0x12162]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12162,
 },
 [0x12163]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12163,
 },
 [0x12164]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12164,
 },
 [0x12165]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12165,
 },
 [0x12166]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GAR PLUS SHA0x0003 PLUS A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12166,
 },
 [0x12167]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12167,
 },
 [0x12168]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GIR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12168,
 },
 [0x12169]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GISH PLUS SAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12169,
 },
 [0x1216A]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GISH CROSSING GISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1216A,
 },
 [0x1216B]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1216B,
 },
 [0x1216C]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES GUR0x0007",
  direction="l",
  linebreak="al",
  unicodeslot=0x1216C,
 },
 [0x1216D]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1216D,
 },
 [0x1216E]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES IM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1216E,
 },
 [0x1216F]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES KAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1216F,
 },
 [0x12170]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12170,
 },
 [0x12171]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES KID",
  direction="l",
  linebreak="al",
  unicodeslot=0x12171,
 },
 [0x12172]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12172,
 },
 [0x12173]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12173,
 },
 [0x12174]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x12174,
 },
 [0x12175]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES ME PLUS DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12175,
 },
 [0x12176]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES ME PLUS GI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12176,
 },
 [0x12177]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES ME PLUS TE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12177,
 },
 [0x12178]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12178,
 },
 [0x12179]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES MI PLUS NUNUZ",
  direction="l",
  linebreak="al",
  unicodeslot=0x12179,
 },
 [0x1217A]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1217A,
 },
 [0x1217B]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1217B,
 },
 [0x1217C]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1217C,
 },
 [0x1217D]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1217D,
 },
 [0x1217E]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1217E,
 },
 [0x1217F]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES SAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1217F,
 },
 [0x12180]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12180,
 },
 [0x12181]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12181,
 },
 [0x12182]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES SHID",
  direction="l",
  linebreak="al",
  unicodeslot=0x12182,
 },
 [0x12183]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12183,
 },
 [0x12184]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES SIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12184,
 },
 [0x12185]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES SUHUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12185,
 },
 [0x12186]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES TAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12186,
 },
 [0x12187]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12187,
 },
 [0x12188]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES U0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12188,
 },
 [0x12189]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12189,
 },
 [0x1218A]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES UMUM TIMES PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1218A,
 },
 [0x1218B]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES USH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1218B,
 },
 [0x1218C]={
  category="lo",
  description="CUNEIFORM SIGN KA TIMES ZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1218C,
 },
 [0x1218D]={
  category="lo",
  description="CUNEIFORM SIGN KA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1218D,
 },
 [0x1218E]={
  category="lo",
  description="CUNEIFORM SIGN KA0x0002 CROSSING KA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1218E,
 },
 [0x1218F]={
  category="lo",
  description="CUNEIFORM SIGN KAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1218F,
 },
 [0x12190]={
  category="lo",
  description="CUNEIFORM SIGN KAD0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12190,
 },
 [0x12191]={
  category="lo",
  description="CUNEIFORM SIGN KAD0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12191,
 },
 [0x12192]={
  category="lo",
  description="CUNEIFORM SIGN KAD0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12192,
 },
 [0x12193]={
  category="lo",
  description="CUNEIFORM SIGN KAD0x0005",
  direction="l",
  linebreak="al",
  unicodeslot=0x12193,
 },
 [0x12194]={
  category="lo",
  description="CUNEIFORM SIGN KAD0x0005 OVER KAD0x0005",
  direction="l",
  linebreak="al",
  unicodeslot=0x12194,
 },
 [0x12195]={
  category="lo",
  description="CUNEIFORM SIGN KAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x12195,
 },
 [0x12196]={
  category="lo",
  description="CUNEIFORM SIGN KAK TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12196,
 },
 [0x12197]={
  category="lo",
  description="CUNEIFORM SIGN KAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12197,
 },
 [0x12198]={
  category="lo",
  description="CUNEIFORM SIGN KAL TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12198,
 },
 [0x12199]={
  category="lo",
  description="CUNEIFORM SIGN KAL CROSSING KAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12199,
 },
 [0x1219A]={
  category="lo",
  description="CUNEIFORM SIGN KAM0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1219A,
 },
 [0x1219B]={
  category="lo",
  description="CUNEIFORM SIGN KAM0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1219B,
 },
 [0x1219C]={
  category="lo",
  description="CUNEIFORM SIGN KASKAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1219C,
 },
 [0x1219D]={
  category="lo",
  description="CUNEIFORM SIGN KASKAL LAGAB TIMES U OVER LAGAB TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1219D,
 },
 [0x1219E]={
  category="lo",
  description="CUNEIFORM SIGN KASKAL OVER KASKAL LAGAB TIMES U OVER LAGAB TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1219E,
 },
 [0x1219F]={
  category="lo",
  description="CUNEIFORM SIGN KESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1219F,
 },
 [0x121A0]={
  category="lo",
  description="CUNEIFORM SIGN KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A0,
 },
 [0x121A1]={
  category="lo",
  description="CUNEIFORM SIGN KI TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A1,
 },
 [0x121A2]={
  category="lo",
  description="CUNEIFORM SIGN KI TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A2,
 },
 [0x121A3]={
  category="lo",
  description="CUNEIFORM SIGN KI TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A3,
 },
 [0x121A4]={
  category="lo",
  description="CUNEIFORM SIGN KID",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A4,
 },
 [0x121A5]={
  category="lo",
  description="CUNEIFORM SIGN KIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A5,
 },
 [0x121A6]={
  category="lo",
  description="CUNEIFORM SIGN KISAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A6,
 },
 [0x121A7]={
  category="lo",
  description="CUNEIFORM SIGN KISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A7,
 },
 [0x121A8]={
  category="lo",
  description="CUNEIFORM SIGN KISIM0x0005",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A8,
 },
 [0x121A9]={
  category="lo",
  description="CUNEIFORM SIGN KISIM0x0005 OVER KISIM0x0005",
  direction="l",
  linebreak="al",
  unicodeslot=0x121A9,
 },
 [0x121AA]={
  category="lo",
  description="CUNEIFORM SIGN KU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121AA,
 },
 [0x121AB]={
  category="lo",
  description="CUNEIFORM SIGN KU OVER HI TIMES ASH0x0002 KU OVER HI TIMES ASH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x121AB,
 },
 [0x121AC]={
  category="lo",
  description="CUNEIFORM SIGN KU0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x121AC,
 },
 [0x121AD]={
  category="lo",
  description="CUNEIFORM SIGN KU0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x121AD,
 },
 [0x121AE]={
  category="lo",
  description="CUNEIFORM SIGN KU0x0004 VARIANT FORM",
  direction="l",
  linebreak="al",
  unicodeslot=0x121AE,
 },
 [0x121AF]={
  category="lo",
  description="CUNEIFORM SIGN KU0x0007",
  direction="l",
  linebreak="al",
  unicodeslot=0x121AF,
 },
 [0x121B0]={
  category="lo",
  description="CUNEIFORM SIGN KUL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B0,
 },
 [0x121B1]={
  category="lo",
  description="CUNEIFORM SIGN KUL GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B1,
 },
 [0x121B2]={
  category="lo",
  description="CUNEIFORM SIGN KUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B2,
 },
 [0x121B3]={
  category="lo",
  description="CUNEIFORM SIGN KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B3,
 },
 [0x121B4]={
  category="lo",
  description="CUNEIFORM SIGN KUR OPPOSING KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B4,
 },
 [0x121B5]={
  category="lo",
  description="CUNEIFORM SIGN KUSHU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B5,
 },
 [0x121B6]={
  category="lo",
  description="CUNEIFORM SIGN KWU0x013E",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B6,
 },
 [0x121B7]={
  category="lo",
  description="CUNEIFORM SIGN LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B7,
 },
 [0x121B8]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B8,
 },
 [0x121B9]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x121B9,
 },
 [0x121BA]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES A PLUS DA PLUS HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x121BA,
 },
 [0x121BB]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES A PLUS GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x121BB,
 },
 [0x121BC]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES A PLUS LAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121BC,
 },
 [0x121BD]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES AL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121BD,
 },
 [0x121BE]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x121BE,
 },
 [0x121BF]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES ASH ZIDA TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121BF,
 },
 [0x121C0]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C0,
 },
 [0x121C1]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C1,
 },
 [0x121C2]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES DAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C2,
 },
 [0x121C3]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C3,
 },
 [0x121C4]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C4,
 },
 [0x121C5]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C5,
 },
 [0x121C6]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C6,
 },
 [0x121C7]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES GUD PLUS GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C7,
 },
 [0x121C8]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C8,
 },
 [0x121C9]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES HAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121C9,
 },
 [0x121CA]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES HI TIMES NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x121CA,
 },
 [0x121CB]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121CB,
 },
 [0x121CC]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES IM",
  direction="l",
  linebreak="al",
  unicodeslot=0x121CC,
 },
 [0x121CD]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES IM PLUS HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x121CD,
 },
 [0x121CE]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES IM PLUS LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121CE,
 },
 [0x121CF]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x121CF,
 },
 [0x121D0]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES KIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D0,
 },
 [0x121D1]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES KU0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D1,
 },
 [0x121D2]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES KUL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D2,
 },
 [0x121D3]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES KUL PLUS HI PLUS A",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D3,
 },
 [0x121D4]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES LAGAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D4,
 },
 [0x121D5]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES LISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D5,
 },
 [0x121D6]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D6,
 },
 [0x121D7]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES LUL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D7,
 },
 [0x121D8]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D8,
 },
 [0x121D9]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES ME PLUS EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x121D9,
 },
 [0x121DA]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES MUSH",
  direction="l",
  linebreak="al",
  unicodeslot=0x121DA,
 },
 [0x121DB]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x121DB,
 },
 [0x121DC]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES SHE PLUS SUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x121DC,
 },
 [0x121DD]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH PLUS ERIN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x121DD,
 },
 [0x121DE]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121DE,
 },
 [0x121DF]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES SHU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x121DF,
 },
 [0x121E0]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES SHU0x0002 PLUS SHU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E0,
 },
 [0x121E1]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES SUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E1,
 },
 [0x121E2]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES TAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E2,
 },
 [0x121E3]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E3,
 },
 [0x121E4]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES TE PLUS A PLUS SU PLUS NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E4,
 },
 [0x121E5]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E5,
 },
 [0x121E6]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES U PLUS A",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E6,
 },
 [0x121E7]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES U PLUS U PLUS U",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E7,
 },
 [0x121E8]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES U0x0002 PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E8,
 },
 [0x121E9]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x121E9,
 },
 [0x121EA]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB TIMES USH",
  direction="l",
  linebreak="al",
  unicodeslot=0x121EA,
 },
 [0x121EB]={
  category="lo",
  description="CUNEIFORM SIGN LAGAB SQUARED",
  direction="l",
  linebreak="al",
  unicodeslot=0x121EB,
 },
 [0x121EC]={
  category="lo",
  description="CUNEIFORM SIGN LAGAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x121EC,
 },
 [0x121ED]={
  category="lo",
  description="CUNEIFORM SIGN LAGAR TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x121ED,
 },
 [0x121EE]={
  category="lo",
  description="CUNEIFORM SIGN LAGAR TIMES SHE PLUS SUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x121EE,
 },
 [0x121EF]={
  category="lo",
  description="CUNEIFORM SIGN LAGAR GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121EF,
 },
 [0x121F0]={
  category="lo",
  description="CUNEIFORM SIGN LAGAR GUNU OVER LAGAR GUNU SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F0,
 },
 [0x121F1]={
  category="lo",
  description="CUNEIFORM SIGN LAHSHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F1,
 },
 [0x121F2]={
  category="lo",
  description="CUNEIFORM SIGN LAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F2,
 },
 [0x121F3]={
  category="lo",
  description="CUNEIFORM SIGN LAL TIMES LAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F3,
 },
 [0x121F4]={
  category="lo",
  description="CUNEIFORM SIGN LAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F4,
 },
 [0x121F5]={
  category="lo",
  description="CUNEIFORM SIGN LAM TIMES KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F5,
 },
 [0x121F6]={
  category="lo",
  description="CUNEIFORM SIGN LAM TIMES KUR PLUS RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F6,
 },
 [0x121F7]={
  category="lo",
  description="CUNEIFORM SIGN LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F7,
 },
 [0x121F8]={
  category="lo",
  description="CUNEIFORM SIGN LIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F8,
 },
 [0x121F9]={
  category="lo",
  description="CUNEIFORM SIGN LIMMU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x121F9,
 },
 [0x121FA]={
  category="lo",
  description="CUNEIFORM SIGN LISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x121FA,
 },
 [0x121FB]={
  category="lo",
  description="CUNEIFORM SIGN LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x121FB,
 },
 [0x121FC]={
  category="lo",
  description="CUNEIFORM SIGN LU TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x121FC,
 },
 [0x121FD]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x121FD,
 },
 [0x121FE]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES AL",
  direction="l",
  linebreak="al",
  unicodeslot=0x121FE,
 },
 [0x121FF]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x121FF,
 },
 [0x12200]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES ESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12200,
 },
 [0x12201]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES ESH0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12201,
 },
 [0x12202]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12202,
 },
 [0x12203]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES HI TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12203,
 },
 [0x12204]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES IM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12204,
 },
 [0x12205]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES KAD0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12205,
 },
 [0x12206]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES KAD0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12206,
 },
 [0x12207]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES KAD0x0003 PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12207,
 },
 [0x12208]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12208,
 },
 [0x12209]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES LA PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12209,
 },
 [0x1220A]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES LAGAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1220A,
 },
 [0x1220B]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES ME PLUS EN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1220B,
 },
 [0x1220C]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1220C,
 },
 [0x1220D]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1220D,
 },
 [0x1220E]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES SI PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1220E,
 },
 [0x1220F]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES SIK0x0002 PLUS BU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1220F,
 },
 [0x12210]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TIMES TUG0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12210,
 },
 [0x12211]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12211,
 },
 [0x12212]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 CROSSING LU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12212,
 },
 [0x12213]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 OPPOSING LU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12213,
 },
 [0x12214]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 SQUARED",
  direction="l",
  linebreak="al",
  unicodeslot=0x12214,
 },
 [0x12215]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0002 SHESHIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12215,
 },
 [0x12216]={
  category="lo",
  description="CUNEIFORM SIGN LU0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12216,
 },
 [0x12217]={
  category="lo",
  description="CUNEIFORM SIGN LUGAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12217,
 },
 [0x12218]={
  category="lo",
  description="CUNEIFORM SIGN LUGAL OVER LUGAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12218,
 },
 [0x12219]={
  category="lo",
  description="CUNEIFORM SIGN LUGAL OPPOSING LUGAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12219,
 },
 [0x1221A]={
  category="lo",
  description="CUNEIFORM SIGN LUGAL SHESHIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1221A,
 },
 [0x1221B]={
  category="lo",
  description="CUNEIFORM SIGN LUH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1221B,
 },
 [0x1221C]={
  category="lo",
  description="CUNEIFORM SIGN LUL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1221C,
 },
 [0x1221D]={
  category="lo",
  description="CUNEIFORM SIGN LUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1221D,
 },
 [0x1221E]={
  category="lo",
  description="CUNEIFORM SIGN LUM OVER LUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1221E,
 },
 [0x1221F]={
  category="lo",
  description="CUNEIFORM SIGN LUM OVER LUM GAR OVER GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1221F,
 },
 [0x12220]={
  category="lo",
  description="CUNEIFORM SIGN MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12220,
 },
 [0x12221]={
  category="lo",
  description="CUNEIFORM SIGN MA TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12221,
 },
 [0x12222]={
  category="lo",
  description="CUNEIFORM SIGN MA GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12222,
 },
 [0x12223]={
  category="lo",
  description="CUNEIFORM SIGN MA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12223,
 },
 [0x12224]={
  category="lo",
  description="CUNEIFORM SIGN MAH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12224,
 },
 [0x12225]={
  category="lo",
  description="CUNEIFORM SIGN MAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12225,
 },
 [0x12226]={
  category="lo",
  description="CUNEIFORM SIGN MASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12226,
 },
 [0x12227]={
  category="lo",
  description="CUNEIFORM SIGN MASH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12227,
 },
 [0x12228]={
  category="lo",
  description="CUNEIFORM SIGN ME",
  direction="l",
  linebreak="al",
  unicodeslot=0x12228,
 },
 [0x12229]={
  category="lo",
  description="CUNEIFORM SIGN MES",
  direction="l",
  linebreak="al",
  unicodeslot=0x12229,
 },
 [0x1222A]={
  category="lo",
  description="CUNEIFORM SIGN MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1222A,
 },
 [0x1222B]={
  category="lo",
  description="CUNEIFORM SIGN MIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1222B,
 },
 [0x1222C]={
  category="lo",
  description="CUNEIFORM SIGN MU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1222C,
 },
 [0x1222D]={
  category="lo",
  description="CUNEIFORM SIGN MU OVER MU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1222D,
 },
 [0x1222E]={
  category="lo",
  description="CUNEIFORM SIGN MUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1222E,
 },
 [0x1222F]={
  category="lo",
  description="CUNEIFORM SIGN MUG GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1222F,
 },
 [0x12230]={
  category="lo",
  description="CUNEIFORM SIGN MUNSUB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12230,
 },
 [0x12231]={
  category="lo",
  description="CUNEIFORM SIGN MURGU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12231,
 },
 [0x12232]={
  category="lo",
  description="CUNEIFORM SIGN MUSH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12232,
 },
 [0x12233]={
  category="lo",
  description="CUNEIFORM SIGN MUSH TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12233,
 },
 [0x12234]={
  category="lo",
  description="CUNEIFORM SIGN MUSH TIMES KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12234,
 },
 [0x12235]={
  category="lo",
  description="CUNEIFORM SIGN MUSH TIMES ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12235,
 },
 [0x12236]={
  category="lo",
  description="CUNEIFORM SIGN MUSH OVER MUSH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12236,
 },
 [0x12237]={
  category="lo",
  description="CUNEIFORM SIGN MUSH OVER MUSH TIMES A PLUS NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12237,
 },
 [0x12238]={
  category="lo",
  description="CUNEIFORM SIGN MUSH CROSSING MUSH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12238,
 },
 [0x12239]={
  category="lo",
  description="CUNEIFORM SIGN MUSH0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12239,
 },
 [0x1223A]={
  category="lo",
  description="CUNEIFORM SIGN MUSH0x0003 TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1223A,
 },
 [0x1223B]={
  category="lo",
  description="CUNEIFORM SIGN MUSH0x0003 TIMES A PLUS DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1223B,
 },
 [0x1223C]={
  category="lo",
  description="CUNEIFORM SIGN MUSH0x0003 TIMES DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1223C,
 },
 [0x1223D]={
  category="lo",
  description="CUNEIFORM SIGN MUSH0x0003 GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1223D,
 },
 [0x1223E]={
  category="lo",
  description="CUNEIFORM SIGN NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1223E,
 },
 [0x1223F]={
  category="lo",
  description="CUNEIFORM SIGN NA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1223F,
 },
 [0x12240]={
  category="lo",
  description="CUNEIFORM SIGN NAGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12240,
 },
 [0x12241]={
  category="lo",
  description="CUNEIFORM SIGN NAGA INVERTED",
  direction="l",
  linebreak="al",
  unicodeslot=0x12241,
 },
 [0x12242]={
  category="lo",
  description="CUNEIFORM SIGN NAGA TIMES SHU TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12242,
 },
 [0x12243]={
  category="lo",
  description="CUNEIFORM SIGN NAGA OPPOSING NAGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12243,
 },
 [0x12244]={
  category="lo",
  description="CUNEIFORM SIGN NAGAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12244,
 },
 [0x12245]={
  category="lo",
  description="CUNEIFORM SIGN NAM NUTILLU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12245,
 },
 [0x12246]={
  category="lo",
  description="CUNEIFORM SIGN NAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12246,
 },
 [0x12247]={
  category="lo",
  description="CUNEIFORM SIGN NAM0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12247,
 },
 [0x12248]={
  category="lo",
  description="CUNEIFORM SIGN NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12248,
 },
 [0x12249]={
  category="lo",
  description="CUNEIFORM SIGN NE TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12249,
 },
 [0x1224A]={
  category="lo",
  description="CUNEIFORM SIGN NE TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1224A,
 },
 [0x1224B]={
  category="lo",
  description="CUNEIFORM SIGN NE SHESHIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1224B,
 },
 [0x1224C]={
  category="lo",
  description="CUNEIFORM SIGN NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1224C,
 },
 [0x1224D]={
  category="lo",
  description="CUNEIFORM SIGN NI TIMES E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1224D,
 },
 [0x1224E]={
  category="lo",
  description="CUNEIFORM SIGN NI0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1224E,
 },
 [0x1224F]={
  category="lo",
  description="CUNEIFORM SIGN NIM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1224F,
 },
 [0x12250]={
  category="lo",
  description="CUNEIFORM SIGN NIM TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12250,
 },
 [0x12251]={
  category="lo",
  description="CUNEIFORM SIGN NIM TIMES GAR PLUS GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12251,
 },
 [0x12252]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12252,
 },
 [0x12253]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12253,
 },
 [0x12254]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12254,
 },
 [0x12255]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES ASH PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12255,
 },
 [0x12256]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12256,
 },
 [0x12257]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES ME PLUS GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12257,
 },
 [0x12258]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12258,
 },
 [0x12259]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12259,
 },
 [0x1225A]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1225A,
 },
 [0x1225B]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES SHE PLUS A AN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1225B,
 },
 [0x1225C]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES SHE PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1225C,
 },
 [0x1225D]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES SHE PLUS ASH PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1225D,
 },
 [0x1225E]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES U0x0002 PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1225E,
 },
 [0x1225F]={
  category="lo",
  description="CUNEIFORM SIGN NINDA0x0002 TIMES USH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1225F,
 },
 [0x12260]={
  category="lo",
  description="CUNEIFORM SIGN NISAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12260,
 },
 [0x12261]={
  category="lo",
  description="CUNEIFORM SIGN NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12261,
 },
 [0x12262]={
  category="lo",
  description="CUNEIFORM SIGN NU0x000B",
  direction="l",
  linebreak="al",
  unicodeslot=0x12262,
 },
 [0x12263]={
  category="lo",
  description="CUNEIFORM SIGN NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12263,
 },
 [0x12264]={
  category="lo",
  description="CUNEIFORM SIGN NUN LAGAR TIMES GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12264,
 },
 [0x12265]={
  category="lo",
  description="CUNEIFORM SIGN NUN LAGAR TIMES MASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12265,
 },
 [0x12266]={
  category="lo",
  description="CUNEIFORM SIGN NUN LAGAR TIMES SAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12266,
 },
 [0x12267]={
  category="lo",
  description="CUNEIFORM SIGN NUN LAGAR TIMES SAL OVER NUN LAGAR TIMES SAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12267,
 },
 [0x12268]={
  category="lo",
  description="CUNEIFORM SIGN NUN LAGAR TIMES USH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12268,
 },
 [0x12269]={
  category="lo",
  description="CUNEIFORM SIGN NUN TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12269,
 },
 [0x1226A]={
  category="lo",
  description="CUNEIFORM SIGN NUN OVER NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1226A,
 },
 [0x1226B]={
  category="lo",
  description="CUNEIFORM SIGN NUN CROSSING NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1226B,
 },
 [0x1226C]={
  category="lo",
  description="CUNEIFORM SIGN NUN CROSSING NUN LAGAR OVER LAGAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1226C,
 },
 [0x1226D]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1226D,
 },
 [0x1226E]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES ASHGAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1226E,
 },
 [0x1226F]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1226F,
 },
 [0x12270]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES DUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12270,
 },
 [0x12271]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12271,
 },
 [0x12272]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12272,
 },
 [0x12273]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES KAD0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12273,
 },
 [0x12274]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12274,
 },
 [0x12275]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12275,
 },
 [0x12276]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES SILA0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12276,
 },
 [0x12277]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ AB0x0002 TIMES U0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12277,
 },
 [0x12278]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ KISIM0x0005 TIMES BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12278,
 },
 [0x12279]={
  category="lo",
  description="CUNEIFORM SIGN NUNUZ KISIM0x0005 TIMES BI U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12279,
 },
 [0x1227A]={
  category="lo",
  description="CUNEIFORM SIGN PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1227A,
 },
 [0x1227B]={
  category="lo",
  description="CUNEIFORM SIGN PAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1227B,
 },
 [0x1227C]={
  category="lo",
  description="CUNEIFORM SIGN PAN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1227C,
 },
 [0x1227D]={
  category="lo",
  description="CUNEIFORM SIGN PAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1227D,
 },
 [0x1227E]={
  category="lo",
  description="CUNEIFORM SIGN PESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1227E,
 },
 [0x1227F]={
  category="lo",
  description="CUNEIFORM SIGN PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1227F,
 },
 [0x12280]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12280,
 },
 [0x12281]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES AB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12281,
 },
 [0x12282]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12282,
 },
 [0x12283]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES BU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12283,
 },
 [0x12284]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES E",
  direction="l",
  linebreak="al",
  unicodeslot=0x12284,
 },
 [0x12285]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES I",
  direction="l",
  linebreak="al",
  unicodeslot=0x12285,
 },
 [0x12286]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES IB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12286,
 },
 [0x12287]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12287,
 },
 [0x12288]={
  category="lo",
  description="CUNEIFORM SIGN PI TIMES U0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12288,
 },
 [0x12289]={
  category="lo",
  description="CUNEIFORM SIGN PI CROSSING PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12289,
 },
 [0x1228A]={
  category="lo",
  description="CUNEIFORM SIGN PIRIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1228A,
 },
 [0x1228B]={
  category="lo",
  description="CUNEIFORM SIGN PIRIG TIMES KAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1228B,
 },
 [0x1228C]={
  category="lo",
  description="CUNEIFORM SIGN PIRIG TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1228C,
 },
 [0x1228D]={
  category="lo",
  description="CUNEIFORM SIGN PIRIG TIMES ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1228D,
 },
 [0x1228E]={
  category="lo",
  description="CUNEIFORM SIGN PIRIG OPPOSING PIRIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1228E,
 },
 [0x1228F]={
  category="lo",
  description="CUNEIFORM SIGN RA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1228F,
 },
 [0x12290]={
  category="lo",
  description="CUNEIFORM SIGN RAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12290,
 },
 [0x12291]={
  category="lo",
  description="CUNEIFORM SIGN RI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12291,
 },
 [0x12292]={
  category="lo",
  description="CUNEIFORM SIGN RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12292,
 },
 [0x12293]={
  category="lo",
  description="CUNEIFORM SIGN SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12293,
 },
 [0x12294]={
  category="lo",
  description="CUNEIFORM SIGN SAG NUTILLU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12294,
 },
 [0x12295]={
  category="lo",
  description="CUNEIFORM SIGN SAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12295,
 },
 [0x12296]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12296,
 },
 [0x12297]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES DU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12297,
 },
 [0x12298]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES DUB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12298,
 },
 [0x12299]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12299,
 },
 [0x1229A]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES KAK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1229A,
 },
 [0x1229B]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1229B,
 },
 [0x1229C]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES LUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1229C,
 },
 [0x1229D]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1229D,
 },
 [0x1229E]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1229E,
 },
 [0x1229F]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES SAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1229F,
 },
 [0x122A0]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES SHID",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A0,
 },
 [0x122A1]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES TAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A1,
 },
 [0x122A2]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES U0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A2,
 },
 [0x122A3]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES UB",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A3,
 },
 [0x122A4]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES UM",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A4,
 },
 [0x122A5]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES UR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A5,
 },
 [0x122A6]={
  category="lo",
  description="CUNEIFORM SIGN SAG TIMES USH",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A6,
 },
 [0x122A7]={
  category="lo",
  description="CUNEIFORM SIGN SAG OVER SAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A7,
 },
 [0x122A8]={
  category="lo",
  description="CUNEIFORM SIGN SAG GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A8,
 },
 [0x122A9]={
  category="lo",
  description="CUNEIFORM SIGN SAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x122A9,
 },
 [0x122AA]={
  category="lo",
  description="CUNEIFORM SIGN SAL LAGAB TIMES ASH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122AA,
 },
 [0x122AB]={
  category="lo",
  description="CUNEIFORM SIGN SANGA0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122AB,
 },
 [0x122AC]={
  category="lo",
  description="CUNEIFORM SIGN SAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122AC,
 },
 [0x122AD]={
  category="lo",
  description="CUNEIFORM SIGN SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x122AD,
 },
 [0x122AE]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x122AE,
 },
 [0x122AF]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003 TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x122AF,
 },
 [0x122B0]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003 TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B0,
 },
 [0x122B1]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003 TIMES GISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B1,
 },
 [0x122B2]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003 TIMES NE",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B2,
 },
 [0x122B3]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003 TIMES SHU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B3,
 },
 [0x122B4]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003 TIMES TUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B4,
 },
 [0x122B5]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003 TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B5,
 },
 [0x122B6]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0003 TIMES U PLUS A",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B6,
 },
 [0x122B7]={
  category="lo",
  description="CUNEIFORM SIGN SHA0x0006",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B7,
 },
 [0x122B8]={
  category="lo",
  description="CUNEIFORM SIGN SHAB0x0006",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B8,
 },
 [0x122B9]={
  category="lo",
  description="CUNEIFORM SIGN SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122B9,
 },
 [0x122BA]={
  category="lo",
  description="CUNEIFORM SIGN SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x122BA,
 },
 [0x122BB]={
  category="lo",
  description="CUNEIFORM SIGN SHE HU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122BB,
 },
 [0x122BC]={
  category="lo",
  description="CUNEIFORM SIGN SHE OVER SHE GAD OVER GAD GAR OVER GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122BC,
 },
 [0x122BD]={
  category="lo",
  description="CUNEIFORM SIGN SHE OVER SHE TAB OVER TAB GAR OVER GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122BD,
 },
 [0x122BE]={
  category="lo",
  description="CUNEIFORM SIGN SHEG0x0009",
  direction="l",
  linebreak="al",
  unicodeslot=0x122BE,
 },
 [0x122BF]={
  category="lo",
  description="CUNEIFORM SIGN SHEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x122BF,
 },
 [0x122C0]={
  category="lo",
  description="CUNEIFORM SIGN SHESH",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C0,
 },
 [0x122C1]={
  category="lo",
  description="CUNEIFORM SIGN SHESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C1,
 },
 [0x122C2]={
  category="lo",
  description="CUNEIFORM SIGN SHESHLAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C2,
 },
 [0x122C3]={
  category="lo",
  description="CUNEIFORM SIGN SHID",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C3,
 },
 [0x122C4]={
  category="lo",
  description="CUNEIFORM SIGN SHID TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C4,
 },
 [0x122C5]={
  category="lo",
  description="CUNEIFORM SIGN SHID TIMES IM",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C5,
 },
 [0x122C6]={
  category="lo",
  description="CUNEIFORM SIGN SHIM",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C6,
 },
 [0x122C7]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C7,
 },
 [0x122C8]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES BAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C8,
 },
 [0x122C9]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES BULUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x122C9,
 },
 [0x122CA]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES DIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x122CA,
 },
 [0x122CB]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122CB,
 },
 [0x122CC]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x122CC,
 },
 [0x122CD]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES IGI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122CD,
 },
 [0x122CE]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES KUSHU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122CE,
 },
 [0x122CF]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES LUL",
  direction="l",
  linebreak="al",
  unicodeslot=0x122CF,
 },
 [0x122D0]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES MUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D0,
 },
 [0x122D1]={
  category="lo",
  description="CUNEIFORM SIGN SHIM TIMES SAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D1,
 },
 [0x122D2]={
  category="lo",
  description="CUNEIFORM SIGN SHINIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D2,
 },
 [0x122D3]={
  category="lo",
  description="CUNEIFORM SIGN SHIR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D3,
 },
 [0x122D4]={
  category="lo",
  description="CUNEIFORM SIGN SHIR TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D4,
 },
 [0x122D5]={
  category="lo",
  description="CUNEIFORM SIGN SHIR OVER SHIR BUR OVER BUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D5,
 },
 [0x122D6]={
  category="lo",
  description="CUNEIFORM SIGN SHITA",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D6,
 },
 [0x122D7]={
  category="lo",
  description="CUNEIFORM SIGN SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D7,
 },
 [0x122D8]={
  category="lo",
  description="CUNEIFORM SIGN SHU OVER INVERTED SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D8,
 },
 [0x122D9]={
  category="lo",
  description="CUNEIFORM SIGN SHU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122D9,
 },
 [0x122DA]={
  category="lo",
  description="CUNEIFORM SIGN SHUBUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122DA,
 },
 [0x122DB]={
  category="lo",
  description="CUNEIFORM SIGN SI",
  direction="l",
  linebreak="al",
  unicodeslot=0x122DB,
 },
 [0x122DC]={
  category="lo",
  description="CUNEIFORM SIGN SI GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122DC,
 },
 [0x122DD]={
  category="lo",
  description="CUNEIFORM SIGN SIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x122DD,
 },
 [0x122DE]={
  category="lo",
  description="CUNEIFORM SIGN SIG0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x122DE,
 },
 [0x122DF]={
  category="lo",
  description="CUNEIFORM SIGN SIG0x0004 OVER SIG0x0004 SHU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122DF,
 },
 [0x122E0]={
  category="lo",
  description="CUNEIFORM SIGN SIK0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E0,
 },
 [0x122E1]={
  category="lo",
  description="CUNEIFORM SIGN SILA0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E1,
 },
 [0x122E2]={
  category="lo",
  description="CUNEIFORM SIGN SU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E2,
 },
 [0x122E3]={
  category="lo",
  description="CUNEIFORM SIGN SU OVER SU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E3,
 },
 [0x122E4]={
  category="lo",
  description="CUNEIFORM SIGN SUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E4,
 },
 [0x122E5]={
  category="lo",
  description="CUNEIFORM SIGN SUD0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E5,
 },
 [0x122E6]={
  category="lo",
  description="CUNEIFORM SIGN SUHUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E6,
 },
 [0x122E7]={
  category="lo",
  description="CUNEIFORM SIGN SUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E7,
 },
 [0x122E8]={
  category="lo",
  description="CUNEIFORM SIGN SUMASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E8,
 },
 [0x122E9]={
  category="lo",
  description="CUNEIFORM SIGN SUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122E9,
 },
 [0x122EA]={
  category="lo",
  description="CUNEIFORM SIGN SUR0x0009",
  direction="l",
  linebreak="al",
  unicodeslot=0x122EA,
 },
 [0x122EB]={
  category="lo",
  description="CUNEIFORM SIGN TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x122EB,
 },
 [0x122EC]={
  category="lo",
  description="CUNEIFORM SIGN TA ASTERISK",
  direction="l",
  linebreak="al",
  unicodeslot=0x122EC,
 },
 [0x122ED]={
  category="lo",
  description="CUNEIFORM SIGN TA TIMES HI",
  direction="l",
  linebreak="al",
  unicodeslot=0x122ED,
 },
 [0x122EE]={
  category="lo",
  description="CUNEIFORM SIGN TA TIMES MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x122EE,
 },
 [0x122EF]={
  category="lo",
  description="CUNEIFORM SIGN TA GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122EF,
 },
 [0x122F0]={
  category="lo",
  description="CUNEIFORM SIGN TAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F0,
 },
 [0x122F1]={
  category="lo",
  description="CUNEIFORM SIGN TAB OVER TAB NI OVER NI DISH OVER DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F1,
 },
 [0x122F2]={
  category="lo",
  description="CUNEIFORM SIGN TAB SQUARED",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F2,
 },
 [0x122F3]={
  category="lo",
  description="CUNEIFORM SIGN TAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F3,
 },
 [0x122F4]={
  category="lo",
  description="CUNEIFORM SIGN TAG TIMES BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F4,
 },
 [0x122F5]={
  category="lo",
  description="CUNEIFORM SIGN TAG TIMES GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F5,
 },
 [0x122F6]={
  category="lo",
  description="CUNEIFORM SIGN TAG TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F6,
 },
 [0x122F7]={
  category="lo",
  description="CUNEIFORM SIGN TAG TIMES SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F7,
 },
 [0x122F8]={
  category="lo",
  description="CUNEIFORM SIGN TAG TIMES TUG0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F8,
 },
 [0x122F9]={
  category="lo",
  description="CUNEIFORM SIGN TAG TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x122F9,
 },
 [0x122FA]={
  category="lo",
  description="CUNEIFORM SIGN TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x122FA,
 },
 [0x122FB]={
  category="lo",
  description="CUNEIFORM SIGN TAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x122FB,
 },
 [0x122FC]={
  category="lo",
  description="CUNEIFORM SIGN TE",
  direction="l",
  linebreak="al",
  unicodeslot=0x122FC,
 },
 [0x122FD]={
  category="lo",
  description="CUNEIFORM SIGN TE GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122FD,
 },
 [0x122FE]={
  category="lo",
  description="CUNEIFORM SIGN TI",
  direction="l",
  linebreak="al",
  unicodeslot=0x122FE,
 },
 [0x122FF]={
  category="lo",
  description="CUNEIFORM SIGN TI TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x122FF,
 },
 [0x12300]={
  category="lo",
  description="CUNEIFORM SIGN TIL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12300,
 },
 [0x12301]={
  category="lo",
  description="CUNEIFORM SIGN TIR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12301,
 },
 [0x12302]={
  category="lo",
  description="CUNEIFORM SIGN TIR TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12302,
 },
 [0x12303]={
  category="lo",
  description="CUNEIFORM SIGN TIR OVER TIR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12303,
 },
 [0x12304]={
  category="lo",
  description="CUNEIFORM SIGN TIR OVER TIR GAD OVER GAD GAR OVER GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12304,
 },
 [0x12305]={
  category="lo",
  description="CUNEIFORM SIGN TU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12305,
 },
 [0x12306]={
  category="lo",
  description="CUNEIFORM SIGN TUG0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12306,
 },
 [0x12307]={
  category="lo",
  description="CUNEIFORM SIGN TUK",
  direction="l",
  linebreak="al",
  unicodeslot=0x12307,
 },
 [0x12308]={
  category="lo",
  description="CUNEIFORM SIGN TUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12308,
 },
 [0x12309]={
  category="lo",
  description="CUNEIFORM SIGN TUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12309,
 },
 [0x1230A]={
  category="lo",
  description="CUNEIFORM SIGN TUR OVER TUR ZA OVER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1230A,
 },
 [0x1230B]={
  category="lo",
  description="CUNEIFORM SIGN U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1230B,
 },
 [0x1230C]={
  category="lo",
  description="CUNEIFORM SIGN U GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1230C,
 },
 [0x1230D]={
  category="lo",
  description="CUNEIFORM SIGN U U U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1230D,
 },
 [0x1230E]={
  category="lo",
  description="CUNEIFORM SIGN U OVER U PA OVER PA GAR OVER GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1230E,
 },
 [0x1230F]={
  category="lo",
  description="CUNEIFORM SIGN U OVER U SUR OVER SUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1230F,
 },
 [0x12310]={
  category="lo",
  description="CUNEIFORM SIGN U OVER U U REVERSED OVER U REVERSED",
  direction="l",
  linebreak="al",
  unicodeslot=0x12310,
 },
 [0x12311]={
  category="lo",
  description="CUNEIFORM SIGN U0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12311,
 },
 [0x12312]={
  category="lo",
  description="CUNEIFORM SIGN UB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12312,
 },
 [0x12313]={
  category="lo",
  description="CUNEIFORM SIGN UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12313,
 },
 [0x12314]={
  category="lo",
  description="CUNEIFORM SIGN UD KUSHU0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12314,
 },
 [0x12315]={
  category="lo",
  description="CUNEIFORM SIGN UD TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x12315,
 },
 [0x12316]={
  category="lo",
  description="CUNEIFORM SIGN UD TIMES MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12316,
 },
 [0x12317]={
  category="lo",
  description="CUNEIFORM SIGN UD TIMES U PLUS U PLUS U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12317,
 },
 [0x12318]={
  category="lo",
  description="CUNEIFORM SIGN UD TIMES U PLUS U PLUS U GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12318,
 },
 [0x12319]={
  category="lo",
  description="CUNEIFORM SIGN UD GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12319,
 },
 [0x1231A]={
  category="lo",
  description="CUNEIFORM SIGN UD SHESHIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1231A,
 },
 [0x1231B]={
  category="lo",
  description="CUNEIFORM SIGN UD SHESHIG TIMES BAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1231B,
 },
 [0x1231C]={
  category="lo",
  description="CUNEIFORM SIGN UDUG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1231C,
 },
 [0x1231D]={
  category="lo",
  description="CUNEIFORM SIGN UM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1231D,
 },
 [0x1231E]={
  category="lo",
  description="CUNEIFORM SIGN UM TIMES LAGAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x1231E,
 },
 [0x1231F]={
  category="lo",
  description="CUNEIFORM SIGN UM TIMES ME PLUS DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1231F,
 },
 [0x12320]={
  category="lo",
  description="CUNEIFORM SIGN UM TIMES SHA0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12320,
 },
 [0x12321]={
  category="lo",
  description="CUNEIFORM SIGN UM TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12321,
 },
 [0x12322]={
  category="lo",
  description="CUNEIFORM SIGN UMBIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12322,
 },
 [0x12323]={
  category="lo",
  description="CUNEIFORM SIGN UMUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12323,
 },
 [0x12324]={
  category="lo",
  description="CUNEIFORM SIGN UMUM TIMES KASKAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x12324,
 },
 [0x12325]={
  category="lo",
  description="CUNEIFORM SIGN UMUM TIMES PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12325,
 },
 [0x12326]={
  category="lo",
  description="CUNEIFORM SIGN UN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12326,
 },
 [0x12327]={
  category="lo",
  description="CUNEIFORM SIGN UN GUNU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12327,
 },
 [0x12328]={
  category="lo",
  description="CUNEIFORM SIGN UR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12328,
 },
 [0x12329]={
  category="lo",
  description="CUNEIFORM SIGN UR CROSSING UR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12329,
 },
 [0x1232A]={
  category="lo",
  description="CUNEIFORM SIGN UR SHESHIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1232A,
 },
 [0x1232B]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1232B,
 },
 [0x1232C]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002 TIMES A PLUS HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1232C,
 },
 [0x1232D]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002 TIMES A PLUS NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1232D,
 },
 [0x1232E]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002 TIMES AL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1232E,
 },
 [0x1232F]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002 TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1232F,
 },
 [0x12330]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002 TIMES NUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12330,
 },
 [0x12331]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002 TIMES U0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12331,
 },
 [0x12332]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002 TIMES U0x0002 PLUS ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12332,
 },
 [0x12333]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0002 TIMES U0x0002 PLUS BI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12333,
 },
 [0x12334]={
  category="lo",
  description="CUNEIFORM SIGN UR0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12334,
 },
 [0x12335]={
  category="lo",
  description="CUNEIFORM SIGN URI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12335,
 },
 [0x12336]={
  category="lo",
  description="CUNEIFORM SIGN URI0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12336,
 },
 [0x12337]={
  category="lo",
  description="CUNEIFORM SIGN URU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12337,
 },
 [0x12338]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12338,
 },
 [0x12339]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES ASHGAB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12339,
 },
 [0x1233A]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES BAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1233A,
 },
 [0x1233B]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES DUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1233B,
 },
 [0x1233C]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1233C,
 },
 [0x1233D]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES GAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1233D,
 },
 [0x1233E]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES GAN0x0002 TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1233E,
 },
 [0x1233F]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES GAR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1233F,
 },
 [0x12340]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES GU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12340,
 },
 [0x12341]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12341,
 },
 [0x12342]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES IGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12342,
 },
 [0x12343]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES IM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12343,
 },
 [0x12344]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES ISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12344,
 },
 [0x12345]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12345,
 },
 [0x12346]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES LUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12346,
 },
 [0x12347]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES MIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12347,
 },
 [0x12348]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x12348,
 },
 [0x12349]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES SHE",
  direction="l",
  linebreak="al",
  unicodeslot=0x12349,
 },
 [0x1234A]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES SIG0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1234A,
 },
 [0x1234B]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES TU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1234B,
 },
 [0x1234C]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES U PLUS GUD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1234C,
 },
 [0x1234D]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES UD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1234D,
 },
 [0x1234E]={
  category="lo",
  description="CUNEIFORM SIGN URU TIMES URUDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1234E,
 },
 [0x1234F]={
  category="lo",
  description="CUNEIFORM SIGN URUDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1234F,
 },
 [0x12350]={
  category="lo",
  description="CUNEIFORM SIGN URUDA TIMES U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12350,
 },
 [0x12351]={
  category="lo",
  description="CUNEIFORM SIGN USH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12351,
 },
 [0x12352]={
  category="lo",
  description="CUNEIFORM SIGN USH TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12352,
 },
 [0x12353]={
  category="lo",
  description="CUNEIFORM SIGN USH TIMES KU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12353,
 },
 [0x12354]={
  category="lo",
  description="CUNEIFORM SIGN USH TIMES KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x12354,
 },
 [0x12355]={
  category="lo",
  description="CUNEIFORM SIGN USH TIMES TAK0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12355,
 },
 [0x12356]={
  category="lo",
  description="CUNEIFORM SIGN USHX",
  direction="l",
  linebreak="al",
  unicodeslot=0x12356,
 },
 [0x12357]={
  category="lo",
  description="CUNEIFORM SIGN USH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12357,
 },
 [0x12358]={
  category="lo",
  description="CUNEIFORM SIGN USHUMX",
  direction="l",
  linebreak="al",
  unicodeslot=0x12358,
 },
 [0x12359]={
  category="lo",
  description="CUNEIFORM SIGN UTUKI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12359,
 },
 [0x1235A]={
  category="lo",
  description="CUNEIFORM SIGN UZ0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1235A,
 },
 [0x1235B]={
  category="lo",
  description="CUNEIFORM SIGN UZ0x0003 TIMES KASKAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1235B,
 },
 [0x1235C]={
  category="lo",
  description="CUNEIFORM SIGN UZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1235C,
 },
 [0x1235D]={
  category="lo",
  description="CUNEIFORM SIGN ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1235D,
 },
 [0x1235E]={
  category="lo",
  description="CUNEIFORM SIGN ZA TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1235E,
 },
 [0x1235F]={
  category="lo",
  description="CUNEIFORM SIGN ZA SQUARED TIMES KUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1235F,
 },
 [0x12360]={
  category="lo",
  description="CUNEIFORM SIGN ZAG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12360,
 },
 [0x12361]={
  category="lo",
  description="CUNEIFORM SIGN ZAMX",
  direction="l",
  linebreak="al",
  unicodeslot=0x12361,
 },
 [0x12362]={
  category="lo",
  description="CUNEIFORM SIGN ZE0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12362,
 },
 [0x12363]={
  category="lo",
  description="CUNEIFORM SIGN ZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12363,
 },
 [0x12364]={
  category="lo",
  description="CUNEIFORM SIGN ZI OVER ZI",
  direction="l",
  linebreak="al",
  unicodeslot=0x12364,
 },
 [0x12365]={
  category="lo",
  description="CUNEIFORM SIGN ZI0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12365,
 },
 [0x12366]={
  category="lo",
  description="CUNEIFORM SIGN ZIB",
  direction="l",
  linebreak="al",
  unicodeslot=0x12366,
 },
 [0x12367]={
  category="lo",
  description="CUNEIFORM SIGN ZIB KABA TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12367,
 },
 [0x12368]={
  category="lo",
  description="CUNEIFORM SIGN ZIG",
  direction="l",
  linebreak="al",
  unicodeslot=0x12368,
 },
 [0x12369]={
  category="lo",
  description="CUNEIFORM SIGN ZIZ0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12369,
 },
 [0x1236A]={
  category="lo",
  description="CUNEIFORM SIGN ZU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1236A,
 },
 [0x1236B]={
  category="lo",
  description="CUNEIFORM SIGN ZU0x0005",
  direction="l",
  linebreak="al",
  unicodeslot=0x1236B,
 },
 [0x1236C]={
  category="lo",
  description="CUNEIFORM SIGN ZU0x0005 TIMES A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1236C,
 },
 [0x1236D]={
  category="lo",
  description="CUNEIFORM SIGN ZUBUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1236D,
 },
 [0x1236E]={
  category="lo",
  description="CUNEIFORM SIGN ZUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1236E,
 },
 [0x12400]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12400,
 },
 [0x12401]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12401,
 },
 [0x12402]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12402,
 },
 [0x12403]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12403,
 },
 [0x12404]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SIX ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12404,
 },
 [0x12405]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SEVEN ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12405,
 },
 [0x12406]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN EIGHT ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12406,
 },
 [0x12407]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12407,
 },
 [0x12408]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12408,
 },
 [0x12409]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12409,
 },
 [0x1240A]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1240A,
 },
 [0x1240B]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SIX DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1240B,
 },
 [0x1240C]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SEVEN DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1240C,
 },
 [0x1240D]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN EIGHT DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1240D,
 },
 [0x1240E]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1240E,
 },
 [0x1240F]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR U",
  direction="l",
  linebreak="al",
  unicodeslot=0x1240F,
 },
 [0x12410]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12410,
 },
 [0x12411]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SIX U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12411,
 },
 [0x12412]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SEVEN U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12412,
 },
 [0x12413]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN EIGHT U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12413,
 },
 [0x12414]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE U",
  direction="l",
  linebreak="al",
  unicodeslot=0x12414,
 },
 [0x12415]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12415,
 },
 [0x12416]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12416,
 },
 [0x12417]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12417,
 },
 [0x12418]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12418,
 },
 [0x12419]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12419,
 },
 [0x1241A]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SIX GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1241A,
 },
 [0x1241B]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SEVEN GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1241B,
 },
 [0x1241C]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN EIGHT GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1241C,
 },
 [0x1241D]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE GESH0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1241D,
 },
 [0x1241E]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE GESHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1241E,
 },
 [0x1241F]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO GESHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1241F,
 },
 [0x12420]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE GESHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12420,
 },
 [0x12421]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR GESHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12421,
 },
 [0x12422]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE GESHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12422,
 },
 [0x12423]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12423,
 },
 [0x12424]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12424,
 },
 [0x12425]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE SHAR0x0002 VARIANT FORM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12425,
 },
 [0x12426]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12426,
 },
 [0x12427]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12427,
 },
 [0x12428]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SIX SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12428,
 },
 [0x12429]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SEVEN SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12429,
 },
 [0x1242A]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN EIGHT SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1242A,
 },
 [0x1242B]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE SHAR0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1242B,
 },
 [0x1242C]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE SHARU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1242C,
 },
 [0x1242D]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO SHARU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1242D,
 },
 [0x1242E]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE SHARU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1242E,
 },
 [0x1242F]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE SHARU VARIANT FORM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1242F,
 },
 [0x12430]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR SHARU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12430,
 },
 [0x12431]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE SHARU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12431,
 },
 [0x12432]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SHAR0x0002 TIMES GAL PLUS DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12432,
 },
 [0x12433]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SHAR0x0002 TIMES GAL PLUS MIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12433,
 },
 [0x12434]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE BURU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12434,
 },
 [0x12435]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO BURU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12435,
 },
 [0x12436]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE BURU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12436,
 },
 [0x12437]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE BURU VARIANT FORM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12437,
 },
 [0x12438]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR BURU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12438,
 },
 [0x12439]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE BURU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12439,
 },
 [0x1243A]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH0x0010",
  direction="l",
  linebreak="al",
  unicodeslot=0x1243A,
 },
 [0x1243B]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH0x0015",
  direction="l",
  linebreak="al",
  unicodeslot=0x1243B,
 },
 [0x1243C]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1243C,
 },
 [0x1243D]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1243D,
 },
 [0x1243E]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1243E,
 },
 [0x1243F]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1243F,
 },
 [0x12440]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SIX VARIANT FORM ASH0x0009",
  direction="l",
  linebreak="al",
  unicodeslot=0x12440,
 },
 [0x12441]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12441,
 },
 [0x12442]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12442,
 },
 [0x12443]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN B",
  direction="l",
  linebreak="al",
  unicodeslot=0x12443,
 },
 [0x12444]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12444,
 },
 [0x12445]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12445,
 },
 [0x12446]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU",
  direction="l",
  linebreak="al",
  unicodeslot=0x12446,
 },
 [0x12447]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12447,
 },
 [0x12448]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x12448,
 },
 [0x12449]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU A",
  direction="l",
  linebreak="al",
  unicodeslot=0x12449,
 },
 [0x1244A]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO ASH TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1244A,
 },
 [0x1244B]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE ASH TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1244B,
 },
 [0x1244C]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR ASH TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1244C,
 },
 [0x1244D]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE ASH TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1244D,
 },
 [0x1244E]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN SIX ASH TENU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1244E,
 },
 [0x1244F]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE BAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1244F,
 },
 [0x12450]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO BAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12450,
 },
 [0x12451]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN THREE BAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12451,
 },
 [0x12452]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR BAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12452,
 },
 [0x12453]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FOUR BAN0x0002 VARIANT FORM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12453,
 },
 [0x12454]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE BAN0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x12454,
 },
 [0x12455]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE BAN0x0002 VARIANT FORM",
  direction="l",
  linebreak="al",
  unicodeslot=0x12455,
 },
 [0x12456]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NIGIDAMIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x12456,
 },
 [0x12457]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN NIGIDAESH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12457,
 },
 [0x12458]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE ESHE0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12458,
 },
 [0x12459]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO ESHE0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x12459,
 },
 [0x1245A]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE THIRD DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1245A,
 },
 [0x1245B]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO THIRDS DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1245B,
 },
 [0x1245C]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN FIVE SIXTHS DISH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1245C,
 },
 [0x1245D]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE THIRD VARIANT FORM A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1245D,
 },
 [0x1245E]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN TWO THIRDS VARIANT FORM A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1245E,
 },
 [0x1245F]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE EIGHTH ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1245F,
 },
 [0x12460]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN ONE QUARTER ASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12460,
 },
 [0x12461]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE SIXTH",
  direction="l",
  linebreak="al",
  unicodeslot=0x12461,
 },
 [0x12462]={
  category="nl",
  description="CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE QUARTER",
  direction="l",
  linebreak="al",
  unicodeslot=0x12462,
 },
 [0x12470]={
  category="po",
  description="CUNEIFORM PUNCTUATION SIGN OLD ASSYRIAN WORD DIVIDER",
  direction="l",
  linebreak="ba",
  unicodeslot=0x12470,
 },
 [0x12471]={
  category="po",
  description="CUNEIFORM PUNCTUATION SIGN VERTICAL COLON",
  direction="l",
  linebreak="ba",
  unicodeslot=0x12471,
 },
 [0x12472]={
  category="po",
  description="CUNEIFORM PUNCTUATION SIGN DIAGONAL COLON",
  direction="l",
  linebreak="ba",
  unicodeslot=0x12472,
 },
 [0x12473]={
  category="po",
  description="CUNEIFORM PUNCTUATION SIGN DIAGONAL TRICOLON",
  direction="l",
  linebreak="ba",
  unicodeslot=0x12473,
 },
 [0x13000]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13000,
 },
 [0x13001]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13001,
 },
 [0x13002]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13002,
 },
 [0x13003]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13003,
 },
 [0x13004]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13004,
 },
 [0x13005]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A005A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13005,
 },
 [0x13006]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13006,
 },
 [0x13007]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A006A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13007,
 },
 [0x13008]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A006B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13008,
 },
 [0x13009]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13009,
 },
 [0x1300A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A008",
  direction="l",
  linebreak="al",
  unicodeslot=0x1300A,
 },
 [0x1300B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A009",
  direction="l",
  linebreak="al",
  unicodeslot=0x1300B,
 },
 [0x1300C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A010",
  direction="l",
  linebreak="al",
  unicodeslot=0x1300C,
 },
 [0x1300D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A011",
  direction="l",
  linebreak="al",
  unicodeslot=0x1300D,
 },
 [0x1300E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A012",
  direction="l",
  linebreak="al",
  unicodeslot=0x1300E,
 },
 [0x1300F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A013",
  direction="l",
  linebreak="al",
  unicodeslot=0x1300F,
 },
 [0x13010]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13010,
 },
 [0x13011]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A014A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13011,
 },
 [0x13012]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A015",
  direction="l",
  linebreak="al",
  unicodeslot=0x13012,
 },
 [0x13013]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A016",
  direction="l",
  linebreak="al",
  unicodeslot=0x13013,
 },
 [0x13014]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A017",
  direction="l",
  linebreak="al",
  unicodeslot=0x13014,
 },
 [0x13015]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A017A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13015,
 },
 [0x13016]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13016,
 },
 [0x13017]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13017,
 },
 [0x13018]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13018,
 },
 [0x13019]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13019,
 },
 [0x1301A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A022",
  direction="l",
  linebreak="al",
  unicodeslot=0x1301A,
 },
 [0x1301B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A023",
  direction="l",
  linebreak="al",
  unicodeslot=0x1301B,
 },
 [0x1301C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A024",
  direction="l",
  linebreak="al",
  unicodeslot=0x1301C,
 },
 [0x1301D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A025",
  direction="l",
  linebreak="al",
  unicodeslot=0x1301D,
 },
 [0x1301E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A026",
  direction="l",
  linebreak="al",
  unicodeslot=0x1301E,
 },
 [0x1301F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A027",
  direction="l",
  linebreak="al",
  unicodeslot=0x1301F,
 },
 [0x13020]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A028",
  direction="l",
  linebreak="al",
  unicodeslot=0x13020,
 },
 [0x13021]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A029",
  direction="l",
  linebreak="al",
  unicodeslot=0x13021,
 },
 [0x13022]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A030",
  direction="l",
  linebreak="al",
  unicodeslot=0x13022,
 },
 [0x13023]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A031",
  direction="l",
  linebreak="al",
  unicodeslot=0x13023,
 },
 [0x13024]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A032",
  direction="l",
  linebreak="al",
  unicodeslot=0x13024,
 },
 [0x13025]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A032A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13025,
 },
 [0x13026]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A033",
  direction="l",
  linebreak="al",
  unicodeslot=0x13026,
 },
 [0x13027]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A034",
  direction="l",
  linebreak="al",
  unicodeslot=0x13027,
 },
 [0x13028]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A035",
  direction="l",
  linebreak="al",
  unicodeslot=0x13028,
 },
 [0x13029]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A036",
  direction="l",
  linebreak="al",
  unicodeslot=0x13029,
 },
 [0x1302A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A037",
  direction="l",
  linebreak="al",
  unicodeslot=0x1302A,
 },
 [0x1302B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A038",
  direction="l",
  linebreak="al",
  unicodeslot=0x1302B,
 },
 [0x1302C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A039",
  direction="l",
  linebreak="al",
  unicodeslot=0x1302C,
 },
 [0x1302D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A040",
  direction="l",
  linebreak="al",
  unicodeslot=0x1302D,
 },
 [0x1302E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A040A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1302E,
 },
 [0x1302F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A041",
  direction="l",
  linebreak="al",
  unicodeslot=0x1302F,
 },
 [0x13030]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A042",
  direction="l",
  linebreak="al",
  unicodeslot=0x13030,
 },
 [0x13031]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A042A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13031,
 },
 [0x13032]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A043",
  direction="l",
  linebreak="al",
  unicodeslot=0x13032,
 },
 [0x13033]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A043A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13033,
 },
 [0x13034]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A044",
  direction="l",
  linebreak="al",
  unicodeslot=0x13034,
 },
 [0x13035]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A045",
  direction="l",
  linebreak="al",
  unicodeslot=0x13035,
 },
 [0x13036]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A045A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13036,
 },
 [0x13037]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A046",
  direction="l",
  linebreak="al",
  unicodeslot=0x13037,
 },
 [0x13038]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A047",
  direction="l",
  linebreak="al",
  unicodeslot=0x13038,
 },
 [0x13039]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A048",
  direction="l",
  linebreak="al",
  unicodeslot=0x13039,
 },
 [0x1303A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A049",
  direction="l",
  linebreak="al",
  unicodeslot=0x1303A,
 },
 [0x1303B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A050",
  direction="l",
  linebreak="al",
  unicodeslot=0x1303B,
 },
 [0x1303C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A051",
  direction="l",
  linebreak="al",
  unicodeslot=0x1303C,
 },
 [0x1303D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A052",
  direction="l",
  linebreak="al",
  unicodeslot=0x1303D,
 },
 [0x1303E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A053",
  direction="l",
  linebreak="al",
  unicodeslot=0x1303E,
 },
 [0x1303F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A054",
  direction="l",
  linebreak="al",
  unicodeslot=0x1303F,
 },
 [0x13040]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A055",
  direction="l",
  linebreak="al",
  unicodeslot=0x13040,
 },
 [0x13041]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A056",
  direction="l",
  linebreak="al",
  unicodeslot=0x13041,
 },
 [0x13042]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A057",
  direction="l",
  linebreak="al",
  unicodeslot=0x13042,
 },
 [0x13043]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A058",
  direction="l",
  linebreak="al",
  unicodeslot=0x13043,
 },
 [0x13044]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A059",
  direction="l",
  linebreak="al",
  unicodeslot=0x13044,
 },
 [0x13045]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A060",
  direction="l",
  linebreak="al",
  unicodeslot=0x13045,
 },
 [0x13046]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A061",
  direction="l",
  linebreak="al",
  unicodeslot=0x13046,
 },
 [0x13047]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A062",
  direction="l",
  linebreak="al",
  unicodeslot=0x13047,
 },
 [0x13048]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A063",
  direction="l",
  linebreak="al",
  unicodeslot=0x13048,
 },
 [0x13049]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A064",
  direction="l",
  linebreak="al",
  unicodeslot=0x13049,
 },
 [0x1304A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A065",
  direction="l",
  linebreak="al",
  unicodeslot=0x1304A,
 },
 [0x1304B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A066",
  direction="l",
  linebreak="al",
  unicodeslot=0x1304B,
 },
 [0x1304C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A067",
  direction="l",
  linebreak="al",
  unicodeslot=0x1304C,
 },
 [0x1304D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A068",
  direction="l",
  linebreak="al",
  unicodeslot=0x1304D,
 },
 [0x1304E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A069",
  direction="l",
  linebreak="al",
  unicodeslot=0x1304E,
 },
 [0x1304F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH A070",
  direction="l",
  linebreak="al",
  unicodeslot=0x1304F,
 },
 [0x13050]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13050,
 },
 [0x13051]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13051,
 },
 [0x13052]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13052,
 },
 [0x13053]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13053,
 },
 [0x13054]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13054,
 },
 [0x13055]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B005A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13055,
 },
 [0x13056]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13056,
 },
 [0x13057]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13057,
 },
 [0x13058]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13058,
 },
 [0x13059]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH B009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13059,
 },
 [0x1305A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1305A,
 },
 [0x1305B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1305B,
 },
 [0x1305C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C002A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1305C,
 },
 [0x1305D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C002B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1305D,
 },
 [0x1305E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C002C",
  direction="l",
  linebreak="al",
  unicodeslot=0x1305E,
 },
 [0x1305F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1305F,
 },
 [0x13060]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13060,
 },
 [0x13061]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13061,
 },
 [0x13062]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13062,
 },
 [0x13063]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13063,
 },
 [0x13064]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13064,
 },
 [0x13065]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13065,
 },
 [0x13066]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C010",
  direction="l",
  linebreak="al",
  unicodeslot=0x13066,
 },
 [0x13067]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C010A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13067,
 },
 [0x13068]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13068,
 },
 [0x13069]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C012",
  direction="l",
  linebreak="al",
  unicodeslot=0x13069,
 },
 [0x1306A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C013",
  direction="l",
  linebreak="al",
  unicodeslot=0x1306A,
 },
 [0x1306B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C014",
  direction="l",
  linebreak="al",
  unicodeslot=0x1306B,
 },
 [0x1306C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C015",
  direction="l",
  linebreak="al",
  unicodeslot=0x1306C,
 },
 [0x1306D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C016",
  direction="l",
  linebreak="al",
  unicodeslot=0x1306D,
 },
 [0x1306E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C017",
  direction="l",
  linebreak="al",
  unicodeslot=0x1306E,
 },
 [0x1306F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C018",
  direction="l",
  linebreak="al",
  unicodeslot=0x1306F,
 },
 [0x13070]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13070,
 },
 [0x13071]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13071,
 },
 [0x13072]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13072,
 },
 [0x13073]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C022",
  direction="l",
  linebreak="al",
  unicodeslot=0x13073,
 },
 [0x13074]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C023",
  direction="l",
  linebreak="al",
  unicodeslot=0x13074,
 },
 [0x13075]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH C024",
  direction="l",
  linebreak="al",
  unicodeslot=0x13075,
 },
 [0x13076]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13076,
 },
 [0x13077]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13077,
 },
 [0x13078]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13078,
 },
 [0x13079]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13079,
 },
 [0x1307A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D005",
  direction="l",
  linebreak="al",
  unicodeslot=0x1307A,
 },
 [0x1307B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D006",
  direction="l",
  linebreak="al",
  unicodeslot=0x1307B,
 },
 [0x1307C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D007",
  direction="l",
  linebreak="al",
  unicodeslot=0x1307C,
 },
 [0x1307D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D008",
  direction="l",
  linebreak="al",
  unicodeslot=0x1307D,
 },
 [0x1307E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D008A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1307E,
 },
 [0x1307F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D009",
  direction="l",
  linebreak="al",
  unicodeslot=0x1307F,
 },
 [0x13080]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D010",
  direction="l",
  linebreak="al",
  unicodeslot=0x13080,
 },
 [0x13081]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13081,
 },
 [0x13082]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D012",
  direction="l",
  linebreak="al",
  unicodeslot=0x13082,
 },
 [0x13083]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D013",
  direction="l",
  linebreak="al",
  unicodeslot=0x13083,
 },
 [0x13084]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13084,
 },
 [0x13085]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D015",
  direction="l",
  linebreak="al",
  unicodeslot=0x13085,
 },
 [0x13086]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D016",
  direction="l",
  linebreak="al",
  unicodeslot=0x13086,
 },
 [0x13087]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D017",
  direction="l",
  linebreak="al",
  unicodeslot=0x13087,
 },
 [0x13088]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13088,
 },
 [0x13089]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13089,
 },
 [0x1308A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D020",
  direction="l",
  linebreak="al",
  unicodeslot=0x1308A,
 },
 [0x1308B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D021",
  direction="l",
  linebreak="al",
  unicodeslot=0x1308B,
 },
 [0x1308C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D022",
  direction="l",
  linebreak="al",
  unicodeslot=0x1308C,
 },
 [0x1308D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D023",
  direction="l",
  linebreak="al",
  unicodeslot=0x1308D,
 },
 [0x1308E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D024",
  direction="l",
  linebreak="al",
  unicodeslot=0x1308E,
 },
 [0x1308F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D025",
  direction="l",
  linebreak="al",
  unicodeslot=0x1308F,
 },
 [0x13090]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D026",
  direction="l",
  linebreak="al",
  unicodeslot=0x13090,
 },
 [0x13091]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D027",
  direction="l",
  linebreak="al",
  unicodeslot=0x13091,
 },
 [0x13092]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D027A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13092,
 },
 [0x13093]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D028",
  direction="l",
  linebreak="al",
  unicodeslot=0x13093,
 },
 [0x13094]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D029",
  direction="l",
  linebreak="al",
  unicodeslot=0x13094,
 },
 [0x13095]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D030",
  direction="l",
  linebreak="al",
  unicodeslot=0x13095,
 },
 [0x13096]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D031",
  direction="l",
  linebreak="al",
  unicodeslot=0x13096,
 },
 [0x13097]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D031A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13097,
 },
 [0x13098]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D032",
  direction="l",
  linebreak="al",
  unicodeslot=0x13098,
 },
 [0x13099]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D033",
  direction="l",
  linebreak="al",
  unicodeslot=0x13099,
 },
 [0x1309A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D034",
  direction="l",
  linebreak="al",
  unicodeslot=0x1309A,
 },
 [0x1309B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D034A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1309B,
 },
 [0x1309C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D035",
  direction="l",
  linebreak="al",
  unicodeslot=0x1309C,
 },
 [0x1309D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D036",
  direction="l",
  linebreak="al",
  unicodeslot=0x1309D,
 },
 [0x1309E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D037",
  direction="l",
  linebreak="al",
  unicodeslot=0x1309E,
 },
 [0x1309F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D038",
  direction="l",
  linebreak="al",
  unicodeslot=0x1309F,
 },
 [0x130A0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D039",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A0,
 },
 [0x130A1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D040",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A1,
 },
 [0x130A2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D041",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A2,
 },
 [0x130A3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D042",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A3,
 },
 [0x130A4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D043",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A4,
 },
 [0x130A5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D044",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A5,
 },
 [0x130A6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D045",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A6,
 },
 [0x130A7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D046",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A7,
 },
 [0x130A8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D046A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A8,
 },
 [0x130A9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D047",
  direction="l",
  linebreak="al",
  unicodeslot=0x130A9,
 },
 [0x130AA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D048",
  direction="l",
  linebreak="al",
  unicodeslot=0x130AA,
 },
 [0x130AB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D048A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130AB,
 },
 [0x130AC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D049",
  direction="l",
  linebreak="al",
  unicodeslot=0x130AC,
 },
 [0x130AD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050",
  direction="l",
  linebreak="al",
  unicodeslot=0x130AD,
 },
 [0x130AE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130AE,
 },
 [0x130AF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050B",
  direction="l",
  linebreak="al",
  unicodeslot=0x130AF,
 },
 [0x130B0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050C",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B0,
 },
 [0x130B1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050D",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B1,
 },
 [0x130B2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050E",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B2,
 },
 [0x130B3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050F",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B3,
 },
 [0x130B4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050G",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B4,
 },
 [0x130B5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050H",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B5,
 },
 [0x130B6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D050I",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B6,
 },
 [0x130B7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D051",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B7,
 },
 [0x130B8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D052",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B8,
 },
 [0x130B9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D052A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130B9,
 },
 [0x130BA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D053",
  direction="l",
  linebreak="al",
  unicodeslot=0x130BA,
 },
 [0x130BB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D054",
  direction="l",
  linebreak="al",
  unicodeslot=0x130BB,
 },
 [0x130BC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D054A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130BC,
 },
 [0x130BD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D055",
  direction="l",
  linebreak="al",
  unicodeslot=0x130BD,
 },
 [0x130BE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D056",
  direction="l",
  linebreak="al",
  unicodeslot=0x130BE,
 },
 [0x130BF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D057",
  direction="l",
  linebreak="al",
  unicodeslot=0x130BF,
 },
 [0x130C0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D058",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C0,
 },
 [0x130C1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D059",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C1,
 },
 [0x130C2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D060",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C2,
 },
 [0x130C3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D061",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C3,
 },
 [0x130C4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D062",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C4,
 },
 [0x130C5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D063",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C5,
 },
 [0x130C6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D064",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C6,
 },
 [0x130C7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D065",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C7,
 },
 [0x130C8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D066",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C8,
 },
 [0x130C9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067",
  direction="l",
  linebreak="al",
  unicodeslot=0x130C9,
 },
 [0x130CA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130CA,
 },
 [0x130CB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067B",
  direction="l",
  linebreak="al",
  unicodeslot=0x130CB,
 },
 [0x130CC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067C",
  direction="l",
  linebreak="al",
  unicodeslot=0x130CC,
 },
 [0x130CD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067D",
  direction="l",
  linebreak="al",
  unicodeslot=0x130CD,
 },
 [0x130CE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067E",
  direction="l",
  linebreak="al",
  unicodeslot=0x130CE,
 },
 [0x130CF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067F",
  direction="l",
  linebreak="al",
  unicodeslot=0x130CF,
 },
 [0x130D0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067G",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D0,
 },
 [0x130D1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH D067H",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D1,
 },
 [0x130D2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E001",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D2,
 },
 [0x130D3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E002",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D3,
 },
 [0x130D4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E003",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D4,
 },
 [0x130D5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E004",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D5,
 },
 [0x130D6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E005",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D6,
 },
 [0x130D7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E006",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D7,
 },
 [0x130D8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E007",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D8,
 },
 [0x130D9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E008",
  direction="l",
  linebreak="al",
  unicodeslot=0x130D9,
 },
 [0x130DA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E008A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130DA,
 },
 [0x130DB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E009",
  direction="l",
  linebreak="al",
  unicodeslot=0x130DB,
 },
 [0x130DC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E009A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130DC,
 },
 [0x130DD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E010",
  direction="l",
  linebreak="al",
  unicodeslot=0x130DD,
 },
 [0x130DE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E011",
  direction="l",
  linebreak="al",
  unicodeslot=0x130DE,
 },
 [0x130DF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E012",
  direction="l",
  linebreak="al",
  unicodeslot=0x130DF,
 },
 [0x130E0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E013",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E0,
 },
 [0x130E1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E014",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E1,
 },
 [0x130E2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E015",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E2,
 },
 [0x130E3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E016",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E3,
 },
 [0x130E4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E016A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E4,
 },
 [0x130E5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E017",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E5,
 },
 [0x130E6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E017A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E6,
 },
 [0x130E7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E018",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E7,
 },
 [0x130E8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E019",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E8,
 },
 [0x130E9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E020",
  direction="l",
  linebreak="al",
  unicodeslot=0x130E9,
 },
 [0x130EA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E020A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130EA,
 },
 [0x130EB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E021",
  direction="l",
  linebreak="al",
  unicodeslot=0x130EB,
 },
 [0x130EC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E022",
  direction="l",
  linebreak="al",
  unicodeslot=0x130EC,
 },
 [0x130ED]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E023",
  direction="l",
  linebreak="al",
  unicodeslot=0x130ED,
 },
 [0x130EE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E024",
  direction="l",
  linebreak="al",
  unicodeslot=0x130EE,
 },
 [0x130EF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E025",
  direction="l",
  linebreak="al",
  unicodeslot=0x130EF,
 },
 [0x130F0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E026",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F0,
 },
 [0x130F1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E027",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F1,
 },
 [0x130F2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E028",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F2,
 },
 [0x130F3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E028A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F3,
 },
 [0x130F4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E029",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F4,
 },
 [0x130F5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E030",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F5,
 },
 [0x130F6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E031",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F6,
 },
 [0x130F7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E032",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F7,
 },
 [0x130F8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E033",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F8,
 },
 [0x130F9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E034",
  direction="l",
  linebreak="al",
  unicodeslot=0x130F9,
 },
 [0x130FA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E034A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130FA,
 },
 [0x130FB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E036",
  direction="l",
  linebreak="al",
  unicodeslot=0x130FB,
 },
 [0x130FC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E037",
  direction="l",
  linebreak="al",
  unicodeslot=0x130FC,
 },
 [0x130FD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH E038",
  direction="l",
  linebreak="al",
  unicodeslot=0x130FD,
 },
 [0x130FE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F001",
  direction="l",
  linebreak="al",
  unicodeslot=0x130FE,
 },
 [0x130FF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F001A",
  direction="l",
  linebreak="al",
  unicodeslot=0x130FF,
 },
 [0x13100]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13100,
 },
 [0x13101]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13101,
 },
 [0x13102]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13102,
 },
 [0x13103]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13103,
 },
 [0x13104]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13104,
 },
 [0x13105]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13105,
 },
 [0x13106]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13106,
 },
 [0x13107]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13107,
 },
 [0x13108]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F010",
  direction="l",
  linebreak="al",
  unicodeslot=0x13108,
 },
 [0x13109]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13109,
 },
 [0x1310A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F012",
  direction="l",
  linebreak="al",
  unicodeslot=0x1310A,
 },
 [0x1310B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F013",
  direction="l",
  linebreak="al",
  unicodeslot=0x1310B,
 },
 [0x1310C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F013A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1310C,
 },
 [0x1310D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F014",
  direction="l",
  linebreak="al",
  unicodeslot=0x1310D,
 },
 [0x1310E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F015",
  direction="l",
  linebreak="al",
  unicodeslot=0x1310E,
 },
 [0x1310F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F016",
  direction="l",
  linebreak="al",
  unicodeslot=0x1310F,
 },
 [0x13110]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F017",
  direction="l",
  linebreak="al",
  unicodeslot=0x13110,
 },
 [0x13111]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13111,
 },
 [0x13112]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13112,
 },
 [0x13113]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13113,
 },
 [0x13114]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13114,
 },
 [0x13115]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F021A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13115,
 },
 [0x13116]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F022",
  direction="l",
  linebreak="al",
  unicodeslot=0x13116,
 },
 [0x13117]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F023",
  direction="l",
  linebreak="al",
  unicodeslot=0x13117,
 },
 [0x13118]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F024",
  direction="l",
  linebreak="al",
  unicodeslot=0x13118,
 },
 [0x13119]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F025",
  direction="l",
  linebreak="al",
  unicodeslot=0x13119,
 },
 [0x1311A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F026",
  direction="l",
  linebreak="al",
  unicodeslot=0x1311A,
 },
 [0x1311B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F027",
  direction="l",
  linebreak="al",
  unicodeslot=0x1311B,
 },
 [0x1311C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F028",
  direction="l",
  linebreak="al",
  unicodeslot=0x1311C,
 },
 [0x1311D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F029",
  direction="l",
  linebreak="al",
  unicodeslot=0x1311D,
 },
 [0x1311E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F030",
  direction="l",
  linebreak="al",
  unicodeslot=0x1311E,
 },
 [0x1311F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F031",
  direction="l",
  linebreak="al",
  unicodeslot=0x1311F,
 },
 [0x13120]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F031A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13120,
 },
 [0x13121]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F032",
  direction="l",
  linebreak="al",
  unicodeslot=0x13121,
 },
 [0x13122]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F033",
  direction="l",
  linebreak="al",
  unicodeslot=0x13122,
 },
 [0x13123]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F034",
  direction="l",
  linebreak="al",
  unicodeslot=0x13123,
 },
 [0x13124]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F035",
  direction="l",
  linebreak="al",
  unicodeslot=0x13124,
 },
 [0x13125]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F036",
  direction="l",
  linebreak="al",
  unicodeslot=0x13125,
 },
 [0x13126]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F037",
  direction="l",
  linebreak="al",
  unicodeslot=0x13126,
 },
 [0x13127]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F037A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13127,
 },
 [0x13128]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F038",
  direction="l",
  linebreak="al",
  unicodeslot=0x13128,
 },
 [0x13129]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F038A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13129,
 },
 [0x1312A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F039",
  direction="l",
  linebreak="al",
  unicodeslot=0x1312A,
 },
 [0x1312B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F040",
  direction="l",
  linebreak="al",
  unicodeslot=0x1312B,
 },
 [0x1312C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F041",
  direction="l",
  linebreak="al",
  unicodeslot=0x1312C,
 },
 [0x1312D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F042",
  direction="l",
  linebreak="al",
  unicodeslot=0x1312D,
 },
 [0x1312E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F043",
  direction="l",
  linebreak="al",
  unicodeslot=0x1312E,
 },
 [0x1312F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F044",
  direction="l",
  linebreak="al",
  unicodeslot=0x1312F,
 },
 [0x13130]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F045",
  direction="l",
  linebreak="al",
  unicodeslot=0x13130,
 },
 [0x13131]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F045A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13131,
 },
 [0x13132]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F046",
  direction="l",
  linebreak="al",
  unicodeslot=0x13132,
 },
 [0x13133]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F046A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13133,
 },
 [0x13134]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F047",
  direction="l",
  linebreak="al",
  unicodeslot=0x13134,
 },
 [0x13135]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F047A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13135,
 },
 [0x13136]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F048",
  direction="l",
  linebreak="al",
  unicodeslot=0x13136,
 },
 [0x13137]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F049",
  direction="l",
  linebreak="al",
  unicodeslot=0x13137,
 },
 [0x13138]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F050",
  direction="l",
  linebreak="al",
  unicodeslot=0x13138,
 },
 [0x13139]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F051",
  direction="l",
  linebreak="al",
  unicodeslot=0x13139,
 },
 [0x1313A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F051A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1313A,
 },
 [0x1313B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F051B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1313B,
 },
 [0x1313C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F051C",
  direction="l",
  linebreak="al",
  unicodeslot=0x1313C,
 },
 [0x1313D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F052",
  direction="l",
  linebreak="al",
  unicodeslot=0x1313D,
 },
 [0x1313E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH F053",
  direction="l",
  linebreak="al",
  unicodeslot=0x1313E,
 },
 [0x1313F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1313F,
 },
 [0x13140]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13140,
 },
 [0x13141]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13141,
 },
 [0x13142]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13142,
 },
 [0x13143]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13143,
 },
 [0x13144]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13144,
 },
 [0x13145]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G006A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13145,
 },
 [0x13146]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13146,
 },
 [0x13147]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G007A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13147,
 },
 [0x13148]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G007B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13148,
 },
 [0x13149]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13149,
 },
 [0x1314A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G009",
  direction="l",
  linebreak="al",
  unicodeslot=0x1314A,
 },
 [0x1314B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G010",
  direction="l",
  linebreak="al",
  unicodeslot=0x1314B,
 },
 [0x1314C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G011",
  direction="l",
  linebreak="al",
  unicodeslot=0x1314C,
 },
 [0x1314D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G011A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1314D,
 },
 [0x1314E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G012",
  direction="l",
  linebreak="al",
  unicodeslot=0x1314E,
 },
 [0x1314F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G013",
  direction="l",
  linebreak="al",
  unicodeslot=0x1314F,
 },
 [0x13150]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13150,
 },
 [0x13151]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G015",
  direction="l",
  linebreak="al",
  unicodeslot=0x13151,
 },
 [0x13152]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G016",
  direction="l",
  linebreak="al",
  unicodeslot=0x13152,
 },
 [0x13153]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G017",
  direction="l",
  linebreak="al",
  unicodeslot=0x13153,
 },
 [0x13154]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13154,
 },
 [0x13155]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13155,
 },
 [0x13156]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13156,
 },
 [0x13157]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G020A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13157,
 },
 [0x13158]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13158,
 },
 [0x13159]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G022",
  direction="l",
  linebreak="al",
  unicodeslot=0x13159,
 },
 [0x1315A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G023",
  direction="l",
  linebreak="al",
  unicodeslot=0x1315A,
 },
 [0x1315B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G024",
  direction="l",
  linebreak="al",
  unicodeslot=0x1315B,
 },
 [0x1315C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G025",
  direction="l",
  linebreak="al",
  unicodeslot=0x1315C,
 },
 [0x1315D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G026",
  direction="l",
  linebreak="al",
  unicodeslot=0x1315D,
 },
 [0x1315E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G026A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1315E,
 },
 [0x1315F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G027",
  direction="l",
  linebreak="al",
  unicodeslot=0x1315F,
 },
 [0x13160]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G028",
  direction="l",
  linebreak="al",
  unicodeslot=0x13160,
 },
 [0x13161]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G029",
  direction="l",
  linebreak="al",
  unicodeslot=0x13161,
 },
 [0x13162]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G030",
  direction="l",
  linebreak="al",
  unicodeslot=0x13162,
 },
 [0x13163]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G031",
  direction="l",
  linebreak="al",
  unicodeslot=0x13163,
 },
 [0x13164]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G032",
  direction="l",
  linebreak="al",
  unicodeslot=0x13164,
 },
 [0x13165]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G033",
  direction="l",
  linebreak="al",
  unicodeslot=0x13165,
 },
 [0x13166]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G034",
  direction="l",
  linebreak="al",
  unicodeslot=0x13166,
 },
 [0x13167]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G035",
  direction="l",
  linebreak="al",
  unicodeslot=0x13167,
 },
 [0x13168]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G036",
  direction="l",
  linebreak="al",
  unicodeslot=0x13168,
 },
 [0x13169]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G036A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13169,
 },
 [0x1316A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G037",
  direction="l",
  linebreak="al",
  unicodeslot=0x1316A,
 },
 [0x1316B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G037A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1316B,
 },
 [0x1316C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G038",
  direction="l",
  linebreak="al",
  unicodeslot=0x1316C,
 },
 [0x1316D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G039",
  direction="l",
  linebreak="al",
  unicodeslot=0x1316D,
 },
 [0x1316E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G040",
  direction="l",
  linebreak="al",
  unicodeslot=0x1316E,
 },
 [0x1316F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G041",
  direction="l",
  linebreak="al",
  unicodeslot=0x1316F,
 },
 [0x13170]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G042",
  direction="l",
  linebreak="al",
  unicodeslot=0x13170,
 },
 [0x13171]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G043",
  direction="l",
  linebreak="al",
  unicodeslot=0x13171,
 },
 [0x13172]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G043A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13172,
 },
 [0x13173]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G044",
  direction="l",
  linebreak="al",
  unicodeslot=0x13173,
 },
 [0x13174]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G045",
  direction="l",
  linebreak="al",
  unicodeslot=0x13174,
 },
 [0x13175]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G045A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13175,
 },
 [0x13176]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G046",
  direction="l",
  linebreak="al",
  unicodeslot=0x13176,
 },
 [0x13177]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G047",
  direction="l",
  linebreak="al",
  unicodeslot=0x13177,
 },
 [0x13178]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G048",
  direction="l",
  linebreak="al",
  unicodeslot=0x13178,
 },
 [0x13179]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G049",
  direction="l",
  linebreak="al",
  unicodeslot=0x13179,
 },
 [0x1317A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G050",
  direction="l",
  linebreak="al",
  unicodeslot=0x1317A,
 },
 [0x1317B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G051",
  direction="l",
  linebreak="al",
  unicodeslot=0x1317B,
 },
 [0x1317C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G052",
  direction="l",
  linebreak="al",
  unicodeslot=0x1317C,
 },
 [0x1317D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G053",
  direction="l",
  linebreak="al",
  unicodeslot=0x1317D,
 },
 [0x1317E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH G054",
  direction="l",
  linebreak="al",
  unicodeslot=0x1317E,
 },
 [0x1317F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1317F,
 },
 [0x13180]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13180,
 },
 [0x13181]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13181,
 },
 [0x13182]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13182,
 },
 [0x13183]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13183,
 },
 [0x13184]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13184,
 },
 [0x13185]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H006A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13185,
 },
 [0x13186]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13186,
 },
 [0x13187]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH H008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13187,
 },
 [0x13188]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13188,
 },
 [0x13189]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13189,
 },
 [0x1318A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1318A,
 },
 [0x1318B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1318B,
 },
 [0x1318C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I005",
  direction="l",
  linebreak="al",
  unicodeslot=0x1318C,
 },
 [0x1318D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I005A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1318D,
 },
 [0x1318E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I006",
  direction="l",
  linebreak="al",
  unicodeslot=0x1318E,
 },
 [0x1318F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I007",
  direction="l",
  linebreak="al",
  unicodeslot=0x1318F,
 },
 [0x13190]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13190,
 },
 [0x13191]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13191,
 },
 [0x13192]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I009A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13192,
 },
 [0x13193]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I010",
  direction="l",
  linebreak="al",
  unicodeslot=0x13193,
 },
 [0x13194]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I010A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13194,
 },
 [0x13195]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13195,
 },
 [0x13196]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I011A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13196,
 },
 [0x13197]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I012",
  direction="l",
  linebreak="al",
  unicodeslot=0x13197,
 },
 [0x13198]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I013",
  direction="l",
  linebreak="al",
  unicodeslot=0x13198,
 },
 [0x13199]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13199,
 },
 [0x1319A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH I015",
  direction="l",
  linebreak="al",
  unicodeslot=0x1319A,
 },
 [0x1319B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH K001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1319B,
 },
 [0x1319C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH K002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1319C,
 },
 [0x1319D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH K003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1319D,
 },
 [0x1319E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH K004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1319E,
 },
 [0x1319F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH K005",
  direction="l",
  linebreak="al",
  unicodeslot=0x1319F,
 },
 [0x131A0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH K006",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A0,
 },
 [0x131A1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH K007",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A1,
 },
 [0x131A2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH K008",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A2,
 },
 [0x131A3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L001",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A3,
 },
 [0x131A4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L002",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A4,
 },
 [0x131A5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L002A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A5,
 },
 [0x131A6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L003",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A6,
 },
 [0x131A7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L004",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A7,
 },
 [0x131A8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L005",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A8,
 },
 [0x131A9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L006",
  direction="l",
  linebreak="al",
  unicodeslot=0x131A9,
 },
 [0x131AA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L006A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131AA,
 },
 [0x131AB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L007",
  direction="l",
  linebreak="al",
  unicodeslot=0x131AB,
 },
 [0x131AC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH L008",
  direction="l",
  linebreak="al",
  unicodeslot=0x131AC,
 },
 [0x131AD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M001",
  direction="l",
  linebreak="al",
  unicodeslot=0x131AD,
 },
 [0x131AE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M001A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131AE,
 },
 [0x131AF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M001B",
  direction="l",
  linebreak="al",
  unicodeslot=0x131AF,
 },
 [0x131B0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M002",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B0,
 },
 [0x131B1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M003",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B1,
 },
 [0x131B2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M003A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B2,
 },
 [0x131B3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M004",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B3,
 },
 [0x131B4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M005",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B4,
 },
 [0x131B5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M006",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B5,
 },
 [0x131B6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M007",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B6,
 },
 [0x131B7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M008",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B7,
 },
 [0x131B8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M009",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B8,
 },
 [0x131B9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M010",
  direction="l",
  linebreak="al",
  unicodeslot=0x131B9,
 },
 [0x131BA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M010A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131BA,
 },
 [0x131BB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M011",
  direction="l",
  linebreak="al",
  unicodeslot=0x131BB,
 },
 [0x131BC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012",
  direction="l",
  linebreak="al",
  unicodeslot=0x131BC,
 },
 [0x131BD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131BD,
 },
 [0x131BE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012B",
  direction="l",
  linebreak="al",
  unicodeslot=0x131BE,
 },
 [0x131BF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012C",
  direction="l",
  linebreak="al",
  unicodeslot=0x131BF,
 },
 [0x131C0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012D",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C0,
 },
 [0x131C1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012E",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C1,
 },
 [0x131C2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012F",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C2,
 },
 [0x131C3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012G",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C3,
 },
 [0x131C4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M012H",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C4,
 },
 [0x131C5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M013",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C5,
 },
 [0x131C6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M014",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C6,
 },
 [0x131C7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M015",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C7,
 },
 [0x131C8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M015A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C8,
 },
 [0x131C9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M016",
  direction="l",
  linebreak="al",
  unicodeslot=0x131C9,
 },
 [0x131CA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M016A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131CA,
 },
 [0x131CB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M017",
  direction="l",
  linebreak="al",
  unicodeslot=0x131CB,
 },
 [0x131CC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M017A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131CC,
 },
 [0x131CD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M018",
  direction="l",
  linebreak="al",
  unicodeslot=0x131CD,
 },
 [0x131CE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M019",
  direction="l",
  linebreak="al",
  unicodeslot=0x131CE,
 },
 [0x131CF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M020",
  direction="l",
  linebreak="al",
  unicodeslot=0x131CF,
 },
 [0x131D0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M021",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D0,
 },
 [0x131D1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M022",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D1,
 },
 [0x131D2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M022A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D2,
 },
 [0x131D3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M023",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D3,
 },
 [0x131D4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M024",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D4,
 },
 [0x131D5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M024A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D5,
 },
 [0x131D6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M025",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D6,
 },
 [0x131D7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M026",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D7,
 },
 [0x131D8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M027",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D8,
 },
 [0x131D9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M028",
  direction="l",
  linebreak="al",
  unicodeslot=0x131D9,
 },
 [0x131DA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M028A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131DA,
 },
 [0x131DB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M029",
  direction="l",
  linebreak="al",
  unicodeslot=0x131DB,
 },
 [0x131DC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M030",
  direction="l",
  linebreak="al",
  unicodeslot=0x131DC,
 },
 [0x131DD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M031",
  direction="l",
  linebreak="al",
  unicodeslot=0x131DD,
 },
 [0x131DE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M031A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131DE,
 },
 [0x131DF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M032",
  direction="l",
  linebreak="al",
  unicodeslot=0x131DF,
 },
 [0x131E0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M033",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E0,
 },
 [0x131E1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M033A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E1,
 },
 [0x131E2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M033B",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E2,
 },
 [0x131E3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M034",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E3,
 },
 [0x131E4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M035",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E4,
 },
 [0x131E5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M036",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E5,
 },
 [0x131E6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M037",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E6,
 },
 [0x131E7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M038",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E7,
 },
 [0x131E8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M039",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E8,
 },
 [0x131E9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M040",
  direction="l",
  linebreak="al",
  unicodeslot=0x131E9,
 },
 [0x131EA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M040A",
  direction="l",
  linebreak="al",
  unicodeslot=0x131EA,
 },
 [0x131EB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M041",
  direction="l",
  linebreak="al",
  unicodeslot=0x131EB,
 },
 [0x131EC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M042",
  direction="l",
  linebreak="al",
  unicodeslot=0x131EC,
 },
 [0x131ED]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M043",
  direction="l",
  linebreak="al",
  unicodeslot=0x131ED,
 },
 [0x131EE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH M044",
  direction="l",
  linebreak="al",
  unicodeslot=0x131EE,
 },
 [0x131EF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N001",
  direction="l",
  linebreak="al",
  unicodeslot=0x131EF,
 },
 [0x131F0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N002",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F0,
 },
 [0x131F1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N003",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F1,
 },
 [0x131F2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N004",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F2,
 },
 [0x131F3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N005",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F3,
 },
 [0x131F4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N006",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F4,
 },
 [0x131F5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N007",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F5,
 },
 [0x131F6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N008",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F6,
 },
 [0x131F7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N009",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F7,
 },
 [0x131F8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N010",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F8,
 },
 [0x131F9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N011",
  direction="l",
  linebreak="al",
  unicodeslot=0x131F9,
 },
 [0x131FA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N012",
  direction="l",
  linebreak="al",
  unicodeslot=0x131FA,
 },
 [0x131FB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N013",
  direction="l",
  linebreak="al",
  unicodeslot=0x131FB,
 },
 [0x131FC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N014",
  direction="l",
  linebreak="al",
  unicodeslot=0x131FC,
 },
 [0x131FD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N015",
  direction="l",
  linebreak="al",
  unicodeslot=0x131FD,
 },
 [0x131FE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N016",
  direction="l",
  linebreak="al",
  unicodeslot=0x131FE,
 },
 [0x131FF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N017",
  direction="l",
  linebreak="al",
  unicodeslot=0x131FF,
 },
 [0x13200]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13200,
 },
 [0x13201]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N018A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13201,
 },
 [0x13202]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N018B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13202,
 },
 [0x13203]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13203,
 },
 [0x13204]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13204,
 },
 [0x13205]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13205,
 },
 [0x13206]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N022",
  direction="l",
  linebreak="al",
  unicodeslot=0x13206,
 },
 [0x13207]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N023",
  direction="l",
  linebreak="al",
  unicodeslot=0x13207,
 },
 [0x13208]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N024",
  direction="l",
  linebreak="al",
  unicodeslot=0x13208,
 },
 [0x13209]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N025",
  direction="l",
  linebreak="al",
  unicodeslot=0x13209,
 },
 [0x1320A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N025A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1320A,
 },
 [0x1320B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N026",
  direction="l",
  linebreak="al",
  unicodeslot=0x1320B,
 },
 [0x1320C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N027",
  direction="l",
  linebreak="al",
  unicodeslot=0x1320C,
 },
 [0x1320D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N028",
  direction="l",
  linebreak="al",
  unicodeslot=0x1320D,
 },
 [0x1320E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N029",
  direction="l",
  linebreak="al",
  unicodeslot=0x1320E,
 },
 [0x1320F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N030",
  direction="l",
  linebreak="al",
  unicodeslot=0x1320F,
 },
 [0x13210]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N031",
  direction="l",
  linebreak="al",
  unicodeslot=0x13210,
 },
 [0x13211]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N032",
  direction="l",
  linebreak="al",
  unicodeslot=0x13211,
 },
 [0x13212]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N033",
  direction="l",
  linebreak="al",
  unicodeslot=0x13212,
 },
 [0x13213]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N033A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13213,
 },
 [0x13214]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N034",
  direction="l",
  linebreak="al",
  unicodeslot=0x13214,
 },
 [0x13215]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N034A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13215,
 },
 [0x13216]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N035",
  direction="l",
  linebreak="al",
  unicodeslot=0x13216,
 },
 [0x13217]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N035A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13217,
 },
 [0x13218]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N036",
  direction="l",
  linebreak="al",
  unicodeslot=0x13218,
 },
 [0x13219]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N037",
  direction="l",
  linebreak="al",
  unicodeslot=0x13219,
 },
 [0x1321A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N037A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1321A,
 },
 [0x1321B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N038",
  direction="l",
  linebreak="al",
  unicodeslot=0x1321B,
 },
 [0x1321C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N039",
  direction="l",
  linebreak="al",
  unicodeslot=0x1321C,
 },
 [0x1321D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N040",
  direction="l",
  linebreak="al",
  unicodeslot=0x1321D,
 },
 [0x1321E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N041",
  direction="l",
  linebreak="al",
  unicodeslot=0x1321E,
 },
 [0x1321F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH N042",
  direction="l",
  linebreak="al",
  unicodeslot=0x1321F,
 },
 [0x13220]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13220,
 },
 [0x13221]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13221,
 },
 [0x13222]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13222,
 },
 [0x13223]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13223,
 },
 [0x13224]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13224,
 },
 [0x13225]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL005A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13225,
 },
 [0x13226]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13226,
 },
 [0x13227]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13227,
 },
 [0x13228]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13228,
 },
 [0x13229]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13229,
 },
 [0x1322A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL010",
  direction="l",
  linebreak="al",
  unicodeslot=0x1322A,
 },
 [0x1322B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL011",
  direction="l",
  linebreak="al",
  unicodeslot=0x1322B,
 },
 [0x1322C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL012",
  direction="l",
  linebreak="al",
  unicodeslot=0x1322C,
 },
 [0x1322D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL013",
  direction="l",
  linebreak="al",
  unicodeslot=0x1322D,
 },
 [0x1322E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL014",
  direction="l",
  linebreak="al",
  unicodeslot=0x1322E,
 },
 [0x1322F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL015",
  direction="l",
  linebreak="al",
  unicodeslot=0x1322F,
 },
 [0x13230]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL016",
  direction="l",
  linebreak="al",
  unicodeslot=0x13230,
 },
 [0x13231]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL017",
  direction="l",
  linebreak="al",
  unicodeslot=0x13231,
 },
 [0x13232]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL017A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13232,
 },
 [0x13233]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13233,
 },
 [0x13234]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13234,
 },
 [0x13235]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NL020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13235,
 },
 [0x13236]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13236,
 },
 [0x13237]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13237,
 },
 [0x13238]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13238,
 },
 [0x13239]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13239,
 },
 [0x1323A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU005",
  direction="l",
  linebreak="al",
  unicodeslot=0x1323A,
 },
 [0x1323B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU006",
  direction="l",
  linebreak="al",
  unicodeslot=0x1323B,
 },
 [0x1323C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU007",
  direction="l",
  linebreak="al",
  unicodeslot=0x1323C,
 },
 [0x1323D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU008",
  direction="l",
  linebreak="al",
  unicodeslot=0x1323D,
 },
 [0x1323E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU009",
  direction="l",
  linebreak="al",
  unicodeslot=0x1323E,
 },
 [0x1323F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU010",
  direction="l",
  linebreak="al",
  unicodeslot=0x1323F,
 },
 [0x13240]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU010A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13240,
 },
 [0x13241]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13241,
 },
 [0x13242]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU011A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13242,
 },
 [0x13243]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU012",
  direction="l",
  linebreak="al",
  unicodeslot=0x13243,
 },
 [0x13244]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU013",
  direction="l",
  linebreak="al",
  unicodeslot=0x13244,
 },
 [0x13245]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13245,
 },
 [0x13246]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU015",
  direction="l",
  linebreak="al",
  unicodeslot=0x13246,
 },
 [0x13247]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU016",
  direction="l",
  linebreak="al",
  unicodeslot=0x13247,
 },
 [0x13248]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU017",
  direction="l",
  linebreak="al",
  unicodeslot=0x13248,
 },
 [0x13249]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13249,
 },
 [0x1324A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU018A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1324A,
 },
 [0x1324B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU019",
  direction="l",
  linebreak="al",
  unicodeslot=0x1324B,
 },
 [0x1324C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU020",
  direction="l",
  linebreak="al",
  unicodeslot=0x1324C,
 },
 [0x1324D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU021",
  direction="l",
  linebreak="al",
  unicodeslot=0x1324D,
 },
 [0x1324E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU022",
  direction="l",
  linebreak="al",
  unicodeslot=0x1324E,
 },
 [0x1324F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH NU022A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1324F,
 },
 [0x13250]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13250,
 },
 [0x13251]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O001A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13251,
 },
 [0x13252]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13252,
 },
 [0x13253]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13253,
 },
 [0x13254]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13254,
 },
 [0x13255]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13255,
 },
 [0x13256]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O005A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13256,
 },
 [0x13257]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13257,
 },
 [0x13258]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O006A",
  direction="l",
  linebreak="op",
  unicodeslot=0x13258,
 },
 [0x13259]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O006B",
  direction="l",
  linebreak="op",
  unicodeslot=0x13259,
 },
 [0x1325A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O006C",
  direction="l",
  linebreak="op",
  unicodeslot=0x1325A,
 },
 [0x1325B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O006D",
  direction="l",
  linebreak="cl",
  unicodeslot=0x1325B,
 },
 [0x1325C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O006E",
  direction="l",
  linebreak="cl",
  unicodeslot=0x1325C,
 },
 [0x1325D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O006F",
  direction="l",
  linebreak="cl",
  unicodeslot=0x1325D,
 },
 [0x1325E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O007",
  direction="l",
  linebreak="al",
  unicodeslot=0x1325E,
 },
 [0x1325F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O008",
  direction="l",
  linebreak="al",
  unicodeslot=0x1325F,
 },
 [0x13260]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13260,
 },
 [0x13261]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O010",
  direction="l",
  linebreak="al",
  unicodeslot=0x13261,
 },
 [0x13262]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O010A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13262,
 },
 [0x13263]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O010B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13263,
 },
 [0x13264]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O010C",
  direction="l",
  linebreak="al",
  unicodeslot=0x13264,
 },
 [0x13265]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13265,
 },
 [0x13266]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O012",
  direction="l",
  linebreak="al",
  unicodeslot=0x13266,
 },
 [0x13267]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O013",
  direction="l",
  linebreak="al",
  unicodeslot=0x13267,
 },
 [0x13268]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13268,
 },
 [0x13269]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O015",
  direction="l",
  linebreak="al",
  unicodeslot=0x13269,
 },
 [0x1326A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O016",
  direction="l",
  linebreak="al",
  unicodeslot=0x1326A,
 },
 [0x1326B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O017",
  direction="l",
  linebreak="al",
  unicodeslot=0x1326B,
 },
 [0x1326C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O018",
  direction="l",
  linebreak="al",
  unicodeslot=0x1326C,
 },
 [0x1326D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O019",
  direction="l",
  linebreak="al",
  unicodeslot=0x1326D,
 },
 [0x1326E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O019A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1326E,
 },
 [0x1326F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O020",
  direction="l",
  linebreak="al",
  unicodeslot=0x1326F,
 },
 [0x13270]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O020A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13270,
 },
 [0x13271]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13271,
 },
 [0x13272]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O022",
  direction="l",
  linebreak="al",
  unicodeslot=0x13272,
 },
 [0x13273]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O023",
  direction="l",
  linebreak="al",
  unicodeslot=0x13273,
 },
 [0x13274]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O024",
  direction="l",
  linebreak="al",
  unicodeslot=0x13274,
 },
 [0x13275]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O024A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13275,
 },
 [0x13276]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O025",
  direction="l",
  linebreak="al",
  unicodeslot=0x13276,
 },
 [0x13277]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O025A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13277,
 },
 [0x13278]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O026",
  direction="l",
  linebreak="al",
  unicodeslot=0x13278,
 },
 [0x13279]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O027",
  direction="l",
  linebreak="al",
  unicodeslot=0x13279,
 },
 [0x1327A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O028",
  direction="l",
  linebreak="al",
  unicodeslot=0x1327A,
 },
 [0x1327B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O029",
  direction="l",
  linebreak="al",
  unicodeslot=0x1327B,
 },
 [0x1327C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O029A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1327C,
 },
 [0x1327D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O030",
  direction="l",
  linebreak="al",
  unicodeslot=0x1327D,
 },
 [0x1327E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O030A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1327E,
 },
 [0x1327F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O031",
  direction="l",
  linebreak="al",
  unicodeslot=0x1327F,
 },
 [0x13280]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O032",
  direction="l",
  linebreak="al",
  unicodeslot=0x13280,
 },
 [0x13281]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O033",
  direction="l",
  linebreak="al",
  unicodeslot=0x13281,
 },
 [0x13282]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O033A",
  direction="l",
  linebreak="cl",
  unicodeslot=0x13282,
 },
 [0x13283]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O034",
  direction="l",
  linebreak="al",
  unicodeslot=0x13283,
 },
 [0x13284]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O035",
  direction="l",
  linebreak="al",
  unicodeslot=0x13284,
 },
 [0x13285]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O036",
  direction="l",
  linebreak="al",
  unicodeslot=0x13285,
 },
 [0x13286]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O036A",
  direction="l",
  linebreak="op",
  unicodeslot=0x13286,
 },
 [0x13287]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O036B",
  direction="l",
  linebreak="cl",
  unicodeslot=0x13287,
 },
 [0x13288]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O036C",
  direction="l",
  linebreak="op",
  unicodeslot=0x13288,
 },
 [0x13289]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O036D",
  direction="l",
  linebreak="cl",
  unicodeslot=0x13289,
 },
 [0x1328A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O037",
  direction="l",
  linebreak="al",
  unicodeslot=0x1328A,
 },
 [0x1328B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O038",
  direction="l",
  linebreak="al",
  unicodeslot=0x1328B,
 },
 [0x1328C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O039",
  direction="l",
  linebreak="al",
  unicodeslot=0x1328C,
 },
 [0x1328D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O040",
  direction="l",
  linebreak="al",
  unicodeslot=0x1328D,
 },
 [0x1328E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O041",
  direction="l",
  linebreak="al",
  unicodeslot=0x1328E,
 },
 [0x1328F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O042",
  direction="l",
  linebreak="al",
  unicodeslot=0x1328F,
 },
 [0x13290]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O043",
  direction="l",
  linebreak="al",
  unicodeslot=0x13290,
 },
 [0x13291]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O044",
  direction="l",
  linebreak="al",
  unicodeslot=0x13291,
 },
 [0x13292]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O045",
  direction="l",
  linebreak="al",
  unicodeslot=0x13292,
 },
 [0x13293]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O046",
  direction="l",
  linebreak="al",
  unicodeslot=0x13293,
 },
 [0x13294]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O047",
  direction="l",
  linebreak="al",
  unicodeslot=0x13294,
 },
 [0x13295]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O048",
  direction="l",
  linebreak="al",
  unicodeslot=0x13295,
 },
 [0x13296]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O049",
  direction="l",
  linebreak="al",
  unicodeslot=0x13296,
 },
 [0x13297]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O050",
  direction="l",
  linebreak="al",
  unicodeslot=0x13297,
 },
 [0x13298]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O050A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13298,
 },
 [0x13299]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O050B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13299,
 },
 [0x1329A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH O051",
  direction="l",
  linebreak="al",
  unicodeslot=0x1329A,
 },
 [0x1329B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1329B,
 },
 [0x1329C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P001A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1329C,
 },
 [0x1329D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1329D,
 },
 [0x1329E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1329E,
 },
 [0x1329F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P003A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1329F,
 },
 [0x132A0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P004",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A0,
 },
 [0x132A1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P005",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A1,
 },
 [0x132A2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P006",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A2,
 },
 [0x132A3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P007",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A3,
 },
 [0x132A4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P008",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A4,
 },
 [0x132A5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P009",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A5,
 },
 [0x132A6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P010",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A6,
 },
 [0x132A7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH P011",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A7,
 },
 [0x132A8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Q001",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A8,
 },
 [0x132A9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Q002",
  direction="l",
  linebreak="al",
  unicodeslot=0x132A9,
 },
 [0x132AA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Q003",
  direction="l",
  linebreak="al",
  unicodeslot=0x132AA,
 },
 [0x132AB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Q004",
  direction="l",
  linebreak="al",
  unicodeslot=0x132AB,
 },
 [0x132AC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Q005",
  direction="l",
  linebreak="al",
  unicodeslot=0x132AC,
 },
 [0x132AD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Q006",
  direction="l",
  linebreak="al",
  unicodeslot=0x132AD,
 },
 [0x132AE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Q007",
  direction="l",
  linebreak="al",
  unicodeslot=0x132AE,
 },
 [0x132AF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R001",
  direction="l",
  linebreak="al",
  unicodeslot=0x132AF,
 },
 [0x132B0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R002",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B0,
 },
 [0x132B1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R002A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B1,
 },
 [0x132B2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R003",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B2,
 },
 [0x132B3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R003A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B3,
 },
 [0x132B4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R003B",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B4,
 },
 [0x132B5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R004",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B5,
 },
 [0x132B6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R005",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B6,
 },
 [0x132B7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R006",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B7,
 },
 [0x132B8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R007",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B8,
 },
 [0x132B9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R008",
  direction="l",
  linebreak="al",
  unicodeslot=0x132B9,
 },
 [0x132BA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R009",
  direction="l",
  linebreak="al",
  unicodeslot=0x132BA,
 },
 [0x132BB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R010",
  direction="l",
  linebreak="al",
  unicodeslot=0x132BB,
 },
 [0x132BC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R010A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132BC,
 },
 [0x132BD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R011",
  direction="l",
  linebreak="al",
  unicodeslot=0x132BD,
 },
 [0x132BE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R012",
  direction="l",
  linebreak="al",
  unicodeslot=0x132BE,
 },
 [0x132BF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R013",
  direction="l",
  linebreak="al",
  unicodeslot=0x132BF,
 },
 [0x132C0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R014",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C0,
 },
 [0x132C1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R015",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C1,
 },
 [0x132C2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R016",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C2,
 },
 [0x132C3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R016A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C3,
 },
 [0x132C4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R017",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C4,
 },
 [0x132C5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R018",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C5,
 },
 [0x132C6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R019",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C6,
 },
 [0x132C7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R020",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C7,
 },
 [0x132C8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R021",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C8,
 },
 [0x132C9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R022",
  direction="l",
  linebreak="al",
  unicodeslot=0x132C9,
 },
 [0x132CA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R023",
  direction="l",
  linebreak="al",
  unicodeslot=0x132CA,
 },
 [0x132CB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R024",
  direction="l",
  linebreak="al",
  unicodeslot=0x132CB,
 },
 [0x132CC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R025",
  direction="l",
  linebreak="al",
  unicodeslot=0x132CC,
 },
 [0x132CD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R026",
  direction="l",
  linebreak="al",
  unicodeslot=0x132CD,
 },
 [0x132CE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R027",
  direction="l",
  linebreak="al",
  unicodeslot=0x132CE,
 },
 [0x132CF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R028",
  direction="l",
  linebreak="al",
  unicodeslot=0x132CF,
 },
 [0x132D0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH R029",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D0,
 },
 [0x132D1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S001",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D1,
 },
 [0x132D2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S002",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D2,
 },
 [0x132D3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S002A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D3,
 },
 [0x132D4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S003",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D4,
 },
 [0x132D5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S004",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D5,
 },
 [0x132D6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S005",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D6,
 },
 [0x132D7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S006",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D7,
 },
 [0x132D8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S006A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D8,
 },
 [0x132D9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S007",
  direction="l",
  linebreak="al",
  unicodeslot=0x132D9,
 },
 [0x132DA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S008",
  direction="l",
  linebreak="al",
  unicodeslot=0x132DA,
 },
 [0x132DB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S009",
  direction="l",
  linebreak="al",
  unicodeslot=0x132DB,
 },
 [0x132DC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S010",
  direction="l",
  linebreak="al",
  unicodeslot=0x132DC,
 },
 [0x132DD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S011",
  direction="l",
  linebreak="al",
  unicodeslot=0x132DD,
 },
 [0x132DE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S012",
  direction="l",
  linebreak="al",
  unicodeslot=0x132DE,
 },
 [0x132DF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S013",
  direction="l",
  linebreak="al",
  unicodeslot=0x132DF,
 },
 [0x132E0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S014",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E0,
 },
 [0x132E1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S014A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E1,
 },
 [0x132E2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S014B",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E2,
 },
 [0x132E3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S015",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E3,
 },
 [0x132E4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S016",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E4,
 },
 [0x132E5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S017",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E5,
 },
 [0x132E6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S017A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E6,
 },
 [0x132E7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S018",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E7,
 },
 [0x132E8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S019",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E8,
 },
 [0x132E9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S020",
  direction="l",
  linebreak="al",
  unicodeslot=0x132E9,
 },
 [0x132EA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S021",
  direction="l",
  linebreak="al",
  unicodeslot=0x132EA,
 },
 [0x132EB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S022",
  direction="l",
  linebreak="al",
  unicodeslot=0x132EB,
 },
 [0x132EC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S023",
  direction="l",
  linebreak="al",
  unicodeslot=0x132EC,
 },
 [0x132ED]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S024",
  direction="l",
  linebreak="al",
  unicodeslot=0x132ED,
 },
 [0x132EE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S025",
  direction="l",
  linebreak="al",
  unicodeslot=0x132EE,
 },
 [0x132EF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S026",
  direction="l",
  linebreak="al",
  unicodeslot=0x132EF,
 },
 [0x132F0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S026A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F0,
 },
 [0x132F1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S026B",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F1,
 },
 [0x132F2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S027",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F2,
 },
 [0x132F3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S028",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F3,
 },
 [0x132F4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S029",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F4,
 },
 [0x132F5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S030",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F5,
 },
 [0x132F6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S031",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F6,
 },
 [0x132F7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S032",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F7,
 },
 [0x132F8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S033",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F8,
 },
 [0x132F9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S034",
  direction="l",
  linebreak="al",
  unicodeslot=0x132F9,
 },
 [0x132FA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S035",
  direction="l",
  linebreak="al",
  unicodeslot=0x132FA,
 },
 [0x132FB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S035A",
  direction="l",
  linebreak="al",
  unicodeslot=0x132FB,
 },
 [0x132FC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S036",
  direction="l",
  linebreak="al",
  unicodeslot=0x132FC,
 },
 [0x132FD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S037",
  direction="l",
  linebreak="al",
  unicodeslot=0x132FD,
 },
 [0x132FE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S038",
  direction="l",
  linebreak="al",
  unicodeslot=0x132FE,
 },
 [0x132FF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S039",
  direction="l",
  linebreak="al",
  unicodeslot=0x132FF,
 },
 [0x13300]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S040",
  direction="l",
  linebreak="al",
  unicodeslot=0x13300,
 },
 [0x13301]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S041",
  direction="l",
  linebreak="al",
  unicodeslot=0x13301,
 },
 [0x13302]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S042",
  direction="l",
  linebreak="al",
  unicodeslot=0x13302,
 },
 [0x13303]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S043",
  direction="l",
  linebreak="al",
  unicodeslot=0x13303,
 },
 [0x13304]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S044",
  direction="l",
  linebreak="al",
  unicodeslot=0x13304,
 },
 [0x13305]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S045",
  direction="l",
  linebreak="al",
  unicodeslot=0x13305,
 },
 [0x13306]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH S046",
  direction="l",
  linebreak="al",
  unicodeslot=0x13306,
 },
 [0x13307]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13307,
 },
 [0x13308]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13308,
 },
 [0x13309]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13309,
 },
 [0x1330A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T003A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1330A,
 },
 [0x1330B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1330B,
 },
 [0x1330C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T005",
  direction="l",
  linebreak="al",
  unicodeslot=0x1330C,
 },
 [0x1330D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T006",
  direction="l",
  linebreak="al",
  unicodeslot=0x1330D,
 },
 [0x1330E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T007",
  direction="l",
  linebreak="al",
  unicodeslot=0x1330E,
 },
 [0x1330F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T007A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1330F,
 },
 [0x13310]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13310,
 },
 [0x13311]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T008A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13311,
 },
 [0x13312]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13312,
 },
 [0x13313]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T009A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13313,
 },
 [0x13314]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T010",
  direction="l",
  linebreak="al",
  unicodeslot=0x13314,
 },
 [0x13315]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13315,
 },
 [0x13316]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T011A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13316,
 },
 [0x13317]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T012",
  direction="l",
  linebreak="al",
  unicodeslot=0x13317,
 },
 [0x13318]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T013",
  direction="l",
  linebreak="al",
  unicodeslot=0x13318,
 },
 [0x13319]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13319,
 },
 [0x1331A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T015",
  direction="l",
  linebreak="al",
  unicodeslot=0x1331A,
 },
 [0x1331B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T016",
  direction="l",
  linebreak="al",
  unicodeslot=0x1331B,
 },
 [0x1331C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T016A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1331C,
 },
 [0x1331D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T017",
  direction="l",
  linebreak="al",
  unicodeslot=0x1331D,
 },
 [0x1331E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T018",
  direction="l",
  linebreak="al",
  unicodeslot=0x1331E,
 },
 [0x1331F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T019",
  direction="l",
  linebreak="al",
  unicodeslot=0x1331F,
 },
 [0x13320]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13320,
 },
 [0x13321]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13321,
 },
 [0x13322]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T022",
  direction="l",
  linebreak="al",
  unicodeslot=0x13322,
 },
 [0x13323]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T023",
  direction="l",
  linebreak="al",
  unicodeslot=0x13323,
 },
 [0x13324]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T024",
  direction="l",
  linebreak="al",
  unicodeslot=0x13324,
 },
 [0x13325]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T025",
  direction="l",
  linebreak="al",
  unicodeslot=0x13325,
 },
 [0x13326]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T026",
  direction="l",
  linebreak="al",
  unicodeslot=0x13326,
 },
 [0x13327]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T027",
  direction="l",
  linebreak="al",
  unicodeslot=0x13327,
 },
 [0x13328]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T028",
  direction="l",
  linebreak="al",
  unicodeslot=0x13328,
 },
 [0x13329]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T029",
  direction="l",
  linebreak="al",
  unicodeslot=0x13329,
 },
 [0x1332A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T030",
  direction="l",
  linebreak="al",
  unicodeslot=0x1332A,
 },
 [0x1332B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T031",
  direction="l",
  linebreak="al",
  unicodeslot=0x1332B,
 },
 [0x1332C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T032",
  direction="l",
  linebreak="al",
  unicodeslot=0x1332C,
 },
 [0x1332D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T032A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1332D,
 },
 [0x1332E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T033",
  direction="l",
  linebreak="al",
  unicodeslot=0x1332E,
 },
 [0x1332F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T033A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1332F,
 },
 [0x13330]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T034",
  direction="l",
  linebreak="al",
  unicodeslot=0x13330,
 },
 [0x13331]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T035",
  direction="l",
  linebreak="al",
  unicodeslot=0x13331,
 },
 [0x13332]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH T036",
  direction="l",
  linebreak="al",
  unicodeslot=0x13332,
 },
 [0x13333]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13333,
 },
 [0x13334]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U002",
  direction="l",
  linebreak="al",
  unicodeslot=0x13334,
 },
 [0x13335]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U003",
  direction="l",
  linebreak="al",
  unicodeslot=0x13335,
 },
 [0x13336]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13336,
 },
 [0x13337]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13337,
 },
 [0x13338]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13338,
 },
 [0x13339]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U006A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13339,
 },
 [0x1333A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U006B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1333A,
 },
 [0x1333B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U007",
  direction="l",
  linebreak="al",
  unicodeslot=0x1333B,
 },
 [0x1333C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U008",
  direction="l",
  linebreak="al",
  unicodeslot=0x1333C,
 },
 [0x1333D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U009",
  direction="l",
  linebreak="al",
  unicodeslot=0x1333D,
 },
 [0x1333E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U010",
  direction="l",
  linebreak="al",
  unicodeslot=0x1333E,
 },
 [0x1333F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U011",
  direction="l",
  linebreak="al",
  unicodeslot=0x1333F,
 },
 [0x13340]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U012",
  direction="l",
  linebreak="al",
  unicodeslot=0x13340,
 },
 [0x13341]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U013",
  direction="l",
  linebreak="al",
  unicodeslot=0x13341,
 },
 [0x13342]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13342,
 },
 [0x13343]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U015",
  direction="l",
  linebreak="al",
  unicodeslot=0x13343,
 },
 [0x13344]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U016",
  direction="l",
  linebreak="al",
  unicodeslot=0x13344,
 },
 [0x13345]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U017",
  direction="l",
  linebreak="al",
  unicodeslot=0x13345,
 },
 [0x13346]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13346,
 },
 [0x13347]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13347,
 },
 [0x13348]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13348,
 },
 [0x13349]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13349,
 },
 [0x1334A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U022",
  direction="l",
  linebreak="al",
  unicodeslot=0x1334A,
 },
 [0x1334B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U023",
  direction="l",
  linebreak="al",
  unicodeslot=0x1334B,
 },
 [0x1334C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U023A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1334C,
 },
 [0x1334D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U024",
  direction="l",
  linebreak="al",
  unicodeslot=0x1334D,
 },
 [0x1334E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U025",
  direction="l",
  linebreak="al",
  unicodeslot=0x1334E,
 },
 [0x1334F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U026",
  direction="l",
  linebreak="al",
  unicodeslot=0x1334F,
 },
 [0x13350]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U027",
  direction="l",
  linebreak="al",
  unicodeslot=0x13350,
 },
 [0x13351]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U028",
  direction="l",
  linebreak="al",
  unicodeslot=0x13351,
 },
 [0x13352]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U029",
  direction="l",
  linebreak="al",
  unicodeslot=0x13352,
 },
 [0x13353]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U029A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13353,
 },
 [0x13354]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U030",
  direction="l",
  linebreak="al",
  unicodeslot=0x13354,
 },
 [0x13355]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U031",
  direction="l",
  linebreak="al",
  unicodeslot=0x13355,
 },
 [0x13356]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U032",
  direction="l",
  linebreak="al",
  unicodeslot=0x13356,
 },
 [0x13357]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U032A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13357,
 },
 [0x13358]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U033",
  direction="l",
  linebreak="al",
  unicodeslot=0x13358,
 },
 [0x13359]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U034",
  direction="l",
  linebreak="al",
  unicodeslot=0x13359,
 },
 [0x1335A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U035",
  direction="l",
  linebreak="al",
  unicodeslot=0x1335A,
 },
 [0x1335B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U036",
  direction="l",
  linebreak="al",
  unicodeslot=0x1335B,
 },
 [0x1335C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U037",
  direction="l",
  linebreak="al",
  unicodeslot=0x1335C,
 },
 [0x1335D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U038",
  direction="l",
  linebreak="al",
  unicodeslot=0x1335D,
 },
 [0x1335E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U039",
  direction="l",
  linebreak="al",
  unicodeslot=0x1335E,
 },
 [0x1335F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U040",
  direction="l",
  linebreak="al",
  unicodeslot=0x1335F,
 },
 [0x13360]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U041",
  direction="l",
  linebreak="al",
  unicodeslot=0x13360,
 },
 [0x13361]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH U042",
  direction="l",
  linebreak="al",
  unicodeslot=0x13361,
 },
 [0x13362]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001",
  direction="l",
  linebreak="al",
  unicodeslot=0x13362,
 },
 [0x13363]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13363,
 },
 [0x13364]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13364,
 },
 [0x13365]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001C",
  direction="l",
  linebreak="al",
  unicodeslot=0x13365,
 },
 [0x13366]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001D",
  direction="l",
  linebreak="al",
  unicodeslot=0x13366,
 },
 [0x13367]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001E",
  direction="l",
  linebreak="al",
  unicodeslot=0x13367,
 },
 [0x13368]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001F",
  direction="l",
  linebreak="al",
  unicodeslot=0x13368,
 },
 [0x13369]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001G",
  direction="l",
  linebreak="al",
  unicodeslot=0x13369,
 },
 [0x1336A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001H",
  direction="l",
  linebreak="al",
  unicodeslot=0x1336A,
 },
 [0x1336B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V001I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1336B,
 },
 [0x1336C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1336C,
 },
 [0x1336D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V002A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1336D,
 },
 [0x1336E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1336E,
 },
 [0x1336F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1336F,
 },
 [0x13370]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13370,
 },
 [0x13371]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13371,
 },
 [0x13372]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13372,
 },
 [0x13373]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V007A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13373,
 },
 [0x13374]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V007B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13374,
 },
 [0x13375]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13375,
 },
 [0x13376]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13376,
 },
 [0x13377]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V010",
  direction="l",
  linebreak="al",
  unicodeslot=0x13377,
 },
 [0x13378]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13378,
 },
 [0x13379]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V011A",
  direction="l",
  linebreak="op",
  unicodeslot=0x13379,
 },
 [0x1337A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V011B",
  direction="l",
  linebreak="cl",
  unicodeslot=0x1337A,
 },
 [0x1337B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V011C",
  direction="l",
  linebreak="cl",
  unicodeslot=0x1337B,
 },
 [0x1337C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V012",
  direction="l",
  linebreak="al",
  unicodeslot=0x1337C,
 },
 [0x1337D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V012A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1337D,
 },
 [0x1337E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V012B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1337E,
 },
 [0x1337F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V013",
  direction="l",
  linebreak="al",
  unicodeslot=0x1337F,
 },
 [0x13380]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V014",
  direction="l",
  linebreak="al",
  unicodeslot=0x13380,
 },
 [0x13381]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V015",
  direction="l",
  linebreak="al",
  unicodeslot=0x13381,
 },
 [0x13382]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V016",
  direction="l",
  linebreak="al",
  unicodeslot=0x13382,
 },
 [0x13383]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V017",
  direction="l",
  linebreak="al",
  unicodeslot=0x13383,
 },
 [0x13384]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13384,
 },
 [0x13385]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13385,
 },
 [0x13386]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13386,
 },
 [0x13387]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13387,
 },
 [0x13388]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13388,
 },
 [0x13389]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020C",
  direction="l",
  linebreak="al",
  unicodeslot=0x13389,
 },
 [0x1338A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020D",
  direction="l",
  linebreak="al",
  unicodeslot=0x1338A,
 },
 [0x1338B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020E",
  direction="l",
  linebreak="al",
  unicodeslot=0x1338B,
 },
 [0x1338C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020F",
  direction="l",
  linebreak="al",
  unicodeslot=0x1338C,
 },
 [0x1338D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020G",
  direction="l",
  linebreak="al",
  unicodeslot=0x1338D,
 },
 [0x1338E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020H",
  direction="l",
  linebreak="al",
  unicodeslot=0x1338E,
 },
 [0x1338F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020I",
  direction="l",
  linebreak="al",
  unicodeslot=0x1338F,
 },
 [0x13390]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020J",
  direction="l",
  linebreak="al",
  unicodeslot=0x13390,
 },
 [0x13391]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020K",
  direction="l",
  linebreak="al",
  unicodeslot=0x13391,
 },
 [0x13392]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V020L",
  direction="l",
  linebreak="al",
  unicodeslot=0x13392,
 },
 [0x13393]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13393,
 },
 [0x13394]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V022",
  direction="l",
  linebreak="al",
  unicodeslot=0x13394,
 },
 [0x13395]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V023",
  direction="l",
  linebreak="al",
  unicodeslot=0x13395,
 },
 [0x13396]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V023A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13396,
 },
 [0x13397]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V024",
  direction="l",
  linebreak="al",
  unicodeslot=0x13397,
 },
 [0x13398]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V025",
  direction="l",
  linebreak="al",
  unicodeslot=0x13398,
 },
 [0x13399]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V026",
  direction="l",
  linebreak="al",
  unicodeslot=0x13399,
 },
 [0x1339A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V027",
  direction="l",
  linebreak="al",
  unicodeslot=0x1339A,
 },
 [0x1339B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V028",
  direction="l",
  linebreak="al",
  unicodeslot=0x1339B,
 },
 [0x1339C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V028A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1339C,
 },
 [0x1339D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V029",
  direction="l",
  linebreak="al",
  unicodeslot=0x1339D,
 },
 [0x1339E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V029A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1339E,
 },
 [0x1339F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V030",
  direction="l",
  linebreak="al",
  unicodeslot=0x1339F,
 },
 [0x133A0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V030A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A0,
 },
 [0x133A1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V031",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A1,
 },
 [0x133A2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V031A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A2,
 },
 [0x133A3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V032",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A3,
 },
 [0x133A4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V033",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A4,
 },
 [0x133A5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V033A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A5,
 },
 [0x133A6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V034",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A6,
 },
 [0x133A7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V035",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A7,
 },
 [0x133A8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V036",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A8,
 },
 [0x133A9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V037",
  direction="l",
  linebreak="al",
  unicodeslot=0x133A9,
 },
 [0x133AA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V037A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133AA,
 },
 [0x133AB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V038",
  direction="l",
  linebreak="al",
  unicodeslot=0x133AB,
 },
 [0x133AC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V039",
  direction="l",
  linebreak="al",
  unicodeslot=0x133AC,
 },
 [0x133AD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V040",
  direction="l",
  linebreak="al",
  unicodeslot=0x133AD,
 },
 [0x133AE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH V040A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133AE,
 },
 [0x133AF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W001",
  direction="l",
  linebreak="al",
  unicodeslot=0x133AF,
 },
 [0x133B0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W002",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B0,
 },
 [0x133B1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W003",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B1,
 },
 [0x133B2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W003A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B2,
 },
 [0x133B3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W004",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B3,
 },
 [0x133B4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W005",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B4,
 },
 [0x133B5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W006",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B5,
 },
 [0x133B6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W007",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B6,
 },
 [0x133B7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W008",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B7,
 },
 [0x133B8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W009",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B8,
 },
 [0x133B9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W009A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133B9,
 },
 [0x133BA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W010",
  direction="l",
  linebreak="al",
  unicodeslot=0x133BA,
 },
 [0x133BB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W010A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133BB,
 },
 [0x133BC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W011",
  direction="l",
  linebreak="al",
  unicodeslot=0x133BC,
 },
 [0x133BD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W012",
  direction="l",
  linebreak="al",
  unicodeslot=0x133BD,
 },
 [0x133BE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W013",
  direction="l",
  linebreak="al",
  unicodeslot=0x133BE,
 },
 [0x133BF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W014",
  direction="l",
  linebreak="al",
  unicodeslot=0x133BF,
 },
 [0x133C0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W014A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C0,
 },
 [0x133C1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W015",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C1,
 },
 [0x133C2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W016",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C2,
 },
 [0x133C3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W017",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C3,
 },
 [0x133C4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W017A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C4,
 },
 [0x133C5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W018",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C5,
 },
 [0x133C6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W018A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C6,
 },
 [0x133C7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W019",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C7,
 },
 [0x133C8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W020",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C8,
 },
 [0x133C9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W021",
  direction="l",
  linebreak="al",
  unicodeslot=0x133C9,
 },
 [0x133CA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W022",
  direction="l",
  linebreak="al",
  unicodeslot=0x133CA,
 },
 [0x133CB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W023",
  direction="l",
  linebreak="al",
  unicodeslot=0x133CB,
 },
 [0x133CC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W024",
  direction="l",
  linebreak="al",
  unicodeslot=0x133CC,
 },
 [0x133CD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W024A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133CD,
 },
 [0x133CE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH W025",
  direction="l",
  linebreak="al",
  unicodeslot=0x133CE,
 },
 [0x133CF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X001",
  direction="l",
  linebreak="al",
  unicodeslot=0x133CF,
 },
 [0x133D0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X002",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D0,
 },
 [0x133D1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X003",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D1,
 },
 [0x133D2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X004",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D2,
 },
 [0x133D3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X004A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D3,
 },
 [0x133D4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X004B",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D4,
 },
 [0x133D5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X005",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D5,
 },
 [0x133D6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X006",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D6,
 },
 [0x133D7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X006A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D7,
 },
 [0x133D8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X007",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D8,
 },
 [0x133D9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X008",
  direction="l",
  linebreak="al",
  unicodeslot=0x133D9,
 },
 [0x133DA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH X008A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133DA,
 },
 [0x133DB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y001",
  direction="l",
  linebreak="al",
  unicodeslot=0x133DB,
 },
 [0x133DC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y001A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133DC,
 },
 [0x133DD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y002",
  direction="l",
  linebreak="al",
  unicodeslot=0x133DD,
 },
 [0x133DE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y003",
  direction="l",
  linebreak="al",
  unicodeslot=0x133DE,
 },
 [0x133DF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y004",
  direction="l",
  linebreak="al",
  unicodeslot=0x133DF,
 },
 [0x133E0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y005",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E0,
 },
 [0x133E1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y006",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E1,
 },
 [0x133E2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y007",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E2,
 },
 [0x133E3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Y008",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E3,
 },
 [0x133E4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z001",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E4,
 },
 [0x133E5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z002",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E5,
 },
 [0x133E6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z002A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E6,
 },
 [0x133E7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z002B",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E7,
 },
 [0x133E8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z002C",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E8,
 },
 [0x133E9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z002D",
  direction="l",
  linebreak="al",
  unicodeslot=0x133E9,
 },
 [0x133EA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z003",
  direction="l",
  linebreak="al",
  unicodeslot=0x133EA,
 },
 [0x133EB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z003A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133EB,
 },
 [0x133EC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z003B",
  direction="l",
  linebreak="al",
  unicodeslot=0x133EC,
 },
 [0x133ED]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z004",
  direction="l",
  linebreak="al",
  unicodeslot=0x133ED,
 },
 [0x133EE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z004A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133EE,
 },
 [0x133EF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z005",
  direction="l",
  linebreak="al",
  unicodeslot=0x133EF,
 },
 [0x133F0]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z005A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F0,
 },
 [0x133F1]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z006",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F1,
 },
 [0x133F2]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z007",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F2,
 },
 [0x133F3]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z008",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F3,
 },
 [0x133F4]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z009",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F4,
 },
 [0x133F5]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z010",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F5,
 },
 [0x133F6]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z011",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F6,
 },
 [0x133F7]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z012",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F7,
 },
 [0x133F8]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z013",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F8,
 },
 [0x133F9]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z014",
  direction="l",
  linebreak="al",
  unicodeslot=0x133F9,
 },
 [0x133FA]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015",
  direction="l",
  linebreak="al",
  unicodeslot=0x133FA,
 },
 [0x133FB]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015A",
  direction="l",
  linebreak="al",
  unicodeslot=0x133FB,
 },
 [0x133FC]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015B",
  direction="l",
  linebreak="al",
  unicodeslot=0x133FC,
 },
 [0x133FD]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015C",
  direction="l",
  linebreak="al",
  unicodeslot=0x133FD,
 },
 [0x133FE]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015D",
  direction="l",
  linebreak="al",
  unicodeslot=0x133FE,
 },
 [0x133FF]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015E",
  direction="l",
  linebreak="al",
  unicodeslot=0x133FF,
 },
 [0x13400]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015F",
  direction="l",
  linebreak="al",
  unicodeslot=0x13400,
 },
 [0x13401]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015G",
  direction="l",
  linebreak="al",
  unicodeslot=0x13401,
 },
 [0x13402]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015H",
  direction="l",
  linebreak="al",
  unicodeslot=0x13402,
 },
 [0x13403]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z015I",
  direction="l",
  linebreak="al",
  unicodeslot=0x13403,
 },
 [0x13404]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016",
  direction="l",
  linebreak="al",
  unicodeslot=0x13404,
 },
 [0x13405]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13405,
 },
 [0x13406]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13406,
 },
 [0x13407]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016C",
  direction="l",
  linebreak="al",
  unicodeslot=0x13407,
 },
 [0x13408]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016D",
  direction="l",
  linebreak="al",
  unicodeslot=0x13408,
 },
 [0x13409]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016E",
  direction="l",
  linebreak="al",
  unicodeslot=0x13409,
 },
 [0x1340A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016F",
  direction="l",
  linebreak="al",
  unicodeslot=0x1340A,
 },
 [0x1340B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016G",
  direction="l",
  linebreak="al",
  unicodeslot=0x1340B,
 },
 [0x1340C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH Z016H",
  direction="l",
  linebreak="al",
  unicodeslot=0x1340C,
 },
 [0x1340D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1340D,
 },
 [0x1340E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1340E,
 },
 [0x1340F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1340F,
 },
 [0x13410]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA004",
  direction="l",
  linebreak="al",
  unicodeslot=0x13410,
 },
 [0x13411]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA005",
  direction="l",
  linebreak="al",
  unicodeslot=0x13411,
 },
 [0x13412]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA006",
  direction="l",
  linebreak="al",
  unicodeslot=0x13412,
 },
 [0x13413]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA007",
  direction="l",
  linebreak="al",
  unicodeslot=0x13413,
 },
 [0x13414]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA007A",
  direction="l",
  linebreak="al",
  unicodeslot=0x13414,
 },
 [0x13415]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA007B",
  direction="l",
  linebreak="al",
  unicodeslot=0x13415,
 },
 [0x13416]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA008",
  direction="l",
  linebreak="al",
  unicodeslot=0x13416,
 },
 [0x13417]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA009",
  direction="l",
  linebreak="al",
  unicodeslot=0x13417,
 },
 [0x13418]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA010",
  direction="l",
  linebreak="al",
  unicodeslot=0x13418,
 },
 [0x13419]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA011",
  direction="l",
  linebreak="al",
  unicodeslot=0x13419,
 },
 [0x1341A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA012",
  direction="l",
  linebreak="al",
  unicodeslot=0x1341A,
 },
 [0x1341B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA013",
  direction="l",
  linebreak="al",
  unicodeslot=0x1341B,
 },
 [0x1341C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA014",
  direction="l",
  linebreak="al",
  unicodeslot=0x1341C,
 },
 [0x1341D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA015",
  direction="l",
  linebreak="al",
  unicodeslot=0x1341D,
 },
 [0x1341E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA016",
  direction="l",
  linebreak="al",
  unicodeslot=0x1341E,
 },
 [0x1341F]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA017",
  direction="l",
  linebreak="al",
  unicodeslot=0x1341F,
 },
 [0x13420]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA018",
  direction="l",
  linebreak="al",
  unicodeslot=0x13420,
 },
 [0x13421]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA019",
  direction="l",
  linebreak="al",
  unicodeslot=0x13421,
 },
 [0x13422]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA020",
  direction="l",
  linebreak="al",
  unicodeslot=0x13422,
 },
 [0x13423]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA021",
  direction="l",
  linebreak="al",
  unicodeslot=0x13423,
 },
 [0x13424]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA022",
  direction="l",
  linebreak="al",
  unicodeslot=0x13424,
 },
 [0x13425]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA023",
  direction="l",
  linebreak="al",
  unicodeslot=0x13425,
 },
 [0x13426]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA024",
  direction="l",
  linebreak="al",
  unicodeslot=0x13426,
 },
 [0x13427]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA025",
  direction="l",
  linebreak="al",
  unicodeslot=0x13427,
 },
 [0x13428]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA026",
  direction="l",
  linebreak="al",
  unicodeslot=0x13428,
 },
 [0x13429]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA027",
  direction="l",
  linebreak="al",
  unicodeslot=0x13429,
 },
 [0x1342A]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA028",
  direction="l",
  linebreak="al",
  unicodeslot=0x1342A,
 },
 [0x1342B]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA029",
  direction="l",
  linebreak="al",
  unicodeslot=0x1342B,
 },
 [0x1342C]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA030",
  direction="l",
  linebreak="al",
  unicodeslot=0x1342C,
 },
 [0x1342D]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA031",
  direction="l",
  linebreak="al",
  unicodeslot=0x1342D,
 },
 [0x1342E]={
  category="lo",
  description="EGYPTIAN HIEROGLYPH AA032",
  direction="l",
  linebreak="al",
  unicodeslot=0x1342E,
 },
 [0x16800]={
  category="lo",
  description="BAMUM LETTER PHASE-A NGKUE MFON",
  direction="l",
  linebreak="al",
  unicodeslot=0x16800,
 },
 [0x16801]={
  category="lo",
  description="BAMUM LETTER PHASE-A GBIEE FON",
  direction="l",
  linebreak="al",
  unicodeslot=0x16801,
 },
 [0x16802]={
  category="lo",
  description="BAMUM LETTER PHASE-A PON MFON PIPAEMGBIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16802,
 },
 [0x16803]={
  category="lo",
  description="BAMUM LETTER PHASE-A PON MFON PIPAEMBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16803,
 },
 [0x16804]={
  category="lo",
  description="BAMUM LETTER PHASE-A NAA MFON",
  direction="l",
  linebreak="al",
  unicodeslot=0x16804,
 },
 [0x16805]={
  category="lo",
  description="BAMUM LETTER PHASE-A SHUENSHUET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16805,
 },
 [0x16806]={
  category="lo",
  description="BAMUM LETTER PHASE-A TITA MFON",
  direction="l",
  linebreak="al",
  unicodeslot=0x16806,
 },
 [0x16807]={
  category="lo",
  description="BAMUM LETTER PHASE-A NZA MFON",
  direction="l",
  linebreak="al",
  unicodeslot=0x16807,
 },
 [0x16808]={
  category="lo",
  description="BAMUM LETTER PHASE-A SHINDA PA NJI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16808,
 },
 [0x16809]={
  category="lo",
  description="BAMUM LETTER PHASE-A PON PA NJI PIPAEMGBIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16809,
 },
 [0x1680A]={
  category="lo",
  description="BAMUM LETTER PHASE-A PON PA NJI PIPAEMBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1680A,
 },
 [0x1680B]={
  category="lo",
  description="BAMUM LETTER PHASE-A MAEMBGBIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1680B,
 },
 [0x1680C]={
  category="lo",
  description="BAMUM LETTER PHASE-A TU MAEMBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1680C,
 },
 [0x1680D]={
  category="lo",
  description="BAMUM LETTER PHASE-A NGANGU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1680D,
 },
 [0x1680E]={
  category="lo",
  description="BAMUM LETTER PHASE-A MAEMVEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x1680E,
 },
 [0x1680F]={
  category="lo",
  description="BAMUM LETTER PHASE-A MANSUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1680F,
 },
 [0x16810]={
  category="lo",
  description="BAMUM LETTER PHASE-A MVEUAENGAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16810,
 },
 [0x16811]={
  category="lo",
  description="BAMUM LETTER PHASE-A SEUNYAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16811,
 },
 [0x16812]={
  category="lo",
  description="BAMUM LETTER PHASE-A NTOQPEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16812,
 },
 [0x16813]={
  category="lo",
  description="BAMUM LETTER PHASE-A KEUKEUTNDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16813,
 },
 [0x16814]={
  category="lo",
  description="BAMUM LETTER PHASE-A NKINDI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16814,
 },
 [0x16815]={
  category="lo",
  description="BAMUM LETTER PHASE-A SUU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16815,
 },
 [0x16816]={
  category="lo",
  description="BAMUM LETTER PHASE-A NGKUENZEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16816,
 },
 [0x16817]={
  category="lo",
  description="BAMUM LETTER PHASE-A LAPAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16817,
 },
 [0x16818]={
  category="lo",
  description="BAMUM LETTER PHASE-A LET KUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x16818,
 },
 [0x16819]={
  category="lo",
  description="BAMUM LETTER PHASE-A NTAP MFAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16819,
 },
 [0x1681A]={
  category="lo",
  description="BAMUM LETTER PHASE-A MAEKEUP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1681A,
 },
 [0x1681B]={
  category="lo",
  description="BAMUM LETTER PHASE-A PASHAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1681B,
 },
 [0x1681C]={
  category="lo",
  description="BAMUM LETTER PHASE-A GHEUAERAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1681C,
 },
 [0x1681D]={
  category="lo",
  description="BAMUM LETTER PHASE-A PAMSHAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1681D,
 },
 [0x1681E]={
  category="lo",
  description="BAMUM LETTER PHASE-A MON NGGEUAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x1681E,
 },
 [0x1681F]={
  category="lo",
  description="BAMUM LETTER PHASE-A NZUN MEUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1681F,
 },
 [0x16820]={
  category="lo",
  description="BAMUM LETTER PHASE-A U YUQ NAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16820,
 },
 [0x16821]={
  category="lo",
  description="BAMUM LETTER PHASE-A GHEUAEGHEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16821,
 },
 [0x16822]={
  category="lo",
  description="BAMUM LETTER PHASE-A NTAP NTAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16822,
 },
 [0x16823]={
  category="lo",
  description="BAMUM LETTER PHASE-A SISA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16823,
 },
 [0x16824]={
  category="lo",
  description="BAMUM LETTER PHASE-A MGBASA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16824,
 },
 [0x16825]={
  category="lo",
  description="BAMUM LETTER PHASE-A MEUNJOMNDEUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16825,
 },
 [0x16826]={
  category="lo",
  description="BAMUM LETTER PHASE-A MOOMPUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16826,
 },
 [0x16827]={
  category="lo",
  description="BAMUM LETTER PHASE-A KAFA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16827,
 },
 [0x16828]={
  category="lo",
  description="BAMUM LETTER PHASE-A PA LEERAEWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16828,
 },
 [0x16829]={
  category="lo",
  description="BAMUM LETTER PHASE-A NDA LEERAEWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16829,
 },
 [0x1682A]={
  category="lo",
  description="BAMUM LETTER PHASE-A PET",
  direction="l",
  linebreak="al",
  unicodeslot=0x1682A,
 },
 [0x1682B]={
  category="lo",
  description="BAMUM LETTER PHASE-A MAEMKPEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1682B,
 },
 [0x1682C]={
  category="lo",
  description="BAMUM LETTER PHASE-A NIKA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1682C,
 },
 [0x1682D]={
  category="lo",
  description="BAMUM LETTER PHASE-A PUP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1682D,
 },
 [0x1682E]={
  category="lo",
  description="BAMUM LETTER PHASE-A TUAEP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1682E,
 },
 [0x1682F]={
  category="lo",
  description="BAMUM LETTER PHASE-A LUAEP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1682F,
 },
 [0x16830]={
  category="lo",
  description="BAMUM LETTER PHASE-A SONJAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16830,
 },
 [0x16831]={
  category="lo",
  description="BAMUM LETTER PHASE-A TEUTEUWEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16831,
 },
 [0x16832]={
  category="lo",
  description="BAMUM LETTER PHASE-A MAENYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16832,
 },
 [0x16833]={
  category="lo",
  description="BAMUM LETTER PHASE-A KET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16833,
 },
 [0x16834]={
  category="lo",
  description="BAMUM LETTER PHASE-A NDAANGGEUAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16834,
 },
 [0x16835]={
  category="lo",
  description="BAMUM LETTER PHASE-A KUOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16835,
 },
 [0x16836]={
  category="lo",
  description="BAMUM LETTER PHASE-A MOOMEUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x16836,
 },
 [0x16837]={
  category="lo",
  description="BAMUM LETTER PHASE-A SHUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16837,
 },
 [0x16838]={
  category="lo",
  description="BAMUM LETTER PHASE-A LOMMAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16838,
 },
 [0x16839]={
  category="lo",
  description="BAMUM LETTER PHASE-A FIRI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16839,
 },
 [0x1683A]={
  category="lo",
  description="BAMUM LETTER PHASE-A ROM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1683A,
 },
 [0x1683B]={
  category="lo",
  description="BAMUM LETTER PHASE-A KPOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1683B,
 },
 [0x1683C]={
  category="lo",
  description="BAMUM LETTER PHASE-A SOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1683C,
 },
 [0x1683D]={
  category="lo",
  description="BAMUM LETTER PHASE-A MAP PIEET",
  direction="l",
  linebreak="al",
  unicodeslot=0x1683D,
 },
 [0x1683E]={
  category="lo",
  description="BAMUM LETTER PHASE-A SHIRAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1683E,
 },
 [0x1683F]={
  category="lo",
  description="BAMUM LETTER PHASE-A NTAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1683F,
 },
 [0x16840]={
  category="lo",
  description="BAMUM LETTER PHASE-A SHOQ NSHUT YUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16840,
 },
 [0x16841]={
  category="lo",
  description="BAMUM LETTER PHASE-A NYIT MONGKEUAEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16841,
 },
 [0x16842]={
  category="lo",
  description="BAMUM LETTER PHASE-A PAARAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16842,
 },
 [0x16843]={
  category="lo",
  description="BAMUM LETTER PHASE-A NKAARAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16843,
 },
 [0x16844]={
  category="lo",
  description="BAMUM LETTER PHASE-A UNKNOWN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16844,
 },
 [0x16845]={
  category="lo",
  description="BAMUM LETTER PHASE-A NGGEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16845,
 },
 [0x16846]={
  category="lo",
  description="BAMUM LETTER PHASE-A MAESI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16846,
 },
 [0x16847]={
  category="lo",
  description="BAMUM LETTER PHASE-A NJAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16847,
 },
 [0x16848]={
  category="lo",
  description="BAMUM LETTER PHASE-A MBANYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16848,
 },
 [0x16849]={
  category="lo",
  description="BAMUM LETTER PHASE-A NYET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16849,
 },
 [0x1684A]={
  category="lo",
  description="BAMUM LETTER PHASE-A TEUAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1684A,
 },
 [0x1684B]={
  category="lo",
  description="BAMUM LETTER PHASE-A SOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1684B,
 },
 [0x1684C]={
  category="lo",
  description="BAMUM LETTER PHASE-A PAAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1684C,
 },
 [0x1684D]={
  category="lo",
  description="BAMUM LETTER PHASE-A NSHIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1684D,
 },
 [0x1684E]={
  category="lo",
  description="BAMUM LETTER PHASE-A MAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1684E,
 },
 [0x1684F]={
  category="lo",
  description="BAMUM LETTER PHASE-A NYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1684F,
 },
 [0x16850]={
  category="lo",
  description="BAMUM LETTER PHASE-A KAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16850,
 },
 [0x16851]={
  category="lo",
  description="BAMUM LETTER PHASE-A NSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16851,
 },
 [0x16852]={
  category="lo",
  description="BAMUM LETTER PHASE-A VEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16852,
 },
 [0x16853]={
  category="lo",
  description="BAMUM LETTER PHASE-A LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16853,
 },
 [0x16854]={
  category="lo",
  description="BAMUM LETTER PHASE-A NEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16854,
 },
 [0x16855]={
  category="lo",
  description="BAMUM LETTER PHASE-A NAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16855,
 },
 [0x16856]={
  category="lo",
  description="BAMUM LETTER PHASE-A MBAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16856,
 },
 [0x16857]={
  category="lo",
  description="BAMUM LETTER PHASE-B NSHUET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16857,
 },
 [0x16858]={
  category="lo",
  description="BAMUM LETTER PHASE-B TU MAEMGBIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16858,
 },
 [0x16859]={
  category="lo",
  description="BAMUM LETTER PHASE-B SIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16859,
 },
 [0x1685A]={
  category="lo",
  description="BAMUM LETTER PHASE-B SET TU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1685A,
 },
 [0x1685B]={
  category="lo",
  description="BAMUM LETTER PHASE-B LOM NTEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1685B,
 },
 [0x1685C]={
  category="lo",
  description="BAMUM LETTER PHASE-B MBA MAELEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1685C,
 },
 [0x1685D]={
  category="lo",
  description="BAMUM LETTER PHASE-B KIEEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1685D,
 },
 [0x1685E]={
  category="lo",
  description="BAMUM LETTER PHASE-B YEURAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1685E,
 },
 [0x1685F]={
  category="lo",
  description="BAMUM LETTER PHASE-B MBAARAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1685F,
 },
 [0x16860]={
  category="lo",
  description="BAMUM LETTER PHASE-B KAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16860,
 },
 [0x16861]={
  category="lo",
  description="BAMUM LETTER PHASE-B PEESHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16861,
 },
 [0x16862]={
  category="lo",
  description="BAMUM LETTER PHASE-B YAFU LEERAEWA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16862,
 },
 [0x16863]={
  category="lo",
  description="BAMUM LETTER PHASE-B LAM NSHUT NYAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16863,
 },
 [0x16864]={
  category="lo",
  description="BAMUM LETTER PHASE-B NTIEE SHEUOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16864,
 },
 [0x16865]={
  category="lo",
  description="BAMUM LETTER PHASE-B NDU NJAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16865,
 },
 [0x16866]={
  category="lo",
  description="BAMUM LETTER PHASE-B GHEUGHEUAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16866,
 },
 [0x16867]={
  category="lo",
  description="BAMUM LETTER PHASE-B PIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x16867,
 },
 [0x16868]={
  category="lo",
  description="BAMUM LETTER PHASE-B TU NSIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16868,
 },
 [0x16869]={
  category="lo",
  description="BAMUM LETTER PHASE-B SHET NJAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16869,
 },
 [0x1686A]={
  category="lo",
  description="BAMUM LETTER PHASE-B SHEUAEQTU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1686A,
 },
 [0x1686B]={
  category="lo",
  description="BAMUM LETTER PHASE-B MFON TEUAEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1686B,
 },
 [0x1686C]={
  category="lo",
  description="BAMUM LETTER PHASE-B MBIT MBAAKET",
  direction="l",
  linebreak="al",
  unicodeslot=0x1686C,
 },
 [0x1686D]={
  category="lo",
  description="BAMUM LETTER PHASE-B NYI NTEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1686D,
 },
 [0x1686E]={
  category="lo",
  description="BAMUM LETTER PHASE-B KEUPUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1686E,
 },
 [0x1686F]={
  category="lo",
  description="BAMUM LETTER PHASE-B GHEUGHEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1686F,
 },
 [0x16870]={
  category="lo",
  description="BAMUM LETTER PHASE-B KEUYEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16870,
 },
 [0x16871]={
  category="lo",
  description="BAMUM LETTER PHASE-B LAANAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16871,
 },
 [0x16872]={
  category="lo",
  description="BAMUM LETTER PHASE-B PARUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16872,
 },
 [0x16873]={
  category="lo",
  description="BAMUM LETTER PHASE-B VEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16873,
 },
 [0x16874]={
  category="lo",
  description="BAMUM LETTER PHASE-B NGKINDI MVOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16874,
 },
 [0x16875]={
  category="lo",
  description="BAMUM LETTER PHASE-B NGGEU MBU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16875,
 },
 [0x16876]={
  category="lo",
  description="BAMUM LETTER PHASE-B WUAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16876,
 },
 [0x16877]={
  category="lo",
  description="BAMUM LETTER PHASE-B SAKEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16877,
 },
 [0x16878]={
  category="lo",
  description="BAMUM LETTER PHASE-B TAAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16878,
 },
 [0x16879]={
  category="lo",
  description="BAMUM LETTER PHASE-B MEUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16879,
 },
 [0x1687A]={
  category="lo",
  description="BAMUM LETTER PHASE-B NGGUOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1687A,
 },
 [0x1687B]={
  category="lo",
  description="BAMUM LETTER PHASE-B NGGUOQ LARGE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1687B,
 },
 [0x1687C]={
  category="lo",
  description="BAMUM LETTER PHASE-B MFIYAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1687C,
 },
 [0x1687D]={
  category="lo",
  description="BAMUM LETTER PHASE-B SUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1687D,
 },
 [0x1687E]={
  category="lo",
  description="BAMUM LETTER PHASE-B MBEURI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1687E,
 },
 [0x1687F]={
  category="lo",
  description="BAMUM LETTER PHASE-B MONTIEEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1687F,
 },
 [0x16880]={
  category="lo",
  description="BAMUM LETTER PHASE-B NYAEMAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16880,
 },
 [0x16881]={
  category="lo",
  description="BAMUM LETTER PHASE-B PUNGAAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16881,
 },
 [0x16882]={
  category="lo",
  description="BAMUM LETTER PHASE-B MEUT NGGEET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16882,
 },
 [0x16883]={
  category="lo",
  description="BAMUM LETTER PHASE-B FEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16883,
 },
 [0x16884]={
  category="lo",
  description="BAMUM LETTER PHASE-B MBUOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16884,
 },
 [0x16885]={
  category="lo",
  description="BAMUM LETTER PHASE-B FEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16885,
 },
 [0x16886]={
  category="lo",
  description="BAMUM LETTER PHASE-B KEUAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16886,
 },
 [0x16887]={
  category="lo",
  description="BAMUM LETTER PHASE-B MA NJEUAENA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16887,
 },
 [0x16888]={
  category="lo",
  description="BAMUM LETTER PHASE-B MA NJUQA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16888,
 },
 [0x16889]={
  category="lo",
  description="BAMUM LETTER PHASE-B LET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16889,
 },
 [0x1688A]={
  category="lo",
  description="BAMUM LETTER PHASE-B NGGAAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1688A,
 },
 [0x1688B]={
  category="lo",
  description="BAMUM LETTER PHASE-B NSEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1688B,
 },
 [0x1688C]={
  category="lo",
  description="BAMUM LETTER PHASE-B MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1688C,
 },
 [0x1688D]={
  category="lo",
  description="BAMUM LETTER PHASE-B KIQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1688D,
 },
 [0x1688E]={
  category="lo",
  description="BAMUM LETTER PHASE-B NGOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1688E,
 },
 [0x1688F]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGKUE MAEMBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1688F,
 },
 [0x16890]={
  category="lo",
  description="BAMUM LETTER PHASE-C NZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16890,
 },
 [0x16891]={
  category="lo",
  description="BAMUM LETTER PHASE-C YUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16891,
 },
 [0x16892]={
  category="lo",
  description="BAMUM LETTER PHASE-C WANGKUOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16892,
 },
 [0x16893]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGGEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16893,
 },
 [0x16894]={
  category="lo",
  description="BAMUM LETTER PHASE-C NDEUAEREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16894,
 },
 [0x16895]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGKAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16895,
 },
 [0x16896]={
  category="lo",
  description="BAMUM LETTER PHASE-C GHARAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16896,
 },
 [0x16897]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBEEKEET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16897,
 },
 [0x16898]={
  category="lo",
  description="BAMUM LETTER PHASE-C GBAYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16898,
 },
 [0x16899]={
  category="lo",
  description="BAMUM LETTER PHASE-C NYIR MKPARAQ MEUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16899,
 },
 [0x1689A]={
  category="lo",
  description="BAMUM LETTER PHASE-C NTU MBIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1689A,
 },
 [0x1689B]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1689B,
 },
 [0x1689C]={
  category="lo",
  description="BAMUM LETTER PHASE-C PIRIEEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1689C,
 },
 [0x1689D]={
  category="lo",
  description="BAMUM LETTER PHASE-C NDOMBU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1689D,
 },
 [0x1689E]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBAA CABBAGE-TREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1689E,
 },
 [0x1689F]={
  category="lo",
  description="BAMUM LETTER PHASE-C KEUSHEUAEP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1689F,
 },
 [0x168A0]={
  category="lo",
  description="BAMUM LETTER PHASE-C GHAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A0,
 },
 [0x168A1]={
  category="lo",
  description="BAMUM LETTER PHASE-C KEUKAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A1,
 },
 [0x168A2]={
  category="lo",
  description="BAMUM LETTER PHASE-C YU MUOMAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A2,
 },
 [0x168A3]={
  category="lo",
  description="BAMUM LETTER PHASE-C NZEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A3,
 },
 [0x168A4]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A4,
 },
 [0x168A5]={
  category="lo",
  description="BAMUM LETTER PHASE-C NSEUAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A5,
 },
 [0x168A6]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A6,
 },
 [0x168A7]={
  category="lo",
  description="BAMUM LETTER PHASE-C YEUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A7,
 },
 [0x168A8]={
  category="lo",
  description="BAMUM LETTER PHASE-C KPARAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A8,
 },
 [0x168A9]={
  category="lo",
  description="BAMUM LETTER PHASE-C KAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x168A9,
 },
 [0x168AA]={
  category="lo",
  description="BAMUM LETTER PHASE-C SEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x168AA,
 },
 [0x168AB]={
  category="lo",
  description="BAMUM LETTER PHASE-C NDIDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x168AB,
 },
 [0x168AC]={
  category="lo",
  description="BAMUM LETTER PHASE-C TAASHAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168AC,
 },
 [0x168AD]={
  category="lo",
  description="BAMUM LETTER PHASE-C NJUEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168AD,
 },
 [0x168AE]={
  category="lo",
  description="BAMUM LETTER PHASE-C TITA YUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168AE,
 },
 [0x168AF]={
  category="lo",
  description="BAMUM LETTER PHASE-C SUAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x168AF,
 },
 [0x168B0]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGGUAEN NYAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B0,
 },
 [0x168B1]={
  category="lo",
  description="BAMUM LETTER PHASE-C VEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B1,
 },
 [0x168B2]={
  category="lo",
  description="BAMUM LETTER PHASE-C NANSANAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B2,
 },
 [0x168B3]={
  category="lo",
  description="BAMUM LETTER PHASE-C MA KEUAERI",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B3,
 },
 [0x168B4]={
  category="lo",
  description="BAMUM LETTER PHASE-C NTAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B4,
 },
 [0x168B5]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGGUON",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B5,
 },
 [0x168B6]={
  category="lo",
  description="BAMUM LETTER PHASE-C LAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B6,
 },
 [0x168B7]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBIRIEEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B7,
 },
 [0x168B8]={
  category="lo",
  description="BAMUM LETTER PHASE-C MGBASAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B8,
 },
 [0x168B9]={
  category="lo",
  description="BAMUM LETTER PHASE-C NTEUNGBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x168B9,
 },
 [0x168BA]={
  category="lo",
  description="BAMUM LETTER PHASE-C TEUTEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x168BA,
 },
 [0x168BB]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGGUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168BB,
 },
 [0x168BC]={
  category="lo",
  description="BAMUM LETTER PHASE-C FUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168BC,
 },
 [0x168BD]={
  category="lo",
  description="BAMUM LETTER PHASE-C NDEUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x168BD,
 },
 [0x168BE]={
  category="lo",
  description="BAMUM LETTER PHASE-C NSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x168BE,
 },
 [0x168BF]={
  category="lo",
  description="BAMUM LETTER PHASE-C NSHAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168BF,
 },
 [0x168C0]={
  category="lo",
  description="BAMUM LETTER PHASE-C BUNG",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C0,
 },
 [0x168C1]={
  category="lo",
  description="BAMUM LETTER PHASE-C VEUAEPEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C1,
 },
 [0x168C2]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBERAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C2,
 },
 [0x168C3]={
  category="lo",
  description="BAMUM LETTER PHASE-C RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C3,
 },
 [0x168C4]={
  category="lo",
  description="BAMUM LETTER PHASE-C NJAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C4,
 },
 [0x168C5]={
  category="lo",
  description="BAMUM LETTER PHASE-C LAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C5,
 },
 [0x168C6]={
  category="lo",
  description="BAMUM LETTER PHASE-C TITUAEP",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C6,
 },
 [0x168C7]={
  category="lo",
  description="BAMUM LETTER PHASE-C NSUOT NGOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C7,
 },
 [0x168C8]={
  category="lo",
  description="BAMUM LETTER PHASE-C NJEEEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C8,
 },
 [0x168C9]={
  category="lo",
  description="BAMUM LETTER PHASE-C KET",
  direction="l",
  linebreak="al",
  unicodeslot=0x168C9,
 },
 [0x168CA]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGGU",
  direction="l",
  linebreak="al",
  unicodeslot=0x168CA,
 },
 [0x168CB]={
  category="lo",
  description="BAMUM LETTER PHASE-C MAESI",
  direction="l",
  linebreak="al",
  unicodeslot=0x168CB,
 },
 [0x168CC]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBUAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168CC,
 },
 [0x168CD]={
  category="lo",
  description="BAMUM LETTER PHASE-C LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x168CD,
 },
 [0x168CE]={
  category="lo",
  description="BAMUM LETTER PHASE-C KUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x168CE,
 },
 [0x168CF]={
  category="lo",
  description="BAMUM LETTER PHASE-C NJAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168CF,
 },
 [0x168D0]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D0,
 },
 [0x168D1]={
  category="lo",
  description="BAMUM LETTER PHASE-C WUP",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D1,
 },
 [0x168D2]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGGUEET",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D2,
 },
 [0x168D3]={
  category="lo",
  description="BAMUM LETTER PHASE-C NSOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D3,
 },
 [0x168D4]={
  category="lo",
  description="BAMUM LETTER PHASE-C NTEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D4,
 },
 [0x168D5]={
  category="lo",
  description="BAMUM LETTER PHASE-C KUOP NKAARAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D5,
 },
 [0x168D6]={
  category="lo",
  description="BAMUM LETTER PHASE-C NSUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D6,
 },
 [0x168D7]={
  category="lo",
  description="BAMUM LETTER PHASE-C NDAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D7,
 },
 [0x168D8]={
  category="lo",
  description="BAMUM LETTER PHASE-C MA NSIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D8,
 },
 [0x168D9]={
  category="lo",
  description="BAMUM LETTER PHASE-C YAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x168D9,
 },
 [0x168DA]={
  category="lo",
  description="BAMUM LETTER PHASE-C NDAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x168DA,
 },
 [0x168DB]={
  category="lo",
  description="BAMUM LETTER PHASE-C SHUEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168DB,
 },
 [0x168DC]={
  category="lo",
  description="BAMUM LETTER PHASE-C SETFON",
  direction="l",
  linebreak="al",
  unicodeslot=0x168DC,
 },
 [0x168DD]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBI",
  direction="l",
  linebreak="al",
  unicodeslot=0x168DD,
 },
 [0x168DE]={
  category="lo",
  description="BAMUM LETTER PHASE-C MAEMBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x168DE,
 },
 [0x168DF]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBANYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x168DF,
 },
 [0x168E0]={
  category="lo",
  description="BAMUM LETTER PHASE-C KEUSEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E0,
 },
 [0x168E1]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E1,
 },
 [0x168E2]={
  category="lo",
  description="BAMUM LETTER PHASE-C KEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E2,
 },
 [0x168E3]={
  category="lo",
  description="BAMUM LETTER PHASE-C MBAA PICKET",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E3,
 },
 [0x168E4]={
  category="lo",
  description="BAMUM LETTER PHASE-C YUWOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E4,
 },
 [0x168E5]={
  category="lo",
  description="BAMUM LETTER PHASE-C NJEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E5,
 },
 [0x168E6]={
  category="lo",
  description="BAMUM LETTER PHASE-C MIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E6,
 },
 [0x168E7]={
  category="lo",
  description="BAMUM LETTER PHASE-C MUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E7,
 },
 [0x168E8]={
  category="lo",
  description="BAMUM LETTER PHASE-C SHIQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E8,
 },
 [0x168E9]={
  category="lo",
  description="BAMUM LETTER PHASE-C KEN LAW",
  direction="l",
  linebreak="al",
  unicodeslot=0x168E9,
 },
 [0x168EA]={
  category="lo",
  description="BAMUM LETTER PHASE-C KEN FATIGUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168EA,
 },
 [0x168EB]={
  category="lo",
  description="BAMUM LETTER PHASE-C NGAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168EB,
 },
 [0x168EC]={
  category="lo",
  description="BAMUM LETTER PHASE-C NAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168EC,
 },
 [0x168ED]={
  category="lo",
  description="BAMUM LETTER PHASE-C LIQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x168ED,
 },
 [0x168EE]={
  category="lo",
  description="BAMUM LETTER PHASE-C PIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168EE,
 },
 [0x168EF]={
  category="lo",
  description="BAMUM LETTER PHASE-C PEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168EF,
 },
 [0x168F0]={
  category="lo",
  description="BAMUM LETTER PHASE-C TET",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F0,
 },
 [0x168F1]={
  category="lo",
  description="BAMUM LETTER PHASE-D MBUO",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F1,
 },
 [0x168F2]={
  category="lo",
  description="BAMUM LETTER PHASE-D WAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F2,
 },
 [0x168F3]={
  category="lo",
  description="BAMUM LETTER PHASE-D NJI",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F3,
 },
 [0x168F4]={
  category="lo",
  description="BAMUM LETTER PHASE-D MFON",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F4,
 },
 [0x168F5]={
  category="lo",
  description="BAMUM LETTER PHASE-D NJIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F5,
 },
 [0x168F6]={
  category="lo",
  description="BAMUM LETTER PHASE-D LIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F6,
 },
 [0x168F7]={
  category="lo",
  description="BAMUM LETTER PHASE-D NJEUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F7,
 },
 [0x168F8]={
  category="lo",
  description="BAMUM LETTER PHASE-D NSHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F8,
 },
 [0x168F9]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGGAAMAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168F9,
 },
 [0x168FA]={
  category="lo",
  description="BAMUM LETTER PHASE-D NYAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x168FA,
 },
 [0x168FB]={
  category="lo",
  description="BAMUM LETTER PHASE-D WUAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168FB,
 },
 [0x168FC]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGKUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168FC,
 },
 [0x168FD]={
  category="lo",
  description="BAMUM LETTER PHASE-D SHEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x168FD,
 },
 [0x168FE]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGKAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x168FE,
 },
 [0x168FF]={
  category="lo",
  description="BAMUM LETTER PHASE-D KEUAETMEUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x168FF,
 },
 [0x16900]={
  category="lo",
  description="BAMUM LETTER PHASE-D TEUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x16900,
 },
 [0x16901]={
  category="lo",
  description="BAMUM LETTER PHASE-D SHEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16901,
 },
 [0x16902]={
  category="lo",
  description="BAMUM LETTER PHASE-D NJAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16902,
 },
 [0x16903]={
  category="lo",
  description="BAMUM LETTER PHASE-D SUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16903,
 },
 [0x16904]={
  category="lo",
  description="BAMUM LETTER PHASE-D KET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16904,
 },
 [0x16905]={
  category="lo",
  description="BAMUM LETTER PHASE-D YAEMMAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16905,
 },
 [0x16906]={
  category="lo",
  description="BAMUM LETTER PHASE-D KUOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16906,
 },
 [0x16907]={
  category="lo",
  description="BAMUM LETTER PHASE-D SAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16907,
 },
 [0x16908]={
  category="lo",
  description="BAMUM LETTER PHASE-D MFEUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x16908,
 },
 [0x16909]={
  category="lo",
  description="BAMUM LETTER PHASE-D NDEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16909,
 },
 [0x1690A]={
  category="lo",
  description="BAMUM LETTER PHASE-D MALEERI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1690A,
 },
 [0x1690B]={
  category="lo",
  description="BAMUM LETTER PHASE-D MEUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1690B,
 },
 [0x1690C]={
  category="lo",
  description="BAMUM LETTER PHASE-D SEUAEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1690C,
 },
 [0x1690D]={
  category="lo",
  description="BAMUM LETTER PHASE-D YEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1690D,
 },
 [0x1690E]={
  category="lo",
  description="BAMUM LETTER PHASE-D NJEUAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1690E,
 },
 [0x1690F]={
  category="lo",
  description="BAMUM LETTER PHASE-D KEUOT MBUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1690F,
 },
 [0x16910]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGKEURI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16910,
 },
 [0x16911]={
  category="lo",
  description="BAMUM LETTER PHASE-D TU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16911,
 },
 [0x16912]={
  category="lo",
  description="BAMUM LETTER PHASE-D GHAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16912,
 },
 [0x16913]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGKYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16913,
 },
 [0x16914]={
  category="lo",
  description="BAMUM LETTER PHASE-D FEUFEUAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16914,
 },
 [0x16915]={
  category="lo",
  description="BAMUM LETTER PHASE-D NDEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16915,
 },
 [0x16916]={
  category="lo",
  description="BAMUM LETTER PHASE-D MGBOFUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16916,
 },
 [0x16917]={
  category="lo",
  description="BAMUM LETTER PHASE-D LEUAEP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16917,
 },
 [0x16918]={
  category="lo",
  description="BAMUM LETTER PHASE-D NDON",
  direction="l",
  linebreak="al",
  unicodeslot=0x16918,
 },
 [0x16919]={
  category="lo",
  description="BAMUM LETTER PHASE-D MONI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16919,
 },
 [0x1691A]={
  category="lo",
  description="BAMUM LETTER PHASE-D MGBEUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1691A,
 },
 [0x1691B]={
  category="lo",
  description="BAMUM LETTER PHASE-D PUUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1691B,
 },
 [0x1691C]={
  category="lo",
  description="BAMUM LETTER PHASE-D MGBIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1691C,
 },
 [0x1691D]={
  category="lo",
  description="BAMUM LETTER PHASE-D MFO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1691D,
 },
 [0x1691E]={
  category="lo",
  description="BAMUM LETTER PHASE-D LUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1691E,
 },
 [0x1691F]={
  category="lo",
  description="BAMUM LETTER PHASE-D NSIEEP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1691F,
 },
 [0x16920]={
  category="lo",
  description="BAMUM LETTER PHASE-D MBAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16920,
 },
 [0x16921]={
  category="lo",
  description="BAMUM LETTER PHASE-D KWAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16921,
 },
 [0x16922]={
  category="lo",
  description="BAMUM LETTER PHASE-D NYET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16922,
 },
 [0x16923]={
  category="lo",
  description="BAMUM LETTER PHASE-D TEUAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16923,
 },
 [0x16924]={
  category="lo",
  description="BAMUM LETTER PHASE-D SOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x16924,
 },
 [0x16925]={
  category="lo",
  description="BAMUM LETTER PHASE-D YUWOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16925,
 },
 [0x16926]={
  category="lo",
  description="BAMUM LETTER PHASE-D KEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16926,
 },
 [0x16927]={
  category="lo",
  description="BAMUM LETTER PHASE-D RAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16927,
 },
 [0x16928]={
  category="lo",
  description="BAMUM LETTER PHASE-D TEEEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16928,
 },
 [0x16929]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGKEUAEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16929,
 },
 [0x1692A]={
  category="lo",
  description="BAMUM LETTER PHASE-D MFEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1692A,
 },
 [0x1692B]={
  category="lo",
  description="BAMUM LETTER PHASE-D NSIEET",
  direction="l",
  linebreak="al",
  unicodeslot=0x1692B,
 },
 [0x1692C]={
  category="lo",
  description="BAMUM LETTER PHASE-D KEUP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1692C,
 },
 [0x1692D]={
  category="lo",
  description="BAMUM LETTER PHASE-D PIP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1692D,
 },
 [0x1692E]={
  category="lo",
  description="BAMUM LETTER PHASE-D PEUTAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1692E,
 },
 [0x1692F]={
  category="lo",
  description="BAMUM LETTER PHASE-D NYUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1692F,
 },
 [0x16930]={
  category="lo",
  description="BAMUM LETTER PHASE-D LET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16930,
 },
 [0x16931]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGGAAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16931,
 },
 [0x16932]={
  category="lo",
  description="BAMUM LETTER PHASE-D MFIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16932,
 },
 [0x16933]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGGWAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16933,
 },
 [0x16934]={
  category="lo",
  description="BAMUM LETTER PHASE-D YUOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16934,
 },
 [0x16935]={
  category="lo",
  description="BAMUM LETTER PHASE-D PAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16935,
 },
 [0x16936]={
  category="lo",
  description="BAMUM LETTER PHASE-D YUOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16936,
 },
 [0x16937]={
  category="lo",
  description="BAMUM LETTER PHASE-D NDAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16937,
 },
 [0x16938]={
  category="lo",
  description="BAMUM LETTER PHASE-D NTEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16938,
 },
 [0x16939]={
  category="lo",
  description="BAMUM LETTER PHASE-D SUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16939,
 },
 [0x1693A]={
  category="lo",
  description="BAMUM LETTER PHASE-D KUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1693A,
 },
 [0x1693B]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGGEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x1693B,
 },
 [0x1693C]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGKIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1693C,
 },
 [0x1693D]={
  category="lo",
  description="BAMUM LETTER PHASE-D TUOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1693D,
 },
 [0x1693E]={
  category="lo",
  description="BAMUM LETTER PHASE-D MEUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1693E,
 },
 [0x1693F]={
  category="lo",
  description="BAMUM LETTER PHASE-D KUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1693F,
 },
 [0x16940]={
  category="lo",
  description="BAMUM LETTER PHASE-D NSUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16940,
 },
 [0x16941]={
  category="lo",
  description="BAMUM LETTER PHASE-D TEUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16941,
 },
 [0x16942]={
  category="lo",
  description="BAMUM LETTER PHASE-D MAENJET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16942,
 },
 [0x16943]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGGAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16943,
 },
 [0x16944]={
  category="lo",
  description="BAMUM LETTER PHASE-D LEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16944,
 },
 [0x16945]={
  category="lo",
  description="BAMUM LETTER PHASE-D NGGUOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16945,
 },
 [0x16946]={
  category="lo",
  description="BAMUM LETTER PHASE-D NSHUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x16946,
 },
 [0x16947]={
  category="lo",
  description="BAMUM LETTER PHASE-D NJUEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16947,
 },
 [0x16948]={
  category="lo",
  description="BAMUM LETTER PHASE-D GHEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16948,
 },
 [0x16949]={
  category="lo",
  description="BAMUM LETTER PHASE-D KU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16949,
 },
 [0x1694A]={
  category="lo",
  description="BAMUM LETTER PHASE-D REN OLD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1694A,
 },
 [0x1694B]={
  category="lo",
  description="BAMUM LETTER PHASE-D TAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1694B,
 },
 [0x1694C]={
  category="lo",
  description="BAMUM LETTER PHASE-D TOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1694C,
 },
 [0x1694D]={
  category="lo",
  description="BAMUM LETTER PHASE-D NYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1694D,
 },
 [0x1694E]={
  category="lo",
  description="BAMUM LETTER PHASE-D RII",
  direction="l",
  linebreak="al",
  unicodeslot=0x1694E,
 },
 [0x1694F]={
  category="lo",
  description="BAMUM LETTER PHASE-D LEEEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1694F,
 },
 [0x16950]={
  category="lo",
  description="BAMUM LETTER PHASE-D MEEEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16950,
 },
 [0x16951]={
  category="lo",
  description="BAMUM LETTER PHASE-D M",
  direction="l",
  linebreak="al",
  unicodeslot=0x16951,
 },
 [0x16952]={
  category="lo",
  description="BAMUM LETTER PHASE-D SUU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16952,
 },
 [0x16953]={
  category="lo",
  description="BAMUM LETTER PHASE-D MU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16953,
 },
 [0x16954]={
  category="lo",
  description="BAMUM LETTER PHASE-D SHII",
  direction="l",
  linebreak="al",
  unicodeslot=0x16954,
 },
 [0x16955]={
  category="lo",
  description="BAMUM LETTER PHASE-D SHEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16955,
 },
 [0x16956]={
  category="lo",
  description="BAMUM LETTER PHASE-D KYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16956,
 },
 [0x16957]={
  category="lo",
  description="BAMUM LETTER PHASE-D NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16957,
 },
 [0x16958]={
  category="lo",
  description="BAMUM LETTER PHASE-D SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16958,
 },
 [0x16959]={
  category="lo",
  description="BAMUM LETTER PHASE-D NTEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16959,
 },
 [0x1695A]={
  category="lo",
  description="BAMUM LETTER PHASE-D PEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1695A,
 },
 [0x1695B]={
  category="lo",
  description="BAMUM LETTER PHASE-D NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1695B,
 },
 [0x1695C]={
  category="lo",
  description="BAMUM LETTER PHASE-D SHOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1695C,
 },
 [0x1695D]={
  category="lo",
  description="BAMUM LETTER PHASE-D PUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1695D,
 },
 [0x1695E]={
  category="lo",
  description="BAMUM LETTER PHASE-D MVOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1695E,
 },
 [0x1695F]={
  category="lo",
  description="BAMUM LETTER PHASE-D LOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1695F,
 },
 [0x16960]={
  category="lo",
  description="BAMUM LETTER PHASE-D REN MUCH",
  direction="l",
  linebreak="al",
  unicodeslot=0x16960,
 },
 [0x16961]={
  category="lo",
  description="BAMUM LETTER PHASE-D TI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16961,
 },
 [0x16962]={
  category="lo",
  description="BAMUM LETTER PHASE-D NTUU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16962,
 },
 [0x16963]={
  category="lo",
  description="BAMUM LETTER PHASE-D MBAA SEVEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16963,
 },
 [0x16964]={
  category="lo",
  description="BAMUM LETTER PHASE-D SAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16964,
 },
 [0x16965]={
  category="lo",
  description="BAMUM LETTER PHASE-D FAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16965,
 },
 [0x16966]={
  category="lo",
  description="BAMUM LETTER PHASE-E NDAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16966,
 },
 [0x16967]={
  category="lo",
  description="BAMUM LETTER PHASE-E TOON",
  direction="l",
  linebreak="al",
  unicodeslot=0x16967,
 },
 [0x16968]={
  category="lo",
  description="BAMUM LETTER PHASE-E MBEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16968,
 },
 [0x16969]={
  category="lo",
  description="BAMUM LETTER PHASE-E LAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x16969,
 },
 [0x1696A]={
  category="lo",
  description="BAMUM LETTER PHASE-E VOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1696A,
 },
 [0x1696B]={
  category="lo",
  description="BAMUM LETTER PHASE-E LOON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1696B,
 },
 [0x1696C]={
  category="lo",
  description="BAMUM LETTER PHASE-E PAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1696C,
 },
 [0x1696D]={
  category="lo",
  description="BAMUM LETTER PHASE-E SOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1696D,
 },
 [0x1696E]={
  category="lo",
  description="BAMUM LETTER PHASE-E RAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1696E,
 },
 [0x1696F]={
  category="lo",
  description="BAMUM LETTER PHASE-E NSHUOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1696F,
 },
 [0x16970]={
  category="lo",
  description="BAMUM LETTER PHASE-E NDUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16970,
 },
 [0x16971]={
  category="lo",
  description="BAMUM LETTER PHASE-E PUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16971,
 },
 [0x16972]={
  category="lo",
  description="BAMUM LETTER PHASE-E TAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16972,
 },
 [0x16973]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGKA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16973,
 },
 [0x16974]={
  category="lo",
  description="BAMUM LETTER PHASE-E KPEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16974,
 },
 [0x16975]={
  category="lo",
  description="BAMUM LETTER PHASE-E WUO",
  direction="l",
  linebreak="al",
  unicodeslot=0x16975,
 },
 [0x16976]={
  category="lo",
  description="BAMUM LETTER PHASE-E SEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16976,
 },
 [0x16977]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGGEUAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16977,
 },
 [0x16978]={
  category="lo",
  description="BAMUM LETTER PHASE-E PAAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16978,
 },
 [0x16979]={
  category="lo",
  description="BAMUM LETTER PHASE-E TOO",
  direction="l",
  linebreak="al",
  unicodeslot=0x16979,
 },
 [0x1697A]={
  category="lo",
  description="BAMUM LETTER PHASE-E KUOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1697A,
 },
 [0x1697B]={
  category="lo",
  description="BAMUM LETTER PHASE-E LOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1697B,
 },
 [0x1697C]={
  category="lo",
  description="BAMUM LETTER PHASE-E NSHIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1697C,
 },
 [0x1697D]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGOP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1697D,
 },
 [0x1697E]={
  category="lo",
  description="BAMUM LETTER PHASE-E MAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1697E,
 },
 [0x1697F]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGKEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x1697F,
 },
 [0x16980]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16980,
 },
 [0x16981]={
  category="lo",
  description="BAMUM LETTER PHASE-E NSHUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16981,
 },
 [0x16982]={
  category="lo",
  description="BAMUM LETTER PHASE-E RIMGBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16982,
 },
 [0x16983]={
  category="lo",
  description="BAMUM LETTER PHASE-E NJEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16983,
 },
 [0x16984]={
  category="lo",
  description="BAMUM LETTER PHASE-E PEEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16984,
 },
 [0x16985]={
  category="lo",
  description="BAMUM LETTER PHASE-E SAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16985,
 },
 [0x16986]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGGURAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16986,
 },
 [0x16987]={
  category="lo",
  description="BAMUM LETTER PHASE-E MGBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16987,
 },
 [0x16988]={
  category="lo",
  description="BAMUM LETTER PHASE-E GHEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16988,
 },
 [0x16989]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGKEUAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16989,
 },
 [0x1698A]={
  category="lo",
  description="BAMUM LETTER PHASE-E NJAEMLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1698A,
 },
 [0x1698B]={
  category="lo",
  description="BAMUM LETTER PHASE-E MAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1698B,
 },
 [0x1698C]={
  category="lo",
  description="BAMUM LETTER PHASE-E LOOT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1698C,
 },
 [0x1698D]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGGEEEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1698D,
 },
 [0x1698E]={
  category="lo",
  description="BAMUM LETTER PHASE-E NDIQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1698E,
 },
 [0x1698F]={
  category="lo",
  description="BAMUM LETTER PHASE-E TAEN NTEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1698F,
 },
 [0x16990]={
  category="lo",
  description="BAMUM LETTER PHASE-E SET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16990,
 },
 [0x16991]={
  category="lo",
  description="BAMUM LETTER PHASE-E PUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16991,
 },
 [0x16992]={
  category="lo",
  description="BAMUM LETTER PHASE-E NDAA SOFTNESS",
  direction="l",
  linebreak="al",
  unicodeslot=0x16992,
 },
 [0x16993]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGGUAESHAE NYAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16993,
 },
 [0x16994]={
  category="lo",
  description="BAMUM LETTER PHASE-E YIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16994,
 },
 [0x16995]={
  category="lo",
  description="BAMUM LETTER PHASE-E GHEUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16995,
 },
 [0x16996]={
  category="lo",
  description="BAMUM LETTER PHASE-E TUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16996,
 },
 [0x16997]={
  category="lo",
  description="BAMUM LETTER PHASE-E YEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16997,
 },
 [0x16998]={
  category="lo",
  description="BAMUM LETTER PHASE-E PO",
  direction="l",
  linebreak="al",
  unicodeslot=0x16998,
 },
 [0x16999]={
  category="lo",
  description="BAMUM LETTER PHASE-E TUMAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16999,
 },
 [0x1699A]={
  category="lo",
  description="BAMUM LETTER PHASE-E KEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1699A,
 },
 [0x1699B]={
  category="lo",
  description="BAMUM LETTER PHASE-E SUAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1699B,
 },
 [0x1699C]={
  category="lo",
  description="BAMUM LETTER PHASE-E TEUAEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x1699C,
 },
 [0x1699D]={
  category="lo",
  description="BAMUM LETTER PHASE-E VEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1699D,
 },
 [0x1699E]={
  category="lo",
  description="BAMUM LETTER PHASE-E WEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x1699E,
 },
 [0x1699F]={
  category="lo",
  description="BAMUM LETTER PHASE-E LAAM",
  direction="l",
  linebreak="al",
  unicodeslot=0x1699F,
 },
 [0x169A0]={
  category="lo",
  description="BAMUM LETTER PHASE-E PU",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A0,
 },
 [0x169A1]={
  category="lo",
  description="BAMUM LETTER PHASE-E TAAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A1,
 },
 [0x169A2]={
  category="lo",
  description="BAMUM LETTER PHASE-E GHAAMAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A2,
 },
 [0x169A3]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGEUREUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A3,
 },
 [0x169A4]={
  category="lo",
  description="BAMUM LETTER PHASE-E SHEUAEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A4,
 },
 [0x169A5]={
  category="lo",
  description="BAMUM LETTER PHASE-E MGBEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A5,
 },
 [0x169A6]={
  category="lo",
  description="BAMUM LETTER PHASE-E MBEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A6,
 },
 [0x169A7]={
  category="lo",
  description="BAMUM LETTER PHASE-E NZAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A7,
 },
 [0x169A8]={
  category="lo",
  description="BAMUM LETTER PHASE-E NKOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A8,
 },
 [0x169A9]={
  category="lo",
  description="BAMUM LETTER PHASE-E GBET",
  direction="l",
  linebreak="al",
  unicodeslot=0x169A9,
 },
 [0x169AA]={
  category="lo",
  description="BAMUM LETTER PHASE-E TUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x169AA,
 },
 [0x169AB]={
  category="lo",
  description="BAMUM LETTER PHASE-E KUET",
  direction="l",
  linebreak="al",
  unicodeslot=0x169AB,
 },
 [0x169AC]={
  category="lo",
  description="BAMUM LETTER PHASE-E YAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x169AC,
 },
 [0x169AD]={
  category="lo",
  description="BAMUM LETTER PHASE-E NYI CLEAVER",
  direction="l",
  linebreak="al",
  unicodeslot=0x169AD,
 },
 [0x169AE]={
  category="lo",
  description="BAMUM LETTER PHASE-E YIT",
  direction="l",
  linebreak="al",
  unicodeslot=0x169AE,
 },
 [0x169AF]={
  category="lo",
  description="BAMUM LETTER PHASE-E MFEUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169AF,
 },
 [0x169B0]={
  category="lo",
  description="BAMUM LETTER PHASE-E NDIAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B0,
 },
 [0x169B1]={
  category="lo",
  description="BAMUM LETTER PHASE-E PIEEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B1,
 },
 [0x169B2]={
  category="lo",
  description="BAMUM LETTER PHASE-E YUEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B2,
 },
 [0x169B3]={
  category="lo",
  description="BAMUM LETTER PHASE-E LEUAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B3,
 },
 [0x169B4]={
  category="lo",
  description="BAMUM LETTER PHASE-E FUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B4,
 },
 [0x169B5]={
  category="lo",
  description="BAMUM LETTER PHASE-E GBEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B5,
 },
 [0x169B6]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGKUP",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B6,
 },
 [0x169B7]={
  category="lo",
  description="BAMUM LETTER PHASE-E KET",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B7,
 },
 [0x169B8]={
  category="lo",
  description="BAMUM LETTER PHASE-E MAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B8,
 },
 [0x169B9]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGKAAMI",
  direction="l",
  linebreak="al",
  unicodeslot=0x169B9,
 },
 [0x169BA]={
  category="lo",
  description="BAMUM LETTER PHASE-E GHET",
  direction="l",
  linebreak="al",
  unicodeslot=0x169BA,
 },
 [0x169BB]={
  category="lo",
  description="BAMUM LETTER PHASE-E FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x169BB,
 },
 [0x169BC]={
  category="lo",
  description="BAMUM LETTER PHASE-E NTUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x169BC,
 },
 [0x169BD]={
  category="lo",
  description="BAMUM LETTER PHASE-E PEUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x169BD,
 },
 [0x169BE]={
  category="lo",
  description="BAMUM LETTER PHASE-E YEUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x169BE,
 },
 [0x169BF]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGGEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169BF,
 },
 [0x169C0]={
  category="lo",
  description="BAMUM LETTER PHASE-E NYI BETWEEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C0,
 },
 [0x169C1]={
  category="lo",
  description="BAMUM LETTER PHASE-E NZUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C1,
 },
 [0x169C2]={
  category="lo",
  description="BAMUM LETTER PHASE-E POON",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C2,
 },
 [0x169C3]={
  category="lo",
  description="BAMUM LETTER PHASE-E MIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C3,
 },
 [0x169C4]={
  category="lo",
  description="BAMUM LETTER PHASE-E FUET",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C4,
 },
 [0x169C5]={
  category="lo",
  description="BAMUM LETTER PHASE-E NAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C5,
 },
 [0x169C6]={
  category="lo",
  description="BAMUM LETTER PHASE-E MUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C6,
 },
 [0x169C7]={
  category="lo",
  description="BAMUM LETTER PHASE-E GHEUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C7,
 },
 [0x169C8]={
  category="lo",
  description="BAMUM LETTER PHASE-E FU I",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C8,
 },
 [0x169C9]={
  category="lo",
  description="BAMUM LETTER PHASE-E MVI",
  direction="l",
  linebreak="al",
  unicodeslot=0x169C9,
 },
 [0x169CA]={
  category="lo",
  description="BAMUM LETTER PHASE-E PUAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169CA,
 },
 [0x169CB]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGKUM",
  direction="l",
  linebreak="al",
  unicodeslot=0x169CB,
 },
 [0x169CC]={
  category="lo",
  description="BAMUM LETTER PHASE-E KUT",
  direction="l",
  linebreak="al",
  unicodeslot=0x169CC,
 },
 [0x169CD]={
  category="lo",
  description="BAMUM LETTER PHASE-E PIET",
  direction="l",
  linebreak="al",
  unicodeslot=0x169CD,
 },
 [0x169CE]={
  category="lo",
  description="BAMUM LETTER PHASE-E NTAP",
  direction="l",
  linebreak="al",
  unicodeslot=0x169CE,
 },
 [0x169CF]={
  category="lo",
  description="BAMUM LETTER PHASE-E YEUAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x169CF,
 },
 [0x169D0]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGGUP",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D0,
 },
 [0x169D1]={
  category="lo",
  description="BAMUM LETTER PHASE-E PA PEOPLE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D1,
 },
 [0x169D2]={
  category="lo",
  description="BAMUM LETTER PHASE-E FU CALL",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D2,
 },
 [0x169D3]={
  category="lo",
  description="BAMUM LETTER PHASE-E FOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D3,
 },
 [0x169D4]={
  category="lo",
  description="BAMUM LETTER PHASE-E NJEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D4,
 },
 [0x169D5]={
  category="lo",
  description="BAMUM LETTER PHASE-E A",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D5,
 },
 [0x169D6]={
  category="lo",
  description="BAMUM LETTER PHASE-E TOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D6,
 },
 [0x169D7]={
  category="lo",
  description="BAMUM LETTER PHASE-E O",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D7,
 },
 [0x169D8]={
  category="lo",
  description="BAMUM LETTER PHASE-E I",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D8,
 },
 [0x169D9]={
  category="lo",
  description="BAMUM LETTER PHASE-E LAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169D9,
 },
 [0x169DA]={
  category="lo",
  description="BAMUM LETTER PHASE-E PA PLURAL",
  direction="l",
  linebreak="al",
  unicodeslot=0x169DA,
 },
 [0x169DB]={
  category="lo",
  description="BAMUM LETTER PHASE-E TAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x169DB,
 },
 [0x169DC]={
  category="lo",
  description="BAMUM LETTER PHASE-E TAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169DC,
 },
 [0x169DD]={
  category="lo",
  description="BAMUM LETTER PHASE-E NDAA MY HOUSE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169DD,
 },
 [0x169DE]={
  category="lo",
  description="BAMUM LETTER PHASE-E SHIQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169DE,
 },
 [0x169DF]={
  category="lo",
  description="BAMUM LETTER PHASE-E YEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x169DF,
 },
 [0x169E0]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E0,
 },
 [0x169E1]={
  category="lo",
  description="BAMUM LETTER PHASE-E YUAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E1,
 },
 [0x169E2]={
  category="lo",
  description="BAMUM LETTER PHASE-E YOQ SWIMMING",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E2,
 },
 [0x169E3]={
  category="lo",
  description="BAMUM LETTER PHASE-E YOQ COVER",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E3,
 },
 [0x169E4]={
  category="lo",
  description="BAMUM LETTER PHASE-E YUQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E4,
 },
 [0x169E5]={
  category="lo",
  description="BAMUM LETTER PHASE-E YUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E5,
 },
 [0x169E6]={
  category="lo",
  description="BAMUM LETTER PHASE-E KEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E6,
 },
 [0x169E7]={
  category="lo",
  description="BAMUM LETTER PHASE-E PEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E7,
 },
 [0x169E8]={
  category="lo",
  description="BAMUM LETTER PHASE-E NJEE EPOCH",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E8,
 },
 [0x169E9]={
  category="lo",
  description="BAMUM LETTER PHASE-E PUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169E9,
 },
 [0x169EA]={
  category="lo",
  description="BAMUM LETTER PHASE-E WUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169EA,
 },
 [0x169EB]={
  category="lo",
  description="BAMUM LETTER PHASE-E FEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169EB,
 },
 [0x169EC]={
  category="lo",
  description="BAMUM LETTER PHASE-E VEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169EC,
 },
 [0x169ED]={
  category="lo",
  description="BAMUM LETTER PHASE-E LU",
  direction="l",
  linebreak="al",
  unicodeslot=0x169ED,
 },
 [0x169EE]={
  category="lo",
  description="BAMUM LETTER PHASE-E MI",
  direction="l",
  linebreak="al",
  unicodeslot=0x169EE,
 },
 [0x169EF]={
  category="lo",
  description="BAMUM LETTER PHASE-E REUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x169EF,
 },
 [0x169F0]={
  category="lo",
  description="BAMUM LETTER PHASE-E RAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F0,
 },
 [0x169F1]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGUAET",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F1,
 },
 [0x169F2]={
  category="lo",
  description="BAMUM LETTER PHASE-E NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F2,
 },
 [0x169F3]={
  category="lo",
  description="BAMUM LETTER PHASE-E SHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F3,
 },
 [0x169F4]={
  category="lo",
  description="BAMUM LETTER PHASE-E SHOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F4,
 },
 [0x169F5]={
  category="lo",
  description="BAMUM LETTER PHASE-E FU REMEDY",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F5,
 },
 [0x169F6]={
  category="lo",
  description="BAMUM LETTER PHASE-E NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F6,
 },
 [0x169F7]={
  category="lo",
  description="BAMUM LETTER PHASE-E PI",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F7,
 },
 [0x169F8]={
  category="lo",
  description="BAMUM LETTER PHASE-E LOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F8,
 },
 [0x169F9]={
  category="lo",
  description="BAMUM LETTER PHASE-E KO",
  direction="l",
  linebreak="al",
  unicodeslot=0x169F9,
 },
 [0x169FA]={
  category="lo",
  description="BAMUM LETTER PHASE-E MEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x169FA,
 },
 [0x169FB]={
  category="lo",
  description="BAMUM LETTER PHASE-E MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x169FB,
 },
 [0x169FC]={
  category="lo",
  description="BAMUM LETTER PHASE-E MAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x169FC,
 },
 [0x169FD]={
  category="lo",
  description="BAMUM LETTER PHASE-E TEU",
  direction="l",
  linebreak="al",
  unicodeslot=0x169FD,
 },
 [0x169FE]={
  category="lo",
  description="BAMUM LETTER PHASE-E KI",
  direction="l",
  linebreak="al",
  unicodeslot=0x169FE,
 },
 [0x169FF]={
  category="lo",
  description="BAMUM LETTER PHASE-E MON",
  direction="l",
  linebreak="al",
  unicodeslot=0x169FF,
 },
 [0x16A00]={
  category="lo",
  description="BAMUM LETTER PHASE-E TEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A00,
 },
 [0x16A01]={
  category="lo",
  description="BAMUM LETTER PHASE-E FAQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A01,
 },
 [0x16A02]={
  category="lo",
  description="BAMUM LETTER PHASE-E GHOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A02,
 },
 [0x16A03]={
  category="lo",
  description="BAMUM LETTER PHASE-F KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A03,
 },
 [0x16A04]={
  category="lo",
  description="BAMUM LETTER PHASE-F U",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A04,
 },
 [0x16A05]={
  category="lo",
  description="BAMUM LETTER PHASE-F KU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A05,
 },
 [0x16A06]={
  category="lo",
  description="BAMUM LETTER PHASE-F EE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A06,
 },
 [0x16A07]={
  category="lo",
  description="BAMUM LETTER PHASE-F REE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A07,
 },
 [0x16A08]={
  category="lo",
  description="BAMUM LETTER PHASE-F TAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A08,
 },
 [0x16A09]={
  category="lo",
  description="BAMUM LETTER PHASE-F NYI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A09,
 },
 [0x16A0A]={
  category="lo",
  description="BAMUM LETTER PHASE-F LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A0A,
 },
 [0x16A0B]={
  category="lo",
  description="BAMUM LETTER PHASE-F RII",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A0B,
 },
 [0x16A0C]={
  category="lo",
  description="BAMUM LETTER PHASE-F RIEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A0C,
 },
 [0x16A0D]={
  category="lo",
  description="BAMUM LETTER PHASE-F MEEEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A0D,
 },
 [0x16A0E]={
  category="lo",
  description="BAMUM LETTER PHASE-F TAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A0E,
 },
 [0x16A0F]={
  category="lo",
  description="BAMUM LETTER PHASE-F NDAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A0F,
 },
 [0x16A10]={
  category="lo",
  description="BAMUM LETTER PHASE-F NJAEM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A10,
 },
 [0x16A11]={
  category="lo",
  description="BAMUM LETTER PHASE-F M",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A11,
 },
 [0x16A12]={
  category="lo",
  description="BAMUM LETTER PHASE-F SUU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A12,
 },
 [0x16A13]={
  category="lo",
  description="BAMUM LETTER PHASE-F SHII",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A13,
 },
 [0x16A14]={
  category="lo",
  description="BAMUM LETTER PHASE-F SI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A14,
 },
 [0x16A15]={
  category="lo",
  description="BAMUM LETTER PHASE-F SEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A15,
 },
 [0x16A16]={
  category="lo",
  description="BAMUM LETTER PHASE-F KYEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A16,
 },
 [0x16A17]={
  category="lo",
  description="BAMUM LETTER PHASE-F KET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A17,
 },
 [0x16A18]={
  category="lo",
  description="BAMUM LETTER PHASE-F NUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A18,
 },
 [0x16A19]={
  category="lo",
  description="BAMUM LETTER PHASE-F NU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A19,
 },
 [0x16A1A]={
  category="lo",
  description="BAMUM LETTER PHASE-F NJUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A1A,
 },
 [0x16A1B]={
  category="lo",
  description="BAMUM LETTER PHASE-F YOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A1B,
 },
 [0x16A1C]={
  category="lo",
  description="BAMUM LETTER PHASE-F SHU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A1C,
 },
 [0x16A1D]={
  category="lo",
  description="BAMUM LETTER PHASE-F YA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A1D,
 },
 [0x16A1E]={
  category="lo",
  description="BAMUM LETTER PHASE-F NSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A1E,
 },
 [0x16A1F]={
  category="lo",
  description="BAMUM LETTER PHASE-F PEUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A1F,
 },
 [0x16A20]={
  category="lo",
  description="BAMUM LETTER PHASE-F NTEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A20,
 },
 [0x16A21]={
  category="lo",
  description="BAMUM LETTER PHASE-F WUE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A21,
 },
 [0x16A22]={
  category="lo",
  description="BAMUM LETTER PHASE-F PEE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A22,
 },
 [0x16A23]={
  category="lo",
  description="BAMUM LETTER PHASE-F RU",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A23,
 },
 [0x16A24]={
  category="lo",
  description="BAMUM LETTER PHASE-F NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A24,
 },
 [0x16A25]={
  category="lo",
  description="BAMUM LETTER PHASE-F REUX",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A25,
 },
 [0x16A26]={
  category="lo",
  description="BAMUM LETTER PHASE-F KEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A26,
 },
 [0x16A27]={
  category="lo",
  description="BAMUM LETTER PHASE-F NGKWAEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A27,
 },
 [0x16A28]={
  category="lo",
  description="BAMUM LETTER PHASE-F NGGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A28,
 },
 [0x16A29]={
  category="lo",
  description="BAMUM LETTER PHASE-F SHO",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A29,
 },
 [0x16A2A]={
  category="lo",
  description="BAMUM LETTER PHASE-F PUAE",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A2A,
 },
 [0x16A2B]={
  category="lo",
  description="BAMUM LETTER PHASE-F FOM",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A2B,
 },
 [0x16A2C]={
  category="lo",
  description="BAMUM LETTER PHASE-F WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A2C,
 },
 [0x16A2D]={
  category="lo",
  description="BAMUM LETTER PHASE-F LI",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A2D,
 },
 [0x16A2E]={
  category="lo",
  description="BAMUM LETTER PHASE-F LOQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A2E,
 },
 [0x16A2F]={
  category="lo",
  description="BAMUM LETTER PHASE-F KO",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A2F,
 },
 [0x16A30]={
  category="lo",
  description="BAMUM LETTER PHASE-F MBEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A30,
 },
 [0x16A31]={
  category="lo",
  description="BAMUM LETTER PHASE-F REN",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A31,
 },
 [0x16A32]={
  category="lo",
  description="BAMUM LETTER PHASE-F MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A32,
 },
 [0x16A33]={
  category="lo",
  description="BAMUM LETTER PHASE-F MO",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A33,
 },
 [0x16A34]={
  category="lo",
  description="BAMUM LETTER PHASE-F MBAA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A34,
 },
 [0x16A35]={
  category="lo",
  description="BAMUM LETTER PHASE-F TET",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A35,
 },
 [0x16A36]={
  category="lo",
  description="BAMUM LETTER PHASE-F KPA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A36,
 },
 [0x16A37]={
  category="lo",
  description="BAMUM LETTER PHASE-F SAMBA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A37,
 },
 [0x16A38]={
  category="lo",
  description="BAMUM LETTER PHASE-F VUEQ",
  direction="l",
  linebreak="al",
  unicodeslot=0x16A38,
 },
 [0x16F00]={
  category="lo",
  description="MIAO LETTER PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F00,
 },
 [0x16F01]={
  category="lo",
  description="MIAO LETTER BA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F01,
 },
 [0x16F02]={
  category="lo",
  description="MIAO LETTER YI PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F02,
 },
 [0x16F03]={
  category="lo",
  description="MIAO LETTER PLA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F03,
 },
 [0x16F04]={
  category="lo",
  description="MIAO LETTER MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F04,
 },
 [0x16F05]={
  category="lo",
  description="MIAO LETTER MHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F05,
 },
 [0x16F06]={
  category="lo",
  description="MIAO LETTER ARCHAIC MA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F06,
 },
 [0x16F07]={
  category="lo",
  description="MIAO LETTER FA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F07,
 },
 [0x16F08]={
  category="lo",
  description="MIAO LETTER VA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F08,
 },
 [0x16F09]={
  category="lo",
  description="MIAO LETTER VFA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F09,
 },
 [0x16F0A]={
  category="lo",
  description="MIAO LETTER TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F0A,
 },
 [0x16F0B]={
  category="lo",
  description="MIAO LETTER DA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F0B,
 },
 [0x16F0C]={
  category="lo",
  description="MIAO LETTER YI TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F0C,
 },
 [0x16F0D]={
  category="lo",
  description="MIAO LETTER YI TA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F0D,
 },
 [0x16F0E]={
  category="lo",
  description="MIAO LETTER TTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F0E,
 },
 [0x16F0F]={
  category="lo",
  description="MIAO LETTER DDA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F0F,
 },
 [0x16F10]={
  category="lo",
  description="MIAO LETTER NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F10,
 },
 [0x16F11]={
  category="lo",
  description="MIAO LETTER NHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F11,
 },
 [0x16F12]={
  category="lo",
  description="MIAO LETTER YI NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F12,
 },
 [0x16F13]={
  category="lo",
  description="MIAO LETTER ARCHAIC NA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F13,
 },
 [0x16F14]={
  category="lo",
  description="MIAO LETTER NNA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F14,
 },
 [0x16F15]={
  category="lo",
  description="MIAO LETTER NNHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F15,
 },
 [0x16F16]={
  category="lo",
  description="MIAO LETTER LA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F16,
 },
 [0x16F17]={
  category="lo",
  description="MIAO LETTER LYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F17,
 },
 [0x16F18]={
  category="lo",
  description="MIAO LETTER LHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F18,
 },
 [0x16F19]={
  category="lo",
  description="MIAO LETTER LHYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F19,
 },
 [0x16F1A]={
  category="lo",
  description="MIAO LETTER TLHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F1A,
 },
 [0x16F1B]={
  category="lo",
  description="MIAO LETTER DLHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F1B,
 },
 [0x16F1C]={
  category="lo",
  description="MIAO LETTER TLHYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F1C,
 },
 [0x16F1D]={
  category="lo",
  description="MIAO LETTER DLHYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F1D,
 },
 [0x16F1E]={
  category="lo",
  description="MIAO LETTER KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F1E,
 },
 [0x16F1F]={
  category="lo",
  description="MIAO LETTER GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F1F,
 },
 [0x16F20]={
  category="lo",
  description="MIAO LETTER YI KA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F20,
 },
 [0x16F21]={
  category="lo",
  description="MIAO LETTER QA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F21,
 },
 [0x16F22]={
  category="lo",
  description="MIAO LETTER QGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F22,
 },
 [0x16F23]={
  category="lo",
  description="MIAO LETTER NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F23,
 },
 [0x16F24]={
  category="lo",
  description="MIAO LETTER NGHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F24,
 },
 [0x16F25]={
  category="lo",
  description="MIAO LETTER ARCHAIC NGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F25,
 },
 [0x16F26]={
  category="lo",
  description="MIAO LETTER HA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F26,
 },
 [0x16F27]={
  category="lo",
  description="MIAO LETTER XA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F27,
 },
 [0x16F28]={
  category="lo",
  description="MIAO LETTER GHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F28,
 },
 [0x16F29]={
  category="lo",
  description="MIAO LETTER GHHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F29,
 },
 [0x16F2A]={
  category="lo",
  description="MIAO LETTER TSSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F2A,
 },
 [0x16F2B]={
  category="lo",
  description="MIAO LETTER DZZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F2B,
 },
 [0x16F2C]={
  category="lo",
  description="MIAO LETTER NYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F2C,
 },
 [0x16F2D]={
  category="lo",
  description="MIAO LETTER NYHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F2D,
 },
 [0x16F2E]={
  category="lo",
  description="MIAO LETTER TSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F2E,
 },
 [0x16F2F]={
  category="lo",
  description="MIAO LETTER DZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F2F,
 },
 [0x16F30]={
  category="lo",
  description="MIAO LETTER YI TSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F30,
 },
 [0x16F31]={
  category="lo",
  description="MIAO LETTER YI DZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F31,
 },
 [0x16F32]={
  category="lo",
  description="MIAO LETTER REFORMED TSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F32,
 },
 [0x16F33]={
  category="lo",
  description="MIAO LETTER SHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F33,
 },
 [0x16F34]={
  category="lo",
  description="MIAO LETTER SSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F34,
 },
 [0x16F35]={
  category="lo",
  description="MIAO LETTER ZHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F35,
 },
 [0x16F36]={
  category="lo",
  description="MIAO LETTER ZSHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F36,
 },
 [0x16F37]={
  category="lo",
  description="MIAO LETTER TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F37,
 },
 [0x16F38]={
  category="lo",
  description="MIAO LETTER DZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F38,
 },
 [0x16F39]={
  category="lo",
  description="MIAO LETTER YI TSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F39,
 },
 [0x16F3A]={
  category="lo",
  description="MIAO LETTER SA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F3A,
 },
 [0x16F3B]={
  category="lo",
  description="MIAO LETTER ZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F3B,
 },
 [0x16F3C]={
  category="lo",
  description="MIAO LETTER ZSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F3C,
 },
 [0x16F3D]={
  category="lo",
  description="MIAO LETTER ZZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F3D,
 },
 [0x16F3E]={
  category="lo",
  description="MIAO LETTER ZZSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F3E,
 },
 [0x16F3F]={
  category="lo",
  description="MIAO LETTER ARCHAIC ZZA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F3F,
 },
 [0x16F40]={
  category="lo",
  description="MIAO LETTER ZZYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F40,
 },
 [0x16F41]={
  category="lo",
  description="MIAO LETTER ZZSYA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F41,
 },
 [0x16F42]={
  category="lo",
  description="MIAO LETTER WA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F42,
 },
 [0x16F43]={
  category="lo",
  description="MIAO LETTER AH",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F43,
 },
 [0x16F44]={
  category="lo",
  description="MIAO LETTER HHA",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F44,
 },
 [0x16F50]={
  category="lo",
  description="MIAO LETTER NASALIZATION",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F50,
 },
 [0x16F51]={
  category="mc",
  description="MIAO SIGN ASPIRATION",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F51,
 },
 [0x16F52]={
  category="mc",
  description="MIAO SIGN REFORMED VOICING",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F52,
 },
 [0x16F53]={
  category="mc",
  description="MIAO SIGN REFORMED ASPIRATION",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F53,
 },
 [0x16F54]={
  category="mc",
  description="MIAO VOWEL SIGN A",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F54,
 },
 [0x16F55]={
  category="mc",
  description="MIAO VOWEL SIGN AA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F55,
 },
 [0x16F56]={
  category="mc",
  description="MIAO VOWEL SIGN AHH",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F56,
 },
 [0x16F57]={
  category="mc",
  description="MIAO VOWEL SIGN AN",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F57,
 },
 [0x16F58]={
  category="mc",
  description="MIAO VOWEL SIGN ANG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F58,
 },
 [0x16F59]={
  category="mc",
  description="MIAO VOWEL SIGN O",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F59,
 },
 [0x16F5A]={
  category="mc",
  description="MIAO VOWEL SIGN OO",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F5A,
 },
 [0x16F5B]={
  category="mc",
  description="MIAO VOWEL SIGN WO",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F5B,
 },
 [0x16F5C]={
  category="mc",
  description="MIAO VOWEL SIGN W",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F5C,
 },
 [0x16F5D]={
  category="mc",
  description="MIAO VOWEL SIGN E",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F5D,
 },
 [0x16F5E]={
  category="mc",
  description="MIAO VOWEL SIGN EN",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F5E,
 },
 [0x16F5F]={
  category="mc",
  description="MIAO VOWEL SIGN ENG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F5F,
 },
 [0x16F60]={
  category="mc",
  description="MIAO VOWEL SIGN OEY",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F60,
 },
 [0x16F61]={
  category="mc",
  description="MIAO VOWEL SIGN I",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F61,
 },
 [0x16F62]={
  category="mc",
  description="MIAO VOWEL SIGN IA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F62,
 },
 [0x16F63]={
  category="mc",
  description="MIAO VOWEL SIGN IAN",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F63,
 },
 [0x16F64]={
  category="mc",
  description="MIAO VOWEL SIGN IANG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F64,
 },
 [0x16F65]={
  category="mc",
  description="MIAO VOWEL SIGN IO",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F65,
 },
 [0x16F66]={
  category="mc",
  description="MIAO VOWEL SIGN IE",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F66,
 },
 [0x16F67]={
  category="mc",
  description="MIAO VOWEL SIGN II",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F67,
 },
 [0x16F68]={
  category="mc",
  description="MIAO VOWEL SIGN IU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F68,
 },
 [0x16F69]={
  category="mc",
  description="MIAO VOWEL SIGN ING",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F69,
 },
 [0x16F6A]={
  category="mc",
  description="MIAO VOWEL SIGN U",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F6A,
 },
 [0x16F6B]={
  category="mc",
  description="MIAO VOWEL SIGN UA",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F6B,
 },
 [0x16F6C]={
  category="mc",
  description="MIAO VOWEL SIGN UAN",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F6C,
 },
 [0x16F6D]={
  category="mc",
  description="MIAO VOWEL SIGN UANG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F6D,
 },
 [0x16F6E]={
  category="mc",
  description="MIAO VOWEL SIGN UU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F6E,
 },
 [0x16F6F]={
  category="mc",
  description="MIAO VOWEL SIGN UEI",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F6F,
 },
 [0x16F70]={
  category="mc",
  description="MIAO VOWEL SIGN UNG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F70,
 },
 [0x16F71]={
  category="mc",
  description="MIAO VOWEL SIGN Y",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F71,
 },
 [0x16F72]={
  category="mc",
  description="MIAO VOWEL SIGN YI",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F72,
 },
 [0x16F73]={
  category="mc",
  description="MIAO VOWEL SIGN AE",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F73,
 },
 [0x16F74]={
  category="mc",
  description="MIAO VOWEL SIGN AEE",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F74,
 },
 [0x16F75]={
  category="mc",
  description="MIAO VOWEL SIGN ERR",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F75,
 },
 [0x16F76]={
  category="mc",
  description="MIAO VOWEL SIGN ROUNDED ERR",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F76,
 },
 [0x16F77]={
  category="mc",
  description="MIAO VOWEL SIGN ER",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F77,
 },
 [0x16F78]={
  category="mc",
  description="MIAO VOWEL SIGN ROUNDED ER",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F78,
 },
 [0x16F79]={
  category="mc",
  description="MIAO VOWEL SIGN AI",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F79,
 },
 [0x16F7A]={
  category="mc",
  description="MIAO VOWEL SIGN EI",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F7A,
 },
 [0x16F7B]={
  category="mc",
  description="MIAO VOWEL SIGN AU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F7B,
 },
 [0x16F7C]={
  category="mc",
  description="MIAO VOWEL SIGN OU",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F7C,
 },
 [0x16F7D]={
  category="mc",
  description="MIAO VOWEL SIGN N",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F7D,
 },
 [0x16F7E]={
  category="mc",
  description="MIAO VOWEL SIGN NG",
  direction="l",
  linebreak="cm",
  unicodeslot=0x16F7E,
 },
 [0x16F8F]={
  category="mn",
  description="MIAO TONE RIGHT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x16F8F,
 },
 [0x16F90]={
  category="mn",
  description="MIAO TONE TOP RIGHT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x16F90,
 },
 [0x16F91]={
  category="mn",
  description="MIAO TONE ABOVE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x16F91,
 },
 [0x16F92]={
  category="mn",
  description="MIAO TONE BELOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x16F92,
 },
 [0x16F93]={
  category="lm",
  description="MIAO LETTER TONE-2",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F93,
 },
 [0x16F94]={
  category="lm",
  description="MIAO LETTER TONE-3",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F94,
 },
 [0x16F95]={
  category="lm",
  description="MIAO LETTER TONE-4",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F95,
 },
 [0x16F96]={
  category="lm",
  description="MIAO LETTER TONE-5",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F96,
 },
 [0x16F97]={
  category="lm",
  description="MIAO LETTER TONE-6",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F97,
 },
 [0x16F98]={
  category="lm",
  description="MIAO LETTER TONE-7",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F98,
 },
 [0x16F99]={
  category="lm",
  description="MIAO LETTER TONE-8",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F99,
 },
 [0x16F9A]={
  category="lm",
  description="MIAO LETTER REFORMED TONE-1",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F9A,
 },
 [0x16F9B]={
  category="lm",
  description="MIAO LETTER REFORMED TONE-2",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F9B,
 },
 [0x16F9C]={
  category="lm",
  description="MIAO LETTER REFORMED TONE-4",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F9C,
 },
 [0x16F9D]={
  category="lm",
  description="MIAO LETTER REFORMED TONE-5",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F9D,
 },
 [0x16F9E]={
  category="lm",
  description="MIAO LETTER REFORMED TONE-6",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F9E,
 },
 [0x16F9F]={
  category="lm",
  description="MIAO LETTER REFORMED TONE-8",
  direction="l",
  linebreak="al",
  unicodeslot=0x16F9F,
 },
 [0x1B000]={
  category="lo",
  cjkwd="w",
  description="KATAKANA LETTER ARCHAIC E",
  direction="l",
  linebreak="id",
  unicodeslot=0x1B000,
 },
 [0x1B001]={
  category="lo",
  cjkwd="w",
  description="HIRAGANA LETTER ARCHAIC YE",
  direction="l",
  linebreak="id",
  unicodeslot=0x1B001,
 },
 [0x1D000]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PSILI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D000,
 },
 [0x1D001]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DASEIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D001,
 },
 [0x1D002]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PERISPOMENI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D002,
 },
 [0x1D003]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OXEIA EKFONITIKON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D003,
 },
 [0x1D004]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OXEIA DIPLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D004,
 },
 [0x1D005]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL VAREIA EKFONITIKON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D005,
 },
 [0x1D006]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL VAREIA DIPLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D006,
 },
 [0x1D007]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KATHISTI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D007,
 },
 [0x1D008]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SYRMATIKI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D008,
 },
 [0x1D009]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PARAKLITIKI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D009,
 },
 [0x1D00A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YPOKRISIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D00A,
 },
 [0x1D00B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YPOKRISIS DIPLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D00B,
 },
 [0x1D00C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KREMASTI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D00C,
 },
 [0x1D00D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APESO EKFONITIKON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D00D,
 },
 [0x1D00E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL EXO EKFONITIKON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D00E,
 },
 [0x1D00F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TELEIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D00F,
 },
 [0x1D010]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D010,
 },
 [0x1D011]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APOSTROFOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D011,
 },
 [0x1D012]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APOSTROFOS DIPLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D012,
 },
 [0x1D013]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SYNEVMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D013,
 },
 [0x1D014]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL THITA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D014,
 },
 [0x1D015]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OLIGON ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D015,
 },
 [0x1D016]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GORGON ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D016,
 },
 [0x1D017]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PSILON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D017,
 },
 [0x1D018]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL CHAMILON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D018,
 },
 [0x1D019]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL VATHY",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D019,
 },
 [0x1D01A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ISON ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D01A,
 },
 [0x1D01B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D01B,
 },
 [0x1D01C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMATA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D01C,
 },
 [0x1D01D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SAXIMATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D01D,
 },
 [0x1D01E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PARICHON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D01E,
 },
 [0x1D01F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL STAVROS APODEXIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D01F,
 },
 [0x1D020]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OXEIAI ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D020,
 },
 [0x1D021]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL VAREIAI ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D021,
 },
 [0x1D022]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APODERMA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D022,
 },
 [0x1D023]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APOTHEMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D023,
 },
 [0x1D024]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KLASMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D024,
 },
 [0x1D025]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL REVMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D025,
 },
 [0x1D026]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PIASMA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D026,
 },
 [0x1D027]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TINAGMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D027,
 },
 [0x1D028]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ANATRICHISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D028,
 },
 [0x1D029]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SEISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D029,
 },
 [0x1D02A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SYNAGMA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D02A,
 },
 [0x1D02B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SYNAGMA META STAVROU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D02B,
 },
 [0x1D02C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OYRANISMA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D02C,
 },
 [0x1D02D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL THEMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D02D,
 },
 [0x1D02E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL LEMOI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D02E,
 },
 [0x1D02F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DYO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D02F,
 },
 [0x1D030]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TRIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D030,
 },
 [0x1D031]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TESSERA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D031,
 },
 [0x1D032]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KRATIMATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D032,
 },
 [0x1D033]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APESO EXO NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D033,
 },
 [0x1D034]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D034,
 },
 [0x1D035]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL IMIFTHORA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D035,
 },
 [0x1D036]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TROMIKON ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D036,
 },
 [0x1D037]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KATAVA TROMIKON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D037,
 },
 [0x1D038]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PELASTON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D038,
 },
 [0x1D039]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PSIFISTON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D039,
 },
 [0x1D03A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KONTEVMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D03A,
 },
 [0x1D03B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL CHOREVMA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D03B,
 },
 [0x1D03C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL RAPISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D03C,
 },
 [0x1D03D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PARAKALESMA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D03D,
 },
 [0x1D03E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PARAKLITIKI ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D03E,
 },
 [0x1D03F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ICHADIN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D03F,
 },
 [0x1D040]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL NANA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D040,
 },
 [0x1D041]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PETASMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D041,
 },
 [0x1D042]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KONTEVMA ALLO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D042,
 },
 [0x1D043]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TROMIKON ALLO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D043,
 },
 [0x1D044]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL STRAGGISMATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D044,
 },
 [0x1D045]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GRONTHISMATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D045,
 },
 [0x1D046]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ISON NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D046,
 },
 [0x1D047]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OLIGON NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D047,
 },
 [0x1D048]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OXEIA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D048,
 },
 [0x1D049]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PETASTI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D049,
 },
 [0x1D04A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KOUFISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D04A,
 },
 [0x1D04B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PETASTOKOUFISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D04B,
 },
 [0x1D04C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KRATIMOKOUFISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D04C,
 },
 [0x1D04D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PELASTON NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D04D,
 },
 [0x1D04E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMATA NEO ANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D04E,
 },
 [0x1D04F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMA NEO ANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D04F,
 },
 [0x1D050]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YPSILI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D050,
 },
 [0x1D051]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APOSTROFOS NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D051,
 },
 [0x1D052]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APOSTROFOI SYNDESMOS NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D052,
 },
 [0x1D053]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YPORROI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D053,
 },
 [0x1D054]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KRATIMOYPORROON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D054,
 },
 [0x1D055]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ELAFRON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D055,
 },
 [0x1D056]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL CHAMILI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D056,
 },
 [0x1D057]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MIKRON ISON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D057,
 },
 [0x1D058]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL VAREIA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D058,
 },
 [0x1D059]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PIASMA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D059,
 },
 [0x1D05A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PSIFISTON NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D05A,
 },
 [0x1D05B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OMALON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D05B,
 },
 [0x1D05C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ANTIKENOMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D05C,
 },
 [0x1D05D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL LYGISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D05D,
 },
 [0x1D05E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PARAKLITIKI NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D05E,
 },
 [0x1D05F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PARAKALESMA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D05F,
 },
 [0x1D060]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ETERON PARAKALESMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D060,
 },
 [0x1D061]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KYLISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D061,
 },
 [0x1D062]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ANTIKENOKYLISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D062,
 },
 [0x1D063]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TROMIKON NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D063,
 },
 [0x1D064]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL EKSTREPTON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D064,
 },
 [0x1D065]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SYNAGMA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D065,
 },
 [0x1D066]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SYRMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D066,
 },
 [0x1D067]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL CHOREVMA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D067,
 },
 [0x1D068]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL EPEGERMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D068,
 },
 [0x1D069]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SEISMA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D069,
 },
 [0x1D06A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL XIRON KLASMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D06A,
 },
 [0x1D06B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TROMIKOPSIFISTON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D06B,
 },
 [0x1D06C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PSIFISTOLYGISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D06C,
 },
 [0x1D06D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TROMIKOLYGISMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D06D,
 },
 [0x1D06E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TROMIKOPARAKALESMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D06E,
 },
 [0x1D06F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PSIFISTOPARAKALESMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D06F,
 },
 [0x1D070]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TROMIKOSYNAGMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D070,
 },
 [0x1D071]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL PSIFISTOSYNAGMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D071,
 },
 [0x1D072]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GORGOSYNTHETON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D072,
 },
 [0x1D073]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARGOSYNTHETON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D073,
 },
 [0x1D074]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ETERON ARGOSYNTHETON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D074,
 },
 [0x1D075]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL OYRANISMA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D075,
 },
 [0x1D076]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL THEMATISMOS ESO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D076,
 },
 [0x1D077]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL THEMATISMOS EXO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D077,
 },
 [0x1D078]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL THEMA APLOUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D078,
 },
 [0x1D079]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL THES KAI APOTHES",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D079,
 },
 [0x1D07A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KATAVASMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D07A,
 },
 [0x1D07B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ENDOFONON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D07B,
 },
 [0x1D07C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YFEN KATO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D07C,
 },
 [0x1D07D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YFEN ANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D07D,
 },
 [0x1D07E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL STAVROS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D07E,
 },
 [0x1D07F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KLASMA ANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D07F,
 },
 [0x1D080]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIPLI ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D080,
 },
 [0x1D081]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KRATIMA ARCHAION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D081,
 },
 [0x1D082]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KRATIMA ALLO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D082,
 },
 [0x1D083]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KRATIMA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D083,
 },
 [0x1D084]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APODERMA NEO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D084,
 },
 [0x1D085]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D085,
 },
 [0x1D086]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIPLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D086,
 },
 [0x1D087]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TRIPLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D087,
 },
 [0x1D088]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TETRAPLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D088,
 },
 [0x1D089]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KORONIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D089,
 },
 [0x1D08A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL LEIMMA ENOS CHRONOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D08A,
 },
 [0x1D08B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL LEIMMA DYO CHRONON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D08B,
 },
 [0x1D08C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL LEIMMA TRION CHRONON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D08C,
 },
 [0x1D08D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL LEIMMA TESSARON CHRONON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D08D,
 },
 [0x1D08E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL LEIMMA IMISEOS CHRONOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D08E,
 },
 [0x1D08F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GORGON NEO ANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D08F,
 },
 [0x1D090]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON ARISTERA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D090,
 },
 [0x1D091]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON DEXIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D091,
 },
 [0x1D092]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIGORGON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D092,
 },
 [0x1D093]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA KATO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D093,
 },
 [0x1D094]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA ANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D094,
 },
 [0x1D095]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON DEXIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D095,
 },
 [0x1D096]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL TRIGORGON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D096,
 },
 [0x1D097]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARGON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D097,
 },
 [0x1D098]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL IMIDIARGON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D098,
 },
 [0x1D099]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIARGON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D099,
 },
 [0x1D09A]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL AGOGI POLI ARGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D09A,
 },
 [0x1D09B]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL AGOGI ARGOTERI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D09B,
 },
 [0x1D09C]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL AGOGI ARGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D09C,
 },
 [0x1D09D]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL AGOGI METRIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D09D,
 },
 [0x1D09E]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL AGOGI MESI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D09E,
 },
 [0x1D09F]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL AGOGI GORGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D09F,
 },
 [0x1D0A0]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL AGOGI GORGOTERI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A0,
 },
 [0x1D0A1]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL AGOGI POLI GORGI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A1,
 },
 [0x1D0A2]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A2,
 },
 [0x1D0A3]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI PROTOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A3,
 },
 [0x1D0A4]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA DEYTEROS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A4,
 },
 [0x1D0A5]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI DEYTEROS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A5,
 },
 [0x1D0A6]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA TRITOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A6,
 },
 [0x1D0A7]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA TRIFONIAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A7,
 },
 [0x1D0A8]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A8,
 },
 [0x1D0A9]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS LEGETOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0A9,
 },
 [0x1D0AA]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA LEGETOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0AA,
 },
 [0x1D0AB]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0AB,
 },
 [0x1D0AC]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ISAKIA TELOUS ICHIMATOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0AC,
 },
 [0x1D0AD]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL APOSTROFOI TELOUS ICHIMATOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0AD,
 },
 [0x1D0AE]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FANEROSIS TETRAFONIAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0AE,
 },
 [0x1D0AF]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FANEROSIS MONOFONIAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0AF,
 },
 [0x1D0B0]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FANEROSIS DIFONIAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B0,
 },
 [0x1D0B1]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA VARYS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B1,
 },
 [0x1D0B2]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOVARYS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B2,
 },
 [0x1D0B3]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS TETARTOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B3,
 },
 [0x1D0B4]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GORTHMIKON N APLOUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B4,
 },
 [0x1D0B5]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GORTHMIKON N DIPLOUN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B5,
 },
 [0x1D0B6]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ENARXIS KAI FTHORA VOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B6,
 },
 [0x1D0B7]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL IMIFONON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B7,
 },
 [0x1D0B8]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL IMIFTHORON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B8,
 },
 [0x1D0B9]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION DEYTEROU ICHOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0B9,
 },
 [0x1D0BA]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0BA,
 },
 [0x1D0BB]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NANA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0BB,
 },
 [0x1D0BC]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA NAOS ICHOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0BC,
 },
 [0x1D0BD]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0BD,
 },
 [0x1D0BE]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON DIATONON DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0BE,
 },
 [0x1D0BF]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI KE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0BF,
 },
 [0x1D0C0]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI ZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C0,
 },
 [0x1D0C1]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI KATO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C1,
 },
 [0x1D0C2]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI ANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C2,
 },
 [0x1D0C3]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA DIFONIAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C3,
 },
 [0x1D0C4]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA MONOFONIAS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C4,
 },
 [0x1D0C5]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FHTORA SKLIRON CHROMA VASIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C5,
 },
 [0x1D0C6]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON CHROMA SYNAFI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C6,
 },
 [0x1D0C7]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA NENANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C7,
 },
 [0x1D0C8]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL CHROA ZYGOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C8,
 },
 [0x1D0C9]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL CHROA KLITON",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0C9,
 },
 [0x1D0CA]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL CHROA SPATHI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0CA,
 },
 [0x1D0CB]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA I YFESIS TETARTIMORION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0CB,
 },
 [0x1D0CC]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL FTHORA ENARMONIOS ANTIFONIA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0CC,
 },
 [0x1D0CD]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YFESIS TRITIMORION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0CD,
 },
 [0x1D0CE]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIESIS TRITIMORION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0CE,
 },
 [0x1D0CF]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIESIS TETARTIMORION",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0CF,
 },
 [0x1D0D0]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIESIS APLI DYO DODEKATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D0,
 },
 [0x1D0D1]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIESIS MONOGRAMMOS TESSERA DODEKATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D1,
 },
 [0x1D0D2]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIESIS DIGRAMMOS EX DODEKATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D2,
 },
 [0x1D0D3]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIESIS TRIGRAMMOS OKTO DODEKATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D3,
 },
 [0x1D0D4]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YFESIS APLI DYO DODEKATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D4,
 },
 [0x1D0D5]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YFESIS MONOGRAMMOS TESSERA DODEKATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D5,
 },
 [0x1D0D6]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YFESIS DIGRAMMOS EX DODEKATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D6,
 },
 [0x1D0D7]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL YFESIS TRIGRAMMOS OKTO DODEKATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D7,
 },
 [0x1D0D8]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GENIKI DIESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D8,
 },
 [0x1D0D9]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GENIKI YFESIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0D9,
 },
 [0x1D0DA]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MIKRI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0DA,
 },
 [0x1D0DB]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MEGALI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0DB,
 },
 [0x1D0DC]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIASTOLI DIPLI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0DC,
 },
 [0x1D0DD]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIASTOLI THESEOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0DD,
 },
 [0x1D0DE]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0DE,
 },
 [0x1D0DF]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS DISIMOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0DF,
 },
 [0x1D0E0]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TRISIMOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E0,
 },
 [0x1D0E1]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TETRASIMOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E1,
 },
 [0x1D0E2]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E2,
 },
 [0x1D0E3]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS DISIMOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E3,
 },
 [0x1D0E4]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TRISIMOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E4,
 },
 [0x1D0E5]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TETRASIMOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E5,
 },
 [0x1D0E6]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIGRAMMA GG",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E6,
 },
 [0x1D0E7]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL DIFTOGGOS OU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E7,
 },
 [0x1D0E8]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL STIGMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E8,
 },
 [0x1D0E9]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARKTIKO PA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0E9,
 },
 [0x1D0EA]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARKTIKO VOU",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0EA,
 },
 [0x1D0EB]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARKTIKO GA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0EB,
 },
 [0x1D0EC]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARKTIKO DI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0EC,
 },
 [0x1D0ED]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARKTIKO KE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0ED,
 },
 [0x1D0EE]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARKTIKO ZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0EE,
 },
 [0x1D0EF]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL ARKTIKO NI",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0EF,
 },
 [0x1D0F0]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMATA NEO MESO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0F0,
 },
 [0x1D0F1]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMA NEO MESO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0F1,
 },
 [0x1D0F2]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMATA NEO KATO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0F2,
 },
 [0x1D0F3]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KENTIMA NEO KATO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0F3,
 },
 [0x1D0F4]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL KLASMA KATO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0F4,
 },
 [0x1D0F5]={
  category="so",
  description="BYZANTINE MUSICAL SYMBOL GORGON NEO KATO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D0F5,
 },
 [0x1D100]={
  category="so",
  description="MUSICAL SYMBOL SINGLE BARLINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D100,
 },
 [0x1D101]={
  category="so",
  description="MUSICAL SYMBOL DOUBLE BARLINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D101,
 },
 [0x1D102]={
  category="so",
  description="MUSICAL SYMBOL FINAL BARLINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D102,
 },
 [0x1D103]={
  category="so",
  description="MUSICAL SYMBOL REVERSE FINAL BARLINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D103,
 },
 [0x1D104]={
  category="so",
  description="MUSICAL SYMBOL DASHED BARLINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D104,
 },
 [0x1D105]={
  category="so",
  description="MUSICAL SYMBOL SHORT BARLINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D105,
 },
 [0x1D106]={
  category="so",
  description="MUSICAL SYMBOL LEFT REPEAT SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D106,
 },
 [0x1D107]={
  category="so",
  description="MUSICAL SYMBOL RIGHT REPEAT SIGN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D107,
 },
 [0x1D108]={
  category="so",
  description="MUSICAL SYMBOL REPEAT DOTS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D108,
 },
 [0x1D109]={
  category="so",
  description="MUSICAL SYMBOL DAL SEGNO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D109,
 },
 [0x1D10A]={
  category="so",
  description="MUSICAL SYMBOL DA CAPO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D10A,
 },
 [0x1D10B]={
  category="so",
  description="MUSICAL SYMBOL SEGNO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D10B,
 },
 [0x1D10C]={
  category="so",
  description="MUSICAL SYMBOL CODA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D10C,
 },
 [0x1D10D]={
  category="so",
  description="MUSICAL SYMBOL REPEATED FIGURE-0x0001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D10D,
 },
 [0x1D10E]={
  category="so",
  description="MUSICAL SYMBOL REPEATED FIGURE-0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D10E,
 },
 [0x1D10F]={
  category="so",
  description="MUSICAL SYMBOL REPEATED FIGURE-0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D10F,
 },
 [0x1D110]={
  category="so",
  description="MUSICAL SYMBOL FERMATA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D110,
 },
 [0x1D111]={
  category="so",
  description="MUSICAL SYMBOL FERMATA BELOW",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D111,
 },
 [0x1D112]={
  category="so",
  description="MUSICAL SYMBOL BREATH MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D112,
 },
 [0x1D113]={
  category="so",
  description="MUSICAL SYMBOL CAESURA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D113,
 },
 [0x1D114]={
  category="so",
  description="MUSICAL SYMBOL BRACE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D114,
 },
 [0x1D115]={
  category="so",
  description="MUSICAL SYMBOL BRACKET",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D115,
 },
 [0x1D116]={
  category="so",
  description="MUSICAL SYMBOL ONE-LINE STAFF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D116,
 },
 [0x1D117]={
  category="so",
  description="MUSICAL SYMBOL TWO-LINE STAFF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D117,
 },
 [0x1D118]={
  category="so",
  description="MUSICAL SYMBOL THREE-LINE STAFF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D118,
 },
 [0x1D119]={
  category="so",
  description="MUSICAL SYMBOL FOUR-LINE STAFF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D119,
 },
 [0x1D11A]={
  category="so",
  description="MUSICAL SYMBOL FIVE-LINE STAFF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D11A,
 },
 [0x1D11B]={
  category="so",
  description="MUSICAL SYMBOL SIX-LINE STAFF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D11B,
 },
 [0x1D11C]={
  category="so",
  description="MUSICAL SYMBOL SIX-STRING FRETBOARD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D11C,
 },
 [0x1D11D]={
  category="so",
  description="MUSICAL SYMBOL FOUR-STRING FRETBOARD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D11D,
 },
 [0x1D11E]={
  category="so",
  description="MUSICAL SYMBOL G CLEF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D11E,
 },
 [0x1D11F]={
  category="so",
  description="MUSICAL SYMBOL G CLEF OTTAVA ALTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D11F,
 },
 [0x1D120]={
  category="so",
  description="MUSICAL SYMBOL G CLEF OTTAVA BASSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D120,
 },
 [0x1D121]={
  category="so",
  description="MUSICAL SYMBOL C CLEF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D121,
 },
 [0x1D122]={
  category="so",
  description="MUSICAL SYMBOL F CLEF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D122,
 },
 [0x1D123]={
  category="so",
  description="MUSICAL SYMBOL F CLEF OTTAVA ALTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D123,
 },
 [0x1D124]={
  category="so",
  description="MUSICAL SYMBOL F CLEF OTTAVA BASSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D124,
 },
 [0x1D125]={
  category="so",
  description="MUSICAL SYMBOL DRUM CLEF-0x0001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D125,
 },
 [0x1D126]={
  category="so",
  description="MUSICAL SYMBOL DRUM CLEF-0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D126,
 },
 [0x1D129]={
  category="so",
  description="MUSICAL SYMBOL MULTIPLE MEASURE REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D129,
 },
 [0x1D12A]={
  category="so",
  description="MUSICAL SYMBOL DOUBLE SHARP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D12A,
 },
 [0x1D12B]={
  category="so",
  description="MUSICAL SYMBOL DOUBLE FLAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D12B,
 },
 [0x1D12C]={
  category="so",
  description="MUSICAL SYMBOL FLAT UP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D12C,
 },
 [0x1D12D]={
  category="so",
  description="MUSICAL SYMBOL FLAT DOWN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D12D,
 },
 [0x1D12E]={
  category="so",
  description="MUSICAL SYMBOL NATURAL UP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D12E,
 },
 [0x1D12F]={
  category="so",
  description="MUSICAL SYMBOL NATURAL DOWN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D12F,
 },
 [0x1D130]={
  category="so",
  description="MUSICAL SYMBOL SHARP UP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D130,
 },
 [0x1D131]={
  category="so",
  description="MUSICAL SYMBOL SHARP DOWN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D131,
 },
 [0x1D132]={
  category="so",
  description="MUSICAL SYMBOL QUARTER TONE SHARP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D132,
 },
 [0x1D133]={
  category="so",
  description="MUSICAL SYMBOL QUARTER TONE FLAT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D133,
 },
 [0x1D134]={
  category="so",
  description="MUSICAL SYMBOL COMMON TIME",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D134,
 },
 [0x1D135]={
  category="so",
  description="MUSICAL SYMBOL CUT TIME",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D135,
 },
 [0x1D136]={
  category="so",
  description="MUSICAL SYMBOL OTTAVA ALTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D136,
 },
 [0x1D137]={
  category="so",
  description="MUSICAL SYMBOL OTTAVA BASSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D137,
 },
 [0x1D138]={
  category="so",
  description="MUSICAL SYMBOL QUINDICESIMA ALTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D138,
 },
 [0x1D139]={
  category="so",
  description="MUSICAL SYMBOL QUINDICESIMA BASSA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D139,
 },
 [0x1D13A]={
  category="so",
  description="MUSICAL SYMBOL MULTI REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D13A,
 },
 [0x1D13B]={
  category="so",
  description="MUSICAL SYMBOL WHOLE REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D13B,
 },
 [0x1D13C]={
  category="so",
  description="MUSICAL SYMBOL HALF REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D13C,
 },
 [0x1D13D]={
  category="so",
  description="MUSICAL SYMBOL QUARTER REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D13D,
 },
 [0x1D13E]={
  category="so",
  description="MUSICAL SYMBOL EIGHTH REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D13E,
 },
 [0x1D13F]={
  category="so",
  description="MUSICAL SYMBOL SIXTEENTH REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D13F,
 },
 [0x1D140]={
  category="so",
  description="MUSICAL SYMBOL THIRTY-SECOND REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D140,
 },
 [0x1D141]={
  category="so",
  description="MUSICAL SYMBOL SIXTY-FOURTH REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D141,
 },
 [0x1D142]={
  category="so",
  description="MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D142,
 },
 [0x1D143]={
  category="so",
  description="MUSICAL SYMBOL X NOTEHEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D143,
 },
 [0x1D144]={
  category="so",
  description="MUSICAL SYMBOL PLUS NOTEHEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D144,
 },
 [0x1D145]={
  category="so",
  description="MUSICAL SYMBOL CIRCLE X NOTEHEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D145,
 },
 [0x1D146]={
  category="so",
  description="MUSICAL SYMBOL SQUARE NOTEHEAD WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D146,
 },
 [0x1D147]={
  category="so",
  description="MUSICAL SYMBOL SQUARE NOTEHEAD BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D147,
 },
 [0x1D148]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD UP WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D148,
 },
 [0x1D149]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD UP BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D149,
 },
 [0x1D14A]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D14A,
 },
 [0x1D14B]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D14B,
 },
 [0x1D14C]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D14C,
 },
 [0x1D14D]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D14D,
 },
 [0x1D14E]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D14E,
 },
 [0x1D14F]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D14F,
 },
 [0x1D150]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D150,
 },
 [0x1D151]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D151,
 },
 [0x1D152]={
  category="so",
  description="MUSICAL SYMBOL MOON NOTEHEAD WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D152,
 },
 [0x1D153]={
  category="so",
  description="MUSICAL SYMBOL MOON NOTEHEAD BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D153,
 },
 [0x1D154]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D154,
 },
 [0x1D155]={
  category="so",
  description="MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D155,
 },
 [0x1D156]={
  category="so",
  description="MUSICAL SYMBOL PARENTHESIS NOTEHEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D156,
 },
 [0x1D157]={
  category="so",
  description="MUSICAL SYMBOL VOID NOTEHEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D157,
 },
 [0x1D158]={
  category="so",
  description="MUSICAL SYMBOL NOTEHEAD BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D158,
 },
 [0x1D159]={
  category="so",
  description="MUSICAL SYMBOL NULL NOTEHEAD",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D159,
 },
 [0x1D15A]={
  category="so",
  description="MUSICAL SYMBOL CLUSTER NOTEHEAD WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D15A,
 },
 [0x1D15B]={
  category="so",
  description="MUSICAL SYMBOL CLUSTER NOTEHEAD BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D15B,
 },
 [0x1D15C]={
  category="so",
  description="MUSICAL SYMBOL BREVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D15C,
 },
 [0x1D15D]={
  category="so",
  description="MUSICAL SYMBOL WHOLE NOTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D15D,
 },
 [0x1D15E]={
  category="so",
  description="MUSICAL SYMBOL HALF NOTE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D157, 0x1D165 },
  unicodeslot=0x1D15E,
 },
 [0x1D15F]={
  category="so",
  description="MUSICAL SYMBOL QUARTER NOTE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D158, 0x1D165 },
  unicodeslot=0x1D15F,
 },
 [0x1D160]={
  category="so",
  description="MUSICAL SYMBOL EIGHTH NOTE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D15F, 0x1D16E },
  unicodeslot=0x1D160,
 },
 [0x1D161]={
  category="so",
  description="MUSICAL SYMBOL SIXTEENTH NOTE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D15F, 0x1D16F },
  unicodeslot=0x1D161,
 },
 [0x1D162]={
  category="so",
  description="MUSICAL SYMBOL THIRTY-SECOND NOTE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D15F, 0x1D170 },
  unicodeslot=0x1D162,
 },
 [0x1D163]={
  category="so",
  description="MUSICAL SYMBOL SIXTY-FOURTH NOTE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D15F, 0x1D171 },
  unicodeslot=0x1D163,
 },
 [0x1D164]={
  category="so",
  description="MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH NOTE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D15F, 0x1D172 },
  unicodeslot=0x1D164,
 },
 [0x1D165]={
  category="mc",
  description="MUSICAL SYMBOL COMBINING STEM",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1D165,
 },
 [0x1D166]={
  category="mc",
  description="MUSICAL SYMBOL COMBINING SPRECHGESANG STEM",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1D166,
 },
 [0x1D167]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING TREMOLO-0x0001",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D167,
 },
 [0x1D168]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING TREMOLO-0x0002",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D168,
 },
 [0x1D169]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING TREMOLO-0x0003",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D169,
 },
 [0x1D16A]={
  category="so",
  description="MUSICAL SYMBOL FINGERED TREMOLO-0x0001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D16A,
 },
 [0x1D16B]={
  category="so",
  description="MUSICAL SYMBOL FINGERED TREMOLO-0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D16B,
 },
 [0x1D16C]={
  category="so",
  description="MUSICAL SYMBOL FINGERED TREMOLO-0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D16C,
 },
 [0x1D16D]={
  category="mc",
  description="MUSICAL SYMBOL COMBINING AUGMENTATION DOT",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1D16D,
 },
 [0x1D16E]={
  category="mc",
  description="MUSICAL SYMBOL COMBINING FLAG-0x0001",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1D16E,
 },
 [0x1D16F]={
  category="mc",
  description="MUSICAL SYMBOL COMBINING FLAG-0x0002",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1D16F,
 },
 [0x1D170]={
  category="mc",
  description="MUSICAL SYMBOL COMBINING FLAG-0x0003",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1D170,
 },
 [0x1D171]={
  category="mc",
  description="MUSICAL SYMBOL COMBINING FLAG-0x0004",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1D171,
 },
 [0x1D172]={
  category="mc",
  description="MUSICAL SYMBOL COMBINING FLAG-0x0005",
  direction="l",
  linebreak="cm",
  unicodeslot=0x1D172,
 },
 [0x1D173]={
  category="cf",
  description="MUSICAL SYMBOL BEGIN BEAM",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x1D173,
 },
 [0x1D174]={
  category="cf",
  description="MUSICAL SYMBOL END BEAM",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x1D174,
 },
 [0x1D175]={
  category="cf",
  description="MUSICAL SYMBOL BEGIN TIE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x1D175,
 },
 [0x1D176]={
  category="cf",
  description="MUSICAL SYMBOL END TIE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x1D176,
 },
 [0x1D177]={
  category="cf",
  description="MUSICAL SYMBOL BEGIN SLUR",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x1D177,
 },
 [0x1D178]={
  category="cf",
  description="MUSICAL SYMBOL END SLUR",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x1D178,
 },
 [0x1D179]={
  category="cf",
  description="MUSICAL SYMBOL BEGIN PHRASE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x1D179,
 },
 [0x1D17A]={
  category="cf",
  description="MUSICAL SYMBOL END PHRASE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0x1D17A,
 },
 [0x1D17B]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING ACCENT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D17B,
 },
 [0x1D17C]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING STACCATO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D17C,
 },
 [0x1D17D]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING TENUTO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D17D,
 },
 [0x1D17E]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING STACCATISSIMO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D17E,
 },
 [0x1D17F]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING MARCATO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D17F,
 },
 [0x1D180]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING MARCATO-STACCATO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D180,
 },
 [0x1D181]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING ACCENT-STACCATO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D181,
 },
 [0x1D182]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING LOURE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D182,
 },
 [0x1D183]={
  category="so",
  description="MUSICAL SYMBOL ARPEGGIATO UP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D183,
 },
 [0x1D184]={
  category="so",
  description="MUSICAL SYMBOL ARPEGGIATO DOWN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D184,
 },
 [0x1D185]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING DOIT",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D185,
 },
 [0x1D186]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING RIP",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D186,
 },
 [0x1D187]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING FLIP",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D187,
 },
 [0x1D188]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING SMEAR",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D188,
 },
 [0x1D189]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING BEND",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D189,
 },
 [0x1D18A]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING DOUBLE TONGUE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D18A,
 },
 [0x1D18B]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING TRIPLE TONGUE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D18B,
 },
 [0x1D18C]={
  category="so",
  description="MUSICAL SYMBOL RINFORZANDO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D18C,
 },
 [0x1D18D]={
  category="so",
  description="MUSICAL SYMBOL SUBITO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D18D,
 },
 [0x1D18E]={
  category="so",
  description="MUSICAL SYMBOL Z",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D18E,
 },
 [0x1D18F]={
  category="so",
  description="MUSICAL SYMBOL PIANO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D18F,
 },
 [0x1D190]={
  category="so",
  description="MUSICAL SYMBOL MEZZO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D190,
 },
 [0x1D191]={
  category="so",
  description="MUSICAL SYMBOL FORTE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D191,
 },
 [0x1D192]={
  category="so",
  description="MUSICAL SYMBOL CRESCENDO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D192,
 },
 [0x1D193]={
  category="so",
  description="MUSICAL SYMBOL DECRESCENDO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D193,
 },
 [0x1D194]={
  category="so",
  description="MUSICAL SYMBOL GRACE NOTE SLASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D194,
 },
 [0x1D195]={
  category="so",
  description="MUSICAL SYMBOL GRACE NOTE NO SLASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D195,
 },
 [0x1D196]={
  category="so",
  description="MUSICAL SYMBOL TR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D196,
 },
 [0x1D197]={
  category="so",
  description="MUSICAL SYMBOL TURN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D197,
 },
 [0x1D198]={
  category="so",
  description="MUSICAL SYMBOL INVERTED TURN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D198,
 },
 [0x1D199]={
  category="so",
  description="MUSICAL SYMBOL TURN SLASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D199,
 },
 [0x1D19A]={
  category="so",
  description="MUSICAL SYMBOL TURN UP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D19A,
 },
 [0x1D19B]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D19B,
 },
 [0x1D19C]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D19C,
 },
 [0x1D19D]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D19D,
 },
 [0x1D19E]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0004",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D19E,
 },
 [0x1D19F]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0005",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D19F,
 },
 [0x1D1A0]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0006",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A0,
 },
 [0x1D1A1]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0007",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A1,
 },
 [0x1D1A2]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0008",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A2,
 },
 [0x1D1A3]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x0009",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A3,
 },
 [0x1D1A4]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x000A",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A4,
 },
 [0x1D1A5]={
  category="so",
  description="MUSICAL SYMBOL ORNAMENT STROKE-0x000B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A5,
 },
 [0x1D1A6]={
  category="so",
  description="MUSICAL SYMBOL HAUPTSTIMME",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A6,
 },
 [0x1D1A7]={
  category="so",
  description="MUSICAL SYMBOL NEBENSTIMME",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A7,
 },
 [0x1D1A8]={
  category="so",
  description="MUSICAL SYMBOL END OF STIMME",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A8,
 },
 [0x1D1A9]={
  category="so",
  description="MUSICAL SYMBOL DEGREE SLASH",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1A9,
 },
 [0x1D1AA]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING DOWN BOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D1AA,
 },
 [0x1D1AB]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING UP BOW",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D1AB,
 },
 [0x1D1AC]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING HARMONIC",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D1AC,
 },
 [0x1D1AD]={
  category="mn",
  description="MUSICAL SYMBOL COMBINING SNAP PIZZICATO",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D1AD,
 },
 [0x1D1AE]={
  category="so",
  description="MUSICAL SYMBOL PEDAL MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1AE,
 },
 [0x1D1AF]={
  category="so",
  description="MUSICAL SYMBOL PEDAL UP MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1AF,
 },
 [0x1D1B0]={
  category="so",
  description="MUSICAL SYMBOL HALF PEDAL MARK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B0,
 },
 [0x1D1B1]={
  category="so",
  description="MUSICAL SYMBOL GLISSANDO UP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B1,
 },
 [0x1D1B2]={
  category="so",
  description="MUSICAL SYMBOL GLISSANDO DOWN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B2,
 },
 [0x1D1B3]={
  category="so",
  description="MUSICAL SYMBOL WITH FINGERNAILS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B3,
 },
 [0x1D1B4]={
  category="so",
  description="MUSICAL SYMBOL DAMP",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B4,
 },
 [0x1D1B5]={
  category="so",
  description="MUSICAL SYMBOL DAMP ALL",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B5,
 },
 [0x1D1B6]={
  category="so",
  description="MUSICAL SYMBOL MAXIMA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B6,
 },
 [0x1D1B7]={
  category="so",
  description="MUSICAL SYMBOL LONGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B7,
 },
 [0x1D1B8]={
  category="so",
  description="MUSICAL SYMBOL BREVIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B8,
 },
 [0x1D1B9]={
  category="so",
  description="MUSICAL SYMBOL SEMIBREVIS WHITE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1B9,
 },
 [0x1D1BA]={
  category="so",
  description="MUSICAL SYMBOL SEMIBREVIS BLACK",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1BA,
 },
 [0x1D1BB]={
  category="so",
  description="MUSICAL SYMBOL MINIMA",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D1B9, 0x1D165 },
  unicodeslot=0x1D1BB,
 },
 [0x1D1BC]={
  category="so",
  description="MUSICAL SYMBOL MINIMA BLACK",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D1BA, 0x1D165 },
  unicodeslot=0x1D1BC,
 },
 [0x1D1BD]={
  category="so",
  description="MUSICAL SYMBOL SEMIMINIMA WHITE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D1BB, 0x1D16E },
  unicodeslot=0x1D1BD,
 },
 [0x1D1BE]={
  category="so",
  description="MUSICAL SYMBOL SEMIMINIMA BLACK",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D1BC, 0x1D16E },
  unicodeslot=0x1D1BE,
 },
 [0x1D1BF]={
  category="so",
  description="MUSICAL SYMBOL FUSA WHITE",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D1BB, 0x1D16F },
  unicodeslot=0x1D1BF,
 },
 [0x1D1C0]={
  category="so",
  description="MUSICAL SYMBOL FUSA BLACK",
  direction="l",
  linebreak="al",
  specials={ "char", 0x1D1BC, 0x1D16F },
  unicodeslot=0x1D1C0,
 },
 [0x1D1C1]={
  category="so",
  description="MUSICAL SYMBOL LONGA PERFECTA REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C1,
 },
 [0x1D1C2]={
  category="so",
  description="MUSICAL SYMBOL LONGA IMPERFECTA REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C2,
 },
 [0x1D1C3]={
  category="so",
  description="MUSICAL SYMBOL BREVIS REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C3,
 },
 [0x1D1C4]={
  category="so",
  description="MUSICAL SYMBOL SEMIBREVIS REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C4,
 },
 [0x1D1C5]={
  category="so",
  description="MUSICAL SYMBOL MINIMA REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C5,
 },
 [0x1D1C6]={
  category="so",
  description="MUSICAL SYMBOL SEMIMINIMA REST",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C6,
 },
 [0x1D1C7]={
  category="so",
  description="MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C7,
 },
 [0x1D1C8]={
  category="so",
  description="MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE IMPERFECTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C8,
 },
 [0x1D1C9]={
  category="so",
  description="MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA DIMINUTION-0x0001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1C9,
 },
 [0x1D1CA]={
  category="so",
  description="MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE PERFECTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1CA,
 },
 [0x1D1CB]={
  category="so",
  description="MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1CB,
 },
 [0x1D1CC]={
  category="so",
  description="MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-0x0001",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1CC,
 },
 [0x1D1CD]={
  category="so",
  description="MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-0x0002",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1CD,
 },
 [0x1D1CE]={
  category="so",
  description="MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-0x0003",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1CE,
 },
 [0x1D1CF]={
  category="so",
  description="MUSICAL SYMBOL CROIX",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1CF,
 },
 [0x1D1D0]={
  category="so",
  description="MUSICAL SYMBOL GREGORIAN C CLEF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D0,
 },
 [0x1D1D1]={
  category="so",
  description="MUSICAL SYMBOL GREGORIAN F CLEF",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D1,
 },
 [0x1D1D2]={
  category="so",
  description="MUSICAL SYMBOL SQUARE B",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D2,
 },
 [0x1D1D3]={
  category="so",
  description="MUSICAL SYMBOL VIRGA",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D3,
 },
 [0x1D1D4]={
  category="so",
  description="MUSICAL SYMBOL PODATUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D4,
 },
 [0x1D1D5]={
  category="so",
  description="MUSICAL SYMBOL CLIVIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D5,
 },
 [0x1D1D6]={
  category="so",
  description="MUSICAL SYMBOL SCANDICUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D6,
 },
 [0x1D1D7]={
  category="so",
  description="MUSICAL SYMBOL CLIMACUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D7,
 },
 [0x1D1D8]={
  category="so",
  description="MUSICAL SYMBOL TORCULUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D8,
 },
 [0x1D1D9]={
  category="so",
  description="MUSICAL SYMBOL PORRECTUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1D9,
 },
 [0x1D1DA]={
  category="so",
  description="MUSICAL SYMBOL PORRECTUS FLEXUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1DA,
 },
 [0x1D1DB]={
  category="so",
  description="MUSICAL SYMBOL SCANDICUS FLEXUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1DB,
 },
 [0x1D1DC]={
  category="so",
  description="MUSICAL SYMBOL TORCULUS RESUPINUS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1DC,
 },
 [0x1D1DD]={
  category="so",
  description="MUSICAL SYMBOL PES SUBPUNCTIS",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D1DD,
 },
 [0x1D200]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0001",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D200,
 },
 [0x1D201]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0002",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D201,
 },
 [0x1D202]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0003",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D202,
 },
 [0x1D203]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0004",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D203,
 },
 [0x1D204]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0005",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D204,
 },
 [0x1D205]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0006",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D205,
 },
 [0x1D206]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0007",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D206,
 },
 [0x1D207]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0008",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D207,
 },
 [0x1D208]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0009",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D208,
 },
 [0x1D209]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x000A",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D209,
 },
 [0x1D20A]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x000B",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D20A,
 },
 [0x1D20B]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x000C",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D20B,
 },
 [0x1D20C]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x000D",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D20C,
 },
 [0x1D20D]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x000E",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D20D,
 },
 [0x1D20E]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x000F",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D20E,
 },
 [0x1D20F]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0010",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D20F,
 },
 [0x1D210]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0011",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D210,
 },
 [0x1D211]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0012",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D211,
 },
 [0x1D212]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0013",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D212,
 },
 [0x1D213]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0014",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D213,
 },
 [0x1D214]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0015",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D214,
 },
 [0x1D215]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0016",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D215,
 },
 [0x1D216]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0017",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D216,
 },
 [0x1D217]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0018",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D217,
 },
 [0x1D218]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0032",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D218,
 },
 [0x1D219]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0033",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D219,
 },
 [0x1D21A]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0034",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D21A,
 },
 [0x1D21B]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0035",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D21B,
 },
 [0x1D21C]={
  category="so",
  description="GREEK VOCAL NOTATION SYMBOL-0x0036",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D21C,
 },
 [0x1D21D]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0001",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D21D,
 },
 [0x1D21E]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0002",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D21E,
 },
 [0x1D21F]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0004",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D21F,
 },
 [0x1D220]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0005",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D220,
 },
 [0x1D221]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0007",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D221,
 },
 [0x1D222]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0008",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D222,
 },
 [0x1D223]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x000B",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D223,
 },
 [0x1D224]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x000C",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D224,
 },
 [0x1D225]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x000D",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D225,
 },
 [0x1D226]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x000E",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D226,
 },
 [0x1D227]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0011",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D227,
 },
 [0x1D228]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0012",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D228,
 },
 [0x1D229]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0013",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D229,
 },
 [0x1D22A]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0017",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D22A,
 },
 [0x1D22B]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0018",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D22B,
 },
 [0x1D22C]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0019",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D22C,
 },
 [0x1D22D]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x001A",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D22D,
 },
 [0x1D22E]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x001B",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D22E,
 },
 [0x1D22F]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x001D",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D22F,
 },
 [0x1D230]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x001E",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D230,
 },
 [0x1D231]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0020",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D231,
 },
 [0x1D232]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0024",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D232,
 },
 [0x1D233]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0025",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D233,
 },
 [0x1D234]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0026",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D234,
 },
 [0x1D235]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0027",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D235,
 },
 [0x1D236]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0028",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D236,
 },
 [0x1D237]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x002A",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D237,
 },
 [0x1D238]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x002B",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D238,
 },
 [0x1D239]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x002D",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D239,
 },
 [0x1D23A]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x002F",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D23A,
 },
 [0x1D23B]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0030",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D23B,
 },
 [0x1D23C]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0031",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D23C,
 },
 [0x1D23D]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0032",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D23D,
 },
 [0x1D23E]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0033",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D23E,
 },
 [0x1D23F]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0034",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D23F,
 },
 [0x1D240]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0035",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D240,
 },
 [0x1D241]={
  category="so",
  description="GREEK INSTRUMENTAL NOTATION SYMBOL-0x0036",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D241,
 },
 [0x1D242]={
  category="mn",
  description="COMBINING GREEK MUSICAL TRISEME",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D242,
 },
 [0x1D243]={
  category="mn",
  description="COMBINING GREEK MUSICAL TETRASEME",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D243,
 },
 [0x1D244]={
  category="mn",
  description="COMBINING GREEK MUSICAL PENTASEME",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0x1D244,
 },
 [0x1D245]={
  category="so",
  description="GREEK MUSICAL LEIMMA",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D245,
 },
 [0x1D300]={
  category="so",
  description="MONOGRAM FOR EARTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D300,
 },
 [0x1D301]={
  category="so",
  description="DIGRAM FOR HEAVENLY EARTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D301,
 },
 [0x1D302]={
  category="so",
  description="DIGRAM FOR HUMAN EARTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D302,
 },
 [0x1D303]={
  category="so",
  description="DIGRAM FOR EARTHLY HEAVEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D303,
 },
 [0x1D304]={
  category="so",
  description="DIGRAM FOR EARTHLY HUMAN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D304,
 },
 [0x1D305]={
  category="so",
  description="DIGRAM FOR EARTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D305,
 },
 [0x1D306]={
  category="so",
  description="TETRAGRAM FOR CENTRE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D306,
 },
 [0x1D307]={
  category="so",
  description="TETRAGRAM FOR FULL CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D307,
 },
 [0x1D308]={
  category="so",
  description="TETRAGRAM FOR MIRED",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D308,
 },
 [0x1D309]={
  category="so",
  description="TETRAGRAM FOR BARRIER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D309,
 },
 [0x1D30A]={
  category="so",
  description="TETRAGRAM FOR KEEPING SMALL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D30A,
 },
 [0x1D30B]={
  category="so",
  description="TETRAGRAM FOR CONTRARIETY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D30B,
 },
 [0x1D30C]={
  category="so",
  description="TETRAGRAM FOR ASCENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D30C,
 },
 [0x1D30D]={
  category="so",
  description="TETRAGRAM FOR OPPOSITION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D30D,
 },
 [0x1D30E]={
  category="so",
  description="TETRAGRAM FOR BRANCHING OUT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D30E,
 },
 [0x1D30F]={
  category="so",
  description="TETRAGRAM FOR DEFECTIVENESS OR DISTORTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D30F,
 },
 [0x1D310]={
  category="so",
  description="TETRAGRAM FOR DIVERGENCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D310,
 },
 [0x1D311]={
  category="so",
  description="TETRAGRAM FOR YOUTHFULNESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D311,
 },
 [0x1D312]={
  category="so",
  description="TETRAGRAM FOR INCREASE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D312,
 },
 [0x1D313]={
  category="so",
  description="TETRAGRAM FOR PENETRATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D313,
 },
 [0x1D314]={
  category="so",
  description="TETRAGRAM FOR REACH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D314,
 },
 [0x1D315]={
  category="so",
  description="TETRAGRAM FOR CONTACT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D315,
 },
 [0x1D316]={
  category="so",
  description="TETRAGRAM FOR HOLDING BACK",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D316,
 },
 [0x1D317]={
  category="so",
  description="TETRAGRAM FOR WAITING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D317,
 },
 [0x1D318]={
  category="so",
  description="TETRAGRAM FOR FOLLOWING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D318,
 },
 [0x1D319]={
  category="so",
  description="TETRAGRAM FOR ADVANCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D319,
 },
 [0x1D31A]={
  category="so",
  description="TETRAGRAM FOR RELEASE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D31A,
 },
 [0x1D31B]={
  category="so",
  description="TETRAGRAM FOR RESISTANCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D31B,
 },
 [0x1D31C]={
  category="so",
  description="TETRAGRAM FOR EASE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D31C,
 },
 [0x1D31D]={
  category="so",
  description="TETRAGRAM FOR JOY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D31D,
 },
 [0x1D31E]={
  category="so",
  description="TETRAGRAM FOR CONTENTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D31E,
 },
 [0x1D31F]={
  category="so",
  description="TETRAGRAM FOR ENDEAVOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D31F,
 },
 [0x1D320]={
  category="so",
  description="TETRAGRAM FOR DUTIES",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D320,
 },
 [0x1D321]={
  category="so",
  description="TETRAGRAM FOR CHANGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D321,
 },
 [0x1D322]={
  category="so",
  description="TETRAGRAM FOR DECISIVENESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D322,
 },
 [0x1D323]={
  category="so",
  description="TETRAGRAM FOR BOLD RESOLUTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D323,
 },
 [0x1D324]={
  category="so",
  description="TETRAGRAM FOR PACKING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D324,
 },
 [0x1D325]={
  category="so",
  description="TETRAGRAM FOR LEGION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D325,
 },
 [0x1D326]={
  category="so",
  description="TETRAGRAM FOR CLOSENESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D326,
 },
 [0x1D327]={
  category="so",
  description="TETRAGRAM FOR KINSHIP",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D327,
 },
 [0x1D328]={
  category="so",
  description="TETRAGRAM FOR GATHERING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D328,
 },
 [0x1D329]={
  category="so",
  description="TETRAGRAM FOR STRENGTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D329,
 },
 [0x1D32A]={
  category="so",
  description="TETRAGRAM FOR PURITY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D32A,
 },
 [0x1D32B]={
  category="so",
  description="TETRAGRAM FOR FULLNESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D32B,
 },
 [0x1D32C]={
  category="so",
  description="TETRAGRAM FOR RESIDENCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D32C,
 },
 [0x1D32D]={
  category="so",
  description="TETRAGRAM FOR LAW OR MODEL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D32D,
 },
 [0x1D32E]={
  category="so",
  description="TETRAGRAM FOR RESPONSE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D32E,
 },
 [0x1D32F]={
  category="so",
  description="TETRAGRAM FOR GOING TO MEET",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D32F,
 },
 [0x1D330]={
  category="so",
  description="TETRAGRAM FOR ENCOUNTERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D330,
 },
 [0x1D331]={
  category="so",
  description="TETRAGRAM FOR STOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D331,
 },
 [0x1D332]={
  category="so",
  description="TETRAGRAM FOR GREATNESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D332,
 },
 [0x1D333]={
  category="so",
  description="TETRAGRAM FOR ENLARGEMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D333,
 },
 [0x1D334]={
  category="so",
  description="TETRAGRAM FOR PATTERN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D334,
 },
 [0x1D335]={
  category="so",
  description="TETRAGRAM FOR RITUAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D335,
 },
 [0x1D336]={
  category="so",
  description="TETRAGRAM FOR FLIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D336,
 },
 [0x1D337]={
  category="so",
  description="TETRAGRAM FOR VASTNESS OR WASTING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D337,
 },
 [0x1D338]={
  category="so",
  description="TETRAGRAM FOR CONSTANCY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D338,
 },
 [0x1D339]={
  category="so",
  description="TETRAGRAM FOR MEASURE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D339,
 },
 [0x1D33A]={
  category="so",
  description="TETRAGRAM FOR ETERNITY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D33A,
 },
 [0x1D33B]={
  category="so",
  description="TETRAGRAM FOR UNITY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D33B,
 },
 [0x1D33C]={
  category="so",
  description="TETRAGRAM FOR DIMINISHMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D33C,
 },
 [0x1D33D]={
  category="so",
  description="TETRAGRAM FOR CLOSED MOUTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D33D,
 },
 [0x1D33E]={
  category="so",
  description="TETRAGRAM FOR GUARDEDNESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D33E,
 },
 [0x1D33F]={
  category="so",
  description="TETRAGRAM FOR GATHERING IN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D33F,
 },
 [0x1D340]={
  category="so",
  description="TETRAGRAM FOR MASSING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D340,
 },
 [0x1D341]={
  category="so",
  description="TETRAGRAM FOR ACCUMULATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D341,
 },
 [0x1D342]={
  category="so",
  description="TETRAGRAM FOR EMBELLISHMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D342,
 },
 [0x1D343]={
  category="so",
  description="TETRAGRAM FOR DOUBT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D343,
 },
 [0x1D344]={
  category="so",
  description="TETRAGRAM FOR WATCH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D344,
 },
 [0x1D345]={
  category="so",
  description="TETRAGRAM FOR SINKING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D345,
 },
 [0x1D346]={
  category="so",
  description="TETRAGRAM FOR INNER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D346,
 },
 [0x1D347]={
  category="so",
  description="TETRAGRAM FOR DEPARTURE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D347,
 },
 [0x1D348]={
  category="so",
  description="TETRAGRAM FOR DARKENING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D348,
 },
 [0x1D349]={
  category="so",
  description="TETRAGRAM FOR DIMMING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D349,
 },
 [0x1D34A]={
  category="so",
  description="TETRAGRAM FOR EXHAUSTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D34A,
 },
 [0x1D34B]={
  category="so",
  description="TETRAGRAM FOR SEVERANCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D34B,
 },
 [0x1D34C]={
  category="so",
  description="TETRAGRAM FOR STOPPAGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D34C,
 },
 [0x1D34D]={
  category="so",
  description="TETRAGRAM FOR HARDNESS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D34D,
 },
 [0x1D34E]={
  category="so",
  description="TETRAGRAM FOR COMPLETION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D34E,
 },
 [0x1D34F]={
  category="so",
  description="TETRAGRAM FOR CLOSURE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D34F,
 },
 [0x1D350]={
  category="so",
  description="TETRAGRAM FOR FAILURE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D350,
 },
 [0x1D351]={
  category="so",
  description="TETRAGRAM FOR AGGRAVATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D351,
 },
 [0x1D352]={
  category="so",
  description="TETRAGRAM FOR COMPLIANCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D352,
 },
 [0x1D353]={
  category="so",
  description="TETRAGRAM FOR ON THE VERGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D353,
 },
 [0x1D354]={
  category="so",
  description="TETRAGRAM FOR DIFFICULTIES",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D354,
 },
 [0x1D355]={
  category="so",
  description="TETRAGRAM FOR LABOURING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D355,
 },
 [0x1D356]={
  category="so",
  description="TETRAGRAM FOR FOSTERING",
  direction="on",
  linebreak="al",
  unicodeslot=0x1D356,
 },
 [0x1D360]={
  category="no",
  description="COUNTING ROD UNIT DIGIT ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D360,
 },
 [0x1D361]={
  category="no",
  description="COUNTING ROD UNIT DIGIT TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D361,
 },
 [0x1D362]={
  category="no",
  description="COUNTING ROD UNIT DIGIT THREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D362,
 },
 [0x1D363]={
  category="no",
  description="COUNTING ROD UNIT DIGIT FOUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D363,
 },
 [0x1D364]={
  category="no",
  description="COUNTING ROD UNIT DIGIT FIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D364,
 },
 [0x1D365]={
  category="no",
  description="COUNTING ROD UNIT DIGIT SIX",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D365,
 },
 [0x1D366]={
  category="no",
  description="COUNTING ROD UNIT DIGIT SEVEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D366,
 },
 [0x1D367]={
  category="no",
  description="COUNTING ROD UNIT DIGIT EIGHT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D367,
 },
 [0x1D368]={
  category="no",
  description="COUNTING ROD UNIT DIGIT NINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D368,
 },
 [0x1D369]={
  category="no",
  description="COUNTING ROD TENS DIGIT ONE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D369,
 },
 [0x1D36A]={
  category="no",
  description="COUNTING ROD TENS DIGIT TWO",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D36A,
 },
 [0x1D36B]={
  category="no",
  description="COUNTING ROD TENS DIGIT THREE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D36B,
 },
 [0x1D36C]={
  category="no",
  description="COUNTING ROD TENS DIGIT FOUR",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D36C,
 },
 [0x1D36D]={
  category="no",
  description="COUNTING ROD TENS DIGIT FIVE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D36D,
 },
 [0x1D36E]={
  category="no",
  description="COUNTING ROD TENS DIGIT SIX",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D36E,
 },
 [0x1D36F]={
  category="no",
  description="COUNTING ROD TENS DIGIT SEVEN",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D36F,
 },
 [0x1D370]={
  category="no",
  description="COUNTING ROD TENS DIGIT EIGHT",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D370,
 },
 [0x1D371]={
  category="no",
  description="COUNTING ROD TENS DIGIT NINE",
  direction="l",
  linebreak="al",
  unicodeslot=0x1D371,
 },
 [0x1D400]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D400,
  visual="bf",
 },
 [0x1D401]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D401,
  visual="bf",
 },
 [0x1D402]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D402,
  visual="bf",
 },
 [0x1D403]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D403,
  visual="bf",
 },
 [0x1D404]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D404,
  visual="bf",
 },
 [0x1D405]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D405,
  visual="bf",
 },
 [0x1D406]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D406,
  visual="bf",
 },
 [0x1D407]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D407,
  visual="bf",
 },
 [0x1D408]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D408,
  visual="bf",
 },
 [0x1D409]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D409,
  visual="bf",
 },
 [0x1D40A]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D40A,
  visual="bf",
 },
 [0x1D40B]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D40B,
  visual="bf",
 },
 [0x1D40C]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D40C,
  visual="bf",
 },
 [0x1D40D]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D40D,
  visual="bf",
 },
 [0x1D40E]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D40E,
  visual="bf",
 },
 [0x1D40F]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D40F,
  visual="bf",
 },
 [0x1D410]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D410,
  visual="bf",
 },
 [0x1D411]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D411,
  visual="bf",
 },
 [0x1D412]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D412,
  visual="bf",
 },
 [0x1D413]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D413,
  visual="bf",
 },
 [0x1D414]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D414,
  visual="bf",
 },
 [0x1D415]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D415,
  visual="bf",
 },
 [0x1D416]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D416,
  visual="bf",
 },
 [0x1D417]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D417,
  visual="bf",
 },
 [0x1D418]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D418,
  visual="bf",
 },
 [0x1D419]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D419,
  visual="bf",
 },
 [0x1D41A]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D41A,
  visual="bf",
 },
 [0x1D41B]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D41B,
  visual="bf",
 },
 [0x1D41C]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D41C,
  visual="bf",
 },
 [0x1D41D]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D41D,
  visual="bf",
 },
 [0x1D41E]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D41E,
  visual="bf",
 },
 [0x1D41F]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D41F,
  visual="bf",
 },
 [0x1D420]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D420,
  visual="bf",
 },
 [0x1D421]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D421,
  visual="bf",
 },
 [0x1D422]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D422,
  visual="bf",
 },
 [0x1D423]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D423,
  visual="bf",
 },
 [0x1D424]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D424,
  visual="bf",
 },
 [0x1D425]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D425,
  visual="bf",
 },
 [0x1D426]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D426,
  visual="bf",
 },
 [0x1D427]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D427,
  visual="bf",
 },
 [0x1D428]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D428,
  visual="bf",
 },
 [0x1D429]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D429,
  visual="bf",
 },
 [0x1D42A]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D42A,
  visual="bf",
 },
 [0x1D42B]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D42B,
  visual="bf",
 },
 [0x1D42C]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D42C,
  visual="bf",
 },
 [0x1D42D]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D42D,
  visual="bf",
 },
 [0x1D42E]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D42E,
  visual="bf",
 },
 [0x1D42F]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D42F,
  visual="bf",
 },
 [0x1D430]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D430,
  visual="bf",
 },
 [0x1D431]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D431,
  visual="bf",
 },
 [0x1D432]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D432,
  visual="bf",
 },
 [0x1D433]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D433,
  visual="bf",
 },
 [0x1D434]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D434,
  visual="it",
 },
 [0x1D435]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D435,
  visual="it",
 },
 [0x1D436]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D436,
  visual="it",
 },
 [0x1D437]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D437,
  visual="it",
 },
 [0x1D438]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D438,
  visual="it",
 },
 [0x1D439]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D439,
  visual="it",
 },
 [0x1D43A]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D43A,
  visual="it",
 },
 [0x1D43B]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D43B,
  visual="it",
 },
 [0x1D43C]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D43C,
  visual="it",
 },
 [0x1D43D]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D43D,
  visual="it",
 },
 [0x1D43E]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D43E,
  visual="it",
 },
 [0x1D43F]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D43F,
  visual="it",
 },
 [0x1D440]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D440,
  visual="it",
 },
 [0x1D441]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D441,
  visual="it",
 },
 [0x1D442]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D442,
  visual="it",
 },
 [0x1D443]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D443,
  visual="it",
 },
 [0x1D444]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D444,
  visual="it",
 },
 [0x1D445]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D445,
  visual="it",
 },
 [0x1D446]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D446,
  visual="it",
 },
 [0x1D447]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D447,
  visual="it",
 },
 [0x1D448]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D448,
  visual="it",
 },
 [0x1D449]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D449,
  visual="it",
 },
 [0x1D44A]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D44A,
  visual="it",
 },
 [0x1D44B]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D44B,
  visual="it",
 },
 [0x1D44C]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D44C,
  visual="it",
 },
 [0x1D44D]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D44D,
  visual="it",
 },
 [0x1D44E]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D44E,
  visual="it",
 },
 [0x1D44F]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D44F,
  visual="it",
 },
 [0x1D450]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D450,
  visual="it",
 },
 [0x1D451]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D451,
  visual="it",
 },
 [0x1D452]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D452,
  visual="it",
 },
 [0x1D453]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D453,
  visual="it",
 },
 [0x1D454]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D454,
  visual="it",
 },
 [0x1D456]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D456,
  visual="it",
 },
 [0x1D457]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D457,
  visual="it",
 },
 [0x1D458]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D458,
  visual="it",
 },
 [0x1D459]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D459,
  visual="it",
 },
 [0x1D45A]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D45A,
  visual="it",
 },
 [0x1D45B]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D45B,
  visual="it",
 },
 [0x1D45C]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D45C,
  visual="it",
 },
 [0x1D45D]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D45D,
  visual="it",
 },
 [0x1D45E]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D45E,
  visual="it",
 },
 [0x1D45F]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D45F,
  visual="it",
 },
 [0x1D460]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D460,
  visual="it",
 },
 [0x1D461]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D461,
  visual="it",
 },
 [0x1D462]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D462,
  visual="it",
 },
 [0x1D463]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D463,
  visual="it",
 },
 [0x1D464]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D464,
  visual="it",
 },
 [0x1D465]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D465,
  visual="it",
 },
 [0x1D466]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D466,
  visual="it",
 },
 [0x1D467]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D467,
  visual="it",
 },
 [0x1D468]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D468,
  visual="bi",
 },
 [0x1D469]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D469,
  visual="bi",
 },
 [0x1D46A]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D46A,
  visual="bi",
 },
 [0x1D46B]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D46B,
  visual="bi",
 },
 [0x1D46C]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D46C,
  visual="bi",
 },
 [0x1D46D]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D46D,
  visual="bi",
 },
 [0x1D46E]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D46E,
  visual="bi",
 },
 [0x1D46F]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D46F,
  visual="bi",
 },
 [0x1D470]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D470,
  visual="bi",
 },
 [0x1D471]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D471,
  visual="bi",
 },
 [0x1D472]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D472,
  visual="bi",
 },
 [0x1D473]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D473,
  visual="bi",
 },
 [0x1D474]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D474,
  visual="bi",
 },
 [0x1D475]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D475,
  visual="bi",
 },
 [0x1D476]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D476,
  visual="bi",
 },
 [0x1D477]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D477,
  visual="bi",
 },
 [0x1D478]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D478,
  visual="bi",
 },
 [0x1D479]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D479,
  visual="bi",
 },
 [0x1D47A]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D47A,
  visual="bi",
 },
 [0x1D47B]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D47B,
  visual="bi",
 },
 [0x1D47C]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D47C,
  visual="bi",
 },
 [0x1D47D]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D47D,
  visual="bi",
 },
 [0x1D47E]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D47E,
  visual="bi",
 },
 [0x1D47F]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D47F,
  visual="bi",
 },
 [0x1D480]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D480,
  visual="bi",
 },
 [0x1D481]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D481,
  visual="bi",
 },
 [0x1D482]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D482,
  visual="bi",
 },
 [0x1D483]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D483,
  visual="bi",
 },
 [0x1D484]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D484,
  visual="bi",
 },
 [0x1D485]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D485,
  visual="bi",
 },
 [0x1D486]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D486,
  visual="bi",
 },
 [0x1D487]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D487,
  visual="bi",
 },
 [0x1D488]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D488,
  visual="bi",
 },
 [0x1D489]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D489,
  visual="bi",
 },
 [0x1D48A]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D48A,
  visual="bi",
 },
 [0x1D48B]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D48B,
  visual="bi",
 },
 [0x1D48C]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D48C,
  visual="bi",
 },
 [0x1D48D]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D48D,
  visual="bi",
 },
 [0x1D48E]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D48E,
  visual="bi",
 },
 [0x1D48F]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D48F,
  visual="bi",
 },
 [0x1D490]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D490,
  visual="bi",
 },
 [0x1D491]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D491,
  visual="bi",
 },
 [0x1D492]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D492,
  visual="bi",
 },
 [0x1D493]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D493,
  visual="bi",
 },
 [0x1D494]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D494,
  visual="bi",
 },
 [0x1D495]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D495,
  visual="bi",
 },
 [0x1D496]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D496,
  visual="bi",
 },
 [0x1D497]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D497,
  visual="bi",
 },
 [0x1D498]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D498,
  visual="bi",
 },
 [0x1D499]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D499,
  visual="bi",
 },
 [0x1D49A]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D49A,
  visual="bi",
 },
 [0x1D49B]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D49B,
  visual="bi",
 },
 [0x1D49C]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D49C,
 },
 [0x1D49E]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D49E,
 },
 [0x1D49F]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D49F,
 },
 [0x1D4A2]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D4A2,
 },
 [0x1D4A5]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D4A5,
 },
 [0x1D4A6]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D4A6,
 },
 [0x1D4A9]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D4A9,
 },
 [0x1D4AA]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D4AA,
 },
 [0x1D4AB]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D4AB,
 },
 [0x1D4AC]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D4AC,
 },
 [0x1D4AE]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D4AE,
 },
 [0x1D4AF]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D4AF,
 },
 [0x1D4B0]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D4B0,
 },
 [0x1D4B1]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D4B1,
 },
 [0x1D4B2]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D4B2,
 },
 [0x1D4B3]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D4B3,
 },
 [0x1D4B4]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D4B4,
 },
 [0x1D4B5]={
  category="lu",
  description="MATHEMATICAL SCRIPT CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D4B5,
 },
 [0x1D4B6]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D4B6,
 },
 [0x1D4B7]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D4B7,
 },
 [0x1D4B8]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D4B8,
 },
 [0x1D4B9]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D4B9,
 },
 [0x1D4BB]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D4BB,
 },
 [0x1D4BD]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D4BD,
 },
 [0x1D4BE]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D4BE,
 },
 [0x1D4BF]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D4BF,
 },
 [0x1D4C0]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D4C0,
 },
 [0x1D4C1]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D4C1,
 },
 [0x1D4C2]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D4C2,
 },
 [0x1D4C3]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D4C3,
 },
 [0x1D4C5]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D4C5,
 },
 [0x1D4C6]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D4C6,
 },
 [0x1D4C7]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D4C7,
 },
 [0x1D4C8]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D4C8,
 },
 [0x1D4C9]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D4C9,
 },
 [0x1D4CA]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D4CA,
 },
 [0x1D4CB]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D4CB,
 },
 [0x1D4CC]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D4CC,
 },
 [0x1D4CD]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D4CD,
 },
 [0x1D4CE]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D4CE,
 },
 [0x1D4CF]={
  category="ll",
  description="MATHEMATICAL SCRIPT SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D4CF,
 },
 [0x1D4D0]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D4D0,
  visual="bf",
 },
 [0x1D4D1]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D4D1,
  visual="bf",
 },
 [0x1D4D2]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D4D2,
  visual="bf",
 },
 [0x1D4D3]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D4D3,
  visual="bf",
 },
 [0x1D4D4]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D4D4,
  visual="bf",
 },
 [0x1D4D5]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D4D5,
  visual="bf",
 },
 [0x1D4D6]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D4D6,
  visual="bf",
 },
 [0x1D4D7]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D4D7,
  visual="bf",
 },
 [0x1D4D8]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D4D8,
  visual="bf",
 },
 [0x1D4D9]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D4D9,
  visual="bf",
 },
 [0x1D4DA]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D4DA,
  visual="bf",
 },
 [0x1D4DB]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D4DB,
  visual="bf",
 },
 [0x1D4DC]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D4DC,
  visual="bf",
 },
 [0x1D4DD]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D4DD,
  visual="bf",
 },
 [0x1D4DE]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D4DE,
  visual="bf",
 },
 [0x1D4DF]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D4DF,
  visual="bf",
 },
 [0x1D4E0]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D4E0,
  visual="bf",
 },
 [0x1D4E1]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D4E1,
  visual="bf",
 },
 [0x1D4E2]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D4E2,
  visual="bf",
 },
 [0x1D4E3]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D4E3,
  visual="bf",
 },
 [0x1D4E4]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D4E4,
  visual="bf",
 },
 [0x1D4E5]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D4E5,
  visual="bf",
 },
 [0x1D4E6]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D4E6,
  visual="bf",
 },
 [0x1D4E7]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D4E7,
  visual="bf",
 },
 [0x1D4E8]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D4E8,
  visual="bf",
 },
 [0x1D4E9]={
  category="lu",
  description="MATHEMATICAL BOLD SCRIPT CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D4E9,
  visual="bf",
 },
 [0x1D4EA]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D4EA,
  visual="bf",
 },
 [0x1D4EB]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D4EB,
  visual="bf",
 },
 [0x1D4EC]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D4EC,
  visual="bf",
 },
 [0x1D4ED]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D4ED,
  visual="bf",
 },
 [0x1D4EE]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D4EE,
  visual="bf",
 },
 [0x1D4EF]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D4EF,
  visual="bf",
 },
 [0x1D4F0]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D4F0,
  visual="bf",
 },
 [0x1D4F1]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D4F1,
  visual="bf",
 },
 [0x1D4F2]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D4F2,
  visual="bf",
 },
 [0x1D4F3]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D4F3,
  visual="bf",
 },
 [0x1D4F4]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D4F4,
  visual="bf",
 },
 [0x1D4F5]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D4F5,
  visual="bf",
 },
 [0x1D4F6]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D4F6,
  visual="bf",
 },
 [0x1D4F7]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D4F7,
  visual="bf",
 },
 [0x1D4F8]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D4F8,
  visual="bf",
 },
 [0x1D4F9]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D4F9,
  visual="bf",
 },
 [0x1D4FA]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D4FA,
  visual="bf",
 },
 [0x1D4FB]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D4FB,
  visual="bf",
 },
 [0x1D4FC]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D4FC,
  visual="bf",
 },
 [0x1D4FD]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D4FD,
  visual="bf",
 },
 [0x1D4FE]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D4FE,
  visual="bf",
 },
 [0x1D4FF]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D4FF,
  visual="bf",
 },
 [0x1D500]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D500,
  visual="bf",
 },
 [0x1D501]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D501,
  visual="bf",
 },
 [0x1D502]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D502,
  visual="bf",
 },
 [0x1D503]={
  category="ll",
  description="MATHEMATICAL BOLD SCRIPT SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D503,
  visual="bf",
 },
 [0x1D504]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D504,
 },
 [0x1D505]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D505,
 },
 [0x1D507]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D507,
 },
 [0x1D508]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D508,
 },
 [0x1D509]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D509,
 },
 [0x1D50A]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D50A,
 },
 [0x1D50D]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D50D,
 },
 [0x1D50E]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D50E,
 },
 [0x1D50F]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D50F,
 },
 [0x1D510]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D510,
 },
 [0x1D511]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D511,
 },
 [0x1D512]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D512,
 },
 [0x1D513]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D513,
 },
 [0x1D514]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D514,
 },
 [0x1D516]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D516,
 },
 [0x1D517]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D517,
 },
 [0x1D518]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D518,
 },
 [0x1D519]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D519,
 },
 [0x1D51A]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D51A,
 },
 [0x1D51B]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D51B,
 },
 [0x1D51C]={
  category="lu",
  description="MATHEMATICAL FRAKTUR CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D51C,
 },
 [0x1D51E]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D51E,
 },
 [0x1D51F]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D51F,
 },
 [0x1D520]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D520,
 },
 [0x1D521]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D521,
 },
 [0x1D522]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D522,
 },
 [0x1D523]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D523,
 },
 [0x1D524]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D524,
 },
 [0x1D525]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D525,
 },
 [0x1D526]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D526,
 },
 [0x1D527]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D527,
 },
 [0x1D528]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D528,
 },
 [0x1D529]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D529,
 },
 [0x1D52A]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D52A,
 },
 [0x1D52B]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D52B,
 },
 [0x1D52C]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D52C,
 },
 [0x1D52D]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D52D,
 },
 [0x1D52E]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D52E,
 },
 [0x1D52F]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D52F,
 },
 [0x1D530]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D530,
 },
 [0x1D531]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D531,
 },
 [0x1D532]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D532,
 },
 [0x1D533]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D533,
 },
 [0x1D534]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D534,
 },
 [0x1D535]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D535,
 },
 [0x1D536]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D536,
 },
 [0x1D537]={
  category="ll",
  description="MATHEMATICAL FRAKTUR SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D537,
 },
 [0x1D538]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D538,
 },
 [0x1D539]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D539,
 },
 [0x1D53B]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D53B,
 },
 [0x1D53C]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D53C,
 },
 [0x1D53D]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D53D,
 },
 [0x1D53E]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D53E,
 },
 [0x1D540]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D540,
 },
 [0x1D541]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D541,
 },
 [0x1D542]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D542,
 },
 [0x1D543]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D543,
 },
 [0x1D544]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D544,
 },
 [0x1D546]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D546,
 },
 [0x1D54A]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D54A,
 },
 [0x1D54B]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D54B,
 },
 [0x1D54C]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D54C,
 },
 [0x1D54D]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D54D,
 },
 [0x1D54E]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D54E,
 },
 [0x1D54F]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D54F,
 },
 [0x1D550]={
  category="lu",
  description="MATHEMATICAL DOUBLE-STRUCK CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D550,
 },
 [0x1D552]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D552,
 },
 [0x1D553]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D553,
 },
 [0x1D554]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D554,
 },
 [0x1D555]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D555,
 },
 [0x1D556]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D556,
 },
 [0x1D557]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D557,
 },
 [0x1D558]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D558,
 },
 [0x1D559]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D559,
 },
 [0x1D55A]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D55A,
 },
 [0x1D55B]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D55B,
 },
 [0x1D55C]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D55C,
 },
 [0x1D55D]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D55D,
 },
 [0x1D55E]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D55E,
 },
 [0x1D55F]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D55F,
 },
 [0x1D560]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D560,
 },
 [0x1D561]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D561,
 },
 [0x1D562]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D562,
 },
 [0x1D563]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D563,
 },
 [0x1D564]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D564,
 },
 [0x1D565]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D565,
 },
 [0x1D566]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D566,
 },
 [0x1D567]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D567,
 },
 [0x1D568]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D568,
 },
 [0x1D569]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D569,
 },
 [0x1D56A]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D56A,
 },
 [0x1D56B]={
  category="ll",
  description="MATHEMATICAL DOUBLE-STRUCK SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D56B,
 },
 [0x1D56C]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D56C,
  visual="bf",
 },
 [0x1D56D]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D56D,
  visual="bf",
 },
 [0x1D56E]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D56E,
  visual="bf",
 },
 [0x1D56F]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D56F,
  visual="bf",
 },
 [0x1D570]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D570,
  visual="bf",
 },
 [0x1D571]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D571,
  visual="bf",
 },
 [0x1D572]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D572,
  visual="bf",
 },
 [0x1D573]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D573,
  visual="bf",
 },
 [0x1D574]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D574,
  visual="bf",
 },
 [0x1D575]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D575,
  visual="bf",
 },
 [0x1D576]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D576,
  visual="bf",
 },
 [0x1D577]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D577,
  visual="bf",
 },
 [0x1D578]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D578,
  visual="bf",
 },
 [0x1D579]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D579,
  visual="bf",
 },
 [0x1D57A]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D57A,
  visual="bf",
 },
 [0x1D57B]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D57B,
  visual="bf",
 },
 [0x1D57C]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D57C,
  visual="bf",
 },
 [0x1D57D]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D57D,
  visual="bf",
 },
 [0x1D57E]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D57E,
  visual="bf",
 },
 [0x1D57F]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D57F,
  visual="bf",
 },
 [0x1D580]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D580,
  visual="bf",
 },
 [0x1D581]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D581,
  visual="bf",
 },
 [0x1D582]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D582,
  visual="bf",
 },
 [0x1D583]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D583,
  visual="bf",
 },
 [0x1D584]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D584,
  visual="bf",
 },
 [0x1D585]={
  category="lu",
  description="MATHEMATICAL BOLD FRAKTUR CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D585,
  visual="bf",
 },
 [0x1D586]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D586,
  visual="bf",
 },
 [0x1D587]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D587,
  visual="bf",
 },
 [0x1D588]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D588,
  visual="bf",
 },
 [0x1D589]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D589,
  visual="bf",
 },
 [0x1D58A]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D58A,
  visual="bf",
 },
 [0x1D58B]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D58B,
  visual="bf",
 },
 [0x1D58C]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D58C,
  visual="bf",
 },
 [0x1D58D]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D58D,
  visual="bf",
 },
 [0x1D58E]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D58E,
  visual="bf",
 },
 [0x1D58F]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D58F,
  visual="bf",
 },
 [0x1D590]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D590,
  visual="bf",
 },
 [0x1D591]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D591,
  visual="bf",
 },
 [0x1D592]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D592,
  visual="bf",
 },
 [0x1D593]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D593,
  visual="bf",
 },
 [0x1D594]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D594,
  visual="bf",
 },
 [0x1D595]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D595,
  visual="bf",
 },
 [0x1D596]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D596,
  visual="bf",
 },
 [0x1D597]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D597,
  visual="bf",
 },
 [0x1D598]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D598,
  visual="bf",
 },
 [0x1D599]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D599,
  visual="bf",
 },
 [0x1D59A]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D59A,
  visual="bf",
 },
 [0x1D59B]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D59B,
  visual="bf",
 },
 [0x1D59C]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D59C,
  visual="bf",
 },
 [0x1D59D]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D59D,
  visual="bf",
 },
 [0x1D59E]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D59E,
  visual="bf",
 },
 [0x1D59F]={
  category="ll",
  description="MATHEMATICAL BOLD FRAKTUR SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D59F,
  visual="bf",
 },
 [0x1D5A0]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D5A0,
 },
 [0x1D5A1]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D5A1,
 },
 [0x1D5A2]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D5A2,
 },
 [0x1D5A3]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D5A3,
 },
 [0x1D5A4]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D5A4,
 },
 [0x1D5A5]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D5A5,
 },
 [0x1D5A6]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D5A6,
 },
 [0x1D5A7]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D5A7,
 },
 [0x1D5A8]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D5A8,
 },
 [0x1D5A9]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D5A9,
 },
 [0x1D5AA]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D5AA,
 },
 [0x1D5AB]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D5AB,
 },
 [0x1D5AC]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D5AC,
 },
 [0x1D5AD]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D5AD,
 },
 [0x1D5AE]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D5AE,
 },
 [0x1D5AF]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D5AF,
 },
 [0x1D5B0]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D5B0,
 },
 [0x1D5B1]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D5B1,
 },
 [0x1D5B2]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D5B2,
 },
 [0x1D5B3]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D5B3,
 },
 [0x1D5B4]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D5B4,
 },
 [0x1D5B5]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D5B5,
 },
 [0x1D5B6]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D5B6,
 },
 [0x1D5B7]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D5B7,
 },
 [0x1D5B8]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D5B8,
 },
 [0x1D5B9]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D5B9,
 },
 [0x1D5BA]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D5BA,
 },
 [0x1D5BB]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D5BB,
 },
 [0x1D5BC]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D5BC,
 },
 [0x1D5BD]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D5BD,
 },
 [0x1D5BE]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D5BE,
 },
 [0x1D5BF]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D5BF,
 },
 [0x1D5C0]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D5C0,
 },
 [0x1D5C1]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D5C1,
 },
 [0x1D5C2]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D5C2,
 },
 [0x1D5C3]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D5C3,
 },
 [0x1D5C4]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D5C4,
 },
 [0x1D5C5]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D5C5,
 },
 [0x1D5C6]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D5C6,
 },
 [0x1D5C7]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D5C7,
 },
 [0x1D5C8]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D5C8,
 },
 [0x1D5C9]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D5C9,
 },
 [0x1D5CA]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D5CA,
 },
 [0x1D5CB]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D5CB,
 },
 [0x1D5CC]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D5CC,
 },
 [0x1D5CD]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D5CD,
 },
 [0x1D5CE]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D5CE,
 },
 [0x1D5CF]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D5CF,
 },
 [0x1D5D0]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D5D0,
 },
 [0x1D5D1]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D5D1,
 },
 [0x1D5D2]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D5D2,
 },
 [0x1D5D3]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D5D3,
 },
 [0x1D5D4]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D5D4,
  visual="bf",
 },
 [0x1D5D5]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D5D5,
  visual="bf",
 },
 [0x1D5D6]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D5D6,
  visual="bf",
 },
 [0x1D5D7]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D5D7,
  visual="bf",
 },
 [0x1D5D8]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D5D8,
  visual="bf",
 },
 [0x1D5D9]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D5D9,
  visual="bf",
 },
 [0x1D5DA]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D5DA,
  visual="bf",
 },
 [0x1D5DB]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D5DB,
  visual="bf",
 },
 [0x1D5DC]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D5DC,
  visual="bf",
 },
 [0x1D5DD]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D5DD,
  visual="bf",
 },
 [0x1D5DE]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D5DE,
  visual="bf",
 },
 [0x1D5DF]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D5DF,
  visual="bf",
 },
 [0x1D5E0]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D5E0,
  visual="bf",
 },
 [0x1D5E1]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D5E1,
  visual="bf",
 },
 [0x1D5E2]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D5E2,
  visual="bf",
 },
 [0x1D5E3]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D5E3,
  visual="bf",
 },
 [0x1D5E4]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D5E4,
  visual="bf",
 },
 [0x1D5E5]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D5E5,
  visual="bf",
 },
 [0x1D5E6]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D5E6,
  visual="bf",
 },
 [0x1D5E7]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D5E7,
  visual="bf",
 },
 [0x1D5E8]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D5E8,
  visual="bf",
 },
 [0x1D5E9]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D5E9,
  visual="bf",
 },
 [0x1D5EA]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D5EA,
  visual="bf",
 },
 [0x1D5EB]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D5EB,
  visual="bf",
 },
 [0x1D5EC]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D5EC,
  visual="bf",
 },
 [0x1D5ED]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D5ED,
  visual="bf",
 },
 [0x1D5EE]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D5EE,
  visual="bf",
 },
 [0x1D5EF]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D5EF,
  visual="bf",
 },
 [0x1D5F0]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D5F0,
  visual="bf",
 },
 [0x1D5F1]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D5F1,
  visual="bf",
 },
 [0x1D5F2]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D5F2,
  visual="bf",
 },
 [0x1D5F3]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D5F3,
  visual="bf",
 },
 [0x1D5F4]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D5F4,
  visual="bf",
 },
 [0x1D5F5]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D5F5,
  visual="bf",
 },
 [0x1D5F6]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D5F6,
  visual="bf",
 },
 [0x1D5F7]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D5F7,
  visual="bf",
 },
 [0x1D5F8]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D5F8,
  visual="bf",
 },
 [0x1D5F9]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D5F9,
  visual="bf",
 },
 [0x1D5FA]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D5FA,
  visual="bf",
 },
 [0x1D5FB]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D5FB,
  visual="bf",
 },
 [0x1D5FC]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D5FC,
  visual="bf",
 },
 [0x1D5FD]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D5FD,
  visual="bf",
 },
 [0x1D5FE]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D5FE,
  visual="bf",
 },
 [0x1D5FF]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D5FF,
  visual="bf",
 },
 [0x1D600]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D600,
  visual="bf",
 },
 [0x1D601]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D601,
  visual="bf",
 },
 [0x1D602]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D602,
  visual="bf",
 },
 [0x1D603]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D603,
  visual="bf",
 },
 [0x1D604]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D604,
  visual="bf",
 },
 [0x1D605]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D605,
  visual="bf",
 },
 [0x1D606]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D606,
  visual="bf",
 },
 [0x1D607]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D607,
  visual="bf",
 },
 [0x1D608]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D608,
  visual="it",
 },
 [0x1D609]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D609,
  visual="it",
 },
 [0x1D60A]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D60A,
  visual="it",
 },
 [0x1D60B]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D60B,
  visual="it",
 },
 [0x1D60C]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D60C,
  visual="it",
 },
 [0x1D60D]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D60D,
  visual="it",
 },
 [0x1D60E]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D60E,
  visual="it",
 },
 [0x1D60F]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D60F,
  visual="it",
 },
 [0x1D610]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D610,
  visual="it",
 },
 [0x1D611]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D611,
  visual="it",
 },
 [0x1D612]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D612,
  visual="it",
 },
 [0x1D613]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D613,
  visual="it",
 },
 [0x1D614]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D614,
  visual="it",
 },
 [0x1D615]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D615,
  visual="it",
 },
 [0x1D616]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D616,
  visual="it",
 },
 [0x1D617]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D617,
  visual="it",
 },
 [0x1D618]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D618,
  visual="it",
 },
 [0x1D619]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D619,
  visual="it",
 },
 [0x1D61A]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D61A,
  visual="it",
 },
 [0x1D61B]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D61B,
  visual="it",
 },
 [0x1D61C]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D61C,
  visual="it",
 },
 [0x1D61D]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D61D,
  visual="it",
 },
 [0x1D61E]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D61E,
  visual="it",
 },
 [0x1D61F]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D61F,
  visual="it",
 },
 [0x1D620]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D620,
  visual="it",
 },
 [0x1D621]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF ITALIC CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D621,
  visual="it",
 },
 [0x1D622]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D622,
  visual="it",
 },
 [0x1D623]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D623,
  visual="it",
 },
 [0x1D624]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D624,
  visual="it",
 },
 [0x1D625]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D625,
  visual="it",
 },
 [0x1D626]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D626,
  visual="it",
 },
 [0x1D627]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D627,
  visual="it",
 },
 [0x1D628]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D628,
  visual="it",
 },
 [0x1D629]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D629,
  visual="it",
 },
 [0x1D62A]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D62A,
  visual="it",
 },
 [0x1D62B]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D62B,
  visual="it",
 },
 [0x1D62C]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D62C,
  visual="it",
 },
 [0x1D62D]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D62D,
  visual="it",
 },
 [0x1D62E]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D62E,
  visual="it",
 },
 [0x1D62F]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D62F,
  visual="it",
 },
 [0x1D630]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D630,
  visual="it",
 },
 [0x1D631]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D631,
  visual="it",
 },
 [0x1D632]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D632,
  visual="it",
 },
 [0x1D633]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D633,
  visual="it",
 },
 [0x1D634]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D634,
  visual="it",
 },
 [0x1D635]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D635,
  visual="it",
 },
 [0x1D636]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D636,
  visual="it",
 },
 [0x1D637]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D637,
  visual="it",
 },
 [0x1D638]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D638,
  visual="it",
 },
 [0x1D639]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D639,
  visual="it",
 },
 [0x1D63A]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D63A,
  visual="it",
 },
 [0x1D63B]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF ITALIC SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D63B,
  visual="it",
 },
 [0x1D63C]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D63C,
  visual="bi",
 },
 [0x1D63D]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D63D,
  visual="bi",
 },
 [0x1D63E]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D63E,
  visual="bi",
 },
 [0x1D63F]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D63F,
  visual="bi",
 },
 [0x1D640]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D640,
  visual="bi",
 },
 [0x1D641]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D641,
  visual="bi",
 },
 [0x1D642]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D642,
  visual="bi",
 },
 [0x1D643]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D643,
  visual="bi",
 },
 [0x1D644]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D644,
  visual="bi",
 },
 [0x1D645]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D645,
  visual="bi",
 },
 [0x1D646]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D646,
  visual="bi",
 },
 [0x1D647]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D647,
  visual="bi",
 },
 [0x1D648]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D648,
  visual="bi",
 },
 [0x1D649]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D649,
  visual="bi",
 },
 [0x1D64A]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D64A,
  visual="bi",
 },
 [0x1D64B]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D64B,
  visual="bi",
 },
 [0x1D64C]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D64C,
  visual="bi",
 },
 [0x1D64D]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D64D,
  visual="bi",
 },
 [0x1D64E]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D64E,
  visual="bi",
 },
 [0x1D64F]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D64F,
  visual="bi",
 },
 [0x1D650]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D650,
  visual="bi",
 },
 [0x1D651]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D651,
  visual="bi",
 },
 [0x1D652]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D652,
  visual="bi",
 },
 [0x1D653]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D653,
  visual="bi",
 },
 [0x1D654]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D654,
  visual="bi",
 },
 [0x1D655]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D655,
  visual="bi",
 },
 [0x1D656]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D656,
  visual="bi",
 },
 [0x1D657]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D657,
  visual="bi",
 },
 [0x1D658]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D658,
  visual="bi",
 },
 [0x1D659]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D659,
  visual="bi",
 },
 [0x1D65A]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D65A,
  visual="bi",
 },
 [0x1D65B]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D65B,
  visual="bi",
 },
 [0x1D65C]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D65C,
  visual="bi",
 },
 [0x1D65D]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D65D,
  visual="bi",
 },
 [0x1D65E]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D65E,
  visual="bi",
 },
 [0x1D65F]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D65F,
  visual="bi",
 },
 [0x1D660]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D660,
  visual="bi",
 },
 [0x1D661]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D661,
  visual="bi",
 },
 [0x1D662]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D662,
  visual="bi",
 },
 [0x1D663]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D663,
  visual="bi",
 },
 [0x1D664]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D664,
  visual="bi",
 },
 [0x1D665]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D665,
  visual="bi",
 },
 [0x1D666]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D666,
  visual="bi",
 },
 [0x1D667]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D667,
  visual="bi",
 },
 [0x1D668]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D668,
  visual="bi",
 },
 [0x1D669]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D669,
  visual="bi",
 },
 [0x1D66A]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D66A,
  visual="bi",
 },
 [0x1D66B]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D66B,
  visual="bi",
 },
 [0x1D66C]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D66C,
  visual="bi",
 },
 [0x1D66D]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D66D,
  visual="bi",
 },
 [0x1D66E]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D66E,
  visual="bi",
 },
 [0x1D66F]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D66F,
  visual="bi",
 },
 [0x1D670]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0041 },
  unicodeslot=0x1D670,
 },
 [0x1D671]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0042 },
  unicodeslot=0x1D671,
 },
 [0x1D672]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0043 },
  unicodeslot=0x1D672,
 },
 [0x1D673]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0044 },
  unicodeslot=0x1D673,
 },
 [0x1D674]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0045 },
  unicodeslot=0x1D674,
 },
 [0x1D675]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0046 },
  unicodeslot=0x1D675,
 },
 [0x1D676]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0047 },
  unicodeslot=0x1D676,
 },
 [0x1D677]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0048 },
  unicodeslot=0x1D677,
 },
 [0x1D678]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0049 },
  unicodeslot=0x1D678,
 },
 [0x1D679]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004A },
  unicodeslot=0x1D679,
 },
 [0x1D67A]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004B },
  unicodeslot=0x1D67A,
 },
 [0x1D67B]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004C },
  unicodeslot=0x1D67B,
 },
 [0x1D67C]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004D },
  unicodeslot=0x1D67C,
 },
 [0x1D67D]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004E },
  unicodeslot=0x1D67D,
 },
 [0x1D67E]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x004F },
  unicodeslot=0x1D67E,
 },
 [0x1D67F]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0050 },
  unicodeslot=0x1D67F,
 },
 [0x1D680]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0051 },
  unicodeslot=0x1D680,
 },
 [0x1D681]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0052 },
  unicodeslot=0x1D681,
 },
 [0x1D682]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0053 },
  unicodeslot=0x1D682,
 },
 [0x1D683]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0054 },
  unicodeslot=0x1D683,
 },
 [0x1D684]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0055 },
  unicodeslot=0x1D684,
 },
 [0x1D685]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0056 },
  unicodeslot=0x1D685,
 },
 [0x1D686]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0057 },
  unicodeslot=0x1D686,
 },
 [0x1D687]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0058 },
  unicodeslot=0x1D687,
 },
 [0x1D688]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0059 },
  unicodeslot=0x1D688,
 },
 [0x1D689]={
  category="lu",
  description="MATHEMATICAL MONOSPACE CAPITAL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x005A },
  unicodeslot=0x1D689,
 },
 [0x1D68A]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL A",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0061 },
  unicodeslot=0x1D68A,
 },
 [0x1D68B]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL B",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0062 },
  unicodeslot=0x1D68B,
 },
 [0x1D68C]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL C",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0063 },
  unicodeslot=0x1D68C,
 },
 [0x1D68D]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL D",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0064 },
  unicodeslot=0x1D68D,
 },
 [0x1D68E]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL E",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0065 },
  unicodeslot=0x1D68E,
 },
 [0x1D68F]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL F",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0066 },
  unicodeslot=0x1D68F,
 },
 [0x1D690]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL G",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0067 },
  unicodeslot=0x1D690,
 },
 [0x1D691]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL H",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0068 },
  unicodeslot=0x1D691,
 },
 [0x1D692]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL I",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0069 },
  unicodeslot=0x1D692,
 },
 [0x1D693]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL J",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006A },
  unicodeslot=0x1D693,
 },
 [0x1D694]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL K",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006B },
  unicodeslot=0x1D694,
 },
 [0x1D695]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL L",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006C },
  unicodeslot=0x1D695,
 },
 [0x1D696]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL M",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006D },
  unicodeslot=0x1D696,
 },
 [0x1D697]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL N",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006E },
  unicodeslot=0x1D697,
 },
 [0x1D698]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL O",
  direction="l",
  linebreak="al",
  specials={ "font", 0x006F },
  unicodeslot=0x1D698,
 },
 [0x1D699]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL P",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0070 },
  unicodeslot=0x1D699,
 },
 [0x1D69A]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL Q",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0071 },
  unicodeslot=0x1D69A,
 },
 [0x1D69B]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL R",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0072 },
  unicodeslot=0x1D69B,
 },
 [0x1D69C]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL S",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0073 },
  unicodeslot=0x1D69C,
 },
 [0x1D69D]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL T",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0074 },
  unicodeslot=0x1D69D,
 },
 [0x1D69E]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL U",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0075 },
  unicodeslot=0x1D69E,
 },
 [0x1D69F]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL V",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0076 },
  unicodeslot=0x1D69F,
 },
 [0x1D6A0]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL W",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0077 },
  unicodeslot=0x1D6A0,
 },
 [0x1D6A1]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL X",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0078 },
  unicodeslot=0x1D6A1,
 },
 [0x1D6A2]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL Y",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0079 },
  unicodeslot=0x1D6A2,
 },
 [0x1D6A3]={
  category="ll",
  description="MATHEMATICAL MONOSPACE SMALL Z",
  direction="l",
  linebreak="al",
  specials={ "font", 0x007A },
  unicodeslot=0x1D6A3,
 },
 [0x1D6A4]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL DOTLESS I",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="imath",
  specials={ "font", 0x0131 },
  unicodeslot=0x1D6A4,
  visual="it",
 },
 [0x1D6A5]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL DOTLESS J",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="jmath",
  specials={ "font", 0x0237 },
  unicodeslot=0x1D6A5,
  visual="it",
 },
 [0x1D6A8]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0391 },
  unicodeslot=0x1D6A8,
  visual="bf",
 },
 [0x1D6A9]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0392 },
  unicodeslot=0x1D6A9,
  visual="bf",
 },
 [0x1D6AA]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0393 },
  unicodeslot=0x1D6AA,
  visual="bf",
 },
 [0x1D6AB]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0394 },
  unicodeslot=0x1D6AB,
  visual="bf",
 },
 [0x1D6AC]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0395 },
  unicodeslot=0x1D6AC,
  visual="bf",
 },
 [0x1D6AD]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0396 },
  unicodeslot=0x1D6AD,
  visual="bf",
 },
 [0x1D6AE]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0397 },
  unicodeslot=0x1D6AE,
  visual="bf",
 },
 [0x1D6AF]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0398 },
  unicodeslot=0x1D6AF,
  visual="bf",
 },
 [0x1D6B0]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0399 },
  unicodeslot=0x1D6B0,
  visual="bf",
 },
 [0x1D6B1]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039A },
  unicodeslot=0x1D6B1,
  visual="bf",
 },
 [0x1D6B2]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039B },
  unicodeslot=0x1D6B2,
  visual="bf",
 },
 [0x1D6B3]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039C },
  unicodeslot=0x1D6B3,
  visual="bf",
 },
 [0x1D6B4]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039D },
  unicodeslot=0x1D6B4,
  visual="bf",
 },
 [0x1D6B5]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039E },
  unicodeslot=0x1D6B5,
  visual="bf",
 },
 [0x1D6B6]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039F },
  unicodeslot=0x1D6B6,
  visual="bf",
 },
 [0x1D6B7]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A0 },
  unicodeslot=0x1D6B7,
  visual="bf",
 },
 [0x1D6B8]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A1 },
  unicodeslot=0x1D6B8,
  visual="bf",
 },
 [0x1D6B9]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F4 },
  unicodeslot=0x1D6B9,
  visual="bf",
 },
 [0x1D6BA]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A3 },
  unicodeslot=0x1D6BA,
  visual="bf",
 },
 [0x1D6BB]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A4 },
  unicodeslot=0x1D6BB,
  visual="bf",
 },
 [0x1D6BC]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A5 },
  unicodeslot=0x1D6BC,
  visual="bf",
 },
 [0x1D6BD]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A6 },
  unicodeslot=0x1D6BD,
  visual="bf",
 },
 [0x1D6BE]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A7 },
  unicodeslot=0x1D6BE,
  visual="bf",
 },
 [0x1D6BF]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A8 },
  unicodeslot=0x1D6BF,
  visual="bf",
 },
 [0x1D6C0]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A9 },
  unicodeslot=0x1D6C0,
  visual="bf",
 },
 [0x1D6C1]={
  category="sm",
  description="MATHEMATICAL BOLD NABLA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x2207 },
  unicodeslot=0x1D6C1,
  visual="bf",
 },
 [0x1D6C2]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B1 },
  unicodeslot=0x1D6C2,
  visual="bf",
 },
 [0x1D6C3]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B2 },
  unicodeslot=0x1D6C3,
  visual="bf",
 },
 [0x1D6C4]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B3 },
  unicodeslot=0x1D6C4,
  visual="bf",
 },
 [0x1D6C5]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B4 },
  unicodeslot=0x1D6C5,
  visual="bf",
 },
 [0x1D6C6]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B5 },
  unicodeslot=0x1D6C6,
  visual="bf",
 },
 [0x1D6C7]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B6 },
  unicodeslot=0x1D6C7,
  visual="bf",
 },
 [0x1D6C8]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B7 },
  unicodeslot=0x1D6C8,
  visual="bf",
 },
 [0x1D6C9]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B8 },
  unicodeslot=0x1D6C9,
  visual="bf",
 },
 [0x1D6CA]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B9 },
  unicodeslot=0x1D6CA,
  visual="bf",
 },
 [0x1D6CB]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BA },
  unicodeslot=0x1D6CB,
  visual="bf",
 },
 [0x1D6CC]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BB },
  unicodeslot=0x1D6CC,
  visual="bf",
 },
 [0x1D6CD]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BC },
  unicodeslot=0x1D6CD,
  visual="bf",
 },
 [0x1D6CE]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BD },
  unicodeslot=0x1D6CE,
  visual="bf",
 },
 [0x1D6CF]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BE },
  unicodeslot=0x1D6CF,
  visual="bf",
 },
 [0x1D6D0]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BF },
  unicodeslot=0x1D6D0,
  visual="bf",
 },
 [0x1D6D1]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C0 },
  unicodeslot=0x1D6D1,
  visual="bf",
 },
 [0x1D6D2]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C1 },
  unicodeslot=0x1D6D2,
  visual="bf",
 },
 [0x1D6D3]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL FINAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C2 },
  unicodeslot=0x1D6D3,
  visual="bf",
 },
 [0x1D6D4]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C3 },
  unicodeslot=0x1D6D4,
  visual="bf",
 },
 [0x1D6D5]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C4 },
  unicodeslot=0x1D6D5,
  visual="bf",
 },
 [0x1D6D6]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C5 },
  unicodeslot=0x1D6D6,
  visual="bf",
 },
 [0x1D6D7]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C6 },
  unicodeslot=0x1D6D7,
  visual="bf",
 },
 [0x1D6D8]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C7 },
  unicodeslot=0x1D6D8,
  visual="bf",
 },
 [0x1D6D9]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C8 },
  unicodeslot=0x1D6D9,
  visual="bf",
 },
 [0x1D6DA]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C9 },
  unicodeslot=0x1D6DA,
  visual="bf",
 },
 [0x1D6DB]={
  category="sm",
  description="MATHEMATICAL BOLD PARTIAL DIFFERENTIAL",
  direction="on",
  linebreak="al",
  specials={ "font", 0x2202 },
  unicodeslot=0x1D6DB,
  visual="bf",
 },
 [0x1D6DC]={
  category="ll",
  description="MATHEMATICAL BOLD EPSILON SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F5 },
  unicodeslot=0x1D6DC,
  visual="bf",
 },
 [0x1D6DD]={
  category="ll",
  description="MATHEMATICAL BOLD THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D1 },
  unicodeslot=0x1D6DD,
  visual="bf",
 },
 [0x1D6DE]={
  category="ll",
  description="MATHEMATICAL BOLD KAPPA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F0 },
  unicodeslot=0x1D6DE,
  visual="bf",
 },
 [0x1D6DF]={
  category="ll",
  description="MATHEMATICAL BOLD PHI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D5 },
  unicodeslot=0x1D6DF,
  visual="bf",
 },
 [0x1D6E0]={
  category="ll",
  description="MATHEMATICAL BOLD RHO SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F1 },
  unicodeslot=0x1D6E0,
  visual="bf",
 },
 [0x1D6E1]={
  category="ll",
  description="MATHEMATICAL BOLD PI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D6 },
  unicodeslot=0x1D6E1,
  visual="bf",
 },
 [0x1D6E2]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0391 },
  unicodeslot=0x1D6E2,
  visual="it",
 },
 [0x1D6E3]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0392 },
  unicodeslot=0x1D6E3,
  visual="it",
 },
 [0x1D6E4]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0393 },
  unicodeslot=0x1D6E4,
  visual="it",
 },
 [0x1D6E5]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0394 },
  unicodeslot=0x1D6E5,
  visual="it",
 },
 [0x1D6E6]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0395 },
  unicodeslot=0x1D6E6,
  visual="it",
 },
 [0x1D6E7]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0396 },
  unicodeslot=0x1D6E7,
  visual="it",
 },
 [0x1D6E8]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0397 },
  unicodeslot=0x1D6E8,
  visual="it",
 },
 [0x1D6E9]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0398 },
  unicodeslot=0x1D6E9,
  visual="it",
 },
 [0x1D6EA]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0399 },
  unicodeslot=0x1D6EA,
  visual="it",
 },
 [0x1D6EB]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039A },
  unicodeslot=0x1D6EB,
  visual="it",
 },
 [0x1D6EC]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039B },
  unicodeslot=0x1D6EC,
  visual="it",
 },
 [0x1D6ED]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039C },
  unicodeslot=0x1D6ED,
  visual="it",
 },
 [0x1D6EE]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039D },
  unicodeslot=0x1D6EE,
  visual="it",
 },
 [0x1D6EF]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039E },
  unicodeslot=0x1D6EF,
  visual="it",
 },
 [0x1D6F0]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039F },
  unicodeslot=0x1D6F0,
  visual="it",
 },
 [0x1D6F1]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A0 },
  unicodeslot=0x1D6F1,
  visual="it",
 },
 [0x1D6F2]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A1 },
  unicodeslot=0x1D6F2,
  visual="it",
 },
 [0x1D6F3]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F4 },
  unicodeslot=0x1D6F3,
  visual="it",
 },
 [0x1D6F4]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A3 },
  unicodeslot=0x1D6F4,
  visual="it",
 },
 [0x1D6F5]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A4 },
  unicodeslot=0x1D6F5,
  visual="it",
 },
 [0x1D6F6]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A5 },
  unicodeslot=0x1D6F6,
  visual="it",
 },
 [0x1D6F7]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A6 },
  unicodeslot=0x1D6F7,
  visual="it",
 },
 [0x1D6F8]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A7 },
  unicodeslot=0x1D6F8,
  visual="it",
 },
 [0x1D6F9]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A8 },
  unicodeslot=0x1D6F9,
  visual="it",
 },
 [0x1D6FA]={
  category="lu",
  description="MATHEMATICAL ITALIC CAPITAL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A9 },
  unicodeslot=0x1D6FA,
  visual="it",
 },
 [0x1D6FB]={
  category="sm",
  description="MATHEMATICAL ITALIC NABLA",
  direction="l",
  linebreak="al",
  mathclass="default",
  specials={ "font", 0x2207 },
  unicodeslot=0x1D6FB,
  visual="it",
 },
 [0x1D6FC]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B1 },
  unicodeslot=0x1D6FC,
  visual="it",
 },
 [0x1D6FD]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B2 },
  unicodeslot=0x1D6FD,
  visual="it",
 },
 [0x1D6FE]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B3 },
  unicodeslot=0x1D6FE,
  visual="it",
 },
 [0x1D6FF]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B4 },
  unicodeslot=0x1D6FF,
  visual="it",
 },
 [0x1D700]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B5 },
  unicodeslot=0x1D700,
  visual="it",
 },
 [0x1D701]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B6 },
  unicodeslot=0x1D701,
  visual="it",
 },
 [0x1D702]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B7 },
  unicodeslot=0x1D702,
  visual="it",
 },
 [0x1D703]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B8 },
  unicodeslot=0x1D703,
  visual="it",
 },
 [0x1D704]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B9 },
  unicodeslot=0x1D704,
  visual="it",
 },
 [0x1D705]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BA },
  unicodeslot=0x1D705,
  visual="it",
 },
 [0x1D706]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BB },
  unicodeslot=0x1D706,
  visual="it",
 },
 [0x1D707]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BC },
  unicodeslot=0x1D707,
  visual="it",
 },
 [0x1D708]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BD },
  unicodeslot=0x1D708,
  visual="it",
 },
 [0x1D709]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BE },
  unicodeslot=0x1D709,
  visual="it",
 },
 [0x1D70A]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BF },
  unicodeslot=0x1D70A,
  visual="it",
 },
 [0x1D70B]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C0 },
  unicodeslot=0x1D70B,
  visual="it",
 },
 [0x1D70C]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C1 },
  unicodeslot=0x1D70C,
  visual="it",
 },
 [0x1D70D]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL FINAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C2 },
  unicodeslot=0x1D70D,
  visual="it",
 },
 [0x1D70E]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C3 },
  unicodeslot=0x1D70E,
  visual="it",
 },
 [0x1D70F]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C4 },
  unicodeslot=0x1D70F,
  visual="it",
 },
 [0x1D710]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C5 },
  unicodeslot=0x1D710,
  visual="it",
 },
 [0x1D711]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C6 },
  unicodeslot=0x1D711,
  visual="it",
 },
 [0x1D712]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C7 },
  unicodeslot=0x1D712,
  visual="it",
 },
 [0x1D713]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C8 },
  unicodeslot=0x1D713,
  visual="it",
 },
 [0x1D714]={
  category="ll",
  description="MATHEMATICAL ITALIC SMALL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C9 },
  unicodeslot=0x1D714,
  visual="it",
 },
 [0x1D715]={
  category="sm",
  description="MATHEMATICAL ITALIC PARTIAL DIFFERENTIAL",
  direction="on",
  linebreak="al",
  specials={ "font", 0x2202 },
  unicodeslot=0x1D715,
  visual="it",
 },
 [0x1D716]={
  category="ll",
  description="MATHEMATICAL ITALIC EPSILON SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F5 },
  unicodeslot=0x1D716,
  visual="it",
 },
 [0x1D717]={
  category="ll",
  description="MATHEMATICAL ITALIC THETA SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="vartheta",
  specials={ "font", 0x03D1 },
  unicodeslot=0x1D717,
  visual="it",
 },
 [0x1D718]={
  category="ll",
  description="MATHEMATICAL ITALIC KAPPA SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="default",
  mathname="varkappa",
  specials={ "font", 0x03F0 },
  unicodeslot=0x1D718,
  visual="it",
 },
 [0x1D719]={
  category="ll",
  description="MATHEMATICAL ITALIC PHI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D5 },
  unicodeslot=0x1D719,
  visual="it",
 },
 [0x1D71A]={
  category="ll",
  description="MATHEMATICAL ITALIC RHO SYMBOL",
  direction="l",
  linebreak="al",
  mathclass="variable",
  mathname="varrho",
  specials={ "font", 0x03F1 },
  unicodeslot=0x1D71A,
  visual="it",
 },
 [0x1D71B]={
  category="ll",
  description="MATHEMATICAL ITALIC PI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D6 },
  unicodeslot=0x1D71B,
  visual="it",
 },
 [0x1D71C]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0391 },
  unicodeslot=0x1D71C,
  visual="bi",
 },
 [0x1D71D]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0392 },
  unicodeslot=0x1D71D,
  visual="bi",
 },
 [0x1D71E]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0393 },
  unicodeslot=0x1D71E,
  visual="bi",
 },
 [0x1D71F]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0394 },
  unicodeslot=0x1D71F,
  visual="bi",
 },
 [0x1D720]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0395 },
  unicodeslot=0x1D720,
  visual="bi",
 },
 [0x1D721]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0396 },
  unicodeslot=0x1D721,
  visual="bi",
 },
 [0x1D722]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0397 },
  unicodeslot=0x1D722,
  visual="bi",
 },
 [0x1D723]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0398 },
  unicodeslot=0x1D723,
  visual="bi",
 },
 [0x1D724]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0399 },
  unicodeslot=0x1D724,
  visual="bi",
 },
 [0x1D725]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039A },
  unicodeslot=0x1D725,
  visual="bi",
 },
 [0x1D726]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039B },
  unicodeslot=0x1D726,
  visual="bi",
 },
 [0x1D727]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039C },
  unicodeslot=0x1D727,
  visual="bi",
 },
 [0x1D728]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039D },
  unicodeslot=0x1D728,
  visual="bi",
 },
 [0x1D729]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039E },
  unicodeslot=0x1D729,
  visual="bi",
 },
 [0x1D72A]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039F },
  unicodeslot=0x1D72A,
  visual="bi",
 },
 [0x1D72B]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A0 },
  unicodeslot=0x1D72B,
  visual="bi",
 },
 [0x1D72C]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A1 },
  unicodeslot=0x1D72C,
  visual="bi",
 },
 [0x1D72D]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F4 },
  unicodeslot=0x1D72D,
  visual="bi",
 },
 [0x1D72E]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A3 },
  unicodeslot=0x1D72E,
  visual="bi",
 },
 [0x1D72F]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A4 },
  unicodeslot=0x1D72F,
  visual="bi",
 },
 [0x1D730]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A5 },
  unicodeslot=0x1D730,
  visual="bi",
 },
 [0x1D731]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A6 },
  unicodeslot=0x1D731,
  visual="bi",
 },
 [0x1D732]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A7 },
  unicodeslot=0x1D732,
  visual="bi",
 },
 [0x1D733]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A8 },
  unicodeslot=0x1D733,
  visual="bi",
 },
 [0x1D734]={
  category="lu",
  description="MATHEMATICAL BOLD ITALIC CAPITAL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A9 },
  unicodeslot=0x1D734,
  visual="bi",
 },
 [0x1D735]={
  category="sm",
  description="MATHEMATICAL BOLD ITALIC NABLA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x2207 },
  unicodeslot=0x1D735,
  visual="bi",
 },
 [0x1D736]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B1 },
  unicodeslot=0x1D736,
  visual="bi",
 },
 [0x1D737]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B2 },
  unicodeslot=0x1D737,
  visual="bi",
 },
 [0x1D738]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B3 },
  unicodeslot=0x1D738,
  visual="bi",
 },
 [0x1D739]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B4 },
  unicodeslot=0x1D739,
  visual="bi",
 },
 [0x1D73A]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B5 },
  unicodeslot=0x1D73A,
  visual="bi",
 },
 [0x1D73B]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B6 },
  unicodeslot=0x1D73B,
  visual="bi",
 },
 [0x1D73C]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B7 },
  unicodeslot=0x1D73C,
  visual="bi",
 },
 [0x1D73D]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B8 },
  unicodeslot=0x1D73D,
  visual="bi",
 },
 [0x1D73E]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B9 },
  unicodeslot=0x1D73E,
  visual="bi",
 },
 [0x1D73F]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BA },
  unicodeslot=0x1D73F,
  visual="bi",
 },
 [0x1D740]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BB },
  unicodeslot=0x1D740,
  visual="bi",
 },
 [0x1D741]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BC },
  unicodeslot=0x1D741,
  visual="bi",
 },
 [0x1D742]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BD },
  unicodeslot=0x1D742,
  visual="bi",
 },
 [0x1D743]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BE },
  unicodeslot=0x1D743,
  visual="bi",
 },
 [0x1D744]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BF },
  unicodeslot=0x1D744,
  visual="bi",
 },
 [0x1D745]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C0 },
  unicodeslot=0x1D745,
  visual="bi",
 },
 [0x1D746]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C1 },
  unicodeslot=0x1D746,
  visual="bi",
 },
 [0x1D747]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL FINAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C2 },
  unicodeslot=0x1D747,
  visual="bi",
 },
 [0x1D748]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C3 },
  unicodeslot=0x1D748,
  visual="bi",
 },
 [0x1D749]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C4 },
  unicodeslot=0x1D749,
  visual="bi",
 },
 [0x1D74A]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C5 },
  unicodeslot=0x1D74A,
  visual="bi",
 },
 [0x1D74B]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C6 },
  unicodeslot=0x1D74B,
  visual="bi",
 },
 [0x1D74C]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C7 },
  unicodeslot=0x1D74C,
  visual="bi",
 },
 [0x1D74D]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C8 },
  unicodeslot=0x1D74D,
  visual="bi",
 },
 [0x1D74E]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC SMALL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C9 },
  unicodeslot=0x1D74E,
  visual="bi",
 },
 [0x1D74F]={
  category="sm",
  description="MATHEMATICAL BOLD ITALIC PARTIAL DIFFERENTIAL",
  direction="on",
  linebreak="al",
  specials={ "font", 0x2202 },
  unicodeslot=0x1D74F,
  visual="bi",
 },
 [0x1D750]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC EPSILON SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F5 },
  unicodeslot=0x1D750,
  visual="bi",
 },
 [0x1D751]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D1 },
  unicodeslot=0x1D751,
  visual="bi",
 },
 [0x1D752]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC KAPPA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F0 },
  unicodeslot=0x1D752,
  visual="bi",
 },
 [0x1D753]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC PHI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D5 },
  unicodeslot=0x1D753,
  visual="bi",
 },
 [0x1D754]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC RHO SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F1 },
  unicodeslot=0x1D754,
  visual="bi",
 },
 [0x1D755]={
  category="ll",
  description="MATHEMATICAL BOLD ITALIC PI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D6 },
  unicodeslot=0x1D755,
  visual="bi",
 },
 [0x1D756]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0391 },
  unicodeslot=0x1D756,
  visual="bf",
 },
 [0x1D757]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0392 },
  unicodeslot=0x1D757,
  visual="bf",
 },
 [0x1D758]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0393 },
  unicodeslot=0x1D758,
  visual="bf",
 },
 [0x1D759]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0394 },
  unicodeslot=0x1D759,
  visual="bf",
 },
 [0x1D75A]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0395 },
  unicodeslot=0x1D75A,
  visual="bf",
 },
 [0x1D75B]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0396 },
  unicodeslot=0x1D75B,
  visual="bf",
 },
 [0x1D75C]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0397 },
  unicodeslot=0x1D75C,
  visual="bf",
 },
 [0x1D75D]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0398 },
  unicodeslot=0x1D75D,
  visual="bf",
 },
 [0x1D75E]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0399 },
  unicodeslot=0x1D75E,
  visual="bf",
 },
 [0x1D75F]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039A },
  unicodeslot=0x1D75F,
  visual="bf",
 },
 [0x1D760]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039B },
  unicodeslot=0x1D760,
  visual="bf",
 },
 [0x1D761]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039C },
  unicodeslot=0x1D761,
  visual="bf",
 },
 [0x1D762]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039D },
  unicodeslot=0x1D762,
  visual="bf",
 },
 [0x1D763]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039E },
  unicodeslot=0x1D763,
  visual="bf",
 },
 [0x1D764]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039F },
  unicodeslot=0x1D764,
  visual="bf",
 },
 [0x1D765]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A0 },
  unicodeslot=0x1D765,
  visual="bf",
 },
 [0x1D766]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A1 },
  unicodeslot=0x1D766,
  visual="bf",
 },
 [0x1D767]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F4 },
  unicodeslot=0x1D767,
  visual="bf",
 },
 [0x1D768]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A3 },
  unicodeslot=0x1D768,
  visual="bf",
 },
 [0x1D769]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A4 },
  unicodeslot=0x1D769,
  visual="bf",
 },
 [0x1D76A]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A5 },
  unicodeslot=0x1D76A,
  visual="bf",
 },
 [0x1D76B]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A6 },
  unicodeslot=0x1D76B,
  visual="bf",
 },
 [0x1D76C]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A7 },
  unicodeslot=0x1D76C,
  visual="bf",
 },
 [0x1D76D]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A8 },
  unicodeslot=0x1D76D,
  visual="bf",
 },
 [0x1D76E]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD CAPITAL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A9 },
  unicodeslot=0x1D76E,
  visual="bf",
 },
 [0x1D76F]={
  category="sm",
  description="MATHEMATICAL SANS-SERIF BOLD NABLA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x2207 },
  unicodeslot=0x1D76F,
  visual="bf",
 },
 [0x1D770]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B1 },
  unicodeslot=0x1D770,
  visual="bf",
 },
 [0x1D771]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B2 },
  unicodeslot=0x1D771,
  visual="bf",
 },
 [0x1D772]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B3 },
  unicodeslot=0x1D772,
  visual="bf",
 },
 [0x1D773]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B4 },
  unicodeslot=0x1D773,
  visual="bf",
 },
 [0x1D774]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B5 },
  unicodeslot=0x1D774,
  visual="bf",
 },
 [0x1D775]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B6 },
  unicodeslot=0x1D775,
  visual="bf",
 },
 [0x1D776]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B7 },
  unicodeslot=0x1D776,
  visual="bf",
 },
 [0x1D777]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B8 },
  unicodeslot=0x1D777,
  visual="bf",
 },
 [0x1D778]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B9 },
  unicodeslot=0x1D778,
  visual="bf",
 },
 [0x1D779]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BA },
  unicodeslot=0x1D779,
  visual="bf",
 },
 [0x1D77A]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BB },
  unicodeslot=0x1D77A,
  visual="bf",
 },
 [0x1D77B]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BC },
  unicodeslot=0x1D77B,
  visual="bf",
 },
 [0x1D77C]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BD },
  unicodeslot=0x1D77C,
  visual="bf",
 },
 [0x1D77D]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BE },
  unicodeslot=0x1D77D,
  visual="bf",
 },
 [0x1D77E]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BF },
  unicodeslot=0x1D77E,
  visual="bf",
 },
 [0x1D77F]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C0 },
  unicodeslot=0x1D77F,
  visual="bf",
 },
 [0x1D780]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C1 },
  unicodeslot=0x1D780,
  visual="bf",
 },
 [0x1D781]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL FINAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C2 },
  unicodeslot=0x1D781,
  visual="bf",
 },
 [0x1D782]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C3 },
  unicodeslot=0x1D782,
  visual="bf",
 },
 [0x1D783]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C4 },
  unicodeslot=0x1D783,
  visual="bf",
 },
 [0x1D784]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C5 },
  unicodeslot=0x1D784,
  visual="bf",
 },
 [0x1D785]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C6 },
  unicodeslot=0x1D785,
  visual="bf",
 },
 [0x1D786]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C7 },
  unicodeslot=0x1D786,
  visual="bf",
 },
 [0x1D787]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C8 },
  unicodeslot=0x1D787,
  visual="bf",
 },
 [0x1D788]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD SMALL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C9 },
  unicodeslot=0x1D788,
  visual="bf",
 },
 [0x1D789]={
  category="sm",
  description="MATHEMATICAL SANS-SERIF BOLD PARTIAL DIFFERENTIAL",
  direction="on",
  linebreak="al",
  specials={ "font", 0x2202 },
  unicodeslot=0x1D789,
  visual="bf",
 },
 [0x1D78A]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD EPSILON SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F5 },
  unicodeslot=0x1D78A,
  visual="bf",
 },
 [0x1D78B]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D1 },
  unicodeslot=0x1D78B,
  visual="bf",
 },
 [0x1D78C]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD KAPPA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F0 },
  unicodeslot=0x1D78C,
  visual="bf",
 },
 [0x1D78D]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD PHI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D5 },
  unicodeslot=0x1D78D,
  visual="bf",
 },
 [0x1D78E]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD RHO SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F1 },
  unicodeslot=0x1D78E,
  visual="bf",
 },
 [0x1D78F]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD PI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D6 },
  unicodeslot=0x1D78F,
  visual="bf",
 },
 [0x1D790]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0391 },
  unicodeslot=0x1D790,
  visual="bi",
 },
 [0x1D791]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0392 },
  unicodeslot=0x1D791,
  visual="bi",
 },
 [0x1D792]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0393 },
  unicodeslot=0x1D792,
  visual="bi",
 },
 [0x1D793]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0394 },
  unicodeslot=0x1D793,
  visual="bi",
 },
 [0x1D794]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0395 },
  unicodeslot=0x1D794,
  visual="bi",
 },
 [0x1D795]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0396 },
  unicodeslot=0x1D795,
  visual="bi",
 },
 [0x1D796]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0397 },
  unicodeslot=0x1D796,
  visual="bi",
 },
 [0x1D797]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0398 },
  unicodeslot=0x1D797,
  visual="bi",
 },
 [0x1D798]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x0399 },
  unicodeslot=0x1D798,
  visual="bi",
 },
 [0x1D799]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039A },
  unicodeslot=0x1D799,
  visual="bi",
 },
 [0x1D79A]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039B },
  unicodeslot=0x1D79A,
  visual="bi",
 },
 [0x1D79B]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039C },
  unicodeslot=0x1D79B,
  visual="bi",
 },
 [0x1D79C]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039D },
  unicodeslot=0x1D79C,
  visual="bi",
 },
 [0x1D79D]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039E },
  unicodeslot=0x1D79D,
  visual="bi",
 },
 [0x1D79E]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x039F },
  unicodeslot=0x1D79E,
  visual="bi",
 },
 [0x1D79F]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A0 },
  unicodeslot=0x1D79F,
  visual="bi",
 },
 [0x1D7A0]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A1 },
  unicodeslot=0x1D7A0,
  visual="bi",
 },
 [0x1D7A1]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F4 },
  unicodeslot=0x1D7A1,
  visual="bi",
 },
 [0x1D7A2]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A3 },
  unicodeslot=0x1D7A2,
  visual="bi",
 },
 [0x1D7A3]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A4 },
  unicodeslot=0x1D7A3,
  visual="bi",
 },
 [0x1D7A4]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A5 },
  unicodeslot=0x1D7A4,
  visual="bi",
 },
 [0x1D7A5]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A6 },
  unicodeslot=0x1D7A5,
  visual="bi",
 },
 [0x1D7A6]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A7 },
  unicodeslot=0x1D7A6,
  visual="bi",
 },
 [0x1D7A7]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A8 },
  unicodeslot=0x1D7A7,
  visual="bi",
 },
 [0x1D7A8]={
  category="lu",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03A9 },
  unicodeslot=0x1D7A8,
  visual="bi",
 },
 [0x1D7A9]={
  category="sm",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC NABLA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x2207 },
  unicodeslot=0x1D7A9,
  visual="bi",
 },
 [0x1D7AA]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ALPHA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B1 },
  unicodeslot=0x1D7AA,
  visual="bi",
 },
 [0x1D7AB]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL BETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B2 },
  unicodeslot=0x1D7AB,
  visual="bi",
 },
 [0x1D7AC]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL GAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B3 },
  unicodeslot=0x1D7AC,
  visual="bi",
 },
 [0x1D7AD]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL DELTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B4 },
  unicodeslot=0x1D7AD,
  visual="bi",
 },
 [0x1D7AE]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL EPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B5 },
  unicodeslot=0x1D7AE,
  visual="bi",
 },
 [0x1D7AF]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ZETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B6 },
  unicodeslot=0x1D7AF,
  visual="bi",
 },
 [0x1D7B0]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B7 },
  unicodeslot=0x1D7B0,
  visual="bi",
 },
 [0x1D7B1]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL THETA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B8 },
  unicodeslot=0x1D7B1,
  visual="bi",
 },
 [0x1D7B2]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL IOTA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03B9 },
  unicodeslot=0x1D7B2,
  visual="bi",
 },
 [0x1D7B3]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL KAPPA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BA },
  unicodeslot=0x1D7B3,
  visual="bi",
 },
 [0x1D7B4]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL LAMDA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BB },
  unicodeslot=0x1D7B4,
  visual="bi",
 },
 [0x1D7B5]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL MU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BC },
  unicodeslot=0x1D7B5,
  visual="bi",
 },
 [0x1D7B6]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL NU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BD },
  unicodeslot=0x1D7B6,
  visual="bi",
 },
 [0x1D7B7]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL XI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BE },
  unicodeslot=0x1D7B7,
  visual="bi",
 },
 [0x1D7B8]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMICRON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03BF },
  unicodeslot=0x1D7B8,
  visual="bi",
 },
 [0x1D7B9]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C0 },
  unicodeslot=0x1D7B9,
  visual="bi",
 },
 [0x1D7BA]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL RHO",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C1 },
  unicodeslot=0x1D7BA,
  visual="bi",
 },
 [0x1D7BB]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL FINAL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C2 },
  unicodeslot=0x1D7BB,
  visual="bi",
 },
 [0x1D7BC]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL SIGMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C3 },
  unicodeslot=0x1D7BC,
  visual="bi",
 },
 [0x1D7BD]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL TAU",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C4 },
  unicodeslot=0x1D7BD,
  visual="bi",
 },
 [0x1D7BE]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL UPSILON",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C5 },
  unicodeslot=0x1D7BE,
  visual="bi",
 },
 [0x1D7BF]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C6 },
  unicodeslot=0x1D7BF,
  visual="bi",
 },
 [0x1D7C0]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL CHI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C7 },
  unicodeslot=0x1D7C0,
  visual="bi",
 },
 [0x1D7C1]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PSI",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C8 },
  unicodeslot=0x1D7C1,
  visual="bi",
 },
 [0x1D7C2]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMEGA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03C9 },
  unicodeslot=0x1D7C2,
  visual="bi",
 },
 [0x1D7C3]={
  category="sm",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC PARTIAL DIFFERENTIAL",
  direction="on",
  linebreak="al",
  specials={ "font", 0x2202 },
  unicodeslot=0x1D7C3,
  visual="bi",
 },
 [0x1D7C4]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC EPSILON SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F5 },
  unicodeslot=0x1D7C4,
  visual="bi",
 },
 [0x1D7C5]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC THETA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D1 },
  unicodeslot=0x1D7C5,
  visual="bi",
 },
 [0x1D7C6]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC KAPPA SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F0 },
  unicodeslot=0x1D7C6,
  visual="bi",
 },
 [0x1D7C7]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC PHI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D5 },
  unicodeslot=0x1D7C7,
  visual="bi",
 },
 [0x1D7C8]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC RHO SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03F1 },
  unicodeslot=0x1D7C8,
  visual="bi",
 },
 [0x1D7C9]={
  category="ll",
  description="MATHEMATICAL SANS-SERIF BOLD ITALIC PI SYMBOL",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03D6 },
  unicodeslot=0x1D7C9,
  visual="bi",
 },
 [0x1D7CA]={
  category="lu",
  description="MATHEMATICAL BOLD CAPITAL DIGAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03DC },
  unicodeslot=0x1D7CA,
  visual="bf",
 },
 [0x1D7CB]={
  category="ll",
  description="MATHEMATICAL BOLD SMALL DIGAMMA",
  direction="l",
  linebreak="al",
  specials={ "font", 0x03DD },
  unicodeslot=0x1D7CB,
  visual="bf",
 },
 [0x1D7CE]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT ZERO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0030 },
  unicodeslot=0x1D7CE,
  visual="bf",
 },
 [0x1D7CF]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT ONE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0031 },
  unicodeslot=0x1D7CF,
  visual="bf",
 },
 [0x1D7D0]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT TWO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0032 },
  unicodeslot=0x1D7D0,
  visual="bf",
 },
 [0x1D7D1]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT THREE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0033 },
  unicodeslot=0x1D7D1,
  visual="bf",
 },
 [0x1D7D2]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT FOUR",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0034 },
  unicodeslot=0x1D7D2,
  visual="bf",
 },
 [0x1D7D3]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT FIVE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0035 },
  unicodeslot=0x1D7D3,
  visual="bf",
 },
 [0x1D7D4]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT SIX",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0036 },
  unicodeslot=0x1D7D4,
  visual="bf",
 },
 [0x1D7D5]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT SEVEN",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0037 },
  unicodeslot=0x1D7D5,
  visual="bf",
 },
 [0x1D7D6]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT EIGHT",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0038 },
  unicodeslot=0x1D7D6,
  visual="bf",
 },
 [0x1D7D7]={
  category="nd",
  description="MATHEMATICAL BOLD DIGIT NINE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0039 },
  unicodeslot=0x1D7D7,
  visual="bf",
 },
 [0x1D7D8]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT ZERO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0030 },
  unicodeslot=0x1D7D8,
 },
 [0x1D7D9]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT ONE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0031 },
  unicodeslot=0x1D7D9,
 },
 [0x1D7DA]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT TWO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0032 },
  unicodeslot=0x1D7DA,
 },
 [0x1D7DB]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT THREE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0033 },
  unicodeslot=0x1D7DB,
 },
 [0x1D7DC]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT FOUR",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0034 },
  unicodeslot=0x1D7DC,
 },
 [0x1D7DD]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT FIVE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0035 },
  unicodeslot=0x1D7DD,
 },
 [0x1D7DE]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT SIX",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0036 },
  unicodeslot=0x1D7DE,
 },
 [0x1D7DF]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT SEVEN",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0037 },
  unicodeslot=0x1D7DF,
 },
 [0x1D7E0]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT EIGHT",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0038 },
  unicodeslot=0x1D7E0,
 },
 [0x1D7E1]={
  category="nd",
  description="MATHEMATICAL DOUBLE-STRUCK DIGIT NINE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0039 },
  unicodeslot=0x1D7E1,
 },
 [0x1D7E2]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT ZERO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0030 },
  unicodeslot=0x1D7E2,
 },
 [0x1D7E3]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT ONE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0031 },
  unicodeslot=0x1D7E3,
 },
 [0x1D7E4]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT TWO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0032 },
  unicodeslot=0x1D7E4,
 },
 [0x1D7E5]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT THREE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0033 },
  unicodeslot=0x1D7E5,
 },
 [0x1D7E6]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT FOUR",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0034 },
  unicodeslot=0x1D7E6,
 },
 [0x1D7E7]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT FIVE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0035 },
  unicodeslot=0x1D7E7,
 },
 [0x1D7E8]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT SIX",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0036 },
  unicodeslot=0x1D7E8,
 },
 [0x1D7E9]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT SEVEN",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0037 },
  unicodeslot=0x1D7E9,
 },
 [0x1D7EA]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT EIGHT",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0038 },
  unicodeslot=0x1D7EA,
 },
 [0x1D7EB]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF DIGIT NINE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0039 },
  unicodeslot=0x1D7EB,
 },
 [0x1D7EC]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT ZERO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0030 },
  unicodeslot=0x1D7EC,
  visual="bf",
 },
 [0x1D7ED]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT ONE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0031 },
  unicodeslot=0x1D7ED,
  visual="bf",
 },
 [0x1D7EE]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT TWO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0032 },
  unicodeslot=0x1D7EE,
  visual="bf",
 },
 [0x1D7EF]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT THREE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0033 },
  unicodeslot=0x1D7EF,
  visual="bf",
 },
 [0x1D7F0]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT FOUR",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0034 },
  unicodeslot=0x1D7F0,
  visual="bf",
 },
 [0x1D7F1]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT FIVE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0035 },
  unicodeslot=0x1D7F1,
  visual="bf",
 },
 [0x1D7F2]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT SIX",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0036 },
  unicodeslot=0x1D7F2,
  visual="bf",
 },
 [0x1D7F3]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT SEVEN",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0037 },
  unicodeslot=0x1D7F3,
  visual="bf",
 },
 [0x1D7F4]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT EIGHT",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0038 },
  unicodeslot=0x1D7F4,
  visual="bf",
 },
 [0x1D7F5]={
  category="nd",
  description="MATHEMATICAL SANS-SERIF BOLD DIGIT NINE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0039 },
  unicodeslot=0x1D7F5,
  visual="bf",
 },
 [0x1D7F6]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT ZERO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0030 },
  unicodeslot=0x1D7F6,
 },
 [0x1D7F7]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT ONE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0031 },
  unicodeslot=0x1D7F7,
 },
 [0x1D7F8]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT TWO",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0032 },
  unicodeslot=0x1D7F8,
 },
 [0x1D7F9]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT THREE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0033 },
  unicodeslot=0x1D7F9,
 },
 [0x1D7FA]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT FOUR",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0034 },
  unicodeslot=0x1D7FA,
 },
 [0x1D7FB]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT FIVE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0035 },
  unicodeslot=0x1D7FB,
 },
 [0x1D7FC]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT SIX",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0036 },
  unicodeslot=0x1D7FC,
 },
 [0x1D7FD]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT SEVEN",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0037 },
  unicodeslot=0x1D7FD,
 },
 [0x1D7FE]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT EIGHT",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0038 },
  unicodeslot=0x1D7FE,
 },
 [0x1D7FF]={
  category="nd",
  description="MATHEMATICAL MONOSPACE DIGIT NINE",
  direction="en",
  linebreak="nu",
  specials={ "font", 0x0039 },
  unicodeslot=0x1D7FF,
 },
 [0x1EE00]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL ALEF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0627 },
  unicodeslot=0x1EE00,
 },
 [0x1EE01]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL BEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0628 },
  unicodeslot=0x1EE01,
 },
 [0x1EE02]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL JEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062C },
  unicodeslot=0x1EE02,
 },
 [0x1EE03]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DAL",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062F },
  unicodeslot=0x1EE03,
 },
 [0x1EE05]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL WAW",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0648 },
  unicodeslot=0x1EE05,
 },
 [0x1EE06]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL ZAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0632 },
  unicodeslot=0x1EE06,
 },
 [0x1EE07]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL HAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062D },
  unicodeslot=0x1EE07,
 },
 [0x1EE08]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0637 },
  unicodeslot=0x1EE08,
 },
 [0x1EE09]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL YEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x064A },
  unicodeslot=0x1EE09,
 },
 [0x1EE0A]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL KAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0643 },
  unicodeslot=0x1EE0A,
 },
 [0x1EE0B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LAM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0644 },
  unicodeslot=0x1EE0B,
 },
 [0x1EE0C]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL MEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0645 },
  unicodeslot=0x1EE0C,
 },
 [0x1EE0D]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL NOON",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0646 },
  unicodeslot=0x1EE0D,
 },
 [0x1EE0E]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL SEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0633 },
  unicodeslot=0x1EE0E,
 },
 [0x1EE0F]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL AIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0639 },
  unicodeslot=0x1EE0F,
 },
 [0x1EE10]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL FEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0641 },
  unicodeslot=0x1EE10,
 },
 [0x1EE11]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL SAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0635 },
  unicodeslot=0x1EE11,
 },
 [0x1EE12]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL QAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0642 },
  unicodeslot=0x1EE12,
 },
 [0x1EE13]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL REH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0631 },
  unicodeslot=0x1EE13,
 },
 [0x1EE14]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL SHEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0634 },
  unicodeslot=0x1EE14,
 },
 [0x1EE15]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062A },
  unicodeslot=0x1EE15,
 },
 [0x1EE16]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL THEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062B },
  unicodeslot=0x1EE16,
 },
 [0x1EE17]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL KHAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062E },
  unicodeslot=0x1EE17,
 },
 [0x1EE18]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL THAL",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0630 },
  unicodeslot=0x1EE18,
 },
 [0x1EE19]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0636 },
  unicodeslot=0x1EE19,
 },
 [0x1EE1A]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL ZAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0638 },
  unicodeslot=0x1EE1A,
 },
 [0x1EE1B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL GHAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x063A },
  unicodeslot=0x1EE1B,
 },
 [0x1EE1C]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOTLESS BEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x066E },
  unicodeslot=0x1EE1C,
 },
 [0x1EE1D]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOTLESS NOON",
  direction="al",
  linebreak="al",
  specials={ "font", 0x06BA },
  unicodeslot=0x1EE1D,
 },
 [0x1EE1E]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOTLESS FEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x06A1 },
  unicodeslot=0x1EE1E,
 },
 [0x1EE1F]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOTLESS QAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x066F },
  unicodeslot=0x1EE1F,
 },
 [0x1EE21]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL BEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0628 },
  unicodeslot=0x1EE21,
 },
 [0x1EE22]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL JEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062C },
  unicodeslot=0x1EE22,
 },
 [0x1EE24]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL HEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0647 },
  unicodeslot=0x1EE24,
 },
 [0x1EE27]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL HAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062D },
  unicodeslot=0x1EE27,
 },
 [0x1EE29]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL YEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x064A },
  unicodeslot=0x1EE29,
 },
 [0x1EE2A]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL KAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0643 },
  unicodeslot=0x1EE2A,
 },
 [0x1EE2B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL LAM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0644 },
  unicodeslot=0x1EE2B,
 },
 [0x1EE2C]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL MEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0645 },
  unicodeslot=0x1EE2C,
 },
 [0x1EE2D]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL NOON",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0646 },
  unicodeslot=0x1EE2D,
 },
 [0x1EE2E]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL SEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0633 },
  unicodeslot=0x1EE2E,
 },
 [0x1EE2F]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL AIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0639 },
  unicodeslot=0x1EE2F,
 },
 [0x1EE30]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL FEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0641 },
  unicodeslot=0x1EE30,
 },
 [0x1EE31]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL SAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0635 },
  unicodeslot=0x1EE31,
 },
 [0x1EE32]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL QAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0642 },
  unicodeslot=0x1EE32,
 },
 [0x1EE34]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL SHEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0634 },
  unicodeslot=0x1EE34,
 },
 [0x1EE35]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL TEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062A },
  unicodeslot=0x1EE35,
 },
 [0x1EE36]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL THEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062B },
  unicodeslot=0x1EE36,
 },
 [0x1EE37]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL KHAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062E },
  unicodeslot=0x1EE37,
 },
 [0x1EE39]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL DAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0636 },
  unicodeslot=0x1EE39,
 },
 [0x1EE3B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL INITIAL GHAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x063A },
  unicodeslot=0x1EE3B,
 },
 [0x1EE42]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED JEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062C },
  unicodeslot=0x1EE42,
 },
 [0x1EE47]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED HAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062D },
  unicodeslot=0x1EE47,
 },
 [0x1EE49]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED YEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x064A },
  unicodeslot=0x1EE49,
 },
 [0x1EE4B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED LAM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0644 },
  unicodeslot=0x1EE4B,
 },
 [0x1EE4D]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED NOON",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0646 },
  unicodeslot=0x1EE4D,
 },
 [0x1EE4E]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED SEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0633 },
  unicodeslot=0x1EE4E,
 },
 [0x1EE4F]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED AIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0639 },
  unicodeslot=0x1EE4F,
 },
 [0x1EE51]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED SAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0635 },
  unicodeslot=0x1EE51,
 },
 [0x1EE52]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED QAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0642 },
  unicodeslot=0x1EE52,
 },
 [0x1EE54]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED SHEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0634 },
  unicodeslot=0x1EE54,
 },
 [0x1EE57]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED KHAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062E },
  unicodeslot=0x1EE57,
 },
 [0x1EE59]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED DAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0636 },
  unicodeslot=0x1EE59,
 },
 [0x1EE5B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED GHAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x063A },
  unicodeslot=0x1EE5B,
 },
 [0x1EE5D]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED DOTLESS NOON",
  direction="al",
  linebreak="al",
  specials={ "font", 0x06BA },
  unicodeslot=0x1EE5D,
 },
 [0x1EE5F]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL TAILED DOTLESS QAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x066F },
  unicodeslot=0x1EE5F,
 },
 [0x1EE61]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED BEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0628 },
  unicodeslot=0x1EE61,
 },
 [0x1EE62]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED JEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062C },
  unicodeslot=0x1EE62,
 },
 [0x1EE64]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED HEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0647 },
  unicodeslot=0x1EE64,
 },
 [0x1EE67]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED HAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062D },
  unicodeslot=0x1EE67,
 },
 [0x1EE68]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED TAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0637 },
  unicodeslot=0x1EE68,
 },
 [0x1EE69]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED YEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x064A },
  unicodeslot=0x1EE69,
 },
 [0x1EE6A]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED KAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0643 },
  unicodeslot=0x1EE6A,
 },
 [0x1EE6C]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED MEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0645 },
  unicodeslot=0x1EE6C,
 },
 [0x1EE6D]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED NOON",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0646 },
  unicodeslot=0x1EE6D,
 },
 [0x1EE6E]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED SEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0633 },
  unicodeslot=0x1EE6E,
 },
 [0x1EE6F]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED AIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0639 },
  unicodeslot=0x1EE6F,
 },
 [0x1EE70]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED FEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0641 },
  unicodeslot=0x1EE70,
 },
 [0x1EE71]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED SAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0635 },
  unicodeslot=0x1EE71,
 },
 [0x1EE72]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED QAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0642 },
  unicodeslot=0x1EE72,
 },
 [0x1EE74]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED SHEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0634 },
  unicodeslot=0x1EE74,
 },
 [0x1EE75]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED TEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062A },
  unicodeslot=0x1EE75,
 },
 [0x1EE76]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED THEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062B },
  unicodeslot=0x1EE76,
 },
 [0x1EE77]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED KHAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062E },
  unicodeslot=0x1EE77,
 },
 [0x1EE79]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED DAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0636 },
  unicodeslot=0x1EE79,
 },
 [0x1EE7A]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED ZAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0638 },
  unicodeslot=0x1EE7A,
 },
 [0x1EE7B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED GHAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x063A },
  unicodeslot=0x1EE7B,
 },
 [0x1EE7C]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED DOTLESS BEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x066E },
  unicodeslot=0x1EE7C,
 },
 [0x1EE7E]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL STRETCHED DOTLESS FEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x06A1 },
  unicodeslot=0x1EE7E,
 },
 [0x1EE80]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED ALEF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0627 },
  unicodeslot=0x1EE80,
 },
 [0x1EE81]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED BEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0628 },
  unicodeslot=0x1EE81,
 },
 [0x1EE82]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED JEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062C },
  unicodeslot=0x1EE82,
 },
 [0x1EE83]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED DAL",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062F },
  unicodeslot=0x1EE83,
 },
 [0x1EE84]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED HEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0647 },
  unicodeslot=0x1EE84,
 },
 [0x1EE85]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED WAW",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0648 },
  unicodeslot=0x1EE85,
 },
 [0x1EE86]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED ZAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0632 },
  unicodeslot=0x1EE86,
 },
 [0x1EE87]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED HAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062D },
  unicodeslot=0x1EE87,
 },
 [0x1EE88]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED TAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0637 },
  unicodeslot=0x1EE88,
 },
 [0x1EE89]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED YEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x064A },
  unicodeslot=0x1EE89,
 },
 [0x1EE8B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED LAM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0644 },
  unicodeslot=0x1EE8B,
 },
 [0x1EE8C]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED MEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0645 },
  unicodeslot=0x1EE8C,
 },
 [0x1EE8D]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED NOON",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0646 },
  unicodeslot=0x1EE8D,
 },
 [0x1EE8E]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED SEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0633 },
  unicodeslot=0x1EE8E,
 },
 [0x1EE8F]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED AIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0639 },
  unicodeslot=0x1EE8F,
 },
 [0x1EE90]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED FEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0641 },
  unicodeslot=0x1EE90,
 },
 [0x1EE91]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED SAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0635 },
  unicodeslot=0x1EE91,
 },
 [0x1EE92]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED QAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0642 },
  unicodeslot=0x1EE92,
 },
 [0x1EE93]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED REH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0631 },
  unicodeslot=0x1EE93,
 },
 [0x1EE94]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED SHEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0634 },
  unicodeslot=0x1EE94,
 },
 [0x1EE95]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED TEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062A },
  unicodeslot=0x1EE95,
 },
 [0x1EE96]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED THEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062B },
  unicodeslot=0x1EE96,
 },
 [0x1EE97]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED KHAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062E },
  unicodeslot=0x1EE97,
 },
 [0x1EE98]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED THAL",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0630 },
  unicodeslot=0x1EE98,
 },
 [0x1EE99]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED DAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0636 },
  unicodeslot=0x1EE99,
 },
 [0x1EE9A]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED ZAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0638 },
  unicodeslot=0x1EE9A,
 },
 [0x1EE9B]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL LOOPED GHAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x063A },
  unicodeslot=0x1EE9B,
 },
 [0x1EEA1]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK BEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0628 },
  unicodeslot=0x1EEA1,
 },
 [0x1EEA2]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK JEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062C },
  unicodeslot=0x1EEA2,
 },
 [0x1EEA3]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK DAL",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062F },
  unicodeslot=0x1EEA3,
 },
 [0x1EEA5]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK WAW",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0648 },
  unicodeslot=0x1EEA5,
 },
 [0x1EEA6]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK ZAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0632 },
  unicodeslot=0x1EEA6,
 },
 [0x1EEA7]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK HAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062D },
  unicodeslot=0x1EEA7,
 },
 [0x1EEA8]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK TAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0637 },
  unicodeslot=0x1EEA8,
 },
 [0x1EEA9]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK YEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x064A },
  unicodeslot=0x1EEA9,
 },
 [0x1EEAB]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK LAM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0644 },
  unicodeslot=0x1EEAB,
 },
 [0x1EEAC]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK MEEM",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0645 },
  unicodeslot=0x1EEAC,
 },
 [0x1EEAD]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK NOON",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0646 },
  unicodeslot=0x1EEAD,
 },
 [0x1EEAE]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK SEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0633 },
  unicodeslot=0x1EEAE,
 },
 [0x1EEAF]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK AIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0639 },
  unicodeslot=0x1EEAF,
 },
 [0x1EEB0]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK FEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0641 },
  unicodeslot=0x1EEB0,
 },
 [0x1EEB1]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK SAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0635 },
  unicodeslot=0x1EEB1,
 },
 [0x1EEB2]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK QAF",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0642 },
  unicodeslot=0x1EEB2,
 },
 [0x1EEB3]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK REH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0631 },
  unicodeslot=0x1EEB3,
 },
 [0x1EEB4]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK SHEEN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0634 },
  unicodeslot=0x1EEB4,
 },
 [0x1EEB5]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK TEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062A },
  unicodeslot=0x1EEB5,
 },
 [0x1EEB6]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK THEH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062B },
  unicodeslot=0x1EEB6,
 },
 [0x1EEB7]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK KHAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x062E },
  unicodeslot=0x1EEB7,
 },
 [0x1EEB8]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK THAL",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0630 },
  unicodeslot=0x1EEB8,
 },
 [0x1EEB9]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK DAD",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0636 },
  unicodeslot=0x1EEB9,
 },
 [0x1EEBA]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK ZAH",
  direction="al",
  linebreak="al",
  specials={ "font", 0x0638 },
  unicodeslot=0x1EEBA,
 },
 [0x1EEBB]={
  category="lo",
  comment="check math properties",
  description="ARABIC MATHEMATICAL DOUBLE-STRUCK GHAIN",
  direction="al",
  linebreak="al",
  specials={ "font", 0x063A },
  unicodeslot=0x1EEBB,
 },
 [0x1EEF0]={
  category="sm",
  comment="check math properties",
  description="ARABIC MATHEMATICAL OPERATOR MEEM WITH HAH WITH TATWEEL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1EEF0,
 },
 [0x1EEF1]={
  category="sm",
  comment="check math properties",
  description="ARABIC MATHEMATICAL OPERATOR HAH WITH DAL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1EEF1,
 },
 [0x1F000]={
  category="so",
  description="MAHJONG TILE EAST WIND",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F000,
 },
 [0x1F001]={
  category="so",
  description="MAHJONG TILE SOUTH WIND",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F001,
 },
 [0x1F002]={
  category="so",
  description="MAHJONG TILE WEST WIND",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F002,
 },
 [0x1F003]={
  category="so",
  description="MAHJONG TILE NORTH WIND",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F003,
 },
 [0x1F004]={
  category="so",
  description="MAHJONG TILE RED DRAGON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F004,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x1F005]={
  category="so",
  description="MAHJONG TILE GREEN DRAGON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F005,
 },
 [0x1F006]={
  category="so",
  description="MAHJONG TILE WHITE DRAGON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F006,
 },
 [0x1F007]={
  category="so",
  description="MAHJONG TILE ONE OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F007,
 },
 [0x1F008]={
  category="so",
  description="MAHJONG TILE TWO OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F008,
 },
 [0x1F009]={
  category="so",
  description="MAHJONG TILE THREE OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F009,
 },
 [0x1F00A]={
  category="so",
  description="MAHJONG TILE FOUR OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F00A,
 },
 [0x1F00B]={
  category="so",
  description="MAHJONG TILE FIVE OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F00B,
 },
 [0x1F00C]={
  category="so",
  description="MAHJONG TILE SIX OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F00C,
 },
 [0x1F00D]={
  category="so",
  description="MAHJONG TILE SEVEN OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F00D,
 },
 [0x1F00E]={
  category="so",
  description="MAHJONG TILE EIGHT OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F00E,
 },
 [0x1F00F]={
  category="so",
  description="MAHJONG TILE NINE OF CHARACTERS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F00F,
 },
 [0x1F010]={
  category="so",
  description="MAHJONG TILE ONE OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F010,
 },
 [0x1F011]={
  category="so",
  description="MAHJONG TILE TWO OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F011,
 },
 [0x1F012]={
  category="so",
  description="MAHJONG TILE THREE OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F012,
 },
 [0x1F013]={
  category="so",
  description="MAHJONG TILE FOUR OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F013,
 },
 [0x1F014]={
  category="so",
  description="MAHJONG TILE FIVE OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F014,
 },
 [0x1F015]={
  category="so",
  description="MAHJONG TILE SIX OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F015,
 },
 [0x1F016]={
  category="so",
  description="MAHJONG TILE SEVEN OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F016,
 },
 [0x1F017]={
  category="so",
  description="MAHJONG TILE EIGHT OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F017,
 },
 [0x1F018]={
  category="so",
  description="MAHJONG TILE NINE OF BAMBOOS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F018,
 },
 [0x1F019]={
  category="so",
  description="MAHJONG TILE ONE OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F019,
 },
 [0x1F01A]={
  category="so",
  description="MAHJONG TILE TWO OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F01A,
 },
 [0x1F01B]={
  category="so",
  description="MAHJONG TILE THREE OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F01B,
 },
 [0x1F01C]={
  category="so",
  description="MAHJONG TILE FOUR OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F01C,
 },
 [0x1F01D]={
  category="so",
  description="MAHJONG TILE FIVE OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F01D,
 },
 [0x1F01E]={
  category="so",
  description="MAHJONG TILE SIX OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F01E,
 },
 [0x1F01F]={
  category="so",
  description="MAHJONG TILE SEVEN OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F01F,
 },
 [0x1F020]={
  category="so",
  description="MAHJONG TILE EIGHT OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F020,
 },
 [0x1F021]={
  category="so",
  description="MAHJONG TILE NINE OF CIRCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F021,
 },
 [0x1F022]={
  category="so",
  description="MAHJONG TILE PLUM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F022,
 },
 [0x1F023]={
  category="so",
  description="MAHJONG TILE ORCHID",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F023,
 },
 [0x1F024]={
  category="so",
  description="MAHJONG TILE BAMBOO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F024,
 },
 [0x1F025]={
  category="so",
  description="MAHJONG TILE CHRYSANTHEMUM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F025,
 },
 [0x1F026]={
  category="so",
  description="MAHJONG TILE SPRING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F026,
 },
 [0x1F027]={
  category="so",
  description="MAHJONG TILE SUMMER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F027,
 },
 [0x1F028]={
  category="so",
  description="MAHJONG TILE AUTUMN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F028,
 },
 [0x1F029]={
  category="so",
  description="MAHJONG TILE WINTER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F029,
 },
 [0x1F02A]={
  category="so",
  description="MAHJONG TILE JOKER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F02A,
 },
 [0x1F02B]={
  category="so",
  description="MAHJONG TILE BACK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F02B,
 },
 [0x1F030]={
  category="so",
  description="DOMINO TILE HORIZONTAL BACK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F030,
 },
 [0x1F031]={
  category="so",
  description="DOMINO TILE HORIZONTAL-00-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F031,
 },
 [0x1F032]={
  category="so",
  description="DOMINO TILE HORIZONTAL-00-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F032,
 },
 [0x1F033]={
  category="so",
  description="DOMINO TILE HORIZONTAL-00-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F033,
 },
 [0x1F034]={
  category="so",
  description="DOMINO TILE HORIZONTAL-00-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F034,
 },
 [0x1F035]={
  category="so",
  description="DOMINO TILE HORIZONTAL-00-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F035,
 },
 [0x1F036]={
  category="so",
  description="DOMINO TILE HORIZONTAL-00-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F036,
 },
 [0x1F037]={
  category="so",
  description="DOMINO TILE HORIZONTAL-00-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F037,
 },
 [0x1F038]={
  category="so",
  description="DOMINO TILE HORIZONTAL-01-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F038,
 },
 [0x1F039]={
  category="so",
  description="DOMINO TILE HORIZONTAL-01-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F039,
 },
 [0x1F03A]={
  category="so",
  description="DOMINO TILE HORIZONTAL-01-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F03A,
 },
 [0x1F03B]={
  category="so",
  description="DOMINO TILE HORIZONTAL-01-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F03B,
 },
 [0x1F03C]={
  category="so",
  description="DOMINO TILE HORIZONTAL-01-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F03C,
 },
 [0x1F03D]={
  category="so",
  description="DOMINO TILE HORIZONTAL-01-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F03D,
 },
 [0x1F03E]={
  category="so",
  description="DOMINO TILE HORIZONTAL-01-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F03E,
 },
 [0x1F03F]={
  category="so",
  description="DOMINO TILE HORIZONTAL-02-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F03F,
 },
 [0x1F040]={
  category="so",
  description="DOMINO TILE HORIZONTAL-02-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F040,
 },
 [0x1F041]={
  category="so",
  description="DOMINO TILE HORIZONTAL-02-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F041,
 },
 [0x1F042]={
  category="so",
  description="DOMINO TILE HORIZONTAL-02-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F042,
 },
 [0x1F043]={
  category="so",
  description="DOMINO TILE HORIZONTAL-02-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F043,
 },
 [0x1F044]={
  category="so",
  description="DOMINO TILE HORIZONTAL-02-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F044,
 },
 [0x1F045]={
  category="so",
  description="DOMINO TILE HORIZONTAL-02-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F045,
 },
 [0x1F046]={
  category="so",
  description="DOMINO TILE HORIZONTAL-03-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F046,
 },
 [0x1F047]={
  category="so",
  description="DOMINO TILE HORIZONTAL-03-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F047,
 },
 [0x1F048]={
  category="so",
  description="DOMINO TILE HORIZONTAL-03-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F048,
 },
 [0x1F049]={
  category="so",
  description="DOMINO TILE HORIZONTAL-03-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F049,
 },
 [0x1F04A]={
  category="so",
  description="DOMINO TILE HORIZONTAL-03-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F04A,
 },
 [0x1F04B]={
  category="so",
  description="DOMINO TILE HORIZONTAL-03-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F04B,
 },
 [0x1F04C]={
  category="so",
  description="DOMINO TILE HORIZONTAL-03-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F04C,
 },
 [0x1F04D]={
  category="so",
  description="DOMINO TILE HORIZONTAL-04-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F04D,
 },
 [0x1F04E]={
  category="so",
  description="DOMINO TILE HORIZONTAL-04-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F04E,
 },
 [0x1F04F]={
  category="so",
  description="DOMINO TILE HORIZONTAL-04-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F04F,
 },
 [0x1F050]={
  category="so",
  description="DOMINO TILE HORIZONTAL-04-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F050,
 },
 [0x1F051]={
  category="so",
  description="DOMINO TILE HORIZONTAL-04-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F051,
 },
 [0x1F052]={
  category="so",
  description="DOMINO TILE HORIZONTAL-04-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F052,
 },
 [0x1F053]={
  category="so",
  description="DOMINO TILE HORIZONTAL-04-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F053,
 },
 [0x1F054]={
  category="so",
  description="DOMINO TILE HORIZONTAL-05-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F054,
 },
 [0x1F055]={
  category="so",
  description="DOMINO TILE HORIZONTAL-05-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F055,
 },
 [0x1F056]={
  category="so",
  description="DOMINO TILE HORIZONTAL-05-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F056,
 },
 [0x1F057]={
  category="so",
  description="DOMINO TILE HORIZONTAL-05-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F057,
 },
 [0x1F058]={
  category="so",
  description="DOMINO TILE HORIZONTAL-05-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F058,
 },
 [0x1F059]={
  category="so",
  description="DOMINO TILE HORIZONTAL-05-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F059,
 },
 [0x1F05A]={
  category="so",
  description="DOMINO TILE HORIZONTAL-05-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F05A,
 },
 [0x1F05B]={
  category="so",
  description="DOMINO TILE HORIZONTAL-06-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F05B,
 },
 [0x1F05C]={
  category="so",
  description="DOMINO TILE HORIZONTAL-06-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F05C,
 },
 [0x1F05D]={
  category="so",
  description="DOMINO TILE HORIZONTAL-06-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F05D,
 },
 [0x1F05E]={
  category="so",
  description="DOMINO TILE HORIZONTAL-06-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F05E,
 },
 [0x1F05F]={
  category="so",
  description="DOMINO TILE HORIZONTAL-06-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F05F,
 },
 [0x1F060]={
  category="so",
  description="DOMINO TILE HORIZONTAL-06-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F060,
 },
 [0x1F061]={
  category="so",
  description="DOMINO TILE HORIZONTAL-06-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F061,
 },
 [0x1F062]={
  category="so",
  description="DOMINO TILE VERTICAL BACK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F062,
 },
 [0x1F063]={
  category="so",
  description="DOMINO TILE VERTICAL-00-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F063,
 },
 [0x1F064]={
  category="so",
  description="DOMINO TILE VERTICAL-00-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F064,
 },
 [0x1F065]={
  category="so",
  description="DOMINO TILE VERTICAL-00-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F065,
 },
 [0x1F066]={
  category="so",
  description="DOMINO TILE VERTICAL-00-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F066,
 },
 [0x1F067]={
  category="so",
  description="DOMINO TILE VERTICAL-00-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F067,
 },
 [0x1F068]={
  category="so",
  description="DOMINO TILE VERTICAL-00-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F068,
 },
 [0x1F069]={
  category="so",
  description="DOMINO TILE VERTICAL-00-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F069,
 },
 [0x1F06A]={
  category="so",
  description="DOMINO TILE VERTICAL-01-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F06A,
 },
 [0x1F06B]={
  category="so",
  description="DOMINO TILE VERTICAL-01-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F06B,
 },
 [0x1F06C]={
  category="so",
  description="DOMINO TILE VERTICAL-01-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F06C,
 },
 [0x1F06D]={
  category="so",
  description="DOMINO TILE VERTICAL-01-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F06D,
 },
 [0x1F06E]={
  category="so",
  description="DOMINO TILE VERTICAL-01-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F06E,
 },
 [0x1F06F]={
  category="so",
  description="DOMINO TILE VERTICAL-01-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F06F,
 },
 [0x1F070]={
  category="so",
  description="DOMINO TILE VERTICAL-01-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F070,
 },
 [0x1F071]={
  category="so",
  description="DOMINO TILE VERTICAL-02-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F071,
 },
 [0x1F072]={
  category="so",
  description="DOMINO TILE VERTICAL-02-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F072,
 },
 [0x1F073]={
  category="so",
  description="DOMINO TILE VERTICAL-02-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F073,
 },
 [0x1F074]={
  category="so",
  description="DOMINO TILE VERTICAL-02-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F074,
 },
 [0x1F075]={
  category="so",
  description="DOMINO TILE VERTICAL-02-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F075,
 },
 [0x1F076]={
  category="so",
  description="DOMINO TILE VERTICAL-02-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F076,
 },
 [0x1F077]={
  category="so",
  description="DOMINO TILE VERTICAL-02-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F077,
 },
 [0x1F078]={
  category="so",
  description="DOMINO TILE VERTICAL-03-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F078,
 },
 [0x1F079]={
  category="so",
  description="DOMINO TILE VERTICAL-03-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F079,
 },
 [0x1F07A]={
  category="so",
  description="DOMINO TILE VERTICAL-03-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F07A,
 },
 [0x1F07B]={
  category="so",
  description="DOMINO TILE VERTICAL-03-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F07B,
 },
 [0x1F07C]={
  category="so",
  description="DOMINO TILE VERTICAL-03-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F07C,
 },
 [0x1F07D]={
  category="so",
  description="DOMINO TILE VERTICAL-03-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F07D,
 },
 [0x1F07E]={
  category="so",
  description="DOMINO TILE VERTICAL-03-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F07E,
 },
 [0x1F07F]={
  category="so",
  description="DOMINO TILE VERTICAL-04-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F07F,
 },
 [0x1F080]={
  category="so",
  description="DOMINO TILE VERTICAL-04-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F080,
 },
 [0x1F081]={
  category="so",
  description="DOMINO TILE VERTICAL-04-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F081,
 },
 [0x1F082]={
  category="so",
  description="DOMINO TILE VERTICAL-04-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F082,
 },
 [0x1F083]={
  category="so",
  description="DOMINO TILE VERTICAL-04-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F083,
 },
 [0x1F084]={
  category="so",
  description="DOMINO TILE VERTICAL-04-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F084,
 },
 [0x1F085]={
  category="so",
  description="DOMINO TILE VERTICAL-04-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F085,
 },
 [0x1F086]={
  category="so",
  description="DOMINO TILE VERTICAL-05-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F086,
 },
 [0x1F087]={
  category="so",
  description="DOMINO TILE VERTICAL-05-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F087,
 },
 [0x1F088]={
  category="so",
  description="DOMINO TILE VERTICAL-05-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F088,
 },
 [0x1F089]={
  category="so",
  description="DOMINO TILE VERTICAL-05-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F089,
 },
 [0x1F08A]={
  category="so",
  description="DOMINO TILE VERTICAL-05-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F08A,
 },
 [0x1F08B]={
  category="so",
  description="DOMINO TILE VERTICAL-05-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F08B,
 },
 [0x1F08C]={
  category="so",
  description="DOMINO TILE VERTICAL-05-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F08C,
 },
 [0x1F08D]={
  category="so",
  description="DOMINO TILE VERTICAL-06-00",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F08D,
 },
 [0x1F08E]={
  category="so",
  description="DOMINO TILE VERTICAL-06-01",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F08E,
 },
 [0x1F08F]={
  category="so",
  description="DOMINO TILE VERTICAL-06-02",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F08F,
 },
 [0x1F090]={
  category="so",
  description="DOMINO TILE VERTICAL-06-03",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F090,
 },
 [0x1F091]={
  category="so",
  description="DOMINO TILE VERTICAL-06-04",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F091,
 },
 [0x1F092]={
  category="so",
  description="DOMINO TILE VERTICAL-06-05",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F092,
 },
 [0x1F093]={
  category="so",
  description="DOMINO TILE VERTICAL-06-06",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F093,
 },
 [0x1F0A0]={
  category="so",
  description="PLAYING CARD BACK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A0,
 },
 [0x1F0A1]={
  category="so",
  description="PLAYING CARD ACE OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A1,
 },
 [0x1F0A2]={
  category="so",
  description="PLAYING CARD TWO OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A2,
 },
 [0x1F0A3]={
  category="so",
  description="PLAYING CARD THREE OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A3,
 },
 [0x1F0A4]={
  category="so",
  description="PLAYING CARD FOUR OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A4,
 },
 [0x1F0A5]={
  category="so",
  description="PLAYING CARD FIVE OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A5,
 },
 [0x1F0A6]={
  category="so",
  description="PLAYING CARD SIX OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A6,
 },
 [0x1F0A7]={
  category="so",
  description="PLAYING CARD SEVEN OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A7,
 },
 [0x1F0A8]={
  category="so",
  description="PLAYING CARD EIGHT OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A8,
 },
 [0x1F0A9]={
  category="so",
  description="PLAYING CARD NINE OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0A9,
 },
 [0x1F0AA]={
  category="so",
  description="PLAYING CARD TEN OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0AA,
 },
 [0x1F0AB]={
  category="so",
  description="PLAYING CARD JACK OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0AB,
 },
 [0x1F0AC]={
  category="so",
  description="PLAYING CARD KNIGHT OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0AC,
 },
 [0x1F0AD]={
  category="so",
  description="PLAYING CARD QUEEN OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0AD,
 },
 [0x1F0AE]={
  category="so",
  description="PLAYING CARD KING OF SPADES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0AE,
 },
 [0x1F0B1]={
  category="so",
  description="PLAYING CARD ACE OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B1,
 },
 [0x1F0B2]={
  category="so",
  description="PLAYING CARD TWO OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B2,
 },
 [0x1F0B3]={
  category="so",
  description="PLAYING CARD THREE OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B3,
 },
 [0x1F0B4]={
  category="so",
  description="PLAYING CARD FOUR OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B4,
 },
 [0x1F0B5]={
  category="so",
  description="PLAYING CARD FIVE OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B5,
 },
 [0x1F0B6]={
  category="so",
  description="PLAYING CARD SIX OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B6,
 },
 [0x1F0B7]={
  category="so",
  description="PLAYING CARD SEVEN OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B7,
 },
 [0x1F0B8]={
  category="so",
  description="PLAYING CARD EIGHT OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B8,
 },
 [0x1F0B9]={
  category="so",
  description="PLAYING CARD NINE OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0B9,
 },
 [0x1F0BA]={
  category="so",
  description="PLAYING CARD TEN OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0BA,
 },
 [0x1F0BB]={
  category="so",
  description="PLAYING CARD JACK OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0BB,
 },
 [0x1F0BC]={
  category="so",
  description="PLAYING CARD KNIGHT OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0BC,
 },
 [0x1F0BD]={
  category="so",
  description="PLAYING CARD QUEEN OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0BD,
 },
 [0x1F0BE]={
  category="so",
  description="PLAYING CARD KING OF HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0BE,
 },
 [0x1F0C1]={
  category="so",
  description="PLAYING CARD ACE OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C1,
 },
 [0x1F0C2]={
  category="so",
  description="PLAYING CARD TWO OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C2,
 },
 [0x1F0C3]={
  category="so",
  description="PLAYING CARD THREE OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C3,
 },
 [0x1F0C4]={
  category="so",
  description="PLAYING CARD FOUR OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C4,
 },
 [0x1F0C5]={
  category="so",
  description="PLAYING CARD FIVE OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C5,
 },
 [0x1F0C6]={
  category="so",
  description="PLAYING CARD SIX OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C6,
 },
 [0x1F0C7]={
  category="so",
  description="PLAYING CARD SEVEN OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C7,
 },
 [0x1F0C8]={
  category="so",
  description="PLAYING CARD EIGHT OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C8,
 },
 [0x1F0C9]={
  category="so",
  description="PLAYING CARD NINE OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0C9,
 },
 [0x1F0CA]={
  category="so",
  description="PLAYING CARD TEN OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0CA,
 },
 [0x1F0CB]={
  category="so",
  description="PLAYING CARD JACK OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0CB,
 },
 [0x1F0CC]={
  category="so",
  description="PLAYING CARD KNIGHT OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0CC,
 },
 [0x1F0CD]={
  category="so",
  description="PLAYING CARD QUEEN OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0CD,
 },
 [0x1F0CE]={
  category="so",
  description="PLAYING CARD KING OF DIAMONDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0CE,
 },
 [0x1F0CF]={
  category="so",
  description="PLAYING CARD BLACK JOKER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0CF,
 },
 [0x1F0D1]={
  category="so",
  description="PLAYING CARD ACE OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D1,
 },
 [0x1F0D2]={
  category="so",
  description="PLAYING CARD TWO OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D2,
 },
 [0x1F0D3]={
  category="so",
  description="PLAYING CARD THREE OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D3,
 },
 [0x1F0D4]={
  category="so",
  description="PLAYING CARD FOUR OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D4,
 },
 [0x1F0D5]={
  category="so",
  description="PLAYING CARD FIVE OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D5,
 },
 [0x1F0D6]={
  category="so",
  description="PLAYING CARD SIX OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D6,
 },
 [0x1F0D7]={
  category="so",
  description="PLAYING CARD SEVEN OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D7,
 },
 [0x1F0D8]={
  category="so",
  description="PLAYING CARD EIGHT OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D8,
 },
 [0x1F0D9]={
  category="so",
  description="PLAYING CARD NINE OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0D9,
 },
 [0x1F0DA]={
  category="so",
  description="PLAYING CARD TEN OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0DA,
 },
 [0x1F0DB]={
  category="so",
  description="PLAYING CARD JACK OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0DB,
 },
 [0x1F0DC]={
  category="so",
  description="PLAYING CARD KNIGHT OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0DC,
 },
 [0x1F0DD]={
  category="so",
  description="PLAYING CARD QUEEN OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0DD,
 },
 [0x1F0DE]={
  category="so",
  description="PLAYING CARD KING OF CLUBS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0DE,
 },
 [0x1F0DF]={
  category="so",
  description="PLAYING CARD WHITE JOKER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F0DF,
 },
 [0x1F100]={
  category="no",
  cjkwd="a",
  description="DIGIT ZERO FULL STOP",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0030, 0x002E },
  unicodeslot=0x1F100,
 },
 [0x1F101]={
  category="no",
  cjkwd="a",
  description="DIGIT ZERO COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0030, 0x002C },
  unicodeslot=0x1F101,
 },
 [0x1F102]={
  category="no",
  cjkwd="a",
  description="DIGIT ONE COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0031, 0x002C },
  unicodeslot=0x1F102,
 },
 [0x1F103]={
  category="no",
  cjkwd="a",
  description="DIGIT TWO COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0032, 0x002C },
  unicodeslot=0x1F103,
 },
 [0x1F104]={
  category="no",
  cjkwd="a",
  description="DIGIT THREE COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0033, 0x002C },
  unicodeslot=0x1F104,
 },
 [0x1F105]={
  category="no",
  cjkwd="a",
  description="DIGIT FOUR COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0034, 0x002C },
  unicodeslot=0x1F105,
 },
 [0x1F106]={
  category="no",
  cjkwd="a",
  description="DIGIT FIVE COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0035, 0x002C },
  unicodeslot=0x1F106,
 },
 [0x1F107]={
  category="no",
  cjkwd="a",
  description="DIGIT SIX COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0036, 0x002C },
  unicodeslot=0x1F107,
 },
 [0x1F108]={
  category="no",
  cjkwd="a",
  description="DIGIT SEVEN COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0037, 0x002C },
  unicodeslot=0x1F108,
 },
 [0x1F109]={
  category="no",
  cjkwd="a",
  description="DIGIT EIGHT COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0038, 0x002C },
  unicodeslot=0x1F109,
 },
 [0x1F10A]={
  category="no",
  cjkwd="a",
  description="DIGIT NINE COMMA",
  direction="en",
  linebreak="ai",
  specials={ "compat", 0x0039, 0x002C },
  unicodeslot=0x1F10A,
 },
 [0x1F110]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER A",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0041, 0x0029 },
  unicodeslot=0x1F110,
 },
 [0x1F111]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER B",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0042, 0x0029 },
  unicodeslot=0x1F111,
 },
 [0x1F112]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER C",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0043, 0x0029 },
  unicodeslot=0x1F112,
 },
 [0x1F113]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER D",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0044, 0x0029 },
  unicodeslot=0x1F113,
 },
 [0x1F114]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER E",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0045, 0x0029 },
  unicodeslot=0x1F114,
 },
 [0x1F115]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER F",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0046, 0x0029 },
  unicodeslot=0x1F115,
 },
 [0x1F116]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER G",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0047, 0x0029 },
  unicodeslot=0x1F116,
 },
 [0x1F117]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER H",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0048, 0x0029 },
  unicodeslot=0x1F117,
 },
 [0x1F118]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER I",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0049, 0x0029 },
  unicodeslot=0x1F118,
 },
 [0x1F119]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER J",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x004A, 0x0029 },
  unicodeslot=0x1F119,
 },
 [0x1F11A]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER K",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x004B, 0x0029 },
  unicodeslot=0x1F11A,
 },
 [0x1F11B]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER L",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x004C, 0x0029 },
  unicodeslot=0x1F11B,
 },
 [0x1F11C]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER M",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x004D, 0x0029 },
  unicodeslot=0x1F11C,
 },
 [0x1F11D]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER N",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x004E, 0x0029 },
  unicodeslot=0x1F11D,
 },
 [0x1F11E]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER O",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x004F, 0x0029 },
  unicodeslot=0x1F11E,
 },
 [0x1F11F]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER P",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0050, 0x0029 },
  unicodeslot=0x1F11F,
 },
 [0x1F120]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER Q",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0051, 0x0029 },
  unicodeslot=0x1F120,
 },
 [0x1F121]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER R",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0052, 0x0029 },
  unicodeslot=0x1F121,
 },
 [0x1F122]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER S",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0053, 0x0029 },
  unicodeslot=0x1F122,
 },
 [0x1F123]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER T",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0054, 0x0029 },
  unicodeslot=0x1F123,
 },
 [0x1F124]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER U",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0055, 0x0029 },
  unicodeslot=0x1F124,
 },
 [0x1F125]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER V",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0056, 0x0029 },
  unicodeslot=0x1F125,
 },
 [0x1F126]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER W",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0057, 0x0029 },
  unicodeslot=0x1F126,
 },
 [0x1F127]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER X",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0058, 0x0029 },
  unicodeslot=0x1F127,
 },
 [0x1F128]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER Y",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x0059, 0x0029 },
  unicodeslot=0x1F128,
 },
 [0x1F129]={
  category="so",
  cjkwd="a",
  description="PARENTHESIZED LATIN CAPITAL LETTER Z",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x0028, 0x005A, 0x0029 },
  unicodeslot=0x1F129,
 },
 [0x1F12A]={
  category="so",
  cjkwd="a",
  description="TORTOISE SHELL BRACKETED LATIN CAPITAL LETTER S",
  direction="l",
  linebreak="ai",
  specials={ "compat", 0x3014, 0x0053, 0x3015 },
  unicodeslot=0x1F12A,
 },
 [0x1F12B]={
  category="so",
  cjkwd="a",
  description="CIRCLED ITALIC LATIN CAPITAL LETTER C",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0043 },
  unicodeslot=0x1F12B,
 },
 [0x1F12C]={
  category="so",
  cjkwd="a",
  description="CIRCLED ITALIC LATIN CAPITAL LETTER R",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0052 },
  unicodeslot=0x1F12C,
 },
 [0x1F12D]={
  category="so",
  cjkwd="a",
  description="CIRCLED CD",
  direction="l",
  linebreak="ai",
  specials={ "circle", 0x0043, 0x0044 },
  unicodeslot=0x1F12D,
 },
 [0x1F12E]={
  category="so",
  description="CIRCLED WZ",
  direction="l",
  linebreak="al",
  specials={ "circle", 0x0057, 0x005A },
  unicodeslot=0x1F12E,
 },
 [0x1F130]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER A",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0041 },
  unicodeslot=0x1F130,
 },
 [0x1F131]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER B",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0042 },
  unicodeslot=0x1F131,
 },
 [0x1F132]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER C",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0043 },
  unicodeslot=0x1F132,
 },
 [0x1F133]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER D",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0044 },
  unicodeslot=0x1F133,
 },
 [0x1F134]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER E",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0045 },
  unicodeslot=0x1F134,
 },
 [0x1F135]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER F",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0046 },
  unicodeslot=0x1F135,
 },
 [0x1F136]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER G",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0047 },
  unicodeslot=0x1F136,
 },
 [0x1F137]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER H",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0048 },
  unicodeslot=0x1F137,
 },
 [0x1F138]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER I",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0049 },
  unicodeslot=0x1F138,
 },
 [0x1F139]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER J",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x004A },
  unicodeslot=0x1F139,
 },
 [0x1F13A]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER K",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x004B },
  unicodeslot=0x1F13A,
 },
 [0x1F13B]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER L",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x004C },
  unicodeslot=0x1F13B,
 },
 [0x1F13C]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER M",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x004D },
  unicodeslot=0x1F13C,
 },
 [0x1F13D]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER N",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x004E },
  unicodeslot=0x1F13D,
 },
 [0x1F13E]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER O",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x004F },
  unicodeslot=0x1F13E,
 },
 [0x1F13F]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER P",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0050 },
  unicodeslot=0x1F13F,
 },
 [0x1F140]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER Q",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0051 },
  unicodeslot=0x1F140,
 },
 [0x1F141]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER R",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0052 },
  unicodeslot=0x1F141,
 },
 [0x1F142]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER S",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0053 },
  unicodeslot=0x1F142,
 },
 [0x1F143]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER T",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0054 },
  unicodeslot=0x1F143,
 },
 [0x1F144]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER U",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0055 },
  unicodeslot=0x1F144,
 },
 [0x1F145]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER V",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0056 },
  unicodeslot=0x1F145,
 },
 [0x1F146]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER W",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0057 },
  unicodeslot=0x1F146,
 },
 [0x1F147]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER X",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0058 },
  unicodeslot=0x1F147,
 },
 [0x1F148]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER Y",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0059 },
  unicodeslot=0x1F148,
 },
 [0x1F149]={
  category="so",
  cjkwd="a",
  description="SQUARED LATIN CAPITAL LETTER Z",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x005A },
  unicodeslot=0x1F149,
 },
 [0x1F14A]={
  category="so",
  cjkwd="a",
  description="SQUARED HV",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0048, 0x0056 },
  unicodeslot=0x1F14A,
 },
 [0x1F14B]={
  category="so",
  cjkwd="a",
  description="SQUARED MV",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x004D, 0x0056 },
  unicodeslot=0x1F14B,
 },
 [0x1F14C]={
  category="so",
  cjkwd="a",
  description="SQUARED SD",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0053, 0x0044 },
  unicodeslot=0x1F14C,
 },
 [0x1F14D]={
  category="so",
  cjkwd="a",
  description="SQUARED SS",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0053, 0x0053 },
  unicodeslot=0x1F14D,
 },
 [0x1F14E]={
  category="so",
  cjkwd="a",
  description="SQUARED PPV",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0050, 0x0050, 0x0056 },
  unicodeslot=0x1F14E,
 },
 [0x1F14F]={
  category="so",
  cjkwd="a",
  description="SQUARED WC",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0057, 0x0043 },
  unicodeslot=0x1F14F,
 },
 [0x1F150]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER A",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F150,
 },
 [0x1F151]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER B",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F151,
 },
 [0x1F152]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER C",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F152,
 },
 [0x1F153]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER D",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F153,
 },
 [0x1F154]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER E",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F154,
 },
 [0x1F155]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER F",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F155,
 },
 [0x1F156]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER G",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F156,
 },
 [0x1F157]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER H",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F157,
 },
 [0x1F158]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER I",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F158,
 },
 [0x1F159]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER J",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F159,
 },
 [0x1F15A]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER K",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F15A,
 },
 [0x1F15B]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER L",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F15B,
 },
 [0x1F15C]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER M",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F15C,
 },
 [0x1F15D]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER N",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F15D,
 },
 [0x1F15E]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER O",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F15E,
 },
 [0x1F15F]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER P",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F15F,
 },
 [0x1F160]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER Q",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F160,
 },
 [0x1F161]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER R",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F161,
 },
 [0x1F162]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER S",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F162,
 },
 [0x1F163]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER T",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F163,
 },
 [0x1F164]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER U",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F164,
 },
 [0x1F165]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER V",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F165,
 },
 [0x1F166]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER W",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F166,
 },
 [0x1F167]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER X",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F167,
 },
 [0x1F168]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER Y",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F168,
 },
 [0x1F169]={
  category="so",
  cjkwd="a",
  description="NEGATIVE CIRCLED LATIN CAPITAL LETTER Z",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F169,
 },
 [0x1F16A]={
  category="so",
  description="RAISED MC SIGN",
  direction="on",
  linebreak="al",
  specials={ "super", 0x004D, 0x0043 },
  unicodeslot=0x1F16A,
 },
 [0x1F16B]={
  category="so",
  description="RAISED MD SIGN",
  direction="on",
  linebreak="al",
  specials={ "super", 0x004D, 0x0044 },
  unicodeslot=0x1F16B,
 },
 [0x1F170]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER A",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F170,
 },
 [0x1F171]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER B",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F171,
 },
 [0x1F172]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER C",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F172,
 },
 [0x1F173]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER D",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F173,
 },
 [0x1F174]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER E",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F174,
 },
 [0x1F175]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER F",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F175,
 },
 [0x1F176]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER G",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F176,
 },
 [0x1F177]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER H",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F177,
 },
 [0x1F178]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER I",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F178,
 },
 [0x1F179]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER J",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F179,
 },
 [0x1F17A]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER K",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F17A,
 },
 [0x1F17B]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER L",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F17B,
 },
 [0x1F17C]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER M",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F17C,
 },
 [0x1F17D]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER N",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F17D,
 },
 [0x1F17E]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER O",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F17E,
 },
 [0x1F17F]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER P",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F17F,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x1F180]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER Q",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F180,
 },
 [0x1F181]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER R",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F181,
 },
 [0x1F182]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER S",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F182,
 },
 [0x1F183]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER T",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F183,
 },
 [0x1F184]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER U",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F184,
 },
 [0x1F185]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER V",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F185,
 },
 [0x1F186]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER W",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F186,
 },
 [0x1F187]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER X",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F187,
 },
 [0x1F188]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER Y",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F188,
 },
 [0x1F189]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED LATIN CAPITAL LETTER Z",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F189,
 },
 [0x1F18A]={
  category="so",
  cjkwd="a",
  description="CROSSED NEGATIVE SQUARED LATIN CAPITAL LETTER P",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F18A,
 },
 [0x1F18B]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED IC",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F18B,
 },
 [0x1F18C]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED PA",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F18C,
 },
 [0x1F18D]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED SA",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F18D,
 },
 [0x1F18E]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED AB",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F18E,
 },
 [0x1F18F]={
  category="so",
  cjkwd="a",
  description="NEGATIVE SQUARED WC",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F18F,
 },
 [0x1F190]={
  category="so",
  cjkwd="a",
  description="SQUARE DJ",
  direction="l",
  linebreak="ai",
  specials={ "square", 0x0044, 0x004A },
  unicodeslot=0x1F190,
 },
 [0x1F191]={
  category="so",
  cjkwd="a",
  description="SQUARED CL",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F191,
 },
 [0x1F192]={
  category="so",
  cjkwd="a",
  description="SQUARED COOL",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F192,
 },
 [0x1F193]={
  category="so",
  cjkwd="a",
  description="SQUARED FREE",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F193,
 },
 [0x1F194]={
  category="so",
  cjkwd="a",
  description="SQUARED ID",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F194,
 },
 [0x1F195]={
  category="so",
  cjkwd="a",
  description="SQUARED NEW",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F195,
 },
 [0x1F196]={
  category="so",
  cjkwd="a",
  description="SQUARED NG",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F196,
 },
 [0x1F197]={
  category="so",
  cjkwd="a",
  description="SQUARED OK",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F197,
 },
 [0x1F198]={
  category="so",
  cjkwd="a",
  description="SQUARED SOS",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F198,
 },
 [0x1F199]={
  category="so",
  cjkwd="a",
  description="SQUARED UP WITH EXCLAMATION MARK",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F199,
 },
 [0x1F19A]={
  category="so",
  cjkwd="a",
  description="SQUARED VS",
  direction="l",
  linebreak="ai",
  unicodeslot=0x1F19A,
 },
 [0x1F1E6]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER A",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1E6,
 },
 [0x1F1E7]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER B",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1E7,
 },
 [0x1F1E8]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER C",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1E8,
 },
 [0x1F1E9]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER D",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1E9,
 },
 [0x1F1EA]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER E",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1EA,
 },
 [0x1F1EB]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER F",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1EB,
 },
 [0x1F1EC]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER G",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1EC,
 },
 [0x1F1ED]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER H",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1ED,
 },
 [0x1F1EE]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER I",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1EE,
 },
 [0x1F1EF]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER J",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1EF,
 },
 [0x1F1F0]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER K",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F0,
 },
 [0x1F1F1]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER L",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F1,
 },
 [0x1F1F2]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER M",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F2,
 },
 [0x1F1F3]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER N",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F3,
 },
 [0x1F1F4]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER O",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F4,
 },
 [0x1F1F5]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER P",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F5,
 },
 [0x1F1F6]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER Q",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F6,
 },
 [0x1F1F7]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER R",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F7,
 },
 [0x1F1F8]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER S",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F8,
 },
 [0x1F1F9]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER T",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1F9,
 },
 [0x1F1FA]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER U",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1FA,
 },
 [0x1F1FB]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER V",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1FB,
 },
 [0x1F1FC]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER W",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1FC,
 },
 [0x1F1FD]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER X",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1FD,
 },
 [0x1F1FE]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER Y",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1FE,
 },
 [0x1F1FF]={
  category="so",
  description="REGIONAL INDICATOR SYMBOL LETTER Z",
  direction="l",
  linebreak="ri",
  unicodeslot=0x1F1FF,
 },
 [0x1F200]={
  category="so",
  cjkwd="w",
  description="SQUARE HIRAGANA HOKA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x307B, 0x304B },
  unicodeslot=0x1F200,
 },
 [0x1F201]={
  category="so",
  cjkwd="w",
  description="SQUARED KATAKANA KOKO",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B3, 0x30B3 },
  unicodeslot=0x1F201,
 },
 [0x1F202]={
  category="so",
  cjkwd="w",
  description="SQUARED KATAKANA SA",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30B5 },
  unicodeslot=0x1F202,
 },
 [0x1F210]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-624B",
  direction="l",
  linebreak="id",
  specials={ "square", 0x624B },
  unicodeslot=0x1F210,
 },
 [0x1F211]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-5B57",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5B57 },
  unicodeslot=0x1F211,
 },
 [0x1F212]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-53CC",
  direction="l",
  linebreak="id",
  specials={ "square", 0x53CC },
  unicodeslot=0x1F212,
 },
 [0x1F213]={
  category="so",
  cjkwd="w",
  description="SQUARED KATAKANA DE",
  direction="l",
  linebreak="id",
  specials={ "square", 0x30C7 },
  unicodeslot=0x1F213,
 },
 [0x1F214]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-4E8C",
  direction="l",
  linebreak="id",
  specials={ "square", 0x4E8C },
  unicodeslot=0x1F214,
 },
 [0x1F215]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-591A",
  direction="l",
  linebreak="id",
  specials={ "square", 0x591A },
  unicodeslot=0x1F215,
 },
 [0x1F216]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-89E3",
  direction="l",
  linebreak="id",
  specials={ "square", 0x89E3 },
  unicodeslot=0x1F216,
 },
 [0x1F217]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-5929",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5929 },
  unicodeslot=0x1F217,
 },
 [0x1F218]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-4EA4",
  direction="l",
  linebreak="id",
  specials={ "square", 0x4EA4 },
  unicodeslot=0x1F218,
 },
 [0x1F219]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6620",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6620 },
  unicodeslot=0x1F219,
 },
 [0x1F21A]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-7121",
  direction="l",
  linebreak="id",
  specials={ "square", 0x7121 },
  unicodeslot=0x1F21A,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x1F21B]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6599",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6599 },
  unicodeslot=0x1F21B,
 },
 [0x1F21C]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-524D",
  direction="l",
  linebreak="id",
  specials={ "square", 0x524D },
  unicodeslot=0x1F21C,
 },
 [0x1F21D]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-5F8C",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5F8C },
  unicodeslot=0x1F21D,
 },
 [0x1F21E]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-518D",
  direction="l",
  linebreak="id",
  specials={ "square", 0x518D },
  unicodeslot=0x1F21E,
 },
 [0x1F21F]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-65B0",
  direction="l",
  linebreak="id",
  specials={ "square", 0x65B0 },
  unicodeslot=0x1F21F,
 },
 [0x1F220]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-521D",
  direction="l",
  linebreak="id",
  specials={ "square", 0x521D },
  unicodeslot=0x1F220,
 },
 [0x1F221]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-7D42",
  direction="l",
  linebreak="id",
  specials={ "square", 0x7D42 },
  unicodeslot=0x1F221,
 },
 [0x1F222]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-751F",
  direction="l",
  linebreak="id",
  specials={ "square", 0x751F },
  unicodeslot=0x1F222,
 },
 [0x1F223]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-8CA9",
  direction="l",
  linebreak="id",
  specials={ "square", 0x8CA9 },
  unicodeslot=0x1F223,
 },
 [0x1F224]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-58F0",
  direction="l",
  linebreak="id",
  specials={ "square", 0x58F0 },
  unicodeslot=0x1F224,
 },
 [0x1F225]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-5439",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5439 },
  unicodeslot=0x1F225,
 },
 [0x1F226]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6F14",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6F14 },
  unicodeslot=0x1F226,
 },
 [0x1F227]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6295",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6295 },
  unicodeslot=0x1F227,
 },
 [0x1F228]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6355",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6355 },
  unicodeslot=0x1F228,
 },
 [0x1F229]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-4E00",
  direction="l",
  linebreak="id",
  specials={ "square", 0x4E00 },
  unicodeslot=0x1F229,
 },
 [0x1F22A]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-4E09",
  direction="l",
  linebreak="id",
  specials={ "square", 0x4E09 },
  unicodeslot=0x1F22A,
 },
 [0x1F22B]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-904A",
  direction="l",
  linebreak="id",
  specials={ "square", 0x904A },
  unicodeslot=0x1F22B,
 },
 [0x1F22C]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-5DE6",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5DE6 },
  unicodeslot=0x1F22C,
 },
 [0x1F22D]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-4E2D",
  direction="l",
  linebreak="id",
  specials={ "square", 0x4E2D },
  unicodeslot=0x1F22D,
 },
 [0x1F22E]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-53F3",
  direction="l",
  linebreak="id",
  specials={ "square", 0x53F3 },
  unicodeslot=0x1F22E,
 },
 [0x1F22F]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6307",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6307 },
  unicodeslot=0x1F22F,
  variants={
   [0xFE0E]="text style",
   [0xFE0F]="emoji style",
  },
 },
 [0x1F230]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-8D70",
  direction="l",
  linebreak="id",
  specials={ "square", 0x8D70 },
  unicodeslot=0x1F230,
 },
 [0x1F231]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6253",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6253 },
  unicodeslot=0x1F231,
 },
 [0x1F232]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-7981",
  direction="l",
  linebreak="id",
  specials={ "square", 0x7981 },
  unicodeslot=0x1F232,
 },
 [0x1F233]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-7A7A",
  direction="l",
  linebreak="id",
  specials={ "square", 0x7A7A },
  unicodeslot=0x1F233,
 },
 [0x1F234]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-5408",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5408 },
  unicodeslot=0x1F234,
 },
 [0x1F235]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6E80",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6E80 },
  unicodeslot=0x1F235,
 },
 [0x1F236]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6709",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6709 },
  unicodeslot=0x1F236,
 },
 [0x1F237]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-6708",
  direction="l",
  linebreak="id",
  specials={ "square", 0x6708 },
  unicodeslot=0x1F237,
 },
 [0x1F238]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-7533",
  direction="l",
  linebreak="id",
  specials={ "square", 0x7533 },
  unicodeslot=0x1F238,
 },
 [0x1F239]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-5272",
  direction="l",
  linebreak="id",
  specials={ "square", 0x5272 },
  unicodeslot=0x1F239,
 },
 [0x1F23A]={
  category="so",
  cjkwd="w",
  description="SQUARED CJK UNIFIED IDEOGRAPH-55B6",
  direction="l",
  linebreak="id",
  specials={ "square", 0x55B6 },
  unicodeslot=0x1F23A,
 },
 [0x1F240]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-672C",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x672C, 0x3015 },
  unicodeslot=0x1F240,
 },
 [0x1F241]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E09",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x4E09, 0x3015 },
  unicodeslot=0x1F241,
 },
 [0x1F242]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E8C",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x4E8C, 0x3015 },
  unicodeslot=0x1F242,
 },
 [0x1F243]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-5B89",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x5B89, 0x3015 },
  unicodeslot=0x1F243,
 },
 [0x1F244]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-70B9",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x70B9, 0x3015 },
  unicodeslot=0x1F244,
 },
 [0x1F245]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6253",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x6253, 0x3015 },
  unicodeslot=0x1F245,
 },
 [0x1F246]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-76D7",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x76D7, 0x3015 },
  unicodeslot=0x1F246,
 },
 [0x1F247]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-52DD",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x52DD, 0x3015 },
  unicodeslot=0x1F247,
 },
 [0x1F248]={
  category="so",
  cjkwd="w",
  description="TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6557",
  direction="l",
  linebreak="id",
  specials={ "compat", 0x3014, 0x6557, 0x3015 },
  unicodeslot=0x1F248,
 },
 [0x1F250]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH ADVANTAGE",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x5F97 },
  unicodeslot=0x1F250,
 },
 [0x1F251]={
  category="so",
  cjkwd="w",
  description="CIRCLED IDEOGRAPH ACCEPT",
  direction="l",
  linebreak="id",
  specials={ "circle", 0x53EF },
  unicodeslot=0x1F251,
 },
 [0x1F300]={
  category="so",
  description="CYCLONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F300,
 },
 [0x1F301]={
  category="so",
  description="FOGGY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F301,
 },
 [0x1F302]={
  category="so",
  description="CLOSED UMBRELLA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F302,
 },
 [0x1F303]={
  category="so",
  description="NIGHT WITH STARS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F303,
 },
 [0x1F304]={
  category="so",
  description="SUNRISE OVER MOUNTAINS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F304,
 },
 [0x1F305]={
  category="so",
  description="SUNRISE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F305,
 },
 [0x1F306]={
  category="so",
  description="CITYSCAPE AT DUSK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F306,
 },
 [0x1F307]={
  category="so",
  description="SUNSET OVER BUILDINGS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F307,
 },
 [0x1F308]={
  category="so",
  description="RAINBOW",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F308,
 },
 [0x1F309]={
  category="so",
  description="BRIDGE AT NIGHT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F309,
 },
 [0x1F30A]={
  category="so",
  description="WATER WAVE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F30A,
 },
 [0x1F30B]={
  category="so",
  description="VOLCANO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F30B,
 },
 [0x1F30C]={
  category="so",
  description="MILKY WAY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F30C,
 },
 [0x1F30D]={
  category="so",
  description="EARTH GLOBE EUROPE-AFRICA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F30D,
 },
 [0x1F30E]={
  category="so",
  description="EARTH GLOBE AMERICAS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F30E,
 },
 [0x1F30F]={
  category="so",
  description="EARTH GLOBE ASIA-AUSTRALIA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F30F,
 },
 [0x1F310]={
  category="so",
  description="GLOBE WITH MERIDIANS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F310,
 },
 [0x1F311]={
  category="so",
  description="NEW MOON SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F311,
 },
 [0x1F312]={
  category="so",
  description="WAXING CRESCENT MOON SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F312,
 },
 [0x1F313]={
  category="so",
  description="FIRST QUARTER MOON SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F313,
 },
 [0x1F314]={
  category="so",
  description="WAXING GIBBOUS MOON SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F314,
 },
 [0x1F315]={
  category="so",
  description="FULL MOON SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F315,
 },
 [0x1F316]={
  category="so",
  description="WANING GIBBOUS MOON SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F316,
 },
 [0x1F317]={
  category="so",
  description="LAST QUARTER MOON SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F317,
 },
 [0x1F318]={
  category="so",
  description="WANING CRESCENT MOON SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F318,
 },
 [0x1F319]={
  category="so",
  description="CRESCENT MOON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F319,
 },
 [0x1F31A]={
  category="so",
  description="NEW MOON WITH FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F31A,
 },
 [0x1F31B]={
  category="so",
  description="FIRST QUARTER MOON WITH FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F31B,
 },
 [0x1F31C]={
  category="so",
  description="LAST QUARTER MOON WITH FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F31C,
 },
 [0x1F31D]={
  category="so",
  description="FULL MOON WITH FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F31D,
 },
 [0x1F31E]={
  category="so",
  description="SUN WITH FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F31E,
 },
 [0x1F31F]={
  category="so",
  description="GLOWING STAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F31F,
 },
 [0x1F320]={
  category="so",
  description="SHOOTING STAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F320,
 },
 [0x1F330]={
  category="so",
  description="CHESTNUT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F330,
 },
 [0x1F331]={
  category="so",
  description="SEEDLING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F331,
 },
 [0x1F332]={
  category="so",
  description="EVERGREEN TREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F332,
 },
 [0x1F333]={
  category="so",
  description="DECIDUOUS TREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F333,
 },
 [0x1F334]={
  category="so",
  description="PALM TREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F334,
 },
 [0x1F335]={
  category="so",
  description="CACTUS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F335,
 },
 [0x1F337]={
  category="so",
  description="TULIP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F337,
 },
 [0x1F338]={
  category="so",
  description="CHERRY BLOSSOM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F338,
 },
 [0x1F339]={
  category="so",
  description="ROSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F339,
 },
 [0x1F33A]={
  category="so",
  description="HIBISCUS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F33A,
 },
 [0x1F33B]={
  category="so",
  description="SUNFLOWER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F33B,
 },
 [0x1F33C]={
  category="so",
  description="BLOSSOM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F33C,
 },
 [0x1F33D]={
  category="so",
  description="EAR OF MAIZE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F33D,
 },
 [0x1F33E]={
  category="so",
  description="EAR OF RICE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F33E,
 },
 [0x1F33F]={
  category="so",
  description="HERB",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F33F,
 },
 [0x1F340]={
  category="so",
  description="FOUR LEAF CLOVER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F340,
 },
 [0x1F341]={
  category="so",
  description="MAPLE LEAF",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F341,
 },
 [0x1F342]={
  category="so",
  description="FALLEN LEAF",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F342,
 },
 [0x1F343]={
  category="so",
  description="LEAF FLUTTERING IN WIND",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F343,
 },
 [0x1F344]={
  category="so",
  description="MUSHROOM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F344,
 },
 [0x1F345]={
  category="so",
  description="TOMATO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F345,
 },
 [0x1F346]={
  category="so",
  description="AUBERGINE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F346,
 },
 [0x1F347]={
  category="so",
  description="GRAPES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F347,
 },
 [0x1F348]={
  category="so",
  description="MELON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F348,
 },
 [0x1F349]={
  category="so",
  description="WATERMELON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F349,
 },
 [0x1F34A]={
  category="so",
  description="TANGERINE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F34A,
 },
 [0x1F34B]={
  category="so",
  description="LEMON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F34B,
 },
 [0x1F34C]={
  category="so",
  description="BANANA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F34C,
 },
 [0x1F34D]={
  category="so",
  description="PINEAPPLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F34D,
 },
 [0x1F34E]={
  category="so",
  description="RED APPLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F34E,
 },
 [0x1F34F]={
  category="so",
  description="GREEN APPLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F34F,
 },
 [0x1F350]={
  category="so",
  description="PEAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F350,
 },
 [0x1F351]={
  category="so",
  description="PEACH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F351,
 },
 [0x1F352]={
  category="so",
  description="CHERRIES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F352,
 },
 [0x1F353]={
  category="so",
  description="STRAWBERRY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F353,
 },
 [0x1F354]={
  category="so",
  description="HAMBURGER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F354,
 },
 [0x1F355]={
  category="so",
  description="SLICE OF PIZZA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F355,
 },
 [0x1F356]={
  category="so",
  description="MEAT ON BONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F356,
 },
 [0x1F357]={
  category="so",
  description="POULTRY LEG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F357,
 },
 [0x1F358]={
  category="so",
  description="RICE CRACKER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F358,
 },
 [0x1F359]={
  category="so",
  description="RICE BALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F359,
 },
 [0x1F35A]={
  category="so",
  description="COOKED RICE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F35A,
 },
 [0x1F35B]={
  category="so",
  description="CURRY AND RICE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F35B,
 },
 [0x1F35C]={
  category="so",
  description="STEAMING BOWL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F35C,
 },
 [0x1F35D]={
  category="so",
  description="SPAGHETTI",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F35D,
 },
 [0x1F35E]={
  category="so",
  description="BREAD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F35E,
 },
 [0x1F35F]={
  category="so",
  description="FRENCH FRIES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F35F,
 },
 [0x1F360]={
  category="so",
  description="ROASTED SWEET POTATO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F360,
 },
 [0x1F361]={
  category="so",
  description="DANGO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F361,
 },
 [0x1F362]={
  category="so",
  description="ODEN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F362,
 },
 [0x1F363]={
  category="so",
  description="SUSHI",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F363,
 },
 [0x1F364]={
  category="so",
  description="FRIED SHRIMP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F364,
 },
 [0x1F365]={
  category="so",
  description="FISH CAKE WITH SWIRL DESIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F365,
 },
 [0x1F366]={
  category="so",
  description="SOFT ICE CREAM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F366,
 },
 [0x1F367]={
  category="so",
  description="SHAVED ICE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F367,
 },
 [0x1F368]={
  category="so",
  description="ICE CREAM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F368,
 },
 [0x1F369]={
  category="so",
  description="DOUGHNUT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F369,
 },
 [0x1F36A]={
  category="so",
  description="COOKIE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F36A,
 },
 [0x1F36B]={
  category="so",
  description="CHOCOLATE BAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F36B,
 },
 [0x1F36C]={
  category="so",
  description="CANDY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F36C,
 },
 [0x1F36D]={
  category="so",
  description="LOLLIPOP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F36D,
 },
 [0x1F36E]={
  category="so",
  description="CUSTARD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F36E,
 },
 [0x1F36F]={
  category="so",
  description="HONEY POT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F36F,
 },
 [0x1F370]={
  category="so",
  description="SHORTCAKE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F370,
 },
 [0x1F371]={
  category="so",
  description="BENTO BOX",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F371,
 },
 [0x1F372]={
  category="so",
  description="POT OF FOOD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F372,
 },
 [0x1F373]={
  category="so",
  description="COOKING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F373,
 },
 [0x1F374]={
  category="so",
  description="FORK AND KNIFE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F374,
 },
 [0x1F375]={
  category="so",
  description="TEACUP WITHOUT HANDLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F375,
 },
 [0x1F376]={
  category="so",
  description="SAKE BOTTLE AND CUP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F376,
 },
 [0x1F377]={
  category="so",
  description="WINE GLASS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F377,
 },
 [0x1F378]={
  category="so",
  description="COCKTAIL GLASS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F378,
 },
 [0x1F379]={
  category="so",
  description="TROPICAL DRINK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F379,
 },
 [0x1F37A]={
  category="so",
  description="BEER MUG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F37A,
 },
 [0x1F37B]={
  category="so",
  description="CLINKING BEER MUGS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F37B,
 },
 [0x1F37C]={
  category="so",
  description="BABY BOTTLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F37C,
 },
 [0x1F380]={
  category="so",
  description="RIBBON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F380,
 },
 [0x1F381]={
  category="so",
  description="WRAPPED PRESENT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F381,
 },
 [0x1F382]={
  category="so",
  description="BIRTHDAY CAKE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F382,
 },
 [0x1F383]={
  category="so",
  description="JACK-O-LANTERN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F383,
 },
 [0x1F384]={
  category="so",
  description="CHRISTMAS TREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F384,
 },
 [0x1F385]={
  category="so",
  description="FATHER CHRISTMAS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F385,
 },
 [0x1F386]={
  category="so",
  description="FIREWORKS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F386,
 },
 [0x1F387]={
  category="so",
  description="FIREWORK SPARKLER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F387,
 },
 [0x1F388]={
  category="so",
  description="BALLOON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F388,
 },
 [0x1F389]={
  category="so",
  description="PARTY POPPER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F389,
 },
 [0x1F38A]={
  category="so",
  description="CONFETTI BALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F38A,
 },
 [0x1F38B]={
  category="so",
  description="TANABATA TREE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F38B,
 },
 [0x1F38C]={
  category="so",
  description="CROSSED FLAGS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F38C,
 },
 [0x1F38D]={
  category="so",
  description="PINE DECORATION",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F38D,
 },
 [0x1F38E]={
  category="so",
  description="JAPANESE DOLLS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F38E,
 },
 [0x1F38F]={
  category="so",
  description="CARP STREAMER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F38F,
 },
 [0x1F390]={
  category="so",
  description="WIND CHIME",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F390,
 },
 [0x1F391]={
  category="so",
  description="MOON VIEWING CEREMONY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F391,
 },
 [0x1F392]={
  category="so",
  description="SCHOOL SATCHEL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F392,
 },
 [0x1F393]={
  category="so",
  description="GRADUATION CAP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F393,
 },
 [0x1F3A0]={
  category="so",
  description="CAROUSEL HORSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A0,
 },
 [0x1F3A1]={
  category="so",
  description="FERRIS WHEEL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A1,
 },
 [0x1F3A2]={
  category="so",
  description="ROLLER COASTER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A2,
 },
 [0x1F3A3]={
  category="so",
  description="FISHING POLE AND FISH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A3,
 },
 [0x1F3A4]={
  category="so",
  description="MICROPHONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A4,
 },
 [0x1F3A5]={
  category="so",
  description="MOVIE CAMERA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A5,
 },
 [0x1F3A6]={
  category="so",
  description="CINEMA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A6,
 },
 [0x1F3A7]={
  category="so",
  description="HEADPHONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A7,
 },
 [0x1F3A8]={
  category="so",
  description="ARTIST PALETTE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A8,
 },
 [0x1F3A9]={
  category="so",
  description="TOP HAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3A9,
 },
 [0x1F3AA]={
  category="so",
  description="CIRCUS TENT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3AA,
 },
 [0x1F3AB]={
  category="so",
  description="TICKET",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3AB,
 },
 [0x1F3AC]={
  category="so",
  description="CLAPPER BOARD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3AC,
 },
 [0x1F3AD]={
  category="so",
  description="PERFORMING ARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3AD,
 },
 [0x1F3AE]={
  category="so",
  description="VIDEO GAME",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3AE,
 },
 [0x1F3AF]={
  category="so",
  description="DIRECT HIT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3AF,
 },
 [0x1F3B0]={
  category="so",
  description="SLOT MACHINE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3B0,
 },
 [0x1F3B1]={
  category="so",
  description="BILLIARDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3B1,
 },
 [0x1F3B2]={
  category="so",
  description="GAME DIE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3B2,
 },
 [0x1F3B3]={
  category="so",
  description="BOWLING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3B3,
 },
 [0x1F3B4]={
  category="so",
  description="FLOWER PLAYING CARDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3B4,
 },
 [0x1F3B5]={
  category="so",
  description="MUSICAL NOTE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F3B5,
 },
 [0x1F3B6]={
  category="so",
  description="MULTIPLE MUSICAL NOTES",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F3B6,
 },
 [0x1F3B7]={
  category="so",
  description="SAXOPHONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3B7,
 },
 [0x1F3B8]={
  category="so",
  description="GUITAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3B8,
 },
 [0x1F3B9]={
  category="so",
  description="MUSICAL KEYBOARD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3B9,
 },
 [0x1F3BA]={
  category="so",
  description="TRUMPET",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3BA,
 },
 [0x1F3BB]={
  category="so",
  description="VIOLIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3BB,
 },
 [0x1F3BC]={
  category="so",
  description="MUSICAL SCORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F3BC,
 },
 [0x1F3BD]={
  category="so",
  description="RUNNING SHIRT WITH SASH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3BD,
 },
 [0x1F3BE]={
  category="so",
  description="TENNIS RACQUET AND BALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3BE,
 },
 [0x1F3BF]={
  category="so",
  description="SKI AND SKI BOOT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3BF,
 },
 [0x1F3C0]={
  category="so",
  description="BASKETBALL AND HOOP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C0,
 },
 [0x1F3C1]={
  category="so",
  description="CHEQUERED FLAG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C1,
 },
 [0x1F3C2]={
  category="so",
  description="SNOWBOARDER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C2,
 },
 [0x1F3C3]={
  category="so",
  description="RUNNER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C3,
 },
 [0x1F3C4]={
  category="so",
  description="SURFER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C4,
 },
 [0x1F3C6]={
  category="so",
  description="TROPHY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C6,
 },
 [0x1F3C7]={
  category="so",
  description="HORSE RACING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C7,
 },
 [0x1F3C8]={
  category="so",
  description="AMERICAN FOOTBALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C8,
 },
 [0x1F3C9]={
  category="so",
  description="RUGBY FOOTBALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3C9,
 },
 [0x1F3CA]={
  category="so",
  description="SWIMMER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3CA,
 },
 [0x1F3E0]={
  category="so",
  description="HOUSE BUILDING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E0,
 },
 [0x1F3E1]={
  category="so",
  description="HOUSE WITH GARDEN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E1,
 },
 [0x1F3E2]={
  category="so",
  description="OFFICE BUILDING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E2,
 },
 [0x1F3E3]={
  category="so",
  description="JAPANESE POST OFFICE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E3,
 },
 [0x1F3E4]={
  category="so",
  description="EUROPEAN POST OFFICE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E4,
 },
 [0x1F3E5]={
  category="so",
  description="HOSPITAL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E5,
 },
 [0x1F3E6]={
  category="so",
  description="BANK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E6,
 },
 [0x1F3E7]={
  category="so",
  description="AUTOMATED TELLER MACHINE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E7,
 },
 [0x1F3E8]={
  category="so",
  description="HOTEL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E8,
 },
 [0x1F3E9]={
  category="so",
  description="LOVE HOTEL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3E9,
 },
 [0x1F3EA]={
  category="so",
  description="CONVENIENCE STORE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3EA,
 },
 [0x1F3EB]={
  category="so",
  description="SCHOOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3EB,
 },
 [0x1F3EC]={
  category="so",
  description="DEPARTMENT STORE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3EC,
 },
 [0x1F3ED]={
  category="so",
  description="FACTORY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3ED,
 },
 [0x1F3EE]={
  category="so",
  description="IZAKAYA LANTERN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3EE,
 },
 [0x1F3EF]={
  category="so",
  description="JAPANESE CASTLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3EF,
 },
 [0x1F3F0]={
  category="so",
  description="EUROPEAN CASTLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F3F0,
 },
 [0x1F400]={
  category="so",
  description="RAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F400,
 },
 [0x1F401]={
  category="so",
  description="MOUSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F401,
 },
 [0x1F402]={
  category="so",
  description="OX",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F402,
 },
 [0x1F403]={
  category="so",
  description="WATER BUFFALO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F403,
 },
 [0x1F404]={
  category="so",
  description="COW",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F404,
 },
 [0x1F405]={
  category="so",
  description="TIGER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F405,
 },
 [0x1F406]={
  category="so",
  description="LEOPARD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F406,
 },
 [0x1F407]={
  category="so",
  description="RABBIT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F407,
 },
 [0x1F408]={
  category="so",
  description="CAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F408,
 },
 [0x1F409]={
  category="so",
  description="DRAGON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F409,
 },
 [0x1F40A]={
  category="so",
  description="CROCODILE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F40A,
 },
 [0x1F40B]={
  category="so",
  description="WHALE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F40B,
 },
 [0x1F40C]={
  category="so",
  description="SNAIL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F40C,
 },
 [0x1F40D]={
  category="so",
  description="SNAKE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F40D,
 },
 [0x1F40E]={
  category="so",
  description="HORSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F40E,
 },
 [0x1F40F]={
  category="so",
  description="RAM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F40F,
 },
 [0x1F410]={
  category="so",
  description="GOAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F410,
 },
 [0x1F411]={
  category="so",
  description="SHEEP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F411,
 },
 [0x1F412]={
  category="so",
  description="MONKEY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F412,
 },
 [0x1F413]={
  category="so",
  description="ROOSTER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F413,
 },
 [0x1F414]={
  category="so",
  description="CHICKEN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F414,
 },
 [0x1F415]={
  category="so",
  description="DOG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F415,
 },
 [0x1F416]={
  category="so",
  description="PIG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F416,
 },
 [0x1F417]={
  category="so",
  description="BOAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F417,
 },
 [0x1F418]={
  category="so",
  description="ELEPHANT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F418,
 },
 [0x1F419]={
  category="so",
  description="OCTOPUS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F419,
 },
 [0x1F41A]={
  category="so",
  description="SPIRAL SHELL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F41A,
 },
 [0x1F41B]={
  category="so",
  description="BUG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F41B,
 },
 [0x1F41C]={
  category="so",
  description="ANT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F41C,
 },
 [0x1F41D]={
  category="so",
  description="HONEYBEE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F41D,
 },
 [0x1F41E]={
  category="so",
  description="LADY BEETLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F41E,
 },
 [0x1F41F]={
  category="so",
  description="FISH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F41F,
 },
 [0x1F420]={
  category="so",
  description="TROPICAL FISH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F420,
 },
 [0x1F421]={
  category="so",
  description="BLOWFISH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F421,
 },
 [0x1F422]={
  category="so",
  description="TURTLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F422,
 },
 [0x1F423]={
  category="so",
  description="HATCHING CHICK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F423,
 },
 [0x1F424]={
  category="so",
  description="BABY CHICK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F424,
 },
 [0x1F425]={
  category="so",
  description="FRONT-FACING BABY CHICK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F425,
 },
 [0x1F426]={
  category="so",
  description="BIRD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F426,
 },
 [0x1F427]={
  category="so",
  description="PENGUIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F427,
 },
 [0x1F428]={
  category="so",
  description="KOALA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F428,
 },
 [0x1F429]={
  category="so",
  description="POODLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F429,
 },
 [0x1F42A]={
  category="so",
  description="DROMEDARY CAMEL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F42A,
 },
 [0x1F42B]={
  category="so",
  description="BACTRIAN CAMEL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F42B,
 },
 [0x1F42C]={
  category="so",
  description="DOLPHIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F42C,
 },
 [0x1F42D]={
  category="so",
  description="MOUSE FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F42D,
 },
 [0x1F42E]={
  category="so",
  description="COW FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F42E,
 },
 [0x1F42F]={
  category="so",
  description="TIGER FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F42F,
 },
 [0x1F430]={
  category="so",
  description="RABBIT FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F430,
 },
 [0x1F431]={
  category="so",
  description="CAT FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F431,
 },
 [0x1F432]={
  category="so",
  description="DRAGON FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F432,
 },
 [0x1F433]={
  category="so",
  description="SPOUTING WHALE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F433,
 },
 [0x1F434]={
  category="so",
  description="HORSE FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F434,
 },
 [0x1F435]={
  category="so",
  description="MONKEY FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F435,
 },
 [0x1F436]={
  category="so",
  description="DOG FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F436,
 },
 [0x1F437]={
  category="so",
  description="PIG FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F437,
 },
 [0x1F438]={
  category="so",
  description="FROG FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F438,
 },
 [0x1F439]={
  category="so",
  description="HAMSTER FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F439,
 },
 [0x1F43A]={
  category="so",
  description="WOLF FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F43A,
 },
 [0x1F43B]={
  category="so",
  description="BEAR FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F43B,
 },
 [0x1F43C]={
  category="so",
  description="PANDA FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F43C,
 },
 [0x1F43D]={
  category="so",
  description="PIG NOSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F43D,
 },
 [0x1F43E]={
  category="so",
  description="PAW PRINTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F43E,
 },
 [0x1F440]={
  category="so",
  description="EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F440,
 },
 [0x1F442]={
  category="so",
  description="EAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F442,
 },
 [0x1F443]={
  category="so",
  description="NOSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F443,
 },
 [0x1F444]={
  category="so",
  description="MOUTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F444,
 },
 [0x1F445]={
  category="so",
  description="TONGUE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F445,
 },
 [0x1F446]={
  category="so",
  description="WHITE UP POINTING BACKHAND INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F446,
 },
 [0x1F447]={
  category="so",
  description="WHITE DOWN POINTING BACKHAND INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F447,
 },
 [0x1F448]={
  category="so",
  description="WHITE LEFT POINTING BACKHAND INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F448,
 },
 [0x1F449]={
  category="so",
  description="WHITE RIGHT POINTING BACKHAND INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F449,
 },
 [0x1F44A]={
  category="so",
  description="FISTED HAND SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F44A,
 },
 [0x1F44B]={
  category="so",
  description="WAVING HAND SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F44B,
 },
 [0x1F44C]={
  category="so",
  description="OK HAND SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F44C,
 },
 [0x1F44D]={
  category="so",
  description="THUMBS UP SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F44D,
 },
 [0x1F44E]={
  category="so",
  description="THUMBS DOWN SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F44E,
 },
 [0x1F44F]={
  category="so",
  description="CLAPPING HANDS SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F44F,
 },
 [0x1F450]={
  category="so",
  description="OPEN HANDS SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F450,
 },
 [0x1F451]={
  category="so",
  description="CROWN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F451,
 },
 [0x1F452]={
  category="so",
  description="WOMANS HAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F452,
 },
 [0x1F453]={
  category="so",
  description="EYEGLASSES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F453,
 },
 [0x1F454]={
  category="so",
  description="NECKTIE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F454,
 },
 [0x1F455]={
  category="so",
  description="T-SHIRT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F455,
 },
 [0x1F456]={
  category="so",
  description="JEANS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F456,
 },
 [0x1F457]={
  category="so",
  description="DRESS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F457,
 },
 [0x1F458]={
  category="so",
  description="KIMONO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F458,
 },
 [0x1F459]={
  category="so",
  description="BIKINI",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F459,
 },
 [0x1F45A]={
  category="so",
  description="WOMANS CLOTHES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F45A,
 },
 [0x1F45B]={
  category="so",
  description="PURSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F45B,
 },
 [0x1F45C]={
  category="so",
  description="HANDBAG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F45C,
 },
 [0x1F45D]={
  category="so",
  description="POUCH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F45D,
 },
 [0x1F45E]={
  category="so",
  description="MANS SHOE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F45E,
 },
 [0x1F45F]={
  category="so",
  description="ATHLETIC SHOE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F45F,
 },
 [0x1F460]={
  category="so",
  description="HIGH-HEELED SHOE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F460,
 },
 [0x1F461]={
  category="so",
  description="WOMANS SANDAL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F461,
 },
 [0x1F462]={
  category="so",
  description="WOMANS BOOTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F462,
 },
 [0x1F463]={
  category="so",
  description="FOOTPRINTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F463,
 },
 [0x1F464]={
  category="so",
  description="BUST IN SILHOUETTE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F464,
 },
 [0x1F465]={
  category="so",
  description="BUSTS IN SILHOUETTE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F465,
 },
 [0x1F466]={
  category="so",
  description="BOY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F466,
 },
 [0x1F467]={
  category="so",
  description="GIRL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F467,
 },
 [0x1F468]={
  category="so",
  description="MAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F468,
 },
 [0x1F469]={
  category="so",
  description="WOMAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F469,
 },
 [0x1F46A]={
  category="so",
  description="FAMILY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F46A,
 },
 [0x1F46B]={
  category="so",
  description="MAN AND WOMAN HOLDING HANDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F46B,
 },
 [0x1F46C]={
  category="so",
  description="TWO MEN HOLDING HANDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F46C,
 },
 [0x1F46D]={
  category="so",
  description="TWO WOMEN HOLDING HANDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F46D,
 },
 [0x1F46E]={
  category="so",
  description="POLICE OFFICER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F46E,
 },
 [0x1F46F]={
  category="so",
  description="WOMAN WITH BUNNY EARS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F46F,
 },
 [0x1F470]={
  category="so",
  description="BRIDE WITH VEIL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F470,
 },
 [0x1F471]={
  category="so",
  description="PERSON WITH BLOND HAIR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F471,
 },
 [0x1F472]={
  category="so",
  description="MAN WITH GUA PI MAO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F472,
 },
 [0x1F473]={
  category="so",
  description="MAN WITH TURBAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F473,
 },
 [0x1F474]={
  category="so",
  description="OLDER MAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F474,
 },
 [0x1F475]={
  category="so",
  description="OLDER WOMAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F475,
 },
 [0x1F476]={
  category="so",
  description="BABY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F476,
 },
 [0x1F477]={
  category="so",
  description="CONSTRUCTION WORKER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F477,
 },
 [0x1F478]={
  category="so",
  description="PRINCESS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F478,
 },
 [0x1F479]={
  category="so",
  description="JAPANESE OGRE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F479,
 },
 [0x1F47A]={
  category="so",
  description="JAPANESE GOBLIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F47A,
 },
 [0x1F47B]={
  category="so",
  description="GHOST",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F47B,
 },
 [0x1F47C]={
  category="so",
  description="BABY ANGEL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F47C,
 },
 [0x1F47D]={
  category="so",
  description="EXTRATERRESTRIAL ALIEN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F47D,
 },
 [0x1F47E]={
  category="so",
  description="ALIEN MONSTER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F47E,
 },
 [0x1F47F]={
  category="so",
  description="IMP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F47F,
 },
 [0x1F480]={
  category="so",
  description="SKULL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F480,
 },
 [0x1F481]={
  category="so",
  description="INFORMATION DESK PERSON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F481,
 },
 [0x1F482]={
  category="so",
  description="GUARDSMAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F482,
 },
 [0x1F483]={
  category="so",
  description="DANCER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F483,
 },
 [0x1F484]={
  category="so",
  description="LIPSTICK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F484,
 },
 [0x1F485]={
  category="so",
  description="NAIL POLISH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F485,
 },
 [0x1F486]={
  category="so",
  description="FACE MASSAGE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F486,
 },
 [0x1F487]={
  category="so",
  description="HAIRCUT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F487,
 },
 [0x1F488]={
  category="so",
  description="BARBER POLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F488,
 },
 [0x1F489]={
  category="so",
  description="SYRINGE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F489,
 },
 [0x1F48A]={
  category="so",
  description="PILL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F48A,
 },
 [0x1F48B]={
  category="so",
  description="KISS MARK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F48B,
 },
 [0x1F48C]={
  category="so",
  description="LOVE LETTER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F48C,
 },
 [0x1F48D]={
  category="so",
  description="RING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F48D,
 },
 [0x1F48E]={
  category="so",
  description="GEM STONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F48E,
 },
 [0x1F48F]={
  category="so",
  description="KISS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F48F,
 },
 [0x1F490]={
  category="so",
  description="BOUQUET",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F490,
 },
 [0x1F491]={
  category="so",
  description="COUPLE WITH HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F491,
 },
 [0x1F492]={
  category="so",
  description="WEDDING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F492,
 },
 [0x1F493]={
  category="so",
  description="BEATING HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F493,
 },
 [0x1F494]={
  category="so",
  description="BROKEN HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F494,
 },
 [0x1F495]={
  category="so",
  description="TWO HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F495,
 },
 [0x1F496]={
  category="so",
  description="SPARKLING HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F496,
 },
 [0x1F497]={
  category="so",
  description="GROWING HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F497,
 },
 [0x1F498]={
  category="so",
  description="HEART WITH ARROW",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F498,
 },
 [0x1F499]={
  category="so",
  description="BLUE HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F499,
 },
 [0x1F49A]={
  category="so",
  description="GREEN HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F49A,
 },
 [0x1F49B]={
  category="so",
  description="YELLOW HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F49B,
 },
 [0x1F49C]={
  category="so",
  description="PURPLE HEART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F49C,
 },
 [0x1F49D]={
  category="so",
  description="HEART WITH RIBBON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F49D,
 },
 [0x1F49E]={
  category="so",
  description="REVOLVING HEARTS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F49E,
 },
 [0x1F49F]={
  category="so",
  description="HEART DECORATION",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F49F,
 },
 [0x1F4A0]={
  category="so",
  description="DIAMOND SHAPE WITH A DOT INSIDE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F4A0,
 },
 [0x1F4A1]={
  category="so",
  description="ELECTRIC LIGHT BULB",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4A1,
 },
 [0x1F4A2]={
  category="so",
  description="ANGER SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F4A2,
 },
 [0x1F4A3]={
  category="so",
  description="BOMB",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4A3,
 },
 [0x1F4A4]={
  category="so",
  description="SLEEPING SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F4A4,
 },
 [0x1F4A5]={
  category="so",
  description="COLLISION SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4A5,
 },
 [0x1F4A6]={
  category="so",
  description="SPLASHING SWEAT SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4A6,
 },
 [0x1F4A7]={
  category="so",
  description="DROPLET",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4A7,
 },
 [0x1F4A8]={
  category="so",
  description="DASH SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4A8,
 },
 [0x1F4A9]={
  category="so",
  description="PILE OF POO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4A9,
 },
 [0x1F4AA]={
  category="so",
  description="FLEXED BICEPS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4AA,
 },
 [0x1F4AB]={
  category="so",
  description="DIZZY SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4AB,
 },
 [0x1F4AC]={
  category="so",
  description="SPEECH BALLOON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4AC,
 },
 [0x1F4AD]={
  category="so",
  description="THOUGHT BALLOON",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4AD,
 },
 [0x1F4AE]={
  category="so",
  description="WHITE FLOWER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4AE,
 },
 [0x1F4AF]={
  category="so",
  description="HUNDRED POINTS SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F4AF,
 },
 [0x1F4B0]={
  category="so",
  description="MONEY BAG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4B0,
 },
 [0x1F4B1]={
  category="so",
  description="CURRENCY EXCHANGE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F4B1,
 },
 [0x1F4B2]={
  category="so",
  description="HEAVY DOLLAR SIGN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F4B2,
 },
 [0x1F4B3]={
  category="so",
  description="CREDIT CARD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4B3,
 },
 [0x1F4B4]={
  category="so",
  description="BANKNOTE WITH YEN SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4B4,
 },
 [0x1F4B5]={
  category="so",
  description="BANKNOTE WITH DOLLAR SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4B5,
 },
 [0x1F4B6]={
  category="so",
  description="BANKNOTE WITH EURO SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4B6,
 },
 [0x1F4B7]={
  category="so",
  description="BANKNOTE WITH POUND SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4B7,
 },
 [0x1F4B8]={
  category="so",
  description="MONEY WITH WINGS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4B8,
 },
 [0x1F4B9]={
  category="so",
  description="CHART WITH UPWARDS TREND AND YEN SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4B9,
 },
 [0x1F4BA]={
  category="so",
  description="SEAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4BA,
 },
 [0x1F4BB]={
  category="so",
  description="PERSONAL COMPUTER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4BB,
 },
 [0x1F4BC]={
  category="so",
  description="BRIEFCASE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4BC,
 },
 [0x1F4BD]={
  category="so",
  description="MINIDISC",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4BD,
 },
 [0x1F4BE]={
  category="so",
  description="FLOPPY DISK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4BE,
 },
 [0x1F4BF]={
  category="so",
  description="OPTICAL DISC",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4BF,
 },
 [0x1F4C0]={
  category="so",
  description="DVD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C0,
 },
 [0x1F4C1]={
  category="so",
  description="FILE FOLDER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C1,
 },
 [0x1F4C2]={
  category="so",
  description="OPEN FILE FOLDER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C2,
 },
 [0x1F4C3]={
  category="so",
  description="PAGE WITH CURL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C3,
 },
 [0x1F4C4]={
  category="so",
  description="PAGE FACING UP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C4,
 },
 [0x1F4C5]={
  category="so",
  description="CALENDAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C5,
 },
 [0x1F4C6]={
  category="so",
  description="TEAR-OFF CALENDAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C6,
 },
 [0x1F4C7]={
  category="so",
  description="CARD INDEX",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C7,
 },
 [0x1F4C8]={
  category="so",
  description="CHART WITH UPWARDS TREND",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C8,
 },
 [0x1F4C9]={
  category="so",
  description="CHART WITH DOWNWARDS TREND",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4C9,
 },
 [0x1F4CA]={
  category="so",
  description="BAR CHART",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4CA,
 },
 [0x1F4CB]={
  category="so",
  description="CLIPBOARD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4CB,
 },
 [0x1F4CC]={
  category="so",
  description="PUSHPIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4CC,
 },
 [0x1F4CD]={
  category="so",
  description="ROUND PUSHPIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4CD,
 },
 [0x1F4CE]={
  category="so",
  description="PAPERCLIP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4CE,
 },
 [0x1F4CF]={
  category="so",
  description="STRAIGHT RULER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4CF,
 },
 [0x1F4D0]={
  category="so",
  description="TRIANGULAR RULER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D0,
 },
 [0x1F4D1]={
  category="so",
  description="BOOKMARK TABS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D1,
 },
 [0x1F4D2]={
  category="so",
  description="LEDGER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D2,
 },
 [0x1F4D3]={
  category="so",
  description="NOTEBOOK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D3,
 },
 [0x1F4D4]={
  category="so",
  description="NOTEBOOK WITH DECORATIVE COVER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D4,
 },
 [0x1F4D5]={
  category="so",
  description="CLOSED BOOK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D5,
 },
 [0x1F4D6]={
  category="so",
  description="OPEN BOOK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D6,
 },
 [0x1F4D7]={
  category="so",
  description="GREEN BOOK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D7,
 },
 [0x1F4D8]={
  category="so",
  description="BLUE BOOK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D8,
 },
 [0x1F4D9]={
  category="so",
  description="ORANGE BOOK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4D9,
 },
 [0x1F4DA]={
  category="so",
  description="BOOKS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4DA,
 },
 [0x1F4DB]={
  category="so",
  description="NAME BADGE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4DB,
 },
 [0x1F4DC]={
  category="so",
  description="SCROLL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4DC,
 },
 [0x1F4DD]={
  category="so",
  description="MEMO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4DD,
 },
 [0x1F4DE]={
  category="so",
  description="TELEPHONE RECEIVER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4DE,
 },
 [0x1F4DF]={
  category="so",
  description="PAGER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4DF,
 },
 [0x1F4E0]={
  category="so",
  description="FAX MACHINE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E0,
 },
 [0x1F4E1]={
  category="so",
  description="SATELLITE ANTENNA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E1,
 },
 [0x1F4E2]={
  category="so",
  description="PUBLIC ADDRESS LOUDSPEAKER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E2,
 },
 [0x1F4E3]={
  category="so",
  description="CHEERING MEGAPHONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E3,
 },
 [0x1F4E4]={
  category="so",
  description="OUTBOX TRAY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E4,
 },
 [0x1F4E5]={
  category="so",
  description="INBOX TRAY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E5,
 },
 [0x1F4E6]={
  category="so",
  description="PACKAGE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E6,
 },
 [0x1F4E7]={
  category="so",
  description="E-MAIL SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E7,
 },
 [0x1F4E8]={
  category="so",
  description="INCOMING ENVELOPE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E8,
 },
 [0x1F4E9]={
  category="so",
  description="ENVELOPE WITH DOWNWARDS ARROW ABOVE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4E9,
 },
 [0x1F4EA]={
  category="so",
  description="CLOSED MAILBOX WITH LOWERED FLAG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4EA,
 },
 [0x1F4EB]={
  category="so",
  description="CLOSED MAILBOX WITH RAISED FLAG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4EB,
 },
 [0x1F4EC]={
  category="so",
  description="OPEN MAILBOX WITH RAISED FLAG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4EC,
 },
 [0x1F4ED]={
  category="so",
  description="OPEN MAILBOX WITH LOWERED FLAG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4ED,
 },
 [0x1F4EE]={
  category="so",
  description="POSTBOX",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4EE,
 },
 [0x1F4EF]={
  category="so",
  description="POSTAL HORN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4EF,
 },
 [0x1F4F0]={
  category="so",
  description="NEWSPAPER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F0,
 },
 [0x1F4F1]={
  category="so",
  description="MOBILE PHONE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F1,
 },
 [0x1F4F2]={
  category="so",
  description="MOBILE PHONE WITH RIGHTWARDS ARROW AT LEFT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F2,
 },
 [0x1F4F3]={
  category="so",
  description="VIBRATION MODE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F3,
 },
 [0x1F4F4]={
  category="so",
  description="MOBILE PHONE OFF",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F4,
 },
 [0x1F4F5]={
  category="so",
  description="NO MOBILE PHONES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F5,
 },
 [0x1F4F6]={
  category="so",
  description="ANTENNA WITH BARS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F6,
 },
 [0x1F4F7]={
  category="so",
  description="CAMERA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F7,
 },
 [0x1F4F9]={
  category="so",
  description="VIDEO CAMERA",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4F9,
 },
 [0x1F4FA]={
  category="so",
  description="TELEVISION",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4FA,
 },
 [0x1F4FB]={
  category="so",
  description="RADIO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4FB,
 },
 [0x1F4FC]={
  category="so",
  description="VIDEOCASSETTE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F4FC,
 },
 [0x1F500]={
  category="so",
  description="TWISTED RIGHTWARDS ARROWS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F500,
 },
 [0x1F501]={
  category="so",
  description="CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F501,
 },
 [0x1F502]={
  category="so",
  description="CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS WITH CIRCLED ONE OVERLAY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F502,
 },
 [0x1F503]={
  category="so",
  description="CLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F503,
 },
 [0x1F504]={
  category="so",
  description="ANTICLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F504,
 },
 [0x1F505]={
  category="so",
  description="LOW BRIGHTNESS SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F505,
 },
 [0x1F506]={
  category="so",
  description="HIGH BRIGHTNESS SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F506,
 },
 [0x1F507]={
  category="so",
  description="SPEAKER WITH CANCELLATION STROKE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F507,
 },
 [0x1F508]={
  category="so",
  description="SPEAKER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F508,
 },
 [0x1F509]={
  category="so",
  description="SPEAKER WITH ONE SOUND WAVE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F509,
 },
 [0x1F50A]={
  category="so",
  description="SPEAKER WITH THREE SOUND WAVES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F50A,
 },
 [0x1F50B]={
  category="so",
  description="BATTERY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F50B,
 },
 [0x1F50C]={
  category="so",
  description="ELECTRIC PLUG",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F50C,
 },
 [0x1F50D]={
  category="so",
  description="LEFT-POINTING MAGNIFYING GLASS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F50D,
 },
 [0x1F50E]={
  category="so",
  description="RIGHT-POINTING MAGNIFYING GLASS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F50E,
 },
 [0x1F50F]={
  category="so",
  description="LOCK WITH INK PEN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F50F,
 },
 [0x1F510]={
  category="so",
  description="CLOSED LOCK WITH KEY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F510,
 },
 [0x1F511]={
  category="so",
  description="KEY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F511,
 },
 [0x1F512]={
  category="so",
  description="LOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F512,
 },
 [0x1F513]={
  category="so",
  description="OPEN LOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F513,
 },
 [0x1F514]={
  category="so",
  description="BELL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F514,
 },
 [0x1F515]={
  category="so",
  description="BELL WITH CANCELLATION STROKE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F515,
 },
 [0x1F516]={
  category="so",
  description="BOOKMARK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F516,
 },
 [0x1F517]={
  category="so",
  description="LINK SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F517,
 },
 [0x1F518]={
  category="so",
  description="RADIO BUTTON",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F518,
 },
 [0x1F519]={
  category="so",
  description="BACK WITH LEFTWARDS ARROW ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F519,
 },
 [0x1F51A]={
  category="so",
  description="END WITH LEFTWARDS ARROW ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F51A,
 },
 [0x1F51B]={
  category="so",
  description="ON WITH EXCLAMATION MARK WITH LEFT RIGHT ARROW ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F51B,
 },
 [0x1F51C]={
  category="so",
  description="SOON WITH RIGHTWARDS ARROW ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F51C,
 },
 [0x1F51D]={
  category="so",
  description="TOP WITH UPWARDS ARROW ABOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F51D,
 },
 [0x1F51E]={
  category="so",
  description="NO ONE UNDER EIGHTEEN SYMBOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F51E,
 },
 [0x1F51F]={
  category="so",
  description="KEYCAP TEN",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F51F,
 },
 [0x1F520]={
  category="so",
  description="INPUT SYMBOL FOR LATIN CAPITAL LETTERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F520,
 },
 [0x1F521]={
  category="so",
  description="INPUT SYMBOL FOR LATIN SMALL LETTERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F521,
 },
 [0x1F522]={
  category="so",
  description="INPUT SYMBOL FOR NUMBERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F522,
 },
 [0x1F523]={
  category="so",
  description="INPUT SYMBOL FOR SYMBOLS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F523,
 },
 [0x1F524]={
  category="so",
  description="INPUT SYMBOL FOR LATIN LETTERS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F524,
 },
 [0x1F525]={
  category="so",
  description="FIRE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F525,
 },
 [0x1F526]={
  category="so",
  description="ELECTRIC TORCH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F526,
 },
 [0x1F527]={
  category="so",
  description="WRENCH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F527,
 },
 [0x1F528]={
  category="so",
  description="HAMMER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F528,
 },
 [0x1F529]={
  category="so",
  description="NUT AND BOLT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F529,
 },
 [0x1F52A]={
  category="so",
  description="HOCHO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F52A,
 },
 [0x1F52B]={
  category="so",
  description="PISTOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F52B,
 },
 [0x1F52C]={
  category="so",
  description="MICROSCOPE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F52C,
 },
 [0x1F52D]={
  category="so",
  description="TELESCOPE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F52D,
 },
 [0x1F52E]={
  category="so",
  description="CRYSTAL BALL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F52E,
 },
 [0x1F52F]={
  category="so",
  description="SIX POINTED STAR WITH MIDDLE DOT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F52F,
 },
 [0x1F530]={
  category="so",
  description="JAPANESE SYMBOL FOR BEGINNER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F530,
 },
 [0x1F531]={
  category="so",
  description="TRIDENT EMBLEM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F531,
 },
 [0x1F532]={
  category="so",
  description="BLACK SQUARE BUTTON",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F532,
 },
 [0x1F533]={
  category="so",
  description="WHITE SQUARE BUTTON",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F533,
 },
 [0x1F534]={
  category="so",
  description="LARGE RED CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F534,
 },
 [0x1F535]={
  category="so",
  description="LARGE BLUE CIRCLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F535,
 },
 [0x1F536]={
  category="so",
  description="LARGE ORANGE DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F536,
 },
 [0x1F537]={
  category="so",
  description="LARGE BLUE DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F537,
 },
 [0x1F538]={
  category="so",
  description="SMALL ORANGE DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F538,
 },
 [0x1F539]={
  category="so",
  description="SMALL BLUE DIAMOND",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F539,
 },
 [0x1F53A]={
  category="so",
  description="UP-POINTING RED TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F53A,
 },
 [0x1F53B]={
  category="so",
  description="DOWN-POINTING RED TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F53B,
 },
 [0x1F53C]={
  category="so",
  description="UP-POINTING SMALL RED TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F53C,
 },
 [0x1F53D]={
  category="so",
  description="DOWN-POINTING SMALL RED TRIANGLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F53D,
 },
 [0x1F540]={
  category="so",
  description="CIRCLED CROSS POMMEE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F540,
 },
 [0x1F541]={
  category="so",
  description="CROSS POMMEE WITH HALF-CIRCLE BELOW",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F541,
 },
 [0x1F542]={
  category="so",
  description="CROSS POMMEE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F542,
 },
 [0x1F543]={
  category="so",
  description="NOTCHED LEFT SEMICIRCLE WITH THREE DOTS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F543,
 },
 [0x1F550]={
  category="so",
  description="CLOCK FACE ONE OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F550,
 },
 [0x1F551]={
  category="so",
  description="CLOCK FACE TWO OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F551,
 },
 [0x1F552]={
  category="so",
  description="CLOCK FACE THREE OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F552,
 },
 [0x1F553]={
  category="so",
  description="CLOCK FACE FOUR OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F553,
 },
 [0x1F554]={
  category="so",
  description="CLOCK FACE FIVE OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F554,
 },
 [0x1F555]={
  category="so",
  description="CLOCK FACE SIX OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F555,
 },
 [0x1F556]={
  category="so",
  description="CLOCK FACE SEVEN OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F556,
 },
 [0x1F557]={
  category="so",
  description="CLOCK FACE EIGHT OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F557,
 },
 [0x1F558]={
  category="so",
  description="CLOCK FACE NINE OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F558,
 },
 [0x1F559]={
  category="so",
  description="CLOCK FACE TEN OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F559,
 },
 [0x1F55A]={
  category="so",
  description="CLOCK FACE ELEVEN OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F55A,
 },
 [0x1F55B]={
  category="so",
  description="CLOCK FACE TWELVE OCLOCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F55B,
 },
 [0x1F55C]={
  category="so",
  description="CLOCK FACE ONE-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F55C,
 },
 [0x1F55D]={
  category="so",
  description="CLOCK FACE TWO-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F55D,
 },
 [0x1F55E]={
  category="so",
  description="CLOCK FACE THREE-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F55E,
 },
 [0x1F55F]={
  category="so",
  description="CLOCK FACE FOUR-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F55F,
 },
 [0x1F560]={
  category="so",
  description="CLOCK FACE FIVE-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F560,
 },
 [0x1F561]={
  category="so",
  description="CLOCK FACE SIX-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F561,
 },
 [0x1F562]={
  category="so",
  description="CLOCK FACE SEVEN-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F562,
 },
 [0x1F563]={
  category="so",
  description="CLOCK FACE EIGHT-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F563,
 },
 [0x1F564]={
  category="so",
  description="CLOCK FACE NINE-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F564,
 },
 [0x1F565]={
  category="so",
  description="CLOCK FACE TEN-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F565,
 },
 [0x1F566]={
  category="so",
  description="CLOCK FACE ELEVEN-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F566,
 },
 [0x1F567]={
  category="so",
  description="CLOCK FACE TWELVE-THIRTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F567,
 },
 [0x1F5FB]={
  category="so",
  description="MOUNT FUJI",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F5FB,
 },
 [0x1F5FC]={
  category="so",
  description="TOKYO TOWER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F5FC,
 },
 [0x1F5FD]={
  category="so",
  description="STATUE OF LIBERTY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F5FD,
 },
 [0x1F5FE]={
  category="so",
  description="SILHOUETTE OF JAPAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F5FE,
 },
 [0x1F5FF]={
  category="so",
  description="MOYAI",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F5FF,
 },
 [0x1F600]={
  category="so",
  description="GRINNING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F600,
 },
 [0x1F601]={
  category="so",
  description="GRINNING FACE WITH SMILING EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F601,
 },
 [0x1F602]={
  category="so",
  description="FACE WITH TEARS OF JOY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F602,
 },
 [0x1F603]={
  category="so",
  description="SMILING FACE WITH OPEN MOUTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F603,
 },
 [0x1F604]={
  category="so",
  description="SMILING FACE WITH OPEN MOUTH AND SMILING EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F604,
 },
 [0x1F605]={
  category="so",
  description="SMILING FACE WITH OPEN MOUTH AND COLD SWEAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F605,
 },
 [0x1F606]={
  category="so",
  description="SMILING FACE WITH OPEN MOUTH AND TIGHTLY-CLOSED EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F606,
 },
 [0x1F607]={
  category="so",
  description="SMILING FACE WITH HALO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F607,
 },
 [0x1F608]={
  category="so",
  description="SMILING FACE WITH HORNS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F608,
 },
 [0x1F609]={
  category="so",
  description="WINKING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F609,
 },
 [0x1F60A]={
  category="so",
  description="SMILING FACE WITH SMILING EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F60A,
 },
 [0x1F60B]={
  category="so",
  description="FACE SAVOURING DELICIOUS FOOD",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F60B,
 },
 [0x1F60C]={
  category="so",
  description="RELIEVED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F60C,
 },
 [0x1F60D]={
  category="so",
  description="SMILING FACE WITH HEART-SHAPED EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F60D,
 },
 [0x1F60E]={
  category="so",
  description="SMILING FACE WITH SUNGLASSES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F60E,
 },
 [0x1F60F]={
  category="so",
  description="SMIRKING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F60F,
 },
 [0x1F610]={
  category="so",
  description="NEUTRAL FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F610,
 },
 [0x1F611]={
  category="so",
  description="EXPRESSIONLESS FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F611,
 },
 [0x1F612]={
  category="so",
  description="UNAMUSED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F612,
 },
 [0x1F613]={
  category="so",
  description="FACE WITH COLD SWEAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F613,
 },
 [0x1F614]={
  category="so",
  description="PENSIVE FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F614,
 },
 [0x1F615]={
  category="so",
  description="CONFUSED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F615,
 },
 [0x1F616]={
  category="so",
  description="CONFOUNDED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F616,
 },
 [0x1F617]={
  category="so",
  description="KISSING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F617,
 },
 [0x1F618]={
  category="so",
  description="FACE THROWING A KISS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F618,
 },
 [0x1F619]={
  category="so",
  description="KISSING FACE WITH SMILING EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F619,
 },
 [0x1F61A]={
  category="so",
  description="KISSING FACE WITH CLOSED EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F61A,
 },
 [0x1F61B]={
  category="so",
  description="FACE WITH STUCK-OUT TONGUE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F61B,
 },
 [0x1F61C]={
  category="so",
  description="FACE WITH STUCK-OUT TONGUE AND WINKING EYE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F61C,
 },
 [0x1F61D]={
  category="so",
  description="FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F61D,
 },
 [0x1F61E]={
  category="so",
  description="DISAPPOINTED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F61E,
 },
 [0x1F61F]={
  category="so",
  description="WORRIED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F61F,
 },
 [0x1F620]={
  category="so",
  description="ANGRY FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F620,
 },
 [0x1F621]={
  category="so",
  description="POUTING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F621,
 },
 [0x1F622]={
  category="so",
  description="CRYING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F622,
 },
 [0x1F623]={
  category="so",
  description="PERSEVERING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F623,
 },
 [0x1F624]={
  category="so",
  description="FACE WITH LOOK OF TRIUMPH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F624,
 },
 [0x1F625]={
  category="so",
  description="DISAPPOINTED BUT RELIEVED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F625,
 },
 [0x1F626]={
  category="so",
  description="FROWNING FACE WITH OPEN MOUTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F626,
 },
 [0x1F627]={
  category="so",
  description="ANGUISHED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F627,
 },
 [0x1F628]={
  category="so",
  description="FEARFUL FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F628,
 },
 [0x1F629]={
  category="so",
  description="WEARY FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F629,
 },
 [0x1F62A]={
  category="so",
  description="SLEEPY FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F62A,
 },
 [0x1F62B]={
  category="so",
  description="TIRED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F62B,
 },
 [0x1F62C]={
  category="so",
  description="GRIMACING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F62C,
 },
 [0x1F62D]={
  category="so",
  description="LOUDLY CRYING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F62D,
 },
 [0x1F62E]={
  category="so",
  description="FACE WITH OPEN MOUTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F62E,
 },
 [0x1F62F]={
  category="so",
  description="HUSHED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F62F,
 },
 [0x1F630]={
  category="so",
  description="FACE WITH OPEN MOUTH AND COLD SWEAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F630,
 },
 [0x1F631]={
  category="so",
  description="FACE SCREAMING IN FEAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F631,
 },
 [0x1F632]={
  category="so",
  description="ASTONISHED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F632,
 },
 [0x1F633]={
  category="so",
  description="FLUSHED FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F633,
 },
 [0x1F634]={
  category="so",
  description="SLEEPING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F634,
 },
 [0x1F635]={
  category="so",
  description="DIZZY FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F635,
 },
 [0x1F636]={
  category="so",
  description="FACE WITHOUT MOUTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F636,
 },
 [0x1F637]={
  category="so",
  description="FACE WITH MEDICAL MASK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F637,
 },
 [0x1F638]={
  category="so",
  description="GRINNING CAT FACE WITH SMILING EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F638,
 },
 [0x1F639]={
  category="so",
  description="CAT FACE WITH TEARS OF JOY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F639,
 },
 [0x1F63A]={
  category="so",
  description="SMILING CAT FACE WITH OPEN MOUTH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F63A,
 },
 [0x1F63B]={
  category="so",
  description="SMILING CAT FACE WITH HEART-SHAPED EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F63B,
 },
 [0x1F63C]={
  category="so",
  description="CAT FACE WITH WRY SMILE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F63C,
 },
 [0x1F63D]={
  category="so",
  description="KISSING CAT FACE WITH CLOSED EYES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F63D,
 },
 [0x1F63E]={
  category="so",
  description="POUTING CAT FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F63E,
 },
 [0x1F63F]={
  category="so",
  description="CRYING CAT FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F63F,
 },
 [0x1F640]={
  category="so",
  description="WEARY CAT FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F640,
 },
 [0x1F645]={
  category="so",
  description="FACE WITH NO GOOD GESTURE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F645,
 },
 [0x1F646]={
  category="so",
  description="FACE WITH OK GESTURE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F646,
 },
 [0x1F647]={
  category="so",
  description="PERSON BOWING DEEPLY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F647,
 },
 [0x1F648]={
  category="so",
  description="SEE-NO-EVIL MONKEY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F648,
 },
 [0x1F649]={
  category="so",
  description="HEAR-NO-EVIL MONKEY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F649,
 },
 [0x1F64A]={
  category="so",
  description="SPEAK-NO-EVIL MONKEY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F64A,
 },
 [0x1F64B]={
  category="so",
  description="HAPPY PERSON RAISING ONE HAND",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F64B,
 },
 [0x1F64C]={
  category="so",
  description="PERSON RAISING BOTH HANDS IN CELEBRATION",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F64C,
 },
 [0x1F64D]={
  category="so",
  description="PERSON FROWNING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F64D,
 },
 [0x1F64E]={
  category="so",
  description="PERSON WITH POUTING FACE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F64E,
 },
 [0x1F64F]={
  category="so",
  description="PERSON WITH FOLDED HANDS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F64F,
 },
 [0x1F680]={
  category="so",
  description="ROCKET",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F680,
 },
 [0x1F681]={
  category="so",
  description="HELICOPTER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F681,
 },
 [0x1F682]={
  category="so",
  description="STEAM LOCOMOTIVE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F682,
 },
 [0x1F683]={
  category="so",
  description="RAILWAY CAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F683,
 },
 [0x1F684]={
  category="so",
  description="HIGH-SPEED TRAIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F684,
 },
 [0x1F685]={
  category="so",
  description="HIGH-SPEED TRAIN WITH BULLET NOSE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F685,
 },
 [0x1F686]={
  category="so",
  description="TRAIN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F686,
 },
 [0x1F687]={
  category="so",
  description="METRO",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F687,
 },
 [0x1F688]={
  category="so",
  description="LIGHT RAIL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F688,
 },
 [0x1F689]={
  category="so",
  description="STATION",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F689,
 },
 [0x1F68A]={
  category="so",
  description="TRAM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F68A,
 },
 [0x1F68B]={
  category="so",
  description="TRAM CAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F68B,
 },
 [0x1F68C]={
  category="so",
  description="BUS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F68C,
 },
 [0x1F68D]={
  category="so",
  description="ONCOMING BUS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F68D,
 },
 [0x1F68E]={
  category="so",
  description="TROLLEYBUS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F68E,
 },
 [0x1F68F]={
  category="so",
  description="BUS STOP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F68F,
 },
 [0x1F690]={
  category="so",
  description="MINIBUS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F690,
 },
 [0x1F691]={
  category="so",
  description="AMBULANCE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F691,
 },
 [0x1F692]={
  category="so",
  description="FIRE ENGINE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F692,
 },
 [0x1F693]={
  category="so",
  description="POLICE CAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F693,
 },
 [0x1F694]={
  category="so",
  description="ONCOMING POLICE CAR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F694,
 },
 [0x1F695]={
  category="so",
  description="TAXI",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F695,
 },
 [0x1F696]={
  category="so",
  description="ONCOMING TAXI",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F696,
 },
 [0x1F697]={
  category="so",
  description="AUTOMOBILE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F697,
 },
 [0x1F698]={
  category="so",
  description="ONCOMING AUTOMOBILE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F698,
 },
 [0x1F699]={
  category="so",
  description="RECREATIONAL VEHICLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F699,
 },
 [0x1F69A]={
  category="so",
  description="DELIVERY TRUCK",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F69A,
 },
 [0x1F69B]={
  category="so",
  description="ARTICULATED LORRY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F69B,
 },
 [0x1F69C]={
  category="so",
  description="TRACTOR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F69C,
 },
 [0x1F69D]={
  category="so",
  description="MONORAIL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F69D,
 },
 [0x1F69E]={
  category="so",
  description="MOUNTAIN RAILWAY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F69E,
 },
 [0x1F69F]={
  category="so",
  description="SUSPENSION RAILWAY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F69F,
 },
 [0x1F6A0]={
  category="so",
  description="MOUNTAIN CABLEWAY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A0,
 },
 [0x1F6A1]={
  category="so",
  description="AERIAL TRAMWAY",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A1,
 },
 [0x1F6A2]={
  category="so",
  description="SHIP",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A2,
 },
 [0x1F6A3]={
  category="so",
  description="ROWBOAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A3,
 },
 [0x1F6A4]={
  category="so",
  description="SPEEDBOAT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A4,
 },
 [0x1F6A5]={
  category="so",
  description="HORIZONTAL TRAFFIC LIGHT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A5,
 },
 [0x1F6A6]={
  category="so",
  description="VERTICAL TRAFFIC LIGHT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A6,
 },
 [0x1F6A7]={
  category="so",
  description="CONSTRUCTION SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A7,
 },
 [0x1F6A8]={
  category="so",
  description="POLICE CARS REVOLVING LIGHT",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A8,
 },
 [0x1F6A9]={
  category="so",
  description="TRIANGULAR FLAG ON POST",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6A9,
 },
 [0x1F6AA]={
  category="so",
  description="DOOR",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6AA,
 },
 [0x1F6AB]={
  category="so",
  description="NO ENTRY SIGN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6AB,
 },
 [0x1F6AC]={
  category="so",
  description="SMOKING SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6AC,
 },
 [0x1F6AD]={
  category="so",
  description="NO SMOKING SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6AD,
 },
 [0x1F6AE]={
  category="so",
  description="PUT LITTER IN ITS PLACE SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6AE,
 },
 [0x1F6AF]={
  category="so",
  description="DO NOT LITTER SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6AF,
 },
 [0x1F6B0]={
  category="so",
  description="POTABLE WATER SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B0,
 },
 [0x1F6B1]={
  category="so",
  description="NON-POTABLE WATER SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B1,
 },
 [0x1F6B2]={
  category="so",
  description="BICYCLE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B2,
 },
 [0x1F6B3]={
  category="so",
  description="NO BICYCLES",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B3,
 },
 [0x1F6B4]={
  category="so",
  description="BICYCLIST",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B4,
 },
 [0x1F6B5]={
  category="so",
  description="MOUNTAIN BICYCLIST",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B5,
 },
 [0x1F6B6]={
  category="so",
  description="PEDESTRIAN",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B6,
 },
 [0x1F6B7]={
  category="so",
  description="NO PEDESTRIANS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B7,
 },
 [0x1F6B8]={
  category="so",
  description="CHILDREN CROSSING",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B8,
 },
 [0x1F6B9]={
  category="so",
  description="MENS SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6B9,
 },
 [0x1F6BA]={
  category="so",
  description="WOMENS SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6BA,
 },
 [0x1F6BB]={
  category="so",
  description="RESTROOM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6BB,
 },
 [0x1F6BC]={
  category="so",
  description="BABY SYMBOL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6BC,
 },
 [0x1F6BD]={
  category="so",
  description="TOILET",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6BD,
 },
 [0x1F6BE]={
  category="so",
  description="WATER CLOSET",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6BE,
 },
 [0x1F6BF]={
  category="so",
  description="SHOWER",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6BF,
 },
 [0x1F6C0]={
  category="so",
  description="BATH",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6C0,
 },
 [0x1F6C1]={
  category="so",
  description="BATHTUB",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6C1,
 },
 [0x1F6C2]={
  category="so",
  description="PASSPORT CONTROL",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6C2,
 },
 [0x1F6C3]={
  category="so",
  description="CUSTOMS",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6C3,
 },
 [0x1F6C4]={
  category="so",
  description="BAGGAGE CLAIM",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6C4,
 },
 [0x1F6C5]={
  category="so",
  description="LEFT LUGGAGE",
  direction="on",
  linebreak="id",
  unicodeslot=0x1F6C5,
 },
 [0x1F700]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR QUINTESSENCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F700,
 },
 [0x1F701]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR AIR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F701,
 },
 [0x1F702]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR FIRE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F702,
 },
 [0x1F703]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR EARTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F703,
 },
 [0x1F704]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR WATER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F704,
 },
 [0x1F705]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR AQUAFORTIS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F705,
 },
 [0x1F706]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR AQUA REGIA",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F706,
 },
 [0x1F707]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR AQUA REGIA-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F707,
 },
 [0x1F708]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR AQUA VITAE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F708,
 },
 [0x1F709]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR AQUA VITAE-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F709,
 },
 [0x1F70A]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR VINEGAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F70A,
 },
 [0x1F70B]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR VINEGAR-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F70B,
 },
 [0x1F70C]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR VINEGAR-3",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F70C,
 },
 [0x1F70D]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SULFUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F70D,
 },
 [0x1F70E]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR PHILOSOPHERS SULFUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F70E,
 },
 [0x1F70F]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR BLACK SULFUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F70F,
 },
 [0x1F710]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F710,
 },
 [0x1F711]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F711,
 },
 [0x1F712]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-3",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F712,
 },
 [0x1F713]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CINNABAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F713,
 },
 [0x1F714]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SALT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F714,
 },
 [0x1F715]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR NITRE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F715,
 },
 [0x1F716]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR VITRIOL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F716,
 },
 [0x1F717]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR VITRIOL-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F717,
 },
 [0x1F718]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ROCK SALT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F718,
 },
 [0x1F719]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ROCK SALT-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F719,
 },
 [0x1F71A]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR GOLD",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F71A,
 },
 [0x1F71B]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SILVER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F71B,
 },
 [0x1F71C]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR IRON ORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F71C,
 },
 [0x1F71D]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR IRON ORE-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F71D,
 },
 [0x1F71E]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CROCUS OF IRON",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F71E,
 },
 [0x1F71F]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REGULUS OF IRON",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F71F,
 },
 [0x1F720]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR COPPER ORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F720,
 },
 [0x1F721]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR IRON-COPPER ORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F721,
 },
 [0x1F722]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SUBLIMATE OF COPPER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F722,
 },
 [0x1F723]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CROCUS OF COPPER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F723,
 },
 [0x1F724]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CROCUS OF COPPER-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F724,
 },
 [0x1F725]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR COPPER ANTIMONIATE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F725,
 },
 [0x1F726]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SALT OF COPPER ANTIMONIATE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F726,
 },
 [0x1F727]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF COPPER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F727,
 },
 [0x1F728]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR VERDIGRIS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F728,
 },
 [0x1F729]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR TIN ORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F729,
 },
 [0x1F72A]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR LEAD ORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F72A,
 },
 [0x1F72B]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ANTIMONY ORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F72B,
 },
 [0x1F72C]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SUBLIMATE OF ANTIMONY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F72C,
 },
 [0x1F72D]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SALT OF ANTIMONY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F72D,
 },
 [0x1F72E]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF ANTIMONY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F72E,
 },
 [0x1F72F]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR VINEGAR OF ANTIMONY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F72F,
 },
 [0x1F730]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F730,
 },
 [0x1F731]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F731,
 },
 [0x1F732]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REGULUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F732,
 },
 [0x1F733]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REGULUS-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F733,
 },
 [0x1F734]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REGULUS-3",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F734,
 },
 [0x1F735]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REGULUS-4",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F735,
 },
 [0x1F736]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ALKALI",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F736,
 },
 [0x1F737]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ALKALI-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F737,
 },
 [0x1F738]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR MARCASITE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F738,
 },
 [0x1F739]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SAL-AMMONIAC",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F739,
 },
 [0x1F73A]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ARSENIC",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F73A,
 },
 [0x1F73B]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REALGAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F73B,
 },
 [0x1F73C]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR REALGAR-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F73C,
 },
 [0x1F73D]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR AURIPIGMENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F73D,
 },
 [0x1F73E]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR BISMUTH ORE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F73E,
 },
 [0x1F73F]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR TARTAR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F73F,
 },
 [0x1F740]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR TARTAR-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F740,
 },
 [0x1F741]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR QUICK LIME",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F741,
 },
 [0x1F742]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR BORAX",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F742,
 },
 [0x1F743]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR BORAX-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F743,
 },
 [0x1F744]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR BORAX-3",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F744,
 },
 [0x1F745]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ALUM",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F745,
 },
 [0x1F746]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR OIL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F746,
 },
 [0x1F747]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SPIRIT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F747,
 },
 [0x1F748]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR TINCTURE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F748,
 },
 [0x1F749]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR GUM",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F749,
 },
 [0x1F74A]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR WAX",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F74A,
 },
 [0x1F74B]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR POWDER",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F74B,
 },
 [0x1F74C]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CALX",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F74C,
 },
 [0x1F74D]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR TUTTY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F74D,
 },
 [0x1F74E]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CAPUT MORTUUM",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F74E,
 },
 [0x1F74F]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SCEPTER OF JOVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F74F,
 },
 [0x1F750]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CADUCEUS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F750,
 },
 [0x1F751]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR TRIDENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F751,
 },
 [0x1F752]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR STARRED TRIDENT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F752,
 },
 [0x1F753]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR LODESTONE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F753,
 },
 [0x1F754]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SOAP",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F754,
 },
 [0x1F755]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR URINE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F755,
 },
 [0x1F756]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR HORSE DUNG",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F756,
 },
 [0x1F757]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ASHES",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F757,
 },
 [0x1F758]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR POT ASHES",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F758,
 },
 [0x1F759]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR BRICK",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F759,
 },
 [0x1F75A]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR POWDERED BRICK",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F75A,
 },
 [0x1F75B]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR AMALGAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F75B,
 },
 [0x1F75C]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F75C,
 },
 [0x1F75D]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F75D,
 },
 [0x1F75E]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR SUBLIMATION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F75E,
 },
 [0x1F75F]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR PRECIPITATE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F75F,
 },
 [0x1F760]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR DISTILL",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F760,
 },
 [0x1F761]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR DISSOLVE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F761,
 },
 [0x1F762]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR DISSOLVE-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F762,
 },
 [0x1F763]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR PURIFY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F763,
 },
 [0x1F764]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR PUTREFACTION",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F764,
 },
 [0x1F765]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CRUCIBLE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F765,
 },
 [0x1F766]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CRUCIBLE-2",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F766,
 },
 [0x1F767]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CRUCIBLE-3",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F767,
 },
 [0x1F768]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CRUCIBLE-4",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F768,
 },
 [0x1F769]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR CRUCIBLE-5",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F769,
 },
 [0x1F76A]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR ALEMBIC",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F76A,
 },
 [0x1F76B]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR BATH OF MARY",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F76B,
 },
 [0x1F76C]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR BATH OF VAPOURS",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F76C,
 },
 [0x1F76D]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR RETORT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F76D,
 },
 [0x1F76E]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR HOUR",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F76E,
 },
 [0x1F76F]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR NIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F76F,
 },
 [0x1F770]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR DAY-NIGHT",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F770,
 },
 [0x1F771]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR MONTH",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F771,
 },
 [0x1F772]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR HALF DRAM",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F772,
 },
 [0x1F773]={
  category="so",
  description="ALCHEMICAL SYMBOL FOR HALF OUNCE",
  direction="on",
  linebreak="al",
  unicodeslot=0x1F773,
 },
 [0x2F800]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0320",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E3D },
  unicodeslot=0x2F800,
 },
 [0x2F801]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0321",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E38 },
  unicodeslot=0x2F801,
 },
 [0x2F802]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0322",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4E41 },
  unicodeslot=0x2F802,
 },
 [0x2F803]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0323",
  direction="l",
  linebreak="id",
  specials={ "char", 0x20122 },
  unicodeslot=0x2F803,
 },
 [0x2F804]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0324",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4F60 },
  unicodeslot=0x2F804,
 },
 [0x2F805]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0325",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4FAE },
  unicodeslot=0x2F805,
 },
 [0x2F806]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0326",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4FBB },
  unicodeslot=0x2F806,
 },
 [0x2F807]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0327",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5002 },
  unicodeslot=0x2F807,
 },
 [0x2F808]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0328",
  direction="l",
  linebreak="id",
  specials={ "char", 0x507A },
  unicodeslot=0x2F808,
 },
 [0x2F809]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0329",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5099 },
  unicodeslot=0x2F809,
 },
 [0x2F80A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0050A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x50E7 },
  unicodeslot=0x2F80A,
 },
 [0x2F80B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0050B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x50CF },
  unicodeslot=0x2F80B,
 },
 [0x2F80C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0050C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x349E },
  unicodeslot=0x2F80C,
 },
 [0x2F80D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0050D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2063A },
  unicodeslot=0x2F80D,
 },
 [0x2F80E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0050E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x514D },
  unicodeslot=0x2F80E,
 },
 [0x2F80F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0050F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5154 },
  unicodeslot=0x2F80F,
 },
 [0x2F810]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x032A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5164 },
  unicodeslot=0x2F810,
 },
 [0x2F811]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x032B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5177 },
  unicodeslot=0x2F811,
 },
 [0x2F812]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x032C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2051C },
  unicodeslot=0x2F812,
 },
 [0x2F813]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x032D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x34B9 },
  unicodeslot=0x2F813,
 },
 [0x2F814]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x032E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5167 },
  unicodeslot=0x2F814,
 },
 [0x2F815]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x032F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x518D },
  unicodeslot=0x2F815,
 },
 [0x2F816]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0330",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2054B },
  unicodeslot=0x2F816,
 },
 [0x2F817]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0331",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5197 },
  unicodeslot=0x2F817,
 },
 [0x2F818]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0332",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51A4 },
  unicodeslot=0x2F818,
 },
 [0x2F819]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0333",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4ECC },
  unicodeslot=0x2F819,
 },
 [0x2F81A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0051A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51AC },
  unicodeslot=0x2F81A,
 },
 [0x2F81B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0051B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51B5 },
  unicodeslot=0x2F81B,
 },
 [0x2F81C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0051C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x291DF },
  unicodeslot=0x2F81C,
 },
 [0x2F81D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0051D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x51F5 },
  unicodeslot=0x2F81D,
 },
 [0x2F81E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0051E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5203 },
  unicodeslot=0x2F81E,
 },
 [0x2F81F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0051F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x34DF },
  unicodeslot=0x2F81F,
 },
 [0x2F820]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0334",
  direction="l",
  linebreak="id",
  specials={ "char", 0x523B },
  unicodeslot=0x2F820,
 },
 [0x2F821]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0335",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5246 },
  unicodeslot=0x2F821,
 },
 [0x2F822]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0336",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5272 },
  unicodeslot=0x2F822,
 },
 [0x2F823]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0337",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5277 },
  unicodeslot=0x2F823,
 },
 [0x2F824]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0338",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3515 },
  unicodeslot=0x2F824,
 },
 [0x2F825]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0339",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52C7 },
  unicodeslot=0x2F825,
 },
 [0x2F826]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x033A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52C9 },
  unicodeslot=0x2F826,
 },
 [0x2F827]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x033B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52E4 },
  unicodeslot=0x2F827,
 },
 [0x2F828]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x033C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52FA },
  unicodeslot=0x2F828,
 },
 [0x2F829]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x033D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5305 },
  unicodeslot=0x2F829,
 },
 [0x2F82A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0052A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5306 },
  unicodeslot=0x2F82A,
 },
 [0x2F82B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0052B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5317 },
  unicodeslot=0x2F82B,
 },
 [0x2F82C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0052C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5349 },
  unicodeslot=0x2F82C,
 },
 [0x2F82D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0052D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5351 },
  unicodeslot=0x2F82D,
 },
 [0x2F82E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0052E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x535A },
  unicodeslot=0x2F82E,
 },
 [0x2F82F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0052F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5373 },
  unicodeslot=0x2F82F,
 },
 [0x2F830]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x033E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x537D },
  unicodeslot=0x2F830,
 },
 [0x2F831]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x033F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x537F },
  unicodeslot=0x2F831,
 },
 [0x2F832]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0340",
  direction="l",
  linebreak="id",
  specials={ "char", 0x537F },
  unicodeslot=0x2F832,
 },
 [0x2F833]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0341",
  direction="l",
  linebreak="id",
  specials={ "char", 0x537F },
  unicodeslot=0x2F833,
 },
 [0x2F834]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0342",
  direction="l",
  linebreak="id",
  specials={ "char", 0x20A2C },
  unicodeslot=0x2F834,
 },
 [0x2F835]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0343",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7070 },
  unicodeslot=0x2F835,
 },
 [0x2F836]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0344",
  direction="l",
  linebreak="id",
  specials={ "char", 0x53CA },
  unicodeslot=0x2F836,
 },
 [0x2F837]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0345",
  direction="l",
  linebreak="id",
  specials={ "char", 0x53DF },
  unicodeslot=0x2F837,
 },
 [0x2F838]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0346",
  direction="l",
  linebreak="id",
  specials={ "char", 0x20B63 },
  unicodeslot=0x2F838,
 },
 [0x2F839]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0347",
  direction="l",
  linebreak="id",
  specials={ "char", 0x53EB },
  unicodeslot=0x2F839,
 },
 [0x2F83A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0053A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x53F1 },
  unicodeslot=0x2F83A,
 },
 [0x2F83B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0053B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5406 },
  unicodeslot=0x2F83B,
 },
 [0x2F83C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0053C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x549E },
  unicodeslot=0x2F83C,
 },
 [0x2F83D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0053D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5438 },
  unicodeslot=0x2F83D,
 },
 [0x2F83E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0053E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5448 },
  unicodeslot=0x2F83E,
 },
 [0x2F83F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0053F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5468 },
  unicodeslot=0x2F83F,
 },
 [0x2F840]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0348",
  direction="l",
  linebreak="id",
  specials={ "char", 0x54A2 },
  unicodeslot=0x2F840,
 },
 [0x2F841]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0349",
  direction="l",
  linebreak="id",
  specials={ "char", 0x54F6 },
  unicodeslot=0x2F841,
 },
 [0x2F842]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x034A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5510 },
  unicodeslot=0x2F842,
 },
 [0x2F843]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x034B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5553 },
  unicodeslot=0x2F843,
 },
 [0x2F844]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x034C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5563 },
  unicodeslot=0x2F844,
 },
 [0x2F845]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x034D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5584 },
  unicodeslot=0x2F845,
 },
 [0x2F846]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x034E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5584 },
  unicodeslot=0x2F846,
 },
 [0x2F847]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x034F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5599 },
  unicodeslot=0x2F847,
 },
 [0x2F848]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0350",
  direction="l",
  linebreak="id",
  specials={ "char", 0x55AB },
  unicodeslot=0x2F848,
 },
 [0x2F849]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0351",
  direction="l",
  linebreak="id",
  specials={ "char", 0x55B3 },
  unicodeslot=0x2F849,
 },
 [0x2F84A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0054A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x55C2 },
  unicodeslot=0x2F84A,
 },
 [0x2F84B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0054B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5716 },
  unicodeslot=0x2F84B,
 },
 [0x2F84C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0054C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5606 },
  unicodeslot=0x2F84C,
 },
 [0x2F84D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0054D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5717 },
  unicodeslot=0x2F84D,
 },
 [0x2F84E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0054E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5651 },
  unicodeslot=0x2F84E,
 },
 [0x2F84F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0054F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5674 },
  unicodeslot=0x2F84F,
 },
 [0x2F850]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0352",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5207 },
  unicodeslot=0x2F850,
 },
 [0x2F851]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0353",
  direction="l",
  linebreak="id",
  specials={ "char", 0x58EE },
  unicodeslot=0x2F851,
 },
 [0x2F852]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0354",
  direction="l",
  linebreak="id",
  specials={ "char", 0x57CE },
  unicodeslot=0x2F852,
 },
 [0x2F853]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0355",
  direction="l",
  linebreak="id",
  specials={ "char", 0x57F4 },
  unicodeslot=0x2F853,
 },
 [0x2F854]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0356",
  direction="l",
  linebreak="id",
  specials={ "char", 0x580D },
  unicodeslot=0x2F854,
 },
 [0x2F855]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0357",
  direction="l",
  linebreak="id",
  specials={ "char", 0x578B },
  unicodeslot=0x2F855,
 },
 [0x2F856]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0358",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5832 },
  unicodeslot=0x2F856,
 },
 [0x2F857]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0359",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5831 },
  unicodeslot=0x2F857,
 },
 [0x2F858]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x035A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x58AC },
  unicodeslot=0x2F858,
 },
 [0x2F859]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x035B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x214E4 },
  unicodeslot=0x2F859,
 },
 [0x2F85A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0055A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x58F2 },
  unicodeslot=0x2F85A,
 },
 [0x2F85B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0055B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x58F7 },
  unicodeslot=0x2F85B,
 },
 [0x2F85C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0055C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5906 },
  unicodeslot=0x2F85C,
 },
 [0x2F85D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0055D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x591A },
  unicodeslot=0x2F85D,
 },
 [0x2F85E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0055E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5922 },
  unicodeslot=0x2F85E,
 },
 [0x2F85F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0055F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5962 },
  unicodeslot=0x2F85F,
 },
 [0x2F860]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x035C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x216A8 },
  unicodeslot=0x2F860,
 },
 [0x2F861]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x035D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x216EA },
  unicodeslot=0x2F861,
 },
 [0x2F862]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x035E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x59EC },
  unicodeslot=0x2F862,
 },
 [0x2F863]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x035F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5A1B },
  unicodeslot=0x2F863,
 },
 [0x2F864]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0360",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5A27 },
  unicodeslot=0x2F864,
 },
 [0x2F865]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0361",
  direction="l",
  linebreak="id",
  specials={ "char", 0x59D8 },
  unicodeslot=0x2F865,
 },
 [0x2F866]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0362",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5A66 },
  unicodeslot=0x2F866,
 },
 [0x2F867]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0363",
  direction="l",
  linebreak="id",
  specials={ "char", 0x36EE },
  unicodeslot=0x2F867,
 },
 [0x2F868]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0364",
  direction="l",
  linebreak="id",
  specials={ "char", 0x36FC },
  unicodeslot=0x2F868,
 },
 [0x2F869]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0365",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5B08 },
  unicodeslot=0x2F869,
 },
 [0x2F86A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0056A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5B3E },
  unicodeslot=0x2F86A,
 },
 [0x2F86B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0056B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5B3E },
  unicodeslot=0x2F86B,
 },
 [0x2F86C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0056C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x219C8 },
  unicodeslot=0x2F86C,
 },
 [0x2F86D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0056D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5BC3 },
  unicodeslot=0x2F86D,
 },
 [0x2F86E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0056E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5BD8 },
  unicodeslot=0x2F86E,
 },
 [0x2F86F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0056F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5BE7 },
  unicodeslot=0x2F86F,
 },
 [0x2F870]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0366",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5BF3 },
  unicodeslot=0x2F870,
 },
 [0x2F871]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0367",
  direction="l",
  linebreak="id",
  specials={ "char", 0x21B18 },
  unicodeslot=0x2F871,
 },
 [0x2F872]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0368",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5BFF },
  unicodeslot=0x2F872,
 },
 [0x2F873]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0369",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C06 },
  unicodeslot=0x2F873,
 },
 [0x2F874]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x036A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F53 },
  unicodeslot=0x2F874,
 },
 [0x2F875]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x036B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C22 },
  unicodeslot=0x2F875,
 },
 [0x2F876]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x036C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3781 },
  unicodeslot=0x2F876,
 },
 [0x2F877]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x036D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C60 },
  unicodeslot=0x2F877,
 },
 [0x2F878]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x036E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C6E },
  unicodeslot=0x2F878,
 },
 [0x2F879]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x036F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5CC0 },
  unicodeslot=0x2F879,
 },
 [0x2F87A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0057A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5C8D },
  unicodeslot=0x2F87A,
 },
 [0x2F87B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0057B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x21DE4 },
  unicodeslot=0x2F87B,
 },
 [0x2F87C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0057C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5D43 },
  unicodeslot=0x2F87C,
 },
 [0x2F87D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0057D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x21DE6 },
  unicodeslot=0x2F87D,
 },
 [0x2F87E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0057E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5D6E },
  unicodeslot=0x2F87E,
 },
 [0x2F87F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0057F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5D6B },
  unicodeslot=0x2F87F,
 },
 [0x2F880]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0370",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5D7C },
  unicodeslot=0x2F880,
 },
 [0x2F881]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0371",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5DE1 },
  unicodeslot=0x2F881,
 },
 [0x2F882]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0372",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5DE2 },
  unicodeslot=0x2F882,
 },
 [0x2F883]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0373",
  direction="l",
  linebreak="id",
  specials={ "char", 0x382F },
  unicodeslot=0x2F883,
 },
 [0x2F884]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0374",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5DFD },
  unicodeslot=0x2F884,
 },
 [0x2F885]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0375",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5E28 },
  unicodeslot=0x2F885,
 },
 [0x2F886]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0376",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5E3D },
  unicodeslot=0x2F886,
 },
 [0x2F887]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0377",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5E69 },
  unicodeslot=0x2F887,
 },
 [0x2F888]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0378",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3862 },
  unicodeslot=0x2F888,
 },
 [0x2F889]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0379",
  direction="l",
  linebreak="id",
  specials={ "char", 0x22183 },
  unicodeslot=0x2F889,
 },
 [0x2F88A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0058A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x387C },
  unicodeslot=0x2F88A,
 },
 [0x2F88B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0058B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5EB0 },
  unicodeslot=0x2F88B,
 },
 [0x2F88C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0058C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5EB3 },
  unicodeslot=0x2F88C,
 },
 [0x2F88D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0058D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5EB6 },
  unicodeslot=0x2F88D,
 },
 [0x2F88E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0058E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5ECA },
  unicodeslot=0x2F88E,
 },
 [0x2F88F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0058F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2A392 },
  unicodeslot=0x2F88F,
 },
 [0x2F890]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x037A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5EFE },
  unicodeslot=0x2F890,
 },
 [0x2F891]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x037B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x22331 },
  unicodeslot=0x2F891,
 },
 [0x2F892]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x037C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x22331 },
  unicodeslot=0x2F892,
 },
 [0x2F893]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x037D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8201 },
  unicodeslot=0x2F893,
 },
 [0x2F894]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x037E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F22 },
  unicodeslot=0x2F894,
 },
 [0x2F895]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x037F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F22 },
  unicodeslot=0x2F895,
 },
 [0x2F896]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0380",
  direction="l",
  linebreak="id",
  specials={ "char", 0x38C7 },
  unicodeslot=0x2F896,
 },
 [0x2F897]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0381",
  direction="l",
  linebreak="id",
  specials={ "char", 0x232B8 },
  unicodeslot=0x2F897,
 },
 [0x2F898]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0382",
  direction="l",
  linebreak="id",
  specials={ "char", 0x261DA },
  unicodeslot=0x2F898,
 },
 [0x2F899]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0383",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F62 },
  unicodeslot=0x2F899,
 },
 [0x2F89A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0059A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F6B },
  unicodeslot=0x2F89A,
 },
 [0x2F89B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0059B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x38E3 },
  unicodeslot=0x2F89B,
 },
 [0x2F89C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0059C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5F9A },
  unicodeslot=0x2F89C,
 },
 [0x2F89D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0059D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5FCD },
  unicodeslot=0x2F89D,
 },
 [0x2F89E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0059E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5FD7 },
  unicodeslot=0x2F89E,
 },
 [0x2F89F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0059F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5FF9 },
  unicodeslot=0x2F89F,
 },
 [0x2F8A0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6081 },
  unicodeslot=0x2F8A0,
 },
 [0x2F8A1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x393A },
  unicodeslot=0x2F8A1,
 },
 [0x2F8A2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x391C },
  unicodeslot=0x2F8A2,
 },
 [0x2F8A3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6094 },
  unicodeslot=0x2F8A3,
 },
 [0x2F8A4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x226D4 },
  unicodeslot=0x2F8A4,
 },
 [0x2F8A5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x60C7 },
  unicodeslot=0x2F8A5,
 },
 [0x2F8A6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6148 },
  unicodeslot=0x2F8A6,
 },
 [0x2F8A7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x614C },
  unicodeslot=0x2F8A7,
 },
 [0x2F8A8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x614E },
  unicodeslot=0x2F8A8,
 },
 [0x2F8A9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008A0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x614C },
  unicodeslot=0x2F8A9,
 },
 [0x2F8AA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008AA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x617A },
  unicodeslot=0x2F8AA,
 },
 [0x2F8AB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008AB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x618E },
  unicodeslot=0x2F8AB,
 },
 [0x2F8AC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008AC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61B2 },
  unicodeslot=0x2F8AC,
 },
 [0x2F8AD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008AD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61A4 },
  unicodeslot=0x2F8AD,
 },
 [0x2F8AE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008AE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61AF },
  unicodeslot=0x2F8AE,
 },
 [0x2F8AF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008AF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61DE },
  unicodeslot=0x2F8AF,
 },
 [0x2F8B0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61F2 },
  unicodeslot=0x2F8B0,
 },
 [0x2F8B1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x61F6 },
  unicodeslot=0x2F8B1,
 },
 [0x2F8B2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6210 },
  unicodeslot=0x2F8B2,
 },
 [0x2F8B3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x621B },
  unicodeslot=0x2F8B3,
 },
 [0x2F8B4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x625D },
  unicodeslot=0x2F8B4,
 },
 [0x2F8B5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x62B1 },
  unicodeslot=0x2F8B5,
 },
 [0x2F8B6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x62D4 },
  unicodeslot=0x2F8B6,
 },
 [0x2F8B7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6350 },
  unicodeslot=0x2F8B7,
 },
 [0x2F8B8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x22B0C },
  unicodeslot=0x2F8B8,
 },
 [0x2F8B9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008B0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x633D },
  unicodeslot=0x2F8B9,
 },
 [0x2F8BA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x62FC },
  unicodeslot=0x2F8BA,
 },
 [0x2F8BB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008BB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6368 },
  unicodeslot=0x2F8BB,
 },
 [0x2F8BC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008BC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6383 },
  unicodeslot=0x2F8BC,
 },
 [0x2F8BD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008BD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x63E4 },
  unicodeslot=0x2F8BD,
 },
 [0x2F8BE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x22BF1 },
  unicodeslot=0x2F8BE,
 },
 [0x2F8BF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008BF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6422 },
  unicodeslot=0x2F8BF,
 },
 [0x2F8C0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x63C5 },
  unicodeslot=0x2F8C0,
 },
 [0x2F8C1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x63A9 },
  unicodeslot=0x2F8C1,
 },
 [0x2F8C2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3A2E },
  unicodeslot=0x2F8C2,
 },
 [0x2F8C3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6469 },
  unicodeslot=0x2F8C3,
 },
 [0x2F8C4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x647E },
  unicodeslot=0x2F8C4,
 },
 [0x2F8C5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x649D },
  unicodeslot=0x2F8C5,
 },
 [0x2F8C6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6477 },
  unicodeslot=0x2F8C6,
 },
 [0x2F8C7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3A6C },
  unicodeslot=0x2F8C7,
 },
 [0x2F8C8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x654F },
  unicodeslot=0x2F8C8,
 },
 [0x2F8C9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008C0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x656C },
  unicodeslot=0x2F8C9,
 },
 [0x2F8CA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008CA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2300A },
  unicodeslot=0x2F8CA,
 },
 [0x2F8CB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008CB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x65E3 },
  unicodeslot=0x2F8CB,
 },
 [0x2F8CC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008CC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x66F8 },
  unicodeslot=0x2F8CC,
 },
 [0x2F8CD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008CD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6649 },
  unicodeslot=0x2F8CD,
 },
 [0x2F8CE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008CE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3B19 },
  unicodeslot=0x2F8CE,
 },
 [0x2F8CF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008CF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6691 },
  unicodeslot=0x2F8CF,
 },
 [0x2F8D0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3B08 },
  unicodeslot=0x2F8D0,
 },
 [0x2F8D1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3AE4 },
  unicodeslot=0x2F8D1,
 },
 [0x2F8D2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5192 },
  unicodeslot=0x2F8D2,
 },
 [0x2F8D3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5195 },
  unicodeslot=0x2F8D3,
 },
 [0x2F8D4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6700 },
  unicodeslot=0x2F8D4,
 },
 [0x2F8D5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x669C },
  unicodeslot=0x2F8D5,
 },
 [0x2F8D6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x80AD },
  unicodeslot=0x2F8D6,
 },
 [0x2F8D7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x43D9 },
  unicodeslot=0x2F8D7,
 },
 [0x2F8D8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6717 },
  unicodeslot=0x2F8D8,
 },
 [0x2F8D9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008D0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x671B },
  unicodeslot=0x2F8D9,
 },
 [0x2F8DA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6721 },
  unicodeslot=0x2F8DA,
 },
 [0x2F8DB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008DB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x675E },
  unicodeslot=0x2F8DB,
 },
 [0x2F8DC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008DC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6753 },
  unicodeslot=0x2F8DC,
 },
 [0x2F8DD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008DD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x233C3 },
  unicodeslot=0x2F8DD,
 },
 [0x2F8DE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3B49 },
  unicodeslot=0x2F8DE,
 },
 [0x2F8DF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008DF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x67FA },
  unicodeslot=0x2F8DF,
 },
 [0x2F8E0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6785 },
  unicodeslot=0x2F8E0,
 },
 [0x2F8E1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6852 },
  unicodeslot=0x2F8E1,
 },
 [0x2F8E2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6885 },
  unicodeslot=0x2F8E2,
 },
 [0x2F8E3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2346D },
  unicodeslot=0x2F8E3,
 },
 [0x2F8E4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x688E },
  unicodeslot=0x2F8E4,
 },
 [0x2F8E5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x681F },
  unicodeslot=0x2F8E5,
 },
 [0x2F8E6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6914 },
  unicodeslot=0x2F8E6,
 },
 [0x2F8E7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3B9D },
  unicodeslot=0x2F8E7,
 },
 [0x2F8E8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6942 },
  unicodeslot=0x2F8E8,
 },
 [0x2F8E9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008E0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x69A3 },
  unicodeslot=0x2F8E9,
 },
 [0x2F8EA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008EA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x69EA },
  unicodeslot=0x2F8EA,
 },
 [0x2F8EB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008EB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6AA8 },
  unicodeslot=0x2F8EB,
 },
 [0x2F8EC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008EC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x236A3 },
  unicodeslot=0x2F8EC,
 },
 [0x2F8ED]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008ED",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6ADB },
  unicodeslot=0x2F8ED,
 },
 [0x2F8EE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008EE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3C18 },
  unicodeslot=0x2F8EE,
 },
 [0x2F8EF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008EF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6B21 },
  unicodeslot=0x2F8EF,
 },
 [0x2F8F0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x238A7 },
  unicodeslot=0x2F8F0,
 },
 [0x2F8F1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6B54 },
  unicodeslot=0x2F8F1,
 },
 [0x2F8F2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3C4E },
  unicodeslot=0x2F8F2,
 },
 [0x2F8F3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6B72 },
  unicodeslot=0x2F8F3,
 },
 [0x2F8F4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6B9F },
  unicodeslot=0x2F8F4,
 },
 [0x2F8F5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6BBA },
  unicodeslot=0x2F8F5,
 },
 [0x2F8F6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6BBB },
  unicodeslot=0x2F8F6,
 },
 [0x2F8F7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x23A8D },
  unicodeslot=0x2F8F7,
 },
 [0x2F8F8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x21D0B },
  unicodeslot=0x2F8F8,
 },
 [0x2F8F9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008F0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x23AFA },
  unicodeslot=0x2F8F9,
 },
 [0x2F8FA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008FA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6C4E },
  unicodeslot=0x2F8FA,
 },
 [0x2F8FB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008FB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x23CBC },
  unicodeslot=0x2F8FB,
 },
 [0x2F8FC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008FC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6CBF },
  unicodeslot=0x2F8FC,
 },
 [0x2F8FD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008FD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6CCD },
  unicodeslot=0x2F8FD,
 },
 [0x2F8FE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008FE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6C67 },
  unicodeslot=0x2F8FE,
 },
 [0x2F8FF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0008FF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D16 },
  unicodeslot=0x2F8FF,
 },
 [0x2F900]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0384",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D3E },
  unicodeslot=0x2F900,
 },
 [0x2F901]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0385",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D77 },
  unicodeslot=0x2F901,
 },
 [0x2F902]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0386",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D41 },
  unicodeslot=0x2F902,
 },
 [0x2F903]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0387",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D69 },
  unicodeslot=0x2F903,
 },
 [0x2F904]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0388",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D78 },
  unicodeslot=0x2F904,
 },
 [0x2F905]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0389",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D85 },
  unicodeslot=0x2F905,
 },
 [0x2F906]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x038A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x23D1E },
  unicodeslot=0x2F906,
 },
 [0x2F907]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x038B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6D34 },
  unicodeslot=0x2F907,
 },
 [0x2F908]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x038C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6E2F },
  unicodeslot=0x2F908,
 },
 [0x2F909]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x038D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6E6E },
  unicodeslot=0x2F909,
 },
 [0x2F90A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005AA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3D33 },
  unicodeslot=0x2F90A,
 },
 [0x2F90B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005AB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6ECB },
  unicodeslot=0x2F90B,
 },
 [0x2F90C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005AC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6EC7 },
  unicodeslot=0x2F90C,
 },
 [0x2F90D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005AD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x23ED1 },
  unicodeslot=0x2F90D,
 },
 [0x2F90E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005AE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6DF9 },
  unicodeslot=0x2F90E,
 },
 [0x2F90F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005AF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6F6E },
  unicodeslot=0x2F90F,
 },
 [0x2F910]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x038E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x23F5E },
  unicodeslot=0x2F910,
 },
 [0x2F911]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x038F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x23F8E },
  unicodeslot=0x2F911,
 },
 [0x2F912]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0390",
  direction="l",
  linebreak="id",
  specials={ "char", 0x6FC6 },
  unicodeslot=0x2F912,
 },
 [0x2F913]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0391",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7039 },
  unicodeslot=0x2F913,
 },
 [0x2F914]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0392",
  direction="l",
  linebreak="id",
  specials={ "char", 0x701E },
  unicodeslot=0x2F914,
 },
 [0x2F915]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0393",
  direction="l",
  linebreak="id",
  specials={ "char", 0x701B },
  unicodeslot=0x2F915,
 },
 [0x2F916]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0394",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3D96 },
  unicodeslot=0x2F916,
 },
 [0x2F917]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0395",
  direction="l",
  linebreak="id",
  specials={ "char", 0x704A },
  unicodeslot=0x2F917,
 },
 [0x2F918]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0396",
  direction="l",
  linebreak="id",
  specials={ "char", 0x707D },
  unicodeslot=0x2F918,
 },
 [0x2F919]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0397",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7077 },
  unicodeslot=0x2F919,
 },
 [0x2F91A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x70AD },
  unicodeslot=0x2F91A,
 },
 [0x2F91B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005BB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x20525 },
  unicodeslot=0x2F91B,
 },
 [0x2F91C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005BC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7145 },
  unicodeslot=0x2F91C,
 },
 [0x2F91D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005BD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x24263 },
  unicodeslot=0x2F91D,
 },
 [0x2F91E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x719C },
  unicodeslot=0x2F91E,
 },
 [0x2F91F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005BF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x243AB },
  unicodeslot=0x2F91F,
 },
 [0x2F920]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0398",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7228 },
  unicodeslot=0x2F920,
 },
 [0x2F921]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0399",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7235 },
  unicodeslot=0x2F921,
 },
 [0x2F922]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x039A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7250 },
  unicodeslot=0x2F922,
 },
 [0x2F923]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x039B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x24608 },
  unicodeslot=0x2F923,
 },
 [0x2F924]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x039C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7280 },
  unicodeslot=0x2F924,
 },
 [0x2F925]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x039D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7295 },
  unicodeslot=0x2F925,
 },
 [0x2F926]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x039E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x24735 },
  unicodeslot=0x2F926,
 },
 [0x2F927]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x039F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x24814 },
  unicodeslot=0x2F927,
 },
 [0x2F928]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x737A },
  unicodeslot=0x2F928,
 },
 [0x2F929]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x738B },
  unicodeslot=0x2F929,
 },
 [0x2F92A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005CA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3EAC },
  unicodeslot=0x2F92A,
 },
 [0x2F92B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005CB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x73A5 },
  unicodeslot=0x2F92B,
 },
 [0x2F92C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005CC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3EB8 },
  unicodeslot=0x2F92C,
 },
 [0x2F92D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005CD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3EB8 },
  unicodeslot=0x2F92D,
 },
 [0x2F92E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005CE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7447 },
  unicodeslot=0x2F92E,
 },
 [0x2F92F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005CF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x745C },
  unicodeslot=0x2F92F,
 },
 [0x2F930]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7471 },
  unicodeslot=0x2F930,
 },
 [0x2F931]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7485 },
  unicodeslot=0x2F931,
 },
 [0x2F932]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x74CA },
  unicodeslot=0x2F932,
 },
 [0x2F933]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3F1B },
  unicodeslot=0x2F933,
 },
 [0x2F934]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7524 },
  unicodeslot=0x2F934,
 },
 [0x2F935]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x24C36 },
  unicodeslot=0x2F935,
 },
 [0x2F936]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A8",
  direction="l",
  linebreak="id",
  specials={ "char", 0x753E },
  unicodeslot=0x2F936,
 },
 [0x2F937]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03A9",
  direction="l",
  linebreak="id",
  specials={ "char", 0x24C92 },
  unicodeslot=0x2F937,
 },
 [0x2F938]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03AA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7570 },
  unicodeslot=0x2F938,
 },
 [0x2F939]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03AB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2219F },
  unicodeslot=0x2F939,
 },
 [0x2F93A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7610 },
  unicodeslot=0x2F93A,
 },
 [0x2F93B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005DB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x24FA1 },
  unicodeslot=0x2F93B,
 },
 [0x2F93C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005DC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x24FB8 },
  unicodeslot=0x2F93C,
 },
 [0x2F93D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005DD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25044 },
  unicodeslot=0x2F93D,
 },
 [0x2F93E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x3FFC },
  unicodeslot=0x2F93E,
 },
 [0x2F93F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005DF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4008 },
  unicodeslot=0x2F93F,
 },
 [0x2F940]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03AC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x76F4 },
  unicodeslot=0x2F940,
 },
 [0x2F941]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03AD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x250F3 },
  unicodeslot=0x2F941,
 },
 [0x2F942]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03AE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x250F2 },
  unicodeslot=0x2F942,
 },
 [0x2F943]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03AF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25119 },
  unicodeslot=0x2F943,
 },
 [0x2F944]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25133 },
  unicodeslot=0x2F944,
 },
 [0x2F945]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x771E },
  unicodeslot=0x2F945,
 },
 [0x2F946]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x771F },
  unicodeslot=0x2F946,
 },
 [0x2F947]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x771F },
  unicodeslot=0x2F947,
 },
 [0x2F948]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x774A },
  unicodeslot=0x2F948,
 },
 [0x2F949]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4039 },
  unicodeslot=0x2F949,
 },
 [0x2F94A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005EA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x778B },
  unicodeslot=0x2F94A,
 },
 [0x2F94B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005EB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4046 },
  unicodeslot=0x2F94B,
 },
 [0x2F94C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005EC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4096 },
  unicodeslot=0x2F94C,
 },
 [0x2F94D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005ED",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2541D },
  unicodeslot=0x2F94D,
 },
 [0x2F94E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005EE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x784E },
  unicodeslot=0x2F94E,
 },
 [0x2F94F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005EF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x788C },
  unicodeslot=0x2F94F,
 },
 [0x2F950]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x78CC },
  unicodeslot=0x2F950,
 },
 [0x2F951]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x40E3 },
  unicodeslot=0x2F951,
 },
 [0x2F952]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B8",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25626 },
  unicodeslot=0x2F952,
 },
 [0x2F953]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03B9",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7956 },
  unicodeslot=0x2F953,
 },
 [0x2F954]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2569A },
  unicodeslot=0x2F954,
 },
 [0x2F955]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03BB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x256C5 },
  unicodeslot=0x2F955,
 },
 [0x2F956]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03BC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x798F },
  unicodeslot=0x2F956,
 },
 [0x2F957]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03BD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x79EB },
  unicodeslot=0x2F957,
 },
 [0x2F958]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x412F },
  unicodeslot=0x2F958,
 },
 [0x2F959]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03BF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7A40 },
  unicodeslot=0x2F959,
 },
 [0x2F95A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005FA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7A4A },
  unicodeslot=0x2F95A,
 },
 [0x2F95B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005FB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7A4F },
  unicodeslot=0x2F95B,
 },
 [0x2F95C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005FC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2597C },
  unicodeslot=0x2F95C,
 },
 [0x2F95D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005FD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25AA7 },
  unicodeslot=0x2F95D,
 },
 [0x2F95E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005FE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25AA7 },
  unicodeslot=0x2F95E,
 },
 [0x2F95F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x005FF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7AEE },
  unicodeslot=0x2F95F,
 },
 [0x2F960]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4202 },
  unicodeslot=0x2F960,
 },
 [0x2F961]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25BAB },
  unicodeslot=0x2F961,
 },
 [0x2F962]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7BC6 },
  unicodeslot=0x2F962,
 },
 [0x2F963]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7BC9 },
  unicodeslot=0x2F963,
 },
 [0x2F964]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4227 },
  unicodeslot=0x2F964,
 },
 [0x2F965]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25C80 },
  unicodeslot=0x2F965,
 },
 [0x2F966]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7CD2 },
  unicodeslot=0x2F966,
 },
 [0x2F967]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x42A0 },
  unicodeslot=0x2F967,
 },
 [0x2F968]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C8",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7CE8 },
  unicodeslot=0x2F968,
 },
 [0x2F969]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03C9",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7CE3 },
  unicodeslot=0x2F969,
 },
 [0x2F96A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0060A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7D00 },
  unicodeslot=0x2F96A,
 },
 [0x2F96B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0060B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x25F86 },
  unicodeslot=0x2F96B,
 },
 [0x2F96C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0060C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7D63 },
  unicodeslot=0x2F96C,
 },
 [0x2F96D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0060D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4301 },
  unicodeslot=0x2F96D,
 },
 [0x2F96E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0060E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7DC7 },
  unicodeslot=0x2F96E,
 },
 [0x2F96F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0060F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7E02 },
  unicodeslot=0x2F96F,
 },
 [0x2F970]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03CA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7E45 },
  unicodeslot=0x2F970,
 },
 [0x2F971]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03CB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4334 },
  unicodeslot=0x2F971,
 },
 [0x2F972]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03CC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26228 },
  unicodeslot=0x2F972,
 },
 [0x2F973]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03CD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26247 },
  unicodeslot=0x2F973,
 },
 [0x2F974]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03CE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4359 },
  unicodeslot=0x2F974,
 },
 [0x2F975]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03CF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x262D9 },
  unicodeslot=0x2F975,
 },
 [0x2F976]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7F7A },
  unicodeslot=0x2F976,
 },
 [0x2F977]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2633E },
  unicodeslot=0x2F977,
 },
 [0x2F978]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7F95 },
  unicodeslot=0x2F978,
 },
 [0x2F979]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x7FFA },
  unicodeslot=0x2F979,
 },
 [0x2F97A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0061A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8005 },
  unicodeslot=0x2F97A,
 },
 [0x2F97B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0061B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x264DA },
  unicodeslot=0x2F97B,
 },
 [0x2F97C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0061C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26523 },
  unicodeslot=0x2F97C,
 },
 [0x2F97D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0061D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8060 },
  unicodeslot=0x2F97D,
 },
 [0x2F97E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0061E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x265A8 },
  unicodeslot=0x2F97E,
 },
 [0x2F97F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0061F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8070 },
  unicodeslot=0x2F97F,
 },
 [0x2F980]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2335F },
  unicodeslot=0x2F980,
 },
 [0x2F981]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x43D5 },
  unicodeslot=0x2F981,
 },
 [0x2F982]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x80B2 },
  unicodeslot=0x2F982,
 },
 [0x2F983]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8103 },
  unicodeslot=0x2F983,
 },
 [0x2F984]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D8",
  direction="l",
  linebreak="id",
  specials={ "char", 0x440B },
  unicodeslot=0x2F984,
 },
 [0x2F985]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03D9",
  direction="l",
  linebreak="id",
  specials={ "char", 0x813E },
  unicodeslot=0x2F985,
 },
 [0x2F986]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5AB5 },
  unicodeslot=0x2F986,
 },
 [0x2F987]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03DB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x267A7 },
  unicodeslot=0x2F987,
 },
 [0x2F988]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03DC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x267B5 },
  unicodeslot=0x2F988,
 },
 [0x2F989]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03DD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x23393 },
  unicodeslot=0x2F989,
 },
 [0x2F98A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0062A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2339C },
  unicodeslot=0x2F98A,
 },
 [0x2F98B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0062B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8201 },
  unicodeslot=0x2F98B,
 },
 [0x2F98C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0062C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8204 },
  unicodeslot=0x2F98C,
 },
 [0x2F98D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0062D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8F9E },
  unicodeslot=0x2F98D,
 },
 [0x2F98E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0062E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x446B },
  unicodeslot=0x2F98E,
 },
 [0x2F98F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0062F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8291 },
  unicodeslot=0x2F98F,
 },
 [0x2F990]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x828B },
  unicodeslot=0x2F990,
 },
 [0x2F991]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03DF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x829D },
  unicodeslot=0x2F991,
 },
 [0x2F992]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03E0",
  direction="l",
  linebreak="id",
  specials={ "char", 0x52B3 },
  unicodeslot=0x2F992,
 },
 [0x2F993]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03E1",
  direction="l",
  linebreak="id",
  specials={ "char", 0x82B1 },
  unicodeslot=0x2F993,
 },
 [0x2F994]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03E2",
  direction="l",
  linebreak="id",
  specials={ "char", 0x82B3 },
  unicodeslot=0x2F994,
 },
 [0x2F995]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03E3",
  direction="l",
  linebreak="id",
  specials={ "char", 0x82BD },
  unicodeslot=0x2F995,
 },
 [0x2F996]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03E4",
  direction="l",
  linebreak="id",
  specials={ "char", 0x82E6 },
  unicodeslot=0x2F996,
 },
 [0x2F997]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03E5",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26B3C },
  unicodeslot=0x2F997,
 },
 [0x2F998]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03E6",
  direction="l",
  linebreak="id",
  specials={ "char", 0x82E5 },
  unicodeslot=0x2F998,
 },
 [0x2F999]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x03E7",
  direction="l",
  linebreak="id",
  specials={ "char", 0x831D },
  unicodeslot=0x2F999,
 },
 [0x2F99A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0063A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8363 },
  unicodeslot=0x2F99A,
 },
 [0x2F99B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0063B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83AD },
  unicodeslot=0x2F99B,
 },
 [0x2F99C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0063C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8323 },
  unicodeslot=0x2F99C,
 },
 [0x2F99D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0063D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83BD },
  unicodeslot=0x2F99D,
 },
 [0x2F99E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0063E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83E7 },
  unicodeslot=0x2F99E,
 },
 [0x2F99F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0063F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8457 },
  unicodeslot=0x2F99F,
 },
 [0x2F9A0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8353 },
  unicodeslot=0x2F9A0,
 },
 [0x2F9A1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83CA },
  unicodeslot=0x2F9A1,
 },
 [0x2F9A2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83CC },
  unicodeslot=0x2F9A2,
 },
 [0x2F9A3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x83DC },
  unicodeslot=0x2F9A3,
 },
 [0x2F9A4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26C36 },
  unicodeslot=0x2F9A4,
 },
 [0x2F9A5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26D6B },
  unicodeslot=0x2F9A5,
 },
 [0x2F9A6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26CD5 },
  unicodeslot=0x2F9A6,
 },
 [0x2F9A7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x452B },
  unicodeslot=0x2F9A7,
 },
 [0x2F9A8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x84F1 },
  unicodeslot=0x2F9A8,
 },
 [0x2F9A9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009A0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x84F3 },
  unicodeslot=0x2F9A9,
 },
 [0x2F9AA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009AA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8516 },
  unicodeslot=0x2F9AA,
 },
 [0x2F9AB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009AB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x273CA },
  unicodeslot=0x2F9AB,
 },
 [0x2F9AC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009AC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8564 },
  unicodeslot=0x2F9AC,
 },
 [0x2F9AD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009AD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26F2C },
  unicodeslot=0x2F9AD,
 },
 [0x2F9AE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009AE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x455D },
  unicodeslot=0x2F9AE,
 },
 [0x2F9AF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009AF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4561 },
  unicodeslot=0x2F9AF,
 },
 [0x2F9B0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x26FB1 },
  unicodeslot=0x2F9B0,
 },
 [0x2F9B1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x270D2 },
  unicodeslot=0x2F9B1,
 },
 [0x2F9B2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x456B },
  unicodeslot=0x2F9B2,
 },
 [0x2F9B3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8650 },
  unicodeslot=0x2F9B3,
 },
 [0x2F9B4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x865C },
  unicodeslot=0x2F9B4,
 },
 [0x2F9B5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8667 },
  unicodeslot=0x2F9B5,
 },
 [0x2F9B6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8669 },
  unicodeslot=0x2F9B6,
 },
 [0x2F9B7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x86A9 },
  unicodeslot=0x2F9B7,
 },
 [0x2F9B8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8688 },
  unicodeslot=0x2F9B8,
 },
 [0x2F9B9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009B0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x870E },
  unicodeslot=0x2F9B9,
 },
 [0x2F9BA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009BA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x86E2 },
  unicodeslot=0x2F9BA,
 },
 [0x2F9BB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009BB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8779 },
  unicodeslot=0x2F9BB,
 },
 [0x2F9BC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009BC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8728 },
  unicodeslot=0x2F9BC,
 },
 [0x2F9BD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009BD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x876B },
  unicodeslot=0x2F9BD,
 },
 [0x2F9BE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009BE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8786 },
  unicodeslot=0x2F9BE,
 },
 [0x2F9BF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009BF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x45D7 },
  unicodeslot=0x2F9BF,
 },
 [0x2F9C0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x87E1 },
  unicodeslot=0x2F9C0,
 },
 [0x2F9C1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8801 },
  unicodeslot=0x2F9C1,
 },
 [0x2F9C2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x45F9 },
  unicodeslot=0x2F9C2,
 },
 [0x2F9C3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8860 },
  unicodeslot=0x2F9C3,
 },
 [0x2F9C4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8863 },
  unicodeslot=0x2F9C4,
 },
 [0x2F9C5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x27667 },
  unicodeslot=0x2F9C5,
 },
 [0x2F9C6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x88D7 },
  unicodeslot=0x2F9C6,
 },
 [0x2F9C7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x88DE },
  unicodeslot=0x2F9C7,
 },
 [0x2F9C8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4635 },
  unicodeslot=0x2F9C8,
 },
 [0x2F9C9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009C0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x88FA },
  unicodeslot=0x2F9C9,
 },
 [0x2F9CA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009CA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x34BB },
  unicodeslot=0x2F9CA,
 },
 [0x2F9CB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009CB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x278AE },
  unicodeslot=0x2F9CB,
 },
 [0x2F9CC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009CC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x27966 },
  unicodeslot=0x2F9CC,
 },
 [0x2F9CD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009CD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x46BE },
  unicodeslot=0x2F9CD,
 },
 [0x2F9CE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009CE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x46C7 },
  unicodeslot=0x2F9CE,
 },
 [0x2F9CF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009CF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AA0 },
  unicodeslot=0x2F9CF,
 },
 [0x2F9D0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8AED },
  unicodeslot=0x2F9D0,
 },
 [0x2F9D1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8B8A },
  unicodeslot=0x2F9D1,
 },
 [0x2F9D2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8C55 },
  unicodeslot=0x2F9D2,
 },
 [0x2F9D3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x27CA8 },
  unicodeslot=0x2F9D3,
 },
 [0x2F9D4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8CAB },
  unicodeslot=0x2F9D4,
 },
 [0x2F9D5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8CC1 },
  unicodeslot=0x2F9D5,
 },
 [0x2F9D6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8D1B },
  unicodeslot=0x2F9D6,
 },
 [0x2F9D7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8D77 },
  unicodeslot=0x2F9D7,
 },
 [0x2F9D8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x27F2F },
  unicodeslot=0x2F9D8,
 },
 [0x2F9D9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009D0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x20804 },
  unicodeslot=0x2F9D9,
 },
 [0x2F9DA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009DA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8DCB },
  unicodeslot=0x2F9DA,
 },
 [0x2F9DB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009DB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8DBC },
  unicodeslot=0x2F9DB,
 },
 [0x2F9DC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009DC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8DF0 },
  unicodeslot=0x2F9DC,
 },
 [0x2F9DD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009DD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x208DE },
  unicodeslot=0x2F9DD,
 },
 [0x2F9DE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009DE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8ED4 },
  unicodeslot=0x2F9DE,
 },
 [0x2F9DF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009DF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x8F38 },
  unicodeslot=0x2F9DF,
 },
 [0x2F9E0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x285D2 },
  unicodeslot=0x2F9E0,
 },
 [0x2F9E1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x285ED },
  unicodeslot=0x2F9E1,
 },
 [0x2F9E2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9094 },
  unicodeslot=0x2F9E2,
 },
 [0x2F9E3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x90F1 },
  unicodeslot=0x2F9E3,
 },
 [0x2F9E4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9111 },
  unicodeslot=0x2F9E4,
 },
 [0x2F9E5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2872E },
  unicodeslot=0x2F9E5,
 },
 [0x2F9E6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x911B },
  unicodeslot=0x2F9E6,
 },
 [0x2F9E7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9238 },
  unicodeslot=0x2F9E7,
 },
 [0x2F9E8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x92D7 },
  unicodeslot=0x2F9E8,
 },
 [0x2F9E9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009E0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x92D8 },
  unicodeslot=0x2F9E9,
 },
 [0x2F9EA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009EA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x927C },
  unicodeslot=0x2F9EA,
 },
 [0x2F9EB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009EB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x93F9 },
  unicodeslot=0x2F9EB,
 },
 [0x2F9EC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009EC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9415 },
  unicodeslot=0x2F9EC,
 },
 [0x2F9ED]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009ED",
  direction="l",
  linebreak="id",
  specials={ "char", 0x28BFA },
  unicodeslot=0x2F9ED,
 },
 [0x2F9EE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009EE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x958B },
  unicodeslot=0x2F9EE,
 },
 [0x2F9EF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009EF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4995 },
  unicodeslot=0x2F9EF,
 },
 [0x2F9F0]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x95B7 },
  unicodeslot=0x2F9F0,
 },
 [0x2F9F1]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x28D77 },
  unicodeslot=0x2F9F1,
 },
 [0x2F9F2]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x49E6 },
  unicodeslot=0x2F9F2,
 },
 [0x2F9F3]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x96C3 },
  unicodeslot=0x2F9F3,
 },
 [0x2F9F4]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x5DB2 },
  unicodeslot=0x2F9F4,
 },
 [0x2F9F5]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9723 },
  unicodeslot=0x2F9F5,
 },
 [0x2F9F6]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x29145 },
  unicodeslot=0x2F9F6,
 },
 [0x2F9F7]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2921A },
  unicodeslot=0x2F9F7,
 },
 [0x2F9F8]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4A6E },
  unicodeslot=0x2F9F8,
 },
 [0x2F9F9]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009F0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4A76 },
  unicodeslot=0x2F9F9,
 },
 [0x2F9FA]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009FA",
  direction="l",
  linebreak="id",
  specials={ "char", 0x97E0 },
  unicodeslot=0x2F9FA,
 },
 [0x2F9FB]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009FB",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2940A },
  unicodeslot=0x2F9FB,
 },
 [0x2F9FC]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009FC",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4AB2 },
  unicodeslot=0x2F9FC,
 },
 [0x2F9FD]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009FD",
  direction="l",
  linebreak="id",
  specials={ "char", 0x29496 },
  unicodeslot=0x2F9FD,
 },
 [0x2F9FE]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009FE",
  direction="l",
  linebreak="id",
  specials={ "char", 0x980B },
  unicodeslot=0x2F9FE,
 },
 [0x2F9FF]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002F0x0009FF",
  direction="l",
  linebreak="id",
  specials={ "char", 0x980B },
  unicodeslot=0x2F9FF,
 },
 [0x2FA00]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0000",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9829 },
  unicodeslot=0x2FA00,
 },
 [0x2FA01]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0001",
  direction="l",
  linebreak="id",
  specials={ "char", 0x295B6 },
  unicodeslot=0x2FA01,
 },
 [0x2FA02]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0002",
  direction="l",
  linebreak="id",
  specials={ "char", 0x98E2 },
  unicodeslot=0x2FA02,
 },
 [0x2FA03]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0003",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4B33 },
  unicodeslot=0x2FA03,
 },
 [0x2FA04]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0004",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9929 },
  unicodeslot=0x2FA04,
 },
 [0x2FA05]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0005",
  direction="l",
  linebreak="id",
  specials={ "char", 0x99A7 },
  unicodeslot=0x2FA05,
 },
 [0x2FA06]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0006",
  direction="l",
  linebreak="id",
  specials={ "char", 0x99C2 },
  unicodeslot=0x2FA06,
 },
 [0x2FA07]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0007",
  direction="l",
  linebreak="id",
  specials={ "char", 0x99FE },
  unicodeslot=0x2FA07,
 },
 [0x2FA08]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0008",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4BCE },
  unicodeslot=0x2FA08,
 },
 [0x2FA09]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0009",
  direction="l",
  linebreak="id",
  specials={ "char", 0x29B30 },
  unicodeslot=0x2FA09,
 },
 [0x2FA0A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0000A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9B12 },
  unicodeslot=0x2FA0A,
 },
 [0x2FA0B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0000B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9C40 },
  unicodeslot=0x2FA0B,
 },
 [0x2FA0C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0000C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9CFD },
  unicodeslot=0x2FA0C,
 },
 [0x2FA0D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0000D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4CCE },
  unicodeslot=0x2FA0D,
 },
 [0x2FA0E]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0000E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4CED },
  unicodeslot=0x2FA0E,
 },
 [0x2FA0F]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0000F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9D67 },
  unicodeslot=0x2FA0F,
 },
 [0x2FA10]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x000A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2A0CE },
  unicodeslot=0x2FA10,
 },
 [0x2FA11]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x000B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4CF8 },
  unicodeslot=0x2FA11,
 },
 [0x2FA12]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x000C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2A105 },
  unicodeslot=0x2FA12,
 },
 [0x2FA13]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x000D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2A20E },
  unicodeslot=0x2FA13,
 },
 [0x2FA14]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x000E",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2A291 },
  unicodeslot=0x2FA14,
 },
 [0x2FA15]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x000F",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9EBB },
  unicodeslot=0x2FA15,
 },
 [0x2FA16]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0010",
  direction="l",
  linebreak="id",
  specials={ "char", 0x4D56 },
  unicodeslot=0x2FA16,
 },
 [0x2FA17]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0011",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9EF9 },
  unicodeslot=0x2FA17,
 },
 [0x2FA18]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0012",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9EFE },
  unicodeslot=0x2FA18,
 },
 [0x2FA19]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0013",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F05 },
  unicodeslot=0x2FA19,
 },
 [0x2FA1A]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0001A",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F0F },
  unicodeslot=0x2FA1A,
 },
 [0x2FA1B]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0001B",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F16 },
  unicodeslot=0x2FA1B,
 },
 [0x2FA1C]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0001C",
  direction="l",
  linebreak="id",
  specials={ "char", 0x9F3B },
  unicodeslot=0x2FA1C,
 },
 [0x2FA1D]={
  category="lo",
  cjkwd="w",
  description="CJK COMPATIBILITY IDEOGRAPH-0x0002FA0x0001D",
  direction="l",
  linebreak="id",
  specials={ "char", 0x2A600 },
  unicodeslot=0x2FA1D,
 },
 [0xE0001]={
  category="cf",
  description="LANGUAGE TAG",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0001,
 },
 [0xE0020]={
  category="cf",
  description="TAG SPACE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0020,
 },
 [0xE0021]={
  category="cf",
  description="TAG EXCLAMATION MARK",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0021,
 },
 [0xE0022]={
  category="cf",
  description="TAG QUOTATION MARK",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0022,
 },
 [0xE0023]={
  category="cf",
  description="TAG NUMBER SIGN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0023,
 },
 [0xE0024]={
  category="cf",
  description="TAG DOLLAR SIGN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0024,
 },
 [0xE0025]={
  category="cf",
  description="TAG PERCENT SIGN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0025,
 },
 [0xE0026]={
  category="cf",
  description="TAG AMPERSAND",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0026,
 },
 [0xE0027]={
  category="cf",
  description="TAG APOSTROPHE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0027,
 },
 [0xE0028]={
  category="cf",
  description="TAG LEFT PARENTHESIS",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0028,
 },
 [0xE0029]={
  category="cf",
  description="TAG RIGHT PARENTHESIS",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0029,
 },
 [0xE002A]={
  category="cf",
  description="TAG ASTERISK",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE002A,
 },
 [0xE002B]={
  category="cf",
  description="TAG PLUS SIGN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE002B,
 },
 [0xE002C]={
  category="cf",
  description="TAG COMMA",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE002C,
 },
 [0xE002D]={
  category="cf",
  description="TAG HYPHEN-MINUS",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE002D,
 },
 [0xE002E]={
  category="cf",
  description="TAG FULL STOP",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE002E,
 },
 [0xE002F]={
  category="cf",
  description="TAG SOLIDUS",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE002F,
 },
 [0xE0030]={
  category="cf",
  description="TAG DIGIT ZERO",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0030,
 },
 [0xE0031]={
  category="cf",
  description="TAG DIGIT ONE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0031,
 },
 [0xE0032]={
  category="cf",
  description="TAG DIGIT TWO",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0032,
 },
 [0xE0033]={
  category="cf",
  description="TAG DIGIT THREE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0033,
 },
 [0xE0034]={
  category="cf",
  description="TAG DIGIT FOUR",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0034,
 },
 [0xE0035]={
  category="cf",
  description="TAG DIGIT FIVE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0035,
 },
 [0xE0036]={
  category="cf",
  description="TAG DIGIT SIX",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0036,
 },
 [0xE0037]={
  category="cf",
  description="TAG DIGIT SEVEN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0037,
 },
 [0xE0038]={
  category="cf",
  description="TAG DIGIT EIGHT",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0038,
 },
 [0xE0039]={
  category="cf",
  description="TAG DIGIT NINE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0039,
 },
 [0xE003A]={
  category="cf",
  description="TAG COLON",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE003A,
 },
 [0xE003B]={
  category="cf",
  description="TAG SEMICOLON",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE003B,
 },
 [0xE003C]={
  category="cf",
  description="TAG LESS-THAN SIGN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE003C,
 },
 [0xE003D]={
  category="cf",
  description="TAG EQUALS SIGN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE003D,
 },
 [0xE003E]={
  category="cf",
  description="TAG GREATER-THAN SIGN",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE003E,
 },
 [0xE003F]={
  category="cf",
  description="TAG QUESTION MARK",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE003F,
 },
 [0xE0040]={
  category="cf",
  description="TAG COMMERCIAL AT",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0040,
 },
 [0xE0041]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER A",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0041,
 },
 [0xE0042]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER B",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0042,
 },
 [0xE0043]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER C",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0043,
 },
 [0xE0044]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER D",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0044,
 },
 [0xE0045]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER E",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0045,
 },
 [0xE0046]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER F",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0046,
 },
 [0xE0047]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER G",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0047,
 },
 [0xE0048]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER H",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0048,
 },
 [0xE0049]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER I",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0049,
 },
 [0xE004A]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER J",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE004A,
 },
 [0xE004B]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER K",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE004B,
 },
 [0xE004C]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER L",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE004C,
 },
 [0xE004D]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER M",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE004D,
 },
 [0xE004E]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER N",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE004E,
 },
 [0xE004F]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER O",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE004F,
 },
 [0xE0050]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER P",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0050,
 },
 [0xE0051]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER Q",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0051,
 },
 [0xE0052]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER R",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0052,
 },
 [0xE0053]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER S",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0053,
 },
 [0xE0054]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER T",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0054,
 },
 [0xE0055]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER U",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0055,
 },
 [0xE0056]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER V",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0056,
 },
 [0xE0057]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER W",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0057,
 },
 [0xE0058]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER X",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0058,
 },
 [0xE0059]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER Y",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0059,
 },
 [0xE005A]={
  category="cf",
  description="TAG LATIN CAPITAL LETTER Z",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE005A,
 },
 [0xE005B]={
  category="cf",
  description="TAG LEFT SQUARE BRACKET",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE005B,
 },
 [0xE005C]={
  category="cf",
  description="TAG REVERSE SOLIDUS",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE005C,
 },
 [0xE005D]={
  category="cf",
  description="TAG RIGHT SQUARE BRACKET",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE005D,
 },
 [0xE005E]={
  category="cf",
  description="TAG CIRCUMFLEX ACCENT",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE005E,
 },
 [0xE005F]={
  category="cf",
  description="TAG LOW LINE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE005F,
 },
 [0xE0060]={
  category="cf",
  description="TAG GRAVE ACCENT",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0060,
 },
 [0xE0061]={
  category="cf",
  description="TAG LATIN SMALL LETTER A",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0061,
 },
 [0xE0062]={
  category="cf",
  description="TAG LATIN SMALL LETTER B",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0062,
 },
 [0xE0063]={
  category="cf",
  description="TAG LATIN SMALL LETTER C",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0063,
 },
 [0xE0064]={
  category="cf",
  description="TAG LATIN SMALL LETTER D",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0064,
 },
 [0xE0065]={
  category="cf",
  description="TAG LATIN SMALL LETTER E",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0065,
 },
 [0xE0066]={
  category="cf",
  description="TAG LATIN SMALL LETTER F",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0066,
 },
 [0xE0067]={
  category="cf",
  description="TAG LATIN SMALL LETTER G",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0067,
 },
 [0xE0068]={
  category="cf",
  description="TAG LATIN SMALL LETTER H",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0068,
 },
 [0xE0069]={
  category="cf",
  description="TAG LATIN SMALL LETTER I",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0069,
 },
 [0xE006A]={
  category="cf",
  description="TAG LATIN SMALL LETTER J",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE006A,
 },
 [0xE006B]={
  category="cf",
  description="TAG LATIN SMALL LETTER K",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE006B,
 },
 [0xE006C]={
  category="cf",
  description="TAG LATIN SMALL LETTER L",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE006C,
 },
 [0xE006D]={
  category="cf",
  description="TAG LATIN SMALL LETTER M",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE006D,
 },
 [0xE006E]={
  category="cf",
  description="TAG LATIN SMALL LETTER N",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE006E,
 },
 [0xE006F]={
  category="cf",
  description="TAG LATIN SMALL LETTER O",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE006F,
 },
 [0xE0070]={
  category="cf",
  description="TAG LATIN SMALL LETTER P",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0070,
 },
 [0xE0071]={
  category="cf",
  description="TAG LATIN SMALL LETTER Q",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0071,
 },
 [0xE0072]={
  category="cf",
  description="TAG LATIN SMALL LETTER R",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0072,
 },
 [0xE0073]={
  category="cf",
  description="TAG LATIN SMALL LETTER S",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0073,
 },
 [0xE0074]={
  category="cf",
  description="TAG LATIN SMALL LETTER T",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0074,
 },
 [0xE0075]={
  category="cf",
  description="TAG LATIN SMALL LETTER U",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0075,
 },
 [0xE0076]={
  category="cf",
  description="TAG LATIN SMALL LETTER V",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0076,
 },
 [0xE0077]={
  category="cf",
  description="TAG LATIN SMALL LETTER W",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0077,
 },
 [0xE0078]={
  category="cf",
  description="TAG LATIN SMALL LETTER X",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0078,
 },
 [0xE0079]={
  category="cf",
  description="TAG LATIN SMALL LETTER Y",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE0079,
 },
 [0xE007A]={
  category="cf",
  description="TAG LATIN SMALL LETTER Z",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE007A,
 },
 [0xE007B]={
  category="cf",
  description="TAG LEFT CURLY BRACKET",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE007B,
 },
 [0xE007C]={
  category="cf",
  description="TAG VERTICAL LINE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE007C,
 },
 [0xE007D]={
  category="cf",
  description="TAG RIGHT CURLY BRACKET",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE007D,
 },
 [0xE007E]={
  category="cf",
  description="TAG TILDE",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE007E,
 },
 [0xE007F]={
  category="cf",
  description="CANCEL TAG",
  direction="bn",
  linebreak="cm",
  unicodeslot=0xE007F,
 },
 [0xE0100]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0011",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0100,
 },
 [0xE0101]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0012",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0101,
 },
 [0xE0102]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0013",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0102,
 },
 [0xE0103]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0014",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0103,
 },
 [0xE0104]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0015",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0104,
 },
 [0xE0105]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0016",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0105,
 },
 [0xE0106]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0017",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0106,
 },
 [0xE0107]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0018",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0107,
 },
 [0xE0108]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0019",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0108,
 },
 [0xE0109]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x001A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0109,
 },
 [0xE010A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x001B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE010A,
 },
 [0xE010B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x001C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE010B,
 },
 [0xE010C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x001D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE010C,
 },
 [0xE010D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x001E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE010D,
 },
 [0xE010E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x001F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE010E,
 },
 [0xE010F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0020",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE010F,
 },
 [0xE0110]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0021",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0110,
 },
 [0xE0111]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0022",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0111,
 },
 [0xE0112]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0023",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0112,
 },
 [0xE0113]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0024",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0113,
 },
 [0xE0114]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0025",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0114,
 },
 [0xE0115]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0026",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0115,
 },
 [0xE0116]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0027",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0116,
 },
 [0xE0117]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0028",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0117,
 },
 [0xE0118]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0029",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0118,
 },
 [0xE0119]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x002A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0119,
 },
 [0xE011A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x002B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE011A,
 },
 [0xE011B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x002C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE011B,
 },
 [0xE011C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x002D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE011C,
 },
 [0xE011D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x002E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE011D,
 },
 [0xE011E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x002F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE011E,
 },
 [0xE011F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0030",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE011F,
 },
 [0xE0120]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0031",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0120,
 },
 [0xE0121]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0032",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0121,
 },
 [0xE0122]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0033",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0122,
 },
 [0xE0123]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0034",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0123,
 },
 [0xE0124]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0035",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0124,
 },
 [0xE0125]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0036",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0125,
 },
 [0xE0126]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0037",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0126,
 },
 [0xE0127]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0038",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0127,
 },
 [0xE0128]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0039",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0128,
 },
 [0xE0129]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x003A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0129,
 },
 [0xE012A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x003B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE012A,
 },
 [0xE012B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x003C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE012B,
 },
 [0xE012C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x003D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE012C,
 },
 [0xE012D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x003E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE012D,
 },
 [0xE012E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x003F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE012E,
 },
 [0xE012F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0040",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE012F,
 },
 [0xE0130]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0041",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0130,
 },
 [0xE0131]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0042",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0131,
 },
 [0xE0132]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0043",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0132,
 },
 [0xE0133]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0044",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0133,
 },
 [0xE0134]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0045",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0134,
 },
 [0xE0135]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0046",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0135,
 },
 [0xE0136]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0047",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0136,
 },
 [0xE0137]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0048",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0137,
 },
 [0xE0138]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0049",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0138,
 },
 [0xE0139]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x004A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0139,
 },
 [0xE013A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x004B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE013A,
 },
 [0xE013B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x004C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE013B,
 },
 [0xE013C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x004D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE013C,
 },
 [0xE013D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x004E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE013D,
 },
 [0xE013E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x004F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE013E,
 },
 [0xE013F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0050",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE013F,
 },
 [0xE0140]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0051",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0140,
 },
 [0xE0141]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0052",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0141,
 },
 [0xE0142]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0053",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0142,
 },
 [0xE0143]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0054",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0143,
 },
 [0xE0144]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0055",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0144,
 },
 [0xE0145]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0056",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0145,
 },
 [0xE0146]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0057",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0146,
 },
 [0xE0147]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0058",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0147,
 },
 [0xE0148]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0059",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0148,
 },
 [0xE0149]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x005A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0149,
 },
 [0xE014A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x005B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE014A,
 },
 [0xE014B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x005C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE014B,
 },
 [0xE014C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x005D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE014C,
 },
 [0xE014D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x005E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE014D,
 },
 [0xE014E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x005F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE014E,
 },
 [0xE014F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0060",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE014F,
 },
 [0xE0150]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0061",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0150,
 },
 [0xE0151]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0062",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0151,
 },
 [0xE0152]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0063",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0152,
 },
 [0xE0153]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0064",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0153,
 },
 [0xE0154]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0065",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0154,
 },
 [0xE0155]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0066",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0155,
 },
 [0xE0156]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0067",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0156,
 },
 [0xE0157]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0068",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0157,
 },
 [0xE0158]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0069",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0158,
 },
 [0xE0159]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x006A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0159,
 },
 [0xE015A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x006B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE015A,
 },
 [0xE015B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x006C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE015B,
 },
 [0xE015C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x006D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE015C,
 },
 [0xE015D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x006E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE015D,
 },
 [0xE015E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x006F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE015E,
 },
 [0xE015F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0070",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE015F,
 },
 [0xE0160]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0071",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0160,
 },
 [0xE0161]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0072",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0161,
 },
 [0xE0162]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0073",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0162,
 },
 [0xE0163]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0074",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0163,
 },
 [0xE0164]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0075",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0164,
 },
 [0xE0165]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0076",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0165,
 },
 [0xE0166]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0077",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0166,
 },
 [0xE0167]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0078",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0167,
 },
 [0xE0168]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0079",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0168,
 },
 [0xE0169]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x007A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0169,
 },
 [0xE016A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x007B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE016A,
 },
 [0xE016B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x007C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE016B,
 },
 [0xE016C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x007D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE016C,
 },
 [0xE016D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x007E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE016D,
 },
 [0xE016E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x007F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE016E,
 },
 [0xE016F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0080",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE016F,
 },
 [0xE0170]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0081",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0170,
 },
 [0xE0171]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0082",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0171,
 },
 [0xE0172]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0083",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0172,
 },
 [0xE0173]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0084",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0173,
 },
 [0xE0174]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0085",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0174,
 },
 [0xE0175]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0086",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0175,
 },
 [0xE0176]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0087",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0176,
 },
 [0xE0177]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0088",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0177,
 },
 [0xE0178]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0089",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0178,
 },
 [0xE0179]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x008A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0179,
 },
 [0xE017A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x008B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE017A,
 },
 [0xE017B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x008C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE017B,
 },
 [0xE017C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x008D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE017C,
 },
 [0xE017D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x008E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE017D,
 },
 [0xE017E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x008F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE017E,
 },
 [0xE017F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0090",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE017F,
 },
 [0xE0180]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0091",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0180,
 },
 [0xE0181]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0092",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0181,
 },
 [0xE0182]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0093",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0182,
 },
 [0xE0183]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0094",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0183,
 },
 [0xE0184]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0095",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0184,
 },
 [0xE0185]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0096",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0185,
 },
 [0xE0186]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0097",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0186,
 },
 [0xE0187]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0098",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0187,
 },
 [0xE0188]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0099",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0188,
 },
 [0xE0189]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x009A",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0189,
 },
 [0xE018A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x009B",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE018A,
 },
 [0xE018B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x009C",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE018B,
 },
 [0xE018C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x009D",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE018C,
 },
 [0xE018D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x009E",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE018D,
 },
 [0xE018E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x009F",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE018E,
 },
 [0xE018F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A0",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE018F,
 },
 [0xE0190]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A1",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0190,
 },
 [0xE0191]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A2",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0191,
 },
 [0xE0192]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A3",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0192,
 },
 [0xE0193]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A4",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0193,
 },
 [0xE0194]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A5",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0194,
 },
 [0xE0195]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A6",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0195,
 },
 [0xE0196]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A7",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0196,
 },
 [0xE0197]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A8",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0197,
 },
 [0xE0198]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00A9",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0198,
 },
 [0xE0199]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00AA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE0199,
 },
 [0xE019A]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00AB",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE019A,
 },
 [0xE019B]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00AC",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE019B,
 },
 [0xE019C]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00AD",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE019C,
 },
 [0xE019D]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00AE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE019D,
 },
 [0xE019E]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00AF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE019E,
 },
 [0xE019F]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B0",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE019F,
 },
 [0xE01A0]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B1",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A0,
 },
 [0xE01A1]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B2",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A1,
 },
 [0xE01A2]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B3",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A2,
 },
 [0xE01A3]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B4",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A3,
 },
 [0xE01A4]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B5",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A4,
 },
 [0xE01A5]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B6",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A5,
 },
 [0xE01A6]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B7",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A6,
 },
 [0xE01A7]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B8",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A7,
 },
 [0xE01A8]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00B9",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A8,
 },
 [0xE01A9]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00BA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01A9,
 },
 [0xE01AA]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00BB",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01AA,
 },
 [0xE01AB]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00BC",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01AB,
 },
 [0xE01AC]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00BD",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01AC,
 },
 [0xE01AD]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00BE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01AD,
 },
 [0xE01AE]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00BF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01AE,
 },
 [0xE01AF]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C0",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01AF,
 },
 [0xE01B0]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C1",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B0,
 },
 [0xE01B1]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C2",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B1,
 },
 [0xE01B2]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C3",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B2,
 },
 [0xE01B3]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C4",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B3,
 },
 [0xE01B4]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C5",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B4,
 },
 [0xE01B5]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C6",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B5,
 },
 [0xE01B6]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C7",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B6,
 },
 [0xE01B7]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C8",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B7,
 },
 [0xE01B8]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00C9",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B8,
 },
 [0xE01B9]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00CA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01B9,
 },
 [0xE01BA]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00CB",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01BA,
 },
 [0xE01BB]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00CC",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01BB,
 },
 [0xE01BC]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00CD",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01BC,
 },
 [0xE01BD]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00CE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01BD,
 },
 [0xE01BE]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00CF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01BE,
 },
 [0xE01BF]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D0",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01BF,
 },
 [0xE01C0]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D1",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C0,
 },
 [0xE01C1]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D2",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C1,
 },
 [0xE01C2]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D3",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C2,
 },
 [0xE01C3]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D4",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C3,
 },
 [0xE01C4]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D5",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C4,
 },
 [0xE01C5]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D6",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C5,
 },
 [0xE01C6]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D7",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C6,
 },
 [0xE01C7]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D8",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C7,
 },
 [0xE01C8]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00D9",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C8,
 },
 [0xE01C9]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00DA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01C9,
 },
 [0xE01CA]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00DB",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01CA,
 },
 [0xE01CB]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00DC",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01CB,
 },
 [0xE01CC]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00DD",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01CC,
 },
 [0xE01CD]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00DE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01CD,
 },
 [0xE01CE]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00DF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01CE,
 },
 [0xE01CF]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E0",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01CF,
 },
 [0xE01D0]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E1",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D0,
 },
 [0xE01D1]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E2",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D1,
 },
 [0xE01D2]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E3",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D2,
 },
 [0xE01D3]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E4",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D3,
 },
 [0xE01D4]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E5",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D4,
 },
 [0xE01D5]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E6",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D5,
 },
 [0xE01D6]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E7",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D6,
 },
 [0xE01D7]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E8",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D7,
 },
 [0xE01D8]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00E9",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D8,
 },
 [0xE01D9]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00EA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01D9,
 },
 [0xE01DA]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00EB",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01DA,
 },
 [0xE01DB]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00EC",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01DB,
 },
 [0xE01DC]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00ED",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01DC,
 },
 [0xE01DD]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00EE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01DD,
 },
 [0xE01DE]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00EF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01DE,
 },
 [0xE01DF]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F0",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01DF,
 },
 [0xE01E0]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F1",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E0,
 },
 [0xE01E1]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F2",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E1,
 },
 [0xE01E2]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F3",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E2,
 },
 [0xE01E3]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F4",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E3,
 },
 [0xE01E4]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F5",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E4,
 },
 [0xE01E5]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F6",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E5,
 },
 [0xE01E6]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F7",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E6,
 },
 [0xE01E7]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F8",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E7,
 },
 [0xE01E8]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00F9",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E8,
 },
 [0xE01E9]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00FA",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01E9,
 },
 [0xE01EA]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00FB",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01EA,
 },
 [0xE01EB]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00FC",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01EB,
 },
 [0xE01EC]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00FD",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01EC,
 },
 [0xE01ED]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00FE",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01ED,
 },
 [0xE01EE]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x00FF",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01EE,
 },
 [0xE01EF]={
  category="mn",
  cjkwd="a",
  description="VARIATION SELECTOR-0x0100",
  direction="nsm",
  linebreak="cm",
  unicodeslot=0xE01EF,
 },
}
