%% This is file `qurantext-fa.translation.def',
%% 
%% Copyright © 2015-2021
%% Seiied-Mohammad-Javad Razavian <javadr@gmail.com>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%% 
%% This work is “author-maintained” (as per LPPL maintenance status).
%% 
%% The Current Maintainer of this work is Seiied-Mohammad-Javad Razavian.
%% 
%% to one who has devoted his life to Quran
%%
\qt@newcmd\qurantrans@fa@i{به نام خداوند رحمتگر مهربان\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@ii{ستايش خدايى را كه پروردگار جهانيان،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@iii{رحمتگر مهربان،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@iv{[و] خداوند روز جزاست.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@v{[بار الها] تنها تو را مى‌پرستيم، و تنها از تو يارى مى‌جوييم.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@vi{ما را به راه راست هدايت فرما،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@vii{راه آنان كه گرامى‌شان داشته‌اى، نه [راه‌] مغضوبان، و نه [راه‌] گمراهان.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@viii{\basmalahfa الف، لام، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@ix{اين است كتابى كه در [حقانيت‌] آن هيچ ترديدى نيست؛ [و] مايه هدايت تقواپيشگان است:\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@x{آنان كه به غيب ايمان مى‌آورند، و نماز را بر پا مى‌دارند، و از آنچه به ايشان روزى داده‌ايم انفاق مى‌كنند؛\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@xi{و آنان كه بدانچه به سوى تو فرود آمده، و به آنچه پيش از تو نازل شده است، ايمان مى آورند؛ و آنانند كه به آخرت يقين دارند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@xii{آنان برخوردار از هدايتى از سوى پروردگار خويشند؛ و آنان همان رستگارانند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@xiii{در حقيقت كسانى كه كفر ورزيدند -چه بيمشان دهى، چه بيمشان ندهى- بر ايشان يكسان است؛ [آنها] نخواهند گرويد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@xiv{خداوند بر دلهاى آنان، و بر شنوايى ايشان مُهر نهاده؛ و بر ديدگانشان پرده‌اى است؛ و آنان را عذابى دردناك است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@xv{و برخى از مردم مى‌گويند: «ما به خدا و روز بازپسين ايمان آورده‌ايم»، ولى گروندگان [راستين‌] نيستند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@xvi{با خدا و مؤمنان نيرنگ مى‌بازند؛ ولى جز بر خويشتن نيرنگ نمى‌زنند، و نمى‌فهمند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@xvii{در دلهايشان مرضى است؛ و خدا بر مرضشان افزود؛ و به [سزاى‌] آنچه به دروغ مى گفتند، عذابى دردناك [در پيش‌] خواهند داشت.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@xviii{و چون به آنان گفته شود: «در زمين فساد مكنيد»، مى‌گويند: «ما خود اصلاحگريم.»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@xix{بهوش باشيد كه آنان فسادگرانند، ليكن نمى‌فهمند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@xx{و چون به آنان گفته شود: «همان گونه كه مردم ايمان آوردند، شما هم ايمان بياوريد»، مى‌گويند: «آيا همان گونه كه كم خردان ايمان آورده‌اند، ايمان بياوريم؟» هشدار كه آنان همان كم‌خردانند؛ ولى نمى‌دانند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@xxi{و چون با كسانى كه ايمان آورده‌اند برخورد كنند، مى‌گويند: «ايمان آورديم »، و چون با شيطانهاى خود خلوت كنند، مى‌گويند: «در حقيقت ما با شماييم، ما فقط [آنان را] ريشخند مى‌كنيم.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@xxii{خدا [است كه‌] ريشخندشان مى‌كند، و آنان را در طغيانشان فرو مى‌گذارد تا سرگردان شوند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@xxiii{همين كسانند كه گمراهى را به [بهاى‌] هدايت خريدند، در نتيجه داد و ستدشان سود[ى به بار] نياورد؛ و هدايت‌يافته نبودند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@xxiv{مَثَل آنان، همچون مَثَل كسانى است كه آتشى افروختند، و چون پيرامون آنان را روشنايى داد، خدا نورشان را برد؛ و در ميان تاريكيهايى كه نمى‌بينند رهايشان كرد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@xxv{كرند، لالند، كورند؛ بنابراين به راه نمى‌آيند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@xxvi{يا چون [كسانى كه در معرض‌] رگبارى از آسمان -كه در آن تاريكيها و رعد و برقى است- [قرار گرفته‌اند]؛ از [نهيب‌] آذرخش [و] بيم مرگ، سر انگشتان خود را در گوشهايشان نهند، ولى خدا بر كافران احاطه دارد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@xxvii{نزديك است كه برق چشمانشان را بربايد؛ هر گاه كه بر آنان روشنى بخشد، در آن گام زنند؛ و چون راهشان را تاريك كند، [بر جاى خود] بايستند؛ و اگر خدا مى‌خواست شنوايى و بينايى‌شان را برمى‌گرفت، كه خدا بر همه چيز تواناست.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@xxviii{اى مردم، پروردگارتان را كه شما، و كسانى را كه پيش از شما بوده‌اند آفريده است، پرستش كنيد؛ باشد كه به تقوا گراييد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@xxix{همان [خدايى‌] كه زمين را براى شما فرشى [گسترده‌]، و آسمان را بنايى [افراشته‌] قرار داد؛ و از آسمان آبى فرود آورد؛ و بدان از ميوه‌ها رزقى براى شما بيرون آورد؛ پس براى خدا همتايانى قرار ندهيد، در حالى كه خود مى‌دانيد.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@xxx{و اگر در آنچه بر بنده خود نازل كرده‌ايم شك داريد، پس -اگر راست مى‌گوييد- سوره‌اى مانند آن بياوريد؛ و گواهان خود را -غير خدا- فرا خوانيد.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@xxxi{پس اگر نكرديد -و هرگز نمى‌توانيد كرد- از آن آتشى كه سوختش مردمان و سنگها هستند، و براى كافران آماده شده، بپرهيزيد.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@xxxii{و كسانى را كه ايمان آورده‌اند و كارهاى شايسته انجام داده‌اند، مژده ده كه ايشان را باغهايى خواهد بود كه از زير [درختان‌] آنها جويها روان است. هر گاه ميوه‌اى از آن روزىِ ايشان شود، مى‌گويند: «اين همان است كه پيش از اين [نيز ]روزىِ ما بوده.» و مانند آن [نعمتها] به ايشان داده شود؛ و در آنجا همسرانى پاكيزه خواهند داشت؛ و در آنجا جاودانه بمانند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@xxxiii{خداى را از اينكه به پشه‌اى -يا فروتر [يا فراتر] از آن- مَثَل زند، شرم نيايد. پس كسانى كه ايمان آورده‌اند مى‌دانند كه آن [مَثَل‌] از جانب پروردگارشان بجاست؛ ولى كسانى كه به كفر گراييده‌اند مى‌گويند: «خدا از اين مَثَل چه قصد داشته است؟» [خدا] بسيارى را با آن گمراه، و بسيارى را با آن راهنمايى مى‌كند؛ و[لى‌] جز نافرمانان را با آن گمراه نمى‌كند.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@xxxiv{همانانى كه پيمان خدا را پس از بستن آن مى‌شكنند؛ و آنچه را خداوند به پيوستنش امر فرموده مى‌گسلند؛ و در زمين به فساد مى‌پردازند؛ آنانند كه زيانكارانند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@xxxv{چگونه خدا را منكريد؟ با آنكه مردگانى بوديد و شما را زنده كرد؛ باز شما را مى ميراند [و] باز زنده مى‌كند؛ [و] آنگاه به سوى او بازگردانده مى‌شويد.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@xxxvi{اوست آن كسى كه آنچه در زمين است، همه را براى شما آفريد؛ سپس به [آفرينش‌] آسمان پرداخت، و هفت آسمان را استوار كرد؛ و او به هر چيزى داناست.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@xxxvii{و چون پروردگار تو به فرشتگان گفت: «من در زمين جانشينى خواهم گماشت»، [فرشتگان‌] گفتند: «آيا در آن كسى را مى‌گمارى كه در آن فساد انگيزد، و خونها بريزد؟ و حال آنكه ما با ستايش تو، [تو را] تنزيه مى‌كنيم؛ و به تقديست مى‌پردازيم.» فرمود: «من چيزى مى‌دانم كه شما نمى‌دانيد.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@xxxviii{و [خدا] همه [معانى‌] نامها را به آدم آموخت؛ سپس آنها را بر فرشتگان عرضه نمود و فرمود: «اگر راست مى‌گوييد، از اسامى اينها به من خبر دهيد.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@xxxix{گفتند: «منزهى تو! ما را جز آنچه [خود] به ما آموخته‌اى، هيچ دانشى نيست؛ تويى داناى حكيم.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@xl{فرمود: «اى آدم، ايشان را از اسامى آنان خبر ده.» و چون [آدم‌] ايشان را از اسماءشان خبر داد، فرمود: «آيا به شما نگفتم كه من نهفته آسمانها و زمين را مى‌دانم؛ و آنچه را آشكار مى‌كنيد، و آنچه را پنهان مى‌داشتيد مى‌دانم؟»\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@xli{و چون فرشتگان را فرموديم: «براى آدم سجده كنيد»، پس بجز ابليس -كه سر باز زد و كبر ورزيد و از كافران شد- [همه‌] به سجده درافتادند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@xlii{و گفتيم: «اى آدم، خود و همسرت در اين باغ سكونت گير[يد]؛ و از هر كجاى آن خواهيد فراوان بخوريد؛ و[لى‌] به اين درخت نزديك نشويد، كه از ستمكاران خواهيد بود.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@xliii{پس شيطان هر دو را از آن بلغزانيد؛ و از آنچه در آن بودند ايشان را به درآورد؛ و فرموديم: «فرود آييد، شما دشمن همديگريد؛ و براى شما در زمين قرارگاه، و تا چندى برخوردارى خواهد بود.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@xliv{سپس آدم از پروردگارش كلماتى را دريافت نمود؛ و [خدا] بر او ببخشود؛ آرى، او[ست كه‌] توبه‌پذيرِ مهربان است.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@xlv{فرموديم: «جملگى از آن فرود آييد. پس اگر از جانب من شما را هدايتى رسد، آنان كه هدايتم را پيروى كنند بر ايشان بيمى نيست و غمگين نخواهند شد.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@xlvi{و[لى‌] كسانى كه كفر ورزيدند و نشانه‌هاى ما را دروغ انگاشتند، آنانند كه اهل آتشند؛ و در آن ماندگار خواهند بود.»\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@xlvii{اى فرزندان اسرائيل، نعمتهايم را كه بر شما ارزانى داشتم به ياد آريد، و به پيمانم وفا كنيد، تا به پيمانتان وفا كنم، و تنها از من بترسيد.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@xlviii{و بدانچه نازل كرده‌ام -كه مؤيد همان چيزى است كه با شماست- ايمان آريد؛ و نخستين منكر آن نباشيد، و آيات مرا به بهايى ناچيز نفروشيد، و تنها از من پروا كنيد.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@xlix{و حق را به باطل درنياميزيد، و حقيقت را -با آنكه خود مى‌دانيد- كتمان نكنيد.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@l{و نماز را بر پا داريد، و زكات را بدهيد، و با ركوع‌كنندگان ركوع كنيد.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@li{آيا مردم را به نيكى فرمان مى‌دهيد و خود را فراموش مى‌كنيد، با اينكه شما كتاب [خدا] را مى‌خوانيد؟ آيا [هيچ‌] نمى‌انديشيد؟\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@lii{از شكيبايى و نماز يارى جوييد. و به راستى اين [كار] گران است، مگر بر فروتنان:\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@liii{همان كسانى كه مى‌دانند با پروردگار خود ديدار خواهند كرد؛ و به سوى او باز خواهند گشت.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@liv{اى فرزندان اسرائيل، از نعمتهايم كه بر شما ارزانى داشتم، و [از] اينكه من شما را بر جهانيان برترى دادم، ياد كنيد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@lv{و بترسيد از روزى كه هيچ كس چيزى [از عذاب خدا] را از كسى دفع نمى‌كند؛ و نه از او شفاعتى پذيرفته، و نه به جاى وى بدلى گرفته مى‌شود؛ و نه يارى خواهند شد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@lvi{و [به ياد آريد] آنگاه كه شما را از [چنگ‌] فرعونيان رهانيديم؛ [آنان‌] شما را سخت شكنجه مى‌كردند؛ پسران شما را سر مى‌بريدند؛ و زنهايتان را زنده مى‌گذاشتند، و در آن [امر، بلا و] آزمايش بزرگى از جانب پروردگارتان بود.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@lvii{و هنگامى كه دريا را براى شما شكافتيم و شما را نجات بخشيديم؛ و فرعونيان را -در حالى كه شما نظاره مى‌كرديد- غرق كرديم.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@lviii{و آنگاه كه با موسى چهل شب قرار گذاشتيم؛ آنگاه در غياب وى، شما گوساله را [به پرستش‌] گرفتيد، در حالى كه ستمكار بوديد.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@lix{پس از آن بر شما بخشوديم، باشد كه شكرگزارى كنيد.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@lx{و آنگاه كه موسى را كتاب و فرقان [=جداكننده حق از باطل‌] داديم، شايد هدايت يابيد.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@lxi{و چون موسى به قوم خود گفت: «اى قوم من، شما با [به پرستش‌] گرفتن گوساله، برخود ستم كرديد، پس به درگاه آفريننده خود توبه كنيد، و [خطاكاران‌] خودتان را به قتل برسانيد، كه اين [كار] نزد آفريدگارتان براى شما بهتر است.» پس [خدا] توبه شما را پذيرفت، كه او توبه‌پذير مهربان است.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@lxii{و چون گفتيد: «اى موسى، تا خدا را آشكارا نبينيم، هرگز به تو ايمان نخواهيم آورد.» پس -در حالى كه مى‌نگريستيد- صاعقه شما را فرو گرفت.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@lxiii{سپس شما را پس از مرگتان برانگيختيم؛ باشد كه شكرگزارى كنيد.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@lxiv{و بر شما ابر را سايه‌گستر كرديم؛ و بر شما «گزانگبين» و «بلدرچين» فرو فرستاديم؛ [و گفتيم:] «از خوراكيهاى پاكيزه‌اى كه به شما روزى داده‌ايم، بخوريد.» و[لى آنان‌] بر ما ستم نكردند، بلكه بر خويشتن ستم روا مى‌داشتند.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@lxv{و [نيز به يادآريد] هنگامى را كه گفتيم: «بدين شهر درآييد، و از [نعمتهاى‌] آن، هر گونه خواستيد، فراوان بخوريد، و سجده‌كنان از در [بزرگ‌] درآييد؛ و بگوييد: [خداوندا،] گناهان ما را بريز. تا خطاهاى شما را ببخشاييم، و [پاداش‌] نيكوكاران را خواهيم افزود.»\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@lxvi{اما كسانى كه ستم كرده بودند، [آن سخن را] به سخن ديگرى -غير از آنچه به ايشان گفته شده بود- تبديل كردند. و ما [نيز] بر آنان كه ستم كردند، به سزاى اينكه نافرمانى پيشه كرده بودند، عذابى از آسمان فرو فرستاديم.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@lxvii{و هنگامى كه موسى براى قوم خود در پى آب برآمد، گفتيم: «با عصايت بر آن تخته‌سنگ بزن.» پس دوازده چشمه از آن جوشيدن گرفت، [به گونه‌اى كه‌] هر قبيله‌اى آبشخور خود را مى‌دانست. [و گفتيم:] «از روزى خدا بخوريد و بياشاميد، و[لى ]در زمين سر به فساد برمداريد.»\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@lxviii{و چون گفتيد: «اى موسى! هرگز بر يك [نوع‌] خوراك تاب نياوريم، از خداى خود براى ما بخواه تا از آنچه زمين مى‌روياند، از [قبيل‌] سبزى و خيار و سير و عدس و پياز، براى ما بروياند» [موسى‌] گفت: «آيا به جاى چيز بهتر، خواهان چيز پست‌تريد؟ پس به شهر فرود آييد، كه آنچه را خواسته‌ايد براى شما [در آنجا مهيا]ست.» و [داغ‌] خوارى و نادارى بر [پيشانى‌] آنان زده شد، و به خشم خدا گرفتار آمدند؛ چرا كه آنان به نشانه‌هاى خدا كفر ورزيده بودند، و پيامبران را بناحق مى‌كشتند؛ اين، از آن روى بود كه سركشى نموده، و از حد درگذرانيده بودند.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@lxix{در حقيقت، كسانى كه [به اسلام‌] ايمان آورده، و كسانى كه يهودى شده‌اند، و ترسايان و صابئان، هر كس به خدا و روز بازپسين ايمان داشت و كار شايسته كرد، پس اجرشان را پيش پروردگارشان خواهند داشت، و نه بيمى بر آنان است، و نه اندوهناك خواهند شد.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@lxx{و چون از شما پيمان محكم گرفتيم، و [كوه‌] طور را بر فراز شما افراشتيم، [و فرموديم:] «آنچه را به شما داده‌ايم به جد و جهد بگيريد، و آنچه را در آن است به خاطر داشته باشيد، باشد كه به تقوا گراييد.»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@lxxi{سپس شما بعد از آن [پيمان‌] رويگردان شديد، و اگر فضل خدا و رحمت او بر شما نبود، مسلما از زيانكاران بوديد.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@lxxii{و كسانى از شما را كه در روز شنبه [از فرمان خدا] تجاوز كردند نيك شناختيد، پس ايشان را گفتيم: «بوزينگانى طردشده باشيد.»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@lxxiii{و ما آن [عقوبت‌] را براى حاضران، و [نسلهاى‌] پس از آن، عبرتى، و براى پرهيزگاران پندى قرار داديم.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@lxxiv{و هنگامى كه موسى به قوم خود گفت: «خدا به شما فرمان مى‌دهد كه: ماده گاوى را سر ببريد»، گفتند: «آيا ما را به ريشخند مى‌گيرى؟» گفت: «پناه مى‌برم به خدا كه [مبادا] از جاهلان باشم.»\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@lxxv{گفتند: «پروردگارت را براى ما بخوان، تا بر ما روشن سازد كه آن چگونه [گاوى‌] است؟» گفت: «وى مى‌فرمايد: آن ماده گاوى است نه پير و نه خردسال، [بلكه‌] ميانسالى است بين اين دو. پس آنچه را [بدان ]مأموريد به جاى آريد.»\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@lxxvi{گفتند: «از پروردگارت بخواه، تا بر ما روشن كند كه رنگش چگونه است؟» گفت: «وى مى‌فرمايد: آن ماده گاوى است زرد يكدست و خالص، كه رنگش بينندگان را شاد مى‌كند.»\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@lxxvii{گفتند: «از پروردگارت بخواه، تا بر ما روشن گرداند كه آن چگونه [گاوى‌] باشد؟ زيرا [چگونگى‌] اين ماده گاو بر ما مشتبه شده، و[لى با توضيحات بيشتر تو] ما ان شاء الله حتماً هدايت خواهيم شد.»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@lxxviii{گفت: «وى مى‌فرمايد: در حقيقت، آن ماده گاوى است كه نه رام است تا زمين را شخم زند؛ و نه كشتزار را آبيارى كند؛ بى‌نقص است؛ و هيچ لكه‌اى در آن نيست.» گفتند: «اينك سخن درست آوردى.» پس آن را سر بريدند، و چيزى نمانده بود كه نكنند.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@lxxix{و چون شخصى را كشتيد، و در باره او با يكديگر به ستيزه برخاستيد، و حال آنكه خدا، آنچه را كتمان مى‌كرديد، آشكار گردانيد.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@lxxx{پس فرموديم: «پاره‌اى از آن [گاو سر بريده را] به آن [مقتول‌] بزنيد» [تا زنده شود]. اين گونه خدا مردگان را زنده مى‌كند، و آيات خود را به شما مى‌نماياند، باشد كه بينديشيد.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@lxxxi{سپس دلهاى شما بعد از اين [واقعه‌] سخت گرديد، همانند سنگ، يا سخت‌تر از آن، چرا كه از برخى سنگها، جويهايى بيرون مى‌زند، و پاره‌اى از آنها مى‌شكافد و آب از آن خارج مى‌شود، و برخى از آنها از بيم خدا فرو مى‌ريزد، و خدا از آنچه مى‌كنيد غافل نيست.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@lxxxii{آيا طمع داريد كه [اينان‌] به شما ايمان بياورند؟ با آنكه گروهى از آنان سخنان خدا را مى‌شنيدند، سپس آن را بعد از فهميدنش تحريف مى‌كردند، و خودشان هم مى‌دانستند.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@lxxxiii{و [همين يهوديان‌] چون با كسانى كه ايمان آورده‌اند برخورد كنند، مى‌گويند: «ما ايمان آورده‌ايم.» و وقتى با همديگر خلوت مى‌كنند، مى‌گويند: «چرا از آنچه خداوند بر شما گشوده است، براى آنان حكايت مى‌كنيد تا آنان به [استناد] آن، پيش پروردگارتان بر ضد شما استدلال كنند؟ آيا فكر نمى‌كنيد؟»\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@lxxxiv{آيا نمى‌دانند كه خداوند آنچه را پوشيده مى‌دارند، و آنچه را آشكار مى‌كنند، مى‌داند؟\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@lxxxv{و [بعضى‌] از آنان بى‌سوادانى هستند كه كتاب [خدا] را جز خيالات خامى نمى‌دانند، و فقط گمان مى‌برند.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@lxxxvi{پس واى بر كسانى كه كتاب [تحريف‌شده‌اى‌] با دستهاى خود مى‌نويسند، سپس مى‌گويند: «اين از جانب خداست»، تا بدان بهاى ناچيزى به دست آرند؛ پس واى بر ايشان از آنچه دستهايشان نوشته، و واى بر ايشان از آنچه [از اين راه‌] به دست مى‌آورند.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@lxxxvii{و گفتند: «جز روزهايى چند، هرگز آتش به ما نخواهد رسيد.» بگو: «مگر پيمانى از خدا گرفته‌ايد؟ -كه خدا پيمان خود را هرگز خلاف نخواهد كرد- يا آنچه را نمى‌دانيد به دروغ به خدا نسبت مى‌دهيد؟»\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@lxxxviii{آرى، كسى كه بدى به دست آورد، و گناهش او را در ميان گيرد، پس چنين كسانى اهل آتشند، و در آن ماندگار خواهند بود.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@lxxxix{و كسانى كه ايمان آورده، و كارهاى شايسته كرده‌اند، آنان اهل بهشتند، و در آن جاودان خواهند ماند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@xc{و چون از فرزندان اسرائيل پيمان محكم گرفتيم كه: «جز خدا را نپرستيد، و به پدر و مادر، و خويشان و يتيمان و مستمندان احسان كنيد، و با مردم [به زبان‌] خوش سخن بگوييد، و نماز را به پا داريد، و زكات را بدهيد»؛ آنگاه، جز اندكى از شما، [همگى‌] به حالت اعراض روى برتافتيد.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@xci{و چون از شما پيمان محكم گرفتيم كه: «خون همديگر را مريزيد، و يكديگر را از سرزمين خود بيرون نكنيد»؛ سپس [به اين پيمان‌] اقرار كرديد، و خود گواهيد.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@xcii{[ولى‌] باز همين شما هستيد كه يكديگر را مى‌كشيد، و گروهى از خودتان را از ديارشان بيرون مى‌رانيد، و به گناه و تجاوز، بر ضد آنان به يكديگر كمك مى‌كنيد. و اگر به اسارت پيش شما آيند، به [دادن‌] فديه، آنان را آزاد مى‌كنيد، با آنكه [نه تنها كشتن، بلكه‌] بيرون كردن آنان بر شما حرام شده است. آيا شما به پاره‌اى از كتاب [تورات‌] ايمان مى‌آوريد، و به پاره‌اى كفر مى‌ورزيد؟ پس جزاى هر كس از شما كه چنين كند، جز خوارى در زندگى دنيا چيزى نخواهد بود، و روز رستاخيز ايشان را به سخت‌ترين عذابها باز برند، و خداوند از آنچه مى‌كنيد غافل نيست.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@xciii{همين كسانند كه زندگى دنيا را به [بهاى‌] جهان ديگر خريدند. پس نه عذاب آنان سبك گردد، و نه ايشان يارى شوند.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@xciv{و همانا به موسى كتاب [تورات‌] را داديم، و پس از او پيامبرانى را پشت سر هم فرستاديم، و عيسى پسر مريم را معجزه‌هاى آشكار بخشيديم، و او را با «روح القدس» تأييد كرديم؛ پس چرا هر گاه پيامبرى چيزى را كه خوشايند شما نبود برايتان آورد، كبر ورزيديد؟ گروهى را دروغگو خوانديد و گروهى را كشتيد.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@xcv{و گفتند: «دلهاى ما در غلاف است.» [نه، چنين نيست‌] بلكه خدا به سزاى كفرشان، لعنتشان كرده است. پس آنان كه ايمان مى‌آورند چه اندك‌شماره‌اند.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@xcvi{و هنگامى كه از جانب خداوند كتابى كه مؤيد آنچه نزد آنان است برايشان آمد، و از ديرباز [در انتظارش‌] بر كسانى كه كافر شده بودند پيروزى مى‌جستند؛ ولى همين كه آنچه [كه اوصافش‌] را مى‌شناختند برايشان آمد، انكارش كردند. پس لعنت خدا بر كافران باد.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@xcvii{وه كه به چه بد بهايى خود را فروختند كه به آنچه خدا نازل كرده بود از سر رشك انكار آوردند، كه چرا خداوند از فضل خويش بر هر كس از بندگانش كه بخواهد [آياتى‌] فرو مى‌فرستد. پس به خشمى بر خشم ديگر گرفتار آمدند. و براى كافران عذابى خفت‌آور است.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@xcviii{و چون به آنان گفته شود: «به آنچه خدا نازل كرده ايمان آوريد»، مى‌گويند: «ما به آنچه بر [پيامبر] خودمان نازل شده ايمان مى‌آوريم.» و غير آن را -با آنكه [كاملا] حق و مؤيد همان چيزى است كه با آنان است- انكار مى‌كنند. بگو: «اگر مؤمن بوديد، پس چرا پيش از اين، پيامبران خدا را مى‌كشتيد؟»\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@xcix{و قطعاً موسى براى شما معجزات آشكارى آورد، سپس آن گوساله را در غياب وى [به خدايى‌] گرفتيد، و ستمكار شديد.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@c{و آنگاه كه از شما پيمان محكم گرفتيم، و [كوه‌] طور را بر فراز شما برافراشتيم، [و گفتيم:] «آنچه را به شما داده‌ايم به جد و جهد بگيريد، و [به دستورهاى آن‌] گوش فرا دهيد.» گفتند: «شنيديم و نافرمانى كرديم.» و بر اثر كفرشان، [مِهر ]گوساله در دلشان سرشته شد. بگو: «اگر مؤمنيد [بدانيد كه‌] ايمانتان شما را به بد چيزى وامى‌دارد.»\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@ci{بگو: «اگر در نزد خدا، سراى بازپسين يكسر به شما اختصاص دارد، نه ديگر مردم، پس اگر راست مى‌گوييد آرزوى مرگ كنيد.»\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@cii{ولى به سبب كارهايى كه از پيش كرده‌اند، هرگز آن را آرزو نخواهند كرد. و خدا به [حال‌] ستمگران داناست.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@ciii{و آنان را مسلما آزمندترين مردم به زندگى، و [حتى حريص‌تر] از كسانى كه شرك مى‌ورزند خواهى يافت. هر يك از ايشان آرزو دارد كه كاش هزار سال عمر كند با آنكه اگر چنين عمرى هم به او داده شود، وى را از عذاب دور نتواند داشت. و خدا بر آنچه مى‌كنند بيناست.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@civ{بگو: «كسى كه دشمن جبرئيل است [در واقع دشمن خداست‌] چرا كه او، به فرمان خدا، قرآن را بر قلبت نازل كرده است، در حالى كه مؤيد [كتابهاى آسمانى‌] پيش از آن، و هدايت و بشارتى براى مؤمنان است.»\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@cv{هر كه دشمن خدا، و فرشتگان و فرستادگان او، و جبرئيل و ميكائيل است [بداند كه‌] خدا يقينا دشمن كافران است.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@cvi{و همانا بر تو آياتى روشن فرو فرستاديم، و جز فاسقان [كسى‌] آنها را انكار نمى‌كند.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@cvii{و مگر نه اين بود كه [يهود] هر گاه پيمانى بستند، گروهى از ايشان آن را دور افكندند؟ بلكه [حقيقت اين است كه‌] بيشترشان ايمان نمى‌آورند.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@cviii{و آنگاه كه فرستاده‌اى از جانب خداوند برايشان آمد -كه آنچه را با آنان بود تصديق مى‌داشت- گروهى از اهل كتاب، كتاب خدا را پشت سر افكندند، چنانكه گويى [از آن هيچ‌] نمى‌دانند.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@cix{و آنچه را كه شيطان‌[صفت‌]ها در سلطنت سليمان خوانده [و درس گرفته‌] بودند، پيروى كردند. و سليمان كفر نورزيد، ليكن آن شيطان‌[صفت‌]ها به كفر گراييدند كه به مردم سحر مى‌آموختند. و [نيز از] آنچه بر آن دو فرشته، هاروت و ماروت، در بابِل فرو فرستاده شده بود [پيروى كردند]، با اينكه آن دو [فرشته‌] هيچ كس را تعليم [سحر] نمى‌كردند مگر آنكه [قبلا به او] مى‌گفتند: «ما [وسيله‌] آزمايشى [براى شما ]هستيم، پس زنهار كافر نشوى.» و[لى‌] آنها از آن دو [فرشته‌] چيزهايى مى‌آموختند كه به وسيله آن ميان مرد و همسرش جدايى بيفكنند. هر چند بدون فرمان خدا نمى‌توانستند به وسيله آن به احدى زيان برسانند. و [خلاصه‌] چيزى مى‌آموختند كه برايشان زيان داشت، و سودى بديشان نمى‌رسانيد. و قطعاً [يهوديان‌] دريافته بودند كه هر كس خريدار اين [متاع‌] باشد، در آخرت بهره‌اى ندارد. وه كه چه بد بود آنچه به جان خريدند-اگر مى‌دانستند.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@cx{اگر آنها گرويده و پرهيزگارى كرده بودند قطعاً پاداشى [كه‌] از جانب خدا [مى‌يافتند] بهتر بود-اگر مى‌دانستند.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@cxi{اى كسانى كه ايمان آورده‌ايد، نگوييد: «راعنا»، و بگوييد: «انظرنا»، و [اين توصيه را] بشنويد؛ و [گر نه‌] كافران را عذابى دردناك است.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@cxii{نه كسانى كه از اهل كتاب كافر شده‌اند، و نه مشركان [هيچ كدام‌] دوست نمى‌دارند خيرى از جانب پروردگارتان بر شما فرود آيد، با آنكه خدا هر كه را خواهد به رحمت خود اختصاص دهد، و خدا داراى فزون‌بخشى عظيم است.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@cxiii{هر حكمى را نسخ كنيم، يا آن را به [دست‌] فراموشى بسپاريم، بهتر از آن، يا مانندش را مى‌آوريم؛ مگر ندانستى كه خدا بر هر كارى تواناست؟\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@cxiv{مگر ندانستى كه فرمانروايى آسمانها و زمين از آن خداست؛ و شما جز خدا سرور و ياورى نداريد؟\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@cxv{آيا مى‌خواهيد از پيامبر خود همان را بخواهيد كه قبلا از موسى خواسته شد؟ و هر كس كفر را با ايمان عوض كند، مسلما از راه درست گمراه شده است.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@cxvi{بسيارى از اهل كتاب -پس از اينكه حق برايشان آشكار شد- از روى حسدى كه در وجودشان بود، آرزو مى‌كردند كه شما را، بعد از ايمانتان، كافر گردانند. پس عفو كنيد و درگذريد، تا خدا فرمان خويش را بياورد، كه خدا بر هر كارى تواناست.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@cxvii{و نماز را به پا داريد و زكات را بدهيد؛ و هر گونه نيكى كه براى خويش از پيش فرستيد، آن را نزد خدا باز خواهيد يافت؛ آرى، خدا به آنچه مى‌كنيد بيناست.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@cxviii{و گفتند: «هرگز كسى به بهشت درنيايد، مگر آنكه يهودى يا ترسا باشد.» اين آرزوهاى [واهىِ‌] ايشان است. بگو: «اگر راست مى‌گوييد، دليل خود را بياوريد.»\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@cxix{آرى، هر كس كه خود را با تمام وجود، به خدا تسليم كند و نيكوكار باشد، پس مزد وى پيش پروردگار اوست، و بيمى بر آنان نيست، و غمگين نخواهند شد.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@cxx{و يهوديان گفتند: «ترسايان بر حق نيستند.» و ترسايان گفتند: «يهوديان بر حق نيستند» -با آنكه آنان كتاب [آسمانى‌] را مى‌خوانند. افراد نادان نيز [سخنى‌] همانند گفته ايشان گفتند. پس خداوند، روز رستاخيز در آنچه با هم اختلاف مى‌كردند، ميان آنان داورى خواهد كرد.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@cxxi{و كيست بيدادگرتر از آن كس كه نگذارد در مساجد خدا، نام وى برده شود، و در ويرانى آنها بكوشد؟ آنان حق ندارند جز ترسان-لرزان در آن [مسجد]ها درآيند. در اين دنيا ايشان را خوارى، و در آخرت عذابى بزرگ است.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@cxxii{و مشرق و مغرب از آنِ خداست؛ پس به هر سو رو كنيد، آنجا روى [به‌] خداست. آرى، خدا گشايشگر داناست.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@cxxiii{و گفتند: «خداوند فرزندى براى خود اختيار كرده است.» او منزه است. بلكه هر چه در آسمانها و زمين است، از آن اوست، [و] همه فرمانپذير اويند.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@cxxiv{[او] پديد آورنده آسمانها و زمين [است‌]، و چون به كارى اراده فرمايد، فقط مى‌گويد: «[موجود] باش»؛ پس [فوراً موجود] مى‌شود.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@cxxv{افراد نادان گفتند: «چرا خدا با ما سخن نمى‌گويد؟ يا براى ما معجزه‌اى نمى‌آيد؟» كسانى كه پيش از اينان بودند [نيز] مثل همين گفته ايشان را مى‌گفتند. دلها [و افكار]شان به هم مى‌ماند. ما نشانه‌ها[ى خود] را براى گروهى كه يقين دارند، نيك روشن گردانيده‌ايم.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@cxxvi{ما تو را بحق فرستاديم، تا بشارتگر و بيم‌دهنده باشى، و [لى‌] درباره دوزخيان، از تو پرسشى نخواهد شد.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@cxxvii{و هرگز يهوديان و ترسايان از تو راضى نمى‌شوند، مگر آنكه از كيش آنان پيروى كنى. بگو: «در حقيقت، تنها هدايت خداست كه هدايت [واقعى‌] است.» و چنانچه پس از آن علمى كه تو را حاصل شد، باز از هوسهاى آنان پيروى كنى، در برابر خدا سرور و ياورى نخواهى داشت.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@cxxviii{كسانى كه كتاب [آسمانى‌] به آنان داده‌ايم، [و] آن را چنانكه بايد مى‌خوانند، ايشانند كه بدان ايمان دارند. و[لى‌] كسانى كه بدان كفر ورزند، همانانند كه زيانكارانند.\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@cxxix{اى فرزندان اسرائيل، نعمتم را، كه بر شما ارزانى داشتم، و اينكه شما را بر جهانيان برترى دادم، ياد كنيد.\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@cxxx{و بترسيد از روزى كه هيچ كس چيزى [از عذاب خدا] را از كسى دفع نمى‌كند، و نه بدل و بلاگردانى از وى پذيرفته شود، و نه او را ميانجيگرى سودمند افتد، و نه يارى شوند.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@cxxxi{و چون ابراهيم را پروردگارش با كلماتى بيازمود، و وى آن همه را به انجام رسانيد، [خدا به او] فرمود: «من تو را پيشواى مردم قرار دادم.» [ابراهيم‌] پرسيد: «از دودمانم [چطور]؟» فرمود: «پيمان من به بيدادگران نمى‌رسد.»\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@cxxxii{و چون خانه [كعبه‌] را براى مردم محل اجتماع و [جاى‌] امنى قرار داديم، [و فرموديم:] «در مقام ابراهيم، نمازگاهى براى خود اختيار كنيد»، و به ابراهيم و اسماعيل فرمان داديم كه: «خانه مرا براى طواف‌كنندگان و معتكفان و ركوع و سجودكنندگان پاكيزه كنيد.»\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@cxxxiii{و چون ابراهيم گفت: «پروردگارا، اين [سرزمين‌] را شهرى امن گردان، و مردمش را -هر كس از آنان كه به خدا و روز بازپسين ايمان بياورد- از فرآورده‌ها روزى بخش»، فرمود: «و[لى‌] هر كس كفر بورزد، اندكى برخوردارش مى‌كنم، سپس او را با خوارى به سوى عذاب آتش [دوزخ‌] مى‌كشانم، و چه بد سرانجامى است.»\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@cxxxiv{و هنگامى كه ابراهيم و اسماعيل پايه‌هاى خانه [كعبه‌] را بالا مى‌بردند، [مى‌گفتند:] «اى پروردگار ما، از ما بپذير كه در حقيقت، تو شنواى دانايى.\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@cxxxv{پروردگارا، ما را تسليم [فرمان‌] خود قرار ده؛ و از نسل ما، امتى فرمانبردار خود [پديد آر]؛ و آداب دينى ما را به ما نشان ده؛ و بر ما ببخشاى، كه تويى توبه‌پذير مهربان.\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@cxxxvi{پروردگارا، در ميان آنان، فرستاده‌اى از خودشان برانگيز، تا آيات تو را بر آنان بخواند، و كتاب و حكمت به آنان بياموزد و پاكيزه‌شان كند، زيرا كه تو خود، شكست‌ناپذير حكيمى.»\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@cxxxvii{و چه كسى -جز آنكه به سبك‌مغزى گرايد- از آيين ابراهيم روى برمى‌تابد؟ و ما او را در اين دنيا برگزيديم؛ و البته در آخرت [نيز] از شايستگان خواهد بود.\qt@no{(130)}}
\qt@newcmd\qurantrans@fa@cxxxviii{هنگامى كه پروردگارش به او فرمود: «تسليم شو»، گفت: «به پروردگار جهانيان تسليم شدم.»\qt@no{(131)}}
\qt@newcmd\qurantrans@fa@cxxxix{و ابراهيم و يعقوب، پسران خود را به همان [آيين‌] سفارش كردند؛ [و هر دو در وصيتشان چنين گفتند:] «اى پسران من، خداوند براى شما اين دين را برگزيد؛ پس، البته نبايد جز مسلمان بميريد.»\qt@no{(132)}}
\qt@newcmd\qurantrans@fa@cxl{آيا وقتى كه يعقوب را مرگ فرا رسيد، حاضر بوديد؟ هنگامى كه به پسران خود گفت: «پس از من، چه را خواهيد پرستيد؟» گفتند: «معبود تو، و معبود پدرانت، ابراهيم و اسماعيل و اسحاق -معبودى يگانه- را مى‌پرستيم؛ و در برابر او تسليم هستيم.»\qt@no{(133)}}
\qt@newcmd\qurantrans@fa@cxli{آن جماعت را روزگار به سر آمد؛ دستاورد آنان براى آنان و دستاورد شما براى شماست؛ و از آنچه آنان مى‌كرده‌اند، شما بازخواست نخواهيد شد.\qt@no{(134)}}
\qt@newcmd\qurantrans@fa@cxlii{و [اهل كتاب‌] گفتند: «يهودى يا مسيحى باشيد، تا هدايت يابيد»؛ بگو: «نه، بلكه [بر] آيين ابراهيم حق‌گرا [هستم‌]؛ و وى از مشركان نبود.»\qt@no{(135)}}
\qt@newcmd\qurantrans@fa@cxliii{بگوييد: «ما به خدا، و به آنچه بر ما نازل شده، و به آنچه بر ابراهيم و اسحاق و يعقوب و اسباط نازل آمده، و به آنچه به موسى و عيسى داده شده، و به آنچه به همه پيامبران از سوى پروردگارشان داده شده، ايمان آورده‌ايم؛ ميان هيچ يك از ايشان فرق نمى‌گذاريم؛ و در برابر او تسليم هستيم.»\qt@no{(136)}}
\qt@newcmd\qurantrans@fa@cxliv{پس اگر آنان [هم‌] به آنچه شما بدان ايمان آورده‌ايد، ايمان آوردند، قطعاً هدايت شده‌اند، ولى اگر روى برتافتند، جز اين نيست كه سر ستيز [و جدايى ] دارند؛ و به زودى خداوند [شر] آنان را از تو كفايت خواهد كرد، كه او شنواى داناست.\qt@no{(137)}}
\qt@newcmd\qurantrans@fa@cxlv{اين است نگارگرى الهى؛ و كيست خوش‌نگارتر از خدا؟ و ما او را پرستندگانيم.\qt@no{(138)}}
\qt@newcmd\qurantrans@fa@cxlvi{بگو: آيا درباره خدا با ما بحث و گفتگو مى‌كنيد؟ با آنكه او پروردگار ما و پروردگار شماست؛ و كردارهاى ما از آن ما، و كردارهاى شما از آن شماست، و ما براى او اخلاص مى‌ورزيم.\qt@no{(139)}}
\qt@newcmd\qurantrans@fa@cxlvii{يا مى‌گوييد: «ابراهيم و اسماعيل و اسحاق و يعقوب و اسباط [دوازده‌گانه‌] يهودى يا نصرانى بوده‌اند؟» بگو: «آيا شما بهتر مى‌دانيد يا خدا؟» و كيست ستمكارتر از آن كس كه شهادتى از خدا را در نزد خويش پوشيده دارد؟ و خدا از آنچه مى‌كنيد غافل نيست.\qt@no{(140)}}
\qt@newcmd\qurantrans@fa@cxlviii{آن جماعت را روزگار سپرى شد؛ براى ايشان است آنچه به دست آورده‌اند؛ و براى شماست آنچه به دست آورده‌ايد؛ و از آنچه آنان مى‌كرده‌اند، شما بازخواست نخواهيد شد.\qt@no{(141)}}
\qt@newcmd\qurantrans@fa@cxlix{به زودى مردم كم خرد خواهند گفت: «چه چيز آنان را از قبله‌اى كه بر آن بودند رويگردان كرد؟» بگو: «مشرق و مغرب از آن خداست؛ هر كه را خواهد به راه راست هدايت مى‌كند.»\qt@no{(142)}}
\qt@newcmd\qurantrans@fa@cl{و بدين گونه شما را امتى ميانه قرار داديم، تا بر مردم گواه باشيد؛ و پيامبر بر شما گواه باشد. و قبله‌اى را كه [چندى‌] بر آن بودى، مقرر نكرديم جز براى آنكه كسى را كه از پيامبر پيروى مى‌كند، از آن كس كه از عقيده خود برمى‌گردد بازشناسيم؛ هر چند [اين كار] جز بر كسانى كه خدا هدايت‌[شان‌] كرده، سخت گران بود؛ و خدا بر آن نبود كه ايمان شما را ضايع گرداند، زيرا خدا [نسبت‌] به مردم دلسوز و مهربان است.\qt@no{(143)}}
\qt@newcmd\qurantrans@fa@cli{ما [به هر سو] گردانيدنِ رويت در آسمان را نيك مى‌بينيم. پس [باش تا] تو را به قبله‌اى كه بدان خشنود شوى برگردانيم؛ پس روى خود را به سوى مسجدالحرام كن؛ و هر جا بوديد، روى خود را به سوى آن بگردانيد. در حقيقت، اهل كتاب نيك مى‌دانند كه اين [تغيير قبله‌] از جانب پروردگارشان [بجا و] درست است؛ و خدا از آنچه مى‌كنند غافل نيست.\qt@no{(144)}}
\qt@newcmd\qurantrans@fa@clii{و اگر هر گونه معجزه‌اى براى اهل كتاب بياورى [باز] قبله تو را پيروى نمى‌كنند، و تو [نيز] پيرو قبله آنان نيستى، و خود آنان پيرو قبله يكديگر نيستند، و پس از علمى كه تو را [حاصل‌] آمده، اگر از هوسهاى ايشان پيروى كنى، در آن صورت جداً از ستمكاران خواهى بود.\qt@no{(145)}}
\qt@newcmd\qurantrans@fa@cliii{كسانى كه به ايشان كتاب [آسمانى‌] داده‌ايم، همان گونه كه پسران خود را مى‌شناسند، او [=محمد] را مى‌شناسند؛ و مسلماً گروهى از ايشان حقيقت را نهفته مى‌دارند، و خودشان [هم‌] مى‌دانند.\qt@no{(146)}}
\qt@newcmd\qurantrans@fa@cliv{حق از جانب پروردگار توست. پس مبادا از ترديدكنندگان باشى.\qt@no{(147)}}
\qt@newcmd\qurantrans@fa@clv{و براى هر كسى قبله‌اى است كه وى روى خود را به آن [سوى‌] مى‌گرداند؛ پس در كارهاى نيك بر يكديگر پيشى گيريد. هر كجا كه باشيد، خداوند همگى شما را [به سوى خود باز] مى‌آورد؛ در حقيقت، خدا بر همه چيز تواناست.\qt@no{(148)}}
\qt@newcmd\qurantrans@fa@clvi{و از هر كجا بيرون آمدى، روى خود را به سوى مسجدالحرام بگردان، و البته اين [فرمان‌] حق است و از جانب پروردگار تو است و خداوند از آنچه مى‌كنيد غافل نيست.\qt@no{(149)}}
\qt@newcmd\qurantrans@fa@clvii{و از هر كجا بيرون آمدى، [به هنگام نماز] روى خود را به سمت مسجدالحرام بگردان؛ و هر كجا بوديد رويهاى خود را به سوى آن بگردانيد، تا براى مردم -غير از ستمگرانشان- بر شما حجتى نباشد. پس، از آنان نترسيد، و از من بترسيد، تا نعمت خود را بر شما كامل گردانم، و باشد كه هدايت شويد.\qt@no{(150)}}
\qt@newcmd\qurantrans@fa@clviii{همان طور كه در ميان شما، فرستاده‌اى از خودتان روانه كرديم، [كه‌] آيات ما را بر شما مى‌خواند، و شما را پاك مى‌گرداند، و به شما كتاب و حكمت مى‌آموزد، و آنچه را نمى‌دانستيد به شما ياد مى‌دهد.\qt@no{(151)}}
\qt@newcmd\qurantrans@fa@clix{پس مرا ياد كنيد، [تا] شما را ياد كنم؛ و شكرانه‌ام را به جاى آريد؛ و با من ناسپاسى نكنيد.\qt@no{(152)}}
\qt@newcmd\qurantrans@fa@clx{اى كسانى كه ايمان آورده‌ايد، از شكيبايى و نماز يارى جوييد؛ زيرا خدا با شكيبايان است.\qt@no{(153)}}
\qt@newcmd\qurantrans@fa@clxi{و كسانى را كه در راه خدا كشته مى‌شوند، مرده نخوانيد، بلكه زنده‌اند؛ ولى شما نمى‌دانيد.\qt@no{(154)}}
\qt@newcmd\qurantrans@fa@clxii{و قطعاً شما را به چيزى از [قبيلِ‌] ترس و گرسنگى، و كاهشى در اموال و جانها و محصولات مى‌آزماييم؛ و مژده ده شكيبايان را:\qt@no{(155)}}
\qt@newcmd\qurantrans@fa@clxiii{[همان‌] كسانى كه چون مصيبتى به آنان برسد، مى‌گويند: «ما از آنِ خدا هستيم، و به سوى او باز مى‌گرديم.»\qt@no{(156)}}
\qt@newcmd\qurantrans@fa@clxiv{بر ايشان درودها و رحمتى از پروردگارشان [باد] و راه‌يافتگان [هم‌] خود ايشانند.\qt@no{(157)}}
\qt@newcmd\qurantrans@fa@clxv{در حقيقت، «صفا» و «مروه» از شعاير خداست [كه يادآور اوست‌]؛ پس هر كه خانه [خدا] را حج كند، يا عمره گزارد، بر او گناهى نيست كه ميان آن دو سعى به جاى آورد. و هر كه افزون بر فريضه، كار نيكى كند، خدا حق شناس و داناست.\qt@no{(158)}}
\qt@newcmd\qurantrans@fa@clxvi{كسانى كه نشانه‌هاى روشن، و رهنمودى را كه فرو فرستاده‌ايم، بعد از آنكه آن را براى مردم در كتاب توضيح داده‌ايم، نهفته مى‌دارند، آنان را خدا لعنت مى‌كند، و لعنت‌كنندگان لعنتشان مى‌كنند.\qt@no{(159)}}
\qt@newcmd\qurantrans@fa@clxvii{مگر كسانى كه توبه كردند، و [خود را] اصلاح نمودند، و [حقيقت را] آشكار كردند، پس بر آنان خواهم بخشود؛ و من توبه‌پذير مهربانم.\qt@no{(160)}}
\qt@newcmd\qurantrans@fa@clxviii{كسانى كه كافر شدند، و در حال كفر مردند، لعنت خدا و فرشتگان و تمام مردم بر آنان باد.\qt@no{(161)}}
\qt@newcmd\qurantrans@fa@clxix{در آن [لعنت‌] جاودانه بمانند؛ نه عذابشان كاسته گردد، و نه مهلت يابند.\qt@no{(162)}}
\qt@newcmd\qurantrans@fa@clxx{و معبود شما، معبود يگانه‌اى است كه جز او هيچ معبودى نيست، [و اوست‌] بخشايشگر مهربان.\qt@no{(163)}}
\qt@newcmd\qurantrans@fa@clxxi{راستى كه در آفرينش آسمانها و زمين، و در پى يكديگر آمدن شب و روز، و كشتيهايى كه در دريا روانند با آنچه به مردم سود مى‌رساند، و [همچنين‌] آبى كه خدا از آسمان فرو فرستاده، و با آن، زمين را پس از مردنش زنده گردانيده، و در آن هر گونه جنبنده‌اى پراكنده كرده، و [نيز در] گردانيدن بادها، و ابرى كه ميان آسمان و زمين آرميده است، براى گروهى كه مى‌انديشند، واقعاً نشانه‌هايى [گويا] وجود دارد.\qt@no{(164)}}
\qt@newcmd\qurantrans@fa@clxxii{و برخى از مردم، در برابر خدا، همانندهايى [براى او] برمى‌گزينند، و آنها را چون دوستى خدا، دوست مى‌دارند؛ ولى كسانى كه ايمان آورده‌اند، به خدا محبت بيشترى دارند. كسانى كه [با برگزيدن بتها، به خود] ستم نموده‌اند اگر مى‌دانستند هنگامى كه عذاب را مشاهده كنند تمام نيرو[ها] از آنِ خداست، و خدا سخت‌كيفر است.\qt@no{(165)}}
\qt@newcmd\qurantrans@fa@clxxiii{آنگاه كه پيشوايان از پيروان بيزارى جويند؛ و عذاب را مشاهده كنند، و ميانشان پيوندها بريده گردد.\qt@no{(166)}}
\qt@newcmd\qurantrans@fa@clxxiv{و پيروان مى‌گويند: «كاش براى ما بازگشتى بود تا همان گونه كه [آنان‌] از ما بيزارى جستند [ما نيز] از آنان بيزارى مى‌جستيم.» اين گونه خداوند، كارهايشان را -كه بر آنان مايه حسرتهاست- به ايشان مى‌نماياند، و از آتش بيرون‌آمدنى نيستند.\qt@no{(167)}}
\qt@newcmd\qurantrans@fa@clxxv{اى مردم، از آنچه در زمين است حلال و پاكيزه را بخوريد، و از گامهاى شيطان پيروى مكنيد كه او دشمن آشكار شماست.\qt@no{(168)}}
\qt@newcmd\qurantrans@fa@clxxvi{[او] شما را فقط به بدى و زشتى فرمان مى‌دهد، و [وامى‌دارد] تا بر خدا، چيزى را كه نمى‌دانيد بربنديد.\qt@no{(169)}}
\qt@newcmd\qurantrans@fa@clxxvii{و چون به آنان گفته شود: «از آنچه خدا نازل كرده است پيروى كنيد»؛ مى‌گويند: «نه، بلكه از چيزى كه پدران خود را بر آن يافته‌ايم، پيروى مى‌كنيم.» آيا هر چند پدرانشان چيزى را درك نمى‌كرده و به راه صواب نمى‌رفته‌اند [باز هم در خور پيروى هستند]؟\qt@no{(170)}}
\qt@newcmd\qurantrans@fa@clxxviii{و مَثَل [دعوت‌كننده‌] كافران چون مَثَل كسى است كه حيوانى را كه جز صدا و ندايى [مبهم، چيزى‌] نمى‌شنود بانگ مى‌زند. [آرى،] كرند، لالند، كورند. [و] درنمى‌يابند.\qt@no{(171)}}
\qt@newcmd\qurantrans@fa@clxxix{اى كسانى كه ايمان آورده‌ايد، از نعمتهاى پاكيزه‌اى كه روزى شما كرده‌ايم، بخوريد و اگر تنها او را مى‌پرستيد خدا را شكر كنيد.\qt@no{(172)}}
\qt@newcmd\qurantrans@fa@clxxx{[خداوند،] تنها مردار و خون و گوشت خوك و آنچه را كه [هنگام سر بريدن‌] نام غير خدا بر آن برده شده، بر شما حرام گردانيده است. [ولى‌] كسى كه [براى حفظ جان خود به خوردن آنها] ناچار شود، در صورتى كه ستمگر و متجاوز نباشد بر او گناهى نيست، زيرا خدا آمرزنده و مهربان است.\qt@no{(173)}}
\qt@newcmd\qurantrans@fa@clxxxi{كسانى كه آنچه را خداوند از كتاب نازل كرده، پنهان مى‌دارند و بدان بهاى ناچيزى به دست مى‌آورند، آنان جز آتش در شكمهاى خويش فرو نبرند. و خدا روز قيامت با ايشان سخن نخواهد گفت، و پاكشان نخواهد كرد، و عذابى دردناك خواهند داشت.\qt@no{(174)}}
\qt@newcmd\qurantrans@fa@clxxxii{آنان همان كسانى هستند كه گمراهى را به [بهاى‌] هدايت، و عذاب را به [ازاى‌] آمرزش خريدند، پس به راستى چه اندازه بايد بر آتش شكيبا باشند!\qt@no{(175)}}
\qt@newcmd\qurantrans@fa@clxxxiii{چرا كه خداوند كتاب [تورات‌] را به حق نازل كرده است، و كسانى كه در باره كتاب [خدا] با يكديگر به اختلاف پرداختند، در ستيزه‌اى دور و درازند.\qt@no{(176)}}
\qt@newcmd\qurantrans@fa@clxxxiv{نيكوكارى آن نيست كه روى خود را به سوى مشرق و [يا] مغرب بگردانيد، بلكه نيكى آن است كه كسى به خدا و روز بازپسين و فرشتگان و كتاب [آسمانى‌] و پيامبران ايمان آورد، و مال [خود] را با وجود دوست داشتنش، به خويشاوندان و يتيمان و بينوايان و در راه‌ماندگان و گدايان و در [راه آزاد كردن‌] بندگان بدهد، و نماز را برپاى دارد، و زكات را بدهد، و آنان كه چون عهد بندند، به عهد خود وفادارانند؛ و در سختى و زيان، و به هنگام جنگ شكيبايانند؛ آنانند كسانى كه راست گفته‌اند، و آنان همان پرهيزگارانند.\qt@no{(177)}}
\qt@newcmd\qurantrans@fa@clxxxv{اى كسانى كه ايمان آورده‌ايد، در باره كشتگان، بر شما [حق‌] قصاص مقرر شده: آزاد عوض آزاد و بنده عوض بنده و زن عوض زن. و هر كس كه از جانب برادر [دينى‌]اش [يعنى ولىّ مقتول‌]، چيزى [از حق قصاص‌] به او گذشت شود، [بايد از گذشت ولىّ مقتول‌] به طور پسنديده پيروى كند، و با [رعايت‌] احسان، [خونبها را] به او بپردازد. اين [حكم‌] تخفيف و رحمتى از پروردگار شماست؛ پس هر كس، بعد از آن از اندازه درگذرد، وى را عذابى دردناك است.\qt@no{(178)}}
\qt@newcmd\qurantrans@fa@clxxxvi{و اى خردمندان، شما را در قصاص زندگانى است، باشد كه به تقوا گراييد.\qt@no{(179)}}
\qt@newcmd\qurantrans@fa@clxxxvii{بر شما مقرر شده است كه چون يكى از شما را مرگ فرا رسد، اگر مالى بر جاى گذارد، براى پدر و مادر و خويشاوندان [خود] به طور پسنديده وصيت كند؛ [اين كار] حقى است بر پرهيزگاران.\qt@no{(180)}}
\qt@newcmd\qurantrans@fa@clxxxviii{پس هر كس آن [وصيت‌] را بعد از شنيدنش تغيير دهد، گناهش تنها بر [گردن‌] كسانى است كه آن را تغيير مى‌دهند. آرى، خدا شنواى داناست.\qt@no{(181)}}
\qt@newcmd\qurantrans@fa@clxxxix{ولى كسى كه از انحراف [و تمايل بيجاى‌] وصيت‌كننده‌اى [نسبت به ورثه‌اش‌] يا از گناه او [در وصيت به كار خلاف‌] بيم داشته باشد و ميانشان را سازش دهد، بر او گناهى نيست، كه خدا آمرزنده مهربان است.\qt@no{(182)}}
\qt@newcmd\qurantrans@fa@cxc{اى كسانى كه ايمان آورده‌ايد، روزه بر شما مقرر شده است، همان گونه كه بر كسانى كه پيش از شما [بودند] مقرر شده بود، باشد كه پرهيزگارى كنيد.\qt@no{(183)}}
\qt@newcmd\qurantrans@fa@cxci{[روزه در] روزهاى معدودى [بر شما مقرر شده است‌]. [ولى‌] هر كس از شما بيمار يا در سفر باشد، [به همان شماره‌] تعدادى از روزهاى ديگر [را روزه بدارد]، و بر كسانى كه [روزه‌] طاقت‌فرساست، كفاره‌اى است كه خوراك دادن به بينوايى است. و هر كس به ميل خود، بيشتر نيكى كند، پس آن براى او بهتر است، و اگر بدانيد، روزه گرفتن براى شما بهتر است.\qt@no{(184)}}
\qt@newcmd\qurantrans@fa@cxcii{ماه رمضان [همان ماه‌] است كه در آن، قرآن فرو فرستاده شده است، [كتابى ] كه مردم را راهبر، و [متضمّن‌] دلايل آشكار هدايت، و [ميزان‌] تشخيص حق از باطل است. پس هر كس از شما اين ماه را درك كند بايد آن را روزه بدارد، و كسى كه بيمار يا در سفر است [بايد به شماره آن،] تعدادى از روزهاى ديگر [را روزه بدارد]. خدا براى شما آسانى مى‌خواهد و براى شما دشوارى نمى‌خواهد؛ تا شماره [مقرر ]را تكميل كنيد و خدا را به پاس آنكه رهنمونيتان كرده است به بزرگى بستاييد، و باشد كه شكرگزارى كنيد.\qt@no{(185)}}
\qt@newcmd\qurantrans@fa@cxciii{و هرگاه بندگان من، از تو در باره من بپرسند، [بگو] من نزديكم، و دعاى دعاكننده را -به هنگامى كه مرا بخواند- اجابت مى‌كنم، پس [آنان‌] بايد فرمان مرا گردن نهند و به من ايمان آورند، باشد كه راه يابند.\qt@no{(186)}}
\qt@newcmd\qurantrans@fa@cxciv{در شبهاى روزه، همخوابگى با زنانتان بر شما حلال گرديده است. آنان براى شما لباسى هستند و شما براى آنان لباسى هستيد. خدا مى‌دانست كه شما با خودتان ناراستى مى‌كرديد، پس توبه شما را پذيرفت و از شما درگذشت. پس، اكنون [در شبهاى ماه رمضان مى‌توانيد] با آنان همخوابگى كنيد، و آنچه را خدا براى شما مقرر داشته طلب كنيد. و بخوريد و بياشاميد تا رشته سپيد بامداد از رشته سياه [شب‌] بر شما نمودار شود؛ سپس روزه را تا [فرا رسيدن‌] شب به اتمام رسانيد. و در حالى كه در مساجد معتكف هستيد [با زنان‌] درنياميزيد. اين است حدود احكام الهى! پس [زنهار به قصد گناه‌] بدان نزديك نشويد. اين گونه، خداوند آيات خود را براى مردم بيان مى‌كند، باشد كه پروا پيشه كنند.\qt@no{(187)}}
\qt@newcmd\qurantrans@fa@cxcv{و اموالتان را ميان خودتان به ناروا مخوريد، و [به عنوان رشوه قسمتى از] آن را به قضات مدهيد تا بخشى از اموال مردم را به گناه بخوريد، در حالى كه خودتان [هم خوب‌] مى‌دانيد.\qt@no{(188)}}
\qt@newcmd\qurantrans@fa@cxcvi{در باره [حكمت‌] هلالها[ى ماه‌] از تو مى‌پرسند، بگو: «آنها [شاخص‌] گاه‌شمارى براى مردم و [موسم‌] حجّ‌اند.» و نيكى آن نيست كه از پشت خانه‌ها درآييد، بلكه نيكى آن است كه كسى تقوا پيشه كند، و به خانه‌ها از در [ورودى‌] آنها درآييد، و از خدا بترسيد، باشد كه رستگار گرديد.\qt@no{(189)}}
\qt@newcmd\qurantrans@fa@cxcvii{و در راه خدا، با كسانى كه با شما مى‌جنگند، بجنگيد، ولى از اندازه درنگذريد، زيرا خداوند تجاوزكاران را دوست نمى‌دارد؛\qt@no{(190)}}
\qt@newcmd\qurantrans@fa@cxcviii{و هر كجا بر ايشان دست يافتيد آنان را بكشيد، و همان گونه كه شما را بيرون راندند، آنان را بيرون برانيد، [چرا كه‌] فتنه [=شرك‌] از قتل بدتر است، [با اين همه‌] در كنار مسجد الحرام با آنان جنگ مكنيد، مگر آنكه با شما در آن جا به جنگ درآيند، پس اگر با شما جنگيدند، آنان را بكشيد، كه كيفر كافران چنين است.\qt@no{(191)}}
\qt@newcmd\qurantrans@fa@cxcix{و اگر بازايستادند، البته خدا آمرزنده مهربان است.\qt@no{(192)}}
\qt@newcmd\qurantrans@fa@cc{با آنان بجنگيد تا ديگر فتنه‌اى نباشد، و دين، مخصوص خدا شود. پس اگر دست برداشتند، تجاوز جز بر ستمكاران روا نيست.\qt@no{(193)}}
\qt@newcmd\qurantrans@fa@cci{اين ماه حرام در برابر آن ماه حرام است، و [هتك‌] حرمتها قصاص دارد. پس هر كس بر شما تعدّى كرد، همان گونه كه بر شما تعدّى كرده، بر او تعدّى كنيد و از خدا پروا بداريد و بدانيد كه خدا با تقواپيشگان است.\qt@no{(194)}}
\qt@newcmd\qurantrans@fa@ccii{و در راه خدا انفاق كنيد، و خود را با دست خود به هلاكت ميفكنيد، و نيكى كنيد كه خدا نيكوكاران را دوست مى‌دارد.\qt@no{(195)}}
\qt@newcmd\qurantrans@fa@cciii{و براى خدا حجّ و عمره را به پايان رسانيد، و اگر [به علت موانعى‌] بازداشته شديد، آنچه از قربانى ميسر است [قربانى كنيد]؛ و تا قربانى به قربانگاه نرسيده سر خود را متراشيد؛ و هر كس از شما بيمار باشد يا در سر ناراحتيى داشته باشد [و ناچار شود در احرام سر بتراشد] به كفاره [آن، بايد] روزه‌اى بدارد، يا صدقه‌اى دهد، يا قربانيى بكند؛ و چون ايمنى يافتيد، پس هر كس از [اعمال‌] عمره به حجّ پرداخت، [بايد ]آنچه از قربانى ميسر است [قربانى كند]، و آن كس كه [قربانى ]نيافت [بايد] در هنگام حجّ، سه روز روزه [بدارد]؛ و چون برگشتيد هفت [روز ديگر روزه بداريد]؛ اين ده [روز] تمام است. اين [حجّ تمتّع ]براى كسى است كه اهل مسجد الحرام [=مكّه‌] نباشد؛ و از خدا بترسيد، و بدانيد كه خدا سخت‌كيفر است.\qt@no{(196)}}
\qt@newcmd\qurantrans@fa@cciv{حجّ در ماههاى معينى است. پس هر كس در اين [ماه‌]ها، حجّ را [برخود] واجب گرداند، [بداند كه‌] در اثناى حجّ، همبسترى و گناه و جدال [روا] نيست، و هر كار نيكى انجام مى‌دهيد، خدا آن را مى‌داند، و براى خود توشه برگيريد كه در حقيقت، بهترين توشه، پرهيزگارى است، و اى خردمندان! از من پروا كنيد.\qt@no{(197)}}
\qt@newcmd\qurantrans@fa@ccv{بر شما گناهى نيست كه [در سفر حجّ‌] از فضل پروردگارتان [روزىِ خويش‌] بجوييد؛ پس چون از عرفات كوچ نموديد، خدا را در مشعر الحرام ياد كنيد، و يادش كنيد كه شما را كه پيشتر از بيراهان بوديد، فرا راه آورد.\qt@no{(198)}}
\qt@newcmd\qurantrans@fa@ccvi{پس، از همان جا كه [انبوه‌] مردم روانه مى‌شوند، شما نيز روانه شويد و از خداوند آمرزش خواهيد كه خدا آمرزنده مهربان است.\qt@no{(199)}}
\qt@newcmd\qurantrans@fa@ccvii{و چون آداب ويژه حجّ خود را به جاى آورديد، همان گونه كه پدران خود را به ياد مى‌آوريد، يا با يادكردنى بيشتر، خدا را به ياد آوريد. و از مردم كسى است كه مى‌گويد: «پروردگارا، به ما، در همين دنيا عطا كن» و حال آنكه براى او در آخرت نصيبى نيست.\qt@no{(200)}}
\qt@newcmd\qurantrans@fa@ccviii{و برخى از آنان مى‌گويند: «پروردگارا! در اين دنيا به ما نيكى و در آخرت [نيز] نيكى عطا كن، و ما را از عذاب آتش [دور] نگه دار.»\qt@no{(201)}}
\qt@newcmd\qurantrans@fa@ccix{آنانند كه از دستاوردشان بهره‌اى خواهند داشت و خدا زودشمار است.\qt@no{(202)}}
\qt@newcmd\qurantrans@fa@ccx{و خدا را در روزهايى معيّن ياد كنيد، پس هر كس شتاب كند [و اعمال را] در دو روز [انجام دهد]، گناهى بر او نيست، و هر كه تأخير كند [و اعمال را در سه روز انجام دهد] گناهى بر او نيست. [اين اختيار ]براى كسى است كه [از محرمات‌] پرهيز كرده باشد. و از خدا پروا كنيد و بدانيد كه شما را به سوى او گرد خواهد آورد.\qt@no{(203)}}
\qt@newcmd\qurantrans@fa@ccxi{و از ميان مردم كسى است كه در زندگى اين دنيا سخنش تو را به تعجّب وامى‌دارد، و خدا را بر آنچه در دل دارد گواه مى‌گيرد، و حال آنكه او سخت‌ترين دشمنان است.\qt@no{(204)}}
\qt@newcmd\qurantrans@fa@ccxii{و چون برگردد [يا رياستى يابد] كوشش مى‌كند كه در زمين فساد نمايد و كِشت و نسل را نابود سازد، و خداوند تباهكارى را دوست ندارد.\qt@no{(205)}}
\qt@newcmd\qurantrans@fa@ccxiii{و چون به او گفته شود: «از خدا پروا كن» نخوت، وى را به گناه كشاند. پس جهنم براى او بس است، و چه بد بسترى است.\qt@no{(206)}}
\qt@newcmd\qurantrans@fa@ccxiv{و از ميان مردم كسى است كه جان خود را براى طلب خشنودى خدا مى‌فروشد، و خدا نسبت به [اين‌] بندگان مهربان است.\qt@no{(207)}}
\qt@newcmd\qurantrans@fa@ccxv{اى كسانى كه ايمان آورده‌ايد، همگى به اطاعت [خدا] درآييد، و گامهاى شيطان را دنبال مكنيد كه او براى شما دشمنى آشكار است.\qt@no{(208)}}
\qt@newcmd\qurantrans@fa@ccxvi{و اگر پس از آنكه براى شما دلايل آشكار آمد، دستخوش لغزش شديد، بدانيد كه خداوند تواناى حكيم است.\qt@no{(209)}}
\qt@newcmd\qurantrans@fa@ccxvii{مگر انتظار آنان غير از اين است كه خدا و فرشتگان، در [زير] سايبانهايى از ابر سپيد به سوى آنان بيايند و كار [داورى‌] يكسره شود؟ و كارها به سوى خدا بازگردانده مى‌شود.\qt@no{(210)}}
\qt@newcmd\qurantrans@fa@ccxviii{از فرزندان اسرائيل بپرس: چه بسيار نشانه‌هاى روشنى به آنان داديم و هر كس نعمت خدا را -پس از آنكه براى او آمد- [به كفران‌] بدل كند، خدا سخت‌كيفر است.\qt@no{(211)}}
\qt@newcmd\qurantrans@fa@ccxix{زندگى دنيا در چشم كافران آراسته شده است، و مؤمنان را ريشخند مى‌كنند و [حال آنكه‌] كسانى كه تقواپيشه بوده‌اند، در روز رستاخيز، از آنان برترند و خدا به هر كه بخواهد، بى‌شمار روزى مى‌دهد.\qt@no{(212)}}
\qt@newcmd\qurantrans@fa@ccxx{مردم، امتى يگانه بودند؛ پس خداوند پيامبران را نويدآور و بيم‌دهنده برانگيخت، و با آنان، كتاب [خود] را بحق فرو فرستاد، تا ميان مردم در آنچه با هم اختلاف داشتند داورى كند. و جز كسانى كه [كتاب‌] به آنان داده شد -پس از آنكه دلايل روشن براى آنان آمد- به خاطر ستم [و حسدى‌] كه ميانشان بود، [هيچ كس‌] در آن اختلاف نكرد. پس خداوند آنان را كه ايمان آورده بودند، به توفيق خويش، به حقيقت آنچه كه در آن اختلاف داشتند، هدايت كرد. و خدا هر كه را بخواهد به راه راست هدايت مى‌كند.\qt@no{(213)}}
\qt@newcmd\qurantrans@fa@ccxxi{آيا پنداشتيد كه داخل بهشت مى‌شويد و حال آنكه هنوز مانند آنچه بر [سر] پيشينيان شما آمد، بر [سر] شما نيامده است؟ آنان دچار سختى و زيان شدند و به [هول و] تكان درآمدند، تا جايى كه پيامبر [خدا ]و كسانى كه با وى ايمان آورده بودند گفتند: «پيروزى خدا كى خواهد بود؟» هش دار، كه پيروزى خدا نزديك است.\qt@no{(214)}}
\qt@newcmd\qurantrans@fa@ccxxii{از تو مى‌پرسند: «چه چيزى انفاق كنند [و به چه كسى بدهند]؟» بگو: «هر مالى انفاق كنيد، به پدر و مادر و نزديكان و يتيمان و مسكينان و به در راه‌مانده تعلّق دارد، و هر گونه نيكى كنيد البته خدا به آن داناست.»\qt@no{(215)}}
\qt@newcmd\qurantrans@fa@ccxxiii{بر شما كارزار واجب شده است، در حالى كه براى شما ناگوار است. و بسا چيزى را خوش نمى‌داريد و آن براى شما خوب است، و بسا چيزى را دوست مى‌داريد و آن براى شما بد است، و خدا مى‌داند و شما نمى‌دانيد.\qt@no{(216)}}
\qt@newcmd\qurantrans@fa@ccxxiv{از تو در باره ماهى كه كارزار در آن حرام است مى‌پرسند. بگو: «كارزار در آن، گناهى بزرگ و باز داشتن از راه خدا و كفر ورزيدن به او و باز داشتن از مسجدالحرام [=حج‌]، و بيرون راندن اهل آن از آنجا، نزد خدا [گناهى‌] بزرگتر، و فتنه [=شرك‌] از كشتار بزرگتر است.» و آنان پيوسته با شما مى‌جنگند تا -اگر بتوانند- شما را از دينتان برگردانند. و كسانى از شما كه از دين خود برگردند و در حال كفر بميرند، آنان كردارهايشان در دنيا و آخرت تباه مى‌شود، و ايشان اهل آتشند و در آن ماندگار خواهند بود.\qt@no{(217)}}
\qt@newcmd\qurantrans@fa@ccxxv{آنان كه ايمان آورده، و كسانى كه هجرت كرده و راه خدا جهاد نموده‌اند، آنان به رحمت خدا اميدوارند، خداوند آمرزنده مهربان است.\qt@no{(218)}}
\qt@newcmd\qurantrans@fa@ccxxvi{در باره شراب و قمار، از تو مى‌پرسند، بگو: «در آن دو، گناهى بزرك، و سودهايى براى مردم است، و[لى‌] گناهشان از سودشان بزرگتر است.» و از تو مى‌پرسند: «چه چيزى انفاق كنند؟» بگو: «مازاد [بر نيازمندى خود] را.» اين گونه، خداوند آيات [خود را] براى شما روشن مى‌گرداند، باشد كه در [كار] دنيا و آخرت بينديشيد.\qt@no{(219)}}
\qt@newcmd\qurantrans@fa@ccxxvii{و در باره يتيمان از تو مى‌پرسند، بگو: «به صلاح آنان كار كردن بهتر است، و اگر با آنان همزيستى كنيد، برادران [دينى‌] شما هستند. و خدا تباهكار را از درستكار بازمى‌شناسد.» و اگر خدا مى‌خواست [در اين باره‌] شما را به دشوارى مى‌انداخت. آرى، خداوند توانا و حكيم است.\qt@no{(220)}}
\qt@newcmd\qurantrans@fa@ccxxviii{و با زنان مشرك ازدواج مكنيد، تا ايمان بياورند. قطعاً كنيز با ايمان بهتر از زن مشرك است، هر چند [زيبايى‌] او شما را به شگفت آورد. و به مردان مشرك زن مدهيد تا ايمان بياورند. قطعاً برده با ايمان بهتر از مرد آزاد مشرك است، هر چند شما را به شگفت آورد. آنان [شما را] به سوى آتش فرا مى‌خوانند، و خدا به فرمان خود، [شما را] به سوى بهشت و آمرزش مى‌خواند، و آيات خود را براى مردم روشن مى‌گرداند، باشد كه متذكر شوند.\qt@no{(221)}}
\qt@newcmd\qurantrans@fa@ccxxix{از تو در باره عادت ماهانه [زنان‌] مى‌پرسند، بگو: «آن، رنجى است. پس هنگام عادت ماهانه، از [آميزش با] زنان كناره گيرى كنيد، و به آنان نزديك نشويد تا پاك شوند. پس چون پاك شدند، از همان جا كه خدا به شما فرمان داده است، با آنان آميزش كنيد.» خداوند توبه‌كاران و پاكيزگان را دوست مى‌دارد.\qt@no{(222)}}
\qt@newcmd\qurantrans@fa@ccxxx{زنان شما كشتزار شما هستند. پس، از هر جا [و هر گونه‌] كه خواهيد به كشتزار خود [در]آييد، و آنها را براى خودتان مقدم داريد، و از خدا پروا كنيد و بدانيد كه او را ديدار خواهيد كرد، و مؤمنان را [به اين ديدار] مژده ده.\qt@no{(223)}}
\qt@newcmd\qurantrans@fa@ccxxxi{و خدا را دستاويز سوگندهاى خود قرار مدهيد، تا [بدين بهانه‌] از نيكوكارى و پرهيزگارى و سازش‌دادن ميان مردم [باز ايستيد]، و خدا شنواى داناست.\qt@no{(224)}}
\qt@newcmd\qurantrans@fa@ccxxxii{خداوند شما را به سوگندهاى لغوتان مؤاخذه نمى‌كند، ولى شما را بدانچه دلهايتان [از روى عمد] فراهم آورده است، مؤاخذه مى‌كند، و خدا آمرزنده بردبار است.\qt@no{(225)}}
\qt@newcmd\qurantrans@fa@ccxxxiii{براى كسانى كه به ترك همخوابگى با زنان خود، سوگند مى‌خورند [=ايلاء]، چهار ماه انتظار [و مهلت‌] است، پس اگر [به آشتى‌] بازآمدند، خداوند آمرزنده مهربان است.\qt@no{(226)}}
\qt@newcmd\qurantrans@fa@ccxxxiv{و اگر آهنگ طلاق كردند، در حقيقت خدا شنواى داناست.\qt@no{(227)}}
\qt@newcmd\qurantrans@fa@ccxxxv{و زنان طلاق داده شده، بايد مدت سه پاكى انتظار كشند، و اگر به خدا و روز بازپسين ايمان دارند، براى آنان روا نيست كه آنچه را خداوند در رحم آنان آفريده، پوشيده دارند؛ و شوهرانشان اگر سر آشتى دارند، به بازآوردن آنان در اين [مدّت‌] سزاوارترند. و مانند همان [وظايفى‌] كه بر عهده زنان است، به طور شايسته، به نفع آنان [بر عهده مردان‌] است، و مردان بر آنان درجه برترى دارند، و خداوند توانا و حكيم است.\qt@no{(228)}}
\qt@newcmd\qurantrans@fa@ccxxxvi{طلاق [رجعى‌] دو بار است. پس از آن يا [بايد زن را] بخوبى نگاه داشتن، يا بشايستگى آزاد كردن. و براى شما روا نيست كه از آنچه به آنان داده‌ايد، چيزى بازستانيد. مگر آنكه [طرفين‌] در به پا داشتن حدود خدا بيمناك باشند. پس اگر بيم داريد كه آن دو، حدود خدا را برپاى نمى‌دارند، در آنچه كه [زن براى آزاد كردن خود] فديه دهد، گناهى بر ايشان نيست. اين است حدود احكام الهى؛ پس، از آن تجاوز مكنيد. و كسانى كه از حدود احكام الهى تجاوز كنند، آنان همان ستمكارانند.\qt@no{(229)}}
\qt@newcmd\qurantrans@fa@ccxxxvii{و اگر [شوهر براى بار سوم‌] او را طلاق گفت، پس از آن، ديگر [آن زن‌] براى او حلال نيست، تا اينكه با شوهرى غير از او ازدواج كند [و با او همخوابگى نمايد]. پس اگر [شوهر دوم‌] وى را طلاق گفت، اگر آن دو [همسر سابق‌] پندارند كه حدود خدا را برپا مى‌دارند، گناهى بر آن دو نيست كه به يكديگر بازگردند. و اينها حدود احكام الهى است كه آن را براى قومى كه مى‌دانند، بيان مى‌كند.\qt@no{(230)}}
\qt@newcmd\qurantrans@fa@ccxxxviii{و چون آنان را طلاق گفتيد، و به پايان عدّه خويش رسيدند، پس بخوبى نگاهشان داريد يا بخوبى آزادشان كنيد. و[لى‌] آنان را براى [آزار و] زيان رساندن [به ايشان‌] نگاه مداريد تا [به حقوقشان‌] تعدّى كنيد. و هر كس چنين كند، قطعاً بر خود ستم نموده است. و آيات خدا را به ريشخند مگيريد، و نعمت خدا را بر خود و آنچه را كه از كتاب و حكمت بر شما نازل كرده و به [وسيله‌] آن به شما اندرز مى‌دهد، به ياد آوريد؛ و از خدا پروا داشته باشيد، و بدانيد كه خدا به هر چيزى داناست.\qt@no{(231)}}
\qt@newcmd\qurantrans@fa@ccxxxix{و چون زنان را طلاق گفتيد، و عدّه خود را به پايان رساندند، آنان را از ازدواج با همسران [سابق‌] خود، چنانچه بخوبى با يكديگر تراضى نمايند، جلوگيرى مكنيد. هر كس از شما به خدا و روز بازپسين ايمان دارد، به اين [دستورها] پند داده مى‌شود. [مراعات‌] اين امر براى شما پربركت‌تر و پاكيزه‌تر است، و خدا مى‌داند و شما نمى‌دانيد.\qt@no{(232)}}
\qt@newcmd\qurantrans@fa@ccxl{و مادران [بايد] فرزندان خود را دو سال تمام شير دهند. [اين حكم‌] براى كسى است كه بخواهد دوران شيرخوارگى را تكميل كند. و خوراك و پوشاك آنان [=مادران‌]، به طور شايسته، بر عهده پدر است. هيچ كس جز به قدر وسعش مكلف نمى‌شود. هيچ مادرى نبايد به سبب فرزندش زيان ببيند، و هيچ پدرى [نيز] نبايد به خاطر فرزندش [ضرر ببيند]. و مانند همين [احكام‌] بر عهده وارث [نيز] هست. پس اگر [پدر و مادر] بخواهند با رضايت و صوابديد يكديگر، كودك را [زودتر] از شير بازگيرند، گناهى بر آن دو نيست. و اگر خواستيد براى فرزندان خود دايه بگيريد، بر شما گناهى نيست، به شرط آنكه چيزى را كه پرداخت آن را به عهده گرفته‌ايد، به طور شايسته بپردازيد. و از خدا پروا كنيد و بدانيد كه خداوند به آنچه انجام مى‌دهيد بيناست.\qt@no{(233)}}
\qt@newcmd\qurantrans@fa@ccxli{و كسانى از شما كه مى‌ميرند و همسرانى بر جاى مى‌گذارند، [همسران‌] چهار ماه و ده روز انتظار مى‌برند؛ پس هرگاه عدّه خود را به پايان رساندند، در آنچه آنان به نحو پسنديده درباره خود انجام دهند، گناهى بر شما نيست، و خداوند به آنچه انجام مى‌دهيد آگاه است.\qt@no{(234)}}
\qt@newcmd\qurantrans@fa@ccxlii{و در باره آنچه شما به طور سربسته، از آنان [در عدّه وفات‌] خواستگارى كرده، يا [آن را] در دل پوشيده داشته‌ايد، بر شما گناهى نيست. خدا مى‌دانست كه [شما] به زودى به ياد آنان خواهيد افتاد، ولى با آنان قول و قرار پنهانى مگذاريد، مگر آنكه سخنى پسنديده بگوييد. و به عقد زناشويى تصميم مگيريد، تا زمان مقرر به سرآيد، و بدانيد كه خداوند آنچه را در دل داريد مى‌داند. پس، از [مخالفت‌] او بترسيد، و بدانيد كه خداوند آمرزنده و بردبار است.\qt@no{(235)}}
\qt@newcmd\qurantrans@fa@ccxliii{اگر زنان را، مادامى كه با آنان نزديكى نكرده و بر ايشان مَهرى [نيز] معين نكرده‌ايد، طلاق گوييد، بر شما گناهى نيست، و آنان را به طور پسنديده، به نوعى بهره‌مند كنيد -توانگر به اندازه [توان‌] خود، و تنگدست به اندازه [وسع‌] خود. [اين كارى است‌] شايسته نيكوكاران.\qt@no{(236)}}
\qt@newcmd\qurantrans@fa@ccxliv{و اگر پيش از آنكه با آنان نزديكى كنيد، طلاقشان گفتيد، در حالى كه براى آنان مَهرى معين كرده‌ايد، پس نصف آنچه را تعيين نموده‌ايد [به آنان بدهيد]، مگر اينكه آنان خود ببخشند، يا كسى كه پيوند نكاح به دست اوست ببخشد؛ و گذشت كردنِ شما به تقوا نزديكتر است. و در ميان يكديگر بزرگوارى را فراموش مكنيد، زيرا خداوند به آنچه انجام مى‌دهيد بيناست.\qt@no{(237)}}
\qt@newcmd\qurantrans@fa@ccxlv{بر نمازها و نماز ميانه مواظبت كنيد، و خاضعانه براى خدا به پا خيزيد.\qt@no{(238)}}
\qt@newcmd\qurantrans@fa@ccxlvi{پس اگر بيم داشتيد، پياده يا سواره [نماز كنيد]؛ و چون ايمن شديد، خدا را ياد كنيد كه آنچه نمى‌دانستيد به شما آموخت.\qt@no{(239)}}
\qt@newcmd\qurantrans@fa@ccxlvii{و كسانى از شما كه مرگشان فرا مى‌رسد، و همسرانى بر جاى مى‌گذارند، [بايد] براى همسران خويش وصيّت كنند كه آنان را تا يك سال بهره‌مند سازند و [از خانه شوهر] بيرون نكنند. پس اگر بيرون بروند، در آنچه آنان به طور پسنديده در باره خود انجام دهند، گناهى بر شما نيست. و خداوند توانا و حكيم است.\qt@no{(240)}}
\qt@newcmd\qurantrans@fa@ccxlviii{و فرض است بر مردان پرهيزگار كه زنان طلاق داده شده را بشايستگى چيزى دهند.\qt@no{(241)}}
\qt@newcmd\qurantrans@fa@ccxlix{بدين گونه، خداوند آيات خود را براى شما بيان مى‌كند، باشد كه بينديشيد.\qt@no{(242)}}
\qt@newcmd\qurantrans@fa@ccl{آيا از [حال‌] كسانى كه از بيم مرگ از خانه‌هاى خود خارج شدند، و هزاران تن بودند، خبر نيافتى؟ پس خداوند به آنان گفت: «تن به مرگ بسپاريد» آنگاه آنان را زنده ساخت. آرى، خداوند نسبت به مردم، صاحب بخشش است، ولى بيشتر مردم سپاسگزارى نمى‌كنند.\qt@no{(243)}}
\qt@newcmd\qurantrans@fa@ccli{و در راه خدا كارزار كنيد، و بدانيد كه خداوند شنواى داناست.\qt@no{(244)}}
\qt@newcmd\qurantrans@fa@cclii{كيست آن كس كه به [بندگان‌] خدا وام نيكويى دهد تا [خدا] آن را براى او چند برابر بيفزايد؟ و خداست كه [در معيشت بندگان‌] تنگى و گشايش پديد مى‌آورد؛ و به سوى او بازگردانده مى‌شويد.\qt@no{(245)}}
\qt@newcmd\qurantrans@fa@ccliii{آيا از [حال‌] سران بنى اسرائيل پس از موسى خبر نيافتى آنگاه كه به پيامبرى از خود گفتند: «پادشاهى براى ما بگمار تا در راه خدا پيكار كنيم»، [آن پيامبر] گفت: «اگر جنگيدن بر شما مقرر گردد، چه بسا پيكار نكنيد.» گفتند: «چرا در راه خدا نجنگيم با آنكه ما از ديارمان و از [نزد] فرزندانمان بيرون رانده شده‌ايم.» پس هنگامى كه جنگ بر آنان مقرر شد، جز شمارى اندك از آنان، [همگى‌] پشت كردند، و خداوند به [حال‌] ستمكاران داناست.\qt@no{(246)}}
\qt@newcmd\qurantrans@fa@ccliv{و پيامبرشان به آنان گفت: «در حقيقت، خداوند، طالوت را بر شما به پادشاهى گماشته است.» گفتند: «چگونه او را بر ما پادشاهى باشد با آنكه ما به پادشاهى از وى سزاوارتريم و به او از حيث مال، گشايشى داده نشده است؟» پيامبرشان گفت: «در حقيقت، خدا او را بر شما برترى داده، و او را در دانش و [نيروى‌] بدنى بر شما برترى بخشيده است، و خداوند پادشاهى خود را به هر كس كه بخواهد مى‌دهد، و خدا گشايشگر داناست.»\qt@no{(247)}}
\qt@newcmd\qurantrans@fa@cclv{و پيامبرشان بديشان گفت: «در حقيقت، نشانه پادشاهى او اين است كه آن صندوق [عهد] كه در آن آرامش خاطرى از جانب پروردگارتان، و بازمانده‌اى از آنچه خاندان موسى و خاندان هارون [در آن‌] بر جاى نهاده‌اند -در حالى كه فرشتگان آن را حمل مى‌كنند- به سوى شما خواهد آمد. مسلما اگر مؤمن باشيد، براى شما در اين [رويداد] نشانه‌اى است.»\qt@no{(248)}}
\qt@newcmd\qurantrans@fa@cclvi{و چون طالوت با لشكريان [خود] بيرون شد، گفت: «خداوند شما را به وسيله رودخانه‌اى خواهد آزمود. پس هر كس از آن بنوشد از [پيروان‌] من نيست، و هر كس از آن نخورد، قطعاً او از [پيروان‌] من است، مگر كسى كه با دستش كفى برگيرد. پس [همگى‌] جز اندكى از آنها، از آن نوشيدند. و هنگامى كه [طالوت ] با كسانى كه همراه وى ايمان آورده بودند، از آن [نهر] گذشتند، گفتند:» امروز ما را ياراى [مقابله با ]جالوت و سپاهيانش نيست. «كسانى كه به ديدار خداوند يقين داشتند، گفتند:» بسا گروهى اندك كه بر گروهى بسيار، به اذن خدا پيروز شدند، و خداوند با شكيبايان است.\qt@no{(249)}}
\qt@newcmd\qurantrans@fa@cclvii{و هنگامى كه با جالوت و سپاهيانش روبرو شدند، گفتند: «پروردگارا، بر [دلهاى‌] ما شكيبايى فرو ريز، و گامهاى ما را استوار دار، و ما را بر گروه كافران پيروز فرماى.»\qt@no{(250)}}
\qt@newcmd\qurantrans@fa@cclviii{پس آنان را به اذن خدا شكست دادند، و داوود، جالوت را كشت، و خداوند به او پادشاهى و حكمت ارزانى داشت، و از آنچه مى‌خواست به او آموخت. و اگر خداوند برخى از مردم را به وسيله برخى ديگر دفع نمى‌كرد، قطعاً زمين تباه مى‌گرديد. ولى خداوند نسبت به جهانيان تفضّل دارد.\qt@no{(251)}}
\qt@newcmd\qurantrans@fa@cclix{اين‌[ها] آيات خداست كه ما آن را بحق بر تو مى‌خوانيم، و به راستى تو از جمله پيامبرانى.\qt@no{(252)}}
\qt@newcmd\qurantrans@fa@cclx{برخى از آن پيامبران را بر برخى ديگر برترى بخشيديم. از آنان كسى بود كه خدا با او سخن گفت و درجات بعضى از آنان را بالا برد؛ و به عيسى پسر مريم دلايل آشكار داديم، و او را به وسيله روح القدس تأييد كرديم؛ و اگر خدا مى‌خواست، كسانى كه پس از آنان بودند، بعد از آن [همه‌] دلايل روشن كه برايشان آمد، به كشتار يكديگر نمى‌پرداختند، ولى با هم اختلاف كردند؛ پس، بعضى از آنان كسانى بودند كه ايمان آوردند، و بعضى از آنان كسانى بودند كه كفر ورزيدند؛ و اگر خدا مى‌خواست با يكديگر جنگ نمى‌كردند، ولى خداوند آنچه را مى‌خواهد انجام مى‌دهد.\qt@no{(253)}}
\qt@newcmd\qurantrans@fa@cclxi{اى كسانى كه ايمان آورده‌ايد، از آنچه به شما روزى داده‌ايم انفاق كنيد، پيش از آنكه روزى فرا رسد كه در آن نه داد و ستدى است و نه دوستى و نه شفاعتى. و كافران خود ستمكارانند.\qt@no{(254)}}
\qt@newcmd\qurantrans@fa@cclxii{خداست كه معبودى جز او نيست؛ زنده و برپادارنده است؛ نه خوابى سبك او را فرو مى‌گيرد و نه خوابى گران؛ آنچه در آسمانها و آنچه در زمين است، از آنِ اوست. كيست آن كس كه جز به اذن او در پيشگاهش شفاعت كند؟ آنچه در پيش روى آنان و آنچه در پشت سرشان است مى‌داند. و به چيزى از علم او، جز به آنچه بخواهد، احاطه نمى‌يابند. كرسى او آسمانها و زمين را در بر گرفته، و نگهدارى آنها بر او دشوار نيست، و اوست والاى بزرگ.\qt@no{(255)}}
\qt@newcmd\qurantrans@fa@cclxiii{در دين هيچ اجبارى نيست. و راه از بيراهه بخوبى آشكار شده است. پس هر كس به طاغوت كفر ورزد، و به خدا ايمان آورد، به يقين، به دستاويزى استوار، كه آن را گسستن نيست، چنگ زده است. و خداوند شنواى داناست.\qt@no{(256)}}
\qt@newcmd\qurantrans@fa@cclxiv{خداوند سرور كسانى است كه ايمان آورده‌اند. آنان را از تاريكيها به سوى روشنايى به در مى‌برد. و[لى‌] كسانى كه كفر ورزيده‌اند، سرورانشان [همان عصيانگران=] طاغوتند، كه آنان را از روشنايى به سوى تاريكيها به در مى‌برند. آنان اهل آتشند كه خود، در آن جاودانند.\qt@no{(257)}}
\qt@newcmd\qurantrans@fa@cclxv{آيا از [حال‌] آن كس كه چون خدا به او پادشاهى داده بود [و بدان مى‌نازيد، و] در باره پروردگار خود با ابراهيم محاجّه [مى‌]كرد، خبر نيافتى؟ آنكاه كه ابراهيم گفت: «پروردگار من همان كسى است كه زنده مى‌كند و مى‌ميراند.» گفت: «من [هم‌] زنده مى‌كنم و [هم‌] مى‌ميرانم.» ابراهيم گفت: «خدا[ى من‌] خورشيد را از خاور برمى‌آورد، تو آن را از باختر برآور.» پس آن كس كه كفر ورزيده بود مبهوت ماند. و خداوند قوم ستمكار را هدايت نمى‌كند.\qt@no{(258)}}
\qt@newcmd\qurantrans@fa@cclxvi{يا چون آن كس كه به شهرى كه بامهايش يكسر فرو ريخته بود، عبور كرد؛ [و با خود مى‌]گفت: «چگونه خداوند، [اهل‌] اين [ويرانكده‌] را پس از مرگشان زنده مى‌كند؟». پس خداوند، او را [به مدت‌] صد سال ميراند. آنگاه او را برانگيخت، [و به او] گفت: «چقدر درنگ كردى؟» گفت: «يك روز يا پاره‌اى از روز را درنگ كردم.» گفت: «[نه‌] بلكه صد سال درنگ كردى، به خوراك و نوشيدنى خود بنگر [كه طعم و رنگ آن‌] تغيير نكرده است، و به درازگوش خود نگاه كن [كه چگونه متلاشى شده است. اين ماجرا براى آن است كه هم به تو پاسخ گوييم‌] و هم تو را [در مورد معاد] نشانه‌اى براى مردم قرار دهيم. و به [اين ]استخوانها بنگر، چگونه آنها را برداشته به هم پيوند مى‌دهيم؛ سپس گوشت بر آن مى‌پوشانيم.» پس هنگامى كه [چگونگى زنده ساختن مرده‌] براى او آشكار شد، گفت: «[اكنون‌] مى‌دانم كه خداوند بر هر چيزى تواناست.»\qt@no{(259)}}
\qt@newcmd\qurantrans@fa@cclxvii{و [ياد كن‌] آنگاه كه ابراهيم گفت: «پروردگارا، به من نشان ده؛ چگونه مردگان را زنده مى‌كنى؟» فرمود: «مگر ايمان نياورده‌اى؟» گفت: «چرا، ولى تا دلم آرامش يابد.» فرمود: «پس، چهار پرنده برگير، و آنها را پيش خود، ريز ريز گردان؛ سپس بر هر كوهى پاره‌اى از آنها را قرار ده؛ آنگاه آنها را فرا خوان، شتابان به سوى تو مى‌آيند، و بدان كه خداوند توانا و حكيم است.»\qt@no{(260)}}
\qt@newcmd\qurantrans@fa@cclxviii{مَثَل [صدقات‌] كسانى كه اموال خود را در راه خدا انفاق مى‌كنند همانند دانه‌اى است كه هفت خوشه بروياند كه در هر خوشه‌اى صد دانه باشد؛ و خداوند براى هر كس كه بخواهد [آن را] چند برابر مى‌كند، و خداوند گشايشگر داناست.\qt@no{(261)}}
\qt@newcmd\qurantrans@fa@cclxix{كسانى كه اموال خود را در راه خدا انفاق مى‌كنند، سپس در پى آنچه انفاق كرده‌اند، منّت و آزارى روا نمى‌دارند، پاداش آنان برايشان نزد پروردگارشان [محفوظ] است، و بيمى بر آنان نيست و اندوهگين نمى‌شوند.\qt@no{(262)}}
\qt@newcmd\qurantrans@fa@cclxx{گفتارى پسنديده [در برابر نيازمندان‌] و گذشت [از اصرار و تندىِ آنان‌] بهتر از صدقه‌اى است كه آزارى به دنبال آن باشد، و خداوند بى‌نياز بردبار است.\qt@no{(263)}}
\qt@newcmd\qurantrans@fa@cclxxi{اى كسانى كه ايمان آورده‌ايد، صدقه‌هاى خود را با منّت و آزار، باطل مكنيد، مانند كسى كه مالش را براى خودنمايى به مردم، انفاق مى‌كند و به خدا و روز بازپسين ايمان ندارد. پس مَثَل او همچون مَثَل سنگ خارايى است كه بر روى آن، خاكى [نشسته‌] است، و رگبارى به آن رسيده و آن [سنگ‌] را سخت و صاف بر جاى نهاده است. آنان [=رياكاران‌] نيز از آنچه به دست آورده‌اند، بهره‌اى نمى‌برند؛ و خداوند، گروه كافران را هدايت نمى‌كند.\qt@no{(264)}}
\qt@newcmd\qurantrans@fa@cclxxii{و مَثَل [صدقات‌] كسانى كه اموال خويش را براى طلب خشنودى خدا و استوارى روحشان انفاق مى‌كنند، همچون مَثَل باغى است كه بر فراز پشته‌اى قرار دارد [كه اگر] رگبارى بر آن برسد، دو چندان محصول برآورد، و اگر رگبارى هم بر آن نرسد، بارانِ ريزى [براى آن بس است‌]، و خداوند به آنچه انجام مى‌دهيد بيناست.\qt@no{(265)}}
\qt@newcmd\qurantrans@fa@cclxxiii{آيا كسى از شما دوست دارد كه باغى از درختان خرما و انگور داشته باشد كه از زير آنها نهرها روان است، و براى او در آن [باغ‌] از هر گونه ميوه‌اى [فراهم‌] باشد، و در حالى كه او را پيرى رسيده و فرزندانى خردسال دارد، [ناگهان‌] گردبادى آتشين بر آن [باغ‌] زند و [باغ يكسر] بسوزد؟ اين گونه، خداوند آيات [خود] را براى شما روشن مى‌گرداند، باشد كه شما بينديشيد.\qt@no{(266)}}
\qt@newcmd\qurantrans@fa@cclxxiv{اى كسانى كه ايمان آورده‌ايد، از چيزهاى پاكيزه‌اى كه به دست آورده‌ايد، و از آنچه براى شما از زمين برآورده‌ايم، انفاق كنيد، و در پى ناپاك آن نرويد كه [از آن‌] انفاق نماييد، در حالى كه آن را [اگر به خودتان مى‌دادند] جز با چشم‌پوشى [و بى‌ميلى‌] نسبت به آن، نمى‌گرفتيد، و بدانيد كه خداوند، بى‌نيازِ ستوده [صفات‌] است.\qt@no{(267)}}
\qt@newcmd\qurantrans@fa@cclxxv{شيطان شما را از تهيدستى بيم مى‌دهد و شما را به زشتى وامى‌دارد؛ و[لى‌] خداوند از جانب خود به شما وعده آمرزش و بخشش مى‌دهد، و خداوند گشايشگر داناست.\qt@no{(268)}}
\qt@newcmd\qurantrans@fa@cclxxvi{[خدا] به هر كس كه بخواهد حكمت مى‌بخشد، و به هر كس حكمت داده شود، به يقين، خيرى فراوان داده شده است؛ و جز خردمندان، كسى پند نمى‌گيرد.\qt@no{(269)}}
\qt@newcmd\qurantrans@fa@cclxxvii{و هر نفقه‌اى را كه انفاق، يا هر نذرى را كه عهد كرده‌ايد، قطعاً خداوند آن را مى‌داند، و براى ستمكاران هيچ ياورى نيست.\qt@no{(270)}}
\qt@newcmd\qurantrans@fa@cclxxviii{اگر صدقه‌ها را آشكار كنيد، اين، كار خوبى است، و اگر آن را پنهان داريد و به مستمندان بدهيد، اين براى شما بهتر است؛ و بخشى از گناهانتان را مى‌زدايد، و خداوند به آنچه انجام مى‌دهيد آگاه است.\qt@no{(271)}}
\qt@newcmd\qurantrans@fa@cclxxix{هدايت آنان بر عهده تو نيست، بلكه خدا هر كه را بخواهد هدايت مى‌كند، و هر مالى كه انفاق كنيد، به سود خود شماست، و[لى‌] جز براى طلب خشنودى خدا انفاق مكنيد، و هر مالى را كه انفاق كنيد [پاداش آن‌] به طور كامل به شما داده خواهد شد و ستمى بر شما نخواهد رفت.\qt@no{(272)}}
\qt@newcmd\qurantrans@fa@cclxxx{[اين صدقات‌] براى آن [دسته از] نيازمندانى است كه در راه خدا فرومانده‌اند، و نمى‌توانند [براى تأمين هزينه زندگى‌] در زمين سفر كنند. از شدّت خويشتن‌دارى، فرد بى‌اطلاع، آنان را توانگر مى‌پندارد. آنها را از سيمايشان مى‌شناسى. با اصرار، [چيزى‌] از مردم نمى‌خواهند. و هر مالى [به آنان‌] انفاق كنيد، قطعاً خدا از آن آگاه است.\qt@no{(273)}}
\qt@newcmd\qurantrans@fa@cclxxxi{كسانى كه اموال خود را شب و روز، و نهان و آشكارا، انفاق مى‌كنند، پاداش آنان نزد پروردگارشان براى آنان خواهد بود؛ و نه بيمى بر آنان است و نه اندوهگين مى‌شوند.\qt@no{(274)}}
\qt@newcmd\qurantrans@fa@cclxxxii{كسانى كه ربا مى‌خورند، [از گور] برنمى‌خيزند مگر مانند برخاستن كسى كه شيطان بر اثر تماس، آشفته‌سرش كرده است. اين بدان سبب است كه آنان گفتند: «داد و ستد صرفاً مانند رباست.» و حال آنكه خدا داد و ستد را حلال، و ربا را حرام گردانيده است. پس، هر كس، اندرزى از جانب پروردگارش بدو رسيد، و [از رباخوارى‌] باز ايستاد، آنچه گذشته، از آنِ اوست، و كارش به خدا واگذار مى‌شود، و كسانى كه [به رباخوارى‌] باز گردند، آنان اهل آتشند و در آن ماندگار خواهند بود.\qt@no{(275)}}
\qt@newcmd\qurantrans@fa@cclxxxiii{خدا از [بركت‌] ربا مى‌كاهد، و بر صدقات مى‌افزايد، و خداوند هيچ ناسپاس گناهكارى را دوست نمى‌دارد.\qt@no{(276)}}
\qt@newcmd\qurantrans@fa@cclxxxiv{كسانى كه ايمان آورده و كارهاى شايسته كرده و نماز بر پا داشته و زكات داده‌اند، پاداش آنان نزد پروردگارشان براى آنان خواهد بود؛ و نه بيمى بر آنان است و نه اندوهگين مى‌شوند.\qt@no{(277)}}
\qt@newcmd\qurantrans@fa@cclxxxv{اى كسانى كه ايمان آورده‌ايد، از خدا پروا كنيد؛ و اگر مؤمنيد، آنچه از ربا باقى مانده است واگذاريد.\qt@no{(278)}}
\qt@newcmd\qurantrans@fa@cclxxxvi{و اگر [چنين‌] نكرديد، بدانيد به جنگ با خدا و فرستاده وى، برخاسته‌ايد؛ و اگر توبه كنيد، سرمايه‌هاى شما از خودتان است. نه ستم مى‌كنيد و نه ستم مى‌بينيد.\qt@no{(279)}}
\qt@newcmd\qurantrans@fa@cclxxxvii{و اگر [بدهكارتان‌] تنگدست باشد، پس تا [هنگام‌] گشايش، مهلتى [به او دهيد]؛ و [اگر به راستى قدرت پرداخت ندارد،] بخشيدن آن براى شما بهتر است-اگر بدانيد.\qt@no{(280)}}
\qt@newcmd\qurantrans@fa@cclxxxviii{و بترسيد از روزى كه در آن، به سوى خدا بازگردانده مى‌شويد، سپس به هر كسى [پاداش‌] آنچه به دست آورده، تمام داده شود؛ و آنان مورد ستم قرار نمى‌گيرند.\qt@no{(281)}}
\qt@newcmd\qurantrans@fa@cclxxxix{اى كسانى كه ايمان آورده‌ايد، هر گاه به وامى تا سررسيدى معين، با يكديگر معامله كرديد، آن را بنويسيد. و بايد نويسنده‌اى [صورت معامله را] بر اساس عدالت، ميان شما بنويسد. و هيچ نويسنده‌اى نبايد از نوشتن خوددارى كند؛ همان گونه [و به شكرانه آن‌] كه خدا او را آموزش داده است. و كسى كه بدهكار است بايد املا كند، و او [=نويسنده‌] بنويسد. و از خدا كه پروردگار اوست پروا نمايد، و از آن، چيزى نكاهد. پس اگر كسى كه حق بر ذمه اوست، سفيه يا ناتوان است، يا خود نمى‌تواند املا كند، پس ولىّ او بايد با [رعايت‌] عدالت، املا نمايد. و دو شاهد از مردانتان را به شهادت طلبيد، پس اگر دو مرد نبودند، مردى را با دو زن، از ميان گواهانى كه [به عدالت آنان‌] رضايت داريد [گواه بگيريد]، تا [اگر] يكى از آن دو [زن‌] فراموش كرد، [زنِ‌] ديگر، وى را يادآورى كند. و چون گواهان احضار شوند، نبايد خوددارى ورزند. و از نوشتن [بدهى‌] چه خرد باشد يا بزرگ، ملول نشويد، تا سررسيدش [فرا رسد]. اين [نوشتنِ‌] شما، نزد خدا عادلانه‌تر، و براى شهادت استوارتر، و براى اينكه دچار شك نشويد [به احتياط ]نزديكتر است، مگر آنكه داد و ستدى نقدى باشد كه آن را ميان خود [دست به دست‌] برگزار مى‌كنيد؛ در اين صورت، بر شما گناهى نيست كه آن را ننويسيد. و [در هر حال‌] هر گاه داد و ستد كرديد گواه بگيريد. و هيچ نويسنده و گواهى نبايد زيان ببيند، و اگر چنين كنيد، از نافرمانى شما خواهد بود. و از خدا پروا كنيد، و خدا [بدين گونه‌] به شما آموزش مى‌دهد، و خدا به هر چيزى داناست.\qt@no{(282)}}
\qt@newcmd\qurantrans@fa@ccxc{و اگر در سفر بوديد و نويسنده‌اى نيافتيد وثيقه‌اى بگيريد؛ و اگر برخى از شما برخى ديگر را امين دانست، پس آن كس كه امين شمرده شده، بايد سپرده وى را بازپس دهد؛ و بايد از خداوند كه پروردگار اوست، پروا كند. و شهادت را كتمان مكنيد، و هر كه آن را كتمان كند قلبش گناهكار است، و خداوند به آنچه انجام مى‌دهيد داناست.\qt@no{(283)}}
\qt@newcmd\qurantrans@fa@ccxci{آنچه در آسمانها و آنچه در زمين است از آنِ خداست. و اگر آنچه در دلهاى خود داريد، آشكار يا پنهان كنيد، خداوند شما را به آن محاسبه مى‌كند؛ آنگاه هر كه را بخواهد مى‌بخشد، و هر كه را بخواهد عذاب مى‌كند، و خداوند بر هر چيزى تواناست.\qt@no{(284)}}
\qt@newcmd\qurantrans@fa@ccxcii{پيامبر [خدا] بدانچه از جانب پروردگارش بر او نازل شده است ايمان آورده است، و مؤمنان همگى به خدا و فرشتگان و كتابها و فرستادگانش ايمان آورده‌اند [و گفتند:] «ميان هيچ يك از فرستادگانش فرق نمى‌گذاريم» و گفتند: «شنيديم و گردن نهاديم، پروردگارا، آمرزش تو را [خواستاريم‌] و فرجام به سوى تو است.»\qt@no{(285)}}
\qt@newcmd\qurantrans@fa@ccxciii{خداوند هيچ كس را جز به قدر توانايى‌اش تكليف نمى‌كند. آنچه [از خوبى‌] به دست آورده به سود او، و آنچه [از بدى‌] به دست آورده به زيان اوست. پروردگارا، اگر فراموش كرديم يا به خطا رفتيم بر ما مگير، پروردگارا، هيچ بار گرانى بر [دوش‌] ما مگذار؛ همچنانكه بر [دوش‌] كسانى كه پيش از ما بودند نهادى. پروردگارا، و آنچه تاب آن نداريم بر ما تحميل مكن؛ و از ما درگذر؛ و ما را ببخشاى و بر ما رحمت آور؛ سرور ما تويى؛ پس ما را بر گروه كافران پيروز كن.\qt@no{(286)}}
\qt@newcmd\qurantrans@fa@ccxciv{\basmalahfa الف، لام، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@ccxcv{خداست كه هيچ معبودِ [بحقى‌] جز او نيست و زنده [پاينده‌] است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@ccxcvi{اين كتاب را در حالى كه مؤيّد آنچه [از كتابهاى آسمانى‌] پيش از خود مى‌باشد، به حق [و به تدريج‌] بر تو نازل كرد، و تورات و انجيل را...\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@ccxcvii{پيش از آن براى رهنمود مردم فرو فرستاد، و فرقان [=جداكننده حق از باطل‌] را نازل كرد. كسانى كه به آيات خدا كفر ورزيدند، بى‌ترديد عذابى سخت خواهند داشت، و خداوند، شكست‌ناپذير و صاحب‌انتقام است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@ccxcviii{در حقيقت، هيچ چيز [نه‌] در زمين و نه در آسمان بر خدا پوشيده نمى‌ماند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@ccxcix{اوست كسى كه شما را آن گونه كه مى‌خواهد در رحمها صورتگرى مى‌كند. هيچ معبودى جز آن تواناى حكيم نيست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@ccc{اوست كسى كه اين كتاب [=قرآن‌] را بر تو فرو فرستاد. پاره‌اى از آن، آيات محكم [=صريح و روشن‌] است. آنها اساس كتابند؛ و [پاره‌اى‌] ديگر متشابهاتند [كه تأويل‌پذيرند]. اما كسانى كه در دلهايشان انحراف است براى فتنه‌جويى و طلب تأويل آن [به دلخواه خود،] از متشابه آن پيروى مى‌كنند، با آنكه تأويلش را جز خدا و ريشه‌داران در دانش كسى نمى‌داند. [آنان كه‌] مى‌گويند: «ما بدان ايمان آورديم، همه [چه محكم و چه متشابه‌] از جانب پروردگار ماست»، و جز خردمندان كسى متذكر نمى‌شود.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@ccci{[مى‌گويند:] پروردگارا، پس از آنكه ما را هدايت كردى، دلهايمان را دستخوش انحراف مگردان، و از جانب خود، رحمتى بر ما ارزانى دار كه تو خود بخشايشگرى.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@cccii{پروردگارا، به يقين، تو در روزى كه هيچ ترديدى در آن نيست، گردآورنده [جمله‌] مردمانى. قطعاً خداوند در وعده [خود] خلاف نمى‌كند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@ccciii{در حقيقت، كسانى كه كفر ورزيدند، اموال و اولادشان چيزى [از عذاب خدا] را از آنان دور نخواهد كرد؛ و آنان خود، هيزم دوزخند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@ccciv{[آنان‌] به شيوه فرعونيان و كسانى كه پيش از آنان بودند آيات ما را دروغ شمردند؛ پس خداوند به [سزاى‌] گناهانشان [گريبان‌] آنان را گرفت، و خدا سخت‌كيفر است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@cccv{به كسانى كه كفر ورزيدند بگو: «به زودى مغلوب خواهيد شد و [سپس در روز رستاخيز] در دوزخ محشور مى‌شويد، و چه بد بسترى است.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@cccvi{قطعاً در برخورد ميان دو گروه، براى شما نشانه‌اى [و درس عبرتى‌] بود. گروهى در راه خدا مى‌جنگيدند، و ديگر [گروه‌] كافر بودند كه آنان [=مؤمنان‌] را به چشم، دو برابر خود مى‌ديدند؛ و خدا هر كه را بخواهد به يارى خود تأييد مى‌كند، يقيناً در اين [ماجرا] براى صاحبان بينش عبرتى است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@cccvii{دوستىِ خواستنيها[ى گوناگون‌] از: زنان و پسران و اموال فراوان از زر و سيم و اسب‌هاى نشاندار و دامها و كشتزار[ها] براى مردم آراسته شده، [ليكن‌] اين جمله، مايه تمتّع زندگى دنياست، و [حال آنكه] فرجام نيكو نزد خداست.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@cccviii{بگو: «آيا شما را به بهتر از اينها خبر دهم؟ براى كسانى كه تقوا پيشه كرده‌اند، نزد پروردگارشان باغهايى است كه از زير [درختان‌] آنها نهرها روان است؛ در آن جاودانه بمانند، و همسرانى پاكيزه و [نيز ]خشنودى خدا [را دارند]، و خداوند به [امور] بندگان [خود] بيناست.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@cccix{همان كسانى كه مى‌گويند: پروردگارا، ما ايمان آورديم؛ پس گناهان ما را بر ما ببخش، و ما را از عذاب آتش نگاه دار.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@cccx{[اينانند] شكيبايان و راستگويان و فرمانبرداران و انفاق‌كنندگان و آمرزش‌خواهان در سحرگاهان.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@cccxi{خدا كه همواره به عدل، قيام دارد، گواهى مى‌دهد كه جز او هيچ معبودى نيست؛ و فرشتگانِ [او] و دانشوران [نيز گواهى مى‌دهند كه:] جز او، كه توانا و حكيم است، هيچ معبودى نيست.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@cccxii{در حقيقت، دين نزد خدا همان اسلام است. و كسانى كه كتاب [آسمانى‌] به آنان داده شده، با يكديگر به اختلاف نپرداختند مگر پس از آنكه علم براى آنان [حاصل‌] آمد، آن هم به سابقه حسدى كه ميان آنان وجود داشت. و هر كس به آيات خدا كفر ورزد، پس [بداند] كه خدا زودشمار است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@cccxiii{پس اگر با تو به محاجّه برخاستند، بگو: «من خود را تسليم خدا نموده‌ام، و هر كه مرا پيروى كرده [نيز خود را تسليم خدا نموده است‌].» و به كسانى كه اهل كتابند و به مشركان بگو: «آيا اسلام آورده‌ايد؟» پس اگر اسلام آوردند، قطعاً هدايت يافته‌اند، و اگر روى برتافتند، فقط رساندن پيام بر عهده توست، و خداوند به [امور] بندگان بيناست.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@cccxiv{كسانى كه به آيات خدا كفر مى‌ورزند، و پيامبران را بناحق مى‌كشند، و دادگستران را به قتل مى‌رسانند، آنان را از عذابى دردناك خبر ده.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@cccxv{آنان كسانى‌اند كه در [اين‌] دنيا و [در سراى‌] آخرت، اعمالشان به هدر رفته و براى آنان هيچ ياورى نيست.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@cccxvi{آيا داستان كسانى را كه بهره‌اى از كتاب [تورات‌] يافته‌اند ندانسته‌اى كه چون به سوى كتاب خدا فرا خوانده مى‌شوند تا ميانشان حكم كند، آنگه گروهى از آنان به حال اعراض، روى برمى‌تابند؟\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@cccxvii{اين بدان سبب بود كه آنان [به پندار خود] گفتند: «هرگز آتش جز چند روزى به ما نخواهد رسيد»، و برساخته‌هايشان آنان را در دينشان فريفته كرده است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@cccxviii{پس چگونه خواهد بود [حالشان‌] آنگاه كه آنان را در روزى كه هيچ شكى در آن نيست گرد آوريم؛ و به هر كس [پاداش‌] دستاوردش به تمام [و كمال‌] داده شود و به آنان ستم نرسد؟\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@cccxix{بگو: «بار خدايا، تويى كه فرمانفرمايى؛ هر آن كس را كه خواهى، فرمانروايى بخشى؛ و از هر كه خواهى، فرمانروايى را باز ستانى؛ و هر كه را خواهى، عزت بخشى؛ و هر كه را خواهى، خوار گردانى؛ همه خوبيها به دست توست، و تو بر هر چيز توانايى.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@cccxx{شب را به روز در مى‌آورى، و روز را به شب در مى‌آورى؛ و زنده را از مرده بيرون مى آورى، و مرده را از زنده خارج مى‌سازى؛ و هر كه را خواهى، بى‌حساب روزى مى‌دهى.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@cccxxi{مؤمنان نبايد كافران را -به جاى مؤمنان- به دوستى بگيرند؛ و هر كه چنين كند، در هيچ چيز [او را] از [دوستى‌] خدا [بهره‌اى‌] نيست، مگر اينكه از آنان به نوعى تقيّه كند و خداوند، شما را از [عقوبت‌] خود مى‌ترساند، و بازگشت [همه‌] به سوى خداست.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@cccxxii{بگو: «اگر آنچه در سينه‌هاى شماست نهان داريد يا آشكارش كنيد، خدا آن را مى داند، و [نيز] آنچه را در آسمانها و آنچه را در زمين است مى‌داند، و خداوند بر هر چيزى تواناست.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@cccxxiii{روزى كه هر كسى آنچه كار نيك به جاى آورده و آنچه بدى مرتكب شده، حاضر شده مى يابد؛ و آرزو مى‌كند: كاش ميان او و آن [كارهاى بد] فاصله‌اى دور بود. و خداوند، شما را از [كيفر] خود مى‌ترساند، و [در عين حال‌] خدا به بندگان [خود ]مهربان است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@cccxxiv{بگو: «اگر خدا را دوست داريد، از من پيروى كنيد تا خدا دوستتان بدارد و گناهان شما را بر شما ببخشايد، و خداوند آمرزنده مهربان است.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@cccxxv{بگو: «خدا و پيامبر [او] را اطاعت كنيد.» پس اگر رويگردان شدند، قطعاً خداوند كافران را دوست ندارد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@cccxxvi{به يقين، خداوند، آدم و نوح و خاندان ابراهيم و خاندان عمران را بر مردم جهان برترى داده است.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@cccxxvii{فرزندانى كه بعضى از آنان از [نسل‌] بعضى ديگرند، و خداوند شنواى داناست.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@cccxxviii{چون زن عمران گفت: «پروردگارا، آنچه در شكم خود دارم نذر تو كردم تا آزاد شده [از مشاغل دنيا و پرستشگر تو] باشد؛ پس، از من بپذير كه تو خود شنواى دانايى.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@cccxxix{پس چون فرزندش را بزاد، گفت: «پروردگارا، من دختر زاده‌ام -و خدا به آنچه او زاييد داناتر بود- و پسر چون دختر نيست، و من نامش را مريم نهادم، و او و فرزندانش را از شيطان رانده‌شده، به تو پناه مى‌دهم.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@cccxxx{پس پروردگارش وى [=مريم‌] را با حُسنِ قبول پذيرا شد و او را نيكو بار آورد، و زكريا را سرپرست وى قرار داد. زكريا هر بار كه در محراب بر او وارد مى‌شد، نزد او [نوعى‌] خوراكى مى‌يافت. [مى‌]گفت: «اى مريم، اين از كجا براى تو [آمده است؟ او در پاسخ مى‌]گفت: «اين از جانب خداست، كه خدا به هر كس بخواهد، بى شمار روزى مى‌دهد.»\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@cccxxxi{آنجا [بود كه‌] زكريا پروردگارش را خواند [و] گفت: «پروردگارا، از جانب خود، فرزندى پاك و پسنديده به من عطا كن، كه تو شنونده دعايى.»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@cccxxxii{پس در حالى كه وى ايستاده [و] در محراب [خود] دعا مى‌كرد، فرشتگان، او را ندا دردادند كه: خداوند تو را به [ولادت‌] يحيى -كه تصديق كننده [حقانيت‌] كلمة الله [=عيسى‌] است، و بزرگوار و خويشتندار [=پرهيزنده از آنان‌] و پيامبرى از شايستگان است- مژده مى‌دهد.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@cccxxxiii{گفت: «پروردگارا، چگونه مرا فرزندى خواهد بود؟ در حالى كه پيرىِ من بالا گرفته است و زنم «نازا» است [فرشته‌] گفت: « [كار پروردگار] چنين است. خدا هر چه بخواهد مى‌كند.»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@cccxxxiv{گفت: «پروردگارا، براى من نشانه‌اى قرار ده.» فرمود: «نشانه‌ات اين است كه سه روز با مردم، جز به اشاره سخن نگويى؛ و پروردگارت را بسيار ياد كن، و شبانگاه و بامدادان [او را] تسبيح گوى.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@cccxxxv{و [ياد كن‌] هنگامى را كه فرشتگان گفتند: «اى مريم، خداوند تو را برگزيده و پاك ساخته و تو را بر زنان جهان برترى داده است.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@cccxxxvi{«اى مريم، فرمانبر پروردگار خود باش و سجده كن و با ركوع‌كنندگان ركوع نما.»\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@cccxxxvii{اين [جمله‌] از اخبار غيب است كه به تو وحى مى‌كنيم، و [گرنه‌] وقتى كه آنان قلمهاى خود را [براى قرعه‌كشى به آب‌] مى‌افكندند تا كدام يك سرپرستى مريم را به عهده گيرد، نزد آنان نبودى؛ و [نيز] وقتى با يكديگر كشمكش مى‌كردند نزدشان نبودى.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@cccxxxviii{[ياد كن‌] هنگامى [را] كه فرشتگان گفتند: «اى مريم، خداوند تو را به كلمه‌اى از جانب خود، كه نامش مسيح، عيسى‌بن‌مريم است مژده مى‌دهد، در حالى كه [او] در دنيا و آخرت آبرومند و از مقربان [درگاه خدا] است.»\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@cccxxxix{«و در گهواره [به اعجاز] و در ميانسالى [به وحى‌] با مردم سخن مى‌گويد و از شايستگان است.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@cccxl{[مريم‌] گفت: «پروردگارا، چگونه مرا فرزندى خواهد بود با آنكه بشرى به من دست نزده است؟» گفت: «چنين است [كار] پروردگار.» خدا هر چه بخواهد مى‌آفريند؛ چون به كارى فرمان دهد، فقط به آن مى‌گويد: «باش»؛ پس مى‌باشد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@cccxli{و به او كتاب و حكمت و تورات و انجيل مى‌آموزد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@cccxlii{و [او را به عنوان‌] پيامبرى به سوى بنى اسرائيل [مى‌فرستد، كه او به آنان مى‌گويد:] «در حقيقت، من از جانب پروردگارتان برايتان معجزه‌اى آورده‌ام: من از گل براى شما [چيزى‌] به شكل پرنده مى‌سازم، آنگاه در آن مى‌دمم، پس به اذن خدا پرنده‌اى مى شود؛ و به اذن خدا نابيناى مادرزاد و پيس را بهبود مى‌بخشم؛ و مردگان را زنده مى‌گردانم؛ و شما را از آنچه مى‌خوريد و در خانه هايتان ذخيره مى‌كنيد، خبر مى‌دهم؛ مسلماً در اين [معجزات‌]، براى شما -اگر مؤمن باشيد- عبرت است.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@cccxliii{و [مى‌گويد: «آمده‌ام تا] تورات را كه پيش از من [نازل شده‌] است تصديق كننده باشم، و تا پاره‌اى از آنچه را كه بر شما حرام گرديده، براى شما حلال كنم، و از جانب پروردگارتان براى شما نشانه‌اى آورده‌ام. پس، از خدا پروا داريد و مرا اطاعت كنيد.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@cccxliv{«در حقيقت، خداوند پروردگار من و پروردگار شماست؛ پس او را بپرستيد [كه ] راه راست اين است.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@cccxlv{چون عيسى از آنان احساس كفر كرد، گفت: «ياران من در راه خدا چه كسانند؟» حواريون گفتند: «ما ياران [دين‌] خداييم، به خدا ايمان آورده‌ايم؛ و گواه باش كه ما تسليم [او] هستيم.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@cccxlvi{پروردگارا، به آنچه نازل كردى گرويديم و فرستاده‌[ات‌] را پيروى كرديم؛ پس ما را در زمره گواهان بنويس.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@cccxlvii{و [دشمنان‌] مكر ورزيدند، و خدا [در پاسخشان‌] مكر در ميان آورد، و خداوند بهترين مكرانگيزان است.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@cccxlviii{[ياد كن‌] هنگامى را كه خدا گفت: «اى عيسى، من تو را برگرفته و به سوى خويش بالا مى‌برم، و تو را از [آلايش‌] كسانى كه كفر ورزيده‌اند پاك مى‌گردانم، و تا روز رستاخيز، كسانى را كه از تو پيروى كرده‌اند، فوق كسانى كه كافر شده‌اند قرار خواهم داد؛ آنگاه فرجام شما به سوى من است، پس در آنچه بر سر آن اختلاف مى‌كرديد ميان شما داورى خواهم كرد.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@cccxlix{اما كسانى كه كفر ورزيدند، در دنيا و آخرت به سختى عذابشان كنم و ياورانى نخواهند داشت.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@cccl{و اما كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، [خداوند] مزدشان را به تمامى به آنان مى‌دهد. و خداوند، بيدادگران را دوست نمى‌دارد.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@cccli{اينهاست كه ما آن را از آيات و قرآن حكمت‌آميز بر تو مى‌خوانيم.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@ccclii{در واقع، مَثل عيسى نزد خدا همچون مَثل [خلقت‌] آدم است [كه‌] او را از خاك آفريد؛ سپس بدو گفت: «باش»؛ پس وجود يافت.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@cccliii{[آنچه درباره عيسى گفته شد] حق [و] از جانب پروردگار تو است. پس، از ترديدكنندگان مباش.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@cccliv{پس هر كه در اين [باره‌] پس از دانشى كه تو را [حاصل‌] آمده، با تو محاجه كند، بگو: «بياييد پسرانمان و پسرانتان، و زنانمان و زنانتان، و ما خويشان نزديك و شما خويشان نزديك خود را فرا خوانيم؛ سپس مباهله كنيم، و لعنت خدا را بر دروغگويان قرار دهيم.»\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@ccclv{آرى، داستان درست [مسيح‌] همين است؛ و معبودى جز خدا نيست، و خداست كه در واقع، همان شكست‌ناپذير حكيم است.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@ccclvi{پس اگر رويگردان شدند، همانا خداوند به [حال‌] مفسدان داناست.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@ccclvii{بگو: «اى اهل كتاب، بياييد بر سر سخنى كه ميان ما و شما يكسان است بايستيم كه: جز خدا را نپرستيم و چيزى را شريك او نگردانيم، و بعضى از ما بعضى ديگر را به جاى خدا به خدايى نگيرد.» پس اگر [از اين پيشنهاد] اعراض كردند، بگوييد: «شاهد باشيد كه ما مسلمانيم [نه شما].»\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@ccclviii{اى اهل كتاب، چرا در باره ابراهيم محاجه مى‌كنيد با آنكه تورات و انجيل بعد از او نازل شده است؟ آيا تعقل نمى‌كنيد؟\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@ccclix{هان، شما [اهل كتاب‌] همانان هستيد كه در باره آنچه نسبت به آن دانشى داشتيد محاجه كرديد؛ پس چرا در مورد چيزى كه بدان دانشى نداريد محاجه مى‌كنيد؟ با آنكه خدا مى‌داند و شما نمى‌دانيد.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@ccclx{ابراهيم نه يهودى بود و نه نصرانى، بلكه حق گرايى فرمانبردار بود، و از مشركان نبود.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@ccclxi{در حقيقت، نزديكترين مردم به ابراهيم، همان كسانى هستند كه او را پيروى كرده‌اند، و [نيز] اين پيامبر و كسانى كه [به آيين او] ايمان آورده‌اند؛ و خدا سرور مؤمنان است.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@ccclxii{گروهى از اهل كتاب آرزو مى‌كنند كاش شما را گمراه مى‌كردند، در صورتى كه جز خودشان [كسى‌] را گمراه نمى‌كنند و نمى‌فهمند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@ccclxiii{اى اهل كتاب، چرا به آيات خدا كفر مى‌ورزيد با آنكه خود [به درستى آن‌] گواهى مى‌دهيد؟\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@ccclxiv{اى اهل كتاب، چرا حق را به باطل درمى‌آميزيد و حقيقت را كتمان مى‌كنيد، با اينكه خود مى‌دانيد؟\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@ccclxv{و جماعتى از اهل كتاب گفتند: «در آغاز روز به آنچه بر مؤمنان نازل شد، ايمان بياوريد، و در پايان [روز] انكار كنيد؛ شايد آنان [از اسلام‌] برگردند.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@ccclxvi{و [گفتند:] «جز به كسى كه دين شما را پيروى كند، ايمان نياوريد -بگو: « هدايت، هدايت خداست »- مبادا به كسى نظير آنچه به شما داده شده، داده شود، يا در پيشگاه پروردگارتان با شما محاجه كنند.» بگو: « [اين‌] تفضل به دست خداست؛ آن را به هر كس كه بخواهد مى‌دهد، و خداوند، گشايشگر داناست.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@ccclxvii{رحمت خود را به هر كس كه بخواهد مخصوص مى‌گرداند، و خداوند داراى بخشش بزرگ است.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@ccclxviii{و از اهل كتاب، كسى است كه اگر او را بر مال فراوانى امين شمرى، آن را به تو برگرداند؛ و از آنان كسى است كه اگر او را بر دينارى امين شمرى، آن را به تو نمى‌پردازد، مگر آنكه دايماً بر [سر] وى به پا ايستى. اين بدان سبب است كه آنان [به پندار خود] گفتند: «در مورد كسانى كه كتاب آسمانى ندارند، بر زيان ما راهى نيست.» و بر خدا دروغ مى‌بندند با اينكه خودشان [هم‌] مى‌دانند.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@ccclxix{آرى، هر كه به پيمان خود وفا كند، و پرهيزگارى نمايد، بى‌ترديد خداوند، پرهيزگاران را دوست دارد.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@ccclxx{كسانى كه پيمان خدا و سوگندهاى خود را به بهاى ناچيزى مى‌فروشند، آنان را در آخرت بهره‌اى نيست؛ و خدا روز قيامت با آنان سخن نمى‌گويد، و به ايشان نمى‌نگرد، و پاكشان نمى‌گرداند، و عذابى دردناك خواهند داشت.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@ccclxxi{و از ميان آنان گروهى هستند كه زبان خود را به [خواندن‌] كتاب [تحريف شده‌اى ] مى‌پيچانند، تا آن [بربافته‌] را از [مطالب‌] كتاب [آسمانى‌] پنداريد، با اينكه آن از كتاب [آسمانى‌] نيست؛ و مى‌گويند: آن از جانب خداست، در صورتى كه از جانب خدا نيست، و بر خدا دروغ مى‌بندند، با اينكه خودشان [هم‌] مى‌دانند.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@ccclxxii{هيچ بشرى را نسزد كه خدا به او كتاب و حكم و پيامبرى بدهد؛ سپس او به مردم بگويد: «به جاى خدا، بندگان من باشيد.» بلكه [بايد بگويد:] «به سبب آنكه كتاب [آسمانى‌] تعليم مى‌داديد و از آن رو كه درس مى‌خوانديد، علماى دين باشيد.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@ccclxxiii{و [نيز] شما را فرمان نخواهد داد كه فرشتگان و پيامبران را به خدايى بگيريد. آيا پس از آنكه سر به فرمان [خدا] نهاده‌ايد [باز] شما را به كفر وامى‌دارد؟\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@ccclxxiv{و [ياد كن‌] هنگامى را كه خداوند از پيامبران پيمان گرفت كه هر گاه به شما كتاب و حكمتى دادم، سپس شما را فرستاده‌اى آمد كه آنچه را با شماست تصديق كرد، البته به او ايمان بياوريد و حتماً ياريش كنيد. آنگاه فرمود: «آيا اقرار كرديد و در اين باره پيمانم را پذيرفتيد؟» گفتند: «آرى، اقرار كرديم.» فرمود: «پس گواه باشيد و من با شما از گواهانم.»\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@ccclxxv{پس، كسانى كه بعد از اين [پيمان‌] روى برتابند آنان، خود، نافرمانانند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@ccclxxvi{آيا جز دين خدا را مى‌جويند؟ با آنكه هر كه در آسمانها و زمين است خواه و ناخواه سر به فرمان او نهاده است، و به سوى او بازگردانيده مى‌شويد.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@ccclxxvii{بگو: «به خدا و آنچه بر ما نازل شده، و آنچه بر ابراهيم و اسماعيل و اسحاق و يعقوب و اسباط نازل گرديده، و آنچه به موسى و عيسى و انبياى [ديگر] از جانب پروردگارشان داده شده، گرويديم؛ و ميان هيچ يك از آنان فرق نمى‌گذاريم و ما او را فرمانبرداريم.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@ccclxxviii{و هر كه جز اسلام، دينى [ديگر] جويد، هرگز از وى پذيرفته نشود، و وى در آخرت از زيانكاران است.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@ccclxxix{چگونه خداوند، قومى را كه بعد از ايمانشان كافر شدند، هدايت مى‌كند؟ با آنكه شهادت دادند كه اين رسول، بر حق است و برايشان دلايل روشن آمد، و خداوند قوم بيدادگر را هدايت نمى‌كند.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@ccclxxx{آنان، سزايشان اين است كه لعنت خدا و فرشتگان و مردم، همگى برايشان است.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@ccclxxxi{در آن [لعنت‌] جاودانه بمانند؛ نه عذاب از ايشان كاسته گردد و نه مهلت يابند.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@ccclxxxii{مگر كسانى كه پس از آن توبه كردند و درستگارى [پيشه‌] نمودند، كه خداوند آمرزنده مهربان است.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@ccclxxxiii{كسانى كه پس از ايمان خود كافر شدند، سپس بر كفر [خود] افزودند، هرگز توبه آنان پذيرفته نخواهد شد، و آنان خود گمراهانند.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@ccclxxxiv{در حقيقت، كسانى كه كافر شده و در حال كفر مرده‌اند، اگر چه [فراخناى‌] زمين را پر از طلا كنند و آن را [براى خود] فديه دهند، هرگز از هيچ يك از آنان پذيرفته نگردد؛ آنان را عذابى دردناك خواهد بود، و ياورانى نخواهند داشت.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@ccclxxxv{هرگز به نيكوكارى نخواهيد رسيد تا از آنچه دوست داريد انفاق كنيد؛ و از هر چه انفاق كنيد قطعاً خدا بدان داناست.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@ccclxxxvi{همه خوراكيها بر فرزندان اسرائيل حلال بود. جز آنچه پيش از نزول تورات، اسرائيل [=يعقوب‌] بر خويشتن حرام ساخته بود. بگو: «اگر [جز اين است و] راست مى‌گوييد، تورات را بياوريد و آن را بخوانيد.»\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@ccclxxxvii{پس كسانى كه بعد از اين، بر خدا دروغ بندند، آنان خود ستمكارانند.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@ccclxxxviii{بگو: «خدا راست گفت، پس، از آيين ابراهيم كه حق‌گرا بود و از مشركان نبود، پيروى كنيد.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@ccclxxxix{در حقيقت، نخستين خانه‌اى كه براى [عبادت‌] مردم، نهاده شده، همان است كه در مكه است و مبارك، و براى جهانيان [مايه‌] هدايت است.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@cccxc{در آن، نشانه‌هايى روشن است [از جمله‌] مقام ابراهيم است؛ و هر كه در آن درآيد در امان است؛ و براى خدا، حج آن خانه، بر عهده مردم است؛ [البته بر] كسى كه بتواند به سوى آن راه يابد. و هر كه كفر ورزد، يقيناً خداوند از جهانيان بى‌نياز است.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@cccxci{بگو: «اى اهل كتاب، چرا به آيات خدا كفر مى‌ورزيد؟ با آنكه خدا بر آنچه مى‌كنيد گواه است.»\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@cccxcii{بگو: «اى اهل كتاب، چرا كسى را كه ايمان آورده است، از راه خدا بازمى‌داريد؛ و آن [راه‌] را كج مى‌شماريد، با آنكه خود [به راستىِ آن‌] گواهيد؟» و خدا از آنچه مى‌كنيد غافل نيست.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@cccxciii{اى كسانى كه ايمان آورده‌ايد، اگر از فرقه‌اى از اهل كتاب فرمان بريد، شما را پس از ايمانتان به حال كفر برمى‌گردانند.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@cccxciv{و چگونه كفر مى‌ورزيد، با اينكه آيات خدا بر شما خوانده مى‌شود و پيامبر او ميان شماست؟ و هر كس به خدا تمسك جويد، قطعاً به راه راست هدايت شده است.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@cccxcv{اى كسانى كه ايمان آورده‌ايد، از خدا آن گونه كه حق پرواكردن از اوست، پروا كنيد؛ و زينهار، جز مسلمان نميريد.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@cccxcvi{و همگى به ريسمان خدا چنگ زنيد، و پراكنده نشويد؛ و نعمت خدا را بر خود ياد كنيد: آنگاه كه دشمنان [يكديگر] بوديد، پس ميان دلهاى شما الفت انداخت، تا به لطف او برادران هم شديد؛ و بر كنار پرتگاه آتش بوديد كه شما را از آن رهانيد. اين گونه، خداوند نشانه‌هاى خود را براى شما روشن مى‌كند، باشد كه شما راه يابيد.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@cccxcvii{و بايد از ميان شما، گروهى، [مردم را] به نيكى دعوت كنند و به كار شايسته وادارند و از زشتى بازدارند، و آنان همان رستگارانند.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@cccxcviii{و چون كسانى مباشيد كه پس از آنكه دلايل آشكار برايشان آمد، پراكنده شدند و با هم اختلاف پيدا كردند، و براى آنان عذابى سهمگين است؛\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@cccxcix{[در آن‌] روزى كه چهره‌هايى سپيد، و چهره‌هايى سياه گردد. اما سياهرويان [به آنان گويند:] آيا بعد از ايمانتان كفر ورزيديد؟ پس به سزاى آنكه كفر مى‌ورزيديد [اين‌] عذاب را بچشيد.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@cd{و اما سپيدرويان همواره در رحمت خداوند جاويدانند.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@cdi{اينها آيات خداست كه آن را به حق بر تو مى‌خوانيم؛ و خداوند هيچ ستمى بر جهانيان نمى‌خواهد.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@cdii{و آنچه در آسمانها و آنچه در زمين است از آنِ خداست، و [همه‌] كارها به سوى خدا بازگردانده مى‌شود.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@cdiii{شما بهترين امتى هستيد كه براى مردم پديدار شده‌ايد: به كار پسنديده فرمان مى‌دهيد، و از كار ناپسند بازمى‌داريد، و به خدا ايمان داريد. و اگر اهل كتاب ايمان آورده بودند قطعاً برايشان بهتر بود؛ برخى از آنان مؤمنند و[لى‌] بيشترشان نافرمانند.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@cdiv{111]جز آزارى [اندك‌] هرگز به شما زيانى نخواهند رسانيد؛ و اگر با شما بجنگند، به شما پشت نمايند، سپس يارى نيابند.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@cdv{هر كجا يافته شوند، به خوارى دچار شده‌اند -مگر آنكه به پناه امان خدا و زينهار مردم [روند]- و به خشمى از خدا گرفتار آمدند، و [مُهر] بينوايى بر آنان زده شد. اين بدان سبب بود كه به آيات خدا كفر مى‌ورزيدند و پيامبران را بناحق مى‌كشتند. [و نيز] اين [عقوبت‌] به سزاى آن بود كه نافرمانى كردند و از اندازه درمى‌گذرانيدند.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@cdvi{[ولى همه آنان‌] يكسان نيستند. از ميان اهل كتاب، گروهى درستكردارند كه آيات الهى را در دل شب مى‌خوانند و سر به سجده مى‌نهند.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@cdvii{به خدا و روز قيامت ايمان دارند؛ و به كار پسنديده فرمان مى‌دهند و از كار ناپسند باز مى‌دارند؛ و در كارهاى نيك شتاب مى‌كنند، و آنان از شايستگانند.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@cdviii{و هر كار نيكى انجام دهند، هرگز در باره آن ناسپاسى نبينند، و خداوند به [حال‌] تقواپيشگان داناست.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@cdix{كسانى كه كفر ورزيدند، هرگز اموالشان و اولادشان چيزى [از عذاب خدا] را از آنان دفع نخواهد كرد، و آنان اهل آتشند و در آن جاودانه خواهند بود.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@cdx{مثَل آنچه [آنان‌] در زندگى اين دنيا [در راه دشمنى با پيامبر] خرج مى‌كنند، همانند بادى است كه در آن، سرماى سختى است، كه به كشتزار قومى كه بر خود ستم نموده‌اند بوزد و آن را تباه سازد؛ و خدا به آنان ستم نكرده، بلكه آنان خود بر خويشتن ستم كرده‌اند.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@cdxi{اى كسانى كه ايمان آورده‌ايد، از غير خودتان، [دوست و] همراز مگيريد. [آنان‌] از هيچ نابكارى در حق شما كوتاهى نمى‌ورزند. آرزو دارند كه در رنج بيفتيد. دشمنى از لحن و سخنشان آشكار است؛ و آنچه سينه‌هايشان نهان مى‌دارد، بزرگتر است. در حقيقت، ما نشانه‌ها[ى دشمنى آنان‌] را براى شما بيان كرديم، اگر تعقل كنيد.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@cdxii{هان، شما كسانى هستيد كه آنان را دوست داريد، و [حال آنكه‌] آنان شما را دوست ندارند، و شما به همه كتابها[ى خدا] ايمان داريد؛ و چون با شما برخورد كنند مى‌گويند: «ايمان آورديم.» و چون [با هم ]خلوت كنند، از شدت خشم بر شما، سر انگشتان خود را مى‌گزند. بگو: «به خشم خود بميريد» كه خداوند به راز درون سينه‌ها داناست.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@cdxiii{اگر به شما خوشى رسد آنان را بدحال مى‌كند؛ و اگر به شما گزندى رسد بدان شاد مى‌شوند؛ و اگر صبر كنيد و پرهيزگارى نماييد، نيرنگشان هيچ زيانى به شما نمى‌رساند؛ يقيناً خداوند به آنچه مى‌كنند احاطه دارد.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@cdxiv{و [ياد كن‌] زمانى را كه [در جنگ احد] بامدادان از پيش كسانت بيرون آمدى [تا] مؤمنان را براى جنگيدن، در مواضع خود جاى دهى، و خداوند، شنواى داناست.\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@cdxv{آن هنگام كه دو گروه از شما بر آن شدند كه سستى ورزند با آنكه خدا ياورشان بود. و مؤمنان بايد تنها بر خدا توكل كنند.\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@cdxvi{و يقيناً خدا شما را در [جنگ‌] بدر -با آنكه ناتوان بوديد- يارى كرد. پس، از خدا پروا كنيد، باشد كه سپاسگزارى نماييد.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@cdxvii{آنگاه كه به مؤمنان مى‌گفتى: «آيا شما را بس نيست كه پروردگارتان، شما را با سه هزار فرشته فرودآمده، يارى كند؟»\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@cdxviii{آرى، اگر صبر كنيد و پرهيزگارى نماييد، و با همين جوش [و خروش‌] بر شما بتازند، همانگاه پروردگارتان شما را با پنج هزار فرشته نشاندار يارى خواهد كرد.\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@cdxix{و خدا آن [وعده پيروزى‌] را، جز مژده‌اى براى شما قرار نداد تا [بدين وسيله شادمان شويد و] دلهاى شما بدان آرامش يابد، و پيروزى جز از جانب خداوند تواناى حكيم نيست.\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@cdxx{تا برخى از كسانى را كه كافر شده‌اند نابود كند، يا آنان را خوار سازد، تا نوميد بازگردند.\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@cdxxi{هيچ يك از اين كارها در اختيار تو نيست؛ يا [خدا] بر آنان مى‌بخشايد، يا عذابشان مى‌كند، زيرا آنان ستمكارند.\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@cdxxii{و آنچه در آسمانها و آنچه در زمين است از آنِ خداست. هر كه را بخواهد مى‌آمرزد، و هر كه را بخواهد عذاب مى‌كند، و خداوند، آمرزنده مهربان است.\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@cdxxiii{اى كسانى كه ايمان آورده‌ايد، ربا را [با سود] چندين برابر مخوريد، و از خدا پروا كنيد، باشد كه رستگار شويد.\qt@no{(130)}}
\qt@newcmd\qurantrans@fa@cdxxiv{و از آتشى كه براى كافران آماده شده است بترسيد.\qt@no{(131)}}
\qt@newcmd\qurantrans@fa@cdxxv{خدا و رسول را فرمان بريد، باشد كه مشمول رحمت قرار گيريد.\qt@no{(132)}}
\qt@newcmd\qurantrans@fa@cdxxvi{و براى نيل به آمرزشى از پروردگار خود، و بهشتى كه پهنايش [به قدر] آسمانها و زمين است [و] براى پرهيزگاران آماده شده است، بشتابيد.\qt@no{(133)}}
\qt@newcmd\qurantrans@fa@cdxxvii{همانان كه در فراخى و تنگى انفاق مى‌كنند؛ و خشم خود را فرو مى‌برند؛ و از مردم در مى‌گذرند؛ و خداوند نكوكاران را دوست دارد.\qt@no{(134)}}
\qt@newcmd\qurantrans@fa@cdxxviii{و آنان كه چون كار زشتى كنند، يا بر خود ستم روا دارند، خدا را به ياد مى‌آورند و براى گناهانشان آمرزش مى‌خواهند -و چه كسى جز خدا گناهان را مى‌آمرزد؟ و بر آنچه مرتكب شده‌اند، با آنكه مى‌دانند [كه گناه است‌]، پافشارى نمى‌كنند.\qt@no{(135)}}
\qt@newcmd\qurantrans@fa@cdxxix{آنان، پاداششان آمرزشى از جانب پروردگارشان، و بوستانهايى است كه از زير [درختان‌] آن جويبارها روان است. جاودانه در آن بمانند، و پاداش اهل عمل چه نيكوست.\qt@no{(136)}}
\qt@newcmd\qurantrans@fa@cdxxx{قطعاً پيش از شما سنّتهايى [بوده و] سپرى شده است. پس، در زمين بگرديد و بنگريد كه فرجام تكذيب‌كنندگان چگونه بوده است؟\qt@no{(137)}}
\qt@newcmd\qurantrans@fa@cdxxxi{اين [قرآن‌] براى مردم، بيانى، و براى پرهيزگاران رهنمود و اندرزى است.\qt@no{(138)}}
\qt@newcmd\qurantrans@fa@cdxxxii{و اگر مؤمنيد، سستى مكنيد و غمگين مشويد، كه شما برتريد.\qt@no{(139)}}
\qt@newcmd\qurantrans@fa@cdxxxiii{اگر به شما آسيبى رسيده، آن قوم را نيز آسيبى نظير آن رسيد؛ و ما اين روزها[ى شكست و پيروزى‌] را ميان مردم به نوبت مى‌گردانيم [تا آنان پند گيرند] و خداوند كسانى را كه [واقعاً] ايمان آورده‌اند معلوم بدارد، و از ميان شما گواهانى بگيرد، و خداوند ستمكاران را دوست نمى‌دارد.\qt@no{(140)}}
\qt@newcmd\qurantrans@fa@cdxxxiv{و تا خدا كسانى را كه ايمان آورده‌اند خالص گرداند و كافران را [به تدريج‌] نابود سازد.\qt@no{(141)}}
\qt@newcmd\qurantrans@fa@cdxxxv{آيا پنداشتيد كه داخل بهشت مى‌شويد، بى‌آنكه خداوند جهادگران و شكيبايان شما را معلوم بدارد؟\qt@no{(142)}}
\qt@newcmd\qurantrans@fa@cdxxxvi{و شما مرگ را پيش از آنكه با آن روبرو شويد، سخت آرزو مى‌كرديد؛ پس، آن را ديديد و [همچنان‌] نگاه مى‌كرديد.\qt@no{(143)}}
\qt@newcmd\qurantrans@fa@cdxxxvii{و محمد، جز فرستاده‌اى كه پيش از او [هم‌] پيامبرانى [آمده و] گذشتند، نيست. آيا اگر او بميرد يا كشته شود، از عقيده خود برمى‌گرديد؟ و هر كس از عقيده خود بازگردد، هرگز هيچ زيانى به خدا نمى‌رساند، و به زودى خداوند سپاسگزاران را پاداش مى‌دهد.\qt@no{(144)}}
\qt@newcmd\qurantrans@fa@cdxxxviii{و هيچ نفسى جز به فرمان خدا نميرد. [خداوند، مرگ را] به عنوان سرنوشتى معين [مقرر كرده است‌]. و هر كه پاداش اين دنيا را بخواهد به او از آن مى‌دهيم؛ و هر كه پاداش آن سراى را بخواهد از آن به او مى‌دهيم، و به زودى سپاسگزاران را پاداش خواهيم داد.\qt@no{(145)}}
\qt@newcmd\qurantrans@fa@cdxxxix{و چه بسيار پيامبرانى كه همراه او توده‌هاى انبوه، كارزار كردند؛ و در برابر آنچه در راه خدا بديشان رسيد، سستى نورزيدند و ناتوان نشدند؛ و تسليم [دشمن‌] نگرديدند، و خداوند، شكيبايان را دوست دارد.\qt@no{(146)}}
\qt@newcmd\qurantrans@fa@cdxl{و سخن آنان جز اين نبود كه گفتند: «پروردگارا، گناهان ما و زياده‌روى ما، در كارمان را بر ما ببخش، و گامهاى ما را استوار دار، و ما را بر گروه كافران يارى ده.»\qt@no{(147)}}
\qt@newcmd\qurantrans@fa@cdxli{پس خداوند، پاداش اين دنيا، و پاداش نيك آخرت را به آنان عطا كرد، و خداوند نيكوكاران را دوست دارد.\qt@no{(148)}}
\qt@newcmd\qurantrans@fa@cdxlii{اى كسانى كه ايمان آورده‌ايد، اگر از كسانى كه كفر ورزيده‌اند اطاعت كنيد، شما را از عقيده‌تان بازمى‌گردانند و زيانكار خواهيد گشت.\qt@no{(149)}}
\qt@newcmd\qurantrans@fa@cdxliii{آرى، خدا مولاى شماست، و او بهترين يارى‌دهندگان است.\qt@no{(150)}}
\qt@newcmd\qurantrans@fa@cdxliv{به زودى در دلهاى كسانى كه كفر ورزيده‌اند بيم خواهيم افكند، زيرا چيزى را با خدا شريك گردانيده‌اند كه بر [حقانيت‌] آن، [خدا] دليلى نازل نكرده است. و جايگاهشان آتش است، و جايگاه ستمگران چه بد است.\qt@no{(151)}}
\qt@newcmd\qurantrans@fa@cdxlv{و [در نبرد اُحد] قطعاً خدا وعده خود را با شما راست گردانيد: آنگاه كه به فرمان او، آنان را مى‌كشتيد، تا آنكه سست شديد و در كار [جنگ و بر سر تقسيم غنايم‌] با يكديگر به نزاع پرداختيد؛ و پس از آنكه آنچه را دوست داشتيد [يعنى غنايم را ]به شما نشان داد، نافرمانى نموديد. برخى از شما دنيا را و برخى از شما آخرت را مى‌خواهد. سپس براى آنكه شما را بيازمايد، از [تعقيب‌] آنان منصرفتان كرد و از شما درگذشت، و خدا نسبت به مؤمنان، با تفضل است.\qt@no{(152)}}
\qt@newcmd\qurantrans@fa@cdxlvi{[ياد كنيد] هنگامى را كه در حال گريز [از كوه‌] بالا مى‌رفتيد و به هيچ كس توجه نمى‌كرديد؛ و پيامبر، شما را از پشت سرتان فرا مى‌خواند. پس [خداوند] به سزاى [اين بى‌انضباطى‌] غمى بر غمتان [افزود]، تا سرانجام بر آنچه از كف داده‌ايد و براى آنچه به شما رسيده است اندوهگين نشويد، و خداوند از آنچه مى‌كنيد آگاه است.\qt@no{(153)}}
\qt@newcmd\qurantrans@fa@cdxlvii{سپس [خداوند] بعد از آن اندوه، آرامشى [به صورت‌] خواب سبكى، بر شما فرو فرستاد، كه گروهى از شما را فرا گرفت، و گروهى [تنها] در فكر جان خود بودند؛ و در باره خدا، گمانهاى ناروا، همچون گمانهاى [دوران‌] جاهليت مى‌بردند. مى‌گفتند: «آيا ما را در اين كار اختيارى هست؟» بگو: «سررشته كارها [شكست يا پيروزى‌]، يكسر به دست خداست.» آنان چيزى را در دلهايشان پوشيده مى‌داشتند، كه براى تو آشكار نمى‌كردند. مى‌گفتند: «اگر ما را در اين كار اختيارى بود، [و وعده پيامبر واقعيت داشت،] در اينجا كشته نمى‌شديم.» بگو: «اگر شما در خانه‌هاى خود هم بوديد، كسانى كه كشته شدن بر آنان نوشته شده، قطعاً [با پاى خود] به سوى قتلگاههاى خويش مى‌رفتند. و [اينها ] براى اين است كه خداوند، آنچه را در دلهاى شماست، [در عمل‌] بيازمايد؛ و آنچه را در قلبهاى شماست، پاك گرداند؛ و خدا به راز سينه‌ها آگاه است.\qt@no{(154)}}
\qt@newcmd\qurantrans@fa@cdxlviii{روزى كه دو گروه [در اُحد] با هم روياروى شدند، كسانى كه از ميان شما [به دشمن‌] پشت كردند، در حقيقت جز اين نبود كه به سبب پاره‌اى از آنچه [از گناه‌] حاصل كرده بودند، شيطان آنان را بلغزانيد. و قطعاً خدا از ايشان درگذشت؛ زيرا خدا آمرزگار بردبار است.\qt@no{(155)}}
\qt@newcmd\qurantrans@fa@cdxlix{اى كسانى كه ايمان آورده‌ايد، همچون كسانى نباشيد كه كفر ورزيدند؛ و به برادرانشان - هنگامى كه به سفر رفته [و در سفر مردند] و يا جهادگر شدند [و كشته شدند]، گفتند: «اگر نزد ما [مانده‌] بودند، نمى‌مردند و كشته نمى‌شدند.» [شما چنين سخنانى مگوييد] تا خدا آن را در دلهايشان حسرتى قرار دهد. و خدا[ست كه‌] زنده مى‌كند و مى‌ميراند، و خدا[ست كه‌] به آنچه مى‌كنيد بيناست.\qt@no{(156)}}
\qt@newcmd\qurantrans@fa@cdl{و اگر در راه خدا كشته شويد يا بميريد، قطعاً آمرزش خدا و رحمت او از [همه‌] آنچه [آنان‌] جمع مى‌كنند بهتر است.\qt@no{(157)}}
\qt@newcmd\qurantrans@fa@cdli{و اگر [در راه جهاد] بميريد يا كشته شويد، قطعاً به سوى خدا گردآورده خواهيد شد.\qt@no{(158)}}
\qt@newcmd\qurantrans@fa@cdlii{پس به [بركت‌] رحمت الهى، با آنان نرمخو [و پُرمِهر] شدى، و اگر تندخو و سختدل بودى قطعاً از پيرامون تو پراكنده مى‌شدند. پس، از آنان درگذر و برايشان آمرزش بخواه، و در كار[ها] با آنان مشورت كن، و چون تصميم گرفتى بر خدا توكل كن، زيرا خداوند توكل‌كنندگان را دوست مى‌دارد.\qt@no{(159)}}
\qt@newcmd\qurantrans@fa@cdliii{اگر خدا شما را يارى كند، هيچ كس بر شما غالب نخواهد شد؛ و اگر دست از يارى شما بردارد، چه كسى بعد از او شما را يارى خواهد كرد؟ و مؤمنان بايد تنها بر خدا توكل كنند.\qt@no{(160)}}
\qt@newcmd\qurantrans@fa@cdliv{و هيچ پيامبرى را نسزد كه خيانت ورزد، و هر كس خيانت ورزد، روز قيامت با آنچه در آن خيانت كرده بيايد؛ آنگاه به هر كس [پاداش‌] آنچه كسب كرده، به تمامى داده مى‌شود، و بر آنان ستم نرود.\qt@no{(161)}}
\qt@newcmd\qurantrans@fa@cdlv{آيا كسى كه خشنودى خدا را پيروى مى‌كند، چون كسى است كه به خشمى از خدا دچار گرديده و جايگاهش جهنم است؟ و چه بد بازگشتگاهى است.\qt@no{(162)}}
\qt@newcmd\qurantrans@fa@cdlvi{[هر يك از] ايشان را نزد خداوند درجاتى است، و خدا به آنچه مى‌كنند بيناست.\qt@no{(163)}}
\qt@newcmd\qurantrans@fa@cdlvii{به يقين، خدا بر مؤمنان منت نهاد [كه‌] پيامبرى از خودشان در ميان آنان برانگيخت، تا آيات خود را بر ايشان بخواند و پاكشان گرداند و كتاب و حكمت به آنان بياموزد، قطعاً پيش از آن در گمراهى آشكارى بودند.\qt@no{(164)}}
\qt@newcmd\qurantrans@fa@cdlviii{آيا چون به شما [در نبرد اُحد] مصيبتى رسيد -[با آنكه در نبرد بدر] دو برابرش را [به دشمنان خود] رسانديد- گفتيد: «اين [مصيبت‌] از كجا [به ما رسيد]؟» بگو: «آن از خود شما [و ناشى از بى‌انضباطى خودتان‌] است.» آرى! خدا به هر چيزى تواناست.\qt@no{(165)}}
\qt@newcmd\qurantrans@fa@cdlix{و روزى كه [در اُحد] آن دو گروه با هم برخورد كردند، آنچه به شما رسيد به اذن خدا بود [تا شما را بيازمايد] و مؤمنان را معلوم بدارد؛\qt@no{(166)}}
\qt@newcmd\qurantrans@fa@cdlx{همچنين كسانى را كه دو رويى نمودند [نيز] معلوم بدارد. و به ايشان گفته شد: «بياييد در راه خدا بجنگيد يا دفاع كنيد.» گفتند: «اگر جنگيدن مى‌دانستيم مسلماً از شما پيروى مى‌كرديم.» آن روز، آنان به كفر نزديكتر بودند تا به ايمان. به زبان خويش چيزى مى‌گفتند كه در دلهايشان نبود، و خدا به آنچه مى‌نهفتند داناتر است.\qt@no{(167)}}
\qt@newcmd\qurantrans@fa@cdlxi{همان كسانى كه [خود در خانه‌] نشستند و در باره دوستان خود گفتند: «اگر از ما پيروى مى‌كردند كشته نمى‌شدند.» بگو: «اگر راست مى‌گوييد مرگ را از خودتان دور كنيد.»\qt@no{(168)}}
\qt@newcmd\qurantrans@fa@cdlxii{هرگز كسانى را كه در راه خدا كشته شده‌اند، مرده مپندار، بلكه زنده‌اند كه نزد پروردگارشان روزى داده مى‌شوند.\qt@no{(169)}}
\qt@newcmd\qurantrans@fa@cdlxiii{به آنچه خدا از فضل خود به آنان داده است شادمانند، و براى كسانى كه از پى ايشانند و هنوز به آنان نپيوسته‌اند شادى مى‌كنند كه نه بيمى بر ايشان است و نه اندوهگين مى‌شوند.\qt@no{(170)}}
\qt@newcmd\qurantrans@fa@cdlxiv{بر نعمت و فضل خدا و اينكه خداوند پاداش مؤمنان را تباه نمى‌گرداند، شادى مى‌كنند.\qt@no{(171)}}
\qt@newcmd\qurantrans@fa@cdlxv{كسانى كه [در نبرد اُحد] پس از آنكه زخم برداشته بودند، دعوت خدا و پيامبر [او] را اجابت كردند، براى كسانى از آنان كه نيكى و پرهيزگارى كردند پاداشى بزرگ است.\qt@no{(172)}}
\qt@newcmd\qurantrans@fa@cdlxvi{همان كسانى كه [برخى از] مردم به ايشان گفتند: «مردمان براى [جنگ با] شما گرد آمده‌اند؛ پس، از آن بترسيد.» و[لى اين سخن‌] بر ايمانشان افزود و گفتند: «خدا ما را بس است و نيكو حمايتگرى است.»\qt@no{(173)}}
\qt@newcmd\qurantrans@fa@cdlxvii{پس با نعمت و بخششى از جانب خدا، [از ميدان نبرد] بازگشتند، در حالى كه هيچ آسيبى به آنان نرسيده بود، و همچنان خشنودى خدا را پيروى كردند، و خداوند داراى بخششى عظيم است.\qt@no{(174)}}
\qt@newcmd\qurantrans@fa@cdlxviii{در واقع، اين شيطان است كه دوستانش را مى‌ترساند؛ پس اگر مؤمنيد از آنان مترسيد و از من بترسيد.\qt@no{(175)}}
\qt@newcmd\qurantrans@fa@cdlxix{و كسانى كه در كفر مى‌كوشند، تو را اندوهگين نسازند؛ كه آنان هرگز به خدا هيچ زيانى نمى‌رسانند. خداوند مى‌خواهد در آخرت براى آنان بهره‌اى قرار ندهد، و براى ايشان عذابى بزرگ است.\qt@no{(176)}}
\qt@newcmd\qurantrans@fa@cdlxx{در حقيقت، كسانى كه كفر را به [بهاى‌] ايمان خريدند، هرگز به خداوند هيچ زيانى نخواهند رسانيد، و براى آنان عذابى دردناك است.\qt@no{(177)}}
\qt@newcmd\qurantrans@fa@cdlxxi{و البته نبايد كسانى كه كافر شده‌اند تصور كنند اينكه به ايشان مهلت مى‌دهيم براى آنان نيكوست؛ ما فقط به ايشان مهلت مى‌دهيم تا بر گناه [خود] بيفزايند، و [آنگاه‌] عذابى خفت‌آور خواهند داشت.\qt@no{(178)}}
\qt@newcmd\qurantrans@fa@cdlxxii{خدا بر آن نيست كه مؤمنان را به اين [حالى‌] كه شما بر آن هستيد، واگذارد، تا آنكه پليد را از پاك جدا كند. و خدا بر آن نيست كه شما را از غيب آگاه گرداند، ولى خدا از ميان فرستادگانش هر كه را بخواهد برمى‌گزيند. پس، به خدا و پيامبرانش ايمان بياوريد؛ و اگر بگرويد و پرهيزگارى كنيد، براى شما پاداشى بزرگ خواهد بود.\qt@no{(179)}}
\qt@newcmd\qurantrans@fa@cdlxxiii{و كسانى كه به آنچه خدا از فضل خود به آنان عطا كرده، بخل مى‌ورزند، هرگز تصور نكنند كه آن [بخل‌] براى آنان خوب است، بلكه برايشان بد است. به زودى آنچه كه به آن بخل ورزيده‌اند، روز قيامت طوق گردنشان مى‌شود. ميراث آسمانها و زمين از آنِ خداست، و خدا به آنچه مى‌كنيد آگاه است.\qt@no{(180)}}
\qt@newcmd\qurantrans@fa@cdlxxiv{مسلماً خداوند، سخن كسانى را كه گفتند: «خدا نيازمند است و ما توانگريم »، شنيد. به زودى آنچه را گفتند، و بناحق كشتنِ آنان پيامبران را، خواهيم نوشت و خواهيم گفت: «بچشيد عذاب سوزان را.»\qt@no{(181)}}
\qt@newcmd\qurantrans@fa@cdlxxv{اين [عقوبت‌] به خاطر كار و كردار پيشين شماست، [و گر نه‌] خداوند هرگز نسبت به بندگان [خود] بيدادگر نيست.\qt@no{(182)}}
\qt@newcmd\qurantrans@fa@cdlxxvi{همانان كه گفتند: «خدا با ما پيمان بسته كه به هيچ پيامبرى ايمان نياوريم تا براى ما قربانيى بياورد كه آتش [آسمانى‌] آن را [به نشانه قبول‌] بسوزاند.» بگو: «قطعاً پيش از من، پيامبرانى بودند كه دلايل آشكار را با آنچه گفتيد، براى شما آوردند. اگر راست مى گوييد، پس چرا آنان را كشتيد؟»\qt@no{(183)}}
\qt@newcmd\qurantrans@fa@cdlxxvii{پس اگر تو را تكذيب كردند، بدان كه پيامبرانى [هم‌] كه پيش از تو، دلايل روشن و نوشته‌ها و كتاب روشن آورده بودند، تكذيب شدند.\qt@no{(184)}}
\qt@newcmd\qurantrans@fa@cdlxxviii{هر جاندارى چشنده [طعم‌] مرگ است، و همانا روز رستاخيز پاداشهايتان به طور كامل به شما داده مى‌شود. پس هر كه را از آتش به دور دارند و در بهشت درآورند قطعاً كامياب شده است؛ و زندگى دنيا جز مايه فريب نيست.\qt@no{(185)}}
\qt@newcmd\qurantrans@fa@cdlxxix{قطعاً در مالها و جانهايتان آزموده خواهيد شد، و از كسانى كه پيش از شما به آنان كتاب داده شده و [نيز] از كسانى كه به شرك گراييده‌اند، [سخنان دل‌]آزار بسيارى خواهيد شنيد، و[لى‌] اگر صبر كنيد و پرهيزگارى نماييد، اين [ايستادگى‌] حاكى از عزم استوار [شما] در كارهاست.\qt@no{(186)}}
\qt@newcmd\qurantrans@fa@cdlxxx{و [ياد كن‌] هنگامى را كه خداوند از كسانى كه به آنان كتاب داده شده، پيمان گرفت كه حتماً بايد آن را [به وضوح‌] براى مردم بيان نماييد و كتمانش مكنيد. پس، آن [عهد] را پشت سر خود انداختند و در برابر آن، بهايى ناچيز به دست آوردند، و چه بد معامله‌اى كردند.\qt@no{(187)}}
\qt@newcmd\qurantrans@fa@cdlxxxi{البته گمان مبر كسانى كه بدانچه كرده‌اند شادمانى مى‌كنند و دوست دارند به آنچه نكرده‌اند مورد ستايش قرار گيرند، قطعاً گمان مبر كه براى آنان نجاتى از عذاب است، [كه‌] عذابى دردناك خواهند داشت.\qt@no{(188)}}
\qt@newcmd\qurantrans@fa@cdlxxxii{و فرمانروايى آسمانها و زمين از آنِ خداست، و خداوند بر هر چيزى تواناست.\qt@no{(189)}}
\qt@newcmd\qurantrans@fa@cdlxxxiii{مسلماً در آفرينش آسمانها و زمين، و در پى يكديگر آمدن شب و روز، براى خردمندان نشانه‌هايى [قانع كننده‌] است.\qt@no{(190)}}
\qt@newcmd\qurantrans@fa@cdlxxxiv{همانان كه خدا را [در همه احوال‌] ايستاده و نشسته، و به پهلو آرميده ياد مى‌كنند، و در آفرينش آسمانها و زمين مى‌انديشند [كه:] پروردگارا، اينها را بيهوده نيافريده‌اى؛ منزهى تو! پس ما را از عذاب آتش دوزخ در امان بدار.\qt@no{(191)}}
\qt@newcmd\qurantrans@fa@cdlxxxv{پروردگارا، هر كه را تو در آتش درآورى، يقيناً رسوايش كرده‌اى، و براى ستمكاران ياورانى نيست.\qt@no{(192)}}
\qt@newcmd\qurantrans@fa@cdlxxxvi{پروردگارا، ما شنيديم كه دعوتگرى به ايمان فرا مى‌خواند كه: «به پروردگار خود ايمان آوريد»، پس ايمان آورديم. پروردگارا، گناهان ما را بيامرز، و بديهاى ما را بزداى و ما را در زمره نيكان بميران.\qt@no{(193)}}
\qt@newcmd\qurantrans@fa@cdlxxxvii{پروردگارا، و آنچه را كه به وسيله فرستادگانت به ما وعده داده‌اى به ما عطا كن، و ما را روز رستاخيز رسوا مگردان، زيرا تو وعده‌ات را خلاف نمى‌كنى.\qt@no{(194)}}
\qt@newcmd\qurantrans@fa@cdlxxxviii{پس، پروردگارشان دعاى آنان را اجابت كرد [و فرمود كه:] من عمل هيچ صاحب عملى از شما را، از مرد يا زن، كه همه از يكديگريد، تباه نمى‌كنم؛ پس، كسانى كه هجرت كرده و از خانه‌هاى خود رانده شده و در راه من آزار ديده و جنگيده و كشته شده‌اند، بديهايشان را از آنان مى‌زدايم، و آنان را در باغهايى كه از زيرِ [درختان‌] آن نهرها روان است درمى‌آورم؛ [اين‌] پاداشى است از جانب خدا و پاداش نيكو نزد خداست.\qt@no{(195)}}
\qt@newcmd\qurantrans@fa@cdlxxxix{مبادا رفت و آمد [و جنب و جوش‌] كافران در شهرها تو را دستخوش فريب كند.\qt@no{(196)}}
\qt@newcmd\qurantrans@fa@cdxc{[اين‌] كالاى ناچيز [و برخوردارىِ اندكى‌] است؛ سپس جايگاهشان دوزخ است، و چه بد قرارگاهى است.\qt@no{(197)}}
\qt@newcmd\qurantrans@fa@cdxci{ولى كسانى كه پرواى پروردگارشان را پيشه ساخته‌اند باغهايى خواهند داشت كه از زير [درختان‌] آن نهرها روان است. در آنجا جاودانه بمانند؛ [اين‌] پذيرايى از جانب خداست، و آنچه نزد خداست براى نيكان بهتر است.\qt@no{(198)}}
\qt@newcmd\qurantrans@fa@cdxcii{و البته از ميان اهل كتاب كسانى هستند كه به خدا و بدانچه به سوى شما نازل شده و به آنچه به سوى خودشان فرود آمده ايمان دارند، در حالى كه در برابر خدا خاشعند، و آيات خدا را به بهاى ناچيزى نمى‌فروشند. اينانند كه نزد پروردگارشان پاداش خود را خواهند داشت. آرى! خدا زودشمار است.\qt@no{(199)}}
\qt@newcmd\qurantrans@fa@cdxciii{اى كسانى كه ايمان آورده‌ايد، صبر كنيد و ايستادگى ورزيد و مرزها را نگهبانى كنيد و از خدا پروا نماييد، اميد است كه رستگار شويد.\qt@no{(200)}}
\qt@newcmd\qurantrans@fa@cdxciv{\basmalahfa اى مردم، از پروردگارتان كه شما را از «نفس واحدى» آفريد و جفتش را [نيز ] از او آفريد، و از آن دو، مردان و زنان بسيارى پراكنده كرد، پروا داريد؛ و از خدايى كه به [نام‌] او از همديگر درخواست مى‌كنيد پروا نماييد؛ و زنهار از خويشاوندان مَبُريد، كه خدا همواره بر شما نگهبان است.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@cdxcv{و اموال يتيمان را به آنان [باز]دهيد، و [مال پاك‌] و [مرغوب آنان ] را با [مال‌] ناپاك [خود] عوض نكنيد؛ و اموال آنان را همراه با اموال خود مخوريد كه اين گناهى بزرگ است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@cdxcvi{و اگر در اجراى عدالت ميان دختران يتيم بيمناكيد، هر چه از زنان [ديگر] كه شما را پسند افتاد، دو دو، سه سه، چهار چهار، به زنى گيريد. پس اگر بيم داريد كه به عدالت رفتار نكنيد، به يك [زن آزاد] يا به آنچه [از كنيزان‌] مالك شده‌ايد [اكتفا كنيد]. اين [خوددارى‌] نزديكتر است تا به ستم گراييد [و بيهوده عيال‌وار گرديد].\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@cdxcvii{و مَهر زنان را به عنوان هديه‌اى از روى طيب خاطر به ايشان بدهيد؛ و اگر به ميل خودشان چيزى از آن را به شما واگذاشتند، آن را حلال و گوارا بخوريد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@cdxcviii{و اموال خود را -كه خداوند آن را وسيله قوام [زندگى‌] شما قرار داده- به سفيهان مدهيد، و[لى‌] از [عوايد] آن به ايشان بخورانيد و آنان را پوشاك دهيد؛ و با آنان سخنى پسنديده بگوييد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@cdxcix{و يتيمان را بيازماييد تا وقتى به [سن‌] زناشويى برسند؛ پس اگر در ايشان رشد [فكرى‌] يافتيد، اموالشان را به آنان رد كنيد، و آن را [از بيم آنكه مبادا] بزرگ شوند، به اسراف و شتاب مخوريد. و آن كس كه توانگر است بايد [از گرفتن اجرت سرپرستى‌] خوددارى ورزد؛ و هر كس تهيدست است بايد مطابق عرف [از آن‌] بخورد؛ پس هر گاه اموالشان را به آنان رد كرديد بر ايشان گواه بگيريد، خداوند حسابرسى را كافى است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@d{براى مردان، از آنچه پدر و مادر و خويشاوندان [آنان‌] بر جاى گذاشته‌اند سهمى است؛ و براى زنان [نيز] از آنچه پدر و مادر و خويشاوندان [آنان‌] بر جاى گذاشته‌اند سهمى [خواهد بود] -خواه آن [مال‌] كم باشد يا زياد- نصيب هر كس مفروض شده است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@di{و هر گاه، خويشاوندان يتيمان و مستمندان در تقسيم [ارث‌] حاضر شدند، [چيزى‌] از آن را به ايشان ارزانى داريد و با آنان سخنى پسنديده گوييد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@dii{و آنان كه اگر فرزندان ناتوانى از خود بر جاى بگذارند بر [آينده‌] آنان بيم دارند، بايد [از ستم بر يتيمان مردم نيز] بترسند. پس بايد از خدا پروا دارند و سخنى [بجا و] درست گويند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@diii{در حقيقت، كسانى كه اموال يتيمان را به ستم مى‌خورند، جز اين نيست كه آتشى در شكم خود فرو مى‌برند، و به زودى در آتشى فروزان درآيند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@div{خداوند به شما در باره فرزندانتان سفارش مى‌كند: سهم پسر، چون سهم دو دختر است. و اگر [همه ورثه،] دختر [و] از دو تن بيشتر باشند، سهم آنان دو سوم ماترك است؛ و اگر [دخترى كه ارث مى‌برد ]يكى باشد، نيمى از ميراث از آنِ اوست، و براى هر يك از پدر و مادر وى [=متوفى‌] يك ششم از ماترك [مقرر شده‌] است، اين در صورتى است كه [متوفى‌] فرزندى داشته باشد. ولى اگر فرزندى نداشته باشد و [تنها] پدر و مادرش از او ارث برند، براى مادرش يك سوم است [و بقيه را پدر مى‌برد]؛ و اگر او برادرانى داشته باشد، مادرش يك ششم مى‌برد، [البته همه اينها] پس از انجام وصيتى است كه او بدان سفارش كرده يا دَينى [كه بايد استثنا شود]. شما نمى دانيد پدران و فرزندانتان كدام يك براى شما سودمندترند. [اين ]فرضى است از جانب خدا، زيرا خداوند داناى حكيم است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@dv{و نيمى از ميراث همسرانتان از آنِ شما [شوهران‌] است اگر آنان فرزندى نداشته باشند؛ و اگر فرزندى داشته باشند يك چهارم ماترك آنان از آنِ شماست، [البته‌] پس از انجام وصيتى كه بدان سفارش كرده‌اند يا دَينى [كه بايد استثنا شود]، و يك چهارم از ميراث شما براى آنان است اگر شما فرزندى نداشته باشيد؛ و اگر فرزندى داشته باشيد، يك هشتم براى ميراث شما از ايشان خواهد بود، [البته‌] پس از انجام وصيتى كه بدان سفارش كرده‌ايد يا دَينى [كه بايد استثنا شود]، و اگر مرد يا زنى كه از او ارث مى‌برند كلاله [=بى‌فرزند و بى‌پدر و مادر] باشد و براى او برادر يا خواهرى باشد، پس براى هر يك از آن دو، يك ششم [ماترك‌] است؛ و اگر آنان بيش از اين باشند در يك سوم [ماترك‌] مشاركت دارند، [البته‌] پس از انجام وصيتى كه بدان سفارش شده يا دَينى كه [بايد استثنا شود، به شرط آنكه از اين طريق‌] زيانى [به ورثه‌] نرساند. اين است سفارش خدا و خداست كه داناى بردبار است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@dvi{اينها احكام الهى است، و هر كس از خدا و پيامبر او اطاعت كند، وى را به باغهايى درآورد كه از زير [درختان‌] آن نهرها روان است. در آن جاودانه‌اند، و اين همان كاميابى بزرگ است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@dvii{و هر كس از خدا و پيامبر او نافرمانى كند و از حدود مقرر او تجاوز نمايد، وى را در آتشى درآورد كه همواره در آن خواهد بود و براى او عذابى خفت‌آور است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@dviii{و از زنان شما، كسانى كه مرتكب زنا مى‌شوند، چهار تن از ميان خود [مسلمانان‌] بر آنان گواه گيريد؛ پس اگر شهادت دادند، آنان [=زنان‌] را در خانه‌ها نگاه داريد تا مرگشان فرا رسد يا خدا راهى براى آنان قرار دهد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@dix{و از ميان شما، آن دو تن را كه مرتكب زشتكارى مى‌شوند، آزارشان دهيد؛ پس اگر توبه كردند و درستكار شدند از آنان صرفنظر كنيد، زيرا خداوند توبه‌پذير مهربان است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@dx{توبه، نزد خداوند، تنها براى كسانى است كه از روى نادانى مرتكب گناه مى‌شوند، سپس به زودى توبه مى‌كنند؛ اينانند كه خدا توبه‌شان را مى‌پذيرد، و خداوند داناى حكيم است.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@dxi{و توبه كسانى كه گناه مى‌كنند، تا وقتى كه مرگ يكى از ايشان دررسد، مى‌گويد: «اكنون توبه كردم»، پذيرفته نيست؛ و [نيز توبه‌] كسانى كه در حال كفر مى‌ميرند، پذيرفته نخواهد بود، آنانند كه برايشان عذابى دردناك آماده كرده‌ايم.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@dxii{اى كسانى كه ايمان آورده‌ايد، براى شما حلال نيست كه زنان را به اكراه ارث بريد؛ و آنان را زير فشار مگذاريد تا بخشى از آنچه را به آنان داده‌ايد [از چنگشان به در] بريد، مگر آنكه مرتكب زشتكارى آشكارى شوند، و با آنها بشايستگى رفتار كنيد؛ و اگر از آنان خوشتان نيامد، پس چه بسا چيزى را خوش نمى‌داريد و خدا در آن مصلحت فراوان قرار مى‌دهد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@dxiii{و اگر خواستيد همسرى [ديگر] به جاى همسر [پيشين خود] ستانيد، و به يكى از آنان مال فراوانى داده باشيد، چيزى از او پس مگيريد. آيا مى‌خواهيد آن [مال‌] را به بهتان و گناه آشكار بگيريد؟\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@dxiv{و چگونه آن [مَهر] را مى‌ستانيد با آنكه از يكديگر كام گرفته‌ايد، و آنان از شما پيمانى استوار گرفته‌اند؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@dxv{و با زنانى كه پدرانتان به ازدواج خود درآورده‌اند، نكاح مكنيد؛ مگر آنچه كه پيشتر رخ داده است، چرا كه آن، زشتكارى و [مايه‌] دشمنى، و بد راهى بوده است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@dxvi{[نكاح اينان‌] بر شما حرام شده است: مادرانتان، و دخترانتان، و خواهرانتان، و عمه‌هايتان، و خاله هايتان، و دختران برادر، و دختران خواهر، و مادرهايتان كه به شما شير داده‌اند، و خواهران رضاعى شما، و مادران زنانتان، و دختران همسرانتان كه [آنها دختران‌] در دامان شما پرورش يافته‌اند و با آن همسران همبستر شده‌ايد -پس اگر با آنها همبستر نشده‌ايد بر شما گناهى نيست [كه با دخترانشان ازدواج كنيد]- و زنان پسرانتان كه از پشت خودتان هستند، و جمع دو خواهر با همديگر -مگر آنچه كه در گذشته رخ داده باشد- كه خداوند آمرزنده مهربان است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@dxvii{و زنان شوهردار [نيز بر شما حرام شده است‌] به استثناى زنانى كه مالك آنان شده‌ايد؛ [اين‌] فريضه الهى است كه بر شما مقرر گرديده است. و غير از اين [زنان نامبرده‌]، براى شما حلال است كه [زنان ديگر را] به وسيله اموال خود طلب كنيد -در صورتى كه پاكدامن باشيد و زناكار نباشيد- و زنانى را كه متعه كرده‌ايد، مَهرشان را به عنوان فريضه‌اى به آنان بدهيد، و بر شما گناهى نيست كه پس از [تعيين مبلغ‌] مقرر، با يكديگر توافق كنيد [كه مدت عقد يا مَهر را كم يا زياد كنيد]؛ مسلماً خداوند داناى حكيم است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@dxviii{و هر كس از شما، از نظر مالى نمى‌تواند زنان [آزاد] پاكدامن با ايمان را به همسرى [خود] درآورد، پس با دختران جوانسال با ايمان شما كه مالك آنان هستيد [ازدواج كند]؛ و خدا به ايمان شما داناتر است. [همه‌] از يكديگريد. پس آنان را با اجازه خانواده‌شان به همسرى [خود] درآوريد و مَهرشان را به طور پسنديده به آنان بدهيد [به شرط آنكه‌] پاكدامن باشند نه زناكار، و دوست‌گيران پنهانى نباشند. پس چون به ازدواج [شما] درآمدند، اگر مرتكب فحشا شدند، پس بر آنان نيمى از عذاب [=مجازات‌] زنان آزاد است. اين [پيشنهاد زناشويى با كنيزان‌] براى كسى از شماست كه از آلايش گناه بيم دارد؛ و صبر كردن، براى شما بهتر است، و خداوند آمرزنده مهربان است.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@dxix{خدا مى‌خواهد براى شما توضيح دهد، و راه [و رسم‌] كسانى را كه پيش از شما بوده‌اند به شما بنماياند، و بر شما ببخشايد، و خدا داناى حكيم است.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@dxx{خدا مى‌خواهد تا بر شما ببخشايد؛ و كسانى كه از خواسته‌ها[ى نفسانى‌] پيروى مى‌كنند مى‌خواهند شما دستخوش انحرافى بزرگ شويد.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@dxxi{خدا مى‌خواهد تا بارتان را سبك گرداند؛ و [مى‌داند كه‌] انسان، ناتوان آفريده شده است.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@dxxii{اى كسانى كه ايمان آورده‌ايد، اموال همديگر را به ناروا مخوريد -مگر آنكه داد و ستدى با تراضى يكديگر، از شما [انجام گرفته‌] باشد- و خودتان را مكشيد، زيرا خدا همواره با شما مهربان است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@dxxiii{و هر كس از روى تجاوز و ستم چنين كند، به زودى وى را در آتشى درآوريم، و اين كار بر خدا آسان است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@dxxiv{اگر از گناهان بزرگى كه از آن‌[ها] نهى شده‌ايد دورى گزينيد، بديهاى شما را از شما مى زداييم، و شما را در جايگاهى ارجمند درمى‌آوريم.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@dxxv{و زنهار، آنچه را خداوند به [سبب‌] آن، بعضى از شما را بر بعضى [ديگر] برترى داده آرزو مكنيد. براى مردان از آنچه [به اختيار] كسب كرده‌اند بهره‌اى است، و براى زنان [نيز] از آنچه [به اختيار] كسب كرده‌اند بهره‌اى است. و از فضل خدا درخواست كنيد، كه خدا به هر چيزى داناست.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@dxxvi{و از آنچه پدر و مادر و خويشاوندان، و كسانى كه شما [با آنان‌] پيمان بسته‌ايد، بر جاى گذاشته‌اند، براى هر يك [از مردان و زنان‌]، وارثانى قرار داده‌ايم. پس نصيبشان را به ايشان بدهيد، زيرا خدا همواره بر هر چيزى گواه است.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@dxxvii{مردان، سرپرست زنانند، به دليل آنكه خدا برخى از ايشان را بر برخى برترى داده و [نيز] به دليل آنكه از اموالشان خرج مى‌كنند. پس، زنان درستكار، فرمانبردارند [و] به پاس آنچه خدا [براى آنان‌] حفظ كرده، اسرار [شوهران خود] را حفظ مى‌كنند. و زنانى را كه از نافرمانى آنان بيم داريد [نخست‌] پندشان دهيد و [بعد] در خوابگاه‌ها از ايشان دورى كنيد و [اگر تاثير نكرد] آنان را بزنيد؛ پس اگر شما را اطاعت كردند [ديگر] بر آنها هيچ راهى [براى سرزنش‌] مجوييد، كه خدا والاى بزرگ است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@dxxviii{و اگر از جدايى ميان آن دو [: زن و شوهر] بيم داريد پس داورى از خانواده آن [شوهر] و داورى از خانواده آن [زن‌] تعيين كنيد. اگر سرِ سازگارى دارند، خدا ميان آن دو سازگارى خواهد داد. آرى! خدا داناى آگاه است.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@dxxix{و خدا را بپرستيد، و چيزى را با او شريك مگردانيد؛ و به پدر و مادر احسان كنيد؛ و در باره خويشاوندان و يتيمان و مستمندان و همسايه خويش و همسايه بيگانه و همنشين و در راه‌مانده و بردگان خود [نيكى كنيد]، كه خدا كسى را كه متكبر و فخرفروش است دوست نمى‌دارد:\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@dxxx{همان كسانى كه بخل مى‌ورزند، و مردم را به بخل وامى‌دارند، و آنچه را خداوند از فضل خويش بدانها ارزانى داشته پوشيده مى‌دارند. و براى كافران عذابى خواركننده آماده كرده‌ايم.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@dxxxi{و كسانى كه اموالشان را براى نشان‌دادن به مردم انفاق مى‌كنند، و به خدا و روز بازپسين ايمان ندارند. و هر كس شيطان يار او باشد، چه بد همدمى است.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@dxxxii{و اگر به خدا و روز بازپسين ايمان مى‌آوردند، و از آنچه خدا به آنان روزى داده، انفاق مى‌كردند، چه زيانى برايشان داشت؟ و خدا به [كار] آنان داناست.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@dxxxiii{در حقيقت، خدا هم‌وزن ذره‌اى ستم نمى‌كند و اگر [آن ذره، كار] نيكى باشد دو چندانش مى‌كند، و از نزد خويش پاداشى بزرگ مى‌بخشد.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@dxxxiv{پس چگونه است [حالشان‌] آنگاه كه از هر امتى گواهى آوريم، و تو را بر آنان گواه آوريم؟\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@dxxxv{آن روز، كسانى كه كفر ورزيده‌اند، و از پيامبر [خدا] نافرمانى كرده‌اند، آرزو مى‌كنند كه اى كاش با خاك يكسان مى‌شدند. و از خدا هيچ سخنى را پوشيده نمى‌توانند داشت.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@dxxxvi{اى كسانى كه ايمان آورده‌ايد، در حال مستى به نماز نزديك نشويد تا زمانى كه بدانيد چه مى‌گوييد؛ و [نيز] در حال جنابت [وارد نماز نشويد] -مگر اينكه راهگذر باشيد- تا غسل كنيد؛ و اگر بيماريد يا در سفريد يا يكى از شما از قضاى حاجت آمد يا با زنان آميزش كرده‌ايد و آب نيافته‌ايد، پس بر خاكى پاك تيمم كنيد، و صورت و دستهايتان را مسح نماييد، كه خدا بخشنده و آمرزنده است.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@dxxxvii{آيا به كسانى كه بهره‌اى از كتاب يافته‌اند ننگريستى؟ گمراهى را مى‌خرند و مى‌خواهند شما [نيز] گمراه شويد.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@dxxxviii{و خدا به [حال‌] دشمنان شما داناتر است؛ كافى است كه خدا سرپرست [شما] باشد، و كافى است كه خدا ياور [شما] باشد.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@dxxxix{برخى از آنان كه يهودى‌اند، كلمات را از جاهاى خود برمى‌گردانند، و با پيچانيدن زبان خود و به قصد طعنه زدن در دين [اسلام، با درآميختن عبرى به عربى‌] مى‌گويند: «شنيديم و نافرمانى كرديم؛ و بشنو [كه كاش‌] ناشنوا گردى.» و [نيز از روى استهزا مى‌گويند:] «راعنا» [كه در عربى يعنى: به ما التفات كن، ولى در عبرى يعنى: خبيث ما،] و اگر آنان مى‌گفتند: «شنيديم و فرمان برديم، و بشنو و به ما بنگر»، قطعاً براى آنان بهتر و درست‌تر بود، ولى خدا آنان را به علّت كفرشان لعنت كرد، در نتيجه جز [گروهى‌] اندك ايمان نمى‌آورند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@dxl{اى كسانى كه به شما كتاب داده شده است، به آنچه فرو فرستاديم و تصديق‌كننده همان چيزى است كه با شماست ايمان بياوريد، پيش از آنكه چهره‌هايى را محو كنيم و در نتيجه آنها را به قهقرا بازگردانيم؛ يا همچنانكه «اصحاب سبت» را لعنت كرديم؛ آنان را [نيز] لعنت كنيم، و فرمان خدا همواره تحقق يافته است.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@dxli{مسلماً خدا، اين را كه به او شرك ورزيده شود نمى‌بخشايد و غير از آن را براى هر كه بخواهد مى‌بخشايد، و هر كس به خدا شرك ورزد، به يقين گناهى بزرگ بربافته است.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@dxlii{آيا به كسانى كه خويشتن را پاك مى‌شمارند ننگريسته‌اى؟ [چنين نيست،] بلكه خداست كه هر كه را بخواهد پاك مى‌گرداند، و به قدر نخ روى هسته خرمايى ستم نمى‌بينند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@dxliii{ببين چگونه بر خدا دروغ مى‌بندند. و بس است كه اين، يك گناه آشكار باشد.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@dxliv{آيا كسانى را كه از كتاب [آسمانى‌] نصيبى يافته‌اند نديده‌اى؟ كه به «جبت» و «طاغوت» ايمان دارند، و در باره كسانى كه كفر ورزيده‌اند مى‌گويند: «اينان از كسانى كه ايمان آورده‌اند راه‌يافته‌ترند.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@dxlv{اينانند كه خدا لعنتشان كرده، و هر كه را خدا لعنت كند هرگز براى او ياورى نخواهى يافت.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@dxlvi{آيا آنان نصيبى از حكومت دارند؟ [اگر هم داشتند،] به قدر نقطه پشت هسته خرمايى [چيزى‌] به مردم نمى‌دادند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@dxlvii{بلكه به مردم، براى آنچه خدا از فضل خويش به آنان عطا كرده رشك مى‌ورزند؛ در حقيقت، ما به خاندان ابراهيم كتاب و حكمت داديم، و به آنان ملكى بزرگ بخشيديم.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@dxlviii{پس برخى از آنان به وى ايمان آوردند، و برخى از ايشان از او روى برتافتند، و [براى آنان‌] دوزخ پرشراره بس است.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@dxlix{به زودى كسانى را كه به آيات ما كفر ورزيده‌اند، در آتشى [سوزان‌] درآوريم؛ كه هر چه پوستشان بريان گردد، پوستهاى ديگرى بر جايش نهيم تا عذاب را بچشند. آرى، خداوند تواناى حكيم است.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@dl{و به زودى كسانى را كه ايمان آورده و كارهاى شايسته كرده‌اند، در باغهايى كه از زيرِ [درختان‌] آن نهرها روان است درآوريم. براى هميشه در آن جاودانند، و در آنجا همسرانى پاكيزه دارند، و آنان را در سايه‌اى پايدار درآوريم.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@dli{خدا به شما فرمان مى‌دهد كه سپرده‌ها را به صاحبان آنها رد كنيد؛ و چون ميان مردم داورى مى‌كنيد، به عدالت داورى كنيد. در حقيقت، نيكو چيزى است كه خدا شما را به آن پند مى‌دهد. خدا شنواى بيناست.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@dlii{اى كسانى كه ايمان آورده‌ايد، خدا را اطاعت كنيد و پيامبر و اولياى امر خود را [نيز] اطاعت كنيد؛ پس هر گاه در امرى [دينى‌] اختلاف نظر يافتيد، اگر به خدا و روز بازپسين ايمان داريد، آن را به [كتاب‌] خدا و [سنت‌] پيامبر [او] عرضه بداريد، اين بهتر و نيك‌فرجام‌تر است.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@dliii{آيا نديده‌اى كسانى را كه مى‌پندارند به آنچه به سوى تو نازل شده و [به‌] آنچه پيش از تو نازل گرديده، ايمان آورده‌اند [با اين همه‌] مى‌خواهند داورى ميان خود را به سوى طاغوت ببرند، با آنكه قطعاً فرمان يافته‌اند كه بدان كفر ورزند، و[لى‌] شيطان مى‌خواهد آنان را به گمراهى دورى دراندازد.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@dliv{و چون به ايشان گفته شود: «به سوى آنچه خدا نازل كرده و به سوى پيامبر [او] بياييد»، منافقان را مى‌بينى كه از تو سخت، روى برمى‌تابند.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@dlv{پس چگونه، هنگامى كه به [سزاى‌] كار و كردار پيشينشان مصيبتى به آنان مى‌رسد، نزد تو مى‌آيند و به خدا سوگند مى‌خورند كه ما جز نيكويى و موافقت قصدى نداشتيم؟\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@dlvi{اينان همان كسانند كه خدا مى‌داند چه در دل دارند. پس، از آنان روى برتاب، و[لى‌] پندشان ده، و با آنها سخنى رسا كه در دلشان [مؤثّر] افتد، بگوى.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@dlvii{و ما هيچ پيامبرى را نفرستاديم مگر آنكه به توفيق الهى از او اطاعت كنند. و اگر آنان وقتى به خود ستم كرده بودند، پيش تو مى‌آمدند و از خدا آمرزش مى‌خواستند و پيامبر [نيز] براى آنان طلب آمرزش مى‌كرد، قطعاً خدا را توبه‌پذيرِ مهربان مى‌يافتند.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@dlviii{ولى چنين نيست، به پروردگارت قسم كه ايمان نمى‌آورند، مگر آنكه تو را در مورد آنچه ميان آنان مايه اختلاف است داور گردانند؛ سپس از حكمى كه كرده‌اى در دلهايشان احساس ناراحتى [و ترديد] نكنند، و كاملاً سرِ تسليم فرود آورند.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@dlix{و اگر بر آنان مقرر مى‌كرديم كه تن به كشتن دهيد، يا از خانه‌هاى خود به در آييد، جز اندكى از ايشان آن را به كار نمى‌بستند؛ و اگر آنان آنچه را بدان پند داده مى‌شوند به كار مى‌بستند، قطعاً برايشان بهتر و در ثبات قدم ايشان مؤثرتر بود؛\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@dlx{و در آن صورت، [ما هم‌] از نزد خويش، يقيناً پاداشى بزرگ به آنان مى‌داديم؛\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@dlxi{و قطعاً آنان را به راهى راست هدايت مى‌كرديم.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@dlxii{و كسانى كه از خدا و پيامبر اطاعت كنند، در زمره كسانى خواهند بود كه خدا ايشان را گرامى داشته [يعنى‌] با پيامبران و راستان و شهيدان و شايستگانند و آنان چه نيكو همدمانند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@dlxiii{اين تفضّل از جانب خداست، و خدا بس داناست.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@dlxiv{اى كسانى كه ايمان آورده‌ايد، [در برابر دشمن‌] آماده باشيد [=اسلحه خود را برگيريد] و گروه گروه [به جهاد] بيرون رويد يا به طور جمعى روانه شويد.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@dlxv{و قطعاً از ميان شما كسى است كه كندى به خرج دهد؛ پس اگر آسيبى به شما رسد گويد: «راستى خدا بر من نعمت بخشيد كه با آنان حاضر نبودم.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@dlxvi{و اگر غنيمتى از خدا به شما برسد -چنانكه گويى ميان شما و ميان او [رابطه‌] دوستى نبوده- خواهد گفت: «كاش من با آنان بودم و به نواى بزرگى مى‌رسيدم.»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@dlxvii{پس، بايد كسانى كه زندگى دنيا را به آخرت سودا مى‌كنند در راه خدا بجنگند؛ و هر كس در راه خدا بجنگد و كشته يا پيروز شود، به زودى پاداشى بزرگ به او خواهيم داد.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@dlxviii{و چرا شما در راه خدا [و در راه نجات‌] مردان و زنان و كودكان مستضعف نمى‌جنگيد؟ همانان كه مى‌گويند: «پروردگارا، ما را از اين شهرى كه مردمش ستم‌پيشه‌اند بيرون ببر، و از جانب خود براى ما سرپرستى قرار ده، و از نزد خويش ياورى براى ما تعيين فرما.»\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@dlxix{كسانى كه ايمان آورده‌اند، در راه خدا كارزار مى‌كنند. و كسانى كه كافر شده‌اند، در راه طاغوت مى‌جنگند. پس با ياران شيطان بجنگيد كه نيرنگ شيطان [در نهايت‌] ضعيف است.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@dlxx{آيا نديدى كسانى را كه به آنان گفته شد: «[فعلاً] دست [از جنگ‌] بداريد، و نماز را برپا كنيد و زكات بدهيد»، و[لى‌] همين كه كارزار بر آنان مقرر شد، بناگاه گروهى از آنان از مردم [=مشركان مكّه‌] ترسيدند مانند ترس از خدا يا ترسى سخت‌تر. و گفتند: «پروردگارا، چرا بر ما كارزار مقرّر داشتى؟ چرا ما را تا مدتى كوتاه مهلت ندادى؟» بگو: «برخوردارى [از اين‌] دنيا اندك، و براى كسى كه تقوا پيشه كرده، آخرت بهتر است، و [در آنجا] به قدر نخ هسته خرمايى بر شما ستم نخواهد رفت.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@dlxxi{هر كجا باشيد، شما را مرگ درمى‌يابد؛ هر چند در بُرجهاى استوار باشيد. و اگر [پيشامد] خوبى به آنان برسد، مى‌گويند: «اين از جانب خداست»؛ و چون صدمه‌اى به ايشان برسد، مى‌گويند: «اين از طرف توست.» بگو: «همه از جانب خداست.» [آخر ]اين قوم را چه شده است كه نمى‌خواهند سخنى را [درست‌] دريابند؟\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@dlxxii{هر چه از خوبيها به تو مى‌رسد از جانب خداست؛ و آنچه از بدى به تو مى‌رسد از خود توست؛ و تو را به پيامبرى، براى مردم فرستاديم، و گواه بودن خدا بس است.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@dlxxiii{هر كس از پيامبر فرمان بَرد، در حقيقت، خدا را فرمان برده؛ و هر كس رويگردان شود، ما تو را بر ايشان نگهبان نفرستاده‌ايم.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@dlxxiv{و مى‌گويند: فرمانبرداريم، ولى چون از نزد تو بيرون مى‌روند، جمعى از آنان شبانه، جز آنچه تو مى‌گويى تدبير مى‌كنند. و خدا آنچه را كه شبانه در سر مى‌پرورند، مى‌نگارد. پس، از ايشان روى برتاب و بر خدا توكل كن، و خدا بس كارساز است.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@dlxxv{آيا در [معانىِ‌] قرآن نمى‌انديشند؟ اگر از جانب غير خدا بود قطعاً در آن اختلاف بسيارى مى‌يافتند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@dlxxvi{و چون خبرى [حاكى‌] از ايمنى يا وحشت به آنان برسد، انتشارش دهند؛ و اگر آن را به پيامبر و اولياى امر خود ارجاع كنند، قطعاً از ميان آنان كسانى‌اند كه [مى‌توانند درست و نادرست‌] آن را دريابند، و اگر فضل خدا و رحمت او بر شما نبود، مسلماً جز [شمار] اندكى، از شيطان پيروى مى‌كرديد.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@dlxxvii{پس در راه خدا پيكار كن؛ جز عهده‌دار شخص خود نيستى. و[لى‌] مؤمنان را [به مبارزه‌] برانگيز. باشد كه خداوند آسيب كسانى را كه كفر ورزيده‌اند [از آنان‌] باز دارد، و خداست كه قدرتش بيشتر و كيفرش سخت‌تر است.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@dlxxviii{هر كس شفاعت پسنديده كند، براى وى از آن نصيبى خواهد بود و هر كس شفاعت ناپسنديده‌اى كند، براى او از آن [نيز] سهمى خواهد بود. و خدا همواره به هر چيزى تواناست.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@dlxxix{و چون به شما درود گفته شد، شما به [صورتى‌] بهتر از آن درود گوييد، يا همان را [در پاسخ‌] برگردانيد، كه خدا همواره به هر چيزى حسابرس است.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@dlxxx{خداوند كسى است كه هيچ معبودى جز او نيست. به يقين، در روز رستاخيز -كه هيچ شكى در آن نيست- شما را گرد خواهد آورد، و راستگوتر از خدا در سخن كيست؟\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@dlxxxi{شما را چه شده است كه در باره منافقان، دو دسته شده‌ايد؟ با اينكه خدا آنان را به [سزاى‌] آنچه انجام داده‌اند سرنگون كرده است. آيا مى‌خواهيد كسى را كه خدا در گمراهى‌اش وانهاده است به راه آوريد؟ و حال آنكه هر كه را خدا در گمراهى‌اش وانهد هرگز راهى براى [هدايت‌] او نخواهى يافت.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@dlxxxii{همان گونه كه خودشان كافر شده‌اند، آرزو دارند [كه شما نيز] كافر شويد، تا با هم برابر باشيد. پس زنهار، از ميان ايشان براى خود، دوستانى اختيار مكنيد تا آنكه در راه خدا هجرت كنند. پس اگر روى برتافتند، هر كجا آنان را يافتيد به اسارت بگيريد و بكشيدشان؛ و از ايشان يار و ياورى براى خود مگيريد.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@dlxxxiii{مگر كسانى كه با گروهى كه ميان شما و ميان آنان پيمانى است، پيوند داشته باشند، يا نزد شما بيايند در حالى كه سينه آنان از جنگيدن با شما يا جنگيدن با قوم خود، به تنگ آمده باشد. و اگر خدا مى‌خواست، قطعاً آنان را بر شما چيره مى‌كرد و حتماً با شما مى‌جنگيدند. پس اگر از شما كناره‌گيرى كردند و با شما نجنگيدند و با شما طرح صلح افكندند، [ديگر] خدا براى شما راهى [براى تجاوز] بر آنان قرار نداده است.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@dlxxxiv{به زودى، گروهى ديگر را خواهيد يافت كه مى‌خواهند از شما آسوده خاطر و از قوم خود [نيز] ايمن باشند. هر بار كه به فتنه بازگردانده شوند، سر در آن فرو مى‌برند. پس اگر از شما كناره‌گيرى نكردند و به شما پيشنهاد صلح نكردند و از شما دست برنداشتند، هر كجا آنان را يافتيد به اسارت بگيريد و بكشيدشان. آنانند كه ما براى شما عليه ايشان تسلطى آشكار قرار داده‌ايم.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@dlxxxv{و هيچ مؤمنى را نسزد كه مؤمنى را -جز به اشتباه- بكشد. و هر كس مؤمنى را به اشتباه كشت، بايد بنده مؤمنى را آزاد و به خانواده او خونبها پرداخت كند؛ مگر اينكه آنان گذشت كنند. و اگر [مقتول‌] از گروهى است كه دشمنان شمايند و [خود] وى مؤمن است، [قاتل‌] بايد بنده مؤمنى را آزاد كند [و پرداخت خونبها لازم نيست‌]. و اگر [مقتول‌] از گروهى است كه ميان شما و ميان آنان پيمانى است، بايد به خانواده وى خونبها پرداخت نمايد و بنده مؤمنى را آزاد كند. و هر كس [بنده‌] نيافت، بايد دو ماه پياپى -به عنوان توبه‌اى از جانب خدا- روزه بدارد، و خدا همواره داناى سنجيده‌كار است.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@dlxxxvi{و هر كس عمداً مؤمنى را بكشد، كيفرش دوزخ است كه در آن ماندگار خواهد بود؛ و خدا بر او خشم مى‌گيرد و لعنتش مى‌كند و عذابى بزرگ برايش آماده ساخته است.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@dlxxxvii{اى كسانى كه ايمان آورده‌ايد، چون در راه خدا سفر مى‌كنيد [خوب‌] رسيدگى كنيد و به كسى كه نزد شما [اظهار] اسلام مى‌كند؛ مگوييد: «تو مؤمن نيستى» [تا بدين بهانه‌] متاع زندگى دنيا را بجوييد، چرا كه غنيمتهاى فراوان نزد خداست. قبلا خودتان [نيز] همين گونه بوديد، و خدا بر شما منت نهاد. پس خوب رسيدگى كنيد، كه خدا همواره به آنچه انجام مى‌دهيد آگاه است.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@dlxxxviii{مؤمنان خانه‌نشين كه زيان‌ديده نيستند با آن مجاهدانى كه با مال و جان خود در راه خدا جهاد مى‌كنند يكسان نمى‌باشند. خداوند، كسانى را كه با مال و جان خود جهاد مى‌كنند به درجه‌اى بر خانه‌نشينان مزيت بخشيده، و همه را خدا وعده [پاداش‌] نيكو داده، و[لى‌] مجاهدان را بر خانه‌نشينان به پاداشى بزرگ، برترى بخشيده است؛\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@dlxxxix{[پاداش بزرگى كه‌] به عنوان درجات و آمرزش و رحمتى از جانب او [نصيب آنان مى‌شود]، و خدا آمرزنده مهربان است.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@dxc{كسانى كه بر خويشتن ستمكار بوده‌اند، [وقتى‌] فرشتگان جانشان را مى‌گيرند، مى‌گويند: «در چه [حال‌] بوديد؟» پاسخ مى‌دهند: «ما در زمين از مستضعفان بوديم.» مى‌گويند: «مگر زمين خدا وسيع نبود تا در آن مهاجرت كنيد؟» پس آنان جايگاهشان دوزخ است، و [دوزخ‌] بد سرانجامى است.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@dxci{مگر آن مردان و زنان و كودكان فرودستى كه چاره‌جويى نتوانند و راهى نيابند.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@dxcii{پس آنان [كه فى الجمله عذرى دارند] باشد كه خدا از ايشان درگذرد، كه خدا همواره خطابخش و آمرزنده است.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@dxciii{و هر كه در راه خدا هجرت كند، در زمين اقامتگاه‌هاى فراوان و گشايشها خواهد يافت؛ و هر كس [به قصد] مهاجرت در راه خدا و پيامبر او، از خانه‌اش به درآيد، سپس مرگش دررسد، پاداش او قطعاً بر خداست، و خدا آمرزنده مهربان است.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@dxciv{و چون در زمين سفر كرديد، اگر بيم داشتيد كه آنان كه كفر ورزيده‌اند به شما آزار برسانند، گناهى بر شما نيست كه نماز را كوتاه كنيد، چرا كه كافران پيوسته براى شما دشمنى آشكارند.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@dxcv{و هر گاه در ميان ايشان بودى و برايشان نماز برپا داشتى، پس بايد گروهى از آنان با تو [به نماز] ايستند؛ و بايد جنگ‌افزارهاى خود را برگيرند؛ و چون به سجده رفتند [و نماز را تمام كردند]، بايد پشت سر شما قرار گيرند، و گروه ديگرى كه نماز نكرده‌اند بايد بيايند و با تو نماز گزارند و البته جانب احتياط را فرو نگذارند و جنگ‌افزارهاى خود را برگيرند. [زيرا] كافران آرزو مى‌كنند كه شما از جنگ‌افزارها و ساز و برگ خود غافل شويد تا ناگهان بر شما يورش برند. و اگر از باران در زحمتيد، يا بيماريد، گناهى بر شما نيست كه جنگ افزارهاى خود را بر زمين نهيد، ولى مواظب خود باشيد. بى گمان، خدا براى كافران عذاب خفت‌آورى آماده كرده است.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@dxcvi{و چون نماز را به جاى آورديد، خدا را [در همه حال‌] ايستاده و نشسته و بر پهلوآرميده، ياد كنيد. پس چون آسوده‌خاطر شديد، نماز را [به طور كامل‌] به پا داريد، زيرا نماز بر مؤمنان، در اوقات معين مقرر شده است.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@dxcvii{و در تعقيب گروه [دشمنان‌] سستى نورزيد. اگر شما درد مى‌كشيد، آنان [نيز] همان گونه كه شما درد مى‌كشيد، درد مى‌كشند، و حال آنكه شما چيزهايى از خدا اميد داريد كه آنها اميد ندارند، و خدا همواره داناى سنجيده‌كار است.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@dxcviii{ما اين كتاب را به حق بر تو نازل كرديم، تا ميان مردم به [موجب‌] آنچه خدا به تو آموخته داورى كنى، و زنهار جانبدار خيانتكاران مباش.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@dxcix{و از خدا آمرزش بخواه، كه خدا آمرزنده مهربان است.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@dc{و از كسانى كه به خويشتن خيانت مى‌كنند دفاع مكن، كه خداوند هر كس را كه خيانتگر و گناه‌پيشه باشد دوست ندارد.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@dci{[كارهاى نارواى خود را] از مردم پنهان مى‌دارند، و[لى نمى‌توانند] از خدا پنهان دارند، و چون شبانگاه به چاره‌انديشى مى‌پردازند و سخنانى مى‌گويند كه وى [بدان‌] خشنود نيست، او با آنان است. و خدا به آنچه انجام مى‌دهند همواره احاطه دارد.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@dcii{هان، شما همانان هستيد كه در زندگى دنيا از ايشان جانبدارى كرديد، پس چه كسى روز رستاخيز از آنان در برابر خدا جانبدارى خواهد كرد؟ يا چه كسى حمايتگر [و مدافع‌] آنان تواند بود؟\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@dciii{و هر كس كار بدى كند، يا بر خويشتن ستم ورزد؛ سپس از خدا آمرزش بخواهد، خدا را آمرزنده مهربان خواهد يافت.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@dciv{و هر كس گناهى مرتكب شود، فقط آن را به زيان خود مرتكب شده، و خدا همواره داناى سنجيده‌كار است.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@dcv{و هر كس خطا يا گناهى مرتكب شود؛ سپس آن را به بى‌گناهى نسبت دهد، قطعاً بهتان و گناه آشكارى بر دوش كشيده است.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@dcvi{و اگر فضل خدا و رحمت او بر تو نبود، طايفه‌اى از ايشان آهنگ آن داشتند كه تو را از راه به در كنند، و[لى‌] جز خودشان [كسى‌] را گمراه نمى‌سازند، و هيچ گونه زيانى به تو نمى‌رسانند. و خدا كتاب و حكمت بر تو نازل كرد و آنچه را نمى‌دانستى به تو آموخت، و تفضل خدا بر تو همواره بزرگ بود.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@dcvii{در بسيارى از رازگوييهاى ايشان خيرى نيست، مگر كسى كه [بدين وسيله‌] به صدقه يا كار پسنديده يا سازشى ميان مردم، فرمان دهد. و هر كس براى طلب خشنودى خدا چنين كند، به زودى او را پاداش بزرگى خواهيم داد.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@dcviii{و هر كس، پس از آنكه راه هدايت براى او آشكار شد با پيامبر به مخالفت برخيزد، و [راهى‌] غير راه مؤمنان در پيش گيرد، وى را بدانچه روى خود را بدان سو كرده واگذاريم و به دوزخش كشانيم، و چه بازگشتگاه بدى است.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@dcix{خداوند، اين را كه به او شرك آورده شود، نمى‌آمرزد؛ و فروتر از آن را بر هر كه بخواهد مى‌بخشايد. و هر كس به خدا شرك ورزد، قطعاً دچار گمراهى دور و درازى شده است.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@dcx{[مشركان‌]، به جاى او، جز بتهاى مادينه را [به دعا] نمى‌خوانند، و جز شيطان سركش را نمى‌خوانند.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@dcxi{خدا لعنتش كند، [وقتى كه‌] گفت: «بى‌گمان، از ميان بندگانت نصيبى معين [براى خود] برخواهم گرفت.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@dcxii{و آنان را سخت گمراه و دچار آرزوهاى دور و دراز خواهم كرد، و وادارشان مى‌كنم تا گوشهاى دامها را شكاف دهند، و وادارشان مى‌كنم تا آفريده خدا را دگرگون سازند.» و[لى‌] هر كس به جاى خدا، شيطان را دوست [خدا] گيرد، قطعاً دستخوش زيان آشكارى شده است.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@dcxiii{[آرى،] شيطان به آنان وعده مى‌دهد، و ايشان را در آرزوها مى‌افكند، و جز فريب به آنان وعده نمى‌دهد.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@dcxiv{آنان جايگاهشان جهنم است، و از آن راه گريزى ندارند.\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@dcxv{و كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، به زودى آنان را در بوستانهايى كه از زير [درختان‌] آن، نهرها روان است درآوريم. هميشه در آن جاودانند. وعده خدا راست است و چه كسى در سخن، از خدا راستگوتر است؟\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@dcxvi{[پاداش و كيفر] به دلخواه شما و به دلخواه اهل كتاب نيست؛ هر كس بدى كند، در برابر آن كيفر مى‌بيند، و جز خدا براى خود يار و مددكارى نمى‌يابد.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@dcxvii{و كسانى كه كارهاى شايسته كنند -چه مرد باشند يا آن- در حالى كه مؤمن باشند، آنان داخل بهشت مى‌شوند، و به قدر گودى پشت هسته خرمايى مورد ستم قرار نمى‌گيرند.\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@dcxviii{و دين چه كسى بهتر است از آن كس كه خود را تسليم خدا كرده و نيكوكار است و از آيين ابراهيم حق‌گرا پيروى نموده است؟ و خدا ابراهيم را دوست گرفت.\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@dcxix{و آنچه در آسمانها و آنچه در زمين است از آن خداست، و خدا همواره بر هر چيزى احاطه دارد.\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@dcxx{و در باره زنان، رأى تو را مى‌پرسند. بگو: «خدا در باره آنان به شما فتوا مى‌دهد، و [نيز] در باره آنچه در قرآن بر شما تلاوت مى‌شود: در مورد زنان يتيمى كه حق مقرر آنان را به ايشان نمى‌دهيد و تمايل به ازدواج با آنان داريد، و [در باره‌] كودكان ناتوان و اينكه با يتيمان [چگونه‌] به داد رفتار كنيد [پاسخگر شماست‌].» و هر كار نيكى انجام دهيد، قطعاً خدا به آن داناست.\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@dcxxi{و اگر زنى از شوهر خويش بيم ناسازگارى يا رويگردانى داشته باشد، بر آن دو گناهى نيست كه از راه صلح با يكديگر، به آشتى گرايند؛ كه سازش بهتر است. و[لى‌] بخل [و بى‌گذشت بودن‌]، در نفوس، حضور [و غلبه‌] دارد؛ و اگر نيكى كنيد و پرهيزگارى پيشه نماييد، قطعاً خدا به آنچه انجام مى‌دهيد آگاه است.\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@dcxxii{و شما هرگز نمى‌توانيد ميان زنان عدالت كنيد هر چند [بر عدالت‌] حريص باشيد! پس به يك طرف يكسره تمايل نورزيد تا آن [زن ديگر] را سرگشته [=بلا تكليف‌] رها كنيد. و اگر سازش نماييد و پرهيزگارى كنيد، يقيناً خدا آمرزنده مهربان است.\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@dcxxiii{و اگر آن دو، از يكديگر جدا شوند، خداوند هر يك را از گشايش خود بى‌نياز گرداند، و خدا همواره گشايشگر حكيم است.\qt@no{(130)}}
\qt@newcmd\qurantrans@fa@dcxxiv{و آنچه در آسمانها و آنچه در زمين است، از آنِ خداست. و ما به كسانى كه پيش از شما به آنان كتاب داده شده، و [نيز] به شما سفارش كرديم كه از خدا پروا كنيد. و اگر كفر ورزيد [چه باك؟ كه‌] آنچه در آسمانها و آنچه در زمين است از آنِ خداست، و خدا بى نياز ستوده‌[صفات‌] است.\qt@no{(131)}}
\qt@newcmd\qurantrans@fa@dcxxv{و آنچه در آسمانها و آنچه در زمين است از آنِ خداست، و خدا بس كارساز است.\qt@no{(132)}}
\qt@newcmd\qurantrans@fa@dcxxvi{اى مردم، اگر [خدا] بخواهد، شما را [از ميان‌] مى‌برد و ديگران را [پديد ] مى‌آورد، و خدا بر اين [كار] تواناست.\qt@no{(133)}}
\qt@newcmd\qurantrans@fa@dcxxvii{هر كس پاداش دنيا بخواهد، پاداش دنيا و آخرت نزد خداست، و خدا شنواى بيناست.\qt@no{(134)}}
\qt@newcmd\qurantrans@fa@dcxxviii{اى كسانى كه ايمان آورده‌ايد، پيوسته به عدالت قيام كنيد و براى خدا گواهى دهيد، هر چند به زيان خودتان يا [به زيان‌] پدر و مادر و خويشاوندان [شما] باشد. اگر [يكى از دو طرف دعوا] توانگر يا نيازمند باشد، باز خدا به آن دو [از شما ]سزاوارتر است؛ پس، از پى هوس نرويد كه [درنتيجه از حق‌] عدول كنيد. و اگر به انحراف گراييد يا اعراض نماييد، قطعاً خدا به آنچه انجام مى‌دهيد آگاه است.\qt@no{(135)}}
\qt@newcmd\qurantrans@fa@dcxxix{اى كسانى كه ايمان آورده‌ايد، به خدا و پيامبر او و كتابى كه بر پيامبرش فرو فرستاد، و كتابهايى كه قبلا نازل كرده بگرويد؛ و هر كس به خدا و فرشتگان او و كتابها و پيامبرانش و روز بازپسين كفر ورزد، در حقيقت دچار گمراهى دور و درازى شده است.\qt@no{(136)}}
\qt@newcmd\qurantrans@fa@dcxxx{كسانى كه ايمان آوردند، سپس كافر شدند؛ و باز ايمان آوردند، سپس كافر شدند؛ آنگاه به كفر خود افزودند، قطعاً خدا آنان را نخواهد بخشيد و راهى به ايشان نخواهد نمود.\qt@no{(137)}}
\qt@newcmd\qurantrans@fa@dcxxxi{به منافقان خبر ده كه عذابى دردناك [در پيش‌] خواهند داشت.\qt@no{(138)}}
\qt@newcmd\qurantrans@fa@dcxxxii{همانان كه غير از مؤمنان، كافران را دوستان [خود] مى‌گيرند. آيا سربلندى را نزد آنان مى‌جويند؟ [اين خيالى خام است،] چرا كه عزت، همه از آنِ خداست.\qt@no{(139)}}
\qt@newcmd\qurantrans@fa@dcxxxiii{و البتّه [خدا] در كتاب [قرآن‌] بر شما نازل كرده كه: هر گاه شنيديد آيات خدا مورد انكار و ريشخند قرار مى‌گيرد، با آنان منشينيد تا به سخنى غير از آن درآيند، چرا كه در اين صورت شما هم مثل آنان خواهيد بود. خداوند، منافقان و كافران را همگى در دوزخ گرد خواهد آورد.\qt@no{(140)}}
\qt@newcmd\qurantrans@fa@dcxxxiv{همانان كه مترصّد شمايند؛ پس اگر از جانب خدا به شما فتحى برسد، مى‌گويند: «مگر ما با شما نبوديم؟» و اگر براى كافران نصيبى باشد، مى‌گويند: «مگر ما بر شما تسلّط نداشتيم و شما را از [ورود در جمع ]مؤمنان باز نمى‌داشتيم؟» پس خداوند، روز قيامت ميان شما داورى مى‌كند؛ و خداوند هرگز بر [زيان‌] مؤمنان، براى كافران راه [تسلّطى‌] قرار نداده است.\qt@no{(141)}}
\qt@newcmd\qurantrans@fa@dcxxxv{منافقان، با خدا نيرنگ مى‌كنند، و حال آنكه او با آنان نيرنگ خواهد كرد؛ و چون به نماز ايستند با كسالت برخيزند. با مردم ريا مى‌كنند و خدا را جز اندكى ياد نمى‌كنند.\qt@no{(142)}}
\qt@newcmd\qurantrans@fa@dcxxxvi{ميان آن [دو گروه‌] دو دلند؛ نه با اينانند و نه با آنان. و هر كه را خدا گمراه كند، هرگز راهى براى [نجات‌] او نخواهى يافت.\qt@no{(143)}}
\qt@newcmd\qurantrans@fa@dcxxxvii{اى كسانى كه ايمان آورده‌ايد، به جاى مؤمنان، كافران را به دوستى خود مگيريد. آيا مى‌خواهيد عليه خود حجّتى روشن براى خدا قرار دهيد؟\qt@no{(144)}}
\qt@newcmd\qurantrans@fa@dcxxxviii{آرى، منافقان در فروترين درجات دوزخند، و هرگز براى آنان ياورى نخواهى يافت.\qt@no{(145)}}
\qt@newcmd\qurantrans@fa@dcxxxix{مگر كسانى كه توبه كردند و [عمل خود را] اصلاح نمودند و به خدا تمسّك جُستند و دين خود را براى خدا خالص گردانيدند كه [در نتيجه‌] آنان با مؤمنان خواهند بود، و به زودى خدا مؤمنان را پاداشى بزرگ خواهد بخشيد.\qt@no{(146)}}
\qt@newcmd\qurantrans@fa@dcxl{اگر سپاس بداريد و ايمان آوريد، خدا مى‌خواهد با عذاب شما چه كند؟ و خدا همواره سپاس‌پذير [=حق‌شناس‌] داناست.\qt@no{(147)}}
\qt@newcmd\qurantrans@fa@dcxli{خداوند، بانگ برداشتن به بدزبانى را دوست ندارد، مگر [از] كسى كه بر او ستم رفته باشد، و خدا شنواى داناست.\qt@no{(148)}}
\qt@newcmd\qurantrans@fa@dcxlii{اگر خيرى را آشكار كنيد يا پنهانش داريد، يا از بديى درگذريد، پس خدا درگذرنده تواناست.\qt@no{(149)}}
\qt@newcmd\qurantrans@fa@dcxliii{كسانى كه به خدا و پيامبرانش كفر مى‌ورزند، و مى‌خواهند ميان خدا و پيامبران او جدايى اندازند، و مى‌گويند: «ما به بعضى ايمان داريم و بعضى را انكار مى‌كنيم» و مى‌خواهند ميان اين [دو]، راهى براى خود اختيار كنند،\qt@no{(150)}}
\qt@newcmd\qurantrans@fa@dcxliv{آنان در حقيقت كافرند؛ و ما براى كافران عذابى خفّت‌آور آماده كرده‌ايم.\qt@no{(151)}}
\qt@newcmd\qurantrans@fa@dcxlv{و كسانى كه به خدا و پيامبرانش ايمان آورده و ميان هيچ كدام از آنان فرق نمى‌گذارند، به زودى [خدا] پاداش آنان را عطا مى‌كند، و خدا آمرزنده مهربان است.\qt@no{(152)}}
\qt@newcmd\qurantrans@fa@dcxlvi{اهل كتاب از تو مى‌خواهند كه كتابى از آسمان [يكباره‌] بر آنان فرود آورى. البتّه از موسى بزرگتر از اين را خواستند و گفتند: «خدا را آشكارا به ما بنماى.» پس به سزاى ظلمشان صاعقه آنان را فرو گرفت. سپس، بعد از آنكه دلايل آشكار برايشان آمد، گوساله را [به پرستش‌] گرفتند، و ما از آن هم درگذشتيم و به موسى برهانى روشن عطا كرديم.\qt@no{(153)}}
\qt@newcmd\qurantrans@fa@dcxlvii{و كوه طور را به يادبود پيمان [با] آنان، بالاى سرشان افراشته داشتيم؛ و به آنان گفتيم: «سجده‌كنان از در درآييد» و [نيز] به آنان گفتيم: «در روز شنبه تجاوز مكنيد.» و از ايشان پيمانى استوار گرفتيم.\qt@no{(154)}}
\qt@newcmd\qurantrans@fa@dcxlviii{پس به [سزاى‌] پيمان‌شكنى‌شان، و انكارشان نسبت به آيات خدا، و كشتار ناحق آنان [از] انبيا، و گفتارشان كه: «دلهاى ما در غلاف است» [لعنتشان كرديم‌] بلكه خدا به خاطر كفرشان بر دلهايشان مُهر زده و در نتيجه جز شمارى اندك [از ايشان‌] ايمان نمى‌آورند.\qt@no{(155)}}
\qt@newcmd\qurantrans@fa@dcxlix{و [نيز] به سزاى كفرشان و آن تهمت بزرگى كه به مريم زدند،\qt@no{(156)}}
\qt@newcmd\qurantrans@fa@dcl{و گفته ايشان كه: «ما مسيح، عيسى بن مريم، پيامبر خدا را كشتيم»، و حال آنكه آنان او را نكشتند و مصلوبش نكردند، ليكن امر بر آنان مشتبه شد؛ و كسانى كه در باره او اختلاف كردند، قطعاً در مورد آن دچار شكّ شده‌اند و هيچ علمى بدان ندارند، جز آنكه از گمان پيروى مى‌كنند، و يقيناً او را نكشتند.\qt@no{(157)}}
\qt@newcmd\qurantrans@fa@dcli{بلكه خدا او را به سوى خود بالا برد، و خدا توانا و حكيم است.\qt@no{(158)}}
\qt@newcmd\qurantrans@fa@dclii{و از اهل كتاب، كسى نيست مگر آنكه پيش از مرگ خود حتماً به او ايمان مى‌آورد، و روز قيامت [عيسى نيز] بر آنان شاهد خواهد بود.\qt@no{(159)}}
\qt@newcmd\qurantrans@fa@dcliii{پس به سزاى ستمى كه از يهوديان سر زد و به سبب آنكه [مردم را] بسيار از راه خدا باز داشتند، چيزهاى پاكيزه‌اى را كه بر آنان حلال شده بود حرام گردانيديم؛\qt@no{(160)}}
\qt@newcmd\qurantrans@fa@dcliv{و [به سبب‌] رباگرفتنشان -با آنكه از آن نهى شده بودند- و به ناروا مال مردم خوردنشان، و ما براى كافرانِ آنان عذابى دردناك آماده كرده‌ايم.\qt@no{(161)}}
\qt@newcmd\qurantrans@fa@dclv{ليكن راسخانِ آنان در دانش، و مؤمنان، به آنچه بر تو نازل شده و به آنچه پيش از تو نازل گرديده ايمان دارند و خوشا بر نمازگزاران، و زكات‌دهندگان و ايمان‌آورندگان به خدا و روز بازپسين كه به زودى به آنان پاداشى بزرگ خواهيم داد.\qt@no{(162)}}
\qt@newcmd\qurantrans@fa@dclvi{ما همچنانكه به نوح و پيامبران بعد از او، وحى كرديم، به تو [نيز] وحى كرديم؛ و به ابراهيم و اسماعيل و اسحاق و يعقوب و اسباط و عيسى و ايوب و يونس و هارون و سليمان [نيز] وحى نموديم، و به داوود زبور بخشيديم.\qt@no{(163)}}
\qt@newcmd\qurantrans@fa@dclvii{و پيامبرانى [را فرستاديم‌] كه در حقيقت [ماجراى‌] آنان را قبلاً بر تو حكايت نموديم؛ و پيامبرانى [را نيز برانگيخته‌ايم‌] كه [سرگذشت‌] ايشان را بر تو بازگو نكرده‌ايم. و خدا با موسى آشكارا سخن گفت.\qt@no{(164)}}
\qt@newcmd\qurantrans@fa@dclviii{پيامبرانى كه بشارتگر و هشداردهنده بودند، تا براى مردم، پس از [فرستادن‌] پيامبران، در مقابل خدا [بهانه و] حجّتى نباشد، و خدا توانا و حكيم است.\qt@no{(165)}}
\qt@newcmd\qurantrans@fa@dclix{ليكن خدا به [حقانيّت‌] آنچه بر تو نازل كرده است گواهى مى‌دهد. [او] آن را به علم خويش نازل كرده است؛ و فرشتگان [نيز] گواهى مى‌دهند. و كافى است خدا گواه باشد.\qt@no{(166)}}
\qt@newcmd\qurantrans@fa@dclx{بى‌ترديد، كسانى كه كفر ورزيدند و [مردم را] از راه خدا باز داشتند، به گمراهىِ دور و درازى افتاده‌اند.\qt@no{(167)}}
\qt@newcmd\qurantrans@fa@dclxi{كسانى كه كفر ورزيدند و ستم كردند، خدا بر آن نيست كه آنان را بيامرزد و به راهى هدايت كند،\qt@no{(168)}}
\qt@newcmd\qurantrans@fa@dclxii{مگر راه جهنّم، كه هميشه در آن جاودانند؛ و اين [كار] براى خدا آسان است.\qt@no{(169)}}
\qt@newcmd\qurantrans@fa@dclxiii{اى مردم، آن پيامبر [موعود]، حقيقت را از سوى پروردگارتان براى شما آورده است. پس ايمان بياوريد كه براى شما بهتر است. و اگر كافر شويد [بدانيد كه‌] آنچه در آسمانها و زمين است از آنِ خداست، و خدا داناى حكيم است.\qt@no{(170)}}
\qt@newcmd\qurantrans@fa@dclxiv{اى اهل كتاب، در دين خود غلوّ مكنيد، و در باره خدا جز [سخن‌] درست مگوييد. مسيح، عيسى بن مريم، فقط پيامبر خدا و كلمه اوست كه آن را به سوى مريم افكنده و روحى از جانب اوست. پس به خدا و پيامبرانش ايمان بياوريد و نگوييد [خدا ]سه‌گانه است. باز ايستيد كه براى شما بهتر است. خدا فقط معبودى يگانه است. منزّه از آن است كه براى او فرزندى باشد. آنچه در آسمانها و آنچه در زمين است از آنِ اوست، و خداوند بس كارساز است.\qt@no{(171)}}
\qt@newcmd\qurantrans@fa@dclxv{مسيح از اينكه بنده خدا باشد هرگز ابا نمى‌ورزد، و فرشتگان مقرّب [نيز ابا ندارند]؛ و هر كس از پرستش او امتناع ورزد و بزرگى فروشد، به زودى همه آنان را به سوى خود گرد مى‌آورد.\qt@no{(172)}}
\qt@newcmd\qurantrans@fa@dclxvi{اما كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، پاداششان را به تمام [و كمال‌] خواهد داد، و از فضل خود به ايشان افزونتر مى‌بخشد. و اما كسانى كه امتناع ورزيده و بزرگى فروخته‌اند، آنان را به عذابى دردناك دچار مى‌سازد و در برابر خدا براى خود يار و ياورى نخواهند يافت.\qt@no{(173)}}
\qt@newcmd\qurantrans@fa@dclxvii{اى مردم، در حقيقت براى شما از جانب پروردگارتان برهانى آمده است، و ما به سوى شما نورى تابناك فرو فرستاده‌ايم.\qt@no{(174)}}
\qt@newcmd\qurantrans@fa@dclxviii{و اما كسانى كه به خدا گرويدند و به او تمسّك جستند، به زودى [خدا] آنان را در جوار رحمت و فضلى از جانب خويش درآورد، و ايشان را به سوى خود، به راهى راست هدايت كند.\qt@no{(175)}}
\qt@newcmd\qurantrans@fa@dclxix{از تو [در باره كلاله‌] فتوا مى‌طلبند؛ بگو: «خدا در باره كلاله فتوا مى‌دهد: اگر مردى بميرد و فرزندى نداشته باشد، و خواهرى داشته باشد، نصف ميراث از آن اوست. و آن [مرد نيز] از او ارث مى‌برد، اگر براى او [=خواهر] فرزندى نباشد. پس اگر [ورثه فقط] دو خواهر باشند، دو سوم ميراث براى آن دو است، و اگر [چند] خواهر و برادرند، پس نصيب مرد، مانند نصيب دو زن است. خدا براى شما توضيح مى‌دهد تا مبادا گمراه شويد، و خداوند به هر چيزى داناست.\qt@no{(176)}}
\qt@newcmd\qurantrans@fa@dclxx{\basmalahfa اى كسانى كه ايمان آورده‌ايد، به قراردادها[ى خود] وفا كنيد. براى شما [گوشت‌] چارپايان حلال گرديده، جز آنچه [حكمش‌] بر شما خوانده مى‌شود، در حالى كه نبايد شكار را در حال احرام، حلال بشمريد. خدا هر چه بخواهد فرمان مى‌دهد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@dclxxi{اى كسانى كه ايمان آورده‌ايد، حرمت شعاير خدا، و ماه حرام، و قربانى بى‌نشان، و قربانيهاى گردن‌بنددار، و راهيان بيت الحرام را كه فضل و خشنودى پروردگار خود را مى‌طلبند، نگه داريد. و چون از احرام بيرون آمديد [مى‌توانيد] شكار كنيد، و البتّه نبايد كينه‌توزىِ گروهى كه شما را از مسجد الحرام باز داشتند، شما را به تعدّى وادارد. و در نيكوكارى و پرهيزگارى با يكديگر همكارى كنيد، و در گناه و تعدّى دستيار هم نشويد، و از خدا پروا كنيد كه خدا سخت‌كيفر است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@dclxxii{بر شما حرام شده است: مردار، و خون، و گوشت خوك، و آنچه به نام غير خدا كشته شده باشد، و [حيوان حلال گوشت‌] خفه شده، و به چوب مرده، و از بلندى افتاده، و به ضرب شاخ مرده، و آنچه درنده از آن خورده باشد -مگر آنچه را [كه زنده دريافته و خود] سر ببريد- و [همچنين‌] آنچه براى بتان سربريده شده، و [نيز] قسمت كردن شما [چيزى را] به وسيله تيرهاى قرعه؛ اين [كارها همه‌] نافرمانىِ [خدا]ست. امروز كسانى كه كافر شده‌اند، از [كارشكنى در] دين شما نوميد گرديده‌اند. پس، از ايشان مترسيد و از من بترسيد. امروز دين شما را برايتان كامل و نعمت خود را بر شما تمام گردانيدم، و اسلام را براى شما [به عنوان‌] آيينى برگزيدم. و هر كس دچار گرسنگى شود، بى‌آنكه به گناه متمايل باشد [اگر از آنچه منع شده است بخورد]، بى ترديد، خدا آمرزنده مهربان است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@dclxxiii{از تو مى‌پرسند: چه چيزى براى آنان حلال شده است؟ بگو: «چيزهاى پاكيزه براى شما حلال گرديده و [نيز صيد] حيوانات شكارگر كه شما بعنوان مربيان سگهاى شكارى، از آنچه خدايتان آموخته، به آنها تعليم داده‌ايد [براى شما حلال شده است‌]. پس از آنچه آنها براى شما گرفته و نگاه داشته‌اند بخوريد، و نام خدا را بر آن ببريد، و پرواى خدا بداريد كه خدا زودشمار است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@dclxxiv{امروز چيزهاى پاكيزه براى شما حلال شده، و طعام كسانى كه اهل كتابند براى شما حلال، و طعام شما براى آنان حلال است. و [بر شما حلال است ازدواج با] زنان پاكدامن از مسلمان، و زنان پاكدامن از كسانى كه پيش از شما كتاب [آسمانى‌] به آنان داده شده، به شرط آنكه مَهرهايشان را به ايشان بدهيد، در حالى كه خود پاكدامن باشيد نه زناكار و نه آنكه زنان را در پنهانى دوست خود بگيريد. و هر كس در ايمان خود شكّ كند، قطعاً عملش تباه شده، و در آخرت از زيانكاران است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@dclxxv{اى كسانى كه ايمان آورده‌ايد، چون به [عزم‌] نماز برخيزيد، صورت و دستهايتان را تا آرنج بشوييد؛ و سر و پاهاى خودتان را تا برآمدگى پيشين [هر دو پا] مسح كنيد؛ و اگر جنب‌ايد خود را پاك كنيد [=غسل نماييد]؛ و اگر بيمار يا در سفر بوديد، يا يكى از شما از قضاى حاجت آمد، يا با زنان نزديكى كرده‌ايد و آبى نيافتيد؛ پس با خاك پاك تيمّم كنيد، و از آن به صورت و دستهايتان بكشيد. خدا نمى‌خواهد بر شما تنگ بگيرد، ليكن مى‌خواهد شما را پاك، و نعمتش را بر شما تمام گرداند، باشد كه سپاس [او] بداريد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@dclxxvi{و نعمتى را كه خدا بر شما ارزانى داشته و [نيز] پيمانى را كه شما را به [انجام‌] آن متعهد گردانيده، به ياد آوريد، آنگاه كه گفتيد: «شنيديم و اطاعت كرديم.» و از خدا پروا داريد كه خدا به راز دلها آگاه است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@dclxxvii{اى كسانى كه ايمان آورده‌ايد، براى خدا به داد برخيزيد [و] به عدالت شهادت دهيد، و البته نبايد دشمنى گروهى شما را بر آن دارد كه عدالت نكنيد. عدالت كنيد كه آن به تقوا نزديكتر است، و از خدا پروا داريد، كه خدا به آنچه انجام مى‌دهيد آگاه است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@dclxxviii{خدا كسانى را كه ايمان آورده و كارهاى شايسته كرده‌اند، به آمرزش و پاداشى بزرگ وعده داده است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@dclxxix{و كسانى كه كفر ورزيدند و آيات ما را دروغ انگاشتند، آنان اهل دوزخند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@dclxxx{اى كسانى كه ايمان آورده‌ايد، نعمت خدا را بر خود، ياد كنيد: آنگاه كه قومى آهنگ آن داشتند كه بر شما دست يازند، و [خدا] دستشان را از شما كوتاه داشت. و از خدا پروا داريد، و مؤمنان بايد تنها بر خدا توكل كنند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@dclxxxi{در حقيقت، خدا از فرزندان اسرائيل پيمان گرفت. و از آنان دوازده سركرده برانگيختيم. و خدا فرمود: «من با شما هستم.» اگر نماز برپا داريد و زكات بدهيد و به فرستادگانم ايمان بياوريد و ياريشان كنيد و وام نيكويى به خدا بدهيد، قطعاً گناهانتان را از شما مى‌زدايم، و شما را به باغهايى كه از زير [درختان‌] آن نهرها روان است در مى‌آورم. پس هر كس از شما بعد از اين كفر ورزد، در حقيقت از راه راست گمراه شده است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@dclxxxii{پس به [سزاى‌] پيمان شكستنشان لعنتشان كرديم و دلهايشان را سخت گردانيديم. [به طورى كه‌] كلمات را از مواضع خود تحريف مى‌كنند، و بخشى از آنچه را بدان اندرز داده شده بودند به فراموشى سپردند. و تو همواره بر خيانتى از آنان آگاه مى‌شوى، مگر [شمارى‌] اندك از ايشان [كه خيانتكار نيستند]. پس، از آنان درگذر و چشم پوشى كن كه خدا نيكوكاران را دوست مى‌دارد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@dclxxxiii{و از كسانى كه گفتند: «ما نصرانى هستيم»، از ايشان [نيز] پيمان گرفتيم، و[لى‌] بخشى از آنچه را بدان اندرز داده شده بودند فراموش كردند، و ما [هم‌] تا روز قيامت ميانشان دشمنى و كينه افكنديم، و به زودى خدا آنان را از آنچه مى‌كرده‌اند [و مى‌ساخته‌اند] خبر مى‌دهد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@dclxxxiv{اى اهل كتاب، پيامبر ما به سوى شما آمده است كه بسيارى از چيزهايى از كتاب [آسمانى خود] را كه پوشيده مى‌داشتيد براى شما بيان مى‌كند، و از بسيارى [خطاهاى شما] درمى‌گذرد. قطعاً براى شما از جانب خدا روشنايى و كتابى روشنگر آمده است.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@dclxxxv{خدا هر كه را از خشنودى او پيروى كند، به وسيله آن [كتاب‌] به راه‌هاى سلامت رهنمون مى‌شود، و به توفيق خويش، آنان را از تاريكيها به سوى روشنايى بيرون مى‌برد و به راهى راست هدايتشان مى‌كند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@dclxxxvi{كسانى كه گفتند: «خدا همان مسيح پسر مريم است» مسلماً كافر شده‌اند. بگو: اگر [خدا] اراده كند كه مسيح پسر مريم و مادرش و هر كه را كه در زمين است، جملگى به هلاكت رساند، چه كسى در مقابل خدا اختيارى دارد؟ فرمانروايى آسمانها و زمين و آنچه ميان آن دو است از آن خداست. هر چه بخواهد مى‌آفريند، و خدا بر هر چيزى تواناست.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@dclxxxvii{و يهودان و ترسايان گفتند: «ما پسران خدا و دوستان او هستيم.» بگو: «پس چرا شما را به [كيفر] گناهانتان عذاب مى‌كند؟ عنه،] بلكه شما [هم‌] بشريد از جمله كسانى كه آفريده است. هر كه را بخواهد مى‌آمرزد، و هر كه را بخواهد عذاب مى‌كند، و فرمانروايى آسمانها و زمين و آنچه ميان آن دو مى‌باشد از آن خداست، و بازگشت [همه‌] به سوى اوست.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@dclxxxviii{اى اهل كتاب، پيامبر ما به سوى شما آمده كه در دوران فترت رسولان [حقايق را] براى شما بيان مى‌كند، تا مبادا [روز قيامت‌] بگوييد: «براى ما بشارتگر و هشداردهنده‌اى نيامد.» پس قطعاً براى شما بشارتگر و هشداردهنده‌اى آمده است. و خدا بر هر چيزى تواناست.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@dclxxxix{و [ياد كن‌] زمانى را كه موسى به قوم خود گفت: «اى قوم من، نعمت خدا را بر خود ياد كنيد، آنگاه كه در ميان شما پيامبرانى قرار داد، و شما را پادشاهانى ساخت، و آنچه را كه به هيچ كس از جهانيان نداده بود، به شما داد.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@dcxc{«اى قوم من، به سرزمين مقدسى كه خداوند براى شما مقرر داشته است درآييد، و به عقب بازنگرديد كه زيانكار خواهيد شد.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@dcxci{گفتند: «اى موسى، در آنجا مردمى زورمندند و تا آنان از آنجا بيرون نروند ما هرگز وارد آن نمى‌شويم. پس اگر از آنجا بيرون بروند ما وارد خواهيم شد.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@dcxcii{دو مرد از [زمره‌] كسانى كه [از خدا] مى‌ترسيدند و خدا به آنان نعمت داده بود، گفتند: «از آن دروازه بر ايشان [بتازيد و] وارد شويد؛ كه اگر از آن، درآمديد قطعاً پيروز خواهيد شد، و اگر مؤمنيد، به خدا توكل كنيد.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@dcxciii{گفتند: «اى موسى، تا وقتى آنان در آن [شهر]ند ما هرگز پاى در آن ننهيم. تو و پروردگارت برو[يد] و جنگ كنيد كه ما همين جا مى‌نشينيم.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@dcxciv{[موسى‌] گفت: «پروردگارا! من جز اختيار شخص خود و برادرم را ندارم؛ پس ميان ما و ميان اين قوم نافرمان جدايى بينداز.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@dcxcv{[خدا به موسى‌] فرمود: «[ورود به‌] آن [سرزمين‌] چهل سال بر ايشان حرام شد، [كه‌] در بيابان سرگردان خواهند بود. پس تو بر گروه نافرمانان اندوه مخور.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@dcxcvi{و داستان دو پسر آدم را به درستى بر ايشان بخوان، هنگامى كه [هر يك از آن دو،] قربانيى پيش داشتند. پس، از يكى از آن دو پذيرفته شد و از ديگرى پذيرفته نشد. [قابيل‌] گفت: «حتماً تو را خواهم كشت.» [هابيل‌] گفت: «خدا فقط از تقواپيشگان مى‌پذيرد.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@dcxcvii{«اگر دست خود را به سوى من دراز كنى تا مرا بكشى، من دستم را به سوى تو دراز نمى‌كنم تا تو را بكشم، چرا كه من از خداوند، پروردگار جهانيان مى‌ترسم.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@dcxcviii{«من مى‌خواهم تو با گناه من و گناه خودت [به سوى خدا] بازگردى، و در نتيجه از اهل آتش باشى، و اين است سزاى ستمگران.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@dcxcix{پس نفس [اماره‌]اش او را به قتل برادرش ترغيب كرد، و وى را كشت و از زيانكاران شد.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@dcc{پس، خدا زاغى را برانگيخت كه زمين را مى‌كاويد، تا به او نشان دهد چگونه جسد برادرش را پنهان كند. [قابيل‌] گفت: «واى بر من، آيا عاجزم كه مثل اين زاغ باشم تا جسد برادرم را پنهان كنم؟» پس از [زمره ]پشيمانان گرديد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@dcci{از اين روى بر فرزندان اسرائيل مقرر داشتيم كه هر كس كسى را -جز به قصاص قتل، يا [به كيفر] فسادى در زمين- بكشد، چنان است كه گويى همه مردم را كشته باشد. و هر كس كسى را زنده بدارد، چنان است كه گويى تمام مردم را زنده داشته است. و قطعاً پيامبران ما دلايل آشكار براى آنان آوردند، [با اين همه‌] پس از آن بسيارى از ايشان در زمين زياده‌روى مى‌كنند.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@dccii{سزاى كسانى كه با [دوستداران‌] خدا و پيامبر او مى‌جنگند و در زمين به فساد مى‌كوشند، جز اين نيست كه كشته شوند يا بر دار آويخته گردند يا دست و پايشان در خلاف جهت يكديگر بريده شود يا از آن سرزمين تبعيد گردند. اين، رسوايى آنان در دنياست و در آخرت عذابى بزرگ خواهند داشت.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@dcciii{مگر كسانى كه پيش از آنكه بر ايشان دست يابيد، توبه كرده باشند. پس بدانيد كه خدا آمرزنده مهربان است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@dcciv{اى كسانى كه ايمان آورده‌ايد، از خدا پروا كنيد؛ و به او [توسل و] تقرب جوييد؛ و در راهش جهاد كنيد، باشد كه رستگار شويد.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@dccv{در حقيقت، كسانى كه كفر ورزيدند، اگر تمام آنچه در زمين است براى آنان باشد، و مثل آن را [نيز] با آن [داشته باشند] تا به وسيله آن، خود را از عذاب روز قيامت بازخرند، از ايشان پذيرفته نمى‌شود و عذابى پر درد خواهند داشت.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@dccvi{مى‌خواهند كه از آتش بيرون آيند، در حالى كه از آن بيرون آمدنى نيستند، و براى آنان عذابى پايدار خواهد بود.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@dccvii{و مرد و زن دزد را به سزاى آنچه كرده‌اند، دستشان را به عنوان كيفرى از جانب خدا ببريد، و خداوند توانا و حكيم است.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@dccviii{پس هر كه بعد از ستم‌كردنش توبه كند و به صلاح آيد، خدا توبه او را مى‌پذيرد، كه خدا آمرزنده مهربان است.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@dccix{مگر ندانسته‌اى كه فرمانروايى آسمانها و زمين از آنِ خداست. هر كه را بخواهد عذاب مى‌كند و هر كه را بخواهد مى‌بخشد، و خدا بر هر چيزى تواناست؟\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@dccx{اى پيامبر، كسانى كه در كفر شتاب مى‌ورزند، تو را غمگين نسازند؛ [چه‌] از آنانكه با زبان خود گفتند: «ايمان آورديم»، و حال آنكه دلهايشان ايمان نياورده بود، و [چه‌] از يهوديان: [آنان‌] كه [به سخنان تو] گوش مى‌سپارند [تا بهانه‌اى ]براى تكذيب [تو بيابند]، و براى گروهى ديگر كه [خود] نزد تو نيامده‌اند، خبرچينى [=جاسوسى‌] مى‌كنند، كلمات را از جاهاى خود دگرگون مى‌كنند [و] مى‌گويند: «اگر اين [حكم‌] به شما داده شد، آن را بپذيريد، و اگر آن به شما داده نشد، پس دورى كنيد.» و هر كه را خدا بخواهد به فتنه درافكند، هرگز در برابر خدا براى او از دست تو چيزى بر نمى‌آيد. اينانند كه خدا نخواسته دلهايشان را پاك گرداند. در دنيا براى آنان رسوايى، و در آخرت عذابى بزرگ خواهد بود.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@dccxi{پذيرا و شنواى دروغ هستند [و] بسيار مال حرام مى‌خورند. پس اگر نزد تو آمدند، [يا] ميان آنان داورى كن، يا از ايشان روى برتاب. و اگر از آنان روى برتابى هرگز زيانى به تو نخواهند رسانيد. و اگر داورى مى‌كنى، پس به عدالت در ميانشان حكم كن كه خداوند دادگران را دوست مى‌دارد.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@dccxii{و چگونه تو را داور قرار مى‌دهند، با آنكه تورات نزد آنان است كه در آن حكم خدا [آمده‌] است؟ سپس آنان بعد از اين [طلب داورى‌] پشت مى‌كنند، و [واقعاً] آنان مؤمن نيستند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@dccxiii{ما تورات را كه در آن رهنمود و روشنايى بود نازل كرديم. پيامبرانى كه تسليم [فرمان خدا] بودند، به موجب آن براى يهود داورى مى‌كردند؛ و [همچنين‌] الهيّون و دانشمندان به سبب آنچه از كتاب خدا به آنان سپرده شده و بر آن گواه بودند. پس، از مردم نترسيد و از من بترسيد، و آيات مرا به بهاى ناچيزى مفروشيد؛ و كسانى كه به موجب آنچه خدا نازل كرده داورى نكرده‌اند، آنان خود كافرانند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@dccxiv{و در [تورات‌] بر آنان مقرر كرديم كه جان در مقابل جان، و چشم در برابر چشم، و بينى در برابر بينى، و گوش در برابر گوش، و دندان در برابر دندان مى‌باشد؛ و زخمها [نيز به همان ترتيب‌] قصاصى دارند. و هر كه از آن [قصاص‌]درگذرد، پس آن، كفاره [گناهان‌] او خواهد بود. و كسانى كه به موجب آنچه خدا نازل كرده داورى نكرده‌اند، آنان خود ستمگرانند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@dccxv{و عيسى پسر مريم را به دنبال آنان [=پيامبران ديگر] درآورديم، در حالى كه تورات را كه پيش از او بود تصديق داشت، و به او انجيل را عطا كرديم كه در آن، هدايت و نورى است و تصديق‌كننده توراتِ قبل از آن است، و براى پرهيزگاران رهنمود و اندرزى است.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@dccxvi{و اهل انجيل بايد به آنچه خدا در آن نازل كرده داورى كنند، و كسانى كه به آنچه خدا نازل كرده حكم نكنند، آنان خود، نافرمانند.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@dccxvii{و ما اين كتاب [=قرآن‌] را به حق به سوى تو فرو فرستاديم، در حالى كه تصديق‌كننده كتابهاى پيشين و حاكم بر آنهاست. پس ميان آنان بر وفق آنچه خدا نازل كرده حكم كن، و از هواهايشان [با دور شدن‌] از حقى كه به سوى تو آمده، پيروى مكن. براى هر يك از شما [امتها] شريعت و راه روشنى قرار داده‌ايم. و اگر خدا مى‌خواست شما را يك امت قرار مى‌داد، ولى [خواست‌] تا شما را در آنچه به شما داده است بيازمايد. پس در كارهاى نيك بر يكديگر سبقت گيريد. بازگشت [همه‌] شما به سوى خداست؛ آنگاه در باره آنچه در آن اختلاف مى‌كرديد آگاهتان خواهد كرد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@dccxviii{و ميان آنان به موجب آنچه خدا نازل كرده، داورى كن و از هواهايشان پيروى مكن و از آنان برحذر باش؛ مبادا تو را در بخشى از آنچه خدا بر تو نازل كرده به فتنه دراندازند. پس اگر پشت كردند، بدان كه خدا مى‌خواهد آنان را فقط به [سزاى‌] پاره‌اى از گناهانشان برساند، و در حقيقت بسيارى از مردم نافرمانند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@dccxix{آيا خواستار حكم جاهليت‌اند؟ و براى مردمى كه يقين دارند، داورى چه كسى از خدا بهتر است؟\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@dccxx{اى كسانى كه ايمان آورده‌ايد، يهود و نصارى را دوستان [خود] مگيريد [كه‌] بعضى از آنان دوستان بعضى ديگرند. و هر كس از شما آنها را به دوستى گيرد، از آنان خواهد بود. آرى، خدا گروه ستمگران را راه نمى‌نمايد.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@dccxxi{مى‌بينى كسانى كه در دلهايشان بيمارى است، در [دوستى‌] با آنان شتاب مى‌ورزند. مى‌گويند: «مى‌ترسيم به ما حادثه ناگوارى برسد.» اميد است خدا از جانب خود فتح [منظور] يا امر ديگرى را پيش آورد، تا [در نتيجه آنان‌] از آنچه در دل خود نهفته داشته‌اند پشيمان گردند.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@dccxxii{و كسانى كه ايمان آورده‌اند، مى‌گويند: «آيا اينان بودند كه به خداوند سوگندهاى سخت مى‌خوردند كه جداً با شما هستند؟» اعمالشان تباه شد و زيانكار گرديدند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@dccxxiii{اى كسانى كه ايمان آورده‌ايد، هر كس از شما از دين خود برگردد، به زودى خدا گروهى [ديگر] را مى‌آورد كه آنان را دوست مى‌دارد و آنان [نيز] او را دوست دارند. [اينان‌] با مؤمنان، فروتن، [و] بر كافران سرفرازند. در راه خدا جهاد مى‌كنند و از سرزنش هيچ ملامتگرى نمى‌ترسند. اين فضل خداست. آن را به هر كه بخواهد مى‌دهد، و خدا گشايشگر داناست.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@dccxxiv{ولىّ شما، تنها خدا و پيامبر اوست و كسانى كه ايمان آورده‌اند: همان كسانى كه نماز برپا مى‌دارند و در حال ركوع زكات مى‌دهند.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@dccxxv{و هر كس خدا و پيامبر او و كسانى را كه ايمان آورده‌اند ولىّ خود بداند [پيروز است، چرا كه‌] حزب خدا همان پيروزمندانند.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@dccxxvi{اى كسانى كه ايمان آورده‌ايد، كسانى را كه دين شما را به ريشخند و بازى گرفته‌اند [چه‌] از كسانى كه پيش از شما به آنان كتاب داده شده و [چه از] كافران، دوستان [خود] مگيريد، و اگر ايمان داريد از خدا پروا داريد.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@dccxxvii{و هنگامى كه [به وسيله اذان، مردم را] به نماز مى‌خوانيد، آن را به مسخره و بازى مى‌گيرند، زيرا آنان مردمى‌اند كه نمى‌انديشند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@dccxxviii{بگو: «اى اهل كتاب، آيا جز اين بر ما عيب مى‌گيريد كه ما به خدا و به آنچه به سوى ما نازل شده، و به آنچه پيش از اين فرود آمده است ايمان آورده‌ايم، و اينكه بيشتر شما فاسقيد؟»\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@dccxxix{بگو: «آيا شما را به بدتر از [صاحبان‌] اين كيفر در پيشگاه خدا، خبر دهم؟ همانان كه خدا لعنتشان كرده و بر آنان خشم گرفته و از آنان بوزينگان و خوكان پديد آورده، و آنانكه طاغوت را پرستش كرده‌اند. اينانند كه از نظر منزلت، بدتر، و از راه راست گمراه‌ترند.»\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@dccxxx{و چون نزد شما مى‌آيند، مى‌گويند: «ايمان آورديم.» در حالى كه با كفر وارد شده و قطعاً با همان [كفر] بيرون رفته‌اند. و خدا به آنچه پنهان مى‌داشتند داناتر است.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@dccxxxi{و بسيارى از آنان را مى‌بينى كه در گناه و تعدّى و حرامخوارى خود شتاب مى‌كنند. واقعاً چه اعمال بدى انجام مى‌دادند.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@dccxxxii{چرا الهيّون و دانشمندان، آنان را از گفتار گناه‌[آلود] و حرامخوارگى‌شان باز نمى‌دارند؟ راستى چه بد است آنچه انجام مى‌دادند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@dccxxxiii{و يهود گفتند: «دست خدا بسته است.» دستهاى خودشان بسته باد. و به [سزاى ] آنچه گفتند، از رحمت خدا دور شوند. بلكه هر دو دست او گشاده است، هر گونه بخواهد مى‌بخشد. و قطعاً آنچه از جانب پروردگارت به سوى تو فرود آمده، بر طغيان و كفر بسيارى از ايشان خواهد افزود، و تا روز قيامت ميانشان دشمنى و كينه افكنديم. هر بار كه آتشى براى پيكار برافروختند، خدا آن را خاموش ساخت. و در زمين براى فساد مى‌كوشند. و خدا مفسدان را دوست نمى‌دارد.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@dccxxxiv{و اگر اهل كتاب ايمان آورده و پرهيزگارى كرده بودند، قطعاً گناهانشان را مى‌زدوديم و آنان را به بوستانهاى پر نعمت درمى‌آورديم.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@dccxxxv{و اگر آنان به تورات و انجيل و آنچه از جانب پروردگارشان به سويشان نازل شده است، عمل مى‌كردند، قطعاً از بالاى سرشان [بركات آسمانى‌] و از زير پاهايشان [بركات زمينى‌] برخوردار مى‌شدند. از ميان آنان گروهى ميانه‌رو هستند، و بسيارى از ايشان بد رفتار مى‌كنند.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@dccxxxvi{اى پيامبر، آنچه از جانب پروردگارت به سوى تو نازل شده، ابلاغ كن؛ و اگر نكنى پيامش را نرسانده‌اى. و خدا تو را از [گزند] مردم نگاه مى‌دارد. آرى، خدا گروه كافران را هدايت نمى‌كند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@dccxxxvii{بگو: «اى اهل كتاب، تا [هنگامى كه‌] به تورات و انجيل و آنچه از پروردگارتان به سوى شما نازل شده است عمل نكرده‌ايد بر هيچ [آيين بر حقى‌] نيستيد.» و قطعاً آنچه از جانب پروردگارت به سوى تو نازل شده، بر طغيان و كفر بسيارى از آنان خواهد افزود. پس بر گروه كافران اندوه مخور.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@dccxxxviii{كسانى كه ايمان آورده و كسانى كه يهودى و صابئى و مسيحى‌اند، هر كس به خدا و روز بازپسين ايمان آورد و كار نيكو كند، پس نه بيمى بر ايشان است و نه اندوهگين خواهند شد.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@dccxxxix{ما از فرزندان اسرائيل سخت پيمان گرفتيم، و به سويشان پيامبرانى روانه كرديم. هر بار پيامبرى چيزى بر خلاف دلخواهشان برايشان آورد، گروهى را تكذيب مى‌كردند و گروهى را مى‌كشتند.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@dccxl{و پنداشتند كيفرى در كار نيست. پس كور و كر شدند. سپس خدا توبه آنان را پذيرفت. باز بسيارى از ايشان كور و كر شدند، و خدا به آنچه انجام مى‌دهند بيناست.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@dccxli{كسانى كه گفتند: «خدا همان مسيح پسر مريم است»، قطعاً كافر شده‌اند، و حال آنكه مسيح، مى‌گفت: «اى فرزندان اسرائيل، پروردگار من و پروردگار خودتان را بپرستيد؛ كه هر كس به خدا شرك آورد، قطعاً خدا بهشت را بر او حرام ساخته و جايگاهش آتش است، و براى ستمكاران ياورانى نيست.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@dccxlii{كسانى كه [به تثليث قائل شده و] گفتند: «خدا سومين [شخص از] سه [شخص يا سه اقنوم‌] است، قطعاً كافر شده‌اند، و حال آنكه هيچ معبودى جز خداى يكتا نيست. و اگر از آنچه مى‌گويند باز نايستند، به كافران ايشان عذابى دردناك خواهد رسيد.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@dccxliii{چرا به درگاه خدا توبه نمى‌كنند، و از وى آمرزش نمى‌خواهند؟ و خدا آمرزنده مهربان است.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@dccxliv{مسيح، پسر مريم جز پيامبرى نبود كه پيش از او [نيز] پيامبرانى آمده بودند؛ و مادرش زنى بسيار راستگو بود. هر دو غذا مى‌خوردند. بنگر چگونه آيات [خود] را براى آنان توضيح مى‌دهيم؛ سپس ببين چگونه [از حقيقت‌] دور مى‌افتند.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@dccxlv{بگو: «آيا غير از خدا چيزى را كه اختيار زيان و سود شما را ندارد، مى‌پرستيد؟ و حال آنكه خداوند شنواى داناست.»\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@dccxlvi{بگو: «اى اهل كتاب، در دين خود بناحق گزافه‌گويى نكنيد، و از پى هوسهاى گروهى كه پيش از اين گمراه گشتند و بسيارى [از مردم‌] را گمراه كردند و [خود] از راه راست منحرف شدند، نرويد.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@dccxlvii{از ميان فرزندان اسرائيل، آنان كه كفر ورزيدند، به زبان داوود و عيسى بن مريم مورد لعنت قرار گرفتند. اين [كيفر] به خاطر آن بود كه عصيان ورزيده و [از فرمان خدا] تجاوز مى‌كردند.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@dccxlviii{[و] از كار زشتى كه آن را مرتكب مى‌شدند، يكديگر را بازنمى‌داشتند. راستى، چه بد بود آنچه مى‌كردند.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@dccxlix{بسيارى از آنان را مى‌بينى كه با كسانى كه كفر ورزيده‌اند دوستى مى‌كنند. راستى چه زشت است آنچه براى خود پيش فرستادند كه [در نتيجه‌] خدا بر ايشان خشم گرفت، و پيوسته در عذاب مى‌مانند.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@dccl{و اگر به خدا و پيامبر و آنچه كه به سوى او فرود آمده ايمان مى‌آوردند، آنان را به دوستى نمى‌گرفتند، ليكن بسيارى از ايشان نافرمانند.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@dccli{مسلماً يهوديان و كسانى را كه شرك ورزيده‌اند، دشمن‌ترين مردم نسبت به مؤمنان خواهى يافت؛ و قطعاً كسانى را كه گفتند: «ما نصرانى هستيم»، نزديكترين مردم در دوستى با مؤمنان خواهى يافت، زيرا برخى از آنان دانشمندان و رهبانانى‌اند كه تكبّر نمى‌ورزند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@dcclii{و چون آنچه را به سوى اين پيامبر نازل شده، بشنوند، مى‌بينى بر اثر آن حقيقتى كه شناخته‌اند، اشك از چشمهايشان سرازير مى‌شود. مى‌گويند: پروردگارا، ما ايمان آورده‌ايم؛ پس ما را در زمره گواهان بنويس.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@dccliii{و براى ما چه [عذرى‌] است كه به خدا و آنچه از حق به ما رسيده، ايمان نياوريم و حال آنكه چشم داريم كه پروردگارمان ما را با گروه شايستگان [به بهشت‌] درآورد؟\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@dccliv{پس به پاس آنچه گفتند، خدا به آنان باغهايى پاداش داد كه از زير [درختان‌] آن نهرها جارى است. در آن جاودانه مى‌مانند، و اين پاداش نيكوكاران است.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@dcclv{و كسانى كه كفر ورزيدند و آيات ما را دروغ پنداشتند، آنان همدم آتشند.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@dcclvi{اى كسانى كه ايمان آورده‌ايد، چيزهاى پاكيزه‌اى را كه خدا براى [استفاده‌] شما حلال كرده، حرام مشماريد و از حدّ مگذريد، كه خدا از حدگذرندگان را دوست نمى‌دارد.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@dcclvii{و از آنچه خداوند روزىِ شما گردانيده، حلال و پاكيزه را بخوريد، و از آن خدايى كه بدو ايمان داريد پروا داريد.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@dcclviii{خدا شما را به سوگندهاى بيهوده‌تان مؤاخذه نمى‌كند، ولى به سوگندهايى كه [از روى اراده‌] مى‌خوريد [و مى‌شكنيد] شما را مؤاخذه مى‌كند. و كفاره‌اش خوراك دادن به ده بينواست -از غذاهاى متوسطى كه به كسان خود مى‌خورانيد- يا پوشانيدن آنان يا آزاد كردن بنده‌اى. و كسى كه [هيچ يك از اينها را] نيابد [بايد] سه روز روزه بدارد. اين است كفاره سوگندهاى شما وقتى كه سوگند خورديد. و سوگندهاى خود را پاس داريد. اين گونه خداوند آيات خود را براى شما بيان مى‌كند، باشد كه سپاسگزارى كنيد.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@dcclix{اى كسانى كه ايمان آورده‌ايد، شراب و قمار و بتها و تيرهاى قرعه پليدند [و] از عمل شيطانند. پس، از آنها دورى گزينيد، باشد كه رستگار شويد.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@dcclx{همانا شيطان مى‌خواهد با شراب و قمار، ميان شما دشمنى و كينه ايجاد كند، و شما را از ياد خدا و از نماز باز دارد. پس آيا شما دست برمى‌داريد؟\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@dcclxi{و اطاعت خدا و اطاعت پيامبر كنيد و [از گناهان‌] برحذر باشيد، پس اگر روى گردانديد، بدانيد كه بر عهده پيامبر ما، فقط رساندن [پيام‌] آشكار است.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@dcclxii{بر كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، گناهى در آنچه [قبلاً] خورده‌اند نيست، در صورتى كه تقوا پيشه كنند و ايمان بياورند و كارهاى شايسته كنند؛ سپس تقوا پيشه كنند و ايمان بياورند؛ آنگاه تقوا پيشه كنند و احسان نمايند، و خدا نيكوكاران را دوست مى‌دارد.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@dcclxiii{اى كسانى كه ايمان آورده‌ايد، خدا شما را به چيزى از شكار كه در دسترس شما و نيزه‌هاى شما باشد خواهد آزمود، تا معلوم دارد چه كسى در نهان از او مى‌ترسد. پس هر كس بعد از آن تجاوز كند، براى او عذابى دردناك خواهد بود.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@dcclxiv{اى كسانى كه ايمان آورده‌ايد، در حالى كه محرميد شكار را مكشيد، و هر كس از شما عمداً آن را بكشد، بايد نظير آنچه كشته است از چهارپايان كفاره‌اى بدهد، كه [نظير بودنِ‌] آن را دو تن عادل از ميان شما تصديق كنند، و به صورت قربانى به كعبه برسد. يا به كفاره [آن‌] مستمندان را خوراك بدهد، يا معادلش روزه بگيرد، تا سزاى زشتكارى خود را بچشد. خداوند از آنچه در گذشته واقع شده عفو كرده است، و[لى‌] هر كس تكرار كند خدا از او انتقام مى‌گيرد، و خداوند، توانا و صاحب‌انتقام است.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@dcclxv{صيد دريا و مأكولات آن براى شما حلال شده است تا براى شما و مسافران بهره‌اى باشد، و[لى‌] صيد بيابان -مادام كه محرم مى‌باشيد- بر شما حرام گرديده است. و از خدايى كه نزد او محشور مى‌شويد پروا داريد.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@dcclxvi{خداوند [زيارت‌] كعبه بيت الحرام را وسيله به پا داشتن [مصالح‌] مردم قرار داده، و ماه حرام و قربانيهاى بى‌نشان و قربانيهاى نشاندار را [نيز به همين منظور مقرّر فرموده است‌]، اين [جمله‌] براى آن است تا بدانيد كه خدا آنچه را در آسمانها و آنچه را در زمين است مى‌داند، و خداست كه بر هر چيزى داناست.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@dcclxvii{بدانيد كه خدا سخت‌كيفر است، و [بدانيد] كه خدا آمرزنده مهربان است.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@dcclxviii{بر پيامبر [خدا، وظيفه‌اى‌] جز ابلاغ [رسالت‌] نيست، و خداوند آنچه را آشكار و آنچه را پوشيده مى‌داريد مى‌داند.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@dcclxix{بگو: «پليد و پاك يكسان نيستند، هر چند كثرت پليد[ها] تو را به شگفت آورد. پس اى خردمندان، از خدا پروا كنيد، باشد كه رستگار شويد.»\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@dcclxx{اى كسانى كه ايمان آورده‌ايد، از چيزهايى كه اگر براى شما آشكار گردد شما را اندوهناك مى‌كند مپرسيد. و اگر هنگامى كه قرآن نازل مى‌شود، در باره آنها سؤال كنيد، براى شما روشن مى‌شود. خدا از آن [پرسشهاى بيجا] گذشت، و خداوند آمرزنده بردبار است.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@dcclxxi{گروهى پيش از شما [نيز] از اين [گونه‌] پرسشها كردند؛ آنگاه به سبب آن كافر شدند.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@dcclxxii{خدا [چيزهاى ممنوعى از قبيل:] بحيره و سائبه و وصيله و حام قرار نداده است. ولى كسانى كه كفر ورزيدند، بر خدا دروغ مى‌بندند و بيشترشان تعقل نمى‌كنند.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@dcclxxiii{و چون به آنان گفته شود: «به سوى آنچه خدا نازل كرده و به سوى پيامبر[ش‌] بياييد»، مى‌گويند: «آنچه پدران خود را بر آن يافته‌ايم ما را بس است.» آيا هر چند پدرانشان چيزى نمى‌دانسته و هدايت نيافته بودند؟\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@dcclxxiv{اى كسانى كه ايمان آورده‌ايد، به خودتان بپردازيد. هر گاه شما هدايت يافتيد، آن كس كه گمراه شده است به شما زيانى نمى‌رساند. بازگشت همه شما به سوى خداست. پس شما را از آنچه انجام مى‌داديد، آگاه خواهد كرد.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@dcclxxv{اى كسانى كه ايمان آورده‌ايد، هنگامى كه يكى از شما را [نشانه‌هاى‌] مرگ دررسيد، بايد از ميان خود دو عادل را در موقع وصيّت، به شهادت ميان خود فرا خوانيد؛ يا اگر در سفر بوديد و مصيبت مرگ، شما را فرا رسيد [و شاهد مسلمان نبود] دو تن از غير [همكيشان‌] خود را [به شهادت بطلبيد]. و اگر [در صداقت آنان‌] شك كرديد، پس از نماز، آن دو را نگاه مى‌داريد؛ پس به خدا سوگند ياد مى‌كنند كه ما اين [حق‌] را به هيچ قيمتى نمى‌فروشيم هر چند [پاى‌] خويشاوند [در كار] باشد، و شهادت الهى را كتمان نمى‌كنيم، كه [اگر كتمان حق كنيم‌] در اين صورت از گناهكاران خواهيم بود.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@dcclxxvi{و اگر معلوم شد كه آن دو دستخوش گناه شده‌اند، دو تن ديگر از كسانى كه بر آنان ستم رفته است، و هر دو [به ميت‌] نزديكترند، به جاى آن دو [شاهد قبلى‌] قيام كنند؛ پس به خدا سوگند ياد مى‌كنند كه: گواهى ما قطعاً از گواهى آن دو درست‌تر است، و [از حق‌] تجاوز نكرده‌ايم، چرا كه [اگر چنين كنيم‌] از ستمكاران خواهيم بود.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@dcclxxvii{اين [روش‌] براى اينكه شهادت را به صورت درست ادا كنند، يا بترسند كه بعد از سوگندخوردنشان، سوگندهايى [به وارثان ميت‌] برگردانده شود، [به صواب‌] نزديكتر است. و از خدا پروا داريد، و [اين پندها را] بشنويد، و خدا گروه فاسقان را هدايت نمى‌كند.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@dcclxxviii{[ياد كن‌] روزى را كه خدا پيامبران را گرد مى‌آورد؛ پس مى‌فرمايد: «چه پاسخى به شما داده شد؟» مى‌گويند: «ما را هيچ دانشى نيست. تويى كه داناى رازهاى نهانى.»\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@dcclxxix{[ياد كن‌] هنگامى را كه خدا فرمود: «اى عيسى پسر مريم، نعمت مرا بر خود و بر مادرت به ياد آور، آنگاه كه تو را به روح‌القدس تأييد كردم كه در گهواره [به اعجاز] و در ميانسالى [به وحى‌] با مردم سخن گفتى؛ و آنگاه كه تو را كتاب و حكمت و تورات و انجيل آموختم؛ و آنگاه كه به اذن من، از گِل، [چيزى‌] به شكل پرنده مى‌ساختى، پس در آن مى‌دميدى، و به اذن من پرنده‌اى مى‌شد، و كور مادرزاد و پيس را به اذن من شفا مى‌دادى؛ و آنگاه كه مردگان را به اذن من [زنده از قبر] بيرون مى‌آوردى؛ و آنگاه كه [آسيب‌] بنى‌اسرائيل را -هنگامى كه براى آنان حجتهاى آشكار آورده بودى- از تو باز داشتم. پس كسانى از آنان كه كافر شده بودند گفتند: اين‌[ها چيزى‌] جز افسونى آشكار نيست.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@dcclxxx{و [ياد كن‌] هنگامى را كه به حواريّون وحى كردم كه به من و فرستاده‌ام ايمان آوريد. گفتند: «ايمان آورديم، و گواه باش كه ما مسلمانيم.»\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@dcclxxxi{و [ياد كن‌] هنگامى را كه حواريّون گفتند: «اى عيسى پسر مريم، آيا پروردگارت مى‌تواند از آسمان، خوانى براى ما فرود آورد؟» [عيسى‌] گفت: «اگر ايمان داريد از خدا پروا داريد.»\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@dcclxxxii{گفتند: «مى‌خواهيم از آن بخوريم، و دلهاى ما آرامش يابد، و بدانيم كه به ما راست گفته‌اى، و بر آن از گواهان باشيم.»\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@dcclxxxiii{عيسى پسر مريم گفت: «بار الها، پروردگارا، از آسمان، خوانى بر ما فرو فرست تا عيدى براى اول و آخر ما باشد و نشانه‌اى از جانب تو. و ما را روزى ده كه تو بهترين روزى‌دهندگانى.»\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@dcclxxxiv{خدا فرمود: «من آن را بر شما فرو خواهم فرستاد، و[لى‌] هر كس از شما پس از آن انكار ورزد، وى را [چنان‌] عذابى كنم كه هيچ يك از جهانيان را [آن چنان‌] عذاب نكرده باشم.»\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@dcclxxxv{و [ياد كن‌] هنگامى را كه خدا فرمود: «اى عيسى پسر مريم، آيا تو به مردم گفتى: من و مادرم را همچون دو خدا به جاى خداوند بپرستيد؟» گفت: «منزهى تو، مرا نزيبد كه [در باره خويشتن‌] چيزى را كه حق من نيست بگويم. اگر آن را گفته بودم قطعاً آن را مى‌دانستى. آنچه در نفس من است تو مى‌دانى؛ و آنچه در ذات توست من نمى‌دانم، چرا كه تو خود، داناى رازهاى نهانى.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@dcclxxxvi{جز آنچه مرا بدان فرمان دادى [چيزى‌] به آنان نگفتم؛ [گفته‌ام‌] كه: خدا، پروردگار من و پروردگار خود را عبادت كنيد، و تا وقتى در ميانشان بودم بر آنان گواه بودم؛ پس چون روح مرا گرفتى، تو خود بر آنان نگهبان بودى، و تو بر هر چيز گواهى.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@dcclxxxvii{اگر عذابشان كنى، آنان بندگان تواند و اگر بر ايشان ببخشايى تو خود، توانا و حكيمى.»\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@dcclxxxviii{خدا فرمود: «اين، روزى است كه راستگويان را راستى‌شان سود بخشد.» براى آنان باغهايى است كه از زير [درختان‌] آن نهرها روان است. هميشه در آن جاودانند. خدا از آنان خشنود است و آنان [نيز] از او خشنودند. اين است رستگارى بزرگ.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@dcclxxxix{فرمانروايى آسمانها و زمين و آنچه در آنهاست از آنِ خداست، و او بر هر چيزى تواناست.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@dccxc{\basmalahfa ستايش خدايى را كه آسمانها و زمين را آفريد، و تاريكيها و روشنايى را پديد آورد. با اين همه كسانى كه كفر ورزيده‌اند، [غير او را] با پروردگار خود برابر مى‌كنند.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@dccxci{اوست كسى كه شما را از گِل آفريد. آنگاه مدتى را [براى شما عُمْر] مقرر داشت. و اَجَل حتمى نزد اوست. با اين همه، [بعضى از] شما [در قدرت او] ترديد مى‌كنيد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@dccxcii{و او در آسمانها و زمين خداست. نهان و آشكار شما را مى‌داند، و آنچه را به دست مى‌آوريد [نيز] مى‌داند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@dccxciii{و هيچ نشانه‌اى از نشانه‌هاى پروردگارشان به سويشان نمى‌آمد مگر آنكه از آن روى بر مى‌تافتند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@dccxciv{آنان حق را هنگامى كه به سويشان آمد تكذيب كردند، پس به زودى، [حقيقت‌] خبرهاى آنچه را كه به ريشخند مى‌گرفتند به آنان خواهد رسيد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@dccxcv{آيا نديده‌اند كه پيش از آنان چه بسيار امتها را هلاك كرديم؟ [امتهايى كه‌] در زمين به آنان امكاناتى داديم كه براى شما آن امكانات را فراهم نكرده‌ايم، و [بارانهاى‌] آسمان را پى در پى بر آنان فرو فرستاديم، و رودبارها از زير [شهرهاى‌] آنان روان ساختيم. پس ايشان را به [سزاى‌] گناهانشان هلاك كرديم، و پس از آنان نسلهاى ديگرى پديد آورديم.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@dccxcvi{و اگر مكتوبى، نوشته بر كاغذ، بر تو نازل مى‌كرديم و آنان، آن را با دستهاى خود لمس مى‌كردند قطعاً كافران مى‌گفتند: «اين [چيزى‌] جز سحر آشكار نيست.»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@dccxcvii{و گفتند: «چرا فرشته‌اى بر او نازل نشده است؟» و اگر فرشته‌اى فرود مى‌آورديم، قطعاً كار تمام شده بود؛ سپس مهلت نمى‌يافتند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@dccxcviii{و اگر او را فرشته‌اى قرار مى‌داديم، حتماً وى را [به صورت‌] مردى در مى‌آورديم، و امر را همچنان بر آنان مشتبه مى‌ساختيم.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@dccxcix{و پيش از تو پيامبرانى به استهزا گرفته شدند. پس آنچه را ريشخند مى‌كردند گريبانگير ريشخندكنندگان ايشان گرديد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@dccc{بگو: «در زمين بگرديد، آنگاه بنگريد كه فرجام تكذيب‌كنندگان چگونه بوده است؟»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@dccci{بگو: «آنچه در آسمانها و زمين است از آنِ كيست؟» بگو: «از آن خداست »؛ كه رحمت را بر خويشتن واجب گردانيده است. يقيناً شما را در روز قيامت -كه در آن هيچ شكى نيست- گرد خواهد آورد. خودباختگان كسانى‌اند كه ايمان نمى‌آورند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@dcccii{و آنچه در شب و روز آرام [و تكاپو] دارد، از آنِ اوست و او شنواى داناست.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@dccciii{بگو: «آيا غير از خدا -پديدآورنده آسمانها و زمين- سرپرستى برگزينم؟ و اوست كه خوراك مى‌دهد، و خوراك داده نمى‌شود.» بگو: «من مأمورم كه نخستين كسى باشم كه اسلام آورده است، و [به من فرمان داده شده كه:] هرگز از مشركان مباش.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@dccciv{بگو: «اگر به پروردگارم عصيان ورزم از عذاب روزى بزرگ مى‌ترسم.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@dcccv{آن روز، كسى كه [عذاب‌] از او برگردانده شود، قطعاً [خدا] بر او رحمت آورده، و اين است همان رستگارى آشكار.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@dcccvi{و اگر خدا به تو زيانى برساند، كسى جز او برطرف كننده آن نيست، و اگر خيرى به تو برساند پس او بر هر چيزى تواناست.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@dcccvii{و اوست كه بر بندگان خويش چيره است، و اوست حكيم آگاه.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@dcccviii{بگو: «گواهى چه كسى از همه برتر است؟» بگو: «خدا ميان من و شما گواه است. و اين قرآن به من وحى شده تا به وسيله آن، شما و هر كس را [كه اين پيام به او] برسد، هشدار دهم. آيا واقعاً شما گواهى مى‌دهيد كه در جَنب خدا، خدايان ديگرى است؟» بگو: «من گواهى نمى‌دهم.» بگو: «او تنها معبودى يگانه است، و بى‌ترديد، من از آنچه شريك [او] قرار مى‌دهيد بيزارم.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@dcccix{كسانى كه كتاب [آسمانى‌] به آنان داده‌ايم، همان گونه كه پسران خود را مى‌شناسد، او [=پيامبر] را مى‌شناسد. كسانى كه به خود زيان زده‌اند، ايمان نمى‌آورند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@dcccx{و كيست ستمكارتر از آن كس كه بر خدا دروغ بسته يا آيات او را تكذيب نموده؟ بى ترديد، ستمكاران رستگار نمى‌شوند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@dcccxi{و [ياد كن‌] روزى را كه همه آنان را محشور مى‌كنيم، آنگاه به كسانى كه شرك آورده‌اند مى‌گوييم: «كجايند شريكان شما كه [آنها را شريك خدا] مى‌پنداشتيد؟»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@dcccxii{آنگاه عذرشان جز اين نيست كه مى‌گويند: «به خدا، پروردگارمان سوگند كه ما مشرك نبوديم.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@dcccxiii{ببين، چگونه به خود دروغ مى‌گويند و آنچه برمى‌بافتند از ايشان ياوه شد.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@dcccxiv{و برخى از آنان به تو گوش فرا مى‌دهند، و[لى‌] ما بر دلهايشان پرده‌ها افكنده‌ايم تا آن را نفهمند، و در گوشهايشان سنگينى [قرار داده‌ايم‌]. و اگر هر معجزه‌اى را ببينند به آن ايمان نمى‌آورند. تا آنجا كه وقتى نزد تو مى‌آيند و با تو جدال مى‌كنند، كسانى كه كفر ورزيدند، مى‌گويند: «اين [كتاب‌] چيزى جز افسانه‌هاى پيشينيان نيست.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@dcccxv{و آنان [مردم را] از آن باز مى‌دارند و [خود نيز] از آن دورى مى‌كنند، و[لى‌] جز خويشتن را به هلاكت نمى‌افكنند و نمى‌دانند.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@dcccxvi{و اى كاش [منكران را] هنگامى كه بر آتش عرضه مى‌شوند، مى‌ديدى كه مى‌گويند: «كاش بازگردانده مى‌شديم و [ديگر] آيات پروردگارمان را تكذيب نمى‌كرديم و از مؤمنان مى‌شديم.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@dcccxvii{[ولى چنين نيست‌] بلكه آنچه را پيش از اين نهان مى‌داشتند، براى آنان آشكار شده است. و اگر هم بازگردانده شوند قطعاً به آنچه از آن منع شده بودند برمى‌گردند و آنان دروغگويند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@dcccxviii{و گفتند: «جز زندگى دنياى ما [زندگى ديگرى‌] نيست و برانگيخته نخواهيم شد.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@dcccxix{و اگر بنگرى هنگامى را كه در برابر پروردگارشان باز داشته مى‌شوند. [خدا] مى‌فرمايد: «آيا اين حق نيست؟» مى‌گويند: «چرا، سوگند به پروردگارمان [كه حق است‌].» مى‌فرمايد: «پس به [كيفر] آنكه كفر مى‌ورزيديد، اين عذاب را بچشيد.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@dcccxx{كسانى كه لقاى الهى را دروغ انگاشتند قطعاً زيان ديدند. تا آنگاه كه قيامت بناگاه بر آنان دررسد، مى‌گويند: «اى دريغ بر ما، بر آنچه در باره آن كوتاهى كرديم.» و آنان بار سنگين گناهانشان را به دوش مى‌كشند. چه بد است بارى كه مى‌كِشند.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@dcccxxi{و زندگى دنيا جز بازى و سرگرمى نيست، و قطعاً سراى بازپسين براى كسانى كه پرهيزگارى مى‌كنند بهتر است. آيا نمى‌انديشيد؟\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@dcccxxii{به يقين، مى‌دانيم كه آنچه مى‌گويند تو را سخت غمگين مى‌كند. در واقع آنان تو را تكذيب نمى‌كنند، ولى ستمكاران آيات خدا را انكار مى‌كنند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@dcccxxiii{و پيش از تو نيز پيامبرانى تكذيب شدند، ولى بر آنچه تكذيب شدند و آزار ديدند شكيبايى كردند تا يارى ما به آنان رسيد، و براى كلمات خدا هيچ تغييردهنده‌اى نيست. و مسلماً اخبار پيامبران به تو رسيده است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@dcccxxiv{و اگر اعراض كردنِ آنان [از قرآن‌] بر تو گران است، اگر مى‌توانى نَقْبى در زمين يا نردبانى در آسمان بجويى تا معجزه‌اى [ديگر] برايشان بياورى [پس چنين كن‌]، و اگر خدا مى‌خواست قطعاً آنان را بر هدايت گِرد مى‌آورد، پس زنهار از نادانان مباش.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@dcccxxv{تنها كسانى [دعوت تو را] اجابت مى‌كنند كه گوش شنوا دارند، و [امّا] مردگان را خداوند [در قيامت‌] بر خواهد انگيخت؛ سپس به سوى او بازگردانيده مى‌شوند.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@dcccxxvi{و گفتند: «چرا معجزه‌اى از جانب پروردگارش بر او نازل نشده است؟» بگو: «بى‌ترديد، خدا قادر است كه پديده‌اى شگرف فرو فرستد، ليكن بيشتر آنان نمى‌دانند.»\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@dcccxxvii{و هيچ جنبنده‌اى در زمين نيست و نه هيچ پرنده‌اى كه با دو بال خود پرواز مى‌كند؛ مگر آنكه آنها [نيز] گروه‌هايى مانند شما هستند، ما هيچ چيزى را در كتاب [لوح محفوظ] فروگذار نكرده‌ايم؛ سپس [همه‌] به سوى پروردگارشان محشور خواهند گرديد.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@dcccxxviii{و كسانى كه آيات ما را دروغ پنداشتند، در تاريكيها[ى كفر] كر و لالند، هر كه را خدا بخواهد گمراهش مى‌گذارد؛ و هر كه را بخواهد بر راه راست قرارش مى‌دهد.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@dcccxxix{بگو: «به نظر شما، اگر عذاب خدا شما را دررسد يا رستاخيز شما را دريابد، اگر راستگوييد، كسى غير از خدا را مى‌خوانيد؟»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@dcccxxx{[نه،] بلكه تنها او را مى‌خوانيد، و اگر او بخواهد رنج و بلا را از شما دور مى‌گرداند، و آنچه را شريك [او] مى‌گردانيد فراموش مى‌كنيد.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@dcccxxxi{و به يقين، ما به سوى امّتهايى كه پيش از تو بودند [پيامبرانى‌] فرستاديم، و آنان را به تنگى معيشت و بيمارى دچار ساختيم، تا به زارى و خاكسارى درآيند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@dcccxxxii{پس چرا هنگامى كه عذاب ما به آنان رسيد تضرّع نكردند؟ ولى [حقيقت اين است كه‌] دلهايشان سخت شده، و شيطان آنچه را انجام مى‌دادند برايشان آراسته است.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@dcccxxxiii{پس چون آنچه را كه بدان پند داده شده بودند فراموش كردند، درهاى هر چيزى [از نعمتها] را بر آنان گشوديم، تا هنگامى كه به آنچه داده شده بودند شاد گرديدند؛ ناگهان [گريبان‌] آنان را گرفتيم، و يكباره نوميد شدند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@dcccxxxiv{پس ريشه آن گروهى كه ستم كردند بركنده شد، و ستايش براى خداوند، پروردگار جهانيان است.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@dcccxxxv{بگو: «به نظر شما، اگر خدا شنوايى شما و ديدگانتان را بگيرد و بر دلهايتان مُهر نهد، آيا غير از خدا كدام معبودى است كه آن را به شما بازپس دهد؟» بنگر چگونه آيات [خود] را [گوناگون‌] بيان مى‌كنيم، سپس آنان روى برمى‌تابند؟\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@dcccxxxvi{بگو: «به نظر شما، اگر عذاب خدا ناگهان يا آشكارا به شما برسد، آيا جز گروه ستمگران [كسى‌] هلاك خواهد شد؟»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@dcccxxxvii{و ما پيامبران [خود] را جز بشارتگر و هشداردهنده نمى‌فرستيم، پس كسانى كه ايمان آورند و نيكوكارى كنند بيمى بر آنان نيست و اندوهگين نخواهند شد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@dcccxxxviii{و كسانى كه آيات ما را دروغ انگاشتند، به [سزاى‌] آنكه نافرمانى مى‌كردند، عذاب به آنان خواهد رسيد.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@dcccxxxix{بگو: «به شما نمى‌گويم گنجينه‌هاى خدا نزد من است؛ و غيب نيز نمى‌دانم؛ و به شما نمى‌گويم كه من فرشته‌ام. جز آنچه را كه به سوى من وحى مى‌شود پيروى نمى‌كنم.» بگو: «آيا نابينا و بينا يكسان است؟ آيا تفكّر نمى‌كنيد.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@dcccxl{و به وسيله اين [قرآن‌] كسانى را كه بيم دارند كه به سوى پروردگارشان محشور شوند هشدار ده [چرا] كه غير او براى آنها يار و شفيعى نيست، باشد كه پروا كنند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@dcccxli{و كسانى را كه پروردگار خود را بامدادان و شامگاهان مى‌خوانند -در حالى كه خشنودى او را مى‌خواهند- مران. از حساب آنان چيزى بر عهده تو نيست، و از حساب تو [نيز] چيزى بر عهده آنان نيست، تا ايشان را برانى و از ستمكاران باشى.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@dcccxlii{و بدين گونه ما برخى از آنان را به برخى ديگر آزموديم، تا بگويند: «آيا اينانند كه از ميان ما، خدا بر ايشان منّت نهاده است؟» آيا خدا به [حال‌] سپاسگزاران داناتر نيست؟\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@dcccxliii{و چون كسانى كه به آيات ما ايمان دارند، نزد تو آيند، بگو: «درود بر شما»، پروردگارتان رحمت را بر خود مقرّر كرده كه هر كس از شما به نادانى كار بدى كند و آنگاه به توبه و صلاح آيد، پس وى آمرزنده مهربان است.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@dcccxliv{و اين گونه، آيات [خود] را به روشنى بيان مى‌كنيم تا راه و رسم گناهكاران روشن شود.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@dcccxlv{بگو: «من نهى شده‌ام كه كسانى را كه شما غير از خدا مى‌خوانيد بپرستم!» بگو: «من از هوسهاى شما پيروى نمى‌كنم، و گر نه گمراه شوم و از راه‌يافتگان نباشم.»\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@dcccxlvi{بگو: «من از جانب پروردگارم دليل آشكارى [همراه‌] دارم، و[لى‌] شما آن را دروغ پنداشتيد، [و] آنچه را به شتاب خواستار آنيد در اختيار من نيست. فرمان جز به دست خدا نيست، كه حق را بيان مى‌كند، و او بهترين داوران است.»\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@dcccxlvii{بگو: «اگر آنچه را با شتاب خواستار آنيد نزد من بود، قطعاً ميان من و شما كار به انجام رسيده بود، و خدا به [حال‌] ستمكاران داناتر است.»\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@dcccxlviii{و كليدهاى غيب، تنها نزد اوست. جز او [كسى‌] آن را نمى‌داند، و آنچه در خشكى و درياست مى‌داند، و هيچ برگى فرو نمى‌افتد مگر [اينكه‌] آن را مى‌داند، و هيچ دانه‌اى در تاريكيهاى زمين، و هيچ تر و خشكى نيست مگر اينكه در كتابى روشن [ثبت ]است.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@dcccxlix{و اوست كسى كه شبانگاه، روح شما را [به هنگام خواب‌] مى‌گيرد؛ و آنچه را در روز به دست آورده‌ايد مى‌داند؛ سپس شما را در آن بيدار مى‌كند، تا هنگامى معيّن به سر آيد؛ آنگاه بازگشت شما به سوى اوست؛ سپس شما را به آنچه انجام مى‌داده‌ايد آگاه خواهد كرد.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@dcccl{و اوست كه بر بندگانش قاهر [و غالب‌] است؛ و نگهبانانى بر شما مى‌فرستد، تا هنگامى كه يكى از شما را مرگ فرا رسد، فرشتگان ما جانش بستانند، در حالى كه كوتاهى نمى‌كنند.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@dcccli{آنگاه به سوى خداوند -مولاى بحقشان- برگردانيده شوند. آگاه باشيد كه داورى از آن اوست، و او سريعترين حسابرسان است.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@dccclii{بگو: «چه كسى شما را از تاريكيهاى خشكى و دريا مى‌رهاند؟ در حالى كه او را به زارى و در نهان مى‌خوانيد: كه اگر ما را از اين [مهلكه‌] برهاند، البته از سپاسگزاران خواهيم بود.»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@dcccliii{بگو: «خداست كه شما را از آن [تاريكيها] و از هر اندوهى مى‌رهاند، باز شما شرك مى‌ورزيد.»\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@dcccliv{بگو: «او تواناست كه از بالاى سرتان يا از زير پاهايتان عذابى بر شما بفرستد يا شما را گروه گروه به هم اندازد [و دچار تفرقه سازد] و عذاب بعضى از شما را به بعضى [ديگر] بچشاند.» بنگر، چگونه آيات [خود] را گوناگون بيان مى‌كنيم باشد كه آنان بفهمند.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@dccclv{و قوم تو آن [=قرآن‌] را دروغ شمردند، در حالى كه آن بر حق است. بگو: «من بر شما نگهبان نيستم.»\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@dccclvi{براى هر خبرى هنگام [وقوع‌] است، و به زودى خواهيد دانست.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@dccclvii{و چون ببينى كسانى [به قصد تخطئه‌] در آيات ما فرو مى‌روند از ايشان روى برتاب، تا در سخنى غير از آن درآيند؛ و اگر شيطان تو را [در اين باره‌] به فراموشى انداخت، پس از توجّه، [ديگر] با قوم ستمكار منشين.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@dccclviii{و چيزى از حساب آنان [=ستمكاران‌] بر عهده كسانى كه پروا[ى خدا] دارند، نيست. ليكن، تذكّر دادن [لازم‌] است، باشد كه [از استهزا] پرهيز كنند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@dccclix{و كسانى را كه دين خود را به بازى و سرگرمى گرفتند و زندگى دنيا آنان را فريفته است، رها كن؛ و [مردم را] به وسيله اين [قرآن‌] اندرز ده؛ مبادا كسى به [كيفر] آنچه كسب كرده به هلاكت افتد، در حالى كه براى او در برابر خدا يارى و شفاعتگرى نباشد؛ و اگر [براى رهايى خود] هر گونه فديه‌اى دهد، از او پذيرفته نگردد. اينانند كه به [سزاى‌] آنچه كسب كرده‌اند به هلاكت افتاده‌اند، و به [كيفر] آنكه كفر مى‌ورزيدند، شرابى از آب جوشان و عذابى پر درد خواهند داشت.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@dccclx{بگو: «آيا به جاى خدا چيزى را بخوانيم كه نه سودى به ما مى‌رساند و نه زيانى؛ و آيا پس از اينكه خدا ما را هدايت كرده از عقيده خود بازگرديم؟ مانند كسى كه شيطانها او را در بيابان از راه به در برده‌اند، و حيران [بر جاى مانده ]است؟ براى او يارانى است كه وى را به سوى هدايت مى‌خوانند كه:» به سوى ما بيا. «بگو:» هدايت خداست كه هدايتِ [واقعى‌] است، و دستور يافته‌ايم كه تسليم پروردگار جهانيان باشيم.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@dccclxi{و اينكه نماز برپا داريد و از او بترسيد، و هم اوست كه نزد وى محشور خواهيد گرديد.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@dccclxii{و او كسى است كه آسمانها و زمين را به حق آفريد، و هر گاه كه مى‌گويد: «باش»، بى‌درنگ موجود شود؛ سخنش راست است؛ و روزى كه در صور دميده شود، فرمانروايى از آن اوست؛ داننده غيب و شهود است؛ و اوست حكيم آگاه.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@dccclxiii{و [ياد كن‌] هنگامى را كه ابراهيم به پدر خود «آزر» گفت: «آيا بتان را خدايان [خود] مى‌گيرى؟ من همانا تو و قوم تو را در گمراهى آشكارى مى‌بينم.»\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@dccclxiv{و اين گونه، ملكوت آسمانها و زمين را به ابراهيم نمايانديم تا از جمله يقين‌كنندگان باشد.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@dccclxv{پس چون شب بر او پرده افكند، ستاره‌اى ديد؛ گفت: «اين پروردگار من است.» و آنگاه چون غروب كرد، گفت: «غروب‌كنندگان را دوست ندارم.»\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@dccclxvi{و چون ماه را در حال طلوع ديد، گفت: «اين پروردگار من است.» آنگاه چون ناپديد شد، گفت: «اگر پروردگارم مرا هدايت نكرده بود قطعاً از گروه گمراهان بودم.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@dccclxvii{پس چون خورشيد را برآمده ديد، گفت: «اين پروردگار من است. اين بزرگتر است.» و هنگامى كه افول كرد، گفت: «اى قوم من، من از آنچه [براى خدا] شريك مى‌سازيد بيزارم.»\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@dccclxviii{من از روى اخلاص، پاكدلانه روى خود را به سوى كسى گردانيدم كه آسمانها و زمين را پديد آورده است؛ و من از مشركان نيستم.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@dccclxix{و قومش با او به ستيزه پرداختند. گفت: «آيا با من در باره خدا محاجّه مى‌كنيد و حال آنكه او مرا راهنمايى كرده است؟ و من از آنچه شريك او مى‌سازيد بيمى ندارم، مگر آنكه پروردگارم چيزى بخواهد. علم پروردگارم به هر چيزى احاطه يافته است. پس آيا متذكّر نمى‌شويد؟»\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@dccclxx{و چگونه از آنچه شريك [خدا] مى‌گردانيد بترسم، با آنكه شما خود از اينكه چيزى را شريك خدا ساخته‌ايد كه [خدا] دليلى در باره آن بر شما نازل نكرده است نمى‌هراسيد؟ پس اگر مى‌دانيد، كدام يك از [ما] دو دسته به ايمنى سزاوارتر است؟\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@dccclxxi{كسانى كه ايمان آورده و ايمان خود را به شرك نيالوده‌اند، آنان راست ايمنى و ايشان راه‌يافتگانند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@dccclxxii{و آن حجّت ما بود كه به ابراهيم در برابر قومش داديم. درجات هر كس را كه بخواهيم فرا مى‌بريم، زيرا پروردگار تو حكيم داناست.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@dccclxxiii{و به او اسحاق و يعقوب را بخشيديم، و همه را به راه راست درآورديم، و نوح را از پيش راه نموديم، و از نسل او داوود و سليمان و ايوب و يوسف و موسى و هارون را [هدايت كرديم‌] و اين گونه، نيكوكاران را پاداش مى‌دهيم.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@dccclxxiv{و زكريّا و يحيى و عيسى و الياس را كه همه از شايستگان بودند،\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@dccclxxv{و اسماعيل و يسع و يونس و لوط، كه جملگى را بر جهانيان برترى داديم.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@dccclxxvi{و از پدران و فرزندان و برادرانشان برخى را [بر جهانيان برترى داديم‌]، و آنان را برگزيديم و به راه راست راهنمايى كرديم.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@dccclxxvii{اين، هدايت خداست كه هر كس از بندگانش را بخواهد بدان هدايت مى‌كند. و اگر آنان شرك ورزيده بودند، قطعاً آن چه انجام مى‌دادند از دستشان مى‌رفت.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@dccclxxviii{آنان كسانى بودند كه كتاب و داورى و نبوت بديشان داديم؛ و اگر اينان [=مشركان‌] بدان كفر ورزند، بى‌گمان، گروهى [ديگر] را بر آن گماريم كه بدان كافر نباشند.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@dccclxxix{اينان كسانى هستند كه خدا هدايتشان كرده است، پس به هدايت آنان اقتدا كن. بگو: «من، از شما هيچ مزدى بر اين [رسالت‌] نمى‌طلبم. اين [قرآن‌] جز تذكرى براى جهانيان نيست.»\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@dccclxxx{و آنگاه كه [يهوديان‌] گفتند: «خدا چيزى بر بشرى نازل نكرده»، بزرگى خدا را چنانكه بايد نشناختند. بگو: «چه كسى آن كتابى را كه موسى آورده است نازل كرده؟ [همان كتابى كه‌] براى مردم روشنايى و رهنمود است، [و] آن را به صورت طومارها درمى‌آوريد. [آنچه را] از آن [مى‌خواهيد] آشكار و بسيارى را پنهان مى‌كنيد، در صورتى كه چيزى كه نه شما مى‌دانستيد و نه پدرانتان، [به وسيله آن‌] به شما آموخته شد.» بگو: «خدا [همه را فرستاده‌]»؛ آنگاه بگذار تا در ژرفاى [باطل‌] خود به بازى [سرگرم‌] شوند.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@dccclxxxi{و اين خجسته‌كتابى است كه ما آن را فرو فرستاديم، [و] كتابهايى را كه پيش از آن آمده تصديق مى‌كند. و براى اينكه [مردم‌]ام‌القرى [=مكّه‌] و كسانى را كه پيرامون آنند هشدار دهى. و كسانى كه به آخرت ايمان مى‌آورند، به آن [قرآن نيز] ايمان مى‌آورند، و آنان بر نمازهاى خود مراقبت مى‌كنند.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@dccclxxxii{و كيست ستمكارتر از آن كس كه بر خدا دروغ مى‌بندد يا مى‌گويد: «به من وحى شده»، در حالى كه چيزى به او وحى نشده باشد، و آن كس كه مى‌گويد: «به زودى نظير آنچه را خدا نازل كرده است نازل مى‌كنم»؟ و كاش ستمكاران را در گردابهاى مرگ مى‌ديدى كه فرشتگان [به سوى آنان‌] دستهايشان را گشوده‌اند [و نهيب مى‌زنند:] «جانهايتان را بيرون دهيد»؛ امروز به [سزاى‌] آنچه بناحق بر خدا دروغ مى‌بستيد و در برابر آيات او تكبر مى‌كرديد، به عذاب خواركننده كيفر مى‌يابيد.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@dccclxxxiii{و همان گونه كه شما را نخستين بار آفريديم [اكنون نيز] تنها به سوى ما آمده‌ايد، و آنچه را به شما عطا كرده بوديم پشت سر خود نهاده‌ايد، و شفيعانى را كه در [كار] خودتان، شريكان [خدا] مى‌پنداشتيد با شما نمى‌بينيم. به يقين، پيوند ميان شما بريده شده، و آنچه را كه مى‌پنداشتيد از دست شما رفته است.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@dccclxxxiv{خدا شكافنده دانه و هسته است. زنده را از مرده، و مرده را از زنده بيرون مى‌آورد. چنين است خداى شما؛ پس چگونه [از حق‌] منحرف مى‌شويد؟\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@dccclxxxv{[هموست كه‌] شكافنده صبح است، و شب را براى آرامش و خورشيد و ماه را وسيله حساب قرار داده. اين اندازه‌گيرىِ آن تواناى داناست.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@dccclxxxvi{و اوست كسى كه ستارگان را براى شما قرار داده تا به وسيله آنها در تاريكيهاى خشكى و دريا راه يابيد. به يقين، ما دلايل [خود] را براى گروهى كه مى‌دانند به روشنى بيان كرده‌ايم.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@dccclxxxvii{و او همان كسى است كه شما را از يك تن پديد آورد. پس [براى شما] قرارگاه و محل امانتى [مقرر كرد]. بى‌ترديد، ما آيات [خود] را براى مردمى كه مى‌فهمند به روشنى بيان كرده‌ايم.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@dccclxxxviii{و اوست كسى كه از آسمان، آبى فرود آورد؛ پس به وسيله آن از هر گونه گياه برآورديم، و از آن [گياه‌] جوانه سبزى خارج ساختيم كه از آن، دانه‌هاى متراكمى برمى‌آوريم، و از شكوفه درخت خرما خوشه‌هايى است نزديك به هم. و [نيز ]باغهايى از انگور و زيتون و انار -همانند و غير همانند- خارج نموديم. به ميوه آن چون ثمر دهد و به [طرز] رسيدنش بنگريد. قطعاً در اينها براى مردمى كه ايمان مى‌آورند نشانه‌هاست.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@dccclxxxix{و براى خدا شريكانى از جن قرار دادند، با اينكه خدا آنها را خلق كرده است. و براى او، بى هيچ دانشى، پسران و دخترانى تراشيدند. او پاك و برتر است از آنچه وصف مى‌كنند.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@dcccxc{پديدآورنده آسمانها و زمين است. چگونه او را فرزندى باشد، در صورتى كه براى او همسرى نبوده، و هر چيزى را آفريده، و اوست كه به هر چيزى داناست.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@dcccxci{اين است خدا، پروردگار شما: هيچ معبودى جز او نيست، آفريننده هر چيزى است. پس او را بپرستيد، و او بر هر چيزى نگهبان است.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@dcccxcii{چشمها او را درنمى‌يابند و اوست كه ديدگان را درمى‌يابد، و او لطيف آگاه است.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@dcccxciii{به راستى رهنمودهايى از جانب پروردگارتان براى شما آمده است. پس هر كه به ديده بصيرت بنگرد به سود خود او، و هر كس از سر بصيرت ننگرد به زيان خود اوست، و من بر شما نگهبان نيستم.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@dcccxciv{و اين گونه آيات [خود] را گوناگون بيان مى‌كنيم، تا مبادا بگويند تو درس خوانده‌اى، و تا اينكه آن را براى گروهى كه مى‌دانند روشن سازيم.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@dcccxcv{از آنچه از پروردگارت به تو وحى شده پيروى كن. هيچ معبودى جز او نيست، و از مشركان روى بگردان.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@dcccxcvi{و اگر خدا مى‌خواست آنان شرك نمى‌آوردند، و ما تو را بر ايشان نگهبان نكرده‌ايم، و تو وكيل آنان نيستى.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@dcccxcvii{و آنهايى را كه جز خدا مى‌خوانند دشنام مدهيد كه آنان از روى دشمنى [و] به نادانى، خدا را دشنام خواهند داد. اين گونه براى هر امتى كردارشان را آراستيم. آنگاه بازگشت آنان به سوى پروردگارشان خواهد بود، و ايشان را از آنچه انجام مى‌دادند آگاه خواهد ساخت.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@dcccxcviii{و با سخت‌ترين سوگندهايشان، به خدا سوگند خوردند كه اگر معجزه‌اى براى آنان بيايد، حتماً بدان مى‌گروند. بگو: «معجزات، تنها در اختيار خداست.» و شما چه مى‌دانيد كه اگر [معجزه هم‌] بيايد باز ايمان نمى‌آورند.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@dcccxcix{و دلها و ديدگانشان را برمى‌گردانيم [در نتيجه به آيات ما ايمان نمى‌آورند] چنانكه نخستين بار به آن ايمان نياوردند. و آنان را رها مى‌كنيم تا در طغيانشان سرگردان بمانند.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@cm{و اگر ما فرشتگان را به سوى آنان مى‌فرستاديم و اگر مردگان با آنان به سخن مى‌آمدند، و هر چيزى را دسته دسته در برابر آنان گرد مى‌آورديم، باز هم ايمان نمى‌آوردند -جز اينكه خدا بخواهد- ولى بيشترشان نادانى مى‌كنند.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@cmi{و بدين گونه براى هر پيامبرى دشمنى از شيطانهاى انس و جن برگماشتيم. بعضى از آنها به بعضى، براى فريب [يكديگر]، سخنان آراسته القا مى‌كنند؛ و اگر پروردگار تو مى‌خواست چنين نمى‌كردند. پس آنان را با آنچه به دروغ مى‌سازند واگذار.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@cmii{و [چنين مقرر شده است‌] تا دلهاى كسانى كه به آخرت ايمان نمى‌آورند به آن [سخن باطل‌] بگرايد و آن را بپسندد، و تا اينكه آنچه را بايد به دست بياورند، به دست آورند.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@cmiii{پس، آيا داورى جز خدا جويم؟ با اينكه اوست كه اين كتاب را به تفصيل به سوى شما نازل كرده است. و كسانى كه كتاب [آسمانى‌] بديشان داده‌ايم مى‌دانند كه آن از جانب پروردگارت به حق فرو فرستاده شده است. پس تو از ترديدكنندگان مباش.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@cmiv{و سخن پروردگارت به راستى و داد، سرانجام گرفته است؛ و هيچ تغييردهنده‌اى براى كلمات او نيست؛ و او شنواى داناست.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@cmv{و اگر از بيشتر كسانى كه در [اين سر]زمين مى‌باشند پيروى كنى، تو را از راه خدا گمراه مى‌كنند. آنان جز از گمان [خود] پيروى نمى‌كنند و جز به حدس و تخمين نمى‌پردازند.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@cmvi{بارى، پروردگار تو به [حال‌] كسى كه از راه او منحرف مى‌شود داناتر است، و او به [حال‌] راه‌يافتگان [نيز] داناتر است.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@cmvii{پس، اگر به آيات او ايمان داريد از آنچه نام خدا [به هنگام ذبح‌] بر آن برده شده است بخوريد.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@cmviii{و شما را چه شده است كه از آنچه نام خدا بر آن برده شده است نمى‌خوريد؟ با اينكه [خدا] آنچه را بر شما حرام كرده -جز آنچه بدان ناچار شده‌ايد- براى شما به تفصيل بيان نموده است. و به راستى، بسيارى [از مردم، ديگران را] از روى نادانى، با هوسهاى خود گمراه مى‌كنند. آرى، پروردگار تو به [حال‌] تجاوزكاران داناتر است.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@cmix{و گناه آشكار و پنهان را رها كنيد، زيرا كسانى كه مرتكب گناه مى‌شوند، به زودى در برابر آنچه به دست مى‌آوردند كيفر خواهند يافت.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@cmx{و از آنچه نام خدا بر آن برده نشده است مخوريد، چرا كه آن قطعاً نافرمانى است. و در حقيقت، شيطانها به دوستان خود وسوسه مى‌كنند تا با شما ستيزه نمايند. و اگر اطاعتشان كنيد قطعاً شما هم مشركيد.\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@cmxi{آيا كسى كه مرده‌[دل‌] بود و زنده‌اش گردانيديم و براى او نورى پديد آورديم تا در پرتو آن، در ميان مردم راه برود، چون كسى است كه گويى گرفتار در تاريكيهاست و از آن بيرون‌آمدنى نيست؟ اين گونه براى كافران آنچه انجام مى‌دادند زينت داده شده است.\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@cmxii{و بدين گونه، در هر شهرى گناهكاران بزرگش را مى‌گماريم تا در آن به نيرنگ پردازند، و[لى‌] آنان جز به خودشان نيرنگ نمى‌زنند و درك نمى‌كنند.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@cmxiii{و چون آيتى برايشان بيايد، مى‌گويند: «هرگز ايمان نمى‌آوريم تا اينكه نظير آنچه به فرستادگان خدا داده شده است به ما [نيز] داده شود.» خدا بهتر مى‌داند رسالتش را كجا قرار دهد. به زودى، كسانى را كه مرتكب گناه شدند، به [سزاى ]آنكه نيرنگ مى‌كردند، در پيشگاه خدا خوارى و شكنجه‌اى سخت خواهد رسيد.\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@cmxiv{پس كسى را كه خدا بخواهد هدايت نمايد، دلش را به پذيرش اسلام مى‌گشايد؛ و هر كه را بخواهد گمراه كند، دلش را سخت تنگ مى‌گرداند؛ چنانكه گويى به زحمت در آسمان بالا مى‌رود. اين گونه، خدا پليدى را بر كسانى كه ايمان نمى‌آورند قرار مى‌دهد.\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@cmxv{و راه راست پروردگارت همين است. ما آيات [خود] را براى گروهى كه پند مى‌گيرند، به روشنى بيان نموده‌ايم.\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@cmxvi{براى آنان، نزد پروردگارشان سراى عافيت است، و به [پاداش‌] آنچه انجام مى‌دادند، او يارشان خواهد بود.\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@cmxvii{و [ياد كن‌] روزى را كه همه آنان را گرد مى‌آورد [و مى‌فرمايد:] «اى گروه جنيان، از آدميان [پيروان‌] فراوان يافتيد.» و هواخواهان آنها از [نوع‌] انسان مى‌گويند: «پروردگارا، برخى از ما از برخى ديگر بهره بردارى كرد، و به پايانى كه براى ما معين كردى رسيديم.» [خدا] مى‌فرمايد: «جايگاه شما آتش است؛ در آن ماندگار خواهيد بود، مگر آنچه را خدا بخواهد [كه خود تخفيف دهد]؛ آرى، پروردگار تو حكيم داناست.»\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@cmxviii{و اين گونه برخى از ستمكاران را به [كيفر] آنچه به دست مى‌آوردند، سرپرست برخى ديگر مى‌گردانيم.\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@cmxix{اى گروه جن و انس، آيا از ميان شما فرستادگانى براى شما نيامدند كه آيات مرا بر شما بخوانند و از ديدار اين روزتان به شما هشدار دهند؟ گفتند: «ما به زيان خود گواهى دهيم.» [كه آرى، آمدند] و زندگى دنيا فريبشان داد، و بر ضد خود گواهى دادند كه آنان كافر بوده‌اند.\qt@no{(130)}}
\qt@newcmd\qurantrans@fa@cmxx{اين [اتمام حجت‌] بدان سبب است كه پروردگار تو هيچ گاه شهرها را به ستم نابوده نكرده، در حالى كه مردم آن غافل باشند.\qt@no{(131)}}
\qt@newcmd\qurantrans@fa@cmxxi{و براى هر يك [از اين دو گروه‌]، از آنچه انجام داده‌اند، [در جزا] مراتبى خواهد بود، و پروردگارت از آنچه مى‌كنند غافل نيست.\qt@no{(132)}}
\qt@newcmd\qurantrans@fa@cmxxii{و پروردگار تو بى‌نياز و رحمتگر است. اگر بخواهد شما را مى‌برد، و پس از شما، هر كه را بخواهد جانشين [شما] مى‌كند؛ همچنانكه شما را از نسل گروهى ديگر پديد آورده است.\qt@no{(133)}}
\qt@newcmd\qurantrans@fa@cmxxiii{قطعاً آنچه به شما وعده داده مى‌شود آمدنى است، و شما درمانده‌كنندگان [خدا] نيستيد.\qt@no{(134)}}
\qt@newcmd\qurantrans@fa@cmxxiv{بگو: «اى قوم من، هر چه مقدور شما هست انجام دهيد؛ من [هم‌] انجام مى‌دهم. به زودى خواهيد دانست كه فرجام [نيكوى‌] آن سراى از آنِ كيست. آرى، ستمكاران رستگار نمى‌شوند.»\qt@no{(135)}}
\qt@newcmd\qurantrans@fa@cmxxv{و [مشركان،] براى خدا از آنچه از كِشت و دامها كه آفريده است سهمى گذاشتند، و به پندار خودشان گفتند: «اين ويژه خداست و اين ويژه بتان ما.» پس آنچه خاص بتانشان بود به خدا نمى‌رسيد، و[لى‌] آنچه خاص خدا بود به بتانشان مى‌رسيد. چه بد داورى مى‌كنند.\qt@no{(136)}}
\qt@newcmd\qurantrans@fa@cmxxvi{و اين گونه براى بسيارى از مشركان، بتانشان كشتن فرزندانشان را آراستند، تا هلاكشان كنند و دينشان را بر آنان مشتبه سازند؛ و اگر خدا مى‌خواست چنين نمى‌كردند. پس ايشان را با آنچه به دروغ مى‌سازند رها كن.\qt@no{(137)}}
\qt@newcmd\qurantrans@fa@cmxxvii{و به زعم خودشان گفتند: «اينها دامها و كشتزار[هاى‌] ممنوع است، كه جز كسى كه ما بخواهيم نبايد از آن بخورد، و دامهايى است كه [سوار شدن بر] پشت آنها حرام شده است. و دامهايى [داشتند] كه [هنگام ذبح‌] نام خدا را بر آن‌[ها] نمى‌بردند به صرف افترا بر [خدا] به زودى [خدا] آنان را به خاطر آنچه افترا مى‌بستند جزا مى‌دهد.\qt@no{(138)}}
\qt@newcmd\qurantrans@fa@cmxxviii{و گفتند: «آنچه در شكم اين دامهاست اختصاص به مردان ما دارد و بر همسران ما حرام شده است، و اگر [آن جنين‌] مرده باشد، همه آنان [از زن و مرد ] در آن شريكند. به زودى [خدا] توصيف آنان را سزا خواهد داد، زيرا او حكيم داناست.\qt@no{(139)}}
\qt@newcmd\qurantrans@fa@cmxxix{كسانى كه از روى بى‌خردى و نادانى، فرزندان خود را كشته‌اند، و آنچه را خدا روزيشان كرده بود -از راه افترا به خدا- حرام شمرده‌اند، سخت زيان كردند. آنان به راستى گمراه شده، و هدايت نيافته‌اند.\qt@no{(140)}}
\qt@newcmd\qurantrans@fa@cmxxx{و اوست كسى كه باغهايى با داربست و بدون داربست، و خرمابن، و كشتزار با ميوه‌هاى گوناگون آن، و زيتون، و انار، شبيه به يكديگر و غير شبيه پديد آورد. از ميوه آن -چون ثمر داد- بخوريد، و حق [بينوايان از] آن را روز بهره‌بردارى از آن بدهيد، و[لى‌] زياده‌روى مكنيد كه او اسرافكاران را دوست ندارد.\qt@no{(141)}}
\qt@newcmd\qurantrans@fa@cmxxxi{و [نيز] از دامها، حيوانات باركش و حيوانات كرك و پشم‌دهنده را [پديد آورد]. از آنچه خدا روزيتان كرده است بخوريد، و از پى گامهاى شيطان مرويد كه او براى شما دشمنى آشكار است.\qt@no{(142)}}
\qt@newcmd\qurantrans@fa@cmxxxii{هشت فرد [آفريد و بر شما حلال كرد]: از گوسفند دو تا، و از بز دو تا. بگو: «آيا [خدا] نرها[ى آنها] را حرام كرده يا ماده را؟ يا آنچه را كه رحم آن دو ماده در بر گرفته است؟» اگر راست مى‌گوييد، از روى علم، به من خبر دهيد.\qt@no{(143)}}
\qt@newcmd\qurantrans@fa@cmxxxiii{و از شتر دو، و از گاو دو. بگو: «آيا [خدا] نرها[ى آنها] را حرام كرده يا ماده‌ها را؟ يا آنچه را كه رحم آن دو ماده در بر گرفته است؟» آيا وقتى خداوند شما را به اين [تحريم‌] سفارش كرد حاضر بوديد؟ پس كيست ستمكارتر از آنكس كه بر خدا دروغ بندد، تا از روى نادانى، مردم را گمراه كند؟ آرى، خدا گروه ستمكاران را راهنمايى نمى‌كند.\qt@no{(144)}}
\qt@newcmd\qurantrans@fa@cmxxxiv{بگو: «در آنچه به من وحى شده است، بر خورنده‌اى كه آن را مى‌خورد هيچ حرامى نمى‌يابم، مگر آنكه مردار يا خون ريخته يا گوشت خوك باشد كه اينها همه پليدند. يا [قربانيى كه‌] از روى نافرمانى، [به هنگام ذبح‌] نام غير خدا بر آن برده شده باشد. پس كسى كه بدون سركشى و زياده‌خواهى [به خوردن آنها] ناچار گردد، قطعاً پروردگار تو آمرزنده مهربان است.\qt@no{(145)}}
\qt@newcmd\qurantrans@fa@cmxxxv{و بر يهوديان، هر [حيوان‌] چنگال‌دارى را حرام كرديم، و از گاو و گوسفند، پيه آن دو را بر آنان حرام كرديم، به استثناى پيه‌هايى كه بر پشت آن دو يا بر روده‌هاست يا آنچه با استخوان درآميخته است. اين [تحريم‌] را به سزاى ستم‌كردنشان، به آنان كيفر داديم، و ما البتّه راستگوييم.\qt@no{(146)}}
\qt@newcmd\qurantrans@fa@cmxxxvi{[اى پيامبر،] پس اگر تو را تكذيب كردند، بگو: «پروردگار شما داراى رحمتى گسترده است؛ و [با اين حال‌] عذاب او از گروه مجرمان بازگردانده نخواهد شد.»\qt@no{(147)}}
\qt@newcmd\qurantrans@fa@cmxxxvii{كسانى كه شرك آوردند به زودى خواهند گفت: «اگر خدا مى‌خواست، نه ما و نه پدرانمان شرك نمى‌آورديم، و چيزى را [خودسرانه‌] تحريم نمى‌كرديم.» كسانى هم كه پيش از آنان بودند، همين گونه [پيامبران خود را] تكذيب كردند، تا عقوبت ما را چشيدند. بگو: «آيا نزد شما دانشى هست كه آن را براى ما آشكار كنيد؟ شما جز از گمان پيروى نمى‌كنيد، و جز دروغ نمى‌گوييد.»\qt@no{(148)}}
\qt@newcmd\qurantrans@fa@cmxxxviii{بگو: «برهان رسا ويژه خداست، و اگر [خدا] مى‌خواست قطعاً همه شما را هدايت مى‌كرد.»\qt@no{(149)}}
\qt@newcmd\qurantrans@fa@cmxxxix{بگو: «گواهان خود را كه گواهى مى‌دهند به اينكه خدا اينها را حرام كرده، بياوريد.» پس اگر هم شهادت دادند تو با آنان شهادت مده، و هوسهاى كسانى را كه آيات ما را تكذيب كردند و كسانى كه به آخرت ايمان نمى‌آورند و [معبودان دروغين را] با پروردگارشان همتا قرار مى‌دهند، پيروى مكن.\qt@no{(150)}}
\qt@newcmd\qurantrans@fa@cmxl{بگو: «بياييد تا آنچه را پروردگارتان بر شما حرام كرده براى شما بخوانم: چيزى را با او شريك قرار مدهيد؛ و به پدر و مادر احسان كنيد؛ و فرزندان خود را از بيم تنگدستى مكشيد؛ ما شما و آنان را روزى مى‌رسانيم؛ و به كارهاى زشت -چه علنى آن و چه پوشيده‌[اش‌]- نزديك مشويد؛ و نَفْسى را كه خدا حرام گردانيده، جز بحق مكشيد. اينهاست كه [خدا] شما را به [انجام دادن‌] آن سفارش كرده است، باشد كه بينديشد.\qt@no{(151)}}
\qt@newcmd\qurantrans@fa@cmxli{و به مال يتيم -جز به نحوى [هر چه نيكوتر]- نزديك مشويد، تا به حد رشد خود برسد. و پيمانه و ترازو را به عدالت، تمام بپيماييد. هيچ كس را جز به قدر توانش تكليف نمى‌كنيم. و چون [به داورى يا شهادت‌] سخن گوييد دادگرى كنيد، هر چند [در باره‌] خويشاوند [شما] باشد. و به پيمان خدا وفا كنيد. اينهاست كه [خدا] شما را به آن سفارش كرده است، باشد كه پند گيريد.\qt@no{(152)}}
\qt@newcmd\qurantrans@fa@cmxlii{و [بدانيد] اين است راه راست من؛ پس، از آن پيروى كنيد. و از راه‌ها[ى ديگر] كه شما را از راه وى پراكنده مى‌سازد پيروى مكنيد. اينهاست كه [خدا] شما را به آن سفارش كرده است، باشد كه به تقوا گراييد.\qt@no{(153)}}
\qt@newcmd\qurantrans@fa@cmxliii{آنگاه به موسى كتاب داديم، براى اينكه [نعمت را] بر كسى كه نيكى كرده است تمام كنيم، و براى اينكه هر چيزى را بيان نماييم، و هدايت و رحمتى باشد، اميد كه به لقاى پروردگارشان ايمان بياورند.\qt@no{(154)}}
\qt@newcmd\qurantrans@fa@cmxliv{و اين، خجسته كتابى است كه ما آن را نازل كرديم؛ پس، از آن پيروى كنيد و پرهيزگارى نماييد، باشد كه مورد رحمت قرار گيريد،\qt@no{(155)}}
\qt@newcmd\qurantrans@fa@cmxlv{تا نگوييد: «كتاب [آسمانى‌]، تنها بر دو طايفه پيش از ما نازل شده، و ما از آموختن آنان بى‌خبر بوديم.»\qt@no{(156)}}
\qt@newcmd\qurantrans@fa@cmxlvi{يا نگوييد: «اگر كتاب بر ما نازل مى‌شد، قطعاً از آنان هدايت‌يافته‌تر بوديم.» اينك حجّتى از جانب پروردگارتان براى شما آمده و رهنمود و رحمتى است. پس كيست ستمكارتر از آن كس كه آيات خدا را دروغ پندارد و از آنها روى گرداند؟ به زودى كسانى را كه از آيات ما روى مى‌گردانند، به سبب [همين‌] اعراضشان، به عذابى سخت مجازات خواهيم كرد.\qt@no{(157)}}
\qt@newcmd\qurantrans@fa@cmxlvii{آيا جز اين انتظار دارند كه فرشتگان به سويشان بيايند، يا پروردگارت بيايد، يا پاره‌اى از نشانه‌هاى پروردگارت بيايد؟ [اما] روزى كه پاره‌اى از نشانه‌هاى پروردگارت [پديد] آيد، كسى كه قبلاً ايمان نياورده يا خيرى در ايمان آوردن خود به دست نياورده، ايمان آوردنش سود نمى‌بخشد. بگو: «منتظر باشيد كه ما [هم‌] منتظريم.»\qt@no{(158)}}
\qt@newcmd\qurantrans@fa@cmxlviii{كسانى كه دين خود را پراكنده ساختند و فرقه فرقه شدند، تو هيچ گونه مسؤول ايشان نيستى، كارشان فقط با خداست. آنگاه به آنچه انجام مى‌دادند آگاهشان خواهد كرد.\qt@no{(159)}}
\qt@newcmd\qurantrans@fa@cmxlix{هر كس كار نيكى بياورد، ده برابر آن [پاداش‌] خواهد داشت، و هر كس كار بدى بياورد، جز مانند آن جزا نيابد و بر آنان ستم نرود.\qt@no{(160)}}
\qt@newcmd\qurantrans@fa@cml{بگو: «آرى! پروردگارم مرا به راه راست هدايت كرده است: دينى پايدار، آيين ابراهيمِ حق‌گراى! و او از مشركان نبود.»\qt@no{(161)}}
\qt@newcmd\qurantrans@fa@cmli{بگو: «در حقيقت، نماز من و [ساير] عبادات من و زندگى و مرگ من، براى خدا، پروردگار جهانيان است.»\qt@no{(162)}}
\qt@newcmd\qurantrans@fa@cmlii{[كه‌] او را شريكى نيست، و بر اين [كار] دستور يافته‌ام، و من نخستين مسلمانم.\qt@no{(163)}}
\qt@newcmd\qurantrans@fa@cmliii{بگو: «آيا جز خدا پروردگارى بجويم؟ با اينكه او پروردگار هر چيزى است، و هيچ كس جز بر زيان خود [گناهى‌] انجام نمى‌دهد، و هيچ باربردارى بار [گناه‌] ديگرى را برنمى‌دارد، آنگاه بازگشت شما به سوى پروردگارتان خواهد بود، پس ما را به آنچه در آن اختلاف مى‌كرديد آگاه خواهد كرد.\qt@no{(164)}}
\qt@newcmd\qurantrans@fa@cmliv{و اوست كسى كه شما را در زمين جانشين [يكديگر] قرار داد، و بعضى از شما را بر برخى ديگر به درجاتى برترى داد تا شما را در آنچه به شما داده است بيازمايد. آرى، پروردگار تو زودكيفر است، و [هم‌] او بس آمرزنده مهربان است.\qt@no{(165)}}
\qt@newcmd\qurantrans@fa@cmlv{\basmalahfa الف، لام، ميم، صاد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@cmlvi{كتابى است كه به سوى تو فرو فرستاده شده است -پس نبايد در سينه تو از ناحيه آن، تنگى باشد- تا به وسيله آن هشدار دهى و براى مؤمنان پندى باشد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@cmlvii{آنچه را از جانب پروردگارتان به سوى شما فرو فرستاده شده است، پيروى كنيد؛ و جز او از معبودان [ديگر] پيروى مكنيد. چه اندك پند مى‌گيريد!\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@cmlviii{و چه بسيار شهرها كه [مردمِ‌] آن را به هلاكت رسانيديم، و در حالى كه به خواب شبانگاهى رفته يا نيمروز غنوده بودند، عذاب ما به آنها رسيد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@cmlix{و هنگامى كه عذاب ما بر آنان آمد سخنشان جز اين نبود كه گفتند: «راستى كه ما ستمكار بوديم.»\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@cmlx{پس، قطعاً از كسانى كه [پيامبران‌] به سوى آنان فرستاده شده‌اند خواهيم پرسيد، و قطعاً از [خودِ] فرستادگان [نيز] خواهيم پرسيد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@cmlxi{و از روى دانش به آنان گزارش خواهيم داد و ما [از احوال آنان‌] غايب نبوده‌ايم.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@cmlxii{و در آن روز، سنجش [اعمال‌] درست است. پس هر كس ميزانهاى [عمل‌] او گران باشد، آنان خود رستگارانند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@cmlxiii{و هر كس ميزانهاى [عمل‌] او سبك باشد، پس آنانند كه به خود زيان زده‌اند، چرا كه به آيات ما ستم كرده‌اند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@cmlxiv{و قطعاً شما را در زمين قدرت عمل داديم، و براى شما در آن، وسايل معيشت نهاديم، [اما] چه كم سپاسگزارى مى‌كنيد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@cmlxv{و در حقيقت، شما را خلق كرديم، سپس به صورتگرى شما پرداختيم؛ آنگاه به فرشتگان گفتيم: «براى آدم سجده كنيد.» پس [همه‌] سجده كردند، جز ابليس كه از سجده‌كنندگان نبود.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@cmlxvi{فرمود: «چون تو را به سجده امر كردم چه چيز تو را باز داشت از اينكه سجده كنى؟» گفت: «من از او بهترم. مرا از آتشى آفريدى و او را از گِل آفريدى.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@cmlxvii{فرمود: «از آن [مقام‌] فرو شو، تو را نرسد كه در آن [جايگاه‌] تكبّر نمايى. پس بيرون شو كه تو از خوارشدگانى.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@cmlxviii{گفت: «مرا تا روزى كه [مردم‌] برانگيخته خواهند شد مهلت ده.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@cmlxix{فرمود: «تو از مهلت‌يافتگانى.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@cmlxx{گفت: «پس به سبب آنكه مرا به بيراهه افكندى، من هم براى [فريفتن‌] آنان حتماً بر سر راه راست تو خواهم نشست.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@cmlxxi{«آنگاه از پيش رو و از پشت سرشان و از طرف راست و از طرف چپشان بر آنها مى‌تازم، و بيشترشان را شكرگزار نخواهى يافت.»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@cmlxxii{فرمود: «نكوهيده و رانده، از آن [مقام‌] بيرون شو؛ كه قطعاً هر كه از آنان از تو پيروى كند، جهنّم را از همه شما پر خواهم كرد.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@cmlxxiii{«و اى آدم! تو با جفت خويش در آن باغ سكونت گير، و از هر جا كه خواهيد بخوريد، و[لى‌] به اين درخت نزديك مشويد كه از ستمكاران خواهيد شد.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@cmlxxiv{پس شيطان، آن دو را وسوسه كرد تا آنچه را از عورتهايشان برايشان پوشيده مانده بود، براى آنان نمايان گرداند؛ و گفت: «پروردگارتان شما را از اين درخت منع نكرد، جز [براى‌] آنكه [مبادا] دو فرشته گرديد يا از [زمره‌] جاودانان شويد.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@cmlxxv{و براى آن دو سوگند ياد كرد كه: من قطعاً از خيرخواهان شما هستم.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@cmlxxvi{پس آن دو را با فريب به سقوط كشانيد؛ پس چون آن دو از [ميوه‌] آن درختِ [ممنوع‌] چشيدند، برهنگى‌هايشان بر آنان آشكار شد، و به چسبانيدن برگ‌[هاى درختانِ‌] بهشت بر خود آغاز كردند، و پروردگارشان بر آن دو بانگ بر زد: «مگر شما را از اين درخت منع نكردم و به شما نگفتم كه در حقيقت شيطان براى شما دشمنى آشكار است.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@cmlxxvii{گفتند: «پروردگارا، ما بر خويشتن ستم كرديم، و اگر بر ما نبخشايى و به ما رحم نكنى، مسلماً از زيانكاران خواهيم بود.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@cmlxxviii{فرمود: «فرود آييد، كه بعضى از شما دشمن بعضى [ديگر]يد؛ و براى شما در زمين، تا هنگامى [معيّن‌] قرارگاه و برخوردارى است.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@cmlxxix{فرمود: «در آن زندگى مى‌كنيد و در آن مى‌ميريد و از آن برانگيخته خواهيد شد.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@cmlxxx{اى فرزندان آدم، در حقيقت، ما براى شما لباسى فرو فرستاديم كه عورتهاى شما را پوشيده مى‌دارد و [براى شما] زينتى است، و[لى‌] بهترين جامه، [لباس‌] تقوا است. اين از نشانه‌هاى [قدرت‌] خداست، باشد كه متذكّر شوند.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@cmlxxxi{اى فرزندان آدم، زنهار تا شيطان شما را به فتنه نيندازد؛ چنانكه پدر و مادر شما را از بهشت بيرون راند، و لباسشان را از ايشان بركند، تا عورتهايشان را بر آنان نمايان كند. در حقيقت، او و قبيله‌اش، شما را از آنجا كه آنها را نمى‌بينيد، مى‌بينند. ما شياطين را دوستان كسانى قرار داديم كه ايمان نمى‌آورند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@cmlxxxii{و چون كار زشتى كنند، مى‌گويند: «پدران خود را بر آن يافتيم و خدا ما را بدان فرمان داده است.» بگو: «قطعاً خدا به كار زشت فرمان نمى‌دهد، آيا چيزى را كه نمى‌دانيد به خدا نسبت مى‌دهيد؟»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@cmlxxxiii{بگو: «پروردگارم به دادگرى فرمان داده است، و [اينكه‌] در هر مسجدى روى خود را مستقيم [به سوى قبله‌] كنيد، و در حالى كه دين خود را براى او خالص گردانيده‌ايد وى را بخوانيد، همان گونه كه شما را پديد آورد [به سوى او] برمى‌گرديد.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@cmlxxxiv{[در حالى كه‌] گروهى را هدايت نموده، و گروهى گمراهى بر آنان ثابت شده است، زيرا آنان شياطين را به جاى خدا، دوستان [خود] گرفته‌اند و مى‌پندارند كه راه‌يافتگانند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@cmlxxxv{اى فرزندان آدم، جامه خود را در هر نمازى برگيريد، و بخوريد و بياشاميد و[لى‌] زياده‌روى مكنيد كه او اسرافكاران را دوست نمى‌دارد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@cmlxxxvi{[اى پيامبر] بگو: «زيورهايى را كه خدا براى بندگانش پديد آورده، و [نيز ] روزيهاى پاكيزه را چه كسى حرام گردانيده؟» بگو: «اين [نعمتها] در زندگى دنيا براى كسانى است كه ايمان آورده‌اند و روز قيامت [نيز ]خاصّ آنان مى‌باشد.» اين گونه آيات [خود] را براى گروهى كه مى‌دانند به روشنى بيان مى‌كنيم.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@cmlxxxvii{بگو: «پروردگار من فقط زشتكاريها را -چه آشكارش [باشد] و چه پنهان- و گناه و ستم ناحق را حرام گردانيده است؛ و [نيز] اينكه چيزى را شريك خدا سازيد كه دليلى بر [حقّانيّت‌] آن نازل نكرده؛ و اينكه چيزى را كه نمى‌دانيد به خدا نسبت دهيد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@cmlxxxviii{و براى هر امّتى اجلى است؛ پس چون اجلشان فرا رسد، نه [مى‌توانند] ساعتى آن را پس اندازند و نه پيش.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@cmlxxxix{اى فرزندان آدم، چون پيامبرانى از خودتان براى شما بيايند و آيات مرا بر شما بخوانند، پس هر كس به پرهيزگارى و صلاح گرايد، نه بيمى بر آنان خواهد بود و نه اندوهگين مى شوند.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@cmxc{و كسانى كه آيات ما را دروغ انگاشتند و از [پذيرش‌] آنها تكبّر ورزيدند آنان همدم آتشند [و] در آن جاودانند.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@cmxci{پس كيست ستمكارتر از آن كس كه بر خدا دروغ بندد يا آيات او را تكذيب كند؟ اينان كسانى هستند كه نصيبشان از آنچه مقرّر شده به ايشان خواهد رسيد، تا آنگاه كه فرشتگان ما به سراغشان بيايند كه جانشان بستانند، مى‌گويند: «آنچه غير از خدا مى‌خوانديد كجاست؟» مى‌گويند: «از [چشم‌] ما ناپديد شدند» و عليه خود گواهى مى‌دهند كه آنان كافر بودند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@cmxcii{مى‌فرمايد: «در ميان امّتهايى از جنّ و انس، كه پيش از شما بوده‌اند، داخل آتش شويد.» هر بار كه امّتى [در آتش‌] درآيد، همكيشان خود را لعنت كند، تا وقتى كه همگى در آن به هم پيوندند؛ [آنگاه‌] پيروانشان در باره پيشوايانشان مى‌گويند: «پروردگارا، اينان ما را گمراه كردند، پس دو برابر عذاب آتش به آنان بده.» [خدا] مى‌فرمايد: «براى هر كدام [عذاب‌] دو چندان است ولى شما نمى‌دانيد.»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@cmxciii{و پيشوايانشان به پيروانشان مى‌گويند: «شما را بر ما امتيازى نيست. پس به سزاى آنچه به دست مى‌آورديد عذاب را بچشيد.»\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@cmxciv{در حقيقت، كسانى كه آيات ما را دروغ شمردند و از [پذيرفتن‌] آنها تكبّر ورزيدند، درهاى آسمان را برايشان نمى‌گشايند و در بهشت درنمى‌آيند مگر آنكه شتر در سوراخ سوزن داخل شود. و بدينسان بزهكاران را كيفر مى‌دهيم.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@cmxcv{براى آنان از جهنّم بسترى و از بالايشان پوششهاست، و اين گونه بيدادگران را سزا مى‌دهيم.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@cmxcvi{و كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند -هيچ كسى را جز به قدر توانش تكليف نمى‌كنيم- آنان همدم بهشتند [كه‌] در آن جاودانند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@cmxcvii{و هر گونه كينه‌اى را از سينه‌هايشان مى‌زداييم. از زير [قصرهاى‌]شان نهرها جارى است، و مى‌گويند: «ستايش خدايى را كه ما را بدين [راه‌] هدايت نمود، و اگر خدا ما را رهبرى نمى‌كرد ما خود هدايت نمى‌يافتيم. در حقيقت، فرستادگانِ پروردگارِ ما حق را آوردند.» و به آنان ندا داده مى‌شود كه اين همان بهشتى است كه آن را به [پاداش‌] آنچه انجام مى‌داديد ميراث يافته‌ايد.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@cmxcviii{و بهشتيان، دوزخيان را آواز مى‌دهند كه: «ما آنچه را پروردگارمان به ما وعده داده بود درست يافتيم؛ آيا شما [نيز] آنچه را پروردگارتان وعده كرده بود راست و درست يافتيد؟» مى‌گويند: «آرى.» پس آوازدهنده‌اى ميان آنان آواز درمى‌دهد كه: «لعنت خدا بر ستمكاران باد.»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@cmxcix{همانان كه [مردم را] از راه خدا باز مى‌دارند و آن را كج مى‌خواهند و آنها آخرت را منكرند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@m{و ميان آن دو [گروه‌]، حايلى است، و بر اعراف، مردانى هستند كه هر يك [از آن دو دسته‌] را از سيمايشان مى‌شناسند، و بهشتيان را -كه هنوز وارد آن نشده و[لى‌] [بدان‌] اميد دارند- آواز مى‌دهند كه: «سلام بر شما.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mi{و چون چشمانشان به سوى دوزخيان گردانيده شود، مى‌گويند: «پروردگارا، ما را در زمره گروه ستمكاران قرار مده.»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mii{و اهل اَعراف، مردانى را كه آنان را از سيمايشان مى‌شناسند، ندا مى دهند [و] مى‌گويند: «جمعيّت شما و آن [همه‌] گردنكشى كه مى‌كرديد، به حال شما سودى نداشت.»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@miii{«آيا اينان همان كسان نبودند كه سوگند ياد مى‌كرديد كه خدا آنان را به رحمتى نخواهد رسانيد؟» « [اينك‌] به بهشت درآييد. نه بيمى بر شماست و نه اندوهگين مى‌شويد.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@miv{و دوزخيان، بهشتيان را آواز مى‌دهند كه: «از آن آب يا از آنچه خدا روزىِ شما كرده، بر ما فرو ريزيد.» مى‌گويند: «خدا آنها را بر كافران حرام كرده است.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mv{همانان كه دين خود را سرگرمى و بازى پنداشتند، و زندگى دنيا مغرورشان كرد. پس همان گونه كه آنان ديدار امروز خود را از ياد بردند، و آيات ما را انكار مى‌كردند، ما [هم‌] امروز آنان را از ياد مى‌بريم.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mvi{و در حقيقت، ما براى آنان كتابى آورديم كه آن را از روى دانش، روشن و شيوايش ساخته‌ايم، و براى گروهى كه ايمان مى‌آورند هدايت و رحمتى است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mvii{آيا [آنان‌] جز در انتظار تأويل آنند؟ روزى كه تأويلش فرا رسد، كسانى كه آن را پيش از آن به فراموشى سپرده‌اند مى‌گويند: «حقاً فرستادگان پروردگار ما حق را آوردند. پس آيا [امروز] ما را شفاعتگرانى هست كه براى ما شفاعت كنند يا [ممكن است به دنيا] بازگردانيده شويم، تا غير از آنچه انجام مى‌داديم انجام دهيم؟» به راستى كه [آنان‌] به خويشتن زيان زدند، و آنچه را به دروغ مى‌ساختند از كف دادند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mviii{در حقيقت، پروردگار شما آن خدايى است كه آسمانها و زمين را در شش روز آفريد؛ سپس بر عرش [جهاندارى‌] استيلا يافت. روز را به شب -كه شتابان آن را مى طلبد- مى‌پوشاند، و [نيز] خورشيد و ماه و ستارگان را كه به فرمان او رام شده‌اند [پديد آورد]. آگاه باش كه [عالم‌] خلق و امر از آن اوست. فرخنده خدايى است پروردگار جهانيان.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mix{پروردگار خود را به زارى و نهانى بخوانيد كه او از حدگذرندگان را دوست نمى‌دارد.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mx{و در زمين پس از اصلاح آن فساد مكنيد، و با بيم و اميد او را بخوانيد كه رحمت خدا به نيكوكاران نزديك است.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mxi{و اوست كه بادها را پيشاپيش [باران‌] رحمتش مژده‌رسان مى‌فرستد، تا آن گاه كه ابرهاى گرانبار را بردارند، آن را به سوى سرزمينى مرده برانيم، و از آن، باران فرود آوريم؛ و از هر گونه ميوه‌اى [از خاك ]برآوريم. بدينسان مردگان را [نيز از قبرها] خارج مى‌سازيم، باشد كه شما متذكر شويد.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mxii{و زمين پاك [و آماده‌]، گياهش به اذن پروردگارش برمى‌آيد؛ و آن [زمينى‌] كه ناپاك [و نامناسب‌] است [گياهش‌] جز اندك و بى‌فايده برنمى‌آيد. اين گونه، آيات [خود] را براى گروهى كه شكر مى‌گزارند، گونه‌گون بيان مى‌كنيم.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mxiii{همانا نوح را به سوى قومش فرستاديم. پس گفت: «اى قوم من، خدا را بپرستيد كه براى شما معبودى جز او نيست، من از عذاب روزى سترگ بر شما بيمناكم.»\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mxiv{سران قومش گفتند: «واقعاً ما تو را در گمراهى آشكارى مى‌بينيم.»\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mxv{گفت: «اى قوم من، هيچ گونه گمراهى در من نيست، بلكه من فرستاده‌اى از جانب پروردگار جهانيانم.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mxvi{پيامهاى پروردگارم را به شما مى‌رسانم و اندرزتان مى‌دهم و چيزهايى از خدا مى‌دانم كه [شما] نمى‌دانيد.»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mxvii{آيا تعجب كرديد كه بر مردى از خودتان، پندى از جانب پروردگارتان براى شما آمده تا شما را بيم دهد و تا شما پرهيزگارى كنيد و باشد كه مورد رحمت قرار گيريد؟\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mxviii{پس او را تكذيب كردند، و ما او و كسانى را كه با وى در كشتى بودند نجات داديم؛ و كسانى را كه آيات ما را دروغ پنداشتند غرق كرديم، زيرا آنان گروهى كور[دل‌] بودند.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mxix{و به سوى عاد، برادرشان هود را [فرستاديم‌]؛ گفت: «اى قوم من، خدا را بپرستيد كه براى شما معبودى جز او نيست، پس آيا پرهيزگارى نمى‌كنيد؟»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mxx{سران قومش كه كافر بودند گفتند: «در حقيقت، ما تو را در [نوعى‌] سفاهت مى‌بينيم و جداً تو را از دروغگويان مى‌پنداريم.»\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mxxi{گفت: «اى قوم من، در من سفاهتى نيست، ولى من فرستاده‌اى از جانب پروردگار جهانيانم.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mxxii{پيامهاى پروردگارم را به شما مى‌رسانم و براى شما خير خواهى امينم.»\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mxxiii{آيا تعجب كرديد كه بر مردى از خودتان، پندى از جانب پروردگارتان براى شما آمده تا شما را هشدار دهد؟ و به خاطر آوريد زمانى را كه [خداوند] شما را پس از قوم نوح، جانشينان [آنان‌] قرار داد، و در خلقت، بر قوّت شما افزود. پس نعمتهاى خدا را به ياد آوريد، باشد كه رستگار شويد.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mxxiv{گفتند: «آيا به سوى ما آمده‌اى كه تنها خدا را بپرستيم و آنچه را كه پدرانمان مى پرستيدند رها كنيم؟ اگر راست مى‌گويى، آنچه را به ما وعده مى‌دهى براى ما بياور.»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mxxv{گفت: «راستى كه عذاب و خشمى [سخت‌] از پروردگارتان بر شما مقرر گرديده است. آيا در باره نامهايى كه خود و پدرانتان [براى بتها] نامگذارى كرده‌ايد، و خدا بر [حقانيت‌] آنها برهانى فرو نفرستاده با من مجادله مى‌كنيد؟ پس منتظر باشيد كه من [هم‌] با شما از منتظرانم.»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mxxvi{پس او و كسانى را كه با او بودند به رحمتى از خود رهانيديم؛ و كسانى را كه آيات ما را دروغ شمردند و مؤمن نبودند ريشه‌كن كرديم.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mxxvii{و به سوى [قوم‌] ثمود، صالح، برادرشان را [فرستاديم‌]؛ گفت: «اى قوم من، خدا را بپرستيد، براى شما معبودى جز او نيست؛ در حقيقت، براى شما از جانب پروردگارتان دليلى آشكار آمده است. اين، ماده‌شتر خدا براى شماست كه پديده‌اى شگرف است. پس آن را بگذاريد تا در زمين خدا بخورد و گزندى به او نرسانيد تا [مبادا] شما را عذابى دردناك فرو گيرد.»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mxxviii{و به ياد آوريد هنگامى را كه شما را پس از [قوم‌] عاد جانشينان [آنان‌] گردانيد، و در زمين به شما جاىِ [مناسب‌] داد. در دشتهاى آن [براى خود] كاخهايى اختيار مى كرديد، و از كوهها خانه‌هايى [زمستانى ]مى‌تراشيديد. پس نعمتهاى خدا را به ياد آوريد و در زمين سر به فساد برمداريد.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mxxix{سران قوم او كه استكبار مى‌ورزيدند، به مستضعفانى كه ايمان آورده بودند، گفتند: «آيا مى‌دانيد كه صالح از طرف پروردگارش فرستاده شده است؟» گفتند: «بى‌ترديد، ما به آنچه وى بدان رسالت يافته است مؤمنيم.»\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mxxx{كسانى كه استكبار مى‌ورزيدند، گفتند: «ما به آنچه شما بدان ايمان آورده‌ايد كافريم.»\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mxxxi{پس آن ماده‌شتر را پى كردند و از فرمان پروردگار خود سرپيچيدند و گفتند: «اى صالح، اگر از پيامبرانى، آنچه را به ما وعده مى‌دهى براى ما بياور.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mxxxii{آنگاه زمين‌لرزه آنان را فرو گرفت و در خانه هايشان از پا درآمدند.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mxxxiii{پس [صالح‌] از ايشان روى برتافت و گفت: «اى قوم من، به راستى، من پيام پروردگارم را به شما رساندم و خير شما را خواستم ولى شما [خيرخواهان و نصيحتگران‌] را دوست نمى‌داريد.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mxxxiv{و لوط را [فرستاديم‌] هنگامى كه به قوم خود گفت: «آيا آن كار زشت‌[ى‌] را مرتكب مى‌شويد، كه هيچ كس از جهانيان در آن بر شما پيشى نگرفته است؟\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mxxxv{شما از روى شهوت، به جاى زنان با مردان درمى‌آميزيد، آرى، شما گروهى تجاوزكاريد.»\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mxxxvi{ولى پاسخ قومش جز اين نبود كه گفتند: «آنان را از شهرتان بيرون كنيد، زيرا آنان كسانى‌اند كه به پاكى تظاهر مى‌كنند.»\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mxxxvii{پس او و خانواده‌اش را -غير از زنش كه از زمره باقيماندگانِ [در خاكستر مواد گوگردى‌] بود- نجات داديم.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mxxxviii{و بر سر آنان بارشى [از مواد گوگردى‌] بارانيديم. پس ببين فرجام گنهكاران چسان بود.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mxxxix{و به سوى [مردم‌] مدين، برادرشان شعيب را [فرستاديم‌]؛ گفت: «اى قوم من، خدا را بپرستيد كه براى شما هيچ معبودى جز او نيست. در حقيقت، شما را از جانب پروردگارتان برهانى روشن آمده است. پس پيمانه و ترازو را تمام نهيد، و اموال مردم را كم مدهيد، و در زمين، پس از اصلاح آن فساد مكنيد. اين [رهنمودها] اگر مؤمنيد براى شما بهتر است.»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mxl{و بر سر هر راهى منشينيد كه [مردم را] بترسانيد و كسى را كه ايمان به خدا آورده از راه خدا باز داريد و راه او را كج بخواهيد؛ و به ياد آوريد هنگامى را كه اندك بوديد، پس شما را بسيار گردانيد، و بنگريد كه فرجام فسادكاران چگونه بوده است.»\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mxli{و اگر گروهى از شما به آنچه من بدان فرستاده شده‌ام ايمان آورده و گروه ديگر ايمان نياورده‌اند، صبر كنيد تا خدا ميان ما داورى كند [كه‌] او بهترين داوران است.»\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mxlii{سران قومش كه تكبر مى‌ورزيدند، گفتند: «اى شعيب، يا تو و كسانى را كه با تو ايمان آورده‌اند، از شهر خودمان بيرون خواهيم كرد؛ يا به كيش ما برگرديد.» گفت: «آيا هر چند كراهت داشته باشيم؟»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mxliii{اگر بعد از آنكه خدا ما را از آن نجات بخشيده [باز] به كيش شما برگرديم، در حقيقت به خدا دروغ بسته‌ايم؛ و ما را سزاوار نيست كه به آن بازگرديم، مگر آنكه خدا، پروردگار ما بخواهد. [كه‌] پروردگار ما از نظر دانش بر هر چيزى احاطه دارد. بر خدا توكل كرده‌ايم. بار پروردگارا، ميان ما و قوم ما به حق داورى كن كه تو بهترين داورانى.»\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mxliv{و سران قومش كه كافر بودند گفتند: «اگر از شعيب پيروى كنيد، در اين صورت قطعاً زيانكاريد.»\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mxlv{پس زمين‌لرزه آنان را فرو گرفت، و در خانه‌هايشان از پا درآمدند.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mxlvi{كسانى كه شعيب را تكذيب كرده بودند، گويى خود در آن [ديار] سكونت نداشتند. كسانى كه شعيب را تكذيب كرده بودند، خود، همان زيانكاران بودند.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mxlvii{پس [شعيب‌] از ايشان روى برتافت و گفت: «اى قوم من، به راستى كه پيامهاى پروردگارم را به شما رسانيدم و پندتان دادم؛ ديگر چگونه بر گروهى كه كافرند دريغ بخورم؟»\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mxlviii{و در هيچ شهرى، پيامبرى نفرستاديم مگر آنكه مردمش را به سختى و رنج دچار كرديم تا مگر به زارى درآيند.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mxlix{آنگاه به جاى بدى [=بلا]، نيكى [=نعمت‌] قرار داديم تا انبوه شدند و گفتند: «پدران ما را [هم مسلماً به حكم طبيعت‌] رنج و راحت مى‌رسيده است.» پس در حالى كه بى خبر بودند بناگاه [گريبان‌] آنان را گرفتيم.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@ml{و اگر مردم شهرها ايمان آورده و به تقوا گراييده بودند، قطعاً بركاتى از آسمان و زمين برايشان مى‌گشوديم، ولى تكذيب كردند؛ پس به [كيفر] دستاوردشان [گريبان‌] آنان را گرفتيم.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mli{آيا ساكنان شهرها ايمن شده‌اند از اينكه عذاب ما شامگاهان -در حالى كه به خواب فرو رفته‌اند- به آنان برسد؟\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mlii{و آيا ساكنان شهرها ايمن شده‌اند از اينكه عذاب ما نيمروز -در حالى كه به بازى سرگرمند- به ايشان دررسد؟\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mliii{آيا از مكر خدا خود را ايمن دانستند؟ [با آنكه‌] جز مردم زيانكار [كسى‌] خود را از مكر خدا ايمن نمى‌داند.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mliv{مگر براى كسانى كه زمين را پس از ساكنان [پيشين‌] آن به ارث مى‌برند، باز ننموده است كه اگر مى‌خواستيم آنان را به [كيفر] گناهانشان مى‌رسانديم و بر دلهايشان مُهر مى‌نهاديم تا ديگر نشنوند.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mlv{اين شهرهاست كه برخى از خبرهاى آن را بر تو حكايت مى‌كنيم. در حقيقت، پيامبرانشان دلايل روشن برايشان آوردند. اما آنان به آنچه قبلاً تكذيب كرده بودند [باز] ايمان نمى‌آوردند. اين گونه خدا بر دلهاى كافران مُهر مى‌نهد.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mlvi{و در بيشتر آنان عهدى [استوار] نيافتيم و بيشترشان را جداً نافرمان يافتيم.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mlvii{آنگاه بعد از آنان، موسى را با آيات خود به سوى فرعون و سران قومش فرستاديم. ولى آنها به آن [آيات‌] كفر ورزيدند. پس ببين فرجام مفسدان چگونه بود.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mlviii{و موسى گفت: «اى فرعون، بى‌ترديد، من پيامبرى از سوى پروردگار جهانيانم.»\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mlix{شايسته است كه بر خدا جز [سخن‌] حق نگويم. من در حقيقت دليلى روشن از سوى پروردگارتان براى شما آورده‌ام، پس فرزندان اسرائيل را همراه من بفرست.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mlx{[فرعون‌] گفت: «اگر معجزه‌اى آورده‌اى، پس اگر راست مى‌گويى آن را ارائه بده.»\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mlxi{پس [موسى‌] عصايش را افكند و بناگاه اژدهايى آشكار شد.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mlxii{و دست خود را [از گريبان‌] بيرون كشيد و ناگهان براى تماشاگران سپيد [و درخشنده‌] بود.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mlxiii{سران قوم فرعون گفتند: «بى‌شك، اين [مرد] ساحرى داناست.»\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mlxiv{مى‌خواهد شما را از سرزمينتان بيرون كند. پس چه دستور مى‌دهيد؟\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mlxv{گفتند: «او و برادرش را بازداشت كن، و گردآورندگانى را به شهرها بفرست.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mlxvi{تا هر ساحر دانايى را نزد تو آرند.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mlxvii{و ساحران نزد فرعون آمدند [و] گفتند: «[آيا] اگر ما پيروز شويم براى ما پاداشى خواهد بود؟»\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@mlxviii{گفت: «آرى، و مسلماً شما از مقربان [دربار من‌] خواهيد بود.»\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@mlxix{گفتند: «اى موسى، آيا تو مى‌افكنى و يا اينكه ما مى‌افكنيم؟»\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@mlxx{گفت: «شما بيفكنيد.» و چون افكندند، ديدگان مردم را افسون كردند و آنان را به ترس انداختند و سحرى بزرگ در ميان آوردند.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@mlxxi{و به موسى وحى كرديم كه: «عصايت را بينداز»؛ پس [انداخت و اژدها شد] و ناگهان آنچه را به دروغ ساخته بودند فرو بلعيد.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@mlxxii{پس حقيقت آشكار گرديد و كارهايى كه مى‌كردند باطل شد.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@mlxxiii{و در آنجا مغلوب و خوار گرديدند.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@mlxxiv{و ساحران به سجده درافتادند.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@mlxxv{[و] گفتند: «به پروردگار جهانيان ايمان آورديم،\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@mlxxvi{پروردگار موسى و هارون.\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@mlxxvii{فرعون گفت: «آيا پيش از آنكه به شما رخصت دهم، به او ايمان آورديد؟ قطعاً اين نيرنگى است كه در شهر به راه انداخته‌ايد تا مردمش را از آن بيرون كنيد. پس به زودى خواهيد دانست.»\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@mlxxviii{دستها و پاهايتان را يكى از چپ و يكى از راست خواهم بريد سپس همه شما را به دار خواهم آويخت.\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@mlxxix{گفتند: «ما به سوى پروردگارمان بازخواهيم گشت.\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@mlxxx{و تو جز براى اين ما را به كيفر نمى‌رسانى كه ما به معجزات پروردگارمان -وقتى براى ما آمد- ايمان آورديم. پروردگارا، بر ما شكيبايى فرو ريز و ما را مسلمان بميران.»\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@mlxxxi{و سران قوم فرعون گفتند: «آيا موسى و قومش را رها مى‌كنى تا در اين سرزمين فساد كنند و [موسى‌] تو و خدايانت را رها كند؟» [فرعون‌] گفت: «بزودى پسرانشان را مى‌كُشيم و زنانشان را زنده نگاه مى‌داريم، و ما بر آنان مسلطيم.»\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@mlxxxii{موسى به قوم خود گفت: «از خدا يارى جوييد و پايدارى ورزيد، كه زمين از آنِ خداست؛ آن را به هر كس از بندگانش كه بخواهد مى‌دهد؛ و فرجام [نيك‌] براى پرهيزگاران است.»\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@mlxxxiii{[قوم موسى‌] گفتند: «پيش از آنكه تو نزد ما بيايى و [حتى‌] بعد از آنكه به سوى ما آمدى مورد آزار قرار گرفتيم.» گفت: «اميد است كه پروردگارتان دشمن شما را هلاك كند و شما را روى زمين جانشين [آنان ]سازد؛ آنگاه بنگرد تا چگونه عمل مى‌كنيد.»\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@mlxxxiv{و در حقيقت، ما فرعونيان را به خشكسالى و كمبود محصولات دچار كرديم باشد كه عبرت گيرند.\qt@no{(130)}}
\qt@newcmd\qurantrans@fa@mlxxxv{پس هنگامى كه نيكى [و نعمت‌] به آنان روى مى‌آورد مى‌گفتند: «اين براى [شايستگى‌] خود ماست» و چون گزندى به آنان مى‌رسيد، به موسى و همراهانش شگون بد مى‌زدند. آگاه باشيد كه [سرچشمه ]بدشگونى آنان تنها نزد خداست [كه آنان را به بدى اعمالشان كيفر مى‌دهد]، ليكن بيشترشان نمى‌دانستند.\qt@no{(131)}}
\qt@newcmd\qurantrans@fa@mlxxxvi{و گفتند: «هر گونه پديده شگرفى كه به وسيله آن ما را افسون كنى براى ما بياورى، ما به تو ايمان آورنده نيستيم.»\qt@no{(132)}}
\qt@newcmd\qurantrans@fa@mlxxxvii{پس بر آنان طوفان و ملخ و كنه ريز و غوكها و خون را به صورت نشانه‌هايى آشكار فرستاديم و باز سركشى كردند و گروهى بدكار بودند.\qt@no{(133)}}
\qt@newcmd\qurantrans@fa@mlxxxviii{و هنگامى كه عذاب بر آنان فرود آمد، گفتند: «اى موسى، پروردگارت را به عهدى كه نزد تو دارد براى ما بخوان، اگر اين عذاب را از ما برطرف كنى حتماً به تو ايمان خواهيم آورد و بنى‌اسرائيل را قطعاً با تو روانه خواهيم ساخت.»\qt@no{(134)}}
\qt@newcmd\qurantrans@fa@mlxxxix{و چون عذاب را -تا سررسيدى كه آنان بدان رسيدند- از آنها برداشتيم باز هم پيمان‌شكنى كردند.\qt@no{(135)}}
\qt@newcmd\qurantrans@fa@mxc{سرانجام از آنان انتقام گرفتيم و در دريا غرقشان ساختيم، چرا كه آيات ما را تكذيب كردند و از آنها غافل بودند.\qt@no{(136)}}
\qt@newcmd\qurantrans@fa@mxci{و به آن گروهى كه پيوسته تضعيف مى‌شدند، [بخشهاى‌] باختر و خاورى سرزمين [فلسطين‌] را -كه در آن بركت قرار داده بوديم- به ميراث عطا كرديم. و به پاس آنكه صبر كردند، وعده نيكوى پروردگارت به فرزندان اسرائيل تحقق يافت، و آنچه را كه فرعون و قومش ساخته و افراشته بودند ويران كرديم.\qt@no{(137)}}
\qt@newcmd\qurantrans@fa@mxcii{و فرزندان اسرائيل را از دريا گذرانديم. تا به قومى رسيدند كه بر [پرستش‌] بتهاى خويش همت مى‌گماشتند. گفتند: «اى موسى، همان گونه كه براى آنان خدايانى است، براى ما [نيز] خدايى قرار ده.» گفت: «راستى شما نادانى مى‌كنيد.»\qt@no{(138)}}
\qt@newcmd\qurantrans@fa@mxciii{در حقيقت، آنچه ايشان در آنند نابود [و زايل‌] و آنچه انجام مى‌دادند باطل است.\qt@no{(139)}}
\qt@newcmd\qurantrans@fa@mxciv{گفت: «آيا غير از خدا معبودى براى شما بجويم، با اينكه او شما را بر جهانيان برترى داده است؟»\qt@no{(140)}}
\qt@newcmd\qurantrans@fa@mxcv{و [ياد كن‌] هنگامى را كه شما را از فرعونيان نجات داديم كه شما را سخت شكنجه مى‌كردند: پسرانتان را مى‌كشتند و زنانتان را زنده باقى مى‌گذاشتند و در اين، براى شما آزمايشِ بزرگى از جانب پروردگارتان بود.\qt@no{(141)}}
\qt@newcmd\qurantrans@fa@mxcvi{و با موسى، سى شب وعده گذاشتيم و آن را با ده شب ديگر تمام كرديم. تا آنكه وقت معين پروردگارش در چهل شب به سر آمد. و موسى [هنگام رفتن به كوه طور] به برادرش هارون گفت: «در ميان قوم من جانشينم باش، و [كار آنان را] اصلاح كن، و راه فسادگران را پيروى مكن.»\qt@no{(142)}}
\qt@newcmd\qurantrans@fa@mxcvii{و چون موسى به ميعاد ما آمد و پروردگارش با او سخن گفت، عرض كرد: «پروردگارا، خود را به من بنماى تا بر تو بنگرم.» فرمود: «هرگز مرا نخواهى ديد، ليكن به كوه بنگر؛ پس اگر بر جاى خود قرار گرفت به زودى مرا خواهى ديد. « پس چون پروردگارش به كوه جلوه نمود، آن را ريز ريز ساخت، و موسى بيهوش بر زمين افتاد، و چون به خود آمد، گفت: «تو منزهى! به درگاهت توبه كردم و من نخستين مؤمنانم.»\qt@no{(143)}}
\qt@newcmd\qurantrans@fa@mxcviii{فرمود: «اى موسى، تو را با رسالتها و با سخن گفتنم [با تو]، بر مردم [روزگار] برگزيدم؛ پس آنچه را به تو دادم بگير و از سپاسگزاران باش.»\qt@no{(144)}}
\qt@newcmd\qurantrans@fa@mxcix{و در الواح [تورات‌] براى او در هر موردى پندى، و براى هر چيزى تفصيلى نگاشتيم، پس [فرموديم:] «آن را به جدّ و جهد بگير و قوم خود را وادار كن كه بهترين آن را فرا گيرند، به زودى سراى نافرمانان را به شما مى‌نمايانم.»\qt@no{(145)}}
\qt@newcmd\qurantrans@fa@mc{به زودى كسانى را كه در زمين، بناحق تكبّر مى‌ورزند، از آياتم رويگردان سازم [به طورى كه‌] اگر هر نشانه‌اى را [از قدرت من‌] بنگرند، بدان ايمان نياورند، و اگر راه صواب را ببينند آن را برنگزينند، و اگر راه گمراهى را ببينند آن را راه خود قرار دهند. اين بدان سبب است كه آنان آيات ما را دروغ انگاشته و غفلت ورزيدند.\qt@no{(146)}}
\qt@newcmd\qurantrans@fa@mci{و كسانى كه آيات ما و ديدار آخرت را دروغ پنداشتند، اعمالشان تباه شده است. آيا جز در برابر آنچه مى‌كردند كيفر مى‌بينند؟\qt@no{(147)}}
\qt@newcmd\qurantrans@fa@mcii{و قوم موسى پس از [عزيمت‌] او، از زيورهاى خود مجسمه گوساله‌اى براى خود ساختند كه صداى گاو داشت. آيا نديدند كه آن [گوساله‌] با ايشان سخن نمى‌گويد و راهى بدانها نمى‌نمايد؟ آن را [به پرستش ]گرفتند و ستمكار بودند.\qt@no{(148)}}
\qt@newcmd\qurantrans@fa@mciii{و چون انگشت ندامت گِزيدند و دانستند كه واقعاً گمراه شده‌اند گفتند: «اگر پروردگار ما به ما رحم نكند و ما را نبخشايد قطعاً از زيانكاران خواهيم بود.»\qt@no{(149)}}
\qt@newcmd\qurantrans@fa@mciv{و چون موسى، خشمناك و اندوهگين به سوى قوم خود بازگشت، گفت: «پس از من چه بد جانشينى براى من بوديد! آيا بر فرمان پروردگارتان پيشى گرفتيد؟ و الواح را افكند و [موى‌] سر برادرش را گرفت و او را به طرف خود كشيد. [هارون ] گفت: « اى فرزند مادرم، اين قوم، مرا ناتوان يافتند و چيزى نمانده بود كه مرا بكشند؛ پس مرا دشمن‌شاد مكن و مرا در شمار گروه ستمكاران قرار مده.\qt@no{(150)}}
\qt@newcmd\qurantrans@fa@mcv{[موسى‌] گفت: «پروردگارا، من و برادرم را بيامرز و ما را در [پناه‌] رحمت خود درآور، و تو مهربانترين مهربانانى.»\qt@no{(151)}}
\qt@newcmd\qurantrans@fa@mcvi{آرى، كسانى كه گوساله را [به پرستش‌] گرفتند، به زودى خشمى از پروردگارشان و ذلّتى در زندگى دنيا به ايشان خواهد رسيد؛ و ما اين گونه، دروغ‌پردازان را كيفر مى‌دهيم.\qt@no{(152)}}
\qt@newcmd\qurantrans@fa@mcvii{و[لى‌] كسانى كه مرتكب گناهان شدند، آنگاه توبه كردند و ايمان آوردند، قطعاً پروردگار تو پس از آن آمرزنده مهربان خواهد بود.\qt@no{(153)}}
\qt@newcmd\qurantrans@fa@mcviii{و چون خشم موسى فرو نشست، الواح را برگرفت، و در رونويس آن، براى كسانى كه از پروردگارشان بيمناك بودند، هدايت و رحمتى بود.\qt@no{(154)}}
\qt@newcmd\qurantrans@fa@mcix{و موسى از ميان قوم خود هفتاد مرد براى ميعاد ما برگزيد، و چون زلزله، آنان را فرو گرفت، گفت: «پروردگارا، اگر مى‌خواستى، آنان را و مرا پيش از اين هلاك مى‌ساختى. آيا ما را به [سزاى‌] آنچه كم‌خردان ما كرده‌اند هلاك مى‌كنى؟ اين جز آزمايش تو نيست؛ هر كه را بخواهى به وسيله آن گمراه و هر كه را بخواهى هدايت مى‌كنى؛ تو سرور مايى؛ پس ما را بيامرز و به ما رحم كن، و تو بهترين آمرزندگانى.»\qt@no{(155)}}
\qt@newcmd\qurantrans@fa@mcx{«و براى ما در اين دنيا نيكى مقرّر فرما و در آخرت [نيز]، زيرا كه ما به سوى تو بازگشته‌ايم.» فرمود: «عذاب خود را به هر كس بخواهم مى‌رسانم، و رحمتم همه چيز را فرا گرفته است؛ و به زودى آن را براى كسانى كه پرهيزگارى مى‌كنند و زكات مى‌دهند و آنان كه به آيات ما ايمان مى‌آورند، مقرّر مى‌دارم.»\qt@no{(156)}}
\qt@newcmd\qurantrans@fa@mcxi{همانان كه از اين فرستاده، پيامبر درس نخوانده -كه [نام‌] او را نزد خود، در تورات و انجيل نوشته مى‌يابند- پيروى مى‌كنند؛ [همان پيامبرى كه‌] آنان را به كار پسنديده فرمان مى‌دهد، و از كار ناپسند باز مى‌دارد، و براى آنان چيزهاى پاكيزه را حلال و چيزهاى ناپاك را بر ايشان حرام مى‌گرداند، و از [دوش‌] آنان قيد و بندهايى را كه بر ايشان بوده است برمى‌دارد. پس كسانى كه به او ايمان آوردند و بزرگش داشتند و ياريش كردند و نورى را كه با او نازل شده است پيروى كردند، آنان همان رستگارانند.\qt@no{(157)}}
\qt@newcmd\qurantrans@fa@mcxii{بگو: «اى مردم، من پيامبر خدا به سوى همه شما هستم، همان [خدايى‌] كه فرمانروايى آسمانها و زمين از آن اوست. هيچ معبودى جز او نيست؛ كه زنده مى‌كند و مى‌ميراند. پس به خدا و فرستاده او -كه پيامبر درس‌نخوانده‌اى است كه به خدا و كلمات او ايمان دارد- بگرويد و او را پيروى كنيد، اميد كه هدايت شويد.»\qt@no{(158)}}
\qt@newcmd\qurantrans@fa@mcxiii{و از ميان قوم موسى جماعتى هستند كه به حق راهنمايى مى‌كنند و به حق داورى مى‌نمايند.\qt@no{(159)}}
\qt@newcmd\qurantrans@fa@mcxiv{و آنان را به دوازده عشيره كه هر يك امتى بودند تقسيم كرديم، و به موسى -وقتى قومش از او آب خواستند- وحى كرديم كه با عصايت بر آن تخته سنگ بزن. پس، از آن، دوازده چشمه جوشيد. هر گروهى آبشخور خود را بشناخت؛ و ابر را بر فراز آنان سايبان كرديم، و گزانگبين و بلدرچين بر ايشان فرو فرستاديم. از چيزهاى پاكيزه‌اى كه روزيتان كرده‌ايم بخوريد. و بر ما ستم نكردند، ليكن بر خودشان ستم مى‌كردند.\qt@no{(160)}}
\qt@newcmd\qurantrans@fa@mcxv{و [ياد كن‌] هنگامى را كه بديشان گفته شد: «در اين شهر سكونت گزينيد، و از آن -هر جا كه خواستيد- بخوريد، و بگوييد: [خداوندا،] گناهان ما را فرو ريز. و سجده‌كنان از دروازه [شهر] درآييد، تا گناهان شما را بر شما ببخشاييم [و] به زودى بر [اجر] نيكوكاران بيفزاييم.»\qt@no{(161)}}
\qt@newcmd\qurantrans@fa@mcxvi{پس، كسانى از آنان كه ستم كردند، سخنى را كه به ايشان گفته شده بود به سخن ديگرى تبديل كردند. پس به سزاى آنكه ستم مى‌ورزيدند، عذابى از آسمان بر آنان فرو فرستاديم.\qt@no{(162)}}
\qt@newcmd\qurantrans@fa@mcxvii{و از اهالى آن شهرى كه كنار دريا بود، از ايشان جويا شو: آنگاه كه به [حكم‌] روز شنبه تجاوز مى‌كردند؛ آنگاه كه روز شنبه آنان، ماهيهايشان روى آب مى‌آمدند، و روزهاى غير شنبه به سوى آنان نمى‌آمدند. اين گونه ما آنان را به سبب آنكه نافرمانى مى‌كردند، مى‌آزموديم.\qt@no{(163)}}
\qt@newcmd\qurantrans@fa@mcxviii{و آنگاه كه گروهى از ايشان گفتند: «براى چه قومى را كه خدا هلاك‌كننده ايشان است، يا آنان را به عذابى سخت عذاب خواهد كرد، پند مى‌دهيد؟» گفتند: «تا معذرتى پيش پروردگارتان باشد، و شايد كه آنان پرهيزگارى كنند.»\qt@no{(164)}}
\qt@newcmd\qurantrans@fa@mcxix{پس هنگامى كه آنچه را بدان تذكر داده شده بودند، از ياد بردند، كسانى را كه از [كارِ] بد باز مى‌داشتند نجات داديم؛ و كسانى را كه ستم كردند، به سزاى آنكه نافرمانى مى‌كردند، به عذابى شديد گرفتار كرديم.\qt@no{(165)}}
\qt@newcmd\qurantrans@fa@mcxx{و چون از آنچه از آن نهى شده بودند سرپيچى كردند، به آنان گفتيم: «بوزينگانى رانده‌شده باشيد.»\qt@no{(166)}}
\qt@newcmd\qurantrans@fa@mcxxi{و [ياد كن‌] هنگامى را كه پروردگارت اعلام داشت كه تا روز قيامت بر آنان [=يهوديان‌] كسانى را خواهد گماشت كه بديشان عذاب سخت بچشانند. آرى، پروردگار تو زودكيفر است و همو آمرزنده بسيار مهربان است.\qt@no{(167)}}
\qt@newcmd\qurantrans@fa@mcxxii{و آنان را در زمين به صورت گروه‌هايى پراكنده ساختيم: برخى از آنان درستكارند و برخى از آنان جز اينند. و آنها را به خوشيها و ناخوشيها آزموديم، باشد كه ايشان بازگردند.\qt@no{(168)}}
\qt@newcmd\qurantrans@fa@mcxxiii{آنگاه بعد از آنان، جانشينانى وارث كتاب [آسمانى‌] شدند كه متاع اين دنياى پست را مى‌گيرند و مى‌گويند: «بخشيده خواهيم شد.» و اگر متاعى مانند آن به ايشان برسد [باز] آن را مى‌ستانند. آيا از آنان پيمان كتاب [آسمانى‌] گرفته نشده كه جز به حق نسبت به خدا سخن نگويند، با اينكه آنچه را كه در آن [كتاب‌] است آموخته‌اند؟ و سراى آخرت براى كسانى كه پروا پيشه مى‌كنند بهتر است. آيا باز تعقّل نمى‌كنيد؟\qt@no{(169)}}
\qt@newcmd\qurantrans@fa@mcxxiv{و كسانى كه به كتاب [آسمانى‌] چنگ درمى‌زنند و نماز برپا داشته‌اند [بدانند كه‌] ما اجر درستكاران را تباه نخواهيم كرد.\qt@no{(170)}}
\qt@newcmd\qurantrans@fa@mcxxv{و [ياد كن‌] هنگامى را كه كوه [طور] را بر فرازشان سايبان‌آسا، برافراشتيم، و چنان پنداشتند كه [كوه‌] بر سرشان فرو خواهد افتاد. [و گفتيم:] آنچه را كه به شما داده‌ايم به جدّ و جهد بگيريد، و آنچه را در آن است به ياد داشته باشيد. شايد كه پرهيزگار شويد.\qt@no{(171)}}
\qt@newcmd\qurantrans@fa@mcxxvi{و هنگامى را كه پروردگارت از پشت فرزندان آدم، ذريه آنان را برگرفت و ايشان را بر خودشان گواه ساخت كه آيا پروردگار شما نيستم؟ گفتند: «چرا، گواهى داديم» تا مبادا روز قيامت بگوييد ما از اين [امر] غافل بوديم.\qt@no{(172)}}
\qt@newcmd\qurantrans@fa@mcxxvii{يا بگوييد پدران ما پيش از اين مشرك بوده‌اند و ما فرزندانى پس از ايشان بوديم. آيا ما را به خاطر آنچه باطل‌انديشان انجام داده‌اند هلاك مى‌كنى؟\qt@no{(173)}}
\qt@newcmd\qurantrans@fa@mcxxviii{و اينگونه آيات [خود] را به تفصيل بيان مى‌كنيم، و باشد كه آنان [به سوى حق‌] بازگردند.\qt@no{(174)}}
\qt@newcmd\qurantrans@fa@mcxxix{و خبر آن كس را كه آيات خود را به او داده بوديم براى آنان بخوان كه از آن عارى گشت؛ آنگاه شيطان، او را دنبال كرد و از گمراهان شد.\qt@no{(175)}}
\qt@newcmd\qurantrans@fa@mcxxx{و اگر مى‌خواستيم، قدر او را به وسيله آن [آيات‌] بالا مى‌برديم، اما او به زمين [=دنيا] گراييد و از هواى نَفْس خود پيروى كرد. از اين رو داستانش چون داستان سگ است [كه‌] اگر بر آن حمله‌ور شوى زبان از كام برآورد، و اگر آن را رها كنى [باز هم‌] زبان از كام برآورد. اين، مَثَل آن گروهى است كه آيات ما را تكذيب كردند. پس اين داستان را [براى آنان‌] حكايت كن، شايد كه آنان بينديشند.\qt@no{(176)}}
\qt@newcmd\qurantrans@fa@mcxxxi{چه زشت است داستان گروهى كه آيات ما را تكذيب و به خود ستم مى‌نمودند.\qt@no{(177)}}
\qt@newcmd\qurantrans@fa@mcxxxii{هر كه را خدا هدايت كند، او راه‌يافته است؛ و كسانى را كه گمراه نمايد، آنان خود زيانكارانند.\qt@no{(178)}}
\qt@newcmd\qurantrans@fa@mcxxxiii{و در حقيقت، بسيارى از جنّيان و آدميان را براى دوزخ آفريده‌ايم. [چرا كه‌] دلهايى دارند كه با آن [حقايق را] دريافت نمى‌كنند، و چشمانى دارند كه با آنها نمى‌بينند، و گوشهايى دارند كه با آنها نمى‌شنوند. آنان همانند چهارپايان بلكه گمراه‌ترند. [آرى،] آنها همان غافل‌ماندگانند.\qt@no{(179)}}
\qt@newcmd\qurantrans@fa@mcxxxiv{و نامهاى نيكو به خدا اختصاص دارد، پس او را با آنها بخوانيد، و كسانى را كه در مورد نامهاى او به كژى مى‌گرايند رها كنيد. زودا كه به [سزاى‌] آنچه انجام مى‌دادند كيفر خواهند يافت.\qt@no{(180)}}
\qt@newcmd\qurantrans@fa@mcxxxv{و از ميان كسانى كه آفريده‌ايم، گروهى هستند كه به حق هدايت مى‌كنند و به حق داورى مى‌نمايند.\qt@no{(181)}}
\qt@newcmd\qurantrans@fa@mcxxxvi{و كسانى كه آيات ما را تكذيب كردند، به تدريج، از جايى كه نمى‌دانند گريبانشان را خواهيم گرفت.\qt@no{(182)}}
\qt@newcmd\qurantrans@fa@mcxxxvii{و به آنان مهلت مى‌دهم، كه تدبير من استوار است.\qt@no{(183)}}
\qt@newcmd\qurantrans@fa@mcxxxviii{آيا نينديشيده‌اند كه همنشين آنان هيچ جنونى ندارد؟ او جز هشداردهنده‌اى آشكار نيست.\qt@no{(184)}}
\qt@newcmd\qurantrans@fa@mcxxxix{آيا در ملكوت آسمانها و زمين و هر چيزى كه خدا آفريده است ننگريسته‌اند؛ و اينكه شايد هنگام مرگشان نزديك شده باشد؟ پس به كدام سخن، بعد از قرآن ايمان مى‌آورند؟\qt@no{(185)}}
\qt@newcmd\qurantrans@fa@mcxl{هر كه را خداوند گمراه كند، براى او هيچ رهبرى نيست، و آنان را در طغيانشان سرگردان وا مى‌گذارد.\qt@no{(186)}}
\qt@newcmd\qurantrans@fa@mcxli{از تو در باره قيامت مى‌پرسند [كه‌] وقوع آن چه وقت است؟ بگو: «علم آن، تنها نزد پروردگار من است. جز او [هيچ كس‌] آن را به موقع خود آشكار نمى‌گرداند. [اين حادثه‌] بر آسمانها و زمين گران است، جز ناگهان به شما نمى‌رسد.» [باز] از تو مى‌پرسند گويا تو از [زمان وقوع‌] آن آگاهى. بگو: «علم آن، تنها نزد خداست، ولى بيشتر مردم نمى‌دانند.»\qt@no{(187)}}
\qt@newcmd\qurantrans@fa@mcxlii{بگو: «جز آنچه خدا بخواهد، براى خودم اختيار سود و زيانى ندارم، و اگر غيب مى‌دانستم قطعاً خير بيشترى مى‌اندوختم و هرگز به من آسيبى نمى‌رسيد. من جز بيم‌دهنده و بشارتگر براى گروهى كه ايمان مى‌آورند، نيستم.»\qt@no{(188)}}
\qt@newcmd\qurantrans@fa@mcxliii{اوست آن كس كه شما را از نَفْس واحدى آفريد، و جفت وى را از آن پديد آورد تا بدان آرام گيرد. پس چون [آدم‌] با او [حوّا] درآميخت باردار شد، بارى سبك. و [چندى‌] با آن [بار سبك‌] گذرانيد، و چون سنگين‌بار شد، خدا، پروردگار خود را خواندند كه اگر به ما [فرزندى‌] شايسته عطا كنى قطعاً از سپاسگزاران خواهيم بود.\qt@no{(189)}}
\qt@newcmd\qurantrans@fa@mcxliv{و چون به آن دو، [فرزندى‌] شايسته داد، در آنچه [خدا] به ايشان داده بود، براى او شريكانى قرار دادند، و خدا از آنچه [با او] شريك مى‌گردانند برتر است.\qt@no{(190)}}
\qt@newcmd\qurantrans@fa@mcxlv{آيا موجوداتى را [با او] شريك مى‌گردانند كه چيزى را نمى‌آفرينند و خودشان مخلوقند؟\qt@no{(191)}}
\qt@newcmd\qurantrans@fa@mcxlvi{و نمى‌توانند آنان را يارى كنند و نه خويشتن را يارى دهند.\qt@no{(192)}}
\qt@newcmd\qurantrans@fa@mcxlvii{و اگر آنها را به [راه‌] هدايت فراخوانيد، از شما پيروى نمى‌كنند. چه آنها را بخوانيد يا خاموش بمانيد، براى شما يكسان است.\qt@no{(193)}}
\qt@newcmd\qurantrans@fa@mcxlviii{در حقيقت، كسانى را كه به جاى خدا مى‌خوانيد، بندگانى امثال شما هستند. پس آنها را [در گرفتاريها] بخوانيد، اگر راست مى‌گوييد بايد شما را اجابت كنند.\qt@no{(194)}}
\qt@newcmd\qurantrans@fa@mcxlix{آيا آنها پاهايى دارند كه با آن راه بروند، يا دستهايى دارند كه با آن كارى انجام دهند، يا چشمهايى دارند كه با آن بنگرند، يا گوشهايى دارند كه با آن بشنوند؟ بگو: «شريكان خود را بخوانيد؛ سپس در باره من حيله به كار بريد و مرا مهلت مدهيد.»\qt@no{(195)}}
\qt@newcmd\qurantrans@fa@mcl{بى‌ترديد، سرور من آن خدايى است كه قرآن را فرو فرستاده، و همو دوستدار شايستگان است.\qt@no{(196)}}
\qt@newcmd\qurantrans@fa@mcli{و كسانى را كه به جاى او مى‌خوانيد، نمى‌توانند شما را يارى كنند و نه خويشتن را يارى دهند.\qt@no{(197)}}
\qt@newcmd\qurantrans@fa@mclii{و اگر آنها را به [راه‌] هدايت فرا خوانيد، نمى‌شنوند، و آنها را مى‌بينى كه به سوى تو مى‌نگرند در حالى كه نمى‌بينند.\qt@no{(198)}}
\qt@newcmd\qurantrans@fa@mcliii{گذشت پيشه كن، و به [كار] پسنديده فرمان ده، و از نادانان رخ برتاب.\qt@no{(199)}}
\qt@newcmd\qurantrans@fa@mcliv{و اگر از شيطان وسوسه‌اى به تو رسد، به خدا پناه بَر، زيرا كه او شنواى داناست.\qt@no{(200)}}
\qt@newcmd\qurantrans@fa@mclv{در حقيقت، كسانى كه [از خدا] پروا دارند، چون وسوسه‌اى از جانب شيطان بديشان رسد [خدا را] به ياد آورند و بناگاه بينا شوند.\qt@no{(201)}}
\qt@newcmd\qurantrans@fa@mclvi{و يارانشان آنان را به گمراهى مى‌كشانند و كوتاهى نمى‌كنند.\qt@no{(202)}}
\qt@newcmd\qurantrans@fa@mclvii{و هر گاه براى آنان آياتى نياورى، مى‌گويند: «چرا آن را خود برنگزيدى؟ « بگو: «من فقط آنچه را كه از پروردگارم به من وحى مى‌شود پيروى مى‌كنم. اين [قرآن‌] رهنمودى است از جانب پروردگار شما و براى گروهى كه ايمان مى‌آورند هدايت و رحمتى است.\qt@no{(203)}}
\qt@newcmd\qurantrans@fa@mclviii{و چون قرآن خوانده شود، گوش بدان فرا داريد و خاموش مانيد، اميد كه بر شما رحمت آيد.\qt@no{(204)}}
\qt@newcmd\qurantrans@fa@mclix{و در دل خويش، پروردگارت را بامدادان و شامگاهان با تضرع و ترس، بى‌صداى بلند، ياد كن و از غافلان مباش.\qt@no{(205)}}
\qt@newcmd\qurantrans@fa@mclx{به يقين، كسانى كه نزد پروردگار تو هستند، از پرستش او تكبر نمى‌ورزند و او را به پاكى مى‌ستايند و براى او سجده مى‌كنند.\qt@no{(206)}}
\qt@newcmd\qurantrans@fa@mclxi{\basmalahfa [اى پيامبر،] از تو در باره غنايم جنگى مى‌پرسند. بگو: «غنايم جنگى اختصاص به خدا و فرستاده [او] دارد. پس از خدا پروا داريد و با يكديگر سازش نماييد، و اگر ايمان داريد از خدا و پيامبرش اطاعت كنيد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mclxii{مؤمنان، همان كسانى‌اند كه چون خدا ياد شود دلهايشان بترسد، و چون آيات او بر آنان خوانده شود بر ايمانشان بيفزايد، و بر پروردگار خود توكل مى‌كنند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mclxiii{همانان كه نماز را به پا مى‌دارند و از آنچه به ايشان روزى داده‌ايم انفاق مى‌كنند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mclxiv{آنان هستند كه حقاً مؤمنند، براى آنان نزد پروردگارشان درجات و آمرزش و روزىِ نيكو خواهد بود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mclxv{همان گونه كه پروردگارت تو را از خانه‌ات به حق بيرون آورد و حال آنكه دسته‌اى از مؤمنان سخت كراهت داشتند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mclxvi{با تو در باره حق -بعد از آنكه روشن گرديد- مجادله مى‌كنند. گويى كه آنان را به سوى مرگ مى‌رانند و ايشان [بدان‌] مى‌نگرند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mclxvii{و [به ياد آوريد] هنگامى را كه خدا يكى از دو دسته [كاروان تجارتى قريش يا سپاه ابوسفيان‌] را به شما وعده داد كه از آنِ شما باشد، و شما دوست داشتيد كه دسته بى‌سلاح براى شما باشد، و[لى‌] خدا مى‌خواست حق [=اسلام‌] را با كلمات خود ثابت، و كافران را ريشه‌كن كند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mclxviii{تا حق را ثابت و باطل را نابود گرداند، هر چند بزهكاران خوش نداشته باشند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mclxix{[به ياد آوريد] زمانى را كه پروردگار خود را به فرياد مى‌طلبيديد، پس دعاى شما را اجابت كرد كه: «من شما را با هزار فرشته پياپى، يارى خواهم كرد.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mclxx{و اين [وعده‌] را خداوند جز نويدى [براى شما] قرار نداد، و تا آنكه دلهاى شما بدان اطمينان يابد؛ و پيروزى جز از نزد خدا نيست، كه خدا شكست ناپذير [و] حكيم است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mclxxi{[به ياد آوريد] هنگامى را كه [خدا] خواب سبك آرامش‌بخشى كه از جانب او بود بر شما مسلط ساخت، و از آسمان بارانى بر شما فرو ريزانيد تا شما را با آن پاك گرداند، و وسوسه شيطان را از شما بزدايد و دلهايتان را محكم سازد و گامهايتان را بدان استوار دارد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mclxxii{هنگامى كه پروردگارت به فرشتگان وحى مى‌كرد كه من با شما هستم، پس كسانى را كه ايمان آورده‌اند ثابت‌قدم بداريد. به زودى در دل كافران وحشت خواهم افكند. پس، فراز گردنها را بزنيد، و همه سرانگشتانشان را قلم كنيد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mclxxiii{اين [كيفر] بدان سبب است كه آنان با خدا و پيامبر او به مخالفت برخاستند، و هر كس با خدا و پيامبر او به مخالفت برخيزد قطعاً خدا سخت‌كيفر است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mclxxiv{اين [عذاب دنيا] را بچشيد، و [بدانيد كه‌] براى كافران عذاب آتش خواهد بود.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mclxxv{اى كسانى كه ايمان آورده‌ايد، هر گاه [در ميدان نبرد] به كافران برخورد كرديد كه [به سوى شما] روى مى‌آورند، به آنان پشت مكنيد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mclxxvi{و هر كه در آن هنگام به آنان پشت كند -مگر آنكه [هدفش‌] كناره‌گيرى براى نبردى [مجدد] يا پيوستن به جمعى [ديگر از همرزمانش‌] باشد- قطعاً به خشم خدا گرفتار خواهد شد، و جايگاهش دوزخ است، و چه بد سرانجامى است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mclxxvii{و شما آنان را نكشتيد، بلكه خدا آنان را كُشت. و چون [ريگ به سوى آنان‌] افكندى، تو نيفكندى، بلكه خدا افكند. [آرى، خدا چنين كرد تا كافران را مغلوب كند] و بدين وسيله مؤمنان را به آزمايشى نيكو، بيازمايد. قطعاً خدا شنواى داناست.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mclxxviii{[ماجرا] اين بود، و [بدانيد كه‌] خدا نيرنگ كافران را سست مى‌گرداند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mclxxix{[اى مشركان‌] اگر شما پيروزى [حق‌] را مى‌طلبيد، اينك پيروزى به سراغ شما آمد [و اسلام پيروز شد]؛ و اگر [از دشمنى‌] بازايستيد، آن براى شما بهتر است؛ و اگر [به جنگ‌] برگرديد ما هم بر مى‌گرديم، و [بدانيد] كه گروه شما هر چند زياد باشد، هرگز از شما چيزى را دفع نتوانند كرد و خداست كه با مؤمنان است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mclxxx{اى كسانى كه ايمان آورده‌ايد، خدا و فرستاده او را فرمان بريد و از او روى برنتابيد در حالى كه [سخنان او را] مى‌شنويد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mclxxxi{و مانند كسانى مباشيد كه گفتند: «شنيديم» در حالى كه نمى‌شنيدند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mclxxxii{قطعاً بدترين جنبندگان نزد خدا كران و لالانى‌اند كه نمى‌انديشند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mclxxxiii{و اگر خدا در آنان خيرى مى‌يافت قطعاً شنوايشان مى‌ساخت، و اگر آنان را شنوا مى‌كرد، حتماً باز به حال اعراض، روى برمى‌تافتند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mclxxxiv{اى كسانى كه ايمان آورده‌ايد، چون خدا و پيامبر، شما را به چيزى فرا خواندند كه به شما حيات مى‌بخشد، آنان را اجابت كنيد، و بدانيد كه خدا ميان آدمى و دلش حايل مى‌گردد، و هم در نزد او محشور خواهيد شد.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mclxxxv{و از فتنه‌اى كه تنها به ستمكاران شما نمى‌رسد بترسيد و بدانيد كه خدا سخت‌كيفر است.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mclxxxvi{و به ياد آوريد هنگامى را كه شما در زمين، گروهى اندك و مستضعف بوديد. مى ترسيديد مردم شما را بربايند، پس [خدا] به شما پناه داد و شما را به يارى خود نيرومند گردانيد و از چيزهاى پاك به شما روزى داد، باشد كه سپاسگزارى كنيد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mclxxxvii{اى كسانى كه ايمان آورده‌ايد، به خدا و پيامبر او خيانت مكنيد و [نيز] در امانتهاى خود خيانت نورزيد و خود مى‌دانيد [كه نبايد خيانت كرد].\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mclxxxviii{و بدانيد كه اموال و فرزندان شما [وسيله‌] آزمايش [شما] هستند، و خداست كه نزد او پاداشى بزرگ است.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mclxxxix{اى كسانى كه ايمان آورده‌ايد، اگر از خدا پروا داريد، براى شما [نيروى‌] تشخيص [حق از باطل‌] قرار مى‌دهد؛ و گناهانتان را از شما مى‌زدايد؛ و شما را مى‌آمرزد؛ و خدا داراى بخشش بزرگ است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mcxc{و [ياد كن‌] هنگامى را كه كافران در باره تو نيرنگ مى‌كردند تا تو را به بند كشند يا بكشند يا [از مكه‌] اخراج كنند، و نيرنگ مى‌زدند، و خدا تدبير مى‌كرد، و خدا بهترين تدبيركنندگان است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mcxci{و چون آيات ما بر آنان خوانده شود، مى‌گويند: «به خوبى شنيديم، اگر مى‌خواستيم، قطعاً ما نيز همانند اين را مى‌گفتيم، اين جز افسانه‌هاى پيشينيان نيست.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mcxcii{و [ياد كن‌] هنگامى را كه گفتند: «خدايا، اگر اين [كتاب‌] همان حق از جانب توست، پس بر ما از آسمان سنگهايى بباران يا عذابى دردناك بر سر ما بياور.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mcxciii{و[لى‌] تا تو در ميان آنان هستى، خدا بر آن نيست كه ايشان را عذاب كند، و تا آنان طلب آمرزش مى‌كنند، خدا عذاب‌كننده ايشان نخواهد بود.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mcxciv{چرا خدا [در آخرت‌] عذابشان نكند، با اينكه آنان [مردم را] از [زيارت‌] مسجدالحرام باز مى‌دارند در حالى كه ايشان سرپرست آن نباشند. چرا كه سرپرست آن جز پرهيزگاران نيستند، ولى بيشترشان نمى‌دانند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mcxcv{و نمازشان در خانه [خدا] جز سوت كشيدن و كف زدن نبود. پس به سزاى آنكه كفر مى‌ورزيديد، اين عذاب را بچشيد!\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mcxcvi{بى‌گمان، كسانى كه كفر ورزيدند، اموال خود را خرج مى‌كنند تا [مردم را] از راه خدا بازدارند. پس به زودى [همه‌] آن را خرج مى‌كنند، و آنگاه حسرتى بر آنان خواهد گشت؛ سپس مغلوب مى‌شوند. و كسانى كه كفر ورزيدند، به سوى دوزخ گردآورده خواهند شد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mcxcvii{تا خدا، ناپاك را از پاك جدا كند، و ناپاكها را روى يكديگر نهد و همه را متراكم كند؛ آنگاه در جهنم قرار دهد. اينان همان زيانكارانند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mcxcviii{به كسانى كه كفر ورزيده‌اند، بگو: «اگر بازايستند، آنچه گذشته است برايشان آمرزيده مى‌شود؛ و اگر بازگردند، به يقين، سنت [خدا در مورد] پيشينيان گذشت.»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mcxcix{و با آنان بجنگيد تا فتنه‌اى بر جاى نماند و دين يكسره از آنِ خدا گردد. پس اگر [از كفر] بازايستند قطعاً خدا به آنچه انجام مى‌دهند بيناست.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mcc{و اگر روى برتافتند، پس بدانيد كه خدا سرور شماست. چه نيكو سرور و چه نيكو ياورى است.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mcci{و بدانيد كه هر چيزى را به غنيمت گرفتيد، يك پنجم آن براى خدا و پيامبر و براى خويشاوندان [او] و يتيمان و بينوايان و در راه‌ماندگان است، اگر به خدا و آنچه بر بنده خود در روز جدايى [حق از باطل ]-روزى كه آن دو گروه با هم روبرو شدند- نازل كرديم، ايمان آورده‌ايد. و خدا بر هر چيزى تواناست.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mccii{آنگاه كه شما بر دامنه نزديكتر [كوه‌] بوديد و آنان در دامنه دورتر [كوه ]، و سواران [دشمن‌] پايين‌تر از شما [موضع گرفته‌] بودند، و اگر با يكديگر وعده گذارده بوديد، قطعاً در وعده‌گاه خود اختلاف مى‌كرديد، ولى [چنين شد] تا خداوند كارى را كه انجام‌شدنى بود به انجام رساند [و] تا كسى كه [بايد] هلاك شود، با دليلى روشن هلاك گردد، و كسى كه [بايد] زنده شود، با دليلى واضح زنده بماند، و خداست كه در حقيقت شنواى داناست.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mcciii{[اى پيامبر، ياد كن‌] آنگاه را كه خداوند آنان [=سپاه دشمن‌] را در خوابت به تو اندك نشان داد؛ و اگر ايشان را به تو بسيار نشان مى‌داد قطعاً سست مى‌شديد و حتماً در كار [جهاد] منازعه مى‌كرديد، ولى خدا شما را به سلامت داشت، چرا كه او به راز دلها داناست.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mcciv{و آنگاه كه چون با هم برخورد كرديد، آنان را در ديدگان شما اندك جلوه داد و شما را [نيز] در ديدگان آنان كم نمودار ساخت تا خداوند كارى را كه انجام‌شدنى بود تحقق بخشد، و كارها به سوى خدا بازگردانده مى‌شود.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mccv{اى كسانى كه ايمان آورده‌ايد، چون با گروهى برخورد مى‌كنيد پايدارى ورزيد و خدا را بسيار ياد كنيد، باشد كه رستگار شويد.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mccvi{و از خدا و پيامبرش اطاعت كنيد و با هم نزاع مكنيد كه سست شويد و مهابت شما از بين برود، و صبر كنيد كه خدا با شكيبايان است.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mccvii{و مانند كسانى مباشيد كه از خانه‌هايشان با حالت سرمستى و به صرف نمايش به مردم خارج شدند و [مردم را] از راه خدا باز مى‌داشتند، و خدا به آنچه مى‌كنند احاطه دارد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mccviii{و [ياد كن‌] هنگامى را كه شيطان اعمال آنان را برايشان بياراست و گفت: «امروز هيچ كس از مردم بر شما پيروز نخواهد شد، و من پناه شما هستم.» پس هنگامى كه دو گروه، يكديگر را ديدند [شيطان‌] به عقب برگشت و گفت: «من از شما بيزارم، من چيزى را مى‌بينم كه شما نمى‌بينيد، من از خدا بيمناكم.» و خدا سخت‌كيفر است.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mccix{آنگاه كه منافقان و كسانى كه در دلهايشان بيمارى بود مى‌گفتند: «اينان [=مؤمنان‌] را دينشان فريفته است.» و هر كس بر خدا توكل كند [بداند كه‌] در حقيقت خدا شكست‌ناپذير حكيم است.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mccx{و اگر ببينى آنگاه كه فرشتگان جان كافران را مى‌ستانند، بر چهره و پشت آنان مى‌زنند و [گويند:] عذاب سوزان را بچشيد.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mccxi{اين [كيفر] دستاوردهاى پيشين شماست، و [گر نه‌] خدا بر بندگان [خود] ستمكار نيست.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mccxii{[رفتارشان‌] مانند رفتار خاندان فرعون و كسانى است كه پيش از آنان بودند: به آيات خدا كفر ورزيدند؛ پس خدا به [سزاى‌] گناهانشان گرفتارشان كرد. آرى، خدا نيرومند سخت‌كيفر است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mccxiii{اين [كيفر] بدان سبب است كه خداوند نعمتى را كه بر قومى ارزانى داشته تغيير نمى‌دهد، مگر آنكه آنان آنچه را در دل دارند تغيير دهند، و خدا شنواى داناست.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mccxiv{[رفتارى‌] چون رفتار فرعونيان و كسانى كه پيش از آنان بودند، كه آيات پروردگارشان را تكذيب كردند؛ پس ما آنان را به [سزاى‌] گناهانشان هلاك، و فرعونيان را غرق كرديم و همه آنان ستمكار بودند.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mccxv{بى‌ترديد، بدترين جنبندگان پيش خدا كسانى‌اند كه كفر ورزيدند و ايمان نمى‌آورند.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mccxvi{همانان كه از ايشان پيمان گرفتى ولى هر بار پيمان خود را مى‌شكنند و [از خدا] پروا نمى‌دارند.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mccxvii{پس اگر در جنگ بر آنان دست يافتى با [عقوبت‌] آنان، كسانى را كه در پى ايشانند تارومار كن، باشد كه عبرت گيرند.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mccxviii{و اگر از گروهى بيم خيانت دارى [پيمانشان را] به سويشان بينداز [تا طرفين‌] به طور يكسان [بدانند كه پيمان گسسته است‌]، زيرا خدا خائنان را دوست نمى‌دارد.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mccxix{و زنهار كسانى كه كافر شده‌اند گمان نكنند كه پيشى جسته‌اند، زيرا آنان نمى‌توانند [ما را] درمانده كنند.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mccxx{و هر چه در توان داريد از نيرو و اسبهاى آماده بسيج كنيد، تا با اين [تداركات‌]، دشمن خدا و دشمن خودتان و [دشمنان‌] ديگرى را جز ايشان -كه شما نمى‌شناسيدشان و خدا آنان را مى‌شناسد- بترسانيد. و هر چيزى در راه خدا خرج كنيد پاداشش به خود شما بازگردانيده مى‌شود و بر شما ستم نخواهد رفت.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mccxxi{و اگر به صلح گراييدند، تو [نيز] بدان گراى و بر خدا توكل نما كه او شنواى داناست.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mccxxii{و اگر بخواهند تو را بفريبند، [يارى‌] خدا براى تو بس است. همو بود كه تو را با يارى خود و مؤمنان نيرومند گردانيد.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mccxxiii{و ميان دلهايشان اُلفت انداخت، كه اگر آنچه در روى زمين است همه را خرج مى‌كردى نمى‌توانستى ميان دلهايشان اُلفت برقرار كنى، ولى خدا بود كه ميان آنان اُلفت انداخت، چرا كه او تواناى حكيم است.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mccxxiv{اى پيامبر، خدا و كسانى از مؤمنان كه پيرو تواند تو را بس است.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mccxxv{اى پيامبر، مؤمنان را به جهاد برانگيز. اگر از [ميان‌] شما بيست تن، شكيبا باشند بر دويست تن چيره مى‌شوند، و اگر از شما يكصد تن باشند بر هزار تن از كافران پيروز مى‌گردند، چرا كه آنان قومى‌اند كه نمى‌فهمند.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mccxxvi{اكنون خدا بر شما تخفيف داده و معلوم داشت كه در شما ضعفى هست. پس اگر از [ميان‌] شما يكصد تن شكيبا باشند بر دويست تن پيروز گردند، و اگر از شما هزار تن باشند، به توفيق الهى بر دو هزار تن غلبه كنند، و خدا با شكيبايان است.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mccxxvii{هيچ پيامبرى را سزاوار نيست كه [براى اخذ سربها از دشمنان‌] اسيرانى بگيرد، تا در زمين به طور كامل از آنان كشتار كند. شما متاع دنيا را مى‌خواهيد و خدا آخرت را مى‌خواهد، و خدا شكست‌ناپذير حكيم است.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mccxxviii{اگر در آنچه گرفته‌ايد، از جانب خدا نوشته‌اى نبود، قطعاً به شما عذابى بزرگ مى‌رسيد.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mccxxix{پس، از آنچه به غنيمت برده‌ايد، حلال و پاكيزه بخوريد و از خدا پروا داريد كه خدا آمرزنده مهربان است.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mccxxx{اى پيامبر، به كسانى كه در دست شما اسيرند بگو: «اگر خدا در دلهاى شما خيرى سراغ داشته باشد، بهتر از آنچه از شما گرفته شده به شما عطا مى‌كند و بر شما مى‌بخشايد و خدا آمرزنده مهربان است.»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mccxxxi{و اگر بخواهند به تو خيانت كنند، پيش از اين [نيز] به خدا خيانت كردند؛ [و خدا تو را] بر آنان مسلّط ساخت، و خدا داناى حكيم است.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mccxxxii{كسانى كه ايمان آورده و هجرت كرده‌اند و در راه خدا با مال و جان خود جهاد نموده‌اند و كسانى كه [مهاجران را] پناه داده‌اند و يارى كرده‌اند، آنان ياران يكديگرند؛ و كسانى كه ايمان آورده‌اند ولى مهاجرت نكرده‌اند هيچ گونه خويشاوندى [دينى‌] با شما ندارند مگر آنكه [در راه خدا] هجرت كنند؛ و اگر در [كار] دين از شما يارى جويند، يارى آنان بر شما [واجب‌] است، مگر بر عليه گروهى باشد كه ميان شما و ميان آنان پيمانى [منعقد شده‌] است، و خدا به آنچه انجام مى‌دهيد بيناست.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mccxxxiii{و كسانى كه كفر ورزيدند ياران يكديگرند. اگر اين [دستور] را به كار نبنديد، در زمين فتنه و فسادى بزرگ پديد خواهد آمد.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mccxxxiv{و كسانى كه ايمان آورده و هجرت كرده و در راه خدا به جهاد پرداخته، و كسانى كه [مهاجران را] پناه داده و يارى كرده‌اند، آنان همان مؤمنان واقعى‌اند، براى آنان بخشايش و روزىِ شايسته‌اى خواهد بود.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mccxxxv{و كسانى كه بعداً ايمان آورده و هجرت نموده و همراه شما جهاد كرده‌اند، اينان از زمره شمايند، و خويشاوندان نسبت به يكديگر [از ديگران‌] در كتاب خدا سزاوارترند. آرى، خدا به هر چيزى داناست.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mccxxxvi{\basmalahfa [اين آيات‌] اعلام بيزارى [و عدم تعهّد] است از طرف خدا و پيامبرش نسبت به آن مشركانى كه با ايشان پيمان بسته‌ايد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mccxxxvii{پس [اى مشركان،] چهار ماه [ديگر با امنيّت كامل‌] در زمين بگرديد و بدانيد كه شما نمى‌توانيد خدا را به ستوه آوريد، و اين خداست كه رسواكننده كافران است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mccxxxviii{و [اين آيات‌] اعلامى است از جانب خدا و پيامبرش به مردم در روز حجّ اكبر كه خدا و پيامبرش در برابر مشركان تعهّدى ندارند [با اين حال‌] اگر [از كفر] توبه كنيد آن براى شما بهتر است، و اگر روى بگردانيد پس بدانيد كه شما خدا را درمانده نخواهيد كرد؛ و كسانى را كه كفر ورزيدند از عذابى دردناك خبر ده.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mccxxxix{مگر آن مشركانى كه با آنان پيمان بسته‌ايد، و چيزى از [تعهّدات خود نسبت به‌] شما فروگذار نكرده، و كسى را بر ضدّ شما پشتيبانى ننموده‌اند. پس پيمان اينان را تا [پايان‌] مدّتشان تمام كنيد، چرا كه خدا پرهيزگاران را دوست دارد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mccxl{پس چون ماه‌هاى حرام سپرى شد، مشركان را هر كجا يافتيد بكُشيد و آنان را دستگير كنيد و به محاصره درآوريد و در هر كمينگاهى به كمين آنان بنشينيد؛ پس اگر توبه كردند و نماز برپا داشتند و زكات دادند، راه برايشان گشاده گردانيد، زيرا خدا آمرزنده مهربان است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mccxli{و اگر يكى از مشركان از تو پناه خواست پناهش ده تا كلام خدا را بشنود؛ سپس او را به مكان امنش برسان، چرا كه آنان قومى نادانند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mccxlii{چگونه مشركان را نزد خدا و نزد فرستاده او عهدى تواند بود؟ مگر با كسانى كه كنار مسجد الحرام پيمان بسته‌ايد. پس تا با شما [بر سر عهد] پايدارند، با آنان پايدار باشيد، زيرا خدا پرهيزگاران را دوست مى‌دارد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mccxliii{چگونه [براى آنان عهدى است‌] با اينكه اگر بر شما دست يابند، در باره شما نه خويشاوندى را مراعات مى‌كنند و نه تعهّدى را، شما را با زبانشان راضى مى‌كنند و حال آنكه دلهايشان امتناع مى‌ورزد و بيشترشان منحرفند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mccxliv{آيات خدا را به بهاى ناچيزى فروختند و [مردم را] از راه او باز داشتند، به راستى آنان چه بد اعمالى انجام مى‌دادند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mccxlv{در باره هيچ مؤمنى مراعات خويشاوندى و پيمانى را نمى‌كنند، و ايشان همان تجاوزكارانند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mccxlvi{پس اگر توبه كنند و نماز برپا دارند و زكات دهند، در اين صورت برادران دينى شما مى‌باشند، و ما آيات [خود] را براى گروهى كه مى‌دانند به تفصيل بيان مى‌كنيم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mccxlvii{و اگر سوگندهاى خود را پس از پيمان خويش شكستند و شما را در دينتان طعن زدند، پس با پيشوايانِ كفر بجنگيد، چرا كه آنان را هيچ پيمانى نيست، باشد كه [از پيمان‌شكنى‌] باز ايستند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mccxlviii{چرا با گروهى كه سوگندهاى خود را شكستند و بر آن شدند كه فرستاده [خدا] را بيرون كنند، و آنان بودند كه نخستين‌بار [جنگ را] با شما آغاز كردند، نمى‌جنگيد؟ آيا از آنان مى‌ترسيد؟ با اينكه اگر مؤمنيد خدا سزاوارتر است كه از او بترسيد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mccxlix{با آنان بجنگيد؛ خدا آنان را به دست شما عذاب و رسوايشان مى‌كند و شما را بر ايشان پيروزى مى‌بخشد و دلهاى گروه مؤمنان را خنك مى‌گرداند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mccl{و خشمِ دلهايشان را بِبَرد، و خدا توبه هر كه را بخواهد مى‌پذيرد، و خدا داناى حكيم است.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mccli{آيا پنداشته‌ايد كه به خود واگذار مى‌شويد، و خداوند كسانى را كه از ميان شما جهاد كرده و غير از خدا و فرستاده او و مؤمنان، محرم اسرارى نگرفته‌اند، معلوم نمى‌دارد؟ و خدا به آنچه انجام مى‌دهيد آگاه است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mcclii{مشركان را نرسد كه مساجد خدا را آباد كنند، در حالى كه به كفر خويش شهادت مى‌دهند. آنانند كه اعمالشان به هدر رفته و خود در آتش جاودانند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mccliii{مساجد خدا را تنها كسانى آباد مى‌كنند كه به خدا و روز بازپسين ايمان آورده و نماز برپا داشته و زكات داده و جز از خدا نترسيده‌اند، پس اميد است كه اينان از راه‌يافتگان باشند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mccliv{آيا سيراب ساختن حاجيان و آباد كردن مسجد الحرام را همانند [كار] كسى پنداشته‌ايد كه به خدا و روز بازپسين ايمان آورده و در راه خدا جهاد مى‌كند؟ [نه، اين دو] نزد خدا يكسان نيستند، و خدا بيدادگران را هدايت نخواهد كرد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mcclv{كسانى كه ايمان آورده و هجرت كرده و در راه خدا با مال و جانشان به جهاد پرداخته‌اند نزد خدا مقامى هر چه والاتر دارند و اينان همان رستگارانند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mcclvi{پروردگارشان آنان را از جانب خود، به رحمت و خشنودى و باغهايى [در بهشت‌] كه در آنها نعمتهايى پايدار دارند، مژده مى‌دهد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mcclvii{جاودانه در آنها خواهند بود، در حقيقت، خداست كه نزد او پاداشى بزرگ است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mcclviii{اى كسانى كه ايمان آورده‌ايد، اگر پدرانتان و برادرانتان كفر را بر ايمان ترجيح دهند [آنان را] به دوستى مگيريد، و هر كس از ميان شما آنان را به دوستى گيرد، آنان همان ستمكارانند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mcclix{بگو: «اگر پدران و پسران و برادران و زنان و خاندان شما و اموالى كه گرد آورده‌ايد و تجارتى كه از كسادش بيمناكيد و سراهايى را كه خوش مى‌داريد، نزد شما از خدا و پيامبرش و جهاد در راه وى دوست‌داشتنى‌تر است، پس منتظر باشيد تا خدا فرمانش را [به اجرا در]آورد.» و خداوند گروه فاسقان را راهنمايى نمى‌كند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mcclx{قطعاً خداوند شما را در مواضع بسيارى يارى كرده است، و [نيز] در روز «حنين»؛ آن هنگام كه شمار زيادتان شما را به شگفت آورده بود، ولى به هيچ وجه از شما دفع [خطر] نكرد، و زمين با همه فراخى بر شما تنگ گرديد، سپس در حالى كه پشت [به دشمن‌] كرده بوديد برگشتيد.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mcclxi{آنگاه خدا آرامش خود را بر فرستاده خود و بر مؤمنان فرود آورد، و سپاهيانى فرو فرستاد كه آنها را نمى‌ديديد، و كسانى را كه كفر ورزيدند عذاب كرد، و سزاى كافران همين بود.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mcclxii{سپس خدا بعد از اين [واقعه‌] توبه هر كس را بخواهد مى‌پذيرد، و خدا آمرزنده مهربان است.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mcclxiii{اى كسانى كه ايمان آورده‌ايد، حقيقت اين است كه مشركان ناپاكند، پس نبايد از سال آينده به مسجدالحرام نزديك شوند، و اگر [در اين قطع رابطه‌] از فقر بيمناكيد، پس به زودى خدا -اگر بخواهد- شما را به فضل خويش بى‌نياز مى‌گرداند، كه خدا داناى حكيم است.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mcclxiv{با كسانى از اهل كتاب كه به خدا و روز بازپسين ايمان نمى‌آورند، و آنچه را خدا و فرستاده‌اش حرام گردانيده‌اند حرام نمى‌دارند و متدين به دين حق نمى‌گردند، كارزار كنيد، تا با [كمال‌] خوارى به دست خود جزيه دهند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mcclxv{و يهود گفتند: «عُزَير، پسر خداست.» و نصارى گفتند: «مسيح، پسر خداست.» اين سخنى است [باطل‌] كه به زبان مى‌آورند، و به گفتار كسانى كه پيش از اين كافر شده‌اند شباهت دارد. خدا آنان را بكشد؛ چگونه [از حق‌] بازگردانده مى‌شوند؟\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mcclxvi{اينان دانشمندان و راهبان خود و مسيح پسر مريم را به جاى خدا به الوهيّت گرفتند، با آنكه مأمور نبودند جز اينكه خدايى يگانه را بپرستند كه هيچ معبودى جز او نيست. منزه است او از آنچه [با وى‌] شريك مى‌گردانند.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mcclxvii{مى‌خواهند نور خدا را با سخنان خويش خاموش كنند، ولى خداوند نمى‌گذارد، تا نور خود را كامل كند، هر چند كافران را خوش نيايد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mcclxviii{او كسى است كه پيامبرش را با هدايت و دين درست، فرستاد تا آن را بر هر چه دين است پيروز گرداند، هر چند مشركان خوش نداشته باشند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mcclxix{اى كسانى كه ايمان آورده‌ايد، بسيارى از دانشمندان يهود و راهبان، اموال مردم را به ناروا مى‌خورند، و [آنان را] از راه خدا باز مى‌دارند، و كسانى كه زر و سيم را گنجينه مى‌كنند و آن را در راه خدا هزينه نمى‌كنند، ايشان را از عذابى دردناك خبر ده.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mcclxx{روزى كه آن [گنجينه‌]ها را در آتش دوزخ بگدازند، و پيشانى و پهلو و پشت آنان را با آنها داغ كنند [و گويند:] «اين است آنچه براى خود اندوختيد، پس [كيفر] آنچه را مى‌اندوختيد بچشيد.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mcclxxi{در حقيقت، شماره ماه‌ها نزد خدا، از روزى كه آسمانها و زمين را آفريده، در كتاب [علم‌] خدا، دوازده ماه است؛ از اين [دوازده ماه‌]، چهار ماه، [ماهِ‌] حرام است. اين است آيين استوار، پس در اين [چهار ماه ]بر خود ستم مكنيد، و همگى با مشركان بجنگيد، چنانكه آنان همگى با شما مى‌جنگند، و بدانيد كه خدا با پرهيزگاران است.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mcclxxii{جز اين نيست كه جابجا كردن [ماههاى حرام‌]، فزونى در كفر است كه كافران به وسيله آن گمراه مى‌شوند؛ آن را يكسال حلال مى‌شمارند، و يكسال [ديگر]، آن را حرام مى‌دانند، تا با شماره ماههايى كه خدا حرام كرده است موافق سازند، و در نتيجه آنچه را خدا حرام كرده [بر خود] حلال گردانند. زشتى اعمالشان برايشان آراسته شده است، و خدا گروه كافران را هدايت نمى‌كند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mcclxxiii{اى كسانى كه ايمان آورده‌ايد، شما را چه شده است كه چون به شما گفته مى‌شود: «در راه خدا بسيج شويد» كندى به خرج مى‌دهيد؟ آيا به جاى آخرت به زندگى دنيا دل خوش كرده‌ايد؟ متاع زندگى دنيا در برابر آخرت، جز اندكى نيست.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mcclxxiv{اگر بسيج نشويد، [خدا] شما را به عذابى دردناك عذاب مى‌كند، و گروهى ديگر به جاى شما مى‌آورد، و به او زيانى نخواهيد رسانيد، و خدا بر هر چيزى تواناست.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mcclxxv{اگر او [پيامبر] را يارى نكنيد، قطعاً خدا او را يارى كرد: هنگامى كه كسانى كه كفر ورزيدند، او را [از مكّه‌] بيرون كردند، و او نفرِ دوم از دو تن بود، آنگاه كه در غار [ثور] بودند، وقتى به همراه خود مى‌گفت: «اندوه مدار كه خدا با ماست.» پس خدا آرامش خود را بر او فرو فرستاد، و او را با سپاهيانى كه آنها را نمى‌ديديد تأييد كرد، و كلمه كسانى را كه كفر ورزيدند پست‌تر گردانيد، و كلمه خداست كه برتر است، و خدا شكست‌ناپذيرِ حكيم است.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mcclxxvi{سبكبار و گرانبار، بسيج شويد و با مال و جانتان در راه خدا جهاد كنيد. اگر بدانيد، اين براى شما بهتر است.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mcclxxvii{اگر مالى در دسترس و سفرى [آسان و] كوتاه بود، قطعاً از پى تو مى‌آمدند، ولى آن راهِ پر مشقت بر آنان دور مى‌نمايد، و به زودى به خدا سوگند خواهند خورد كه اگر مى‌توانستيم حتماً با شما بيرون مى‌آمديم، [با سوگند دروغ‌]، خود را به هلاكت مى‌كشانند و خدا مى‌داند كه آنان سخت دروغگويند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mcclxxviii{خدايت ببخشايد، چرا پيش از آنكه [حال‌] راستگويان بر تو روشن شود و دروغگويان را بازشناسى، به آنان اجازه دادى؟\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mcclxxix{كسانى كه به خدا و روز بازپسين ايمان دارند، در جهاد با مال و جانشان از تو عذر و اجازه نمى‌خواهند، و خدا به [حال‌] تقواپيشگان داناست.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mcclxxx{تنها كسانى از تو اجازه مى‌خواهند [به جهاد نروند] كه به خدا و روز بازپسين ايمان ندارند و دلهايشان به شك افتاده و در شك خود سرگردانند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mcclxxxi{و اگر [به راستى‌] اراده بيرون رفتن داشتند، قطعاً براى آن ساز و برگى تدارك مى‌ديدند، ولى خداوند راه‌افتادن آنان را خوش نداشت، پس ايشان را منصرف گردانيد و [به آنان‌] گفته شد: «با ماندگان بمانيد.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mcclxxxii{اگر با شما بيرون آمده بودند جز فساد براى شما نمى‌افزودند، و به سرعت خود را ميان شما مى‌انداختند و در حق شما فتنه‌جويى مى‌كردند، و در ميان شما جاسوسانى دارند [كه‌] به نفع آنان [اقدام مى‌كنند]، و خدا به [حال‌] ستمكاران داناست.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mcclxxxiii{در حقيقت، پيش از اين [نيز] در صدد فتنه‌جويى برآمدند و كارها را بر تو وارونه ساختند، تا حقّ آمد و امر خدا آشكار شد، در حالى كه آنان ناخشنود بودند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mcclxxxiv{و از آنان كسى است كه مى‌گويد: «مرا [در ماندن‌] اجازه ده و به فتنه‌ام مينداز.» هش‌دار، كه آنان خود به فتنه افتاده‌اند، و بى‌ترديد جهنم بر كافران احاطه دارد.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mcclxxxv{اگر نيكى به تو رسد آنان را بدحال مى‌سازد، و اگر پيشامد ناگوارى به تو رسد مى‌گويند: «ما پيش از اين تصميم خود را گرفته‌ايم.» و شادمان روى بر مى‌تابند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mcclxxxvi{بگو: «جز آنچه خدا براى ما مقرر داشته هرگز به ما نمى‌رسد. او سرپرست ماست، و مؤمنان بايد تنها بر خدا توكل كنند.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mcclxxxvii{بگو: «آيا براى ما جز يكى از اين دو نيكى را انتظار مى‌بريد؟ در حالى كه ما انتظار مى‌كشيم كه خدا از جانب خود يا به دست ما عذابى به شما برساند. پس انتظار بكشيد كه ما هم با شما در انتظاريم.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mcclxxxviii{بگو: «چه به رغبت چه با بى‌ميلى انفاق كنيد، هرگز از شما پذيرفته نخواهد شد، چرا كه شما گروهى فاسق بوده‌ايد.»\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mcclxxxix{و هيچ چيز مانع پذيرفته شدن انفاقهاى آنان نشد جز اينكه به خدا و پيامبرش كفر ورزيدند، و جز با [حال‌] كسالت نماز به جا نمى‌آورند، و جز با كراهت انفاق نمى‌كنند.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mccxc{اموال و فرزندانشان تو را به شگفت نياورد. جز اين نيست كه خدا مى‌خواهد در زندگى دنيا به وسيله اينها عذابشان كند و جانشان در حال كفر بيرون رود.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mccxci{و به خدا سوگند ياد مى‌كنند كه آنان قطعاً از شمايند، در حالى كه از شما نيستند، ليكن آنان گروهى هستند كه مى‌ترسند.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mccxcii{اگر پناهگاه يا غارها يا سوراخى [براى فرار] مى‌يافتند، شتابزده به سوى آن روى مى‌آوردند.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mccxciii{و برخى از آنان در [تقسيم‌] صدقات بر تو خرده مى‌گيرند، پس اگر از آن [اموال‌] به ايشان داده شود خشنود مى‌گردند، و اگر از آن به ايشان داده نشود بناگاه به خشم مى‌آيند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mccxciv{و اگر آنان بدانچه خدا و پيامبرش به ايشان داده‌اند خشنود مى‌گشتند و مى‌گفتند: «خدا ما را بس است به زودى خدا و پيامبرش از كرم خود به ما مى‌دهند و ما به خدا مشتاقيم» [قطعاً براى آنان بهتر بود].\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mccxcv{صدقات، تنها به تهيدستان و بينوايان و متصديّان [گردآورى و پخش‌] آن، و كسانى كه دلشان به دست آورده مى‌شود، و در [راه آزادى‌] بردگان، و وامداران، و در راه خدا، و به در راه مانده، اختصاص دارد. [اين‌] به عنوان فريضه از جانب خداست، و خدا داناى حكيم است.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mccxcvi{و از ايشان كسانى هستند كه پيامبر را آزار مى‌دهند و مى‌گويند: «او زودباور است.» بگو: «گوش خوبى براى شماست، به خدا ايمان دارد و [سخن‌] مؤمنان را باور مى‌كند، و براى كسانى از شما كه ايمان آورده‌اند رحمتى است.» و كسانى كه پيامبر خدا را آزار مى‌رسانند، عذابى پر درد [در پيش‌] خواهند داشت.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mccxcvii{براى [اِغفال‌] شما به خدا سوگند ياد مى‌كنند تا شما را خشنود گردانند، در صورتى كه اگر مؤمن باشند [بدانند] سزاوارتر است كه خدا و فرستاده او را خشنود سازند.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mccxcviii{آيا ندانسته‌اند كه هر كس با خدا و پيامبر او درافتد براى او آتش جهنم است كه در آن جاودانه خواهد بود، اين همان رسوايى بزرگ است.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mccxcix{منافقان بيم دارند از اينكه [مبادا] سوره‌اى در باره آنان نازل شود كه ايشان را از آنچه در دلهايشان هست خبر دهد. بگو: «ريشخند كنيد، بى‌ترديد خدا آنچه را كه [از آن‌] مى‌ترسيد برملا خواهد كرد.»\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mccc{و اگر از ايشان بپرسى، مسلماً خواهند گفت: «ما فقط شوخى و بازى مى‌كرديم.» بگو: «آيا خدا و آيات او و پيامبرش را ريشخند مى‌كرديد؟»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mccci{عذر نياوريد، شما بعد از ايمانتان كافر شده‌ايد. اگر از گروهى از شما درگذريم، گروهى [ديگر] را عذاب خواهيم كرد، چرا كه آنان تبهكار بودند.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mcccii{مردان و زنان دو چهره، [همانند] يكديگرند. به كار ناپسند وامى‌دارند و از كار پسنديده باز مى‌دارند، و دستهاى خود را [از انفاق‌] فرو مى‌بندند. خدا را فراموش كردند، پس [خدا هم‌] فراموششان كرد. در حقيقت، اين منافقانند كه فاسقند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mccciii{خدا به مردان و زنان دو چهره و كافران، آتش جهنم را وعده داده است. در آن جاودانه‌اند. آن [آتش‌] براى ايشان كافى است، و خدا لعنتشان كرده و براى آنان عذابى پايدار است.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mccciv{[حال شما منافقان‌] چون كسانى است كه پيش از شما بودند: آنان از شما نيرومندتر و داراى اموال و فرزندان بيشتر بودند. پس، از نصيب خويش [در دنيا] برخوردار شدند، و شما [هم‌] از نصيب خود برخوردار شديد؛ همان گونه كه آنان كه پيش از شما بودند از نصيب خويش برخوردار شدند، و شما [در باطل‌] فرو رفتيد؛ همان گونه كه آنان فرو رفتند. آنان اعمالشان در دنيا و آخرت به هدر رفت و آنان همان زيانكارانند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mcccv{آيا گزارش [حال‌] كسانى كه پيش از آنان بودند: قوم نوح و عاد و ثمود و قوم ابراهيم و اصحاب مَدْيَن و شهرهاى زير و رو شده، به ايشان نرسيده است؟ پيامبرانشان دلايل آشكار برايشان آوردند، خدا بر آن نبود كه به آنان ستم كند ولى آنان بر خود ستم روا مى‌داشتند.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mcccvi{و مردان و زنان با ايمان، دوستان يكديگرند، كه به كارهاى پسنديده وا مى‌دارند، و از كارهاى ناپسند باز مى‌دارند، و نماز را بر پا مى‌كنند و زكات مى‌دهند، و از خدا و پيامبرش فرمان مى‌برند. آنانند كه خدا به زودى مشمول رحمتشان قرار خواهد داد، كه خدا توانا و حكيم است.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mcccvii{خداوند به مردان و زنان با ايمان باغهايى وعده داده است كه از زير [درختان‌] آن نهرها جارى است. در آن جاودانه خواهند بود. و [نيز] سراهايى پاكيزه در بهشتهاى جاودان [به آنان وعده داده است‌] و خشنودى خدا بزرگتر است. اين است همان كاميابى بزرگ.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mcccviii{اى پيامبر، با كافران و منافقان جهاد كن و بر آنان سخت بگير، و جايگاهشان دوزخ است، و چه بد سرانجامى است.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mcccix{به خدا سوگند مى‌خورند كه [سخن ناروا] نگفته‌اند، در حالى كه قطعاً سخن كفر گفته و پس از اسلام آوردنشان كفر ورزيده‌اند، و بر آنچه موفق به انجام آن نشدند همّت گماشتند، و به عيبجويى برنخاستند مگر [بعد از] آنكه خدا و پيامبرش از فضل خود آنان را بى‌نياز گردانيدند. پس اگر توبه كنند براى آنان بهتر است، و اگر روى برتابند، خدا آنان را در دنيا و آخرت عذابى دردناك مى‌كند، و در روى زمين يار و ياورى نخواهند داشت.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mcccx{و از آنان كسانى‌اند كه با خدا عهد كرده‌اند كه اگر از كرم خويش به ما عطا كند، قطعاً صدقه خواهيم داد و از شايستگان خواهيم شد.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mcccxi{پس چون از فضل خويش به آنان بخشيد، بدان بخل ورزيدند، و به حال اعراض روى برتافتند.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mcccxii{در نتيجه، به سزاى آنكه با خدا خلف وعده كردند و از آن روى كه دروغ مى‌گفتند، در دلهايشان -تا روزى كه او را ديدار مى‌كنند- پيامدهاى نفاق را باقى گذارد.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mcccxiii{آيا ندانسته‌اند كه خدا راز آنان و نجواى ايشان را مى‌داند و خدا داناى رازهاى نهانى است؟\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mcccxiv{كسانى كه بر مؤمنانى كه [افزون بر صدقه واجب‌]، از روى ميل، صدقات [مستحبّ نيز] مى‌دهند، عيب مى‌گيرند، و [همچنين‌] از كسانى كه [در انفاق‌] جز به اندازه توانشان نمى‌يابند، [عيبجويى مى‌كنند] و آنان را به ريشخند مى‌گيرند، [بدانند كه ]خدا آنان را به ريشخند مى‌گيرد و براى ايشان عذابى پر درد خواهد بود.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mcccxv{چه براى آنان آمرزش بخواهى يا برايشان آمرزش نخواهى [يكسان است، حتى‌] اگر هفتاد بار برايشان آمرزش طلب كنى هرگز خدا آنان را نخواهد آمرزيد، چرا كه آنان به خدا و فرستاده‌اش كفر ورزيدند، و خدا گروه فاسقان را هدايت نمى‌كند.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mcccxvi{بر جاى‌ماندگان، به [خانه‌] نشستن خود، پس از رسول خدا، شادمان شدند، و از اينكه با مال و جان خود در راه خدا جهاد كنند، كراهت داشتند، و گفتند: «در اين گرما بيرون نرويد.» بگو: «-اگر دريابند- آتش جهنّم سوزان‌تر است.»\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mcccxvii{از اين پس كم بخندند، و به جزاى آنچه به دست مى‌آوردند، بسيار بگريند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mcccxviii{و اگر خدا تو را به سوى طايفه‌اى از آنان بازگردانيد، و آنان براى بيرون آمدن [به جنگ ديگرى‌] از تو اجازه خواستند، بگو: «شما هرگز با من خارج نخواهيد شد، و هرگز همراه من با هيچ دشمنى نبرد نخواهيد كرد، زيرا شما نخستين‌بار به نشستن تن درداديد. پس [اكنون هم‌] با خانه‌نشينان بنشينيد.»\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mcccxix{و هرگز بر هيچ مرده‌اى از آنان نماز مگزار و بر سر قبرش نايست، چرا كه آنان به خدا و پيامبر او كافر شدند و در حال فسق مردند.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mcccxx{و اموال و فرزندان آنان تو را به شگفت نيندازد. جز اين نيست كه خدا مى‌خواهد ايشان را در دنيا به وسيله آن عذاب كند و جانشان در حال كفر بيرون رود.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mcccxxi{و چون سوره‌اى نازل شود كه به خدا ايمان آوريد و همراه پيامبرش جهاد كنيد، ثروتمندانشان از تو عذر و اجازه خواهند و گويند: «بگذار كه ما با خانه‌نشينان باشيم.»\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mcccxxii{راضى شدند كه با خانه‌نشينان باشند، و بر دلهايشان مُهر زده شده است، در نتيجه قدرت درك ندارند.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mcccxxiii{ولى پيامبر و كسانى كه با او ايمان آورده‌اند با مال و جانشان به جهاد برخاسته‌اند. و اينانند كه همه خوبيها براى آنان است، اينان همان رستگارانند.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mcccxxiv{خدا براى آنان باغهايى آماده كرده است كه از زيرِ [درختان‌] آن نهرها روان است، و در آن جاودانه‌اند. اين همان رستگارىِ بزرگ است.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mcccxxv{و عذرخواهان باديه‌نشين [نزد تو] آمدند تا به آنان اجازه [ترك جهاد] داده شود. و كسانى كه به خدا و فرستاده او دروغ گفتند نيز در خانه نشستند. به زودى كسانى از آنان را كه كفر ورزيدند عذابى دردناك خواهد رسيد.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mcccxxvi{بر ناتوانان و بر بيماران و بر كسانى كه چيزى نمى‌يابند [تا در راه جهاد ] خرج كنند -در صورتى كه براى خدا و پيامبرش خيرخواهى نمايند- هيچ گناهى نيست، [و نيز] بر نيكوكاران ايرادى نيست، و خدا آمرزنده مهربان است.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mcccxxvii{و [نيز] گناهى نيست بر كسانى كه چون پيش تو آمدند تا سوارشان كنى [و] گفتى: «چيزى پيدا نمى‌كنم تا بر آن سوارتان كنم»، برگشتند، و در اثر اندوه، از چشمانشان اشك فرو مى‌ريخت كه [چرا] چيزى نمى‌يابند تا [در راه جهاد] خرج كنند.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mcccxxviii{ايراد فقط بر كسانى است كه با اينكه توانگرند از تو اجازه [ترك جهاد] مى‌خواهند. [و به اين‌] راضى شده‌اند كه با خانه‌نشينان باشند، و خدا بر دلهايشان مُهر نهاد، در نتيجه آنان نمى‌فهمند.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mcccxxix{هنگامى كه به سوى آنان بازگرديد براى شما عذر مى‌آورند. بگو: «عذر نياوريد، هرگز شما را باور نخواهيم داشت؛ خدا ما را از خبرهاى شما آگاه گردانيده، و به زودى خدا و رسولش عمل شما را خواهند ديد. آنگاه به سوى داناى نهان و آشكار، بازگردانيده مى‌شويد، و از آنچه انجام مى‌داديد به شما خبر مى‌دهد.»\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mcccxxx{وقتى به سوى آنان بازگشتيد، براى شما به خدا سوگند مى‌خورند تا از ايشان صرفنظر كنيد. پس، از آنان روى برتابيد، چرا كه آنان پليدند، و به [سزاى‌] آنچه به دست آورده‌اند جايگاهشان دوزخ خواهد بود.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mcccxxxi{براى شما سوگند ياد مى‌كنند تا از آنان خشنود گرديد. پس اگر شما هم از ايشان خشنود شويد قطعاً خدا از گروه فاسقان خشنود نخواهد شد.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mcccxxxii{باديه‌نشينان عرب، در كفر و نفاق [از ديگران‌] سخت‌تر، و به اينكه حدود آنچه را كه خدا بر فرستاده‌اش نازل كرده، ندانند، سزاوارترند. و خدا داناى حكيم است.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mcccxxxiii{و برخى از آن باديه‌نشينان كسانى هستند كه آنچه را [در راه خدا] هزينه مى‌كنند، خسارتى [براى خود] مى‌دانند، و براى شما پيشامدهاى بد انتظار مى‌برند. پيشامد بد براى آنان خواهد بود، و خدا شنواى داناست.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mcccxxxiv{و برخى [ديگر] از باديه‌نشينان كسانى‌اند كه به خدا و روز بازپسين ايمان دارند و آنچه را انفاق مى‌كنند مايه تقرّب نزد خدا و دعاهاى پيامبر مى‌دانند. بدانيد كه اين [انفاق‌] مايه تقرّب آنان است. به زودى خدا ايشان را در جوار رحمت خويش درآورد، كه خدا آمرزنده مهربان است.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mcccxxxv{و پيشگامان نخستين از مهاجران و انصار، و كسانى كه با نيكوكارى از آنان پيروى كردند، خدا از ايشان خشنود و آنان [نيز] از او خشنودند، و براى آنان باغهايى آماده كرده كه از زير [درختان‌] آن نهرها روان است. هميشه در آن جاودانه‌اند. اين است همان كاميابى بزرگ.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mcccxxxvi{و برخى از باديه‌نشينانى كه پيرامون شما هستند منافقند، و از ساكنان مدينه [نيز عده‌اى‌] بر نفاق خو گرفته‌اند. تو آنان را نمى‌شناسى، ما آنان را مى‌شناسيم. به زودى آنان را دو بار عذاب مى‌كنيم؛ سپس به عذابى بزرگ بازگردانيده مى‌شوند.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mcccxxxvii{و ديگرانى هستند كه به گناهان خود اعتراف كرده و كار شايسته را با [كارى‌] ديگر كه بد است درآميخته‌اند. اميد است خدا توبه آنان را بپذيرد، كه خدا آمرزنده مهربان است.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mcccxxxviii{از اموال آنان صدقه‌اى بگير تا به وسيله آن پاك و پاكيزه‌شان سازى، و برايشان دعا كن، زيرا دعاى تو براى آنان آرامشى است، و خدا شنواى داناست.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mcccxxxix{آيا ندانسته‌اند كه تنها خداست كه از بندگانش توبه را مى‌پذيرد و صدقات را مى‌گيرد، و خداست كه خود توبه‌پذير مهربان است؟\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mcccxl{و بگو: «[هر كارى مى‌خواهيد] بكنيد، كه به زودى خدا و پيامبر او و مؤمنان در كردار شما خواهند نگريست، و به زودى به سوى داناى نهان و آشكار بازگردانيده مى‌شويد؛ پس ما را به آنچه انجام مى‌داديد آگاه خواهد كرد.»\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mcccxli{و عدّه‌اى ديگر [كارشان‌] موقوف به فرمان خداست: يا آنان را عذاب مى‌كند و يا توبه آنها را مى‌پذيرد، و خدا داناى سنجيده‌كار است.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mcccxlii{و آنهايى كه مسجدى اختيار كردند كه مايه زيان و كفر و پراكندگى ميان مؤمنان است، و [نيز] كمينگاهى است براى كسى كه قبلاً با خدا و پيامبر او به جنگ برخاسته بود، و سخت سوگند ياد مى‌كنند كه جز نيكى قصدى نداشتيم. و[لى‌] خدا گواهى مى‌دهد كه آنان قطعاً دروغگو هستند.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mcccxliii{هرگز در آن جا مايست، چرا كه مسجدى كه از روز نخستين بر پايه تقوا بنا شده، سزاوارتر است كه در آن [به نماز] ايستى. [و] در آن، مردانى‌اند كه دوست دارند خود را پاك سازند، و خدا كسانى را كه خواهان پاكى‌اند دوست مى‌دارد.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mcccxliv{آيا كسى كه بنياد [كار] خود را بر پايه تقوا و خشنودى خدا نهاده بهتر است يا كسى كه بناى خود را بر لب پرتگاهى مُشرف به سقوط پى‌ريزى كرده و با آن در آتش دوزخ فرو مى‌افتد؟ و خدا گروه بيدادگران را هدايت نمى‌كند.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mcccxlv{همواره آن ساختمانى كه بنا كرده‌اند، در دلهايشان مايه شك [و نفاق‌] است، تا آنكه دلهايشان پاره پاره شود، و خدا داناى سنجيده‌كار است.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mcccxlvi{در حقيقت، خدا از مؤمنان، جان و مالشان را به [بهاى‌] اينكه بهشت براى آنان باشد، خريده است؛ همان كسانى كه در راه خدا مى‌جنگند و مى‌كُشند و كشته مى‌شوند. [اين‌] به عنوان وعده حقى در تورات و انجيل و قرآن بر عهده اوست. و چه كسى از خدا به عهد خويش وفادارتر است؟ پس به اين معامله‌اى كه با او كرده‌ايد شادمان باشيد، و اين همان كاميابى بزرگ است.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mcccxlvii{[آن مؤمنان،] همان توبه‌كنندگان، پرستندگان، سپاسگزاران، روزه‌داران، ركوع‌كنندگان، سجده‌كنندگان، وادارندگان به كارهاى پسنديده، بازدارندگان از كارهاى ناپسند و پاسداران مقرّرات خدايند. و مؤمنان را بشارت ده.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mcccxlviii{بر پيامبر و كسانى كه ايمان آورده‌اند سزاوار نيست كه براى مشركان -پس از آنكه برايشان آشكار گرديد كه آنان اهل دوزخند- طلب آمرزش كنند، هر چند خويشاوندِ [آنان‌] باشند.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@mcccxlix{و طلب آمرزش ابراهيم براى پدرش جز براى وعده‌اى كه به او داده بود، نبود. و[لى‌] هنگامى كه براى او روشن شد كه وى دشمن خداست، از او بيزارى جست. راستى، ابراهيم، دلسوزى بردبار بود.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@mcccl{و خدا بر آن نيست كه گروهى را پس از آنكه هدايتشان نمود بى‌راه بگذارد، مگر آنكه چيزى را كه بايد از آن پروا كنند برايشان بيان كرده باشد. آرى، خدا به هر چيزى داناست.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@mcccli{در حقيقت، فرمانروايى آسمانها و زمين از آن خداست. زنده مى‌كند و مى‌ميراند، و براى شما جز خدا يار و ياورى نيست.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@mccclii{به يقين، خدا بر پيامبر و مهاجران و انصار كه در آن ساعت دشوار از او پيروى كردند ببخشود، بعد از آنكه چيزى نمانده بود كه دلهاى دسته‌اى از آنان منحرف شود. باز برايشان ببخشود، چرا كه او نسبت به آنان مهربان و رحيم است.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@mcccliii{و [نيز] بر آن سه تن كه بر جاى مانده بودند، [و قبول توبه آنان به تعويق افتاد] تا آنجا كه زمين با همه فراخى‌اش بر آنان تنگ گرديد، و از خود به تنگ آمدند و دانستند كه پناهى از خدا جز به سوى او نيست. پس [خدا] به آنان [توفيق ]توبه داد، تا توبه كنند. بى ترديد خدا همان توبه‌پذير مهربان است.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@mcccliv{اى كسانى كه ايمان آورده‌ايد، از خدا پروا كنيد و با راستان باشيد.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@mccclv{مردم مدينه و باديه‌نشينان پيرامونشان را نرسد كه از [فرمان‌] پيامبر خدا سر باز زنند و جان خود را عزيزتر از جان او بدانند، چرا كه هيچ تشنگى و رنج و گرسنگيى در راه خدا به آنان نمى‌رسد؛ و در هيچ مكانى كه كافران را به خشم مى‌آورد قدم نمى‌گذارند و از دشمنى غنيمتى به دست نمى‌آورند مگر اينكه به سبب آن، عمل صالحى براى آنان [در كارنامه‌شان‌] نوشته مى‌شود، زيرا خدا پاداش نيكوكاران را ضايع نمى‌كند.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@mccclvi{و هيچ مال كوچك و بزرگى را انفاق نمى‌كنند و هيچ واديى را نمى‌پيمايند مگر اينكه به حساب آنان نوشته مى‌شود، تا خدا آنان را به بهتر از آنچه مى‌كردند پاداش دهد.\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@mccclvii{و شايسته نيست مؤمنان همگى [براى جهاد] كوچ كنند. پس چرا از هر فرقه‌اى از آنان، دسته‌اى كوچ نمى‌كنند تا [دسته‌اى بمانند و] در دين آگاهى پيدا كنند و قوم خود را -وقتى به سوى آنان بازگشتند بيم دهند- باشد كه آنان [از كيفر الهى ]بترسند؟\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@mccclviii{اى كسانى كه ايمان آورده‌ايد، با كافرانى كه مجاور شما هستند كارزار كنيد، و آنان بايد در شما خشونت بيابند، و بدانيد كه خدا با تقواپيشگان است.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@mccclix{و چون سوره‌اى نازل شود، از ميان آنان كسى است كه مى‌گويد: «اين [سوره‌] ايمان كدام يك از شما را افزود؟» اما كسانى كه ايمان آورده‌اند بر ايمانشان مى‌افزايد و آنان شادمانى مى‌كنند.\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@mccclx{اما كسانى كه در دلهايشان بيمارى است، پليدى بر پليديشان افزود و در حال كفر درمى‌گذرند.\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@mccclxi{آيا نمى‌بينند كه آنان در هر سال، يك يا دو بار آزموده مى‌شوند، باز هم توبه نمى‌كنند و عبرت نمى‌گيرند؟\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@mccclxii{و چون سوره‌اى نازل شود، بعضى از آنان به بعضى ديگر نگاه مى‌كنند [و مى‌گويند:] «آيا كسى شما را مى‌بيند؟» سپس [مخفيانه از حضور پيامبر] بازمى‌گردند. خدا دلهايشان را [از حق‌] برگرداند، زيرا آنان گروهى هستند كه نمى‌فهمند.\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@mccclxiii{قطعاً، براى شما پيامبرى از خودتان آمد كه بر او دشوار است شما در رنج بيفتيد، به [هدايت‌] شما حريص، و نسبت به مؤمنان، دلسوز مهربان است.\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@mccclxiv{پس اگر روى برتافتند، بگو: «خدا مرا بس است. هيچ معبودى جز او نيست. بر او توكل كردم، و او پروردگار عرش بزرگ است.»\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@mccclxv{\basmalahfa الف، لام، راء. اين است آيات كتاب حكمت‌آموز.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mccclxvi{آيا براى مردم شگفت‌آور است كه به مردى از خودشان وحى كرديم كه: مردم را بيم ده و به كسانى كه ايمان آورده‌اند مژده ده كه براى آنان نزد پروردگارشان سابقه نيك است؟ كافران گفتند: «اين [مرد] قطعاً افسونگرى آشكار است.»\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mccclxvii{پروردگار شما آن خدايى است كه آسمانها و زمين را در شش هنگام آفريد. سپس بر عرش استيلا يافت. كار [آفرينش‌] را تدبير مى‌كند. شفاعتگرى جز پس از اذن او نيست. اين است خدا، پروردگار شما، پس او را بپرستيد. آيا پند نمى‌گيريد؟\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mccclxviii{بازگشت همه شما به سوى اوست. وعده خدا حق است؛ هموست كه آفرينش را آغاز مى‌كند سپس آن را باز مى‌گرداند تا كسانى را كه ايمان آورده و كارهاى شايسته كرده‌اند به عدالت پاداش دهد، و كسانى كه كفر ورزيده‌اند به سزاى كفرشان شربتى از آب جوشان و عذابى پر درد خواهند داشت.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mccclxix{اوست كسى كه خورشيد را روشنايى بخشيد و ماه را تابان كرد، و براى آن منزلهايى معين كرد تا شماره سالها و حساب را بدانيد. خدا اينها را جز به حق نيافريده است. نشانه‌ها[ى خود] را براى گروهى كه مى‌دانند به روشنى بيان مى‌كند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mccclxx{به راستى، در آمد و رفت شب و روز و آنچه خدا در آسمانها و زمين آفريده، براى مردمى كه پروا دارند دلايلى [آشكار] است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mccclxxi{كسانى كه اميد به ديدار ما ندارند، و به زندگى دنيا دل خوش كرده و بدان اطمينان يافته‌اند، و كسانى كه از آيات ما غافلند،\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mccclxxii{آنان به [كيفر] آنچه به دست مى‌آوردند، جايگاهشان آتش است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mccclxxiii{كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، پروردگارشان به پاس ايمانشان آنان را هدايت مى‌كند به باغهاى [پر ناز و] نعمت، كه از زير [پاى‌] آنان نهرها روان خواهد بود [در خواهند آمد].\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mccclxxiv{نيايش آنان در آنجا سبحانك اللهم [=خدايا! تو پاك و منزهى‌] و درودشان در آنجا سلام است، و پايان نيايش آنان اين است كه: الحمد لله رب العالمين [=ستايش ويژه پروردگار جهانيان است‌].\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mccclxxv{و اگر خدا براى مردم به همان شتاب كه آنان در كار خير مى‌طلبند، در رساندن بلا به آنها شتاب مى‌نمود، قطعاً اجلشان فرا مى‌رسيد. پس كسانى را كه به ديدار ما اميد ندارند، در طغيانشان رها مى‌كنيم تا سرگردان بمانند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mccclxxvi{و چون انسان را آسيبى رسد، ما را -به پهلو خوابيده يا نشسته يا ايستاده- مى‌خواند، و چون گرفتاريش را برطرف كنيم چنان مى‌رود كه گويى ما را براى گرفتاريى كه به او رسيده، نخوانده است. اين گونه براى اسرافكاران آنچه انجام مى‌دادند زينت داده شده است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mccclxxvii{و قطعاً نسلهاى پيش از شما را هنگامى كه ستم كردند به هلاكت رسانديم، و پيامبرانشان دلايل آشكار برايشان آوردند و[لى‌] بر آن نبودند كه ايمان بياورند. اين گونه مردم بزهكار را جزا مى‌دهيم.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mccclxxviii{آنگاه شما را پس از آنان در زمين جانشين قرار داديم تا بنگريم چگونه رفتار مى‌كنيد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mccclxxix{و چون آيات روشن ما بر آنان خوانده شود، آنانكه به ديدار ما اميد ندارند مى‌گويند: «قرآن ديگرى جز اين بياور، يا آن را عوض كن.» بگو: «مرا نرسد كه آن را از پيش خود عوض كنم. جز آنچه را كه به من وحى مى‌شود پيروى نمى‌كنم. اگر پروردگارم را نافرمانى كنم، از عذاب روزى بزرگ مى‌ترسم.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mccclxxx{بگو: «اگر خدا مى‌خواست آن را بر شما نمى‌خواندم، و [خدا] شما را بدان آگاه نمى‌گردانيد. قطعاً پيش از [آوردن‌] آن، روزگارى در ميان شما به سر برده‌ام. آيا فكر نمى‌كنيد؟»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mccclxxxi{پس كيست ستمكارتر از آن كس كه دروغى بر خداى بندد يا آيات او را تكذيب كند؟ به راستى مجرمان رستگار نمى‌شوند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mccclxxxii{و به جاى خدا، چيزهايى را مى‌پرستند كه نه به آنان زيان مى‌رساند و نه به آنان سود مى‌دهد. و مى‌گويند: «اينها نزد خدا شفاعتگران ما هستند.» بگو: «آيا خدا را به چيزى كه در آسمانها و در زمين نمى‌داند، آگاه مى‌گردانيد؟» او پاك و برتر است از آنچه [با وى‌] شريك مى‌سازند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mccclxxxiii{و مردم جز يك امت نبودند. پس اختلاف پيدا كردند. و اگر وعده‌اى از جانب پروردگارت مقرر نگشته بود، قطعاً در آنچه بر سر آن با هم اختلاف مى‌كنند، ميانشان داورى مى‌شد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mccclxxxiv{و مى‌گويند: «چرا معجزه‌اى از جانب پروردگارش بر او نازل نمى‌شود؟» بگو: «غيب فقط به خدا اختصاص دارد. پس منتظر باشيد كه من هم با شما از منتظرانم.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mccclxxxv{و چون مردم را پس از آسيبى كه به ايشان رسيده است، رحمتى بچشانيم، بناگاه آنان را در آيات ما نيرنگى است. بگو: «نيرنگ خدا سريع‌تر است.» در حقيقت، فرستادگان [=فرشتگان‌] ما آنچه نيرنگ مى‌كنيد مى‌نويسند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mccclxxxvi{او كسى است كه شما را در خشكى و دريا مى‌گرداند، تا وقتى كه در كشتيها باشيد و آنها با بادى خوش، آنان را بِبَرَند و ايشان بدان شاد شوند [بناگاه‌] بادى سخت بر آنها وزد و موج از هر طرف بر ايشان تازد و يقين كنند كه در محاصره افتاده‌اند، در آن حال خدا را پاكدلانه مى‌خوانند كه: «اگر ما را از اين [ورطه‌] بِرَهانى، قطعاً از سپاسگزاران خواهيم شد.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mccclxxxvii{پس چون آنان را رهانيد، ناگهان در زمين بناحق سركشى مى‌كنند. اى مردم، سركشى شما فقط به زيان خود شماست. شما بهره زندگى دنيا را [مى‌طلبيد]. سپس بازگشت شما به سوى ما خواهد بود. پس شما را از آنچه انجام مى‌داديد باخبر خواهيم كرد.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mccclxxxviii{در حقيقت، مَثَل زندگى دنيا بسان آبى است كه آن را از آسمان فرو ريختيم، پس گياه زمين -از آنچه مردم و دامها مى‌خورند- با آن درآميخت، تا آنگاه كه زمين پيرايه خود را برگرفت و آراسته گرديد و اهل آن پنداشتند كه آنان بر آن قدرت دارند، شبى يا روزى فرمان [ويرانى‌] ما آمد و آن را چنان دِرَويده كرديم كه گويى ديروز وجود نداشته است. اين گونه نشانه‌ها[ى خود] را براى مردمى كه انديشه مى‌كنند به روشنى بيان مى‌كنيم.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mccclxxxix{و خدا [شما را] به سراى سلامت فرا مى‌خواند، و هر كه را بخواهد به راه راست هدايت مى‌كند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mcccxc{براى كسانى كه كار نيكو كرده‌اند، نيكويى [بهشت‌] و زياده [بر آن‌] است. چهره‌هايشان را غبارى و ذلتى نمى‌پوشاند. اينان اهل بهشتند [و] در آن جاودانه خواهند بود.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mcccxci{و كسانى كه مرتكب بديها شده‌اند، [بدانند كه‌] جزاى [هر] بدى مانند آن است و خوارى آنان را فرو مى‌گيرد. در مقابل خدا، هيچ حمايتگرى براى ايشان نيست. گويى چهره‌هايشان با پاره‌اى از شبِ تار پوشيده شده است. آنان همدم آتشند، كه در آن جاودانه خواهند بود.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mcccxcii{و [ياد كن‌] روزى را كه همه آنان را گرد مى‌آوريم. آنگاه به كسانى كه شرك ورزيده‌اند مى‌گوييم: «شما و شريكانتان بر جاى خود باشيد» پس ميان آنها جدايى مى‌افكنيم. و شريكان آنان مى‌گويند: «در حقيقت، شما ما را نمى‌پرستيديد.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mcccxciii{«و گواهى خدا ميان ما و ميان شما بس است. به راستى ما از عبادت شما بى‌خبر بوديم.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mcccxciv{آنجاست كه هر كسى آنچه را از پيش فرستاده است مى‌آزمايد، و به سوى خدا مولاى حقيقى خود بازگردانيده مى‌شوند، و آنچه به دروغ برمى‌ساخته‌اند از دستشان به در مى‌رود.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mcccxcv{بگو: «كيست كه از آسمان و زمين به شما روزى مى‌بخشد؟ يا كيست كه حاكم بر گوشها و ديدگان است؟ و كيست كه زنده را از مرده بيرون مى‌آورد و مرده را از زنده خارج مى‌سازد؟ و كيست كه كارها را تدبير مى‌كند؟» خواهند گفت: «خدا» پس بگو: «آيا پروا نمى‌كنيد؟»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mcccxcvi{اين است خدا، پروردگار حقيقى شما، و بعد از حقيقت جز گمراهى چيست؟ پس چگونه [از حق‌] بازگردانيده مى‌شويد؟\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mcccxcvii{اين گونه سخن پروردگارت بر كسانى كه نافرمانى كردند به حقيقت پيوست، [چرا] كه آنان ايمان نمى‌آورند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mcccxcviii{بگو: «آيا از شريكان شما كسى هست كه آفرينش را آغاز كند و سپس آن را برگرداند؟» بگو: «خداست كه آفرينش را آغاز مى‌كند و باز آن را برمى‌گرداند. پس چگونه [از حق‌] بازگردانيده مى‌شويد؟»\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mcccxcix{بگو: «آيا از شريكان شما كسى هست كه به سوى حق رهبرى كند؟» بگو: «خداست كه به سوى حق رهبرى مى‌كند» پس، آيا كسى كه به سوى حق رهبرى مى‌كند سزاوارتر است مورد پيروى قرار گيرد يا كسى كه راه نمى‌نمايد مگر آنكه [خود] هدايت شود؟ شما را چه شده، چگونه داورى مى‌كنيد؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mcd{و بيشترشان جز از گمان پيروى نمى‌كنند [ولى‌] گمان به هيچ وجه [آدمى را] از حقيقت بى‌نياز نمى‌گرداند. آرى، خدا به آنچه مى‌كنند داناست.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mcdi{و چنان نيست كه اين قرآن از جانب غير خدا [و] به دروغ ساخته شده باشد. بلكه تصديق [كننده‌] آنچه پيش از آن است مى‌باشد، و توضيحى از آن كتاب است، كه در آن ترديدى نيست، [و] از پروردگار جهانيان است.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mcdii{يا مى‌گويند: «آن را به دروغ ساخته است؟» بگو: «اگر راست مى‌گوييد، سوره‌اى مانند آن بياوريد، و هر كه را جز خدا مى‌توانيد، فرا خوانيد.»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mcdiii{بلكه چيزى را دروغ شمردند كه به علم آن احاطه نداشتند و هنوز تأويل آن برايشان نيامده است. كسانى [هم‌] كه پيش از آنان بودند، همين گونه [پيامبرانشان را] تكذيب كردند. پس بنگر كه فرجام ستمگران چگونه بوده است.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mcdiv{و از آنان كسى است كه بدان ايمان مى‌آورد، و از آنان كسى است كه بدان ايمان نمى‌آورد، و پروردگار تو به [حال‌] فسادگران داناتر است.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mcdv{و اگر تو را تكذيب كردند، بگو: «عمل من به من اختصاص دارد، و عمل شما به شما اختصاص دارد. شما از آنچه من انجام مى‌دهم غير مسؤوليد، و من از آنچه شما انجام نمى‌دهيد غير مسؤولم.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mcdvi{و برخى از آنان كسانى‌اند كه به تو گوش فرا مى‌دهند. آيا تو كران را -هر چند در نيابند- شنوا خواهى كرد؟\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mcdvii{و از آنان كسى است كه به سوى تو مى‌نگرد. آيا تو نابينايان را -هر چند نبينند- هدايت توانى كرد؟\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mcdviii{خدا به هيچ وجه به مردم ستم نمى‌كند، ليكن مردم خود بر خويشتن ستم مى‌كنند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mcdix{و روزى كه آنان را گرد مى‌آورد، گويى جز به اندازه ساعتى از روز درنگ نكرده‌اند. با هم اظهار آشنايى مى‌كنند. قطعاً كسانى كه ديدار خدا را دروغ شمردند زيان كردند و [به حقيقت‌] راه نيافتند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mcdx{و اگر پاره‌اى از آنچه را كه به آنان وعده مى‌دهيم به تو بنمايانيم، يا تو را بميرانيم [در هر دو صورت‌] بازگشتشان به سوى ماست. سپس خدا بر آنچه مى‌كنند گواه است.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mcdxi{و هر امتى را پيامبرى است. پس چون پيامبرشان بيايد، ميانشان به عدالت داورى شود و بر آنان ستم نرود.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mcdxii{و مى‌گويند: «اگر راست مى‌گوييد، اين وعده چه وقت است؟»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mcdxiii{بگو: «براى خود زيان و سودى در اختيار ندارم، مگر آنچه را كه خدا بخواهد. هر امتى را زمانى [محدود] است. آنگاه كه زمانشان به سر رسد، پس نه ساعتى [از آن‌] تأخير كنند و نه پيشى گيرند.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mcdxiv{بگو: «به من خبر دهيد، اگر عذاب او شب يا روز به شما دررسد، بزهكاران چه چيزى از آن به شتاب مى‌خواهند؟»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mcdxv{سپس، آيا هنگامى كه [عذاب بر شما] واقع شد، اكنون به آن ايمان آورديد، در حالى كه به [آمدن‌] آن شتاب مى‌نموديد؟\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mcdxvi{پس به كسانى كه ستم ورزيدند گفته شود: «عذاب جاويد را بچشيد. آيا جز به [كيفر] آنچه به دست مى‌آورديد، جزا داده مى‌شويد؟»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mcdxvii{و از تو خبر مى‌گيرند: «آيا آن راست است؟» بگو: «آرى! سوگند به پروردگارم كه آن قطعاً راست است، و شما نمى‌توانيد [خدا را] درمانده كنيد.»\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mcdxviii{و اگر، براى هر كسى كه ستم كرده است، آنچه در زمين است مى‌بود، قطعاً آن را براى [خلاصى و] بازخريد خود مى‌داد. و چون عذاب را ببينند پشيمانى خود را پنهان دارند، و ميان آنان به عدالت داورى شود و بر ايشان ستم نرود.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mcdxix{بدانيد، كه در حقيقت آنچه در آسمانها و زمين است از آنِ خداست. بدانيد، كه در حقيقت وعده خدا حق است ولى بيشتر آنان نمى‌دانند.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mcdxx{او زنده مى‌كند و مى‌ميراند و به سوى او بازگردانيده مى‌شويد.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mcdxxi{اى مردم، به يقين، براى شما از جانب پروردگارتان اندرزى، و درمانى براى آنچه در سينه‌هاست، و رهنمود و رحمتى براى گروندگان [به خدا] آمده است.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mcdxxii{بگو: «به فضل و رحمت خداست كه [مؤمنان‌] بايد شاد شوند.» و اين از هر چه گرد مى‌آورند بهتر است.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mcdxxiii{بگو: «به من خبر دهيد، آنچه از روزى كه خدا براى شما فرود آورده [چرا] بخشى از آن را حرام و [بخشى را] حلال گردانيده‌ايد.» بگو: «آيا خدا به شما اجازه داده يا بر خدا دروغ مى‌بنديد؟»\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mcdxxiv{و كسانى كه بر خدا دروغ مى‌بندند، روز رستاخيز چه گمان دارند؟ در حقيقت، خدا بر مردم، داراى بخشش است ولى بيشترشان سپاسگزارى نمى‌كنند.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mcdxxv{و در هيچ كارى نباشى و از سوى او [=خدا] هيچ [آيه‌اى‌] از قرآن نخوانى و هيچ كارى نكنيد، مگر اينكه ما بر شما گواه باشيم آنگاه كه بدان مبادرت مى‌ورزيد. و هم‌وزن ذرّه‌اى، نه در زمين و نه در آسمان از پروردگار تو پنهان نيست، و نه كوچكتر و نه بزرگتر از آن چيزى نيست، مگر اينكه در كتابى روشن [درج شده‌] است.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mcdxxvi{آگاه باشيد، كه بر دوستان خدا نه بيمى است و نه آنان اندوهگين مى‌شوند.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mcdxxvii{همانان كه ايمان آورده و پرهيزگارى ورزيده‌اند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mcdxxviii{در زندگى دنيا و در آخرت مژده براى آنان است. وعده‌هاى خدا را تبديلى نيست؛ اين همان كاميابى بزرگ است.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mcdxxix{سخن آنان تو را غمگين نكند، زيرا عزّت، همه از آنِ خداست. او شنواى داناست.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mcdxxx{آگاه باش، كه هر كه [و هر چه‌] در آسمانها، و هر كه [و هر چه‌] در زمين است از آنِ خداست. و كسانى كه غير از خدا شريكانى را مى‌خوانند، [از آنها] پيروى نمى‌كنند. اينان جز از گمان پيروى نمى‌كنند و جز گمان نمى‌برند.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mcdxxxi{اوست كسى كه براى شما شب را قرار داد تا در آن بياراميد و روز را روشن [گردانيد]. بى گمان، در اين [امر] براى مردمى كه مى‌شنوند نشانه‌هايى است.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mcdxxxii{گفتند: «خدا فرزندى براى خود اختيار كرده است.» منزّه است او. او بى‌نياز است. آنچه در آسمانها و آنچه در زمين است از آنِ اوست. شما را بر اين [ادّعا] حجّتى نيست. آيا چيزى را كه نمى‌دانيد، به دروغ بر خدا مى‌بنديد؟\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mcdxxxiii{بگو: «در حقيقت كسانى كه بر خدا دروغ مى‌بندند، رستگار نمى‌شوند.»\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mcdxxxiv{بهره‌اى [اندك‌] در دنيا [دارند]. سپس بازگشتشان به سوى ماست. آنگاه به [سزاى‌] آنكه كفر مى‌ورزيدند، عذاب سخت به آنان مى‌چشانيم.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mcdxxxv{و خبر نوح را بر آنان بخوان، آنگاه كه به قوم خود گفت: «اى قوم من، اگر ماندن من [در ميان شما] و اندرز دادن من به آيات خدا، بر شما گران آمده است، [بدانيد كه من‌] بر خدا توكّل كرده‌ام. پس [در] كارتان با شريكان خود همداستان شويد، تا كارتان بر شما ملتبس ننمايد سپس در باره من تصميم بگيريد و مهلتم ندهيد.»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mcdxxxvi{«و اگر روى گردانيديد، من مزدى از شما نمى‌طلبم. پاداش من جز بر عهده خدا نيست، و مأمورم كه از گردن‌نهندگان باشم.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mcdxxxvii{پس او را تكذيب كردند. آنگاه وى را با كسانى كه در كشتى همراه او بودند نجات داديم، و آنان را جانشين [تبهكاران‌] ساختيم، و كسانى را كه آيات ما را تكذيب كردند غرق كرديم. پس بنگر كه فرجام بيم‌داده‌شدگان چگونه بود.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mcdxxxviii{آنگاه، پس از وى رسولانى را به سوى قومشان برانگيختيم، و آنان دلايل آشكار برايشان آوردند، ولى ايشان بر آن نبودند كه به چيزى كه قبلاً آن را دروغ شمرده بودند ايمان بياورند. اين گونه ما بر دلهاى تجاوزكاران مُهر مى‌نهيم.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mcdxxxix{سپس، بعد از آنان موسى و هارون را با آيات خود، به سوى فرعون و سران [قوم‌] وى فرستاديم، و[لى آنان‌] گردنكشى كردند و گروهى تبهكار بودند.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mcdxl{پس چون حق از نزد ما به سويشان آمد، گفتند: «قطعاً اين سحرى آشكار است.»\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mcdxli{موسى گفت: «آيا وقتى حق به سوى شما آمد، مى‌گوييد: [اين سحر است؟] آيا اين سحر است؟ و حال آنكه جادوگران رستگار نمى‌شوند.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mcdxlii{گفتند: «آيا به سوى ما آمده‌اى تا ما را از شيوه‌اى كه پدرانمان را بر آن يافته‌ايم بازگردانى، و بزرگى در اين سرزمين براى شما دو تن باشد؟ ما به شما دو تن ايمان نداريم.»\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mcdxliii{و فرعون گفت: «هر جادوگر دانايى را پيش من آوريد.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mcdxliv{و چون جادوگران آمدند، موسى به آنان گفت: «آنچه را مى‌اندازيد بيندازيد.»\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mcdxlv{پس چون افكندند، موسى گفت: «آنچه را شما به ميان آورديد سحر است. به زودى خدا آن را باطل خواهد كرد. آرى، خدا كار مفسدان را تأييد نمى‌كند.»\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mcdxlvi{و خدا با كلمات خود، حق را ثابت مى‌گرداند، هر چند بزهكاران را خوش نيايد.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mcdxlvii{سرانجام، كسى به موسى ايمان نياورد مگر فرزندانى از قوم وى، در حالى كه بيم داشتند از آنكه مبادا فرعون و سران آنها ايشان را آزار رسانند، و در حقيقت، فرعون در آن سرزمين برترى‌جوى و از اسرافكاران بود.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mcdxlviii{و موسى گفت: «اى قوم من، اگر به خدا ايمان آورده‌ايد، و اگر اهل تسليميد بر او توكّل كنيد.»\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mcdxlix{پس گفتند: «بر خدا توكّل كرديم. پروردگارا، ما را براى قوم ستمگر [وسيله‌] آزمايش قرار مده.»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mcdl{«و ما را به رحمت خويش، از گروه كافران نجات ده.»\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mcdli{و به موسى و برادرش وحى كرديم كه شما دو تن براى قوم خود در مصر خانه‌هايى ترتيب دهيد و سراهايتان را رو به روى هم قرار دهيد و نماز برپا داريد و مؤمنان را مژده ده.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mcdlii{و موسى گفت: «پروردگارا، تو به فرعون و اشرافش در زندگى دنيا زيور و اموال داده‌اى، پروردگارا، تا [خلق را] از راه تو گمراه كنند، پروردگارا، اموالشان را نابود كن و آنان را دل‌سخت گردان كه ايمان نياورند تا عذاب دردناك را ببينند.»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mcdliii{فرمود: «دعاى هر دوى شما پذيرفته شد. پس ايستادگى كنيد و راه كسانى را كه نمى‌دانند پيروى مكنيد.»\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mcdliv{و فرزندان اسرائيل را از دريا گذرانديم، پس فرعون و سپاهيانش از روى ستم و تجاوز، آنان را دنبال كردند، تا وقتى كه در شُرف غرق شدن قرار گرفت، گفت: «ايمان آوردم كه هيچ معبودى جز آنكه فرزندان اسرائيل به او گرويده‌اند، نيست، و من از تسليم‌شدگانم.»\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mcdlv{اكنون؟ در حالى كه پيش از اين نافرمانى مى‌كردى و از تباهكاران بودى؟\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mcdlvi{پس امروز تو را با زره [زرين‌] خودت به بلندى [ساحل‌] مى‌افكنيم، تا براى كسانى كه از پى تو مى‌آيند عبرتى باشد، و بى‌گمان، بسيارى از مردم از نشانه‌هاى ما غافلند.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mcdlvii{به راستى ما فرزندان اسرائيل را در جايگاه‌[هاى‌] نيكو منزل داديم، و از چيزهاى پاكيزه به آنان روزى بخشيديم. پس به اختلاف نپرداختند مگر پس از آنكه علم براى آنان حاصل شد. همانا پروردگار تو در روز قيامت در باره آنچه بر سر آن اختلاف مى‌كردند ميانشان داورى خواهد كرد.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mcdlviii{و اگر از آنچه به سوى تو نازل كرده‌ايم در ترديدى، از كسانى كه پيش از تو كتاب [آسمانى‌] مى‌خواندند بپرس. قطعاً حق از جانب پروردگارت به سوى تو آمده است. پس زنهار از ترديدكنندگان مباش.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mcdlix{و از كسانى كه آيات ما را دروغ پنداشتند مباش، كه از زيانكاران خواهى بود.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mcdlx{در حقيقت، كسانى كه سخن پروردگارت بر آنان تحقّق يافته ايمان نمى‌آورند،\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mcdlxi{هر چند هر گونه آيتى برايشان بيايد، تا وقتى كه عذاب دردناك را ببينند.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mcdlxii{چرا هيچ شهرى نبود كه [اهل آن‌] ايمان بياورد و ايمانش به حال آن سود بخشد؟ مگر قوم يونس كه وقتى [در آخرين لحظه‌] ايمان آوردند، عذاب رسوايى را در زندگى دنيا از آنان برطرف كرديم، و تا چندى آنان را برخوردار ساختيم.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mcdlxiii{و اگر پروردگار تو مى‌خواست، قطعاً هر كه در زمين است همه آنها يكسر ايمان مى‌آوردند. پس آيا تو مردم را ناگزير مى‌كنى كه بگروند؟\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mcdlxiv{و هيچ كس را نرسد كه جز به اذن خدا ايمان بياورد، و [خدا] بر كسانى كه نمى انديشند، پليدى را قرار مى‌دهد.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mcdlxv{بگو: «بنگريد كه در آسمانها و زمين چيست؟» و[لى‌] نشانه‌ها و هشدارها، گروهى را كه ايمان نمى‌آورند سود نمى‌بخشد.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mcdlxvi{پس آيا جز مانند روزهاى كسانى را كه پيش از آنان درگذشتند، انتظار مى‌برند؟ بگو: «انتظار بريد كه من [نيز] با شما از منتظرانم.»\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mcdlxvii{سپس فرستادگان خود و كسانى را كه گرويدند مى‌رهانيم، زيرا بر ما فريضه است كه مؤمنان را نجات دهيم.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mcdlxviii{بگو: «اى مردم، اگر در دين من ترديد داريد، پس [بدانيد كه من‌] كسانى را كه به جاى خدا مى‌پرستيد نمى‌پرستم، بلكه خدايى را مى‌پرستم كه جان شما را مى‌ستاند، و دستور يافته‌ام كه از مؤمنان باشم.»\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mcdlxix{و [به من دستور داده شده است‌] كه به دين حنيف روى آور، و زنهار از مشركان مباش.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mcdlxx{و به جاى خدا، چيزى را كه سود و زيانى به تو نمى‌رساند، مخوان؛ كه اگر چنين كنى، در آن صورت قطعاً از جمله ستمكارانى.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mcdlxxi{و اگر خدا به تو زيانى برساند، آن را برطرف‌كننده‌اى جز او نيست، و اگر براى تو خيرى بخواهد، بخشش او را ردكننده‌اى نيست. آن را به هر كس از بندگانش كه بخواهد مى‌رساند، و او آمرزنده مهربان است.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mcdlxxii{بگو: «اى مردم، حق از جانب پروردگارتان براى شما آمده است. پس هر كه هدايت يابد به سود خويش هدايت مى‌يابد، و هر كه گمراه گردد به زيان خود گمراه مى‌شود، و من بر شما نگهبان نيستم.»\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mcdlxxiii{و از آنچه بر تو وحى مى‌شود پيروى كن و شكيبا باش تا خدا [ميان تو و آنان‌] داورى كند، و او بهترين داوران است.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mcdlxxiv{\basmalahfa الف، لام، راء. كتابى است كه آيات آن استحكام يافته، سپس از جانب حكيمى آگاه، به روشنى بيان شده است:\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mcdlxxv{كه جز خدا را نپرستيد. به راستى من از جانب او براى شما هشداردهنده و بشارتگرم،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mcdlxxvi{و اينكه از پروردگارتان آمرزش بخواهيد، سپس به درگاه او توبه كنيد، [تا اينكه‌] شما را با بهره‌مندى نيكويى تا زمانى معيّن بهره‌مند سازد، و به هر شايسته نعمتى از كَرَم خود عطا كند، و اگر رويگردان شويد من از عذاب روزى بزرگ بر شما بيمناكم.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mcdlxxvii{بازگشت شما به سوى خداست، و او بر هر چيزى تواناست.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mcdlxxviii{آگاه باشيد كه آنان دل مى‌گردانند [و مى‌كوشند] تا [راز خود را] از او نهفته دارند. آگاه باشيد آنگاه كه آنان جامه‌هايشان را بر سر مى‌كشند [خدا] آنچه را نهفته و آنچه را آشكار مى‌دارند، مى‌داند، زيرا او به اسرار سينه‌ها داناست.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mcdlxxix{و هيچ جنبنده‌اى در زمين نيست مگر [اينكه‌] روزيش بر عهده خداست، و [او] قرارگاه و محل مُردنش را مى‌داند. همه [اينها] در كتابى روشن [ثبت‌] است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mcdlxxx{و اوست كسى كه آسمانها و زمين را در شش هنگام آفريد و عرش او بر آب بود، تا شما را بيازمايد كه كدام‌يك نيكوكارتريد! و اگر بگويى: «شما پس از مرگ برانگيخته خواهيد شد» قطعاً كسانى كه كافر شده‌اند خواهند گفت: «اين [ادّعا] جز سحرى آشكار نيست.»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mcdlxxxi{و اگر عذاب را تا چندگاهى از آنان به تأخير افكنيم، حتماً خواهند گفت: «چه چيز آن را باز مى‌دارد؟» آگاه باش، روزى كه [عذاب‌] به آنان برسد از ايشان بازگشتنى نيست، و آنچه را كه مسخره مى‌كردند آنان را فرو خواهد گرفت.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mcdlxxxii{و اگر از جانب خود رحمتى به انسان بچشانيم، سپس آن را از وى سلب كنيم، قطعاً نوميد و ناسپاس خواهد بود.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mcdlxxxiii{و اگر -پس از محنتى كه به او رسيده- نعمتى به او بچشانيم حتماً خواهد گفت: «گرفتاريها از من دور شد!» بى‌گمان، او شادمان و فخرفروش است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mcdlxxxiv{مگر كسانى كه شكيبايى ورزيده و كارهاى شايسته كرده‌اند [كه‌] براى آنان آمرزش و پاداشى بزرگ خواهد بود.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mcdlxxxv{و مبادا تو برخى از آنچه را كه به سويت وحى مى‌شود ترك گويى و سينه‌ات بدان تنگ گردد كه مى‌گويند: «چرا گنجى بر او فرو فرستاده نشده يا فرشته‌اى با او نيامده است؟» تو فقط هشداردهنده‌اى، و خدا بر هر چيزى نگهبان است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mcdlxxxvi{يا مى‌گويند: «اين [قرآن‌] را به دروغ ساخته است.» بگو: «اگر راست مى‌گوييد، ده سوره برساخته‌شده مانند آن بياوريد و غير از خدا هر كه را مى‌توانيد فرا خوانيد.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mcdlxxxvii{پس اگر شما را اجابت نكردند، بدانيد كه آنچه نازل شده است به علم خداست، و اينكه معبودى جز او نيست. پس آيا شما گردن مى‌نهيد؟\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mcdlxxxviii{كسانى كه زندگى دنيا و زيور آن را بخواهند [جزاى‌] كارهايشان را در آنجا به طور كامل به آنان مى‌دهيم، و به آنان در آنجا كم داده نخواهد شد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mcdlxxxix{اينان كسانى هستند كه در آخرت جز آتش برايشان نخواهد بود، و آنچه در آنجا كرده‌اند به هدر رفته، و آنچه انجام مى‌داده‌اند باطل گرديده است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mcdxc{آيا كسى كه از جانب پروردگارش بر حجتى روشن است و شاهدى از [خويشان‌] او، پيرو آن است، و پيش از وى [نيز] كتاب موسى راهبر و مايه رحمت بوده است [دروغ مى‌بافد]؟ آنان [كه در جستجوى حقيقت‌اند] به آن مى‌گروند، و هر كس از گروه‌هاى [مخالف‌] به آن كفر ورزد آتش وعده‌گاه اوست. پس در آن ترديد مكن كه آن حقّ است [و] از جانب پروردگارت [آمده است‌] ولى بيشتر مردم باور نمى‌كنند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mcdxci{و چه كسى ستمكارتر از آن كس است كه بر خدا دروغ بندد؟ آنان بر پروردگارشان دروغ عرضه مى‌شوند، و گواهان خواهند گفت: «اينان بودند كه بر پروردگارشان دروغ بستند. هان! لعنت خدا بر ستمگران باد.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mcdxcii{همانان كه [مردم را] از راه خدا باز مى‌دارند و آن را كج مى‌شمارند و خود، آخرت را باور ندارند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mcdxciii{آنان در زمين درمانده‌كنندگان [خدا] نيستند، و جز خدا دوستانى براى آنان نيست. عذاب براى آنان دو چندان مى‌شود. آنان توان شنيدن [حق را] نداشتند و [حق را] نمى‌ديدند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mcdxciv{اينانند كه به خويشتن زيان زده و آنچه را به دروغ برساخته بودند از دست داده‌اند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mcdxcv{شك نيست كه آنان در آخرت زيانكارترند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mcdxcvi{بى‌گمان كسانى كه ايمان آورده و كارهاى شايسته كرده و [با فروتنى‌] به سوى پروردگارشان آرام يافتند، آنان اهل بهشتند و در آن جاودانه خواهند بود.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mcdxcvii{مَثَلِ اين دو گروه، چون نابينا و كر [در مقايسه‌] با بينا و شنواست. آيا در مَثَل يكسانند؟ پس آيا پند نمى‌گيريد؟\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mcdxcviii{و به راستى نوح را به سوى قومش فرستاديم. [گفت:] من براى شما هشداردهنده‌اى آشكارم،\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mcdxcix{كه جز خدا را نپرستيد، زيرا من از عذاب روزى سهمگين بر شما بيمناكم.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@md{پس، سران قومش كه كافر بودند، گفتند: «ما تو را جز بشرى مثل خود نمى‌بينيم، و جز [جماعتى از] فرومايگانِ ما، آن هم نسنجيده، نمى‌بينيم كسى تو را پيروى كرده باشد، و شما را بر ما امتيازى نيست، بلكه شما را دروغگو مى‌دانيم.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mdi{گفت: «اى قوم من، به من بگوييد، اگر از طرف پروردگارم حجتى روشن داشته باشم، و مرا از نزد خود رحمتى بخشيده باشد كه بر شما پوشيده است، آيا ما [بايد] شما را در حالى كه بدان اكراه داريد، به آن وادار كنيم؟»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mdii{«و اى قوم من، بر اين [رسالت،] مالى از شما درخواست نمى‌كنم. مُزد من جز بر عهده خدا نيست. و كسانى را كه ايمان آورده‌اند طرد نمى‌كنم. قطعاً آنان پروردگارشان را ديدار خواهند كرد، ولى شما را قومى مى‌بينم كه نادانى مى‌كنيد.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mdiii{و اى قوم من! اگر آنان را برانم، چه كسى مرا در برابر خدا يارى خواهد كرد؟ آيا عبرت نمى‌گيريد؟\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mdiv{«و به شما نمى‌گويم كه گنجينه‌هاى خدا پيش من است، و غيب نمى‌دانم، و نمى‌گويم كه من فرشته‌ام، و در باره كسانى كه ديدگان شما به خوارى در آنان مى‌نگرد، نمى‌گويم خدا هرگز خيرشان نمى‌دهد. خدا به آنچه در دل آنان است آگاه‌تر است. [اگر جز اين بگويم‌] من در آن صورت از ستمكاران خواهم بود.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mdv{گفتند: «اى نوح، واقعاً با ما جدال كردى و بسيار [هم‌] جدال كردى. پس اگر از راستگويانى آنچه را [از عذاب خدا] به ما وعده مى‌دهى براى ما بياور.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mdvi{گفت: «تنها خداست كه اگر بخواهد، آن را براى شما مى‌آورد و شما عاجز كننده [او] نخواهيد بود.»\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mdvii{و اگر بخواهم شما را اندرز دهم، در صورتى كه خدا بخواهد شما را بيراه گذارد، اندرز من شما را سودى نمى‌بخشد. او پروردگار شماست و به سوى او باز گردانيده مى‌شويد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mdviii{يا [در باره قرآن‌] مى‌گويند: «آن را بربافته است.» بگو: «اگر آن را به دروغ سر هم كرده‌ام، گناه من بر عهده خود من است، و[لى‌] من از جُرمى كه به من نسبت مى‌دهيد بركنارم.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mdix{و به نوح وحى شد كه: «از قوم تو، جز كسانى كه [تاكنون‌] ايمان آورده‌اند هرگز [كسى‌] ايمان نخواهد آورد. پس، از آنچه مى‌كردند غمگين مباش.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mdx{«و زير نظر ما و [به‌] وحى ما كِشتى را بساز، و در باره كسانى كه ستم كرده‌اند با من سخن مگوى، چرا كه آنان غرق شدنى‌اند.»\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mdxi{و [نوح‌] كشتى را مى‌ساخت، و هر بار كه اشرافى از قومش بر او مى‌گذشتند، او را مسخره مى‌كردند. مى‌گفت: «اگر ما را مسخره مى‌كنيد، ما [نيز] شما را همان گونه كه مسخره مى‌كنيد، مسخره خواهيم كرد.»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mdxii{به زودى خواهيد دانست چه كسى را عذابى خواركننده درمى‌رسد و بر او عذابى پايدار فرود مى‌آيد؟\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mdxiii{تا آنگاه كه فرمان ما دررسيد و تنور فوران كرد، فرموديم: «در آن [كشتى‌] از هر حيوانى يك جفت، با كسانت -مگر كسى كه قبلا در باره او سخن رفته است- و كسانى كه ايمان آورده‌اند، حمل كن.» و با او جز [عدّه‌] اندكى ايمان نياورده بودند!\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mdxiv{و [نوح‌] گفت: «در آن سوار شويد. به نام خداست روان‌شدنش و لنگرانداختنش، بى گمان پروردگار من آمرزنده مهربان است.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mdxv{و آن [كِشتى‌] ايشان را در ميان موجى كوه‌آسا مى‌بُرد، و نوح پسرش را كه در كنارى بود بانگ درداد: «اى پسرك من، با ما سوار شو و با كافران مباش.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mdxvi{گفت: «به زودى به كوهى پناه مى‌جويم كه مرا از آب در امان نگاه مى‌دارد.» گفت: «امروز در برابر فرمان خدا هيچ نگاهدارنده‌اى نيست، مگر كسى كه [خدا بر او] رحم كند.» و موج ميان آن دو حايل شد و [پسر] از غرق‌شدگان گرديد.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mdxvii{و گفته شد: «اى زمين، آب خود را فرو بر، و اى آسمان، [از باران‌] خوددارى كن. و آب فرو كاست و فرمان گزارده شده و [كشتى‌] بر جودى قرار گرفت.» و گفته شد: «مرگ بر قوم ستمكار.»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mdxviii{و نوح پروردگار خود را آواز داد و گفت: «پروردگارا، پسرم از كسان من است، و قطعاً وعده تو راست است و تو بهترين داورانى.»\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mdxix{فرمود: «اى نوح، او در حقيقت از كسان تو نيست، او [داراى‌] كردارى ناشايسته است. پس چيزى را كه بدان علم ندارى از من مخواه. من به تو اندرز مى‌دهم كه مبادا از نادانان باشى.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mdxx{گفت: «پروردگارا، من به تو پناه مى‌برم كه از تو چيزى بخواهم كه بدان علم ندارم، و اگر مرا نيامرزى و به من رحم نكنى از زيانكاران باشم.»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mdxxi{گفته شد: «اى نوح، با درودى از ما و بركتهايى بر تو و بر گروههايى كه با تواند، فرود آى. و گروههايى هستند كه به زودى برخوردارشان مى‌كنيم، سپس از جانب ما عذابى دردناك به آنان مى‌رسد.»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mdxxii{اين از خبرهاى غيب است كه آن را به تو وحى مى‌كنيم. پيش از اين نه تو آن را مى‌دانستى و نه قوم تو. پس شكيبا باش كه فرجام [نيك‌] از آنِ تقواپيشگان است.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mdxxiii{و به سوى [قوم‌] عاد، برادرشان هود را [فرستاديم. هود] گفت: «اى قوم من، خدا را بپرستيد. جز او هيچ معبودى براى شما نيست. شما فقط دروغ پردازيد.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mdxxiv{«اى قوم من، براى اين [رسالت‌] پاداشى از شما درخواست نمى‌كنم. پاداش من جز بر عهده كسى كه مرا آفريده است، نيست. پس آيا نمى‌انديشيد؟»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mdxxv{«و اى قوم من، از پروردگارتان آمرزش بخواهيد، سپس به درگاه او توبه كنيد [تا] از آسمان بر شما بارش فراوان فرستد و نيرويى بر نيروى شما بيفزايد، و تبهكارانه روى بر مگردانيد.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mdxxvi{گفتند: «اى هود، براى ما دليل روشنى نياوردى، و ما براى سخن تو دست از خدايان خود برنمى‌داريم و تو را باور نداريم.»\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mdxxvii{«[چيزى‌] جز اين نمى‌گوييم كه بعضى از خدايان ما به تو آسيبى رسانده‌اند.» گفت: «من خدا را گواه مى‌گيرم، و شاهد باشيد كه من از آنچه جز او شريك وى مى‌گيريد بيزارم.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mdxxviii{پس، همه شما در كار من نيرنگ كنيد و مرا مهلت مدهيد.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mdxxix{در حقيقت، من بر خدا، پروردگار خودم و پروردگار شما توكّل كردم. هيچ جنبنده‌اى نيست مگر اينكه او مهار هستى‌اش را در دست دارد. به راستى پروردگار من بر راه راست است.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mdxxx{پس اگر روى بگردانيد، به يقين، آنچه را كه به منظور آن به سوى شما فرستاده شده بودم به شما رسانيدم، و پروردگارم قومى جز شما را جانشين [شما] خواهد كرد. و به او هيچ زيانى نمى‌رسانيد. در حقيقت، پروردگارم بر هر چيزى نگاهبان است.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mdxxxi{و چون فرمان ما دررسيد، هود و كسانى را كه با او گرويده بودند، به رحمتى از جانب خود نجات بخشيديم و آنان را از عذابى سخت رهانيديم.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mdxxxii{و اين، [قوم‌] عاد بود كه آيات پروردگارشان را انكار كردند، و فرستادگانش را نافرمانى نمودند، و به دنبال فرمانِ هر زورگوى ستيزه‌جوى رفتند.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mdxxxiii{و [سرانجام‌] در اين دنيا و روز قيامت، لعنت بدرقه [راه‌] آنان گرديد. آگاه باشيد كه عاديان به پروردگارشان كفر ورزيدند. هان، مرگ بر عاديان: قوم هود.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mdxxxiv{و به سوى [قوم‌] ثمود، برادرشان صالح را [فرستاديم‌]. گفت: «اى قوم من! خدا را بپرستيد. براى شما هيچ معبودى جز او نيست. او شما را از زمين پديد آورد و در آن شما را استقرار داد. پس، از او آمرزش بخواهيد، آنگاه به درگاه او توبه كنيد، كه پروردگارم نزديك [و] اجابت‌كننده است.»\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mdxxxv{گفتند: «اى صالح، به راستى تو پيش از اين، ميان ما مايه اميد بودى. آيا ما را از پرستش آنچه پدرانمان مى‌پرستيدند باز مى‌دارى؟ و بى‌گمان، ما از آنچه تو ما را بدان مى‌خوانى سخت دچار شكّيم.»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mdxxxvi{گفت: «اى قوم من، چه بينيد، اگر [در اين دعوا] بر حجتى روشن از پروردگار خود باشم و از جانب خود رحمتى به من داده باشد، پس اگر او را نافرمانى كنم چه كسى در برابر خدا مرا يارى مى‌كند؟ در نتيجه، شما جز بر زيان من نمى‌افزاييد.»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mdxxxvii{«و اى قوم من، اين ماده‌شتر خداست كه براى شما پديده‌اى شگرف است. پس بگذاريد او در زمين خدا بخورد و آسيبش مرسانيد كه شما را عذابى زودرس فرو مى‌گيرد. «\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mdxxxviii{پس آن [ماده‌شتر] را پى كردند، و [صالح‌] گفت: «سه روز در خانه‌هايتان برخوردار شويد. اين وعده‌اى بى‌دروغ است.»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mdxxxix{پس چون فرمان ما در رسيد، صالح و كسانى را كه با او ايمان آورده بودند، به رحمت خود رهانيديم و از رسوايى آن روز [نجات داديم‌]. به يقين، پروردگار تو همان نيرومند شكست‌ناپذير است.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mdxl{و كسانى را كه ستم ورزيده بودند، آن بانگِ [مرگبار] فرا گرفت، و در خانه‌هايشان از پا درآمدند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mdxli{گويا هرگز در آن [خانه‌ها] نبوده‌اند. آگاه باشيد كه ثموديان به پروردگارشان كفر ورزيدند. هان، مرگ بر ثمود.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mdxlii{و به راستى، فرستادگان ما براى ابراهيم مژده آوردند، سلام گفتند، پاسخ داد: «سلام». و ديرى نپاييد كه گوساله‌اى بريان آورد.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mdxliii{و چون ديد دستهايشان به غذا دراز نمى‌شود، آنان را ناشناس يافت و از ايشان ترسى بر دل گرفت. گفتند: «مترس، ما به سوى قوم لوط فرستاده شده‌ايم.»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mdxliv{و زن او ايستاده بود. خنديد. پس وى را به اسحاق و از پى اسحاق به يعقوب مژده داديم.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mdxlv{[همسر ابراهيم‌] گفت: «اى واى بر من، آيا فرزند آورم با آنكه من پيرزنم، و اين شوهرم پيرمرد است؟ واقعاً اين چيزِ بسيار عجيبى است.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mdxlvi{گفتند: «آيا از كار خدا تعجّب مى‌كنى؟ رحمت خدا و بركات او بر شما خاندان [رسالت‌] باد. بى‌گمان، او ستوده‌اى بزرگوار است.»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mdxlvii{پس وقتى ترس ابراهيم زايل شد و مژده [فرزنددار شدن‌] به او رسيد، در باره قوم لوط با ما [به قصد شفاعت‌] چون و چرا مى‌كرد.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mdxlviii{زيرا ابراهيم، بردبار و نرمدل و بازگشت‌كننده [به سوى خدا] بود.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mdxlix{اى ابراهيم! از اين [چون و چرا] روى برتاب، كه فرمان پروردگارت آمده و براى آنان عذابى كه بى‌بازگشت است خواهد آمد.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mdl{و چون فرستادگان ما نزد لوط آمدند، به [آمدنِ‌] آنان ناراحت، و دستش از حمايت ايشان كوتاه شد و گفت: «امروز، روزى سخت است.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mdli{و قوم او شتابان به سويش آمدند، و پيش از آن كارهاى زشت مى‌كردند. [لوط] گفت: «اى قوم من، اينان دختران منند. آنان براى شما پاكيزه‌ترند. پس از خدا بترسيد و مرا در كار مهمانانم رسوا مكنيد. آيا در ميان شما آدمى عقل‌رس پيدا نمى‌شود؟»\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mdlii{گفتند: «تو خوب مى‌دانى كه ما را به دخترانت حاجتى نيست و تو خوب مى‌دانى كه ما چه مى‌خواهيم.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mdliii{[لوط] گفت: «كاش براى مقابله با شما قدرتى داشتم يا به تكيه‌گاهى استوار پناه مى‌جستم.»\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mdliv{گفتند: «اى لوط، ما فرستادگان پروردگار توييم. آنان هرگز به تو دست نخواهند يافت. پس، پاسى از شب گذشته خانواده‌ات را حركت ده -و هيچ كس از شما نبايد واپس بنگرد- مگر زنت، كه آنچه به ايشان رسد به او [نيز] خواهد رسيد. بى‌گمان، وعده‌گاه آنان صبح است. مگر صبح نزديك نيست؟»\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mdlv{پس چون فرمان ما آمد، آن [شهر] را زير و زبر كرديم و سنگ‌پاره‌هايى از [نوع‌] سنگ گلهاى لايه لايه، بر آن فرو ريختيم.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mdlvi{[سنگهايى‌] كه نزد پروردگارت نشان‌زده بود. و [خرابه‌هاى‌] آن از ستمگران چندان دور نيست.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mdlvii{و به سوى [اهل‌] مَدْيَن، برادرشان شعيب را [فرستاديم‌]. گفت: «اى قوم من، خدا را بپرستيد. براى شما جز او معبودى نيست. و پيمانه و ترازو را كم مكنيد. به راستى شما را در نعمت مى‌بينم. و[لى‌] از عذاب روزى فراگير بر شما بيمناكم.»\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mdlviii{«و اى قوم من، پيمانه و ترازو را به داد، تمام دهيد، و حقوق مردم را كم مدهيد، و در زمين به فساد سر برمداريد.»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mdlix{«اگر مؤمن باشيد، باقيمانده [حلال‌] خدا براى شما بهتر است، و من بر شما نگاهبان نيستم.»\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mdlx{گفتند: «اى شعيب، آيا نماز تو به تو دستور مى‌دهد كه آنچه را پدران ما مى‌پرستيده‌اند رها كنيم، يا در اموال خود به ميل خود تصرّف نكنيم؟ راستى كه تو بردبار فرزانه‌اى.»\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mdlxi{گفت: «اى قوم من، بينديشيد، اگر از جانب پروردگارم دليل روشنى داشته باشم، و او از سوى خود روزى نيكويى به من داده باشد [آيا باز هم از پرستش او دست بردارم؟] من نمى‌خواهم در آنچه شما را از آن باز مى‌دارم با شما مخالفت كنم [و خود مرتكب آن شوم‌]. من قصدى جز اصلاح [جامعه‌] تا آنجا كه بتوانم، ندارم، و توفيق من جز به [يارى‌] خدا نيست. بر او توكّل كرده‌ام و به سوى او بازمى‌گردم.»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mdlxii{«و اى قوم من، زنهار تا مخالفت شما با من، شما را بدانجا نكشاند كه [بلايى‌] مانند آنچه به قوم نوح يا قوم هود يا قوم صالح رسيد، به شما [نيز] برسد، و قوم لوط از شما چندان دور نيست.»\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mdlxiii{«و از پروردگار خود آمرزش بخواهيد، سپس به درگاه او توبه كنيد كه پروردگار من مهربان و دوستدار [بندگان‌] است.»\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mdlxiv{گفتند: «اى شعيب! بسيارى از آنچه را كه مى‌گويى نمى‌فهميم، و واقعاً تو را در ميان خود ضعيف مى‌بينيم، و اگر عشيره تو نبود قطعاً سنگسارت مى‌كرديم، و تو بر ما پيروز نيستى!»\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mdlxv{گفت: «اى قوم من، آيا عشيره من پيشِ شما از خدا عزيزتر است كه او را پشت سر خود گرفته‌ايد [و فراموشش كرده‌ايد]؟ در حقيقت، پروردگار من به آنچه انجام مى‌دهيد احاطه دارد.»\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mdlxvi{«و اى قوم من، شما بر حسب امكانات خود عمل كنيد، من [نيز] عمل مى‌كنم. به زودى خواهيد دانست كه عذاب رسواكننده بر چه كسى فرود مى‌آيد و دروغگو كيست؛ و انتظار بريد كه من [هم‌] با شما منتظرم.»\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mdlxvii{و چون فرمان ما آمد، شعيب و كسانى را كه با او ايمان آورده بودند، به رحمتى از جانب خويش نجات داديم، و كسانى را كه ستم كرده بودند، فرياد [مرگبار] فرو گرفت، و در خانه‌هايشان از پا درآمدند.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mdlxviii{گويى در آن [خانه‌ها] هرگز اقامت نداشته‌اند. هان، مرگ بر [مردم‌] مَدْيَن، همان گونه كه ثمود هلاك شدند.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mdlxix{و به راستى، موسى را با آيات خود و حجّتى آشكار،\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mdlxx{به سوى فرعون و سران [قوم‌] وى فرستاديم، ولى [سران‌] از فرمان فرعون پيروى كردند، و فرمان فرعون صواب نبود.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mdlxxi{روز قيامت پيشاپيش قومش مى‌رود و آنان را به آتش درمى‌آورد، و [دوزخ‌] چه ورودگاه بدى براى واردان است.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mdlxxii{و در اين دنيا و روز قيامت به لعنت بدرقه شدند، و چه بد عطايى نصيب آنان مى‌شود.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mdlxxiii{اين، از خبرهاى آن شهرهاست كه آن را بر تو حكايت مى‌كنيم. بعضى از آنها [هنوز] بر سرِ پا هستند و [بعضى‌] بر باد رفته‌اند.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mdlxxiv{و ما به آنان ستم نكرديم، ولى آنان به خودشان ستم كردند. پس چون فرمان پروردگارت آمد، خدايانى كه به جاى خدا[ى حقيقى‌] مى‌خواندند هيچ به كارشان نيامد، و جز بر هلاكت آنان نيفزود.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mdlxxv{و اين گونه بود [به قهر] گرفتن پروردگارت، وقتى شهرها را در حالى كه ستمگر بودند [به قهر] مى‌گرفت. آرى [به قهر] گرفتن او دردناك و سخت است.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mdlxxvi{قطعاً در اين [يادآوريها] براى كسى كه از عذاب آخرت مى‌ترسد عبرتى است. آن [روز] روزى است كه مردم را براى آن گرد مى‌آورند، و آن [روز] روزى است كه [جملگى در آن‌] حاضر مى‌شوند.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mdlxxvii{و ما آن را جز تا زمان معيّنى به تأخير نمى‌افكنيم.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mdlxxviii{روزى [است‌] كه چون فرا رسد هيچ كس جز به اذن وى سخن نگويد. آنگاه بعضى از آنان تيره‌بختند و [برخى‌] نيكبخت.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mdlxxix{و اما كسانى كه تيره‌بخت شده‌اند، در آتش، فرياد و ناله‌اى دارند.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mdlxxx{تا آسمانها و زمين برجاست، در آن ماندگار خواهند بود، مگر آنچه پروردگارت بخواهد، زيرا پروردگار تو همان كُند كه خواهد.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mdlxxxi{و اما كسانى كه نيكبخت شده‌اند، تا آسمانها و زمين برجاست، در بهشت جاودانند، مگر آنچه پروردگارت بخواهد. [كه اين‌] بخششى است كه بريدنى نيست.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mdlxxxii{پس در باره آنچه آنان [=مشركان‌] مى‌پرستند در ترديد مباش. آنان جز همان گونه كه قبلا پدرانشان مى‌پرستيدند، نمى‌پرستند. و ما بهره ايشان را تمام و ناكاسته خواهيم داد.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mdlxxxiii{و به حقيقت، ما به موسى كتاب [آسمانى‌] داديم، پس در مورد آن اختلاف شد، و اگر از جانب پروردگارت وعده‌اى پيشى نگرفته بود، قطعاً ميان آنها داورى شده بود، و بى گمان، آنان در باره آن در شكى بهتان‌آميزند.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mdlxxxiv{و قطعاً پروردگارت [نتيجه‌] اعمال هر يك را به تمام [و كمال‌] به آنان خواهد داد، چرا كه او به آنچه انجام مى‌دهند آگاه است.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mdlxxxv{پس، همان گونه كه دستور يافته‌اى ايستادگى كن، و هر كه با تو توبه كرده [نيز چنين كند]، و طغيان مكنيد كه او به آنچه انجام مى‌دهيد بيناست.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mdlxxxvi{و به كسانى كه ستم كرده‌اند متمايل مشويد كه آتش [دوزخ‌] به شما مى‌رسد، و در برابر خدا براى شما دوستانى نخواهد بود، و سرانجام يارى نخواهيد شد.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@mdlxxxvii{و در دو طرف روز [=اول و آخر آن‌] و نخستين ساعات شب نماز را برپا دار، زيرا خوبيها بديها را از ميان مى‌برد. اين براى پندگيرندگان، پندى است.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@mdlxxxviii{و شكيبا باش كه خدا پاداش نيكوكاران را ضايع نمى‌گرداند.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@mdlxxxix{پس چرا از نسلهاى پيش از شما خردمندانى نبودند كه [مردم را] از فساد در زمين باز دارند؟ جز اندكى از كسانى كه از ميان آنان نجاتشان داديم. و كسانى كه ستم كردند به دنبال ناز و نعمتى كه در آن بودند رفتند، و آنان بزهكار بودند.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@mdxc{و پروردگار تو [هرگز] بر آن نبوده است كه شهرهايى را كه مردمش اصلاحگرند، به ستم هلاك كند.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@mdxci{و اگر پروردگار تو مى‌خواست، قطعاً همه مردم را امّت واحدى قرار مى‌داد، در حالى كه پيوسته در اختلافند،\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@mdxcii{مگر كسانى كه پروردگار تو به آنان رحم كرده، و براى همين آنان را آفريده است. و وعده پروردگارت [چنين‌] تحقّق پذيرفته است [كه:] «البتّه جهنّم را از جنّ و انس يكسره پر خواهم كرد.»\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@mdxciii{و هر يك از سرگذشتهاى پيامبران [خود] را كه بر تو حكايت مى‌كنيم، چيزى است كه دلت را بدان استوار مى‌گردانيم، و در اينها حقيقت براى تو آمده، و براى مؤمنان اندرز و تذكّرى است.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@mdxciv{و به كسانى كه ايمان نمى‌آورند بگو: «بر حسب امكانات خود عمل كنيد كه ما [هم‌] عمل خواهيم كرد.»\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@mdxcv{«و منتظر باشيد كه ما [نيز] منتظر خواهيم بود.»\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@mdxcvi{و نهان آسمانها و زمين از آنِ خداست، و تمام كارها به او بازگردانده مى‌شود؛ پس او را پرستش كن و بر او توكّل نماى، و پروردگار تو از آنچه انجام مى‌دهيد غافل نيست.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@mdxcvii{\basmalahfa الف، لام، راء. اين است آيات كتاب روشنگر.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mdxcviii{ما آن را قرآنى عربى نازل كرديم، باشد كه بينديشيد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mdxcix{ما نيكوترين سرگذشت را به موجب اين قرآن كه به تو وحى كرديم، بر تو حكايت مى‌كنيم، و تو قطعاً پيش از آن از بى‌خبران بودى.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mdc{[ياد كن‌] زمانى را كه يوسف به پدرش گفت: «اى پدر، من [در خواب‌] يازده ستاره را با خورشيد و ماه ديدم. ديدم [آنها] براى من سجده مى‌كنند.»\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mdci{[يعقوب‌] گفت: «اى پسرك من، خوابت را براى برادرانت حكايت مكن كه براى تو نيرنگى مى‌انديشند، زيرا شيطان براى آدمى دشمنى آشكار است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mdcii{و اين چنين، پروردگارت تو را برمى‌گزيند، و از تعبير خوابها به تو مى‌آموزد، و نعمتش را بر تو و بر خاندان يعقوب تمام مى‌كند، همان گونه كه قبلاً بر پدران تو، ابراهيم و اسحاق، تمام كرد. در حقيقت، پروردگار تو داناى حكيم است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mdciii{به راستى در [سرگذشتِ‌] يوسف و برادرانش براى پُرسندگان عبرتهاست.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mdciv{هنگامى كه [برادران او] گفتند: «يوسف و برادرش نزد پدرمان از ما -كه جمعى نيرومند هستيم- دوست‌داشتنى‌ترند. قطعاً پدر ما در گمراهى آشكارى است.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mdcv{[يكى گفت:] «يوسف را بكُشيد يا او را به سرزمينى بيندازيد، تا توجّه پدرتان معطوف شما گردد، و پس از او مردمى شايسته باشيد.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mdcvi{گوينده‌اى از ميان آنان گفت: «يوسف را مكُشيد. اگر كارى مى‌كنيد، او را در نهانخانه چاه بيفكنيد، تا برخى از مسافران او را برگيرند.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mdcvii{گفتند: «اى پدر، تو را چه شده است كه ما را بر يوسف امين نمى‌دانى در حالى كه ما خيرخواه او هستيم؟\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mdcviii{فردا او را با ما بفرست تا [در چمن‌] بگردد و بازى كند، و ما به خوبى نگهبان او خواهيم بود.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mdcix{گفت: «اينكه او را ببَريد سخت مرا اندوهگين مى‌كند، و مى‌ترسم از او غافل شويد و گرگ او را بخورد.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mdcx{گفتند: «اگر گرگ او را بخورد با اينكه ما گروهى نيرومند هستيم، در آن صورت ما قطعاً [مردمى‌] بى‌مقدار خواهيم بود.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mdcxi{پس وقتى او را بردند و همداستان شدند تا او را در نهانخانه چاه بگذارند [چنين كردند]. و به او وحى كرديم كه قطعاً آنان را از اين كارشان -در حالى كه نمى‌دانند- با خبر خواهى كرد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mdcxii{و شامگاهان، گريان نزد پدر خود [باز] آمدند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mdcxiii{گفتند: «اى پدر، ما رفتيم مسابقه دهيم، و يوسف را پيش كالاى خود نهاديم. آنگاه گرگ او را خورد، ولى تو ما را هر چند راستگو باشيم باور نمى‌دارى.»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mdcxiv{و پيراهنش را [آغشته‌] به خونى دروغين آوردند. [يعقوب‌] گفت: «[نه‌] بلكه نَفْس شما كارى [بد] را براى شما آراسته است. اينك صبرى نيكو [براى من بهتر است‌]. و بر آنچه توصيف مى‌كنيد، خدا يارى‌ده است.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mdcxv{و كاروانى آمد. پس آب‌آور خود را فرستادند. و دلوش را انداخت. گفت: «مژده! اين يك پسر است!» و او را چون كالايى پنهان داشتند. و خدا به آنچه مى‌كردند دانا بود.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mdcxvi{و او را به بهاى ناچيزى -چند درهم- فروختند و در آن بى‌رغبت بودند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mdcxvii{و آن كس كه او را از مصر خريده بود به همسرش گفت: «نيكش بدار، شايد به حال ما سود بخشد يا او را به فرزندى اختيار كنيم.» و بدين گونه ما يوسف را در آن سرزمين مكانت بخشيديم تا به او تأويل خوابها را بياموزيم، و خدا بر كار خويش چيره است ولى بيشتر مردم نمى‌دانند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mdcxviii{و چون به حد رشد رسيد، او را حكمت و دانش عطا كرديم، و نيكوكاران را چنين پاداش مى‌دهيم.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mdcxix{و آن [بانو] كه وى در خانه‌اش بود خواست از او كام گيرد، و درها را [پياپى‌] چفت كرد و گفت: «بيا كه از آنِ توام!» [يوسف‌] گفت: «پناه بر خدا، او آقاى من است. به من جاى نيكو داده است. قطعاً ستمكاران رستگار نمى‌شوند.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mdcxx{و در حقيقت [آن زن‌] آهنگ وى كرد، و [يوسف نيز] اگر برهان پروردگارش را نديده بود، آهنگ او مى‌كرد. چنين [كرديم‌] تا بدى و زشتكارى را از او بازگردانيم، چرا كه او از بندگان مخلص ما بود.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mdcxxi{و آن دو به سوى در بر يكديگر سبقت گرفتند، و [آن زن‌] پيراهن او را از پشت بدريد و در آستانه در آقاى آن زن را يافتند. آن گفت: «كيفر كسى كه قصد بد به خانواده تو كرده چيست؟ جز اينكه زندانى يا [دچار] عذابى دردناك شود.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mdcxxii{[يوسف‌] گفت: «او از من كام خواست.» و شاهدى از خانواده آن زن شهادت داد: «اگر پيراهن او از جلو چاك خورده، زن راست گفته و او از دروغگويان است،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mdcxxiii{و اگر پيراهن او از پشت دريده شده، زن دروغ گفته و او از راستگويان است.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mdcxxiv{پس چون [شوهرش‌] ديد پيراهن او از پشت چاك خورده است گفت: «بى‌شك، اين از نيرنگ شما [زنان‌] است، كه نيرنگ شما [زنان‌] بزرگ است.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mdcxxv{«اى يوسف، از اين [پيشامد] روى بگردان. و تو [اى زن‌] براى گناه خود آمرزش بخواه كه تو از خطاكاران بوده‌اى.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mdcxxvi{و [دسته‌اى از] زنان در شهر گفتند: «زن عزيز از غلام خود، كام خواسته و سخت خاطرخواه او شده است. به راستى ما او را در گمراهى آشكارى مى‌بينيم.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mdcxxvii{پس چون [همسر عزيز] از مكرشان اطلاع يافت، نزد آنان [كسى‌] فرستاد، و محفلى برايشان آماده ساخت، و به هر يك از آنان [ميوه و] كاردى داد و [به يوسف‌] گفت: «بر آنان درآى.» پس چون [زنان‌] او را ديدند، وى را بس شگرف يافتند و [از شدت هيجان‌] دستهاى خود را بريدند و گفتند: «منزه است خدا، اين بشر نيست، اين جز فرشته‌اى بزرگوار نيست.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mdcxxviii{[زليخا] گفت: «اين همان است كه در باره او سرزنشم مى‌كرديد. آرى، من از او كام خواستم و[لى‌] او خود را نگاه داشت، و اگر آنچه را به او دستور مى‌دهم نكند قطعاً زندانى خواهد شد و حتماً از خوارشدگان خواهد گرديد.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mdcxxix{[يوسف‌] گفت: «پروردگارا، زندان براى من دوست‌داشتنى‌تر است از آنچه مرا به آن مى‌خوانند، و اگر نيرنگ آنان را از من بازنگردانى، به سوى آنان خواهم گراييد و از [جمله‌] نادانان خواهم شد.»\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mdcxxx{پس، پروردگارش [دعاى‌] او را اجابت كرد و نيرنگ آنان را از او بگردانيد. آرى، او شنواى داناست.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mdcxxxi{آنگاه پس از ديدن آن نشانه‌ها، به نظرشان آمد كه او را تا چندى به زندان افكنند.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mdcxxxii{و دو جوان با او به زندان درآمدند. [روزى‌] يكى از آن دو گفت: «من خويشتن را [به خواب‌] ديدم كه [انگور براى‌] شراب مى‌فشارم»؛ و ديگرى گفت: «من خود را [به خواب‌] ديدم كه بر روى سرم نان مى‌برم و پرندگان از آن مى‌خورند. به ما از تعبيرش خبر ده، كه ما تو را از نيكوكاران مى‌بينيم.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mdcxxxiii{گفت: «غذايى را كه روزى شماست براى شما نمى‌آورند مگر آنكه من از تعبير آن به شما خبر مى‌دهم پيش از آنكه [تعبير آن‌] به شما برسد. اين از چيزهايى است كه پروردگارم به من آموخته است. من آيين قومى را كه به خدا اعتقاد ندارند و منكر آخرتند رها كرده‌ام،\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mdcxxxiv{و آيين پدرانم، ابراهيم و اسحاق و يعقوب را پيروى نموده‌ام. براى ما سزاوار نيست كه چيزى را شريك خدا كنيم. اين از عنايت خدا بر ما و بر مردم است، ولى بيشتر مردم سپاسگزارى نمى‌كنند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mdcxxxv{اى دو رفيق زندانيم، آيا خدايان پراكنده بهترند يا خداى يگانه مقتدر؟\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mdcxxxvi{شما به جاى او جز نامهايى [چند] را نمى‌پرستيد كه شما و پدرانتان آنها را نامگذارى كرده‌ايد، و خدا دليلى بر [حقانيت‌] آنها نازل نكرده است. فرمان جز براى خدا نيست. دستور داده كه جز او را نپرستيد. اين است دين درست، ولى بيشتر مردم نمى‌دانند.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mdcxxxvii{اى دو رفيق زندانيم، اما يكى از شما به آقاى خود باده مى‌نوشاند، و اما ديگرى به دار آويخته مى‌شود و پرندگان از [مغز] سرش مى‌خورند. امرى كه شما دو تن از من جويا شديد تحقق يافت.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mdcxxxviii{و [يوسف‌] به آن كس از آن دو كه گمان مى‌كرد خلاص مى‌شود، گفت: «مرا نزد آقاى خود به ياد آور.» و[لى‌] شيطان، يادآورى به آقايش را از ياد او برد؛ در نتيجه، چند سالى در زندان ماند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mdcxxxix{و پادشاه [مصر] گفت: «من [در خواب‌] ديدم هفت گاو فربه است كه هفت [گاو] لاغر آنها را مى‌خورند، و هفت خوشه سبز و [هفت خوشه‌] خشگيده ديگر. اى سران قوم، اگر خواب تعبير مى‌كنيد، در باره خواب من، به من نظر دهيد.»\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mdcxl{گفتند: «خوابهايى است پريشان، و ما به تعبير خوابهاى آشفته دانا نيستيم.»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mdcxli{و آن كس از آن دو [زندانى‌] كه نجات يافته و پس از چندى [يوسف را] به خاطر آورده بود گفت: «مرا به [زندان‌] بفرستيد تا شما را از تعبير آن خبر دهم.»\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mdcxlii{«اى يوسف، اى مرد راستگوى، در باره [اين خواب كه‌] هفت گاو فربه، هفت [گاو] لاغر آنها را مى‌خورند، و هفت خوشه سبز و [هفت خوشه‌] خشگيده ديگر؛ به ما نظر ده، تا به سوى مردم برگردم، شايد آنان [تعبيرش را] بدانند.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mdcxliii{گفت: «هفت سال پى در پى مى‌كاريد، و آنچه را درويديد -جز اندكى را كه مى‌خوريد- در خوشه‌اش واگذاريد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mdcxliv{آنگاه پس از آن، هفت سال سخت مى‌آيد كه آنچه را براى آن [سالها] از پيش نهاده‌ايد -جز اندكى را كه ذخيره مى‌كنيد- همه را خواهند خورد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mdcxlv{آنگاه پس از آن، سالى فرا مى‌رسد كه به مردم در آن [سال‌] باران مى‌رسد و در آن آب ميوه مى‌گيرند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mdcxlvi{و پادشاه گفت: «او را نزد من آوريد.» پس هنگامى كه آن فرستاده نزد وى آمد، [يوسف‌] گفت: «نزد آقاى خويش برگرد و از او بپرس كه حال آن زنانى كه دستهاى خود را بريدند چگونه است؟ زيرا پروردگار من به نيرنگ آنان آگاه است.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mdcxlvii{[پادشاه‌] گفت: «وقتى از يوسف كام [مى‌]خواستيد چه منظور داشتيد؟» زنان گفتند: «منزه است خدا، ما گناهى بر او نمى‌دانيم،» همسر عزيز گفت: «اكنون حقيقت آشكار شد. من [بودم كه‌] از او كام خواستم، و بى‌شك او از راستگويان است.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mdcxlviii{[يوسف گفت:] «اين [درخواست اعاده حيثيت‌] براى آن بود كه [عزيز] بداند من در نهان به او خيانت نكردم، و خدا نيرنگ خائنان را به جايى نمى‌رساند.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mdcxlix{و من نفس خود را تبرئه نمى‌كنم، چرا كه نفس قطعاً به بدى امر مى‌كند، مگر كسى را كه خدا رحم كند، زيرا پروردگار من آمرزنده مهربان است.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mdcl{و پادشاه گفت: «او را نزد من آوريد، تا وى را خاص خود كنم.» پس چون با او سخن راند، گفت: «تو امروز نزد ما با منزلت و امين هستى.»\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mdcli{[يوسف‌] گفت: «مرا بر خزانه‌هاى اين سرزمين بگمار، كه من نگهبانى دانا هستم.»\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mdclii{و بدين گونه يوسف را در سرزمين [مصر] قدرت داديم، كه در آن، هر جا كه مى خواست سكونت مى‌كرد. هر كه را بخواهيم به رحمت خود مى‌رسانيم و اجر نيكوكاران را تباه نمى‌سازيم.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mdcliii{و البته اجر آخرت، براى كسانى كه ايمان آورده و پرهيزگارى مى‌نمودند، بهتر است.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mdcliv{و برادران يوسف آمدند و بر او وارد شدند. [او] آنان را شناخت ولى آنان او را نشناختند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mdclv{و چون آنان را به خوار و بارشان مجهز كرد، گفت: «برادر پدرى خود را نزد من آوريد. مگر نمى‌بينيد كه من پيمانه را تمام مى‌دهم و من بهترين ميزبانانم؟\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mdclvi{پس اگر او را نزد من نياورديد، براى شما نزد من پيمانه‌اى نيست، و به من نزديك نشويد.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mdclvii{گفتند: «او را با نيرنگ از پدرش خواهيم خواست، و محققاً اين كار را خواهيم كرد.»\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mdclviii{و [يوسف‌] به غلامان خود گفت: «سرمايه‌هاى آنان را در بارهايشان بگذاريد، شايد وقتى به سوى خانواده خود برمى‌گردند آن را بازيابند، اميد كه آنان بازگردند.»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mdclix{پس چون به سوى پدر خود بازگشتند، گفتند: «اى پدر، پيمانه از ما منع شد. برادرمان را با ما بفرست تا پيمانه بگيريم، و ما نگهبان او خواهيم بود.»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mdclx{[يعقوب‌] گفت: «آيا همان گونه كه شما را پيش از اين بر برادرش امين گردانيدم، بر او امين سازم؟ پس خدا بهترين نگهبان است، و اوست مهربانترين مهربانان.»\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mdclxi{و هنگامى كه بارهاى خود را گشودند، دريافتند كه سرمايه‌شان بدانها بازگردانيده شده است. گفتند: «اى پدر، [ديگر] چه مى‌خواهيم؟ اين سرمايه ماست كه به ما بازگردانيده شده است. قوت خانواده خود را فراهم، و برادرمان را نگهبانى مى‌كنيم، و [با بردن او] يك بار شتر مى‌افزاييم، و اين [پيمانه اضافى نزد عزيز] پيمانه‌اى ناچيز است.»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mdclxii{گفت: «هرگز او را با شما نخواهم فرستاد تا با من با نام خدا پيمان استوارى ببنديد كه حتماً او را نزد من باز آوريد، مگر آنكه گرفتار [حادثه‌اى‌] شويد.» پس چون پيمان خود را با او استوار كردند [يعقوب‌] گفت: «خدا بر آنچه مى‌گوييم وكيل است.»\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mdclxiii{و گفت: «اى پسران من، [همه‌] از يك دروازه [به شهر] در نياييد، بلكه از دروازه‌هاى مختلف وارد شويد، و من [با اين سفارش،] چيزى از [قضاى‌] خدا را از شما دور نمى‌توانم داشت. فرمان جز براى خدا نيست. بر او توكل كردم، و توكل‌كنندگان بايد بر او توكل كنند.»\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mdclxiv{و چون همان گونه كه پدرانشان به آنان فرمان داده بود وارد شدند، [اين كار] چيزى را در برابر خدا از آنان برطرف نمى‌كرد جز اينكه يعقوب نيازى را كه در دلش بود، برآورد و بى‌گمان، او از [بركت‌] آنچه بدو آموخته بوديم داراى دانشى [فراوان‌] بود، ولى بيشتر مردم نمى‌دانند.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mdclxv{و هنگامى كه بر يوسف وارد شدند، برادرش [بنيامين‌] را نزد خود جاى داد [و] گفت: «من برادر تو هستم.» بنابراين، از آنچه [برادران‌] مى‌كردند، غمگين مباش.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mdclxvi{پس هنگامى كه آنان را به خوار و بارشان مجهز كرد، آبخورى را در بار برادرش نهاد. سپس [به دستور او] نداكننده‌اى بانگ درداد: «اى كاروانيان، قطعاً شما دزد هستيد.»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mdclxvii{[برادران‌] در حالى كه به آنان روى كردند، گفتند: «چه گم كرده‌ايد؟»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mdclxviii{گفتند: «جام شاه را گم كرده‌ايم، و براى هر كس كه آن را بياورد يك بار شتر خواهد بود.» و [متصدى گفت:] «من ضامن آنم.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mdclxix{گفتند: «به خدا سوگند، شما خوب مى‌دانيد كه ما نيامده‌ايم در اين سرزمين فساد كنيم و ما دزد نبوده‌ايم.»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mdclxx{گفتند: «پس، اگر دروغ بگوييد، كيفرش چيست؟»\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mdclxxi{گفتند: «كيفرش [همان‌] كسى است كه [جام‌] در بار او پيدا شود. پس كيفرش خود اوست. ما ستمكاران را اين گونه كيفر مى‌دهيم.»\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mdclxxii{پس [يوسف‌] به [بازرسى‌] بارهاى آنان، پيش از بار برادرش، پرداخت. آنگاه آن را از بار برادرش [بنيامين‌] در آورد. اين گونه به يوسف شيوه آموختيم. [چرا كه‌] او در آيين پادشاه نمى‌توانست برادرش را بازداشت كند، مگر اينكه خدا بخواهد [و چنين راهى بدو بنمايد]. درجات كسانى را كه بخواهيم بالا مى‌بريم و فوق هر صاحب دانشى دانشورى است.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mdclxxiii{گفتند: «اگر او دزدى كرده، پيش از اين [نيز] برادرش دزدى كرده است. «يوسف اين [سخن‌] را در دل خود پنهان داشت و آن را برايشان آشكار نكرد [ولى‌] گفت: «موقعيت شما بدتر [از او]ست، و خدا به آنچه وصف مى‌كنيد داناتر است.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mdclxxiv{گفتند: «اى عزيز، او پدرى پير سالخورده دارد؛ بنابراين يكى از ما را به جاى او بگير، كه ما تو را از نيكوكاران مى‌بينيم.»\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mdclxxv{گفت: «پناه به خدا، كه جز آن كس را كه كالاى خود را نزد وى يافته‌ايم بازداشت كنيم، زيرا در آن صورت قطعاً ستمكار خواهيم بود.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mdclxxvi{پس چون از او نوميد شدند، رازگويان كنار كشيدند. بزرگشان گفت: «مگر نمى‌دانيد كه پدرتان با نام خدا پيمانى استوار از شما گرفته است و قبلا [هم‌] در باره يوسف تقصير كرديد؟ هرگز از اين سرزمين نمى‌روم تا پدرم به من اجازه دهد يا خدا در حق من داورى كند، و او بهترين داوران است.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mdclxxvii{پيش پدرتان بازگرديد و بگوييد: اى پدر، پسرت دزدى كرده، و ما جز آنچه مى‌دانيم گواهى نمى‌دهيم و ما نگهبان غيب نبوديم.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mdclxxviii{و از [مردم‌] شهرى كه در آن بوديم و كاروانى كه در ميان آن آمديم جويا شو، و ما قطعاً راست مى‌گوييم.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mdclxxix{[يعقوب‌] گفت: «[چنين نيست،] بلكه نفس شما امرى [نادرست‌] را براى شما آراسته است. پس [صبر من‌] صبرى نيكوست. اميد كه خدا همه آنان را به سوى من [باز] آورد، كه او داناى حكيم است.»\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mdclxxx{و از آنان روى گردانيد و گفت: «اى دريغ بر يوسف، و در حالى كه اندوه خود را فرو مى‌خورد، چشمانش از اندوه سپيد شد.»\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mdclxxxi{[پسران او] گفتند: «به خدا سوگند كه پيوسته يوسف را ياد مى‌كنى تا بيمار شوى يا هلاك گردى.»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mdclxxxii{گفت: «من شكايت غم و اندوه خود را پيش خدا مى‌برم، و از [عنايت‌] خدا چيزى مى‌دانم كه شما نمى‌دانيد.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mdclxxxiii{اى پسران من، برويد و از يوسف و برادرش جستجو كنيد و از رحمت خدا نوميد مباشيد، زيرا جز گروه كافران كسى از رحمت خدا نوميد نمى‌شود.»\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mdclxxxiv{پس چون [برادران‌] بر او وارد شدند، گفتند: «اى عزيز، به ما و خانواده ما آسيب رسيده است و سرمايه‌اى ناچيز آورده‌ايم. بنابراين پيمانه ما را تمام بده و بر ما تصدق كن كه خدا صدقه‌دهندگان را پاداش مى‌دهد.»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mdclxxxv{گفت: «آيا دانستيد، وقتى كه نادان بوديد، با يوسف و برادرش چه كرديد؟»\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mdclxxxvi{گفتند: «آيا تو خود، يوسفى؟» گفت: «[آرى،] من يوسفم و اين برادر من است. به راستى خدا بر ما منت نهاده است. بى‌گمان، هر كه تقوا و صبر پيشه كند، خدا پاداش نيكوكاران را تباه نمى‌كند.»\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mdclxxxvii{گفتند: «به خدا سوگند، كه واقعاً خدا تو را بر ما برترى داده است و ما خطاكار بوديم.»\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mdclxxxviii{[يوسف‌] گفت: «امروز بر شما سرزنشى نيست. خدا شما را مى‌آمرزد و او مهربانترين مهربانان است.»\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mdclxxxix{«اين پيراهن مرا ببريد و آن را بر چهره پدرم بيفكنيد [تا] بينا شود، و همه كسان خود را نزد من آوريد.»\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mdcxc{و چون كاروان رهسپار شد، پدرشان گفت: «اگر مرا به كم‌خردى نسبت ندهيد، بوى يوسف را مى‌شنوم.»\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mdcxci{گفتند: «به خدا سوگند كه تو سخت در گمراهىِ ديرين خود هستى.»\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mdcxcii{پس چون مژده‌رسان آمد، آن [پيراهن‌] را بر چهره او انداخت، پس بينا گرديد. گفت: «آيا به شما نگفتم كه بى‌شك من از [عنايت‌] خدا چيزهايى مى‌دانم كه شما نمى‌دانيد؟»\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mdcxciii{گفتند: «اى پدر، براى گناهان ما آمرزش خواه كه ما خطاكار بوديم.»\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mdcxciv{گفت: «به زودى از پروردگارم براى شما آمرزش مى‌خواهم، كه او همانا آمرزنده مهربان است.»\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mdcxcv{پس چون بر يوسف وارد شدند، پدر و مادر خود را در كنار خويش گرفت و گفت: «ان شاء الله، با [امن و] امان داخل مصر شويد.»\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mdcxcvi{و پدر و مادرش را به تخت برنشانيد، و [همه آنان‌] پيش او به سجده درافتادند، و [يوسف‌] گفت: «اى پدر، اين است تعبير خواب پيشين من، به يقين، پروردگارم آن را راست گردانيد و به من احسان كرد آنگاه كه مرا از زندان خارج ساخت و شما را از بيابان [كنعان به مصر] باز آورد -پس از آنكه شيطان ميان من و برادرانم را به هم زد- بى گمان، پروردگار من نسبت به آنچه بخواهد صاحب لطف است، زيرا كه او داناى حكيم است.»\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mdcxcvii{«پروردگارا، تو به من دولت دادى و از تعبير خوابها به من آموختى. اى پديدآورنده آسمانها و زمين، تنها تو در دنيا و آخرت مولاى منى؛ مرا مسلمان بميران و مرا به شايستگان ملحق فرما.»\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mdcxcviii{اين [ماجرا] از خبرهاى غيب است كه به تو وحى مى‌كنيم، و تو هنگامى كه آنان همداستان شدند و نيرنگ مى‌كردند نزدشان نبودى.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mdcxcix{و بيشتر مردم -هر چند آرزومند باشى- ايمان‌آورنده نيستند.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mdcc{و تو بر اين [كار] پاداشى از آنان نمى‌خواهى. آن [قرآن‌] جز پندى براى جهانيان نيست.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mdcci{و چه بسيار نشانه‌ها در آسمانها و زمين است كه بر آنها مى‌گذرند در حالى كه از آنها روى برمى‌گردانند.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mdccii{و بيشترشان به خدا ايمان نمى‌آورند جز اينكه [با او چيزى را] شريك مى‌گيرند.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mdcciii{آيا ايمنند از اينكه عذاب فراگير خدا به آنان دررسد، يا قيامت -در حالى كه بى‌خبرند- بناگاه آنان را فرا رسد؟\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mdcciv{بگو: «اين است راه من، كه من و هر كس (پيروى‌ام) كرد با بينايى به سوى خدا دعوت مى‌كنيم، و منزّه است خدا، و من از مشركان نيستم.»\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mdccv{و پيش از تو [نيز] جز مردانى از اهل شهرها را -كه به آنان وحى مى‌كرديم- نفرستاديم. آيا در زمين نگرديده‌اند تا فرجام كسانى را كه پيش از آنان بوده‌اند بنگرند؟ و قطعاً سراى آخرت براى كسانى كه پرهيزگارى كرده‌اند بهتر است. آيا نمى‌انديشيد؟\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mdccvi{تا هنگامى كه فرستادگان [ما] نوميد شدند و [مردم‌] پنداشتند كه به آنان واقعاً دروغ گفته شده، يارىِ ما به آنان رسيد. پس كسانى را كه مى‌خواستيم، نجات يافتند، و[لى‌] عذاب ما از گروه مجرمان برگشت ندارد.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mdccvii{به راستى در سرگذشت آنان، براى خردمندان عبرتى است. سخنى نيست كه به دروغ ساخته شده باشد، بلكه تصديق آنچه [از كتابهايى‌] است كه پيش از آن بوده و روشنگر هر چيز است و براى مردمى كه ايمان مى‌آورند رهنمود و رحمتى است.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mdccviii{\basmalahfa الف، لام، ميم، راء. اين است آيات كتاب، و آنچه از جانب پروردگارت به سوى تو نازل شده، حق است، ولى بيشتر مردم نمى‌گروند.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mdccix{خدا [همان‌] كسى است كه آسمانها را بدون ستونهايى كه آنها را ببينيد برافراشت، آنگاه بر عرش استيلا يافت و خورشيد و ماه را رام گردانيد؛ هر كدام براى مدّتى معيّن به سير خود ادامه مى‌دهند. [خداوند] در كار [آفرينش‌] تدبير مى‌كند، و آيات [خود] را به روشنى بيان مى‌نمايد، اميد كه شما به لقاى پروردگارتان يقين حاصل كنيد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mdccx{و اوست كسى كه زمين را گسترانيد و در آن، كوهها و رودها نهاد، و از هر گونه ميوه‌اى در آن، جفت جفت قرار داد. روز را به شب مى‌پوشاند. قطعاً در اين [امور] براى مردمى كه تفكّر مى‌كنند نشانه‌هايى وجود دارد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mdccxi{و در زمين قطعاتى است كنار هم، و باغهايى از انگور و كشتزارها و درختان خرما، چه از يك ريشه و چه از غير يك ريشه، كه با يك آب سيراب مى‌گردند، و [با اين همه‌] برخى از آنها را در ميوه [از حيث مزه و نوع و كيفيت‌] بر برخى ديگر برترى مى‌دهيم. بى گمان در اين [امر نيز] براى مردمى كه تعقّل مى‌كنند دلايل [روشنى‌] است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mdccxii{و اگر عجب دارى، عجب از سخن آنان [=كافران‌] است كه: «آيا وقتى خاك شديم، به راستى در آفرينش جديدى خواهيم بود؟» اينان همان كسانند كه به پروردگارشان كفر ورزيده‌اند و در گردنهايشان زنجيرهاست، و آنان همدم آتشند و در آن ماندگار خواهند بود.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mdccxiii{و پيش از رحمت، شتابزده از تو عذاب مى‌طلبند و حال آنكه پيش از آنان [بر كافران‌] عقوبتها رفته است، و به راستى پروردگار تو نسبت به مردم -با وجود ستمشان- بخشايشگر است، و به يقين پروردگار تو سخت‌كيفر است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mdccxiv{و آنان كه كافر شده‌اند مى‌گويند: «چرا نشانه‌اى آشكار از طرف پروردگارش بر او نازل نشده است؟» [اى پيامبر،] تو فقط هشداردهنده‌اى، و براى هر قومى رهبرى است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mdccxv{خدا مى‌داند آنچه را كه هر ماده‌اى [در رحم‌] بار مى‌گيرد، و [نيز] آنچه را كه رحمها مى‌كاهند و آنچه را مى‌افزايند. و هر چيزى نزد او اندازه‌اى دارد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mdccxvi{داناى نهان و آشكار، [و] بزرگِ بلندمرتبه است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mdccxvii{[براى او] يكسان است: كسى از شما سخن [خود] را نهان كند و كسى كه آن را فاش گرداند، و كسى كه خويشتن را به شب پنهان دارد و در روز، آشكارا حركت كند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mdccxviii{براى او فرشتگانى است كه پى در پى او را به فرمان خدا از پيش رو و از پشت سرش پاسدارى مى‌كنند. در حقيقت، خدا حال قومى را تغيير نمى‌دهد تا آنان حال خود را تغيير دهند. و چون خدا براى قومى آسيبى بخواهد، هيچ برگشتى براى آن نيست، و غير از او حمايتگرى براى آنان نخواهد بود.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mdccxix{اوست كسى كه برق را براى بيم و اميد به شما مى‌نماياند، و ابرهاى گرانبار را پديدار مى‌كند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mdccxx{رعد، به حمد او، و فرشتگان [جملگى‌] از بيمش تسبيح مى‌گويند، و صاعقه‌ها را فرو مى‌فرستند و با آنها هر كه را بخواهد، مورد اصابت قرار مى‌دهد، در حالى كه آنان در باره خدا مجادله مى‌كنند، و او سخت‌كيفر است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mdccxxi{دعوت حق براى اوست. و كسانى كه [مشركان‌] جز او مى‌خوانند، هيچ جوابى به آنان نمى‌دهند، مگر مانند كسى كه دو دستش را به سوى آب بگشايد تا [آب‌] به دهانش برسد، در حالى كه [آب‌] به [دهان‌] او نخواهد رسيد، و دعاى كافران جز بر هدر نباشد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mdccxxii{و هر كه در آسمانها و زمين است -خواه و ناخواه- با سايه‌هايشان، بامدادان و شامگاهان، براى خدا سجده مى‌كنند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mdccxxiii{بگو: «پروردگار آسمانها و زمين كيست؟» بگو: «خدا!» بگو: «پس آيا جز او سرپرستانى گرفته‌ايد كه اختيار سود و زيان خود را ندارند؟» بگو: «آيا نابينا و بينا يكسانند؟ يا تاريكيها و روشنايى برابرند؟ يا براى خدا شريكانى پنداشته‌اند كه مانند آفرينش او آفريده‌اند و در نتيجه، [اين دو] آفرينش بر آنان مشتبه شده است؟» بگو: «خدا آفريننده هر چيزى است، و اوست يگانه قهار.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mdccxxiv{[همو كه‌] از آسمان، آبى فرو فرستاد. پس رودخانه‌هايى به اندازه گنجايش خودشان روان شدند، و سيل، كفى بلند روى خود برداشت، و از آنچه براى به دست آوردن زينتى يا كالايى، در آتش مى‌گدازند هم نظير آن كفى برمى‌آيد. خداوند، حق و باطل را چنين مَثَل مى‌زند. اما كف، بيرون افتاده از ميان مى‌رود، ولى آنچه به مردم سود مى‌رساند در زمين [باقى‌] مى‌ماند. خداوند مَثَلها را چنين مى‌زند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mdccxxv{براى كسانى كه پروردگارشان را اجابت كرده‌اند پاداش بس نيكوست. و كسانى كه وى را اجابت نكرده‌اند، اگر سراسر آنچه در زمين است و مانند آن را با آن داشته باشند، قطعاً آن را براى بازخريد خود خواهند داد. آنان به سختى بازخواست شوند و جايشان در دوزخ است و چه بد جايگاهى است.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mdccxxvi{پس، آيا كسى كه مى‌داند آنچه از جانب پروردگارت به تو نازل شده، حقيقت دارد، مانند كسى است كه كوردل است؟ تنها خردمندانند كه عبرت مى‌گيرند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mdccxxvii{همانان كه به پيمان خدا وفادارند و عهد [او] را نمى‌شكنند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mdccxxviii{و آنان كه آنچه را خدا به پيوستنش فرمان داده مى‌پيوندند و از پروردگارشان مى‌ترسند و از سختى حساب بيم دارند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mdccxxix{و كسانى كه براى طلب خشنودى پروردگارشان شكيبايى كردند و نماز برپا داشتند و از آنچه روزيشان داديم، نهان و آشكارا انفاق كردند، و بدى را با نيكى مى‌زدايند، ايشان راست فرجامِ خوشِ سراى باقى.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mdccxxx{[همان‌] بهشتهاى عدن كه آنان با پدرانشان و همسرانشان و فرزندانشان كه درستكارند در آن داخل مى‌شوند، و فرشتگان از هر درى بر آنان درمى‌آيند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mdccxxxi{[و به آنان مى‌گويند:] «درود بر شما به [پاداش‌] آنچه صبر كرديد. راستى چه نيكوست فرجام آن سراى!»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mdccxxxii{و كسانى كه پيمان خدا را پس از بستن آن مى‌شكنند و آنچه را خدا به پيوستن آن فرمان داده مى‌گسلند و در زمين فساد مى‌كنند، بر ايشان لعنت است و بد فرجامى آن سراى ايشان راست.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mdccxxxiii{خدا روزى را براى هر كه بخواهد گشاده يا تنگ مى‌گرداند، و[لى آنان‌] به زندگى دنيا شاد شده‌اند، و زندگى دنيا در [برابر] آخرت جز بهره‌اى [ناچيز] نيست.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mdccxxxiv{و كسانى كه كافر شده‌اند مى‌گويند: «چرا از جانب پروردگارش معجزه‌اى بر او نازل نشده است؟» بگو: «در حقيقت خداست كه هر كس را بخواهد بى‌راه مى‌گذارد و هر كس را كه [به سوى او] بازگردد، به سوى خود راه مى‌نمايد.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mdccxxxv{همان كسانى كه ايمان آورده‌اند و دلهايشان به ياد خدا آرام مى‌گيرد. آگاه باش كه با ياد خدا دلها آرامش مى‌يابد.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mdccxxxvi{كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، خوشا به حالشان، و خوش سرانجامى دارند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mdccxxxvii{بدين گونه تو را در ميان امتى كه پيش از آن، امتهايى روزگار به سر بردند، فرستاديم تا آنچه را به تو وحى كرديم بر آنان بخوانى، در حالى كه آنان به [خداى‌] رحمان كفر مى‌ورزند. بگو: «اوست پروردگار من. معبودى بجز او نيست. بر او توكل كرده‌ام و بازگشت من به سوى اوست.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mdccxxxviii{و اگر قرآنى بود كه كوهها بدان روان مى‌شد، يا زمين بدان قطعه قطعه مى‌گرديد، يا مردگان بدان به سخن درمى‌آمدند [باز هم در آنان اثر نمى‌كرد.] نه چنين است، بلكه همه امور بستگى به خدا دارد. آيا كسانى كه ايمان آورده‌اند، ندانسته‌اند كه اگر خدا مى‌خواست قطعاً تمام مردم را به راه مى‌آورد؟ و كسانى كه كافر شده‌اند پيوسته به [سزاى‌] آنچه كرده‌اند مصيبت كوبنده‌اى به آنان مى‌رسد يا نزديك خانه‌هايشان فرود مى‌آيد، تا وعده خدا فرا رسد. آرى، خدا وعده [خود را] خلاف نمى‌كند.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mdccxxxix{و بى‌گمان، فرستادگان پيش از تو [نيز] مسخره شدند. پس به كسانى كه كافر شده بودند مهلت دادم، آنگاه آنان را [به كيفر] گرفتم. پس چگونه بود كيفر من؟\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mdccxl{آيا كسى كه بر هر شخصى بدانچه كرده است مراقب است [مانند كسى است كه از همه جا بى‌خبر است‌]؟ و براى خدا شريكانى قرار دادند. بگو: «نامشان را ببريد» آيا او را به آنچه در زمين است و او نمى‌داند خبر مى‌دهيد، يا سخنى سطحى [و ميان‌تهى‌] مى‌گوييد؟ [چنين نيست‌] بلكه براى كسانى كه كافر شده‌اند نيرنگشان آراسته شده و از راه [حق‌] بازداشته شده‌اند و هر كه را خدا بى‌راه گذارد رهبرى نخواهد داشت.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mdccxli{براى آنان در زندگى دنيا عذابى است، و قطعاً عذاب آخرت دشوارتر است، و براى ايشان در برابر خدا هيچ نگهدارنده‌اى نيست.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mdccxlii{وصف بهشتى كه به پرهيزگاران وعده داده شده [اين است كه‌] از زير [درختان ] آن نهرها روان است. ميوه و سايه‌اش پايدار است. اين است فرجام كسانى كه پرهيزگارى كرده‌اند و فرجام كافران آتش [دوزخ ]است.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mdccxliii{و كسانى كه به آنان كتاب [آسمانى‌] داده‌ايم، از آنچه به سوى تو نازل شده شاد مى‌شوند. و برخى از دسته‌ها كسانى هستند كه بخشى از آن را انكار مى‌كنند. بگو: «جز اين نيست كه من مأمورم خدا را بپرستم و به او شرك نورزم. به سوى او مى‌خوانم و بازگشتم به سوى اوست.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mdccxliv{و بدين سان آن [قرآن‌] را فرمانى روشن نازل كرديم، و اگر پس از دانشى كه به تو رسيده [باز] از هوسهاى آنان پيروى كنى، در برابر خدا هيچ دوست و حمايتگرى نخواهى داشت.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mdccxlv{و قطعاً پيش از تو [نيز] رسولانى فرستاديم، و براى آنان زنان و فرزندانى قرار داديم. و هيچ پيامبرى را نرسد كه جز به اذن خدا معجزه‌اى بياورد. براى هر زمانى كتابى است.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mdccxlvi{خدا آنچه را بخواهد محو يا اثبات مى‌كند، و اصل كتاب نزد اوست.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mdccxlvii{و اگر پاره‌اى از آنچه را كه به آنان وعده مى‌دهيم به تو بنمايانيم، يا تو را بميرانيم، جز اين نيست كه بر تو رساندن [پيام‌] است و بر ما حساب [آنان‌].\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mdccxlviii{آيا نديده‌اند كه ما [همواره‌] مى‌آييم و از اطراف اين زمين مى‌كاهيم؟ و خداست كه حكم مى‌كند. براى حكم او باز دارنده‌اى نيست، و او به سرعت حسابرسى مى‌كند.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mdccxlix{و به يقين، كسانى كه پيش از آنان بودند نيرنگ كردند، ولى همه تدبيرها نزد خداست. آنچه را كه هر كسى به دست مى‌آورد مى‌داند. و به زودى كافران بدانند كه فرجام آن سراى از كيست.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mdccl{و كسانى كه كافر شدند مى‌گويند: «تو فرستاده نيستى.» بگو: «كافى است خدا و آن كس كه نزد او علم كتاب است، ميان من و شما گواه باشد.»\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mdccli{\basmalahfa الف، لام، راء. كتابى است كه آن را به سوى تو فرود آورديم تا مردم را به اذن پروردگارشان از تاريكيها به سوى روشنايى بيرون آورى: به سوى راه آن شكست ناپذير ستوده.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mdcclii{خدايى كه آنچه در آسمانها و آنچه در زمين است از آنِ اوست، و واى بر كافران از عذابى سخت.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mdccliii{همانان كه زندگى دنيا را بر آخرت ترجيح مى‌دهند و مانع راه خدا مى‌شوند و آن را كج مى‌شمارند. آنانند كه در گمراهى دور و درازى هستند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mdccliv{و ما هيچ پيامبرى را جز به زبان قومش نفرستاديم، تا [حقايق را] براى آنان بيان كند. پس خدا هر كه را بخواهد بى‌راه مى‌گذارد و هر كه را بخواهد هدايت مى‌كند، و اوست ارجمند حكيم.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mdcclv{و در حقيقت، موسى را با آيات خود فرستاديم [و به او فرموديم‌] كه قوم خود را از تاريكيها به سوى روشنايى بيرون آور، و روزهاى خدا را به آنان يادآورى كن، كه قطعاً در اين [يادآورى‌]، براى هر شكيباىِ سپاسگزارى عبرتهاست.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mdcclvi{و [به خاطر بياور] هنگامى را كه موسى به قوم خود گفت: «نعمت خدا را بر خود به ياد آوريد، آنگاه كه شما را از فرعونيان رهانيد، [همانان‌] كه بر شما عذاب سخت روا مى‌داشتند، و پسرانتان را سر مى‌بريدند و زنانتان را زنده مى‌گذاشتند، و در اين [امر] براى شما از جانب پروردگارتان آزمايشى بزرگ بود.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mdcclvii{و آنگاه كه پروردگارتان اِعلام كرد كه اگر واقعاً سپاسگزارى كنيد، [نعمت‌] شما را افزون خواهم كرد، و اگر ناسپاسى نماييد، قطعاً عذاب من سخت خواهد بود.»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mdcclviii{و موسى گفت: «اگر شما و هر كه در روى زمين است همگى كافر شويد، بى‌گمان، خدا بى‌نياز ستوده‌[صفات‌] است.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mdcclix{آيا خبر كسانى كه پيش از شما بودند: قوم نوح و عاد و ثمود، و آنانكه بعد از ايشان بودند [و] كسى جز خدا از آنان آگاهى ندارد، به شما نرسيده است؟ فرستادگانشان دلايل آشكار برايشان آوردند، ولى آنان دستهايشان را [به نشانه اعتراض‌] بر دهانهايشان نهادند و گفتند: «ما به آنچه شما بدان مأموريت داريد كافريم، و از آنچه ما را بدان مى‌خوانيد سخت در شكّيم.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mdcclx{پيامبرانشان گفتند: «مگر در باره خدا -پديد آورنده آسمانها و زمين- ترديدى هست؟ او شما را دعوت مى‌كند تا پاره‌اى از گناهانتان را بر شما ببخشايد و تا زمانِ معينى شما را مهلت دهد.» گفتند: «شما جز بشرى مانند ما نيستيد. مى‌خواهيد ما را از آنچه پدرانمان مى‌پرستيدند باز داريد. پس براى ما حجّتى آشكار بياوريد.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mdcclxi{پيامبرانشان به آنان گفتند: «ما جز بشرى مثل شما نيستيم. ولى خدا بر هر يك از بندگانش كه بخواهد منّت مى‌نهد، و ما را نرسد كه جز به اذن خدا براى شما حجّتى بياوريم، و مؤمنان بايد تنها بر خدا توكل كنند.»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mdcclxii{و چرا بر خدا توكل نكنيم و حال آنكه ما را به راه‌هايمان رهبرى كرده است؟ و البته ما بر آزارى كه به ما رسانديد شكيبايى خواهيم كرد، و توكل‌كنندگان بايد تنها بر خدا توكل كنند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mdcclxiii{و كسانى كه كافر شدند، به پيامبرانشان گفتند: «شما را از سرزمين خودمان بيرون خواهيم كرد مگر اينكه به كيش ما بازگرديد.» پس پروردگارشان به آنان وحى كرد كه حتماً ستمگران را هلاك خواهيم كرد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mdcclxiv{و قطعاً شما را پس از ايشان در آن سرزمين سكونت خواهيم داد. اين براى كسى است كه از ايستادن [در محشر به هنگام حساب‌] در پيشگاه من بترسد و از تهديدم بيم داشته باشد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mdcclxv{و [پيامبران از خدا] گشايش خواستند، و [سرانجام‌] هر زورگوى لجوجى نوميد شد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mdcclxvi{[آن كس كه‌] دوزخ پيش روى اوست و به او آبى چركين نوشانده مى‌شود.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mdcclxvii{آن را جرعه جرعه مى‌نوشد و نمى‌تواند آن را فرو برد، و مرگ از هر جانبى به سويش مى‌آيد ولى نمى‌ميرد و عذابى سنگين به دنبال دارد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mdcclxviii{مَثَل كسانى كه به پروردگار خود كافر شدند، كردارهايشان به خاكسترى مى‌ماند كه بادى تند در روزى طوفانى بر آن بوزد: از آنچه به دست آورده‌اند هيچ [بهره‌اى‌] نمى‌توانند بُرد. اين است همان گمراهى دور و دراز.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mdcclxix{آيا در نيافته‌اى كه خدا آسمانها و زمين را به حق آفريده؟ اگر بخواهد شما را مى‌برد و خلق تازه‌اى مى‌آورد،\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mdcclxx{و اين [كار] بر خدا دشوار نيست.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mdcclxxi{و همگى در برابر خدا ظاهر مى‌شوند. پس ناتوانان به گردنكشان مى‌گويند: «ما پيروان شما بوديم. آيا چيزى از عذاب خدا را از ما دور مى‌كنيد؟» مى‌گويند: «اگر خدا ما را هدايت كرده بود، قطعاً شما را هدايت مى‌كرديم. چه بى‌تابى كنيم، چه صبر نماييم براى ما يكسان است. ما را راهِ گريزى نيست.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mdcclxxii{و چون كار از كار گذشت [و داورى صورت گرفت‌] شيطان مى‌گويد: «در حقيقت، خدا به شما وعده داد وعده راست، و من به شما وعده دادم و با شما خلاف كردم، و مرا بر شما هيچ تسلطى نبود، جز اينكه شما را دعوت كردم و اجابتم نموديد. پس مرا ملامت نكنيد و خود را ملامت كنيد. من فريادرس شما نيستم و شما هم فريادرس من نيستيد. من به آنچه پيش از اين مرا [در كار خدا] شريك مى‌دانستيد كافرم». آرى! ستمكاران عذابى پردرد خواهند داشت.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mdcclxxiii{و كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند به بهشتهايى درآورده مى‌شوند كه از زير [درختان‌] آن جويبارها روان است كه به اذن پروردگارشان در آنجا جاودانه به سر مى‌برند، و درودشان در آنجا سلام است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mdcclxxiv{آيا نديدى خدا چگونه مَثَل زده: سخنى پاك كه مانند درختى پاك است كه ريشه‌اش استوار و شاخه‌اش در آسمان است؟\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mdcclxxv{ميوه‌اش را هر دم به اذن پروردگارش مى‌دهد. و خدا مَثَلها را براى مردم مى‌زند، شايد كه آنان پند گيرند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mdcclxxvi{و مَثَل سخنى ناپاك چون درختى ناپاك است كه از روى زمين كنده شده و قرارى ندارد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mdcclxxvii{خدا كسانى را كه ايمان آورده‌اند، در زندگى دنيا و در آخرت با سخن استوار ثابت مى‌گرداند، و ستمگران را بى‌راه مى‌گذارد، و خدا هر چه بخواهد انجام مى‌دهد.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mdcclxxviii{آيا به كسانى كه [شكر] نعمت خدا را به كفر تبديل كردند و قوم خود را به سراى هلاكت درآوردند ننگريستى؟\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mdcclxxix{[در آن سراى هلاكت كه‌] جهنم است [و] در آن وارد مى‌شوند، و چه بد قرارگاهى است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mdcclxxx{و براى خدا مانندهايى قرار دادند تا [مردم را] از راه او گمراه كنند. بگو: «برخوردار شويد كه قطعاً بازگشت شما به سوى آتش است.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mdcclxxxi{به آن بندگانم كه ايمان آورده‌اند بگو: «نماز را بر پا دارند و از آنچه به ايشان روزى داده‌ايم، پنهان و آشكارا انفاق كنند، پيش از آنكه روزى فرا رسد كه در آن نه داد و ستدى باشد و نه دوستيى.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mdcclxxxii{خداست كه آسمانها و زمين را آفريد، و از آسمان آبى فرستاد، و به وسيله آن از ميوه‌ها براى شما روزى بيرون آورد، و كشتى را براى شما رام گردانيد تا به فرمان او در دريا روان شود، و رودها را براى شما مسخّر كرد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mdcclxxxiii{و خورشيد و ماه را -كه پيوسته روانند- براى شما رام گردانيد و شب و روز را [نيز] مسخر شما ساخت.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mdcclxxxiv{و از هر چه از او خواستيد به شما عطا كرد، و اگر نعمت خدا را شماره كنيد، نمى‌توانيد آن را به شمار درآوريد. قطعاً انسان ستم‌پيشه ناسپاس است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mdcclxxxv{و [ياد كن‌] هنگامى را كه ابراهيم گفت: «پروردگارا، اين شهر را ايمن گردان، و مرا و فرزندانم را از پرستيدن بتان دور دار.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mdcclxxxvi{پروردگارا، آنها بسيارى از مردم را گمراه كردند. پس هر كه از من پيروى كند، بى گمان، او از من است، و هر كه مرا نافرمانى كند، به يقين، تو آمرزنده و مهربانى.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mdcclxxxvii{پروردگارا، من [يكى از] فرزندانم را در درّه‌اى بى‌كشت، نزد خانه محترم تو، سكونت دادم. پروردگارا، تا نماز را به پا دارند، پس دلهاى برخى از مردم را به سوى آنان گرايش ده و آنان را از محصولات [مورد نيازشان‌] روزى ده، باشد كه سپاسگزارى كنند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mdcclxxxviii{پروردگارا، بى‌گمان تو آنچه را كه پنهان مى‌داريم و آنچه را كه آشكار مى‌سازيم مى‌دانى، و چيزى در زمين و در آسمان بر خدا پوشيده نمى‌ماند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mdcclxxxix{سپاس خداى را كه با وجود سالخوردگى، اسماعيل و اسحاق را به من بخشيد. به راستى پروردگار من شنونده دعاست.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mdccxc{پروردگارا، مرا برپادارنده نماز قرار ده، و از فرزندان من نيز. پروردگارا، و دعاى مرا بپذير.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mdccxci{پروردگارا، روزى كه حساب برپا مى‌شود، بر من و پدر و مادرم و بر مؤمنان ببخشاى.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mdccxcii{و خدا را از آنچه ستمكاران مى‌كنند غافل مپندار. جز اين نيست كه [كيفر] آنان را براى روزى به تأخير مى‌اندازد كه چشمها در آن خيره مى‌شود.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mdccxciii{شتابان سر برداشته و چشم بر هم نمى‌زنند و [از وحشت‌] دلهايشان تهى است.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mdccxciv{و مردم را از روزى كه عذاب بر آنان مى‌آيد بترسان. پس آنان كه ستم كرده‌اند مى‌گويند: «پروردگارا، ما را تا چندى مهلت بخش تا دعوت تو را پاسخ گوييم و از فرستادگان [تو] پيروى كنيم.» [به آنان گفته مى‌شود:] «مگر شما پيش از اين سوگند نمى‌خورديد كه شما را فنايى نيست؟\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mdccxcv{و در سراهاى كسانى كه بر خود ستم روا داشتند سكونت گزيديد، و براى شما آشكار گرديد كه با آنان چگونه معامله كرديم، و مَثَلها براى شما زديم.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mdccxcvi{و به يقين آنان نيرنگ خود را به كار بردند، و [جزاى‌] مكرشان با خداست، هر چند از مكرشان كوهها از جاى كنده مى‌شد.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mdccxcvii{پس مپندار كه خدا وعده خود را به پيامبرانش خلاف مى‌كند، كه خدا شكست‌ناپذيرِ انتقام‌گيرنده است.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mdccxcviii{روزى كه زمين به غير اين زمين، و آسمانها [به غير اين آسمانها] مبدل گردد، و [مردم‌] در برابر خداى يگانه قهار ظاهر شوند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mdccxcix{و گناهكاران را در آن روز مى‌بينى كه با هم در زنجيرها بسته شده‌اند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mdccc{تن‌پوشهايشان از «قطران» است و چهره‌هايشان را آتش مى‌پوشاند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mdccci{تا خدا به هر كس هر چه به دست آورده است جزا دهد، كه خدا زودشمار است.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mdcccii{اين [قرآن‌] ابلاغى براى مردم است [تا به وسيله آن هدايت شوند] و بدان بيم يابند و بدانند كه او معبودى يگانه است، و تا صاحبان خرد پند گيرند.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mdccciii{\basmalahfa الف، لام، راء. اين است آيات كتاب [آسمانى‌] و قرآن روشنگر.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mdccciv{چه بسا كسانى كه كافر شدند آرزو كنند كه كاش مسلمان بودند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mdcccv{بگذارشان تا بخورند و برخوردار شوند و آرزو[ها] سرگرمشان كند، پس به زودى خواهند دانست.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mdcccvi{و هيچ شهرى را هلاك نكرديم مگر اينكه براى آن اجلى معيّن بود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mdcccvii{هيچ امتى از اجل خويش نه پيش مى‌افتد و نه پس مى‌ماند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mdcccviii{و گفتند: «اى كسى كه قرآن بر او نازل شده است، به يقين تو ديوانه‌اى.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mdcccix{اگر راست مى‌گويى چرا فرشته‌ها را پيش ما نمى‌آورى؟»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mdcccx{فرشتگان را جز به حق فرو نمى‌فرستيم، و در آن هنگام، ديگر مهلت نيابند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mdcccxi{بى‌ترديد، ما اين قرآن را به تدريج نازل كرده‌ايم، و قطعاً نگهبان آن خواهيم بود.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mdcccxii{و به يقين، پيش از تو [نيز] در گروههاى پيشينيان [پيامبرانى‌] فرستاديم.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mdcccxiii{و هيچ پيامبرى برايشان نيامد جز آنكه او را به مسخره مى‌گرفتند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mdcccxiv{بدين گونه آن [استهزا] را در دل بزهكاران راه مى‌دهيم،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mdcccxv{[كه‌] به او ايمان نمى‌آورند، و راه [و رسم‌] پيشينيان پيوسته چنين بوده است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mdcccxvi{و اگر درى از آسمان بر آنان مى‌گشوديم كه همواره از آن بالا مى‌رفتند،\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mdcccxvii{قطعاً مى‌گفتند: «در حقيقت، ما چشم‌بندى شده‌ايم، بلكه ما مردمى هستيم كه افسون شده‌ايم.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mdcccxviii{و به يقين، ما در آسمان بُرجهايى قرار داديم و آن را براى تماشاگران آراستيم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mdcccxix{و آن را از هر شيطان رانده‌شده‌اى حفظ كرديم.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mdcccxx{مگر آن كس كه دزديده گوش فرا دهد كه شهابى روشن او را دنبال مى‌كند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mdcccxxi{و زمين را گسترانيديم و در آن كوههاى استوار افكنديم و از هر چيز سنجيده‌اى در آن رويانيديم.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mdcccxxii{و براى شما و هر كس كه شما روزى‌دهنده او نيستيد، در آن وسايل زندگى قرار داديم.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mdcccxxiii{و هيچ چيز نيست مگر آنكه گنجينه‌هاى آن نزد ماست، و ما آن را جز به اندازه‌اى معين فرو نمى‌فرستيم.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mdcccxxiv{و بادها را بارداركننده فرستاديم و از آسمان، آبى نازل كرديم، پس شما را بدان سيراب نموديم، و شما خزانه‌دار آن نيستيد.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mdcccxxv{و بى‌ترديد، اين ماييم كه زنده مى‌كنيم و مى‌ميرانيم، و ما وارث [همه‌] هستيم.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mdcccxxvi{و به يقين، پيشينيان شما را شناخته‌ايم و آيندگان [شما را نيز] شناخته‌ايم.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mdcccxxvii{و مسلماً پروردگار توست كه آنان را محشور خواهد كرد، چرا كه او حكيم داناست.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mdcccxxviii{و در حقيقت، انسان را از گِلى خشك، از گِلى سياه و بدبو، آفريديم.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mdcccxxix{و پيش از آن، جن را از آتشى سوزان و بى‌دود خلق كرديم.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mdcccxxx{و [ياد كن‌] هنگامى را كه پروردگار تو به فرشتگان گفت: «من بشرى را از گِلى خشك، از گِلى سياه و بدبو، خواهم آفريد.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mdcccxxxi{پس وقتى آن را درست كردم و از روح خود در آن دميدم، پيش او به سجده درافتيد.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mdcccxxxii{پس فرشتگان همگى يكسره سجده كردند،\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mdcccxxxiii{جز ابليس كه خوددارى كرد از اينكه با سجده‌كنندگان باشد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mdcccxxxiv{فرمود: «اى ابليس، تو را چه شده است كه با سجده‌كنندگان نيستى؟»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mdcccxxxv{گفت: «من آن نيستم كه براى بشرى كه او را از گِلى خشك، از گِلى سياه و بدبو، آفريده‌اى، سجده كنم.»\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mdcccxxxvi{فرمود: «از اين [مقام‌] بيرون شو كه تو رانده‌شده‌اى.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mdcccxxxvii{و تا روز جزا بر تو لعنت باشد.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mdcccxxxviii{گفت: «پروردگارا، پس مرا تا روزى كه برانگيخته خواهند شد مهلت ده.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mdcccxxxix{فرمود: «تو از مهلت‌يافتگانى،\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mdcccxl{تا روز [و] وقت معلوم.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mdcccxli{گفت: «پروردگارا، به سبب آنكه مرا گمراه ساختى، من [هم گناهانشان را] در زمين برايشان مى‌آرايم و همه را گمراه خواهم ساخت،\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mdcccxlii{مگر بندگان خالص تو از ميان آنان را.»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mdcccxliii{فرمود: «اين راهى است راست [كه‌] به سوى من [منتهى مى‌شود].\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mdcccxliv{در حقيقت، تو را بر بندگان من تسلّطى نيست، مگر كسانى از گمراهان كه تو را پيروى كنند،\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mdcccxlv{و قطعاً وعده‌گاه همه آنان دوزخ است،\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mdcccxlvi{[دوزخى‌] كه براى آن هفت در است، و از هر درى بخشى معين از آنان [وارد مى‌شوند].\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mdcccxlvii{بى‌گمان، پرهيزگاران در باغها و چشمه‌سارانند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mdcccxlviii{[به آنان گويند:] «با سلامت و ايمنى در آنجا داخل شويد.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mdcccxlix{و آنچه كينه [و شائبه‌هاى نفسانى‌] در سينه‌هاى آنان است بركنيم؛ برادرانه بر تختهايى روبروى يكديگر نشسته‌اند.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mdcccl{نه رنجى در آنجا به آنان مى‌رسد و نه از آنجا بيرون رانده مى‌شوند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mdcccli{به بندگان من خبر ده كه منم آمرزنده مهربان.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mdccclii{و اينكه عذاب من، عذابى است دردناك.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mdcccliii{و از مهمانان ابراهيم به آنان خبر ده،\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mdcccliv{هنگامى كه بر او وارد شدند و سلام گفتند. [ابراهيم‌] گفت: «ما از شما بيمناكيم.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mdccclv{گفتند: «مترس، كه ما تو را به پسرى دانا مژده مى‌دهيم.»\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mdccclvi{گفت: «آيا با اينكه مرا پيرى فرا رسيده است بشارتم مى‌دهيد؟ به چه بشارت مى‌دهيد؟»\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mdccclvii{گفتند: «ما تو را به حق بشارت داديم. پس، از نوميدان مباش.»\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mdccclviii{گفت: «چه كسى -جز گمراهان- از رحمت پروردگارش نوميد مى‌شود؟»\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mdccclix{[سپس‌] گفت: «اى فرشتگان، [ديگر] كارتان چيست؟»\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mdccclx{گفتند: «ما به سوى گروه مجرمان فرستاده شده‌ايم،\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mdccclxi{مگر خانواده لوط، كه ما قطعاً همه آنان را نجات مى‌دهيم،\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mdccclxii{جز آنش را كه مقدر كرديم او از بازماندگان [در عذاب‌] باشد.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mdccclxiii{پس چون فرشتگان نزد خاندان لوط آمدند،\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mdccclxiv{[لوط] گفت: «شما مردمى ناشناس هستيد.»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mdccclxv{گفتند: «[نه،] بلكه براى تو چيزى آورده‌ايم كه در آن ترديد مى‌كردند،\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mdccclxvi{و حق را براى تو آورده‌ايم و قطعاً ما راستگويانيم،\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mdccclxvii{پس، پاسى از شب [گذشته‌] خانواده‌ات را حركت ده و [خودت‌] به دنبال آنان برو، و هيچ يك از شما نبايد به عقب بنگرد، و هر جا به شما دستور داده مى‌شود برويد.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mdccclxviii{و او را از اين امر آگاه كرديم كه ريشه آن گروه صبحگاهان بريده خواهد شد.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mdccclxix{و مردم شهر، شادى‌كنان روى آوردند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mdccclxx{[لوط] گفت: «اينان مهمانان منند، مرا رسوا مكنيد،\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mdccclxxi{و از خدا پروا كنيد و مرا خوار نسازيد.»\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mdccclxxii{گفتند: «آيا تو را [از مهمان كردن‌] مردم بيگانه منع نكرديم؟»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mdccclxxiii{گفت: «اگر مى‌خواهيد [كارى مشروع‌] انجام دهيد، اينان دختران منند [با آنان ازدواج كنيد].»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mdccclxxiv{به جان تو سوگند، كه آنان در مستى خود سرگردان بودند.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mdccclxxv{پس به هنگام طلوع آفتاب، فرياد [مرگبار] آنان را فرو گرفت.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mdccclxxvi{و آن [شهر] را زير و زبر كرديم و بر آنان سنگهايى از سنگ گِل بارانديم.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mdccclxxvii{به يقين، در اين [كيفر] براى هوشياران عبرتهاست.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mdccclxxviii{و [آثار] آن [شهر هنوز] بر سر راهى [داير] برجاست.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mdccclxxix{بى‌گمان، در اين براى مؤمنان عبرتى است.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mdccclxxx{و راستى اهل «ايكه» ستمگر بودند.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mdccclxxxi{پس، از آنان انتقام گرفتيم، و آن دو [شهر، اكنون‌] بر سر راهى آشكاراست.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mdccclxxxii{و اهل «حِجر» [نيز] پيامبران [ما] را تكذيب كردند.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mdccclxxxiii{و آيات خود را به آنان داديم، و[لى‌] از آنها اعراض كردند.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mdccclxxxiv{و [براى خود] از كوهها خانه‌هايى مى‌تراشيدند كه در امان بمانند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mdccclxxxv{پس صبحدم، فرياد [مرگبار]، آنان را فرو گرفت.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mdccclxxxvi{و آنچه به دست مى‌آوردند، به كارشان نخورد.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mdccclxxxvii{و ما آسمانها و زمين و آنچه را كه ميان آن دو است جز به حق نيافريده‌ايم، و يقيناً قيامت فرا خواهد رسيد. پس به خوبى صرف نظر كن،\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mdccclxxxviii{زيرا پروردگار تو همان آفريننده داناست.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mdccclxxxix{و به راستى، به تو سبع المثانى [=سوره فاتحه‌] و قرآن بزرگ را عطا كرديم.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mdcccxc{و به آنچه ما دسته‌هايى از آنان [=كافران‌] را بدان برخوردار ساخته‌ايم چشم مدوز، و بر ايشان اندوه مخور، و بال خويش براى مؤمنان فرو گستر.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mdcccxci{و بگو: «من همان هشداردهنده آشكارم.»\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mdcccxcii{همان گونه كه [عذاب را] بر تقسيم‌كنندگان نازل كرديم:\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mdcccxciii{همانان كه قرآن را جزء جزء كردند [به برخى از آن عمل كردند و بعضى را رها نمودند].\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mdcccxciv{پس سوگند به پروردگارت كه از همه آنان خواهيم پرسيد،\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mdcccxcv{از آنچه انجام مى‌دادند.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mdcccxcvi{پس آنچه را بدان مأمورى آشكار كن و از مشركان روى برتاب،\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mdcccxcvii{كه ما [شر] ريشخندگران را از تو برطرف خواهيم كرد.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mdcccxcviii{همانان كه با خدا معبودى ديگر قرار مى‌دهند. پس به زودى [حقيقت را] خواهند دانست.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mdcccxcix{و قطعاً مى‌دانيم كه سينه تو از آنچه مى‌گويند تنگ مى‌شود.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mcm{پس با ستايش پروردگارت تسبيح گوى و از سجده‌كنندگان باش.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mcmi{و پروردگارت را پرستش كن تا اينكه مرگ تو فرا رسد.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mcmii{\basmalahfa [هان‌] امر خدا دررسيد، پس در آن شتاب مكنيد. او منزّه و فراتر است از آنچه [با وى‌] شريك مى‌سازند.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mcmiii{فرشتگان را با «روح»، به فرمان خود، بر هر كس از بندگانش كه بخواهد نازل مى‌كند، كه بيم دهيد كه معبودى جز من نيست. پس، از من پروا كنيد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mcmiv{آسمانها و زمين را به حق آفريده است. او فراتر است از آنچه [با وى‌] شريك مى‌گردانند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mcmv{انسان را از نطفه‌اى آفريده است، آنگاه ستيزه‌جويى آشكار است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mcmvi{و چارپايان را براى شما آفريد: در آنها براى شما [وسيله‌] گرمى و سودهايى است، و از آنها مى‌خوريد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mcmvii{و در آنها براى شما زيبايى است، آنگاه كه [آنها را] از چراگاه برمى‌گردانيد، و هنگامى كه [آنها را] به چراگاه مى‌بريد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mcmviii{و بارهاى شما را به شهرى مى‌بَرند كه جز با مشقّت بدنها بدان نمى‌توانستيد برسيد. قطعاً پروردگار شما رئوف و مهربان است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mcmix{و اسبان و استران و خران را [آفريد] تا بر آنها سوار شويد و [براى شما] تجملى [باشد]، و آنچه را نمى‌دانيد مى‌آفريند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mcmx{و نمودن راه راست بر عهده خداست، و برخى از آن [راهها] كژ است، و اگر [خدا] مى‌خواست مسلماً همه شما را هدايت مى‌كرد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mcmxi{اوست كسى كه از آسمان، آبى فرود آورد كه [آب‌] آشاميدنى شما از آن است، و روييدنى‌[هايى‌] كه [رمه‌هاى خود را] در آن مى‌چرانيد [نيز] از آن است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mcmxii{به وسيله آن، كشت و زيتون و درختان خرما و انگور و از هر گونه محصولات [ديگر] براى شما مى‌روياند. قطعاً در اينها براى مردمى كه انديشه مى‌كنند نشانه‌اى است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mcmxiii{و شب و روز و خورشيد و ماه را براى شما رام گردانيد، و ستارگان به فرمان او مسخر شده‌اند. مسلماً در اين [امور] براى مردمى كه تعقل مى‌كنند نشانه‌هاست.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mcmxiv{و [همچنين‌] آنچه را در زمين به رنگهاى گوناگون براى شما پديد آورد [مسخّر شما ساخت‌]. بى‌ترديد، در اين [امور] براى مردمى كه پند مى‌گيرند نشانه‌اى است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mcmxv{و اوست كسى كه دريا را مسخر گردانيد تا از آن گوشت تازه بخوريد، و پيرايه‌اى كه آن را مى‌پوشيد از آن بيرون آوريد. و كشتيها را در آن، شكافنده [آب‌] مى‌بينى، و تا از فضل او بجوييد و باشد كه شما شكر گزاريد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mcmxvi{و در زمين كوههايى استوار افكند تا شما را نجنباند، و رودها و راهها [قرار داد] تا شما راه خود را پيدا كنيد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mcmxvii{و نشانه‌هايى [ديگر نيز قرار داد]، و آنان به وسيله ستاره [قطبى‌] راه‌يابى مى‌كنند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mcmxviii{پس آيا كسى كه مى‌آفريند چون كسى است كه نمى‌آفريند؟ آيا پند نمى‌گيريد؟\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mcmxix{و اگر نعمت‌[هاى‌] خدا را شماره كنيد، آن را نمى‌توانيد بشماريد. قطعاً خدا آمرزنده مهربان است.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mcmxx{و خدا آنچه را كه پنهان مى‌داريد و آنچه را كه آشكار مى‌سازيد مى‌داند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mcmxxi{و كسانى را كه جز خدا مى‌خوانند، چيزى نمى‌آفرينند در حالى كه خود آفريده مى شوند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mcmxxii{مردگانند نه زندگان، و نمى‌دانند كِى برانگيخته خواهند شد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mcmxxiii{معبود شما معبودى است يگانه. پس كسانى كه به آخرت ايمان ندارند، دلهايشان انكاركننده [حق‌] است و خودشان متكبرند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mcmxxiv{شك نيست كه خداوند آنچه را پنهان مى‌دارند و آنچه را آشكار مى‌سازند، مى‌داند، و او گردنكشان را دوست نمى‌دارد.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mcmxxv{و چون به آنان گفته شود: «پروردگارتان چه چيز نازل كرده است؟» مى‌گويند: «افسانه‌هاى پيشينيان است.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mcmxxvi{تا روز قيامت بار گناهان خود را تمام بردارند، و [نيز] بخشى از بار گناهان كسانى را كه ندانسته آنان را گمراه مى‌كنند. آگاه باشيد، چه بد بارى را مى‌كشند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mcmxxvii{پيش از آنان كسانى بودند كه مكر كردند، و[لى‌] خدا از پايه بر بنيانشان زد، درنتيجه از بالاى سرشان سقف بر آنان فرو ريخت، و از آنجا كه حدس نمى‌زدند عذاب به سراغشان آمد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mcmxxviii{سپس روز قيامت آنان را رسوا مى‌كند و مى‌گويد: «كجايند آن شريكان من كه در باره آنها [با پيامبران‌] مخالفت مى‌كرديد؟» كسانى كه به آنان علم داده شده است مى‌گويند: «در حقيقت، امروز رسوايى و خوارى بر كافران است.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mcmxxix{همانان كه فرشتگان جانشان را مى‌گيرند در حالى كه بر خود ستمكار بوده‌اند. پس، از درِ تسليم درمى‌آيند [و مى‌گويند:] «ما هيچ كار بدى نمى‌كرديم.» آرى، خدا به آنچه مى‌كرديد داناست.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mcmxxx{پس، از درهاى دوزخ وارد شويد و در آن هميشه بمانيد، و حقا كه چه بد است جايگاه متكبران.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mcmxxxi{و به كسانى كه تقوا پيشه كردند، گفته شود: «پروردگارتان چه نازل كرد؟» مى گويند: «خوبى.» براى كسانى كه در اين دنيا نيكى كردند [پاداش‌] نيكويى است، و قطعاً سراى آخرت بهتر است، و چه نيكوست سراى پرهيزگاران:\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mcmxxxii{بهشتهاى عدن كه در آن داخل مى‌شوند؛ رودها از زير [درختان‌] آنها روان است؛ در آنجا هر چه بخواهند براى آنان [فراهم‌] است. خدا اين گونه پرهيزگاران را پاداش مى‌دهد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mcmxxxiii{همان كسانى كه فرشتگان جانشان را -در حالى كه پاكند- مى‌ستانند [و به آنان‌] مى‌گويند: «درود بر شما باد، به [پاداش‌] آنچه انجام مى‌داديد به بهشت درآييد.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mcmxxxiv{آيا [كافران‌] جز اين كه فرشتگانِ [جان‌ستان‌] به سويشان آيند، يا فرمان پروردگارت [داير بر عذابشان‌] دررسد، انتظارى مى‌برند؟ كسانى كه پيش از آنان بودند [نيز] اين گونه رفتار كردند، و خدا به ايشان ستم نكرد، بلكه آنان به خود ستم مى‌كردند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mcmxxxv{پس [كيفر] بديهايى كه كردند به آنان رسيد، و آنچه مسخره‌اش مى‌كردند آنان را فرا گرفت.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mcmxxxvi{و كسانى كه شرك ورزيدند گفتند: «اگر خدا مى‌خواست -نه ما و نه پدرانمان- هيچ چيزى را غير از او نمى‌پرستيديم و بدون [حكم‌] او چيزى را حرام نمى‌شمرديم.» پيش از آنان [نيز] چنين رفتار كردند، و[لى‌] آيا جز ابلاغ آشكار بر پيامبران [وظيفه‌اى‌] است؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mcmxxxvii{و در حقيقت، در ميان هر امتى فرستاده‌اى برانگيختيم [تا بگويد:] «خدا را بپرستيد و از طاغوت [=فريبگر] بپرهيزيد.» پس، از ايشان كسى است كه خدا [او را] هدايت كرده، و از ايشان كسى است كه گمراهى بر او سزاوار است. بنابراين در زمين بگرديد و ببينيد فرجام تكذيب‌كنندگان چگونه بوده است.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mcmxxxviii{اگر [چه‌] بر هدايت آنان حرص ورزى، ولى خدا كسى را كه فرو گذاشته است هدايت نمى‌كند، و براى ايشان يارى‌كنندگانى نيست.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mcmxxxix{و با سخت‌ترين سوگندهايشان بخدا سوگند ياد كردند كه خدا كسى را كه مى‌ميرد بر نخواهد انگيخت. آرى، [انجام‌] اين وعده بر او حق است، ليكن بيشتر مردم نمى‌دانند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mcmxl{تا [خدا] آنچه را در [مورد] آن اختلاف دارند، براى آنان توضيح دهد، و تا كسانى كه كافر شده‌اند، بدانند كه آنها خود دروغ مى‌گفته‌اند.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mcmxli{ما وقتى چيزى را اراده كنيم، همين قدر به آن مى‌گوييم: «باش»، بى‌درنگ موجود مى‌شود.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mcmxlii{و كسانى كه پس از ستمديدگى، در راه خدا هجرت كرده‌اند، در اين دنيا جاى نيكويى به آنان مى‌دهيم، و اگر بدانند، قطعاً پاداش آخرت بزرگتر خواهد بود.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mcmxliii{همانان كه صبر نمودند و بر پروردگارشان توكل مى‌كنند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mcmxliv{و پيش از تو [هم‌] جز مردانى كه بديشان وحى مى‌كرديم گسيل نداشتيم. پس اگر نمى‌دانيد، از پژوهندگان كتابهاى آسمانى جويا شويد،\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mcmxlv{[زيرا آنان را] با دلايل آشكار و نوشته‌ها [فرستاديم‌]، و اين قرآن را به سوى تو فرود آورديم، تا براى مردم آنچه را به سوى ايشان نازل شده است توضيح دهى، و اميد كه آنان بينديشند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mcmxlvi{آيا كسانى كه تدبيرهاى بد مى‌انديشند، ايمن شدند از اينكه خدا آنان را در زمين فرو ببرد، يا از جايى كه حدس نمى‌زنند عذاب برايشان بيايد؟\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mcmxlvii{يا در حال رفت و آمدشان [گريبان‌] آنان را بگيرد، و كارى از دستشان برنيايد؟\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mcmxlviii{يا آنان را در حالى كه وحشت‌زده‌اند فرو گيرد؟ همانا پروردگار شما رئوف و مهربان است.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mcmxlix{آيا به چيزهايى كه خدا آفريده است، ننگريسته‌اند كه [چگونه‌] سايه‌هايشان از راست و [از جوانب‌] چپ مى‌گردد، و براى خدا در حال فروتنى سر بر خاك مى‌سايند؟\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mcml{و آنچه در آسمانها و آنچه در زمين از جنبندگان و فرشتگان است، براى خدا سجده مى‌كنند و تكبر نمى‌ورزند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mcmli{از پروردگارشان كه حاكم بر آنهاست مى‌ترسند و آنچه را مأمورند انجام مى‌دهند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mcmlii{و خدا فرمود: «دو معبود براى خود مگيريد. جز اين نيست كه او خدايى يگانه است. پس تنها از من بترسيد.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mcmliii{و آنچه در آسمانها و زمين است از آنِ اوست، و آيين پايدار [نيز] از آنِ اوست. پس آيا از غير خدا پروا داريد؟\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mcmliv{و هر نعمتى كه داريد از خداست، سپس چون آسيبى به شما رسد به سوى او روى مى آوريد [و مى‌ناليد].\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mcmlv{و چون آن آسيب را از شما برطرف كرد، آنگاه گروهى از شما به پروردگارشان شرك مى‌ورزند.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mcmlvi{[بگذار] تا آنچه را به ايشان عطا كرده‌ايم ناسپاسى كنند. اكنون برخوردار شويد، و[لى‌] زودا كه بدانيد.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mcmlvii{و از آنچه به ايشان روزى داديم، نصيبى براى آن [خدايانى‌] كه نمى‌دانند [چيست‌] مى‌نهند. به خدا سوگند كه از آنچه به دروغ برمى‌بافتيد، حتماً سؤال خواهيد شد.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mcmlviii{و براى خدا دخترانى مى‌پندارند. منزه است او. و براى خودشان آنچه را ميل دارند [قرار مى‌دهند].\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mcmlix{و هر گاه يكى از آنان را به دختر مژده آورند، چهره‌اش سياه مى‌گردد، در حالى كه خشم [و اندوه‌] خود را فرو مى‌خورد.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mcmlx{از بدى آنچه بدو بشارت داده شده، از قبيله [خود] روى مى‌پوشاند. آيا او را با خوارى نگاه دارد، يا در خاك پنهانش كند؟ وه چه بد داورى مى‌كنند.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mcmlxi{وصف زشت براى كسانى است كه به آخرت ايمان ندارند، و بهترين وصف از آنِ خداست، و اوست ارجمند حكيم.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mcmlxii{و اگر خداوند مردم را به [سزاى‌] ستمشان مؤاخذه مى‌كرد، جنبنده‌اى بر روى زمين باقى نمى‌گذاشت، ليكن [كيفر] آنان را تا وقتى معين بازپس مى‌اندازد، و چون اجلشان فرا رسد، ساعتى آن را پس و پيش نمى‌توانند افكنند.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mcmlxiii{و چيزى را كه خوش نمى‌دارند، براى خدا قرار مى‌دهند، و زبانشان دروغ‌پردازى مى‌كند كه [سرانجام‌] نيكو از آنِ ايشان است. حقاً كه آتش براى آنان است و به سوى آن پيش فرستاده خواهند شد.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mcmlxiv{سوگند به خدا كه به سوى امتهاى پيش از تو [رسولانى‌] فرستاديم [اما] شيطان اعمالشان را برايشان آراست و امروز [هم‌] سرپرستشان هموست و برايشان عذابى دردناك است.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mcmlxv{و ما [اين‌] كتاب را بر تو نازل نكرديم، مگر براى اينكه آنچه را در آن اختلاف كرده‌اند، براى آنان توضيح دهى، و [آن‌] براى مردمى كه ايمان مى‌آورند، رهنمود و رحمتى است.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mcmlxvi{و خدا از آسمان آبى فرود آورد و با آن زمين را پس از پژمردنش زنده گردانيد، قطعاً در اين [امر] براى مردمى كه شنوايى دارند نشانه‌اى است.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mcmlxvii{و در دامها قطعاً براى شما عبرتى است: از آنچه در [لابلاى‌] شكم آنهاست، از ميان سرگين و خون، شيرى ناب به شما مى‌نوشانيم كه براى نوشندگان گواراست.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mcmlxviii{و از ميوه درختان خرما و انگور، باده مستى‌بخش و خوراكى نيكو براى خود مى گيريد. قطعاً در اين‌[ها] براى مردمى كه تعقل مى‌كنند نشانه‌اى است.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mcmlxix{و پروردگار تو به زنبور عسل وحى [=الهام غريزى‌] كرد كه از پاره‌اى كوهها و از برخى درختان و از آنچه داربست [و چفته‌سازى‌] مى‌كنند، خانه‌هايى براى خود درست كن،\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mcmlxx{سپس از همه ميوه‌ها بخور، و راههاى پروردگارت را فرمانبردارانه، بپوى. [آنگاه‌] از درون [شكم‌] آن، شهدى كه به رنگهاى گوناگون است بيرون مى‌آيد. در آن، براى مردم درمانى است. راستى در اين [زندگى زنبوران‌] براى مردمى كه تفكر مى‌كنند نشانه [قدرت الهى‌] است.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mcmlxxi{و خدا شما را آفريد، سپس [جان‌] شما را مى‌گيرد، و بعضى از شما تا خوارترين [دوره‌] سالهاى زندگى [فرتوتى‌] بازگردانده مى‌شود، به طورى كه بعد از [آن همه‌] دانستن، [ديگر] چيزى نمى‌دانند. قطعاً خدا داناى تواناست.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mcmlxxii{و خدا بعضى از شما را در روزى بر بعضى ديگر برترى داده است. و[لى‌] كسانى كه فزونى يافته‌اند، روزىِ خود را به بندگان خود نمى‌دهند تا در آن با هم مساوى باشند. آيا باز نعمت خدا را انكار مى‌كنند؟\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mcmlxxiii{و خدا براى شما از خودتان همسرانى قرار داد، و از همسرانتان براى شما پسران و نوادگانى نهاد و از چيزهاى پاكيزه به شما روزى بخشيد. آيا [باز هم‌] به باطل ايمان مى‌آورند و به نعمت خدا كفر مى‌ورزند؟\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mcmlxxiv{و به جاى خدا چيزهايى را مى‌پرستند كه در آسمانها و زمين به هيچ وجه اختيار روزى آنان را ندارند و [به كارى‌] توانايى ندارند.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mcmlxxv{پس براى خدا مَثَل نزنيد، كه خدا مى‌داند و شما نمى‌دانيد.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mcmlxxvi{خدا مَثَلى مى‌زند: بنده‌اى است زرخريد كه هيچ كارى از او برنمى‌آيد. آيا [او] با كسى كه به وى از جانب خود روزى نيكو داده‌ايم، و او از آن در نهان و آشكار انفاق مى‌كند يكسان است؟ سپاس خداى راست. [نه،] بلكه بيشترشان نمى‌دانند.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mcmlxxvii{و خدا مَثَلى [ديگر] مى‌زند: دو مردند كه يكى از آنها لال است و هيچ كارى از او برنمى‌آيد و او سربار خداوندگارش مى‌باشد. هر جا كه او را مى‌فرستد خيرى به همراه نمى‌آورد. آيا او با كسى كه به عدالت فرمان مى‌دهد و خود بر راه راست است يكسان است؟\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mcmlxxviii{و نهان آسمانها و زمين از آنِ خداست، و كار قيامت جز مانند يك چشم بر هم زدن يا نزديكتر [از آن‌] نيست، زيرا خدا بر هر چيزى تواناست.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mcmlxxix{و خدا شما را از شكم مادرانتان -در حالى كه چيزى نمى‌دانستيد- بيرون آورد، و براى شما گوش و چشمها و دلها قرار داد، باشد كه سپاسگزارى كنيد.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mcmlxxx{آيا به سوى پرندگانى كه در فضاى آسمان، رام شده‌اند ننگريسته‌اند؟ جز خدا كسى آنها را نگاه نمى‌دارد. راستى در اين [قدرت‌نمايى‌] براى مردمى كه ايمان مى‌آورند نشانه‌هايى است.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mcmlxxxi{و خدا براى شما خانه‌هايتان را مايه آرامش قرار داد، و از پوست دامها براى شما خانه‌هايى نهاد كه آن‌[ها] را در روز جابجا شدنتان و هنگام ماندنتان سبك مى‌يابيد، و از پشمها و كُركها و موهاى آنها وسايل زندگى كه تا چندى مورد استفاده است [قرار داد].\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mcmlxxxii{و خدا از آنچه آفريده، به سود شما سايه‌هايى فراهم آورده و از كوهها براى شما پناهگاه‌هايى قرار داده و براى شما تن‌پوشهايى مقرّر كرده كه شما را از گرما [و سرما] حفظ مى‌كند، و تن‌پوشها [=زره‌ها]يى كه شما را در جنگتان حمايت مى‌نمايد. اين گونه وى نعمتش را بر شما تمام مى‌گرداند، اميد كه شما [به فرمانش‌] گردن نهيد.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mcmlxxxiii{پس اگر رويگردان شوند، بر تو فقط ابلاغ آشكار است.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mcmlxxxiv{نعمت خدا را مى‌شناسند، اما باز هم منكر آن مى‌شوند و بيشترشان كافرند.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mcmlxxxv{و [ياد كن‌] روزى را كه از هر امّتى گواهى برمى‌انگيزيم، سپس به كسانى كه كافر شده‌اند رخصت داده نمى‌شود و آنان مورد بخشش قرار نخواهند گرفت.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mcmlxxxvi{و چون كسانى كه ستم كرده‌اند عذاب را ببينند [شكنجه‌] آنان كاسته نمى‌گردد و مهلت نمى‌يابند.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mcmlxxxvii{و چون كسانى كه شرك ورزيدند، شريكان خود را ببينند مى‌گويند: «پروردگارا، اينها بودند آن شريكانى كه ما به جاى تو مى‌خوانديم». و[لى شريكان‌] قول آنان را رد مى‌كنند كه: «شما جدا دروغگويانيد.»\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mcmlxxxviii{و آن روز در برابر خدا از در تسليم درآيند و آنچه را كه برمى‌بافتند بر باد مى‌رود.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mcmlxxxix{كسانى كه كفر ورزيدند و از راه خدا باز داشتند به [سزاى‌] آنكه فساد مى‌كردند عذابى بر عذابشان مى‌افزاييم.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mcmxc{و [به ياد آور] روزى را كه در هر امتى گواهى از خودشان برايشان برانگيزيم، و تو را [هم‌] بر اين [امت‌] گواه آوريم، و اين كتاب را كه روشنگر هر چيزى است و براى مسلمانان رهنمود و رحمت و بشارتگرى است، بر تو نازل كرديم.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mcmxci{در حقيقت، خدا به دادگرى و نيكوكارى و بخشش به خويشاوندان فرمان مى‌دهد و از كار زشت و ناپسند و ستم باز مى‌دارد. به شما اندرز مى‌دهد، باشد كه پند گيريد.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mcmxcii{و چون با خدا پيمان بستيد، به پيمان خود وفا كنيد و سوگندهاى [خود را] پس از استوار كردن آنها مشكنيد، با اينكه خدا را بر خود ضامن [و گواه‌] قرار داده‌ايد، زيرا خدا آنچه را انجام مى‌دهيد مى‌داند.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mcmxciii{و مانند آن [زنى‌] كه رشته خود را پس از محكم بافتن، [يكى يكى‌] از هم مى‌گسست مباشيد كه سوگندهاى خود را ميان خويش وسيله [فريب و] تقلّب سازيد [به خيال اين‌] كه گروهى از گروه ديگر [در داشتن امكانات‌] افزونترند. جز اين نيست كه خدا شما را بدين وسيله مى‌آزمايد و روز قيامت در آنچه اختلاف مى‌كرديد، قطعاً براى شما توضيح خواهد داد.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mcmxciv{و اگر خدا مى‌خواست قطعاً شما را امتى واحد قرار مى‌داد، ولى هر كه را بخواهد بيراه و هر كه را بخواهد هدايت مى‌كند و از آنچه انجام مى‌داديد حتماً سؤال خواهيد شد.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mcmxcv{و زنهار، سوگندهاى خود را دستاويز تقلّب ميان خود قرار مدهيد، تا گامى بعد از استواريش بلغزد، و شما به [سزاى‌] آنكه [مردم را] از راه خدا باز داشته‌ايد دچار شكنجه شويد و براى شما عذابى بزرگ باشد.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mcmxcvi{و پيمان خدا را به بهاى ناچيزى مفروشيد، زيرا آنچه نزد خداست -اگر بدانيد- همان براى شما بهتر است.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mcmxcvii{آنچه پيش شماست تمام مى‌شود و آنچه پيش خداست پايدار است، و قطعاً كسانى را كه شكيبايى كردند به بهتر از آنچه عمل مى‌كردند، پاداش خواهيم داد.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mcmxcviii{هر كس -از مرد يا زن- كار شايسته كند و مؤمن باشد، قطعاً او را با زندگى پاكيزه‌اى، حيات [حقيقى‌] بخشيم، و مسلماً به آنان بهتر از آنچه انجام مى‌دادند پاداش خواهيم داد.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mcmxcix{پس چون قرآن مى‌خوانى از شيطان مطرود به خدا پناه بر،\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mm{چرا كه او را بر كسانى كه ايمان آورده‌اند، و بر پروردگارشان توكل مى‌كنند، تسلّطى نيست.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mmi{تسلّط او فقط بر كسانى است كه وى را به سرپرستى برمى‌گيرند، و بر كسانى كه آنها به او [=خدا] شرك مى‌ورزند.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mmii{و چون حكمى را به جاى حكم ديگر بياوريم -و خدا به آنچه به تدريج نازل مى‌كند داناتر است- مى‌گويند: «جز اين نيست كه تو دروغ‌بافى.» [نه،] بلكه بيشتر آنان نمى‌دانند.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mmiii{بگو: «آن را روح القدس از طرف پروردگارت به حق فرود آورده، تا كسانى را كه ايمان آورده‌اند استوار گرداند، و براى مسلمانان هدايت و بشارتى است. «\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mmiv{و نيك مى‌دانيم كه آنان مى‌گويند: «جز اين نيست كه بشرى به او مى‌آموزد.» [نه چنين نيست، زيرا] زبان كسى كه [اين‌] نسبت را به او مى‌دهند غير عربى است و اين [قرآن‌] به زبان عربى روشن است.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mmv{در حقيقت، كسانى كه به آيات خدا ايمان ندارند، خدا آنان را هدايت نمى‌كند و برايشان عذابى دردناك است.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mmvi{تنها كسانى دروغ‌پردازى مى‌كنند كه به آيات خدا ايمان ندارند و آنان خود دروغگويانند.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mmvii{هر كس پس از ايمان آوردن خود، به خدا كفر ورزد [عذابى سخت خواهد داشت‌] مگر آن كس كه مجبور شده و[لى‌] قلبش به ايمان اطمينان دارد. ليكن هر كه سينه‌اش به كفر گشاده گردد خشم خدا بر آنان است و برايشان عذابى بزرگ خواهد بود،\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mmviii{زيرا آنان زندگى دنيا را بر آخرت برترى دادند و [هم‌] اينكه خدا گروه كافران را هدايت نمى‌كند.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mmix{آنان كسانى‌اند كه خدا بر دلها و گوش و ديدگانشان مُهر نهاده و آنان خود غافلانند.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mmx{شك نيست كه آنها در آخرت همان زيانكارانند.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mmxi{با اين حال، پروردگار تو نسبت به كسانى كه پس از [آن همه‌] زجر كشيدن، هجرت كرده و سپس جهاد نمودند و صبر پيشه ساختند، پروردگارت [نسبت به آنان‌] بعد از آن [همه مصايب‌] قطعاً آمرزنده و مهربان است.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mmxii{[ياد كن‌] روزى را كه هر كس مى‌آيد [و] از خود دفاع مى‌كند، و هر كس به آنچه كرده، بى كم و كاست پاداش مى‌يابد و بر آنان ستم نمى‌رود.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mmxiii{و خدا شهرى را مَثَل زده است كه امن و امان بود [و] روزيش از هر سو فراوان مى‌رسيد، پس [ساكنانش‌] نعمتهاى خدا را ناسپاسى كردند، و خدا هم به سزاى آنچه انجام مى‌دادند، طعم گرسنگى و هراس را به [مردم‌] آن چشانيد.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mmxiv{و به يقين، فرستاده‌اى از خودشان برايشان آمد، اما او را تكذيب كردند، پس در حالى كه ظالم بودند آنان را عذاب فرو گرفت.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@mmxv{پس، از آنچه خدا شما را روزى كرده است، حلال [و] پاكيزه بخوريد، و نعمت خدا را -اگر تنها او را مى‌پرستيد- شكر گزاريد.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@mmxvi{جز اين نيست كه [خدا] مردار و خون و گوشت خوك و آنچه را كه نام غير خدا بر آن برده شده حرام گردانيده است. [با اين همه،] هر كس كه [به خوردن آنها] ناگزير شود، و سركش و زياده‌خواه نباشد، قطعاً خدا آمرزنده مهربان است.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@mmxvii{و براى آنچه زبان شما به دروغ مى‌پردازد، مگوييد: «اين حلال است و آن حرام » تا بر خدا دروغ بنديد، زيرا كسانى كه بر خدا دروغ مى‌بندند رستگار نمى‌شوند.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@mmxviii{[ايشان راست‌] اندك بهره‌اى، و[لى‌] عذابشان پر درد است.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@mmxix{و بر كسانى كه يهودى شدند، آنچه را قبلا بر تو حكايت كرديم، حرام گردانيديم، و ما بر آنان ستم نكرديم، بلكه آنها به خود ستم مى‌كردند.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@mmxx{[با اين همه‌] پروردگار تو نسبت به كسانى كه به نادانى مرتكب گناه شده، سپس توبه كرده و به صلاح آمده‌اند، البته پروردگارت پس از آن آمرزنده مهربان است.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@mmxxi{به راستى ابراهيم، پيشوايى مطيع خدا [و] حق‌گراى بود و از مشركان نبود.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@mmxxii{[و] نعمتهاى او را شكرگزار بود. [خدا] او را برگزيد و به راهى راست هدايتش كرد.\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@mmxxiii{و در دنيا به او نيكويى و [نعمت‌] داديم و در آخرت [نيز] از شايستگان خواهد بود.\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@mmxxiv{سپس به تو وحى كرديم كه: «از آيين ابراهيم حق‌گراى پيروى كن، [چرا كه‌] او از مشركان نبود.»\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@mmxxv{[بزرگداشت‌] شنبه، بر كسانى كه در باره آن اختلاف كردند مقرّر گرديد، و قطعاً پروردگارت روز رستاخيز ميان آنها در باره چيزى كه در مورد آن اختلاف مى‌كردند، داورى خواهد كرد.\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@mmxxvi{با حكمت و اندرز نيكو به راه پروردگارت دعوت كن و با آنان به [شيوه‌اى‌] كه نيكوتر است مجادله نماى. در حقيقت، پروردگار تو به [حال‌] كسى كه از راه او منحرف شده داناتر، و او به [حال‌] راه‌يافتگان [نيز ]داناتر است.\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@mmxxvii{و اگر عقوبت كرديد، همان گونه كه مورد عقوبت قرار گرفته‌ايد [متجاوز را ] به عقوبت رسانيد، و اگر صبر كنيد البته آن براى شكيبايان بهتر است.\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@mmxxviii{و صبر كن و صبر تو جز به [توفيق‌] خدا نيست و بر آنان اندوه مخور و از آنچه نيرنگ مى‌كنند دل تنگ مدار.\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@mmxxix{در حقيقت، خدا با كسانى است كه پروا داشته‌اند و [با] كسانى [است‌] كه آنها نيكوكارند.\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@mmxxx{\basmalahfa منزّه است آن [خدايى‌] كه بنده‌اش را شبانگاهى از مسجد الحرام به سوى مسجد الاقصى -كه پيرامون آن را بركت داده‌ايم- سير داد، تا از نشانه‌هاى خود به او بنمايانيم، كه او همان شنواى بيناست.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmxxxi{و كتاب آسمانى را به موسى داديم و آن را براى فرزندان اسرائيل رهنمودى گردانيديم كه: زنهار، غير از من كارسازى مگيريد،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmxxxii{[اى‌] فرزندان كسانى كه [آنان را در كِشتى‌] با نوح برداشتيم. راستى كه او بنده‌اى سپاسگزار بود.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmxxxiii{و در كتاب آسمانى‌[شان‌] به فرزندان اسرائيل خبر داديم كه: «قطعاً دو بار در زمين فساد خواهيد كرد، و قطعاً به سركشىِ بسيار بزرگى برخواهيد خاست. »\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmxxxiv{پس آنگاه كه وعده [تحقّق‌] نخستين آن دو فرا رسد، بندگانى از خود را كه سخت نيرومندند بر شما مى‌گماريم، تا ميان خانه‌ها[يتان براى قتل و غارت شما] به جستجو درآيند، و اين تهديد تحقّق‌يافتنى است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmxxxv{پس [از چندى‌] دوباره شما را بر آنان چيره مى‌كنيم و شما را با اموال و پسران يارى مى‌دهيم و [تعداد] نفرات شما را بيشتر مى‌گردانيم.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmxxxvi{اگر نيكى كنيد، به خود نيكى كرده‌ايد، و اگر بدى كنيد، به خود [بد نموده‌ايد]. و چون تهديد آخر فرا رسد [بيايند] تا شما را اندوهگين كنند و در معبد[تان‌] چنانكه بار اول داخل شدند [به زور] درآيند و بر هر چه دست يافتند يكسره [آن را] نابود كنند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmxxxvii{اميد است كه پروردگارتان شما را رحمت كند، و[لى‌] اگر [به گناه‌] بازگرديد [ما نيز به كيفر شما] بازمى‌گرديم، و دوزخ را براى كافران زندان قرار داديم.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmxxxviii{قطعاً اين قرآن به [آيينى‌] كه خود پايدارتر است راه مى‌نمايد، و به آن مؤمنانى كه كارهاى شايسته مى‌كنند، مژده مى‌دهد كه پاداشى بزرگ برايشان خواهد بود.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmxxxix{و اينكه براى كسانى كه به آخرت ايمان نمى‌آورند عذابى پر درد آماده كرده‌ايم.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmxl{و انسان [همان گونه كه‌] خير را فرا مى‌خواند، [پيشامد] بد را مى‌خواند و انسان همواره شتابزده است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmxli{و شب و روز را دو نشانه قرار داديم. نشانه شب را تيره‌گون و نشانه روز را روشنى‌بخش گردانيديم تا [در آن،] فضلى از پروردگارتان بجوييد، و تا شماره سالها و حساب [عمرها و رويدادها] را بدانيد و هر چيزى را به روشنى باز نموديم.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmxlii{و كارنامه هر انسانى را به گردن او بسته‌ايم، و روز قيامت براى او نامه‌اى كه آن را گشاده مى‌بيند بيرون مى‌آوريم.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmxliii{«نامه‌ات را بخوان؛ كافى است كه امروز خودت حسابرس خود باشى.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmxliv{هر كس به راه آمده تنها به سود خود به راه آمده، و هر كس بيراهه رفته تنها به زيان خود بيراهه رفته است. و هيچ بردارنده‌اى بار گناه ديگرى را بر نمى‌دارد، و ما تا پيامبرى برنينگيزيم، به عذاب نمى‌پردازيم.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmxlv{و چون بخواهيم شهرى را هلاك كنيم، خوشگذرانانش را وا مى‌داريم تا در آن به انحراف [و فساد] بپردازند، و در نتيجه عذاب بر آن [شهر] لازم گردد، پس آن را [يكسره‌] زير و زبر كنيم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmxlvi{و چه بسيار نسلها را كه ما پس از نوح به هلاكت رسانديم، و پروردگار تو به گناهان بندگانش بس آگاه و بيناست.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmxlvii{هر كس خواهان [دنياى‌] زودگذر است، به زودى هر كه را خواهيم [نصيبى‌] از آن مى‌دهيم، آنگاه جهنم را كه در آن خوار و رانده داخل خواهد شد، براى او مقرر مى‌داريم.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmxlviii{و هر كس خواهان آخرت است و نهايت كوشش را براى آن بكند و مؤمن باشد، آنانند كه تلاش آنها مورد حق‌شناسى واقع خواهد شد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmxlix{هر دو [دسته:] اينان و آنان را از عطاى پروردگارت مدد مى‌بخشيم، و عطاى پروردگارت [از كسى‌] منع نشده است.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mml{ببين چگونه بعضى از آنان را بر بعضى ديگر برترى داده‌ايم، و قطعاً درجات آخرت و برترى آن بزرگتر و بيشتر است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmli{معبود ديگرى با خدا قرار مده تا نكوهيده و وامانده بنشينى.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmlii{و پروردگار تو مقرر كرد كه جز او را مپرستيد و به پدر و مادر [خود] احسان كنيد. اگر يكى از آن دو يا هر دو، در كنار تو به سالخوردگى رسيدند به آنها [حتى‌] «اوف» مگو و به آنان پَرخاش مكن و با آنها سخنى شايسته بگوى.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmliii{و از سر مهربانى، بالِ فروتنى بر آنان بگستر و بگو: «پروردگارا، آن دو را رحمت كن چنانكه مرا در خردى پروردند.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmliv{پروردگار شما به آنچه در دلهاى خود داريد آگاه‌تر است. اگر شايسته باشيد، قطعاً او آمرزنده توبه‌كنندگان است.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmlv{و حق خويشاوند را به او بده و مستمند و در راه‌مانده را [دستگيرى كن‌] و ولخرجى و اسراف مكن.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmlvi{چرا كه اسرافكاران برادران شيطانهايند، و شيطان همواره نسبت به پروردگارش ناسپاس بوده است.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmlvii{و اگر به اميد رحمتى كه از پروردگارت جوياى آنى، از ايشان روى مى‌گردانى، پس با آنان سخنى نرم بگوى.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmlviii{و دستت را به گردنت زنجير مكن و بسيار [هم‌] گشاده‌دستى منما تا ملامت‌شده و حسرت‌زده بر جاى مانى.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmlix{بى‌گمان، پروردگار تو براى هر كه بخواهد، روزى را گشاده يا تنگ مى‌گرداند. در حقيقت، او به [حال‌] بندگانش آگاه بيناست.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmlx{و از بيم تنگدستى فرزندان خود را مكشيد. ماييم كه به آنها و شما روزى مى‌بخشيم. آرى، كشتن آنان همواره خطايى بزرگ است.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmlxi{و به زنا نزديك مشويد، چرا كه آن همواره زشت و بد راهى است.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmlxii{و نفسى را كه خداوند حرام كرده است جز به حق مكشيد، و هر كس مظلوم كشته شود، به سرپرست وى قدرتى داده‌ايم، پس [او] نبايد در قتل زياده‌روى كند، زيرا او [از طرف شرع‌] يارى شده است.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmlxiii{و به مال يتيم -جز به بهترين وجه- نزديك مشويد تا به رشد برسد، و به پيمان [خود] وفا كنيد، زيرا كه از پيمان پرسش خواهد شد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmlxiv{و چون پيمانه مى‌كنيد، پيمانه را تمام دهيد، و با ترازوى درست بسنجيد كه اين بهتر و خوش فرجام‌تر است.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmlxv{و چيزى را كه بدان علم ندارى دنبال مكن، زيرا گوش و چشم و قلب، همه مورد پرسش واقع خواهند شد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmlxvi{و در [روى‌] زمين به نخوت گام برمدار، چرا كه هرگز زمين را نمى‌توانى شكافت، و در بلندى به كوهها نمى‌توانى رسيد.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmlxvii{همه اين [كارها] بدش نزد پروردگار تو ناپسنديده است.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmlxviii{اين [سفارشها] از حكمتهايى است كه پروردگارت به تو وحى كرده است، و با خداى يگانه معبودى ديگر قرار مده، و گرنه حسرت‌زده و مطرود در جهنم افكنده خواهى شد.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmlxix{آيا [پنداشتيد كه‌] پروردگارتان شما را به [داشتن‌] پسران اختصاص داده، و خود از فرشتگان دخترانى برگرفته است؟ حقاً كه شما سخنى بس بزرگ مى‌گوييد.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmlxx{و به راستى، ما در اين قرآن [حقايق را] گونه‌گون بيان كرديم، تا پند گيرند؛ و[لى‌] آنان را جز نفرت نمى‌افزايد.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmlxxi{بگو: «اگر - چنانكه مى‌گويند- با او خدايانى [ديگر] بود، در آن صورت حتماً در صدد جستن راهى به سوى [خداوند،] صاحب عرش، برمى‌آمدند.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmlxxii{او [پاك و] منزّه است و از آنچه مى‌گويند بسى والاتر است.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmlxxiii{آسمانهاى هفتگانه و زمين و هر كس كه در آنهاست او را تسبيح مى‌گويند، و هيچ چيز نيست مگر اينكه در حال ستايش، تسبيح او مى‌گويد، ولى شما تسبيح آنها را درنمى‌يابيد. به راستى كه او همواره بردبار [و ]آمرزنده است.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmlxxiv{و چون قرآن بخوانى، ميان تو و كسانى كه به آخرت ايمان ندارند پرده‌اى پوشيده قرار مى‌دهيم.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmlxxv{و بر دلهايشان پوششها مى‌نهيم تا آن را نفهمند و در گوشهايشان سنگينى [قرار مى‌دهيم‌] و چون در قرآن پروردگار خود را به يگانگى ياد كنى با نفرت پشت مى‌كنند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmlxxvi{هنگامى كه به سوى تو گوش فرا مى‌دارند ما بهتر مى‌دانيم به چه [منظور] گوش مى‌دهند، و [نيز] آنگاه كه به نجوا مى‌پردازند؛ وقتى كه ستمگران گويند: «جز مردى افسون‌شده را پيروى نمى‌كنيد.»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmlxxvii{ببين چگونه براى تو مَثَلها زدند و گمراه شدند، در نتيجه راه به جايى نمى‌توانند ببرند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmlxxviii{و گفتند: «آيا وقتى استخوان و خاك شديم [باز] به آفرينشى جديد برانگيخته مى‌شويم؟»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmlxxix{بگو: «سنگ باشيد يا آهن،\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmlxxx{يا آفريده‌اى از آنچه در خاطر شما بزرگ مى‌نمايد [باز هم برانگيخته خواهيد شد].» پس خواهند گفت: «چه كسى ما را بازمى‌گرداند؟» بگو: «همان كس كه نخستين بار شما را پديد آورد.» [باز] سرهاى خود را به طرف تو تكان مى‌دهند و مى‌گويند: «آن كى خواهد بود؟» بگو: «شايد كه نزديك باشد.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmlxxxi{روزى كه شما را فرا مى‌خواند، پس در حالى كه او را ستايش مى‌كنيد اجابتش مى‌نماييد و مى‌پنداريد كه جز اندكى [در دنيا] نمانده‌ايد.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmlxxxii{و به بندگانم بگو: «آنچه را كه بهتر است بگويند»، كه شيطان ميانشان را به هم مى‌زند، زيرا شيطان همواره براى انسان دشمنى آشكار است.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmlxxxiii{پروردگار شما به [حال‌] شما داناتر است؛ اگر بخواهد بر شما رحمت مى‌آورد، يا اگر بخواهد شما را عذاب مى‌كند، و تو را بر ايشان نگهبان نفرستاده‌ايم.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmlxxxiv{و پروردگار تو به هر كه [و هر چه‌] در آسمانها و زمين است داناتر است. و در حقيقت، بعضى از انبيا را بر بعضى برترى بخشيديم و به داوود زبور داديم.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmlxxxv{بگو: «كسانى را كه به جاى او [معبود خود] پنداشتيد، بخوانيد. [آنها] نه اختيارى دارند كه از شما دفع زيان كنند و نه [آنكه بلايى را از شما] بگردانند.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmlxxxvi{آن كسانى را كه ايشان مى‌خوانند [خود] به سوى پروردگارشان تقرب مى‌جويند [تا بدانند] كدام يك از آنها [به او] نزديكترند، و به رحمت وى اميدوارند، و از عذابش مى‌ترسند، چرا كه عذاب پروردگارت همواره در خور پرهيز است.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmlxxxvii{و هيچ شهرى نيست مگر اينكه ما آن را [در صورت نافرمانى،] پيش از روز رستاخيز، به هلاكت مى‌رسانيم يا آن را سخت عذاب مى‌كنيم. اين [عقوبت‌] در كتاب [الهى‌] به قلم رفته است.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmlxxxviii{و [چيزى‌] ما را از فرستادن معجزات باز نداشت جز اينكه پيشينيان، آنها را به دروغ گرفتند، و به ثمود ماده‌شتر داديم كه [پديده‌اى‌] روشنگر بود، و[لى‌] به آن ستم كردند، و ما معجزه‌ها را جز براى بيم‌دادن [مردم‌] نمى‌فرستيم.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmlxxxix{و [ياد كن‌] هنگامى را كه به تو گفتيم: «به راستى پروردگارت بر مردم احاطه دارد.» و آن رؤيايى را كه به تو نمايانديم، و [نيز] آن درخت لعنت شده در قرآن را جز براى آزمايش مردم قرار نداديم؛ و ما آنان را بيم مى‌دهيم، ولى جز بر طغيان بيشتر آنها نمى‌افزايد.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmxc{و هنگامى را كه به فرشتگان گفتيم: «براى آدم سجده كنيد» پس [همه‌] جز ابليس سجده كردند. گفت: «آيا براى كسى كه از گل آفريدى سجده كنم؟»\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmxci{[سپس‌] گفت: «به من بگو: اين كسى را كه بر من برترى دادى [براى چه بود]؟ اگر تا روز قيامت مهلتم دهى قطعاً فرزندانش را -جز اندكى [از آنها]- ريشه‌كن خواهم كرد.»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmxcii{فرمود: «برو كه هر كس از آنان تو را پيروى كند مسلماً جهنم سزايتان خواهد بود كه كيفرى تمام است.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmxciii{و از ايشان هر كه را توانستى با آواى خود تحريك كن و با سواران و پيادگانت بر آنها بتاز و با آنان در اموال و اولاد شركت كن و به ايشان وعده بده»، و شيطان جز فريب به آنها وعده نمى‌دهد.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmxciv{«در حقيقت، تو را بر بندگان من تسلطى نيست، و حمايتگرى [چون‌] پروردگارت بس است.»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmxcv{پروردگار شما كسى است كه كشتى را در دريا براى شما به حركت در مى‌آورد، تا از فضل او براى خود بجوييد، چرا كه او همواره به شما مهربان است.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmxcvi{و چون در دريا به شما صدمه‌اى برسد، هر كه را جز او مى‌خوانيد ناپديد [و فراموش‌] مى‌گردد، و چون [خدا] شما را به سوى خشكى رهانيد، رويگردان مى‌شويد، و انسان همواره ناسپاس است.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmxcvii{مگر ايمن شديد از اينكه شما را در كنار خشكى در زمين فرو برد يا بر شما طوفانى از سنگريزه‌ها بفرستد، سپس براى خود نگاهبانى نيابيد.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmxcviii{يا [مگر] ايمن شديد از اينكه بار ديگر شما را در آن [دريا] باز گرداند و تندبادى شكننده بر شما بفرستد و به سزاى آنكه كفر ورزيديد غرقتان كند؛ آنگاه براى خود در برابر ما كسى را نيابيد كه آن را دنبال كند؟\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmxcix{و به راستى ما فرزندان آدم را گرامى داشتيم، و آنان را در خشكى و دريا [بر مركبها] برنشانديم، و از چيزهاى پاكيزه به ايشان روزى داديم، و آنها را بر بسيارى از آفريده‌هاى خود برترى آشكار داديم.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmc{[ياد كن‌] روزى را كه هر گروهى را با پيشوايشان فرا مى‌خوانيم. پس هر كس كارنامه‌اش را به دست راستش دهند، آنان كارنامه خود را مى‌خوانند و به قدر نخك هسته خرمايى به آنها ستم نمى‌شود.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmci{و هر كه در اين [دنيا] كور[دل‌] باشد در آخرت [هم‌] كور[دل‌] و گمراهتر خواهد بود.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmcii{و چيزى نمانده بود كه تو را از آنچه به سوى تو وحى كرده‌ايم گمراه كنند تا غير از آن را بر ما ببندى و در آن صورت تو را به دوستى خود بگيرند.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmciii{و اگر تو را استوار نمى‌داشتيم، قطعاً نزديك بود كمى به سوى آنان متمايل شوى.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmciv{در آن صورت، حتماً تو را دو برابر [در] زندگى و دو برابر [پس از] مرگ [عذاب‌] مى‌چشانيديم، آنگاه در برابر ما براى خود ياورى نمى‌يافتى.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmcv{و چيزى نمانده بود كه تو را از اين سرزمين بَرْكَنَنْد، تا تو را از آنجا بيرون سازند، و در آن صورت آنان [هم‌] پس از تو جز [زمان‌] اندكى نمى‌ماندند؛\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmcvi{سنّتى كه همواره در ميان [امتهاى‌] فرستادگانى كه پيش از تو گسيل داشته‌ايم [جارى‌] بوده است، و براى سنت [و قانون‌] ما تغييرى نخواهى يافت.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmcvii{نماز را از زوال آفتاب تا نهايت تاريكى شب برپادار، و [نيز] نماز صبح را، زيرا نماز صبح همواره [مقرون با] حضور [فرشتگان‌] است.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmcviii{و پاسى از شب را زنده بدار، تا براى تو [به منزله‌] نافله‌اى باشد، اميد كه پروردگارت تو را به مقامى ستوده برساند.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmcix{و بگو: «پروردگارا، مرا [در هر كارى‌] به طرز درست داخل كن و به طرز درست خارج ساز، و از جانب خود براى من تسلطى يارى‌بخش قرار ده.»\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmcx{و بگو: «حق آمد و باطل نابود شد. آرى، باطل همواره نابودشدنى است.»\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmcxi{و ما آنچه را براى مؤمنان مايه درمان و رحمت است از قرآن نازل مى‌كنيم، و[لى‌] ستمگران را جز زيان نمى‌افزايد.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmcxii{و چون به انسان نعمت ارزانى داريم، روى مى‌گرداند و پهلو تهى مى‌كند، و چون آسيبى به وى رسد نوميد مى‌گردد.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmcxiii{بگو: «هر كس بر حسب ساختار [روانى و بدنى‌] خود عمل مى‌كند، و پروردگار شما به هر كه راه‌يافته‌تر باشد داناتر است.»\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmcxiv{و در باره روح از تو مى‌پرسند، بگو: «روح از [سنخ‌] فرمان پروردگار من است، و به شما از دانش جز اندكى داده نشده است.»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmcxv{و اگر بخواهيم، قطعاً آنچه را به تو وحى كرده‌ايم مى‌بَريم، آنگاه براى [حفظ] آن، در برابر ما، براى خود مدافعى نمى‌يابى،\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmcxvi{مگر رحمتى از جانب پروردگارت [به تو برسد]، زيرا فضل او بر تو همواره بسيار است.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmcxvii{بگو: «اگر انس و جن گرد آيند تا نظير اين قرآن را بياورند، مانند آن را نخواهند آورد، هر چند برخى از آنها پشتيبان برخى [ديگر] باشند.»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmcxviii{و به راستى در اين قرآن از هر گونه مَثَلى، گوناگون آورديم، ولى بيشتر مردم جز سرِ انكار ندارند.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmcxix{و گفتند: «تا از زمين چشمه‌اى براى ما نجوشانى، هرگز به تو ايمان نخواهيم آورد.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmcxx{يا [بايد] براى تو باغى از درختان خرما و انگور باشد و آشكارا از ميان آنها جويبارها روان سازى،\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmcxxi{يا چنانكه ادعا مى‌كنى، آسمان را پاره پاره بر [سر] ما فرو اندازى، يا خدا و فرشتگان را در برابر [ما حاضر] آورى،\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmcxxii{يا براى تو خانه‌اى از طلا[كارى‌] باشد، يا به آسمان بالا روى، و به بالا رفتن تو [هم‌] اطمينان نخواهيم داشت، تا بر ما كتابى نازل كنى كه آن را بخوانيم. «بگو:» پاك است پروردگار من، آيا [من‌] جز بشرى فرستاده هستم؟\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmcxxiii{و [چيزى‌] مردم را از ايمان آوردن باز نداشت، آنگاه كه هدايت برايشان آمد، جز اينكه گفتند: «آيا خدا بشرى را به سِمَت رسول مبعوث كرده است؟»\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmcxxiv{بگو: «اگر در روى زمين فرشتگانى بودند كه با اطمينان راه مى‌رفتند، البته بر آنان [نيز] فرشته‌اى را بعنوان پيامبر از آسمان نازل مى‌كرديم.»\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmcxxv{بگو: «ميان من و شما، گواه بودن خدا كافى است، چرا كه او همواره به [حال‌] بندگانش آگاهِ بينا است.»\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmcxxvi{و هر كه را خدا هدايت كند او رهيافته است، و هر كه را گمراه سازد، در برابر او براى آنان هرگز دوستانى نيابى، و روز قيامت آنها را كور و لال و كر، به روى چهره‌شان درافتاده، برخواهيم انگيخت: جايگاهشان دوزخ است. هر بار كه آتش آن فرو نشيند، شراره‌اى [تازه‌] برايشان مى‌افزاييم.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mmcxxvii{جزاى آنها اين است، چرا كه آيات ما را انكار كردند و گفتند: «آيا وقتى ما استخوان و خاك شديم [باز] در آفرينشى جديد برانگيخته خواهيم شد؟»\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mmcxxviii{آيا ندانستند كه خدايى كه آسمانها و زمين را آفريده، تواناست كه مانند آنان را بيافريند و [همان خداست كه‌] برايشان زمانى مقرر فرموده كه در آن هيچ شكى نيست؟ و[لى‌] ستمگران جز انكار [چيزى را ]نپذيرفتند.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mmcxxix{بگو: «اگر شما مالك گنجينه‌هاى رحمت پروردگارم بوديد، باز هم از بيم خرج كردن قطعاً امساك مى‌ورزيديد، و انسان همواره بخيل است.»\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mmcxxx{و در حقيقت، ما به موسى نُه نشانه آشكار داديم. -پس، از فرزندان اسرائيل بپرس- آنگاه كه نزد آنان آمد، و فرعون به او گفت: «اى موسى‌، من جداً تو را افسون‌شده مى‌پندارم.»\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mmcxxxi{گفت: «قطعاً مى‌دانى كه اين [نشانه‌ها] را كه باعث بينشهاست، جز پروردگار آسمانها و زمين نازل نكرده است، و راستى اى فرعون، تو را تباه شده مى‌پندارم.»\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mmcxxxii{پس [فرعون‌] تصميم گرفت كه آنان را از سرزمين [مصر] بركَند، پس او و هر كه را با وى بود همه را غرق كرديم.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mmcxxxiii{و پس از او به فرزندان اسرائيل گفتيم: «در اين سرزمين ساكن شويد، پس چون وعده آخرت فرا رسد شما را همه با هم محشور مى‌كنيم.»\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mmcxxxiv{و آن [قرآن‌] را به حق فرود آورديم و به حق فرود آمد، و تو را جز بشارت‌دهنده و بيم‌رسان نفرستاديم.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mmcxxxv{و قرآنى [با عظمت را] بخش بخش [بر تو] نازل كرديم تا آن را به آرامى به مردم بخوانى، و آن را به تدريج نازل كرديم.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mmcxxxvi{بگو: «[چه‌] به آن ايمان بياوريد يا نياوريد، بى‌گمان كسانى كه پيش از [نزول‌] آن دانش يافته‌اند، چون [اين كتاب‌] بر آنان خوانده شود سجده‌كنان به روى درمى‌افتند.»\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mmcxxxvii{و مى‌گويند: «منزّه است پروردگار ما، كه وعده پروردگار ما قطعاً انجام‌شدنى است.»\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mmcxxxviii{و بر روى زمين مى‌افتند و مى‌گريند و بر فروتنى آنها مى‌افزايد.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mmcxxxix{بگو: «خدا را بخوانيد يا رحمان را بخوانيد، هر كدام را بخوانيد، براى او نامهاى نيكوتر است.» و نمازت را به آوازِ بلند مخوان و بسيار آهسته‌اش مكن، و ميان اين [و آن‌] راهى [ميانه‌] جوى.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mmcxl{و بگو: «ستايش خدايى را كه نه فرزندى گرفته و نه در جهاندارى شريكى دارد و نه خوار بوده كه [نياز به‌] دوستى داشته باشد.» و او را بسيار بزرگ شمار.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mmcxli{\basmalahfa ستايش خدايى را كه اين كتاب [آسمانى‌] را بر بنده خود فرو فرستاد و هيچ گونه كژى در آن ننهاد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmcxlii{[كتابى‌] راست و درست، تا [گناهكاران را] از جانب خود به عذابى سخت بيم دهد، و مؤمنانى را كه كارهاى شايسته مى‌كنند نويد بخشد كه براى آنان پاداشى نيكوست.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmcxliii{در حالى كه جاودانه در آن [بهشت‌] ماندگار خواهند بود.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmcxliv{و تا كسانى را كه گفته‌اند: خداوند فرزندى گرفته است، هشدار دهد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmcxlv{نه آنان و نه پدرانشان به اين [ادّعا] دانشى ندارند. بزرگ سخنى است كه از دهانشان برمى‌آيد. [آنان‌] جز دروغ نمى‌گويند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmcxlvi{شايد، اگر به اين سخن ايمان نياورند، تو جان خود را از اندوه، در پيگيرى [كار]شان تباه كنى.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmcxlvii{در حقيقت، ما آنچه را كه بر زمين است، زيورى براى آن قرار داديم، تا آنان را بيازماييم كه كدام يك از ايشان نيكوكارترند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmcxlviii{و ما آنچه را كه بر آن است، قطعاً بيابانى بى‌گياه خواهيم كرد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmcxlix{مگر پنداشتى اصحاب كهف و رقيم [=خفتگان غار لوحه‌دار] از آيات ما شگفت بوده است؟\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmcl{آنگاه كه جوانان به سوى غار پناه جستند و گفتند: «پروردگار ما! از جانب خود به ما رحمتى بخش و كار ما را براى ما به سامان رسان.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmcli{پس در آن غار، ساليانى چند بر گوشهايشان پرده زديم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmclii{آنگاه آنان را بيدار كرديم، تا بدانيم كدام يك از آن دو دسته، مدت درنگشان را بهتر حساب كرده‌اند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmcliii{ما خبرشان را بر تو درست حكايت مى‌كنيم: آنان جوانانى بودند كه به پروردگارشان ايمان آورده بودند و بر هدايتشان افزوديم.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmcliv{و دلهايشان را استوار گردانيديم آنگاه كه [به قصد مخالفت با شرك‌] برخاستند و گفتند: «پروردگار ما پروردگار آسمانها و زمين است. جز او هرگز معبودى را نخواهيم خواند، كه در اين صورت قطعاً ناصواب گفته‌ايم.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmclv{اين قوم ما جز او معبودانى اختيار كرده‌اند. چرا بر [حقّانيّت‌] آنها برهانى آشكار نمى‌آورند؟ پس كيست ستمكارتر از آن كس كه بر خدا دروغ بندد؟\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmclvi{و چون از آنها و از آنچه كه جز خدا مى‌پرستند كناره گرفتيد، پس به غار پناه جوييد، تا پروردگارتان از رحمت خود بر شما بگستراند و براى شما در كارتان گشايشى فراهم سازد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmclvii{و آفتاب را مى‌بينى كه چون برمى‌آيد، از غارشان به سمت راست مايل است، و چون فرو مى‌شود از سمت چپ دامن برمى‌چيند، در حالى كه آنان در جايى فراخ از آن [غار قرار گرفته‌]اند. اين از نشانه‌هاى [قدرت‌] خداست. خدا هر كه را راهنمايى كند او راه‌يافته است، و هر كه را بى‌راه گذارد، هرگز براى او يارى راهبر نخواهى يافت.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmclviii{و مى‌پندارى كه ايشان بيدارند، در حالى كه خفته‌اند و آنها را به پهلوى راست و چپ مى‌گردانيم، و سگشان بر آستانه [غار] دو دست خود را دراز كرده [بود]. اگر بر حال آنان اطلاع مى‌يافتى، گريزان روى از آنها برمى‌تافتى و از [مشاهده‌] آنها آكنده از بيم مى‌شدى.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmclix{و اين چنين بيدارشان كرديم، تا ميان خود از يكديگر پرسش كنند. گوينده‌اى از آنان گفت: «چقدر مانده‌ايد؟» گفتند: «روزى يا پاره‌اى از روز را مانده‌ايم.» [سرانجام‌] گفتند: «پروردگارتان به آنچه مانده‌ايد داناتر است، اينك يكى از خودتان را با اين پول خود به شهر بفرستيد، تا ببيند كدام يك از غذاهاى آن پاكيزه‌تر است و از آن، غذايى برايتان بياورد، و بايد زيركى به خرج دهد و هيچ كس را از [حال‌] شما آگاه نگرداند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmclx{چرا كه اگر آنان بر شما دست يابند، سنگسارتان مى‌كنند يا شما را به كيش خود بازمى‌گردانند، و در آن صورت هرگز روى رستگارى نخواهيد ديد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmclxi{و بدين گونه [مردم آن ديار را] بر حالشان آگاه ساختيم تا بدانند كه وعده خدا راست است و [در فرا رسيدن‌] قيامت هيچ شكى نيست، هنگامى كه ميان خود در كارشان با يكديگر نزاع مى‌كردند، پس [عده‌اى ]گفتند: «بر روى آنها ساختمانى بنا كنيد، پروردگارشان به [حال‌] آنان داناتر است.» [سرانجام‌] كسانى كه بر كارشان غلبه يافتند گفتند: «حتماً بر ايشان معبدى بنا خواهيم كرد.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmclxii{به زودى خواهند گفت: «سه تن بودند [و] چهارمين آنها سگشان بود.» و مى‌گويند: «پنج تن بودند [و] ششمين آنها سگشان بود.» تير در تاريكى مى‌اندازند. و [عده‌اى‌] مى‌گويند: «هفت تن بودند و هشتمين آنها سگشان بود.» بگو: «پروردگارم به شماره آنها آگاه‌تر است، جز اندكى [كسى شماره‌] آنها را نمى‌داند.» پس در باره ايشان جز به صورت ظاهر جدال مكن و در مورد آنها از هيچ كس جويا مشو.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmclxiii{و زنهار در مورد چيزى مگوى كه من آن را فردا انجام خواهم داد.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmclxiv{مگر آنكه خدا بخواهد، و چون فراموش كردى پروردگارت را ياد كن و بگو: «اميد كه پروردگارم مرا به راهى كه نزديكتر از اين به صواب است، هدايت كند.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmclxv{و سيصد سال در غارشان درنگ كردند و نه سال [نيز بر آن‌] افزودند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmclxvi{بگو: «خدا به آنچه درنگ كردند داناتر است. نهان آسمانها و زمين به او اختصاص دارد. وه! چه بينا و شنواست. براى آنان ياورى جز او نيست و هيچ كس را در فرمانروايى خود شريك نمى‌گيرد.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmclxvii{و آنچه را كه از كتاب پروردگارت به تو وحى شده است بخوان. كلمات او را تغييردهنده‌اى نيست، و جز او هرگز پناهى نخواهى يافت.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmclxviii{و با كسانى كه پروردگارشان را صبح و شام مى‌خوانند [و] خشنودى او را مى‌خواهند، شكيبايى پيشه كن، و دو ديده‌ات را از آنان برمگير كه زيور زندگى دنيا را بخواهى، و از آن كس كه قلبش را از ياد خود غافل ساخته‌ايم و از هوس خود پيروى كرده و [اساس‌] كارش بر زياده‌روى است، اطاعت مكن.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmclxix{و بگو: «حق از پروردگارتان [رسيده‌] است. پس هر كه بخواهد بگرود و هر كه بخواهد انكار كند، كه ما براى ستمگران آتشى آماده كرده‌ايم كه سراپرده‌هايش آنان را در بر مى‌گيرد، و اگر فريادرسى جويند، به آبى چون مس گداخته كه چهره‌ها را بريان مى‌كند يارى مى‌شوند. وه! چه بد شرابى و چه زشت جايگاهى است.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmclxx{كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند [بدانند كه‌] ما پاداش كسى را كه نيكوكارى كرده است تباه نمى‌كنيم.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmclxxi{آنانند كه بهشتهاى عدن به ايشان اختصاص دارد كه از زير [قصرها]شان جويبارها روان است. در آنجا با دستبندهايى از طلا آراسته مى‌شوند و جامه‌هايى سبز از پرنيان نازك و حرير ستبر مى‌پوشند. در آنجا بر سريرها تكيه مى‌زنند. چه خوش پاداش و نيكو تكيه‌گاهى!\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmclxxii{و براى آنان، آن دو مرد را مَثَل بزن كه به يكى از آنها دو باغ انگور داديم و پيرامون آن دو [باغ‌] را با درختان خرما پوشانديم، و ميان آن دو را كشتزارى قرار داديم.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmclxxiii{هر يك از اين دو باغ محصول خود را [به موقع‌] مى‌داد و از [صاحبش‌] چيزى دريغ نمى‌ورزيد، و ميان آن دو [باغ‌] نهرى روان كرده بوديم.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmclxxiv{و براى او ميوه فراوان بود. پس به رفيقش -در حالى كه با او گفت و گو مى‌كرد- گفت: «مال من از تو بيشتر است و از حيث افراد از تو نيرومندترم.»\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmclxxv{و در حالى كه او به خويشتن ستمكار بود، داخل باغ شد [و] گفت: «گمان نمى‌كنم اين نعمت هرگز زوال پذيرد.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmclxxvi{و گمان نمى‌كنم كه رستاخيز بر پا شود، و اگر هم به سوى پروردگارم بازگردانده شوم قطعاً بهتر از اين را در بازگشت، خواهم يافت.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmclxxvii{رفيقش -در حالى كه با او گفت و گو مى‌كرد- به او گفت: «آيا به آن كسى كه تو را از خاك، سپس از نطفه آفريد، آنگاه تو را [به صورت‌] مردى درآورد، كافر شدى؟»\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmclxxviii{اما من [مى‌گويم:] اوست خدا، پروردگار من، و هيچ كس را با پروردگارم شريك نمى‌سازم.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmclxxix{و چون داخل باغت شدى، چرا نگفتى: ماشاء الله، نيرويى جز به [قدرت‌] خدا نيست. اگر مرا از حيث مال و فرزند كمتر از خود مى‌بينى،\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmclxxx{اميد است كه پروردگارم بهتر از باغ تو به من عطا فرمايد، و بر آن [باغ تو] آفتى از آسمان بفرستد، تا به زمينى هموار و لغزنده تبديل گردد؛\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmclxxxi{يا آب آن [در زمين‌] فروكش كند تا هرگز نتوانى آن را به دست آورى.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmclxxxii{[تا به او رسيد آنچه را بايد برسد] و [آفت آسمانى‌] ميوه‌هايش را فرو گرفت. پس براى [از كف دادن‌] آنچه در آن [باغ‌] هزينه كرده بود، دستهايش را بر هم مى‌زد در حالى كه داربستهاى آن فرو ريخته بود. و [به حسرت‌] مى‌گفت: «اى كاش هيچ كس را شريك پروردگارم نمى‌ساختم.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmclxxxiii{و او را در برابر خدا گروهى نبود، تا ياريش كنند، و توانى نداشت كه خود را يارى كند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmclxxxiv{در آنجا [آشكار شد كه‌] يارى به خداىِ حق تعلق دارد. اوست بهترين پاداش و [اوست‌] بهترين فرجام.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmclxxxv{و براى آنان زندگى دنيا را مَثَل بزن كه مانند آبى است كه آن را از آسمان فرو فرستاديم؛ سپس گياه زمين با آن درآميخت و [چنان‌] خشك گرديد كه بادها پراكنده‌اش كردند، و خداست كه همواره بر هر چيزى تواناست.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmclxxxvi{مال و پسران زيور زندگى دنيايند، و نيكيهاى ماندگار از نظر پاداش نزد پروردگارت بهتر و از نظر اميد [نيز] بهتر است.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmclxxxvii{و [ياد كن‌] روزى را كه كوهها را به حركت درمى‌آوريم، و زمين را آشكار [و صاف‌] مى‌بينى، و آنان را گرد مى‌آوريم و هيچ يك را فرو گذار نمى‌كنيم.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmclxxxviii{و ايشان به صف بر پروردگارت عرضه مى‌شوند [و به آنها مى‌فرمايد:] به راستى همان گونه كه نخستين بار شما را آفريديم [باز] به سوى ما آمديد، بلكه پنداشتيد هرگز براى شما موعدى مقرر قرار نخواهيم داد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmclxxxix{و كارنامه [عمل شما در ميان‌] نهاده مى‌شود، آنگاه بزهكاران را از آنچه در آن است بيمناك مى‌بينى، و مى‌گويند: «اى واى بر ما، اين چه نامه‌اى است كه هيچ [كار] كوچك و بزرگى را فرو نگذاشته، جز اينكه همه را به حساب آورده است.» و آنچه را انجام داده‌اند حاضر يابند، و پروردگار تو به هيچ كس ستم روا نمى‌دارد.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmcxc{و [ياد كن‌] هنگامى را كه به فرشتگان گفتيم: «آدم را سجده كنيد،» پس [همه‌] -جز ابليس- سجده كردند، كه از [گروه‌] جن بود و از فرمان پروردگارش سرپيچيد. آيا [با اين حال،] او و نسلش را به جاى من دوستان خود مى‌گيريد، و حال آنكه آنها دشمن شمايند؟ و چه بد جانشينانى براى ستمگرانند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmcxci{[من‌] آنان را نه در آفرينش آسمانها و زمين به شهادت طلبيدم و نه در آفرينش خودشان. و من آن نيستم كه گمراهگران را همكار خود بگيرم.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmcxcii{و [ياد كن‌] روزى را كه [خدا] مى‌گويد: «آنهايى را كه شريكان من پنداشتيد، ندا دهيد»، پس آنها را بخوانند و[لى‌] اجابتشان نكنند، و ما ميان آنان ورطه‌اى قرار دهيم.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmcxciii{و گناهكاران آتش [دوزخ‌] را مى‌بينند و درمى‌يابند كه در آن خواهند افتاد، و از آن راه گريزى نيابند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmcxciv{و به راستى در اين قرآن، براى مردم از هر گونه مَثَلى آورديم، و[لى‌] انسان بيش از هر چيز سرِ جدال دارد.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmcxcv{و چيزى مانع مردم نشد از اينكه وقتى هدايت به سويشان آمد ايمان بياورند، و از پروردگارشان آمرزش بخواهند، جز اينكه [مستحق شوند] تا سنت [خدا در مورد عذاب‌] پيشينيان، در باره آنان [نيز] به كار رود، يا عذاب رويارويشان بيايد.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmcxcvi{و پيامبران [خود] را جز بشارت‌دهنده و بيم‌رسان گسيل نمى‌داريم، و كسانى كه كافر شده‌اند، به باطل مجادله مى‌كنند تا به وسيله آن، حق را پايمال گردانند، و نشانه‌هاى من و آنچه را [بدان‌] بيم داده شده‌اند به ريشخند گرفتند.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmcxcvii{و كيست ستمكارتر از آن كس كه به آيات پروردگارش پند داده شده، و از آن روى برتافته، و دستاورد پيشينه خود را فراموش كرده است؟ ما بر دلهاى آنان پوششهايى قرار داديم تا آن را درنيابند و در گوشهايشان سنگينى [نهاديم‌]. و اگر آنها را به سوى هدايت فراخوانى باز هرگز به راه نخواهند آمد.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmcxcviii{و پروردگار تو آمرزنده [و] صاحب رحمت است. اگر به [جرم‌] آنچه مرتكب شده‌اند، آنها را مؤاخذه مى‌كرد، قطعاً در عذاب آنان تعجيل مى‌نمود [ولى چنين نمى كند] بلكه براى آنها سر رسيدى است كه هرگز از برابر آن راه گريزى نمى‌يابند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmcxcix{و [مردم‌] آن شهرها چون بيدادگرى كردند، هلاكشان كرديم، و براى هلاكتشان موعدى مقرر داشتيم.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmcc{و [ياد كن‌] هنگامى را كه موسى به جوانِ [همراه‌] خود گفت: «دست بردار نيستم تا به محل برخورد دو دريا برسم، هر چند سالها[ى سال‌] سير كنم.»\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmcci{پس چون به محل برخورد دو [دريا] رسيدند، ماهىِ خودشان را فراموش كردند، و ماهى در دريا راه خود را در پيش گرفت [و رفت‌].\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmccii{و هنگامى كه [از آنجا] گذشتند [موسى‌] به جوان خود گفت: «غذايمان را بياور كه راستى ما از اين سفر رنج بسيار ديديم.»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmcciii{گفت: «ديدى؟ وقتى به سوى آن صخره پناه جستيم، من ماهى را فراموش كردم، و جز شيطان، [كسى‌] آن را از ياد من نبرد، تا به يادش باشم، و به طور عجيبى راه خود را در دريا پيش گرفت.»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmcciv{گفت: «اين همان بود كه ما مى‌جستيم.» پس جستجوكنان ردّ پاى خود را گرفتند و برگشتند.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmccv{تا بنده‌اى از بندگان ما را يافتند كه از جانب خود به او رحمتى عطا كرده و از نزد خود بدو دانشى آموخته بوديم.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmccvi{موسى به او گفت: «آيا تو را -به شرط اينكه از بينشى كه آموخته شده‌اى به من ياد دهى- پيروى كنم؟»\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmccvii{گفت: «تو هرگز نمى‌توانى همپاى من صبر كنى.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmccviii{و چگونه مى‌توانى بر چيزى كه به شناخت آن احاطه ندارى صبر كنى؟»\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmccix{گفت: «ان شاء الله مرا شكيبا خواهى يافت و در هيچ كارى تو را نافرمانى نخواهم كرد.»\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmccx{گفت: «اگر مرا پيروى مى‌كنى، پس از چيزى سؤال مكن، تا [خود] از آن با تو سخن آغاز كنم.»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmccxi{پس رهسپار گرديدند، تا وقتى كه سوار كشتى شدند، [وى‌] آن را سوراخ كرد. [موسى‌] گفت: «آيا كشتى را سوراخ كردى تا سرنشينانش را غرق كنى؟ واقعاً به كار ناروايى مبادرت ورزيدى.»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmccxii{گفت: «آيا نگفتم كه تو هرگز نمى‌توانى همپاى من صبر كنى؟»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmccxiii{[موسى‌] گفت: «به سبب آنچه فراموش كردم، مرا مؤاخذه مكن و در كارم بر من سخت مگير.»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmccxiv{پس رفتند تا به نوجوانى برخوردند. [بنده ما] او را كشت. [موسى به او ] گفت: «آيا شخص بى‌گناهى را بدون اينكه كسى را به قتل رسانده باشد كشتى؟ واقعاً كار ناپسندى مرتكب شدى.»\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmccxv{گفت: «آيا به تو نگفتم كه هرگز نمى‌توانى همپاى من صبر كنى؟»\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmccxvi{[موسى‌] گفت: «اگر از اين پس چيزى از تو پرسيدم، ديگر با من همراهى مكن [و] از جانب من قطعاً معذور خواهى بود.»\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmccxvii{پس رفتند تا به اهل قريه‌اى رسيدند. از مردم آنجا خوراكى خواستند، و[لى آنها] از مهمان نمودن آن دو خوددارى كردند. پس در آنجا ديوارى يافتند كه مى‌خواست فرو ريزد، و [بنده ما] آن را استوار كرد. [موسى‌] گفت: «اگر مى‌خواستى [مى‌توانستى‌] براى آن مزدى بگيرى.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmccxviii{گفت: «اين [بار، ديگر وقت‌] جدايى ميان من و توست. به زودى تو را از تأويل آنچه كه نتوانستى بر آن صبر كنى آگاه خواهم ساخت»:\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmccxix{اما كشتى، از آنِ بينوايانى بود كه در دريا كار مى‌كردند، خواستم آن را معيوب كنم، [چرا كه‌] پيشاپيش آنان پادشاهى بود كه هر كشتى [درستى‌] را به زور مى‌گرفت.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmccxx{و اما نوجوان، پدر و مادرش [هر دو] مؤمن بودند، پس ترسيديم [مبادا] آن دو را به طغيان و كفر بكِشد.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmccxxi{پس خواستيم كه پروردگارشان آن دو را به پاكتر و مهربانتر از او عوض دهد.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmccxxii{و اما ديوار، از آنِ دو پسر [بچه‌] يتيم در آن شهر بود، و زير آن، گنجى متعلق به آن دو بود، و پدرشان [مردى‌] نيكوكار بود، پس پروردگار تو خواست آن دو [يتيم‌] به حد رشد برسند و گنجينه خود را -كه رحمتى از جانب پروردگارت بود- بيرون آورند. و اين [كارها] را من خودسرانه انجام ندادم. اين بود تأويل آنچه كه نتوانستى بر آن شكيبايى ورزى.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmccxxiii{و از تو در باره «ذوالقرنين» مى‌پرسند. بگو: «به زودى چيزى از او براى شما خواهم خواند.»\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmccxxiv{ما در زمين به او امكاناتى داديم و از هر چيزى وسيله‌اى بدو بخشيديم.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmccxxv{تا راهى را دنبال كرد.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmccxxvi{تا آنگاه كه به غروبگاه خورشيد رسيد، به نظرش آمد كه [خورشيد] در چشمه‌اى گِل‌آلود و سياه غروب مى‌كند، و نزديك آن طايفه‌اى را يافت. فرموديم: «اى ذوالقرنين، [اختيار با توست‌] يا عذاب مى‌كنى يا در ميانشان [روش‌] نيكويى پيش مى‌گيرى.»\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmccxxvii{گفت: «اما هر كه ستم ورزد عذابش خواهيم كرد، سپس به سوى پروردگارش بازگردانيده مى‌شود، آنگاه او را عذابى سخت خواهد كرد.»\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmccxxviii{و اما هر كه ايمان آورد و كار شايسته كند، پاداشى [هر چه‌] نيكوتر خواهد داشت، و به فرمان خود، او را به كارى آسان واخواهيم داشت.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmccxxix{سپس راهى [ديگر] را دنبال كرد.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmccxxx{تا آنگاه كه به جايگاه برآمدن خورشيد رسيد. [خورشيد] را [چنين‌] يافت كه بر قومى طلوع مى‌كرد كه براى ايشان در برابر آن پوششى قرار نداده بوديم.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmccxxxi{اين چنين [مى‌رفت‌]، و قطعاً به خبرى كه پيش او بود احاطه داشتيم.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmccxxxii{باز راهى را دنبال نمود.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmccxxxiii{تا وقتى به ميان دو سد رسيد، در برابر آن دو [سد]، طايفه‌اى را يافت كه نمى‌توانستند هيچ زبانى را بفهمند.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmccxxxiv{گفتند: «اى ذوالقرنين، يأجوج و مأجوج سخت در زمين فساد مى‌كنند، آيا [ممكن است‌] مالى در اختيار تو قرار دهيم تا ميان ما و آنان سدى قرار دهى؟»\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmccxxxv{گفت: «آنچه پروردگارم به من در آن تمكّن داده، [از كمك مالى شما] بهتر است. مرا با نيرويى [انسانى‌] يارى كنيد [تا] ميان شما و آنها سدى استوار قرار دهم.»\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmccxxxvi{براى من قطعات آهن بياوريد، تا آنگاه كه ميان دو كوه برابر شد، گفت: «بدميد» تا وقتى كه آن [قطعات‌] را آتش گردانيد، گفت: «مس گداخته برايم بياوريد تا روى آن بريزم.»\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmccxxxvii{[در نتيجه، اقوام وحشى‌] نتوانستند از آن [مانع‌] بالا روند و نتوانستند آن را سوراخ كنند.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mmccxxxviii{گفت: «اين رحمتى از جانب پروردگار من است، و[لى‌] چون وعده پروردگارم فرا رسد، آن [سد] را درهم كوبد، و وعده پروردگارم حق است.»\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mmccxxxix{و در آن روز آنان را رها مى‌كنيم تا موج‌آسا بعضى با برخى درآميزند و [همين كه‌] در صور دميده شود، همه آنها را گرد خواهيم آورد.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mmccxl{و آن روز، جهنم را آشكارا به كافران بنماييم.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mmccxli{[به‌] همان كسانى كه چشمان [بصيرت‌]شان از ياد من در پرده بود، و توانايى شنيدن [حق‌] نداشتند.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mmccxlii{آيا كسانى كه كفر ورزيده‌اند، پنداشته‌اند كه [مى‌توانند] به جاى من، بندگانم را سرپرست بگيرند؟ ما جهنم را آماده كرده‌ايم تا جايگاه پذيرايى كافران باشد.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mmccxliii{بگو: «آيا شما را از زيانكارترين مردم آگاه گردانم؟»\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mmccxliv{[آنان‌] كسانى‌اند كه كوشش‌شان در زندگى دنيا به هدر رفته و خود مى‌پندارند كه كار خوب انجام مى‌دهند.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mmccxlv{[آرى،] آنان كسانى‌اند كه آيات پروردگارشان و لقاى او را انكار كردند، در نتيجه اعمالشان تباه گرديد، و روز قيامت براى آنها [قدر و] ارزشى نخواهيم نهاد.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mmccxlvi{اين جهنم سزاى آنان است، چرا كه كافر شدند و آيات من و پيامبرانم را به ريشخند گرفتند.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mmccxlvii{بى‌گمان كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، باغهاى فردوس جايگاه پذيرايى آنان است.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mmccxlviii{جاودانه در آن خواهند بود، و از آنجا درخواست انتقال نمى‌كنند.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mmccxlix{بگو: «اگر دريا براى كلمات پروردگارم مركب شود، پيش از آنكه كلمات پروردگارم پايان پذيرد، قطعاً دريا پايان مى‌يابد، هر چند نظيرش را به مدد [آن‌] بياوريم.»\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mmccl{بگو: «من هم مِثل شما بشرى هستم و[لى‌] به من وحى مى‌شود كه خداى شما خدايى يگانه است. پس هر كس به لقاى پروردگار خود اميد دارد بايد به كار شايسته بپردازد، و هيچ كس را در پرستش پروردگارش شريك نسازد.»\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mmccli{\basmalahfa كاف، ها، يا، عين، صاد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmcclii{[اين‌] يادى از رحمت پروردگار تو [در باره‌] بنده‌اش زكرياست.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmccliii{آنگاه كه [زكريا] پروردگارش را آهسته ندا كرد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmccliv{گفت: «پروردگارا، من استخوانم سست گرديده و [موى‌] سرم از پيرى سپيد گشته، و -اى پروردگار من- هرگز در دعاى تو نااميد نبوده‌ام.»\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmcclv{و من پس از خويشتن از بستگانم بيمناكم و زنم نازاست، پس از جانب خود ولىّ [و جانشينى‌] به من ببخش،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmcclvi{كه از من ارث برد و از خاندان يعقوب [نيز] ارث برد، و او را -اى پروردگار من- پسنديده گردان.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmcclvii{اى زكريا، ما تو را به پسرى -كه نامش يحيى است- مژده مى‌دهيم، كه قبلاً همنامى براى او قرار نداده‌ايم.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmcclviii{گفت: «پروردگارا، چگونه مرا پسرى خواهد بود و حال آنكه زنم نازاست و من از سالخوردگى ناتوان شده‌ام؟»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmcclix{[فرشته‌] گفت: «[فرمان‌] چنين است. پروردگار تو گفته كه اين [كار] بر من آسان است، و تو را در حالى كه چيزى نبودى قبلاً آفريده‌ام.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmcclx{گفت: «پروردگارا، نشانه‌اى براى من قرار ده» فرمود: «نشانه تو اين است كه سه شبانه [روز] با اينكه سالمى با مردم سخن نمى‌گويى.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmcclxi{پس، از محراب بر قوم خويش درآمد و ايشان را آگاه گردانيد كه روز و شب به نيايش بپردازيد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmcclxii{اى يحيى، كتاب [خدا] را به جد و جهد بگير، و از كودكى به او نبوّت داديم.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmcclxiii{و [نيز] از جانب خود، مهربانى و پاكى [به او داديم‌] و تقواپيشه بود.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmcclxiv{و با پدر و مادر خود نيك‌رفتار بود و زورگويى نافرمان نبود.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmcclxv{و درود بر او، روزى كه زاده شد و روزى كه مى‌ميرد و روزى كه زنده برانگيخته مى‌شود.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmcclxvi{و در اين كتاب از مريم ياد كن، آنگاه كه از كسان خود، در مكانى شرقى به كنارى شتافت.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmcclxvii{و در برابر آنان پرده‌اى بر خود گرفت. پس روح خود را به سوى او فرستاديم تا به [شكل‌] بشرى خوش‌اندام بر او نمايان شد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmcclxviii{[مريم‌] گفت: «اگر پرهيزگارى، من از تو به خداى رحمان پناه مى‌برم.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmcclxix{گفت: «من فقط فرستاده پروردگار توام، براى اينكه به تو پسرى پاكيزه ببخشم.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmcclxx{گفت: «چگونه مرا پسرى باشد با آنكه دست بشرى به من نرسيده و بدكار نبوده‌ام؟»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmcclxxi{گفت: « [فرمان‌] چنين است، پروردگار تو گفته كه آن بر من آسان است، و تا او را نشانه‌اى براى مردم و رحمتى از جانب خويش قرار دهيم، و [اين‌] دستورى قطعى بود.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmcclxxii{پس [مريم‌] به او [=عيسى‌] آبستن شد و با او به مكان دورافتاده‌اى پناه جست.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmcclxxiii{تا درد زايمان، او را به سوى تنه درخت خرمايى كشانيد. گفت: «اى كاش، پيش از اين مرده بودم و يكسر فراموش‌شده بودم.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmcclxxiv{پس، از زيرِ [پاى‌] او [فرشته‌] وى را ندا داد كه: غم مدار، پروردگارت زير [پاى‌] تو چشمه آبى پديد آورده است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmcclxxv{و تنه درخت خرما را به طرف خود [بگير و] بتكان، بر تو خرماى تازه مى‌ريزد.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmcclxxvi{و بخور و بنوش و ديده روشن دار. پس اگر كسى از آدميان را ديدى، بگوى: «من براى [خداى‌] رحمان روزه نذر كرده‌ام، و امروز مطلقاً با انسانى سخن نخواهم گفت.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmcclxxvii{پس [مريم‌] در حالى كه او را در آغوش گرفته بود به نزد قومش آورد. گفتند: «اى مريم، به راستى كار بسيار ناپسندى مرتكب شده‌اى.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmcclxxviii{اى خواهر هارون، پدرت مرد بدى نبود و مادرت [نيز] بدكاره نبود.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmcclxxix{[مريم‌] به سوى [عيسى‌] اشاره كرد. گفتند: «چگونه با كسى كه در گهواره [و] كودك است سخن بگوييم؟»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmcclxxx{[كودك‌] گفت: «منم بنده خدا، به من كتاب داده و مرا پيامبر قرار داده است،\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmcclxxxi{و هر جا كه باشم مرا با بركت ساخته، و تا زنده‌ام به نماز و زكات سفارش كرده است،\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmcclxxxii{و مرا نسبت به مادرم نيكوكار كرده و زورگو و نافرمانم نگردانيده است،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmcclxxxiii{و درود بر من، روزى كه زاده شدم و روزى كه مى‌ميرم و روزى كه زنده برانگيخته مى‌شوم.»\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmcclxxxiv{اين است [ماجراى‌] عيسى پسر مريم، [همان‌] گفتار درستى كه در آن شك مى‌كنند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmcclxxxv{خدا را نسزد كه فرزندى برگيرد. منزّه است او؛ چون كارى را اراده كند، همين قدر به آن مى‌گويد: «موجود شو»، پس بى‌درنگ موجود مى‌شود.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmcclxxxvi{و در حقيقت، خداست كه پروردگار من و پروردگار شماست، پس او را بپرستيد. اين است راه راست.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmcclxxxvii{اما دسته‌ها[ى گوناگون‌] از ميان آنها به اختلاف پرداختند، پس واى بر كسانى كه كافر شدند از مشاهده روزى دهشتناك.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmcclxxxviii{چه شنوا و بينايند روزى كه به سوى ما مى‌آيند، ولى ستمگران امروز در گمراهى آشكارند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmcclxxxix{و آنان را از روز حسرت بيم ده، آنگاه كه داورى انجام گيرد، و حال آنكه آنها [اكنون‌] در غفلتند و سر ايمان آوردن ندارند.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmccxc{ماييم كه زمين را با هر كه در آن است، به ميراث مى‌بريم و [همه‌] به سوى ما بازگردانيده مى‌شوند.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmccxci{و در اين كتاب به ياد ابراهيم پرداز، زيرا او پيامبرى بسيار راستگوى بود.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmccxcii{چون به پدرش گفت: «پدر جان، چرا چيزى را كه نمى‌شنود و نمى‌بيند و از تو چيزى را دور نمى‌كند مى‌پرستى؟\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmccxciii{اى پدر، به راستى مرا از دانش [وحى، حقايقى به دست‌] آمده كه تو را نيامده است. پس، از من پيروى كن تا تو را به راهى راست هدايت نمايم،\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmccxciv{پدر جان، شيطان را مپرست، كه شيطان [خداى‌] رحمان را عصيانگر است،\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmccxcv{پدر جان، من مى‌ترسم از جانب [خداى‌] رحمان عذابى به تو رسد و تو يار شيطان باشى.»\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmccxcvi{گفت: «اى ابراهيم، آيا تو از خدايان من متنفّرى؟ اگر باز نايستى تو را سنگسار خواهم كرد، و [برو] براى مدّتى طولانى از من دور شو.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmccxcvii{[ابراهيم‌] گفت: «درود بر تو باد، به زودى از پروردگارم براى تو آمرزش مى‌خواهم، زيرا او همواره نسبت به من پر مهر بوده است،\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmccxcviii{و از شما و [از] آنچه غير از خدا مى‌خوانيد كناره مى‌گيرم و پروردگارم را مى‌خوانم. اميدوارم كه در خواندن پروردگارم نااميد نباشم.»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmccxcix{و چون از آنها و [از] آنچه به جاى خدا مى‌پرستيدند كناره گرفت، اسحاق و يعقوب را به او عطا كرديم و همه را پيامبر گردانيديم.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmccc{و از رحمت خويش به آنان ارزانى داشتيم، و ذكر خيرِ بلندى برايشان قرار داديم.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmccci{و در اين كتاب از موسى ياد كن، زيرا كه او پاكدل و فرستاده‌اى پيامبر بود.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmcccii{و از جانب راست طور، او را ندا داديم، و در حالى كه با وى راز گفتيم او را به خود نزديك ساختيم.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmccciii{و به رحمت خويش برادرش هارون پيامبر را به او بخشيديم.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmccciv{و در اين كتاب از اسماعيل ياد كن، زيرا كه او درست‌وعده و فرستاده‌اى پيامبر بود.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmcccv{و خاندان خود را به نماز و زكات فرمان مى‌داد و همواره نزد پروردگارش پسنديده‌[رفتار] بود.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmcccvi{و در اين كتاب از ادريس ياد كن كه او راستگويى پيامبر بود.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmcccvii{و [ما] او را به مقامى بلند ارتقا داديم.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmcccviii{آنان كسانى از پيامبران بودند كه خداوند بر ايشان نعمت ارزانى داشت: از فرزندان آدم بودند و از كسانى كه همراه نوح [بر كشتى‌] سوار كرديم؛ و از فرزندان ابراهيم و اسرائيل و از كسانى كه [آنان را] هدايت نموديم و برگزيديم؛ [و] هر گاه آيات [خداى‌] رحمان بر ايشان خوانده مى‌شد، سجده‌كنان و گريان به خاك مى‌افتادند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmcccix{آنگاه، پس از آنان جانشينانى به جاى ماندند كه نماز را تباه ساخته و از هوسها پيروى كردند، و به زودى [سزاى‌] گمراهى [خود] را خواهند ديد.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmcccx{مگر آنان كه توبه كرده و ايمان آورده و كار شايسته انجام دادند، كه آنان به بهشت درمى‌آيند و ستمى بر ايشان نخواهد رفت.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmcccxi{باغهاى جاودانى كه [خداى‌] رحمان به بندگانش در جهان ناپيدا وعده داده است. در حقيقت، وعده او انجام‌شدنى است.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmcccxii{در آنجا سخن بيهوده‌اى نمى‌شنوند، جز درود. و روزى‌شان صبح و شام در آنجا [آماده‌] است.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmcccxiii{اين همان بهشتى است كه به هر يك از بندگان ما كه پرهيزگار باشند به ميراث مى‌دهيم.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmcccxiv{و [ما فرشتگان‌] جز به فرمان پروردگارت نازل نمى‌شويم. آنچه پيش روى ما و آنچه پشت سر ما و آنچه ميان اين دو است، [همه‌] به او اختصاص دارد، و پروردگارت هرگز فراموشكار نبوده است.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmcccxv{پروردگار آسمانها و زمين و آنچه ميان آن دو است. پس او را بپرست و در پرستش او شكيبا باش. آيا براى او همنامى مى‌شناسى؟\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmcccxvi{و انسان مى‌گويد: «آيا وقتى بميرم، راستى زنده [از قبر] بيرون آورده مى‌شوم؟»\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmcccxvii{آيا انسان به ياد نمى‌آورد كه ما او را قبلاً آفريده‌ايم و حال آنكه چيزى نبوده است؟\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmcccxviii{پس، به پروردگارت سوگند كه آنها را با شياطين محشور خواهيم ساخت، سپس در حالى كه به زانو درآمده‌اند، آنان را گرداگرد دوزخ حاضر خواهيم كرد.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmcccxix{آنگاه از هر دسته‌اى، كسانى از آنان را كه بر [خداى‌] رحمان سركش‌تر بوده‌اند، بيرون خواهيم كشيد.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmcccxx{پس از آن، به كسانى كه براى درآمدن به [جهنّم‌] سزاوارترند خود داناتريم.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmcccxxi{و هيچ كس از شما نيست مگر [اينكه‌] در آن وارد مى‌گردد. اين [امر] همواره بر پروردگارت حكمى قطعى است.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmcccxxii{آنگاه كسانى را كه پرهيزگار بوده‌اند مى‌رهانيم، و ستمگران را به زانو درافتاده در [دوزخ‌] رها مى‌كنيم.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmcccxxiii{و چون آيات روشن ما بر آنان خوانده شود، كسانى كه كفر ورزيده‌اند به آنان كه ايمان آورده‌اند مى‌گويند: «كدام يك از [ما] دو گروه جايگاهش بهتر و محفلش آراسته‌تر است؟»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmcccxxiv{و چه بسيار نسلها را پيش از آنان نابود كرديم، كه اثاثى بهتر و ظاهرى فريباتر داشتند.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmcccxxv{بگو: «هر كه در گمراهى است [خداى‌] رحمان به او تا زمانى مهلت مى‌دهد، تا وقتى آنچه به آنان وعده داده مى‌شود: يا عذاب، يا روز رستاخيز را ببينند؛ پس به زودى خواهند دانست جايگاه چه كسى بدتر و سپاهش ناتوان‌تر است.»\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmcccxxvi{و خداوند كسانى را كه هدايت يافته‌اند بر هدايتشان مى‌افزايد، و نيكيهاى ماندگار، نزد پروردگارت از حيث پاداش بهتر و خوش‌فرجام‌تر است.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmcccxxvii{آيا ديدى آن كسى را كه به آيات ما كفر ورزيد و گفت: «قطعاً به من مال و فرزند [بسيار] داده خواهد شد»؟\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmcccxxviii{آيا بر غيب آگاه شده يا از [خداى‌] رحمان عهدى گرفته است؟\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmcccxxix{نه چنين است. به زودى آنچه را مى‌گويد، مى‌نويسيم و عذاب را براى او خواهيم افزود.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmcccxxx{و آنچه را مى‌گويد، از او به ارث مى‌بريم و تنها به سوى ما خواهد آمد.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmcccxxxi{و به جاى خدا، معبودانى اختيار كردند تا براى آنان [مايه‌] عزّت باشد.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmcccxxxii{نه چنين است. به زودى [آن معبودان‌] عبادت ايشان را انكار مى‌كنند و دشمن آنان مى‌گردند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmcccxxxiii{آيا ندانستى كه ما شيطانها را بر كافران گماشته‌ايم، تا آنان را [به گناهان‌] تحريك كنند؟\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmcccxxxiv{پس بر ضد آنان شتاب مكن، كه ما [روزها] را براى آنها شماره مى‌كنيم.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmcccxxxv{[ياد كن‌] روزى را كه پرهيزگاران را به سوى [خداى‌] رحمان گروه گروه محشور مى‌كنيم.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmcccxxxvi{و مجرمان را با حال تشنگى به سوى دوزخ مى‌رانيم.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmcccxxxvii{[آنان‌] اختيار شفاعت را ندارند، جز آن كس كه از جانب [خداى‌] رحمان پيمانى گرفته است.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmcccxxxviii{و گفتند: «[خداى‌] رحمان فرزندى اختيار كرده است.»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmcccxxxix{واقعاً چيز زشتى را [بر زبان‌] آورديد.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmcccxl{چيزى نمانده است كه آسمانها از اين [سخن‌] بشكافند و زمين چاك خورد و كوهها به شدت فرو ريزند.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmcccxli{از اينكه براى [خداى‌] رحمان فرزندى قايل شدند.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmcccxlii{[خداى‌] رحمان را نسزد كه فرزندى اختيار كند.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmcccxliii{هر كه در آسمانها و زمين است جز بنده‌وار به سوى [خداى‌] رحمان نمى‌آيد.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmcccxliv{و يقيناً آنها را به حساب آورده و به دقت شماره كرده است.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmcccxlv{و روز قيامت همه آنها تنها، به سوى او خواهند آمد.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmcccxlvi{كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، به زودى [خداى‌] رحمان براى آنان محبتى [در دلها] قرار مى‌دهد.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmcccxlvii{در حقيقت، ما اين [قرآن‌] را بر زبان تو آسان ساختيم تا پرهيزگاران را بدان نويد، و مردم ستيزه‌جو را بدان بيم دهى.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mmcccxlviii{و چه بسيار نسلها كه پيش از آنان هلاك كرديم. آيا كسى از آنان را مى‌يابى يا صدايى از ايشان مى‌شنوى؟\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mmcccxlix{\basmalahfa طه.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmcccl{قرآن را بر تو نازل نكرديم تا به رنج افتى،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmcccli{جز اينكه براى هر كه مى‌ترسد، پندى باشد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmccclii{[كتابى است‌] نازل شده از جانب كسى كه زمين و آسمانهاى بلند را آفريده است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmcccliii{خداى رحمان كه بر عرش استيلا يافته است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmcccliv{آنچه در آسمانها و آنچه در زمين و آنچه ميان آن دو و آنچه زير خاك است از آنِ اوست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmccclv{و اگر سخن به آواز گويى، او نهان و نهان‌تر را مى‌داند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmccclvi{خدايى كه جز او معبودى نيست [و] نامهاى نيكو به او اختصاص دارد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmccclvii{و آيا خبر موسى به تو رسيد؟\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmccclviii{هنگامى كه آتشى ديد، پس به خانواده خود گفت: «درنگ كنيد، زيرا من آتشى ديدم، اميد كه پاره‌اى از آن براى شما بياورم يا در پرتو آتش راه [خود را باز] يابم.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmccclix{پس چون بدان رسيد، ندا داده شد كه: «اى موسى،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmccclx{اين منم پروردگار تو، پاى‌پوش خويش بيرون آور كه تو در وادى مقدس «طُوى‌» هستى.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmccclxi{و من تو را برگزيده‌ام، پس بدانچه وحى مى‌شود گوش فرا ده.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmccclxii{منم، من، خدايى كه جز من خدايى نيست، پس مرا پرستش كن و به ياد من نماز برپا دار.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmccclxiii{در حقيقت، قيامت فرارسنده است. مى‌خواهم آن را پوشيده دارم، تا هر كسى به [موجب‌] آنچه مى‌كوشد جزا يابد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmccclxiv{پس هرگز نبايد كسى كه به آن ايمان ندارد و از هوس خويش پيروى كرده است، تو را از [ايمان به‌] آن باز دارد، كه هلاك خواهى شد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmccclxv{و اى موسى، در دست راست تو چيست؟»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmccclxvi{گفت: «اين عصاى من است، بر آن تكيه مى‌دهم و با آن براى گوسفندانم برگ مى تكانم، و كارهاى ديگرى هم براى من از آن برمى‌آيد.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmccclxvii{فرمود: «اى موسى، آن را بينداز.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmccclxviii{پس آن را انداخت و ناگاه مارى شد كه به سرعت مى‌خزيد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmccclxix{فرمود: «آن را بگير و مترس، به زودى آن را به حال نخستينش بازخواهيم گردانيد،\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmccclxx{و دست خود را به پهلويت ببر، سپيد بى‌گزند برمى‌آيد، [اين‌] معجزه‌اى ديگر است،\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmccclxxi{تا به تو معجزات بزرگ خود را بنمايانيم.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmccclxxii{به سوى فرعون برو كه او به سركشى برخاسته است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmccclxxiii{گفت: «پروردگارا، سينه‌ام را گشاده گردان،\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmccclxxiv{و كارم را براى من آسان ساز،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmccclxxv{و از زبانم گره بگشاى،\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmccclxxvi{[تا] سخنم را بفهمند،\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmccclxxvii{و براى من دستيارى از كسانم قرار ده،\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmccclxxviii{هارون برادرم را،\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmccclxxix{پشتم را به او استوار كن،\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmccclxxx{و او را شريك كارم گردان،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmccclxxxi{تا تو را فراوان تسبيح گوييم،\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmccclxxxii{و بسيار به ياد تو باشيم،\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmccclxxxiii{زيرا تو همواره به [حال‌] ما بينايى.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmccclxxxiv{فرمود: «اى موسى، خواسته‌ات به تو داده شد.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmccclxxxv{و به راستى، بار ديگر [هم‌] بر تو منت نهاديم،\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmccclxxxvi{هنگامى كه به مادرت آنچه را كه [بايد] وحى مى‌شد وحى كرديم:\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmccclxxxvii{كه او را در صندوقچه‌اى بگذار، سپس در دريايش افكن تا دريا [=رود نيل‌] او را به كرانه اندازد [و] دشمن من و دشمن وى، او را برگيرد. و مِهرى از خودم بر تو افكندم تا زير نظر من پرورش يابى.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmccclxxxviii{آنگاه كه خواهر تو مى‌رفت و مى‌گفت: آيا شما را بر كسى كه عهده‌دار او گردد دلالت كنم؟ پس تو را به سوى مادرت بازگردانيديم تا ديده‌اش روشن شود و غم نخورد، و [سپس‌] شخصى را كُشتى و [ما] تو را از اندوه رهانيديم، و تو را بارها آزموديم، و سالى چند در ميان اهل «مدين» ماندى، سپس اى موسى در زمان مقدر [و مقتضى‌] آمدى.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmccclxxxix{و تو را براى خود پروردم.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmcccxc{تو و برادرت معجزه‌هاى مرا [براى مردم‌] ببريد و در يادكردن من سستى مكنيد.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmcccxci{به سوى فرعون برويد كه او به سركشى برخاسته،\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmcccxcii{و با او سخنى نرم گوييد، شايد كه پند پذيرد يا بترسد.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmcccxciii{آن دو گفتند: «پروردگارا، ما مى‌ترسيم كه [او] آسيبى به ما برساند يا آنكه سركشى كند.»\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmcccxciv{فرمود: «مترسيد، من همراه شمايم، مى‌شنوم و مى‌بينم،\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmcccxcv{پس به سوى او برويد و بگوييد: ما دو فرستاده پروردگار توايم، پس فرزندان اسرائيل را با ما بفرست، و عذابشان مكن، به راستى ما براى تو از جانب پروردگارت معجزه‌اى آورده‌ايم، و بر هر كس كه از هدايت پيروى كند درود باد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmcccxcvi{در حقيقت به سوى ما وحى آمده كه عذاب بر كسى است كه تكذيب كند و روى گرداند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmcccxcvii{[فرعون‌] گفت: «اى موسى، پروردگار شما دو تن كيست؟»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmcccxcviii{گفت: «پروردگار ما كسى است كه هر چيزى را خلقتى كه درخور اوست داده، سپس آن را هدايت فرموده است.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmcccxcix{گفت: «حال نسلهاى گذشته چون است؟»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmcd{گفت: «علم آن، در كتابى نزد پروردگار من است. پروردگارم نه خطا مى‌كند و نه فراموش مى‌نمايد.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmcdi{همان كسى كه زمين را برايتان گهواره‌اى ساخت، و براى شما در آن، راهها ترسيم كرد و از آسمان آبى فرود آورد، پس به وسيله آن رستنيهاى گوناگون، جفت جفت بيرون آورديم.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmcdii{بخوريد و دامهايتان را بچرانيد كه قطعاً در اينها براى خردمندان نشانه‌هايى است.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmcdiii{از اين [زمين‌] شما را آفريده‌ايم، در آن شما را بازمى‌گردانيم و بار ديگر شما را از آن بيرون مى‌آوريم.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmcdiv{در حقيقت، [ما] همه آيات خود را به [فرعون‌] نشان داديم، ولى [او آنها را] دروغ پنداشت و نپذيرفت.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmcdv{گفت: «اى موسى، آمده‌اى تا با سحر خود، ما را از سرزمينمان بيرون كنى؟\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmcdvi{ما [هم‌] قطعاً براى تو سحرى مثل آن خواهيم آورد، پس ميان ما و خودت موعدى بگذار كه نه ما آن را خلاف كنيم و نه تو، [آن هم‌] در جايى هموار.»\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmcdvii{[موسى‌] گفت: «موعد شما روز جشن باشد كه مردم پيش از ظهر گرد مى‌آيند.»\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmcdviii{پس فرعون رفت و [همه‌] نيرنگ خود را گرد آورد و بازآمد.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmcdix{موسى به [ساحران‌] گفت: «واى بر شما، به خدا دروغ مبنديد كه شما را به عذابى [سخت‌] هلاك مى‌كند، و هر كه دروغ بندد نوميد مى‌گردد.»\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmcdx{[ساحران‌] ميان خود، در باره كارشان به نزاع برخاستند و به نجوا پرداختند.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmcdxi{[فرعونيان‌] گفتند: «قطعاً اين دو تن ساحرند [و] مى‌خواهند شما را با سحر خود از سرزمينتان بيرون كنند، و آيين والاى شما را براندازند.»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmcdxii{پس نيرنگ خود را گرد آوريد و به صف پيش آييد. در حقيقت، امروز هر كه فايق آيد خوشبخت مى‌شود.»\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmcdxiii{[ساحران‌] گفتند: «اى موسى، يا تو مى‌افكنى يا [ما] نخستين كس باشيم كه مى اندازيم؟»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmcdxiv{گفت: «[نه،] بلكه شما بيندازيد.» پس ناگهان ريسمانها و چوبدستى‌هايشان، بر اثر سِحْرشان، در خيال او، [چنين‌] مى‌نمود كه آنها به شتاب مى‌خزند.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmcdxv{و موسى در خود بيمى احساس كرد.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmcdxvi{گفتيم: «مترس كه تو خود برترى؛\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmcdxvii{و آنچه در دست راست دارى بينداز، تا هر چه را ساخته‌اند ببلعد. در حقيقت، آنچه سرهم‌بندى كرده‌اند، افسون افسونگر است، و افسونگر هر جا برود رستگار نمى شود.»\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmcdxviii{پس ساحران به سجده درافتادند. گفتند: «به پروردگار موسى و هارون ايمان آورديم.»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmcdxix{[فرعون‌] گفت: «آيا پيش از آنكه به شما اجازه دهم، به او ايمان آورديد؟ قطعاً او بزرگ شماست كه به شما سحر آموخته است، پس بى‌شك دستهاى شما و پاهايتان را يكى از راست و يكى از چپ قطع مى‌كنم و شما را بر تنه‌هاى درخت خرما به دار مى‌آويزم، تا خوب بدانيد عذاب كدام يك از ما سخت‌تر و پايدارتر است.»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmcdxx{گفتند: «ما هرگز تو را بر معجزاتى كه به سوى ما آمده و [بر] آن كس كه ما را پديد آورده است، ترجيح نخواهيم داد؛ پس هر حكمى مى‌خواهى بكن كه تنها در اين زندگى دنياست كه [تو] حكم مى‌رانى.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmcdxxi{ما به پروردگارمان ايمان آورديم، تا گناهان ما و آن سحرى كه ما را بدان واداشتى بر ما ببخشايد، و خدا بهتر و پايدارتر است.»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmcdxxii{در حقيقت، هر كه به نزد پروردگارش گنهكار رود، جهنم براى اوست. در آن نه مى‌ميرد و نه زندگى مى‌يابد.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmcdxxiii{و هر كه مؤمن به نزد او رود، در حالى كه كارهاى شايسته انجام داده باشد، براى آنان درجات والا خواهد بود:\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmcdxxiv{بهشتهاى عدن كه از زير [درختان‌] آن جويبارها روان است. جاودانه در آن مى‌مانند، و اين است پاداش كسى كه به پاكى گرايد.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmcdxxv{و در حقيقت به موسى وحى كرديم كه: «بندگانم را شبانه ببر، و راهى خشك در دريا براى آنان باز كن كه نه از فرارسيدن [دشمن‌] بترسى و نه [از غرق‌شدن‌] بيمناك باشى.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmcdxxvi{پس فرعون با لشكريانش آنها را دنبال كرد، و[لى‌] از دريا آنچه آنان را فرو پوشانيد، فرو پوشانيد.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmcdxxvii{و فرعون قوم خود را گمراه كرد و هدايت ننمود.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmcdxxviii{«اى فرزندان اسرائيل، در حقيقت، [ما] شما را از [دست‌] دشمنتان رهانيديم، و در جانب راست طور با شما وعده نهاديم و بر شما ترنجبين و بلدرچين فرو فرستاديم.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmcdxxix{از خوراكيهاى پاكيزه‌اى كه روزى شما كرديم، بخوريد و[لى‌] در آن زياده‌روى مكنيد كه خشم من بر شما فرود آيد، و هر كس خشم من بر او فرود آيد، قطعاً در [ورطه‌] هلاكت افتاده است.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmcdxxx{و به يقين، من آمرزنده كسى هستم كه توبه كند و ايمان بياورد و كار شايسته نمايد و به راه راست راهسپر شود.»\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmcdxxxi{«و اى موسى، چه چيز تو را [دور] از قوم خودت، به شتاب واداشته است؟»\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmcdxxxii{گفت: «اينان در پى منند، و من -اى پروردگارم- به سويت شتافتم تا خشنود شوى.»\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmcdxxxiii{فرمود: «در حقيقت، ما قوم تو را پس از [عزيمت‌] تو آزموديم و سامرى آنها را گمراه ساخت.»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmcdxxxiv{پس موسى خشمگين و اندوهناك به سوى قوم خود برگشت [و] گفت: «اى قوم من، آيا پروردگارتان به شما وعده نيكو نداد؟ آيا اين مدت بر شما طولانى مى‌نمود، يا خواستيد خشمى از پروردگارتان بر شما فرود آيد كه با وعده من مخالفت كرديد؟»\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmcdxxxv{گفتند: «ما به اختيار خود با تو خلاف وعده نكرديم، ولى از زينت‌آلات قوم، بارهايى سنگين بر دوش داشتيم و آنها را افكنديم و [خود] سامرى [هم زينت‌آلاتش را] همين گونه بينداخت.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmcdxxxvi{پس براى آنان پيكر گوساله‌اى كه صدايى داشت بيرون آورد، و [او و پيروانش‌] گفتند: «اين خداى شما و خداى موسى است، و [پيمان خدا را] فراموش كرد.»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmcdxxxvii{مگر نمى‌بينند كه [گوساله‌] پاسخ سخن آنان را نمى‌دهد و به حالشان سود و زيانى ندارد؟\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmcdxxxviii{و در حقيقت، هارون قبلا به آنان گفته بود: «اى قوم من، شما به وسيله اين [گوساله‌] مورد آزمايش قرار گرفته‌ايد، و پروردگار شما [خداى‌] رحمان است، پس مرا پيروى كنيد و فرمان مرا پذيرا باشيد.»\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmcdxxxix{گفتند: «ما هرگز از پرستش آن دست بر نخواهيم داشت تا موسى به سوى ما بازگردد.»\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmcdxl{[موسى‌] گفت: «اى هارون، وقتى ديدى آنها گمراه شدند چه چيز مانع تو شد،\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmcdxli{كه از من پيروى كنى؟ آيا از فرمانم سر باز زدى؟»\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmcdxlii{گفت: «اى پسر مادرم، نه ريش مرا بگير و نه [موى‌] سرم را، من ترسيدم بگويى: ميان بنى‌اسرائيل تفرقه انداختى و سخنم را مراعات نكردى.»\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmcdxliii{[موسى‌] گفت: «اى سامرى، منظور تو چه بود؟»\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmcdxliv{گفت: «به چيزى كه [ديگران‌] به آن پى نبردند، پى بردم، و به قدر مشتى از رد پاى فرستاده [خدا، جبرئيل‌] برداشتم و آن را در پيكر [گوساله‌] انداختم، و نفس من برايم چنين فريبكارى كرد.»\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmcdxlv{گفت: «پس برو كه بهره تو در زندگى اين باشد كه [به هر كه نزديك تو آمد] بگويى: [به من‌] دست مزنيد و تو را موعدى خواهد بود كه هرگز از آن تخلف نخواهى كرد، و [اينك‌] به آن خدايى كه پيوسته ملازمش بودى بنگر، آن را قطعاً مى‌سوزانيم و خاكسترش مى‌كنيم [و] در دريا فرو مى‌پاشيم.»\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mmcdxlvi{«معبود شما تنها آن خدايى است كه جز او معبودى نيست، و دانش او همه چيز را در بر گرفته است.»\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mmcdxlvii{اين گونه از اخبار پيشين بر تو حكايت مى‌رانيم، و مسلماً به تو از جانب خود قرآنى داده‌ايم.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mmcdxlviii{هر كس از [پيروى‌] آن روى برتابد، روز قيامت بار گناهى بر دوش مى‌گيرد.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mmcdxlix{پيوسته در آن [حال‌] مى‌ماند، و چه بد بارى روز قيامت خواهند داشت.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mmcdl{[همان‌] روزى كه در صور دميده مى‌شود، و در آن روز مجرمان را كبودچشم برمى‌انگيزيم.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mmcdli{ميان خود به طور پنهانى با يكديگر مى‌گويند: «شما [در دنيا] جز ده [روز، بيش‌] نمانده‌ايد.»\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mmcdlii{ما داناتريم به آنچه مى‌گويند، آنگاه كه نيك‌آيين‌ترين آنان مى‌گويد: «جز يك روز، بيش نمانده‌ايد.»\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mmcdliii{و از تو در باره كوهها مى‌پرسند، بگو: «پروردگارم آنها را [در قيامت‌] ريز ريز خواهد ساخت،\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mmcdliv{پس آنها را پهن و هموار خواهد كرد،\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mmcdlv{نه در آن كژى مى‌بينى و نه ناهموارى.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mmcdlvi{در آن روز، [همه مردم‌]، داعى [حق‌] را -كه هيچ انحرافى در او نيست- پيروى مى‌كنند، و صداها در مقابل [خداى‌] رحمان خاشع مى‌گردد، و جز صدايى آهسته نمى‌شنوى.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mmcdlvii{در آن روز، شفاعت [به كسى‌] سود نبخشد، مگر كسى را كه [خداى‌] رحمان اجازه دهد و سخنش او را پسند آيد.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mmcdlviii{آنچه را كه آنان در پيش دارند و آنچه را كه پشت سر گذاشته‌اند مى‌داند، و حال آنكه ايشان بدان دانشى ندارند.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mmcdlix{و چهره‌ها براى آن [خداى‌] زنده پاينده خضوع مى‌كنند، و آن كس كه ظلمى بر دوش دارد نوميد مى‌ماند.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mmcdlx{و هر كس كارهاى شايسته كند، در حالى كه مؤمن باشد، نه از ستمى مى‌هراسد و نه از كاسته شدن [حقّش‌].\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mmcdlxi{و اين گونه آن را [به صورت‌] قرآنى عربى نازل كرديم، و در آن از انواع هشدارها سخن آورديم، شايد آنان راه تقوا در پيش گيرند، يا [اين كتاب‌] پندى تازه براى آنان بياورد.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@mmcdlxii{پس بلندمرتبه است خدا، فرمانرواى بر حق، و در [خواندن‌] قرآن، پيش از آنكه وحى آن بر تو پايان يابد، شتاب مكن، و بگو: «پروردگارا، بر دانشم بيفزاى.»\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@mmcdlxiii{و به يقين پيش از اين با آدم پيمان بستيم، و[لى آن را] فراموش كرد، و براى او عزمى [استوار] نيافتيم.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@mmcdlxiv{و [ياد كن‌] هنگامى را كه به فرشتگان گفتيم: «براى آدم سجده كنيد.» پس، جز ابليس كه سر باز زد [همه‌] سجده كردند.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@mmcdlxv{پس گفتيم: «اى آدم، در حقيقت، اين [ابليس‌] براى تو و همسرت دشمنى [خطرناك‌] است، زنهار تا شما را از بهشت به در نكند تا تيره‌بخت گردى.»\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@mmcdlxvi{در حقيقت براى تو در آنجا اين [امتياز] است كه نه گرسنه مى‌شوى و نه برهنه مى‌مانى.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@mmcdlxvii{و [هم‌] اينكه در آنجا نه تشنه مى‌گردى و نه آفتاب‌زده.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@mmcdlxviii{پس شيطان او را وسوسه كرد، گفت: «اى آدم، آيا تو را به درخت جاودانگى و مُلكى كه زايل نمى‌شود، راه نمايم؟»\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@mmcdlxix{آنگاه از آن [درخت ممنوع‌] خوردند و برهنگى آنان برايشان نمايان شد و شروع كردند به چسبانيدن برگهاى بهشت بر خود. و [اين گونه‌] آدم به پروردگار خود عصيان ورزيد و بيراهه رفت.\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@mmcdlxx{سپس پروردگارش او را برگزيد و بر او ببخشود و [وى را] هدايت كرد.\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@mmcdlxxi{فرمود: «همگى از آن [مقام‌] فرود آييد، در حالى كه بعضى از شما دشمن بعضى ديگر است، پس اگر براى شما از جانب من رهنمودى رسد، هر كس از هدايتم پيروى كند نه گمراه مى‌شود و نه تيره‌بخت.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@mmcdlxxii{و هر كس از ياد من دل بگرداند، در حقيقت، زندگى تنگ [و سختى‌] خواهد داشت، و روز رستاخيز او را نابينا محشور مى‌كنيم.»\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@mmcdlxxiii{مى‌گويد: «پروردگارا، چرا مرا نابينا محشور كردى با آنكه بينا بودم؟»\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@mmcdlxxiv{مى‌فرمايد: «همان طور كه نشانه‌هاى ما بر تو آمد و آن را به فراموشى سپردى، امروز همان گونه فراموش مى‌شوى.»\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@mmcdlxxv{و اين گونه هر كه را به افراط گراييده و به نشانه‌هاى پروردگارش نگرويده است سزا مى‌دهيم، و قطعاً شكنجه آخرت سخت‌تر و پايدارتر است.\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@mmcdlxxvi{آيا براى هدايتشان كافى نبود كه [ببينند] چه نسلها را پيش از آنان نابود كرديم كه [اينك آنها] در سراهاى ايشان راه مى‌روند؟ به راستى براى خردمندان در اين [امر] نشانه‌هايى [عبرت‌انگيز] است.\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@mmcdlxxvii{و اگر سخنى از پروردگارت پيشى نگرفته و موعدى معين مقرر نشده بود، قطعاً [عذاب آنها] لازم مى‌آمد.\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@mmcdlxxviii{پس بر آنچه مى‌گويند شكيبا باش، و پيش از بر آمدن آفتاب و قبل از فرو شدن آن، با ستايش پروردگارت [او را] تسبيح گوى، و برخى از ساعات شب و حوالى روز را به نيايش پرداز، باشد كه خشنود گردى.\qt@no{(130)}}
\qt@newcmd\qurantrans@fa@mmcdlxxix{و زنهار به سوى آنچه اصنافى از ايشان را از آن برخوردار كرديم [و فقط] زيور زندگى دنياست تا ايشان را در آن بيازماييم، ديدگان خود مدوز، و [بدان كه‌] روزىِ پروردگار تو بهتر و پايدارتر است.\qt@no{(131)}}
\qt@newcmd\qurantrans@fa@mmcdlxxx{و كسان خود را به نماز فرمان ده و خود بر آن شكيبا باش. ما از تو جوياى روزى نيستيم، ما به تو روزى مى‌دهيم، و فرجام [نيك‌] براى پرهيزگارى است.\qt@no{(132)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxi{و گفتند: «چرا از جانب پروردگارش معجزه‌اى براى ما نمى‌آورد؟» آيا دليل روشن آنچه در صحيفه‌هاى پيشين است براى آنان نيامده است؟\qt@no{(133)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxii{و اگر ما آنان را قبل از [آمدن قرآن‌] به عذابى هلاك مى‌كرديم، قطعاً مى‌گفتند: «پروردگارا، چرا پيامبرى به سوى ما نفرستادى تا پيش از آنكه خوار و رسوا شويم از آيات تو پيروى كنيم؟»\qt@no{(134)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxiii{بگو: «همه در انتظارند. پس در انتظار باشيد. زودا كه بدانيد ياران راه راست كيانند و چه كسى راه‌يافته است.»\qt@no{(135)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxiv{\basmalahfa براى مردم [وقت‌] حسابشان نزديك شده است، و آنان در بى‌خبرى رويگردانند.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxv{هيچ پند تازه‌اى از پروردگارشان نيامد، مگر اينكه بازى‌كنان آن را شنيدند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxvi{در حالى كه دلهايشان مشغول است. و آنانكه ستم كردند پنهانى به نجوا برخاستند كه: «آيا اين [مرد] جز بشرى مانند شماست؟ آيا ديده و دانسته به سوى سحر مى‌رويد؟»\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxvii{[پيامبر] گفت: «پروردگارم [هر] گفتار[ى‌] را در آسمان و زمين مى‌داند، و اوست شنواى دانا.»\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxviii{بلكه گفتند: «خوابهاى شوريده است، [نه‌] بلكه آن را بربافته، بلكه او شاعرى است. پس همان گونه كه براى پيشينيان هم عرضه شد، بايد براى ما نشانه‌اى بياورد.»\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmcdlxxxix{قبل از آنان [نيز مردم‌] هيچ شهرى -كه آن را نابود كرديم- [به آيات ما] ايمان نياوردند. پس آيا اينان [به معجزه‌] ايمان مى‌آورند؟\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmcdxc{و پيش از تو [نيز] جز مردانى را كه به آنان وحى مى‌كرديم گسيل نداشتيم. اگر نمى‌دانيد از پژوهندگان كتابهاى آسمانى بپرسيد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmcdxci{و ايشان را جسدى كه غذا نخورند قرار نداديم و جاويدان [هم‌] نبودند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmcdxcii{سپس وعده [خود] به آنان را راست گردانيديم و آنها و هر كه را خواستيم نجات داديم و افراطكاران را به هلاكت رسانيديم.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmcdxciii{در حقيقت، ما كتابى به سوى شما نازل كرديم كه ياد شما در آن است. آيا نمى‌انديشيد؟\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmcdxciv{و چه بسيار شهرها را كه [مردمش‌] ستمكار بودند در هم شكستيم، و پس از آنها قومى ديگر پديد آورديم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmcdxcv{پس چون عذاب ما را احساس كردند، بناگاه از آن مى‌گريختند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmcdxcvi{[هان‌] مگريزيد، و به سوى آنچه در آن متنعّم بوديد و [به سوى‌] سراهايتان بازگرديد، باشد كه شما مورد پرسش قرار گيريد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmcdxcvii{گفتند: «اى واى بر ما، كه ما واقعاً ستمگر بوديم.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmcdxcviii{سخنشان پيوسته همين بود، تا آنان را دروشده بى‌جان گردانيديم.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmcdxcix{و آسمان و زمين و آنچه را كه ميان آن دو است به بازيچه نيافريديم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmd{اگر مى‌خواستيم بازيچه‌اى بگيريم، قطعاً آن را از پيش خود اختيار مى‌كرديم.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmdi{بلكه حق را بر باطل فرو مى‌افكنيم، پس آن را در هم مى‌شكند، و بناگاه آن نابود مى‌گردد. واى بر شما از آنچه وصف مى‌كنيد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmdii{و هر كه در آسمانها و زمين است براى اوست، و كسانى كه نزد اويند از پرستش وى تكبّر نمى‌ورزند و درمانده نمى‌شوند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmdiii{شبانه روز، بى‌آنكه سستى ورزند، نيايش مى‌كنند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmdiv{آيا براى خود خدايانى از زمين اختيار كرده‌اند كه آنها [مردگان را] زنده مى‌كنند؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmdv{اگر در آنها [=زمين و آسمان‌] جز خدا، خدايانى [ديگر] وجود داشت، قطعاً [زمين و آسمان‌] تباه مى‌شد. پس منزّه است خدا، پروردگار عرش، از آنچه وصف مى‌كنند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmdvi{در آنچه [خدا] انجام مى‌دهد چون و چرا راه ندارد، و[لى‌] آنان [=انسانها] سؤال خواهند شد.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmdvii{آيا به جاى او خدايانى براى خود گرفته‌اند؟ بگو: «برهانتان را بياوريد.» اين است يادنامه هر كه با من است و يادنامه هر كه پيش از من بوده. [نه!] بلكه بيشترشان حق را نمى‌شناسند و در نتيجه از آن رويگردانند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmdviii{و پيش از تو هيچ پيامبرى نفرستاديم مگر اينكه به او وحى كرديم كه: «خدايى جز من نيست، پس مرا بپرستيد.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmdix{و گفتند: «[خداى‌] رحمان فرزندى اختيار كرده.» منزّه است او. بلكه [فرشتگان‌] بندگانى ارجمندند،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmdx{كه در سخن بر او پيشى نمى‌گيرند، و خود به دستور او كار مى‌كنند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmdxi{آنچه فراروى آنان و آنچه پشت سرشان است مى‌داند، و جز براى كسى كه [خدا] رضايت دهد، شفاعت نمى‌كنند و خود از بيم او هراسانند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmdxii{و هر كس از آنان بگويد: «من [نيز] جز او خدايى هستم»، او را به دوزخ كيفر مى‌دهيم. [آرى‌] سزاى ستمكاران را اين گونه مى‌دهيم.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmdxiii{آيا كسانى كه كفر ورزيدند ندانستند كه آسمانها و زمين هر دو به هم پيوسته بودند، و ما آن دو را از هم جدا ساختيم، و هر چيز زنده‌اى را از آب پديد آورديم؟ آيا [باز هم‌] ايمان نمى‌آورند؟\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmdxiv{و در زمين كوههايى استوار نهاديم تا مبادا [زمين‌] آنان [=مردم‌] را بجنباند، و در آن راههايى فراخ پديد آورديم، باشد كه راه يابند.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmdxv{و آسمان را سقفى محفوظ قرار داديم، و[لى‌] آنان از [مطالعه در] نشانه‌هاى آن اِعراض مى‌كنند.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmdxvi{و اوست آن كسى كه شب و روز و خورشيد و ماه را پديد آورده است. هر كدام از اين دو در مدارى [معيّن‌] شناورند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmdxvii{و پيش از تو براى هيچ بشرى جاودانگى [در دنيا] قرار نداديم. آيا اگر تو از دنيا بروى آنان جاويدانند؟\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmdxviii{هر نفسى چشنده مرگ است، و شما را از راه آزمايش به بد و نيك خواهيم آزمود، و به سوى ما بازگردانيده مى‌شويد.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmdxix{و كسانى كه كافر شدند، چون تو را ببينند فقط به مسخره‌ات مى‌گيرند [و مى‌گويند:] «آيا اين همان كس است كه خدايانتان را [به بدى‌] ياد مى‌كند؟» در حالى كه آنان خود، ياد [خداى‌] رحمان را منكرند.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmdxx{انسان از شتاب آفريده شده است. به زودى آياتم را به شما نشان مى‌دهم. پس [عذاب را] به شتاب از من مخواهيد.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmdxxi{و مى‌گويند: «اگر راست مى‌گوييد، اين وعده [قيامت‌] كى خواهد بود؟»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmdxxii{كاش آنان كه كافر شده‌اند مى‌دانستند آنگاه كه آتش را نه از چهره‌هاى خود و نه از پشتشان بازنمى‌توانند داشت، و خود مورد حمايت قرار نمى‌گيرند [چه حالى خواهند داشت‌].\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmdxxiii{بلكه [آتش‌] به طور ناگهانى به آنان مى‌رسد و ايشان را بهت‌زده مى‌كند [به گونه‌اى‌] كه نه مى‌توانند آن را برگردانند و نه به آنان مهلت داده مى‌شود.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmdxxiv{و مسلمّاً پيامبران پيش از تو [نيز] مورد ريشخند قرار گرفتند، پس كسانى كه آنان را مسخره مى‌كردند، [سزاى‌] آنچه كه آن را به ريشخند مى‌گرفتند گريبانگيرشان شد.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmdxxv{بگو: «چه كسى شما را شب و روز از [عذاب‌] رحمان حفظ مى‌كند؟» [نه‌] بلكه آنان از ياد پروردگارشان رويگردانند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmdxxvi{[34]آيا براى آنان خدايانى غير از ماست كه از ايشان حمايت كنند؟ [آن خدايان‌] نه مى‌توانند خود را يارى كنند و نه از جانب ما يارى شوند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmdxxvii{[نه‌] بلكه اينها و پدرانشان را برخوردار كرديم تا عمرشان به درازا كشيد. آيا نمى‌بينند كه ما مى‌آييم و زمين را از جوانب آن فرو مى‌كاهيم؟ آيا باز هم آنان پيروزند؟\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmdxxviii{بگو: «من شما را فقط به وسيله وحى هشدار مى‌دهم.» و[لى‌] چون كران بيم داده شوند، دعوت را نمى‌شنوند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmdxxix{و اگر شمه‌اى از عذاب پروردگارت به آنان برسد، خواهند گفت: «اى واى بر ما كه ستمكار بوديم.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmdxxx{و ترازوهاى داد را در روز رستاخيز مى‌نهيم، پس هيچ كس [در] چيزى ستم نمى‌بيند، و اگر [عمل‌] هموزن دانه خردلى باشد آن را مى‌آوريم و كافى است كه ما حسابرس باشيم.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmdxxxi{و در حقيقت، به موسى و هارون فرقان داديم و [كتابشان‌] براى پرهيزگاران روشنايى و اندرزى است.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmdxxxii{[همان‌] كسانى كه از پروردگارشان در نهان مى‌ترسند و از قيامت هراسناكند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmdxxxiii{و اين [كتاب‌] -كه آن را نازل كرده‌ايم- پندى خجسته است. آيا باز هم آن را انكار مى‌كنيد؟\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmdxxxiv{و در حقيقت، پيش از آن، به ابراهيم رشد [فكرى‌]اش را داديم و ما به [شايستگى‌] او دانا بوديم.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmdxxxv{آنگاه كه به پدر خود و قومش گفت: «اين مجسمه‌هايى كه شما ملازم آنها شده‌ايد چيستند؟»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmdxxxvi{گفتند: «پدران خود را پرستندگان آنها يافتيم.»\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmdxxxvii{گفت: «قطعاً شما و پدرانتان در گمراهى آشكارى بوديد.»\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmdxxxviii{گفتند: «آيا حق را براى ما آورده‌اى يا تو از شوخى‌كنندگانى؟»\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmdxxxix{گفت: «[نه‌] بلكه پروردگارتان، پروردگار آسمانها و زمين است، همان كسى كه آنها را پديد آورده است، و من بر اين [واقعيت‌] از گواهانم.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmdxl{و سوگند به خدا كه پس از آنكه پشت كرديد و رفتيد، قطعاً در كار بتانتان تدبيرى خواهم كرد.»\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmdxli{پس آنها را -جز بزرگترشان را- ريز ريز كرد، باشد كه ايشان به سراغ آن بروند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmdxlii{گفتند: «چه كسى با خدايان ما چنين [معامله‌اى‌] كرده، كه او واقعاً از ستمكاران است؟»\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmdxliii{گفتند: «شنيديم جوانى، از آنها [به بدى‌] ياد مى‌كرد كه به او ابراهيم گفته مى‌شود.»\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmdxliv{گفتند: «پس او را در برابر ديدگان مردم بياوريد، باشد كه آنان شهادت دهند.»\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmdxlv{گفتند: «اى ابراهيم، آيا تو با خدايان ما چنين كردى؟»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmdxlvi{گفت: «[نه‌] بلكه آن را اين بزرگترشان كرده است، اگر سخن مى‌گويند از آنها بپرسيد.»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmdxlvii{پس به خود آمده و [به يكديگر] گفتند: «در حقيقت، شما ستمكاريد.»\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmdxlviii{سپس سرافكنده شدند [و گفتند:] «قطعاً دانسته‌اى كه اينها سخن نمى‌گويند.»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmdxlix{گفت: «آيا جز خدا چيزى را مى‌پرستيد كه هيچ سود و زيانى به شما نمى‌رساند؟\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmdl{اف بر شما و بر آنچه غير از خدا مى‌پرستيد. مگر نمى‌انديشيد؟»\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmdli{گفتند: «اگر كارى مى‌كنيد، او را بسوزانيد و خدايانتان را يارى دهيد.»\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmdlii{گفتيم: «اى آتش، براى ابراهيم سرد و بى‌آسيب باش.»\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmdliii{و خواستند به او نيرنگى بزنند و[لى‌] آنان را زيانكارترين [مردم‌] قرار داديم.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmdliv{و او و لوط را [براى رفتن‌] به سوى آن سرزمينى كه براى جهانيان در آن بركت نهاده بوديم، رهانيديم.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmdlv{و اسحاق و يعقوب را [به عنوان نعمتى‌] افزون به او بخشوديم و همه را از شايستگان قرار داديم.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmdlvi{و آنان را پيشوايانى قرار داديم كه به فرمان ما هدايت مى‌كردند، و به ايشان انجام دادن كارهاى نيك و برپاداشتن نماز و دادن زكات را وحى كرديم و آنان پرستنده ما بودند.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmdlvii{و به لوط حكمت و دانش عطا كرديم و او را از آن شهرى كه [مردمش‌] كارهاى پليد [جنسى‌] مى‌كردند نجات داديم. به راستى آنها گروه بد و منحرفى بودند.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmdlviii{و او را در رحمت خويش داخل كرديم، زيرا او از شايستگان بود.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmdlix{و نوح را [ياد كن‌] آنگاه كه پيش از [ساير پيامبران‌] ندا كرد، پس ما او را اجابت كرديم، و وى را با خانواده‌اش از بلاى بزرگ رهانيديم.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmdlx{و او را در برابر مردمى كه نشانه‌هاى ما را به دروغ گرفته بودند پيروزى بخشيديم، چرا كه آنان مردم بدى بودند، پس همه ايشان را غرق كرديم.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmdlxi{و داوود و سليمان را [ياد كن‌] هنگامى كه در باره آن كشتزار -كه گوسفندان مردم شب‌هنگام در آن چريده بودند- داورى مى‌كردند، و [ما] شاهد داورى آنان بوديم.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmdlxii{پس آن [داورى‌] را به سليمان فهمانديم، و به هر يك [از آن دو] حكمت و دانش عطا كرديم، و كوهها را با داوود و پرندگان به نيايش واداشتيم، و ما كننده [اين كار] بوديم.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmdlxiii{و به [داوود] فن زره [سازى‌] آموختيم، تا شما را از [خطرات‌] جنگتان حفظ كند. پس آيا شما سپاسگزاريد؟\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmdlxiv{و براى سليمان، تندباد را [رام كرديم‌] كه به فرمان او به سوى سرزمينى كه در آن بركت نهاده بوديم جريان مى‌يافت، و ما به هر چيزى دانا بوديم.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmdlxv{و برخى از شياطين بودند كه براى او غواصى و كارهايى غير از آن مى‌كردند، و ما مراقب [حال‌] آنها بوديم.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmdlxvi{و ايوب را [ياد كن‌] هنگامى كه پروردگارش را ندا داد كه: «به من آسيب رسيده است و تويى مهربانترين مهربانان.»\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmdlxvii{پس [دعاى‌] او را اجابت نموديم و آسيب وارده بر او را برطرف كرديم، و كسان او و نظيرشان را همراه با آنان [مجدداً] به وى عطا كرديم [تا] رحمتى از جانب ما و عبرتى براى عبادت‌كنندگان [باشد].\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmdlxviii{و اسماعيل و ادريس و ذوالكفل را [ياد كن‌] كه همه از شكيبايان بودند.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmdlxix{و آنان را در رحمت خود داخل نموديم، چرا كه ايشان از شايستگان بودند.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmdlxx{و «ذوالنون» را [ياد كن‌] آنگاه كه خشمگين رفت و پنداشت كه ما هرگز بر او قدرتى نداريم، تا در [دل‌] تاريكيها ندا درداد كه: «معبودى جز تو نيست، منزّهى تو، راستى كه من از ستمكاران بودم.»\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmdlxxi{پس [دعاى‌] او را برآورده كرديم و او را از اندوه رهانيديم، و مؤمنان را [نيز] چنين نجات مى‌دهيم.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmdlxxii{و زكريّا را [ياد كن‌] هنگامى كه پروردگار خود را خواند: «پروردگارا، مرا تنها مگذار و تو بهترين ارث برندگانى.»\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmdlxxiii{پس [دعاى‌] او را اجابت نموديم، و يحيى را بدو بخشيديم و همسرش را براى او شايسته [و آماده حمل‌] كرديم، زيرا آنان در كارهاى نيك شتاب مى‌نمودند و ما را از روى رغبت و بيم مى‌خواندند و در برابر ما فروتن بودند.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmdlxxiv{و آن [زن را ياد كن‌] كه خود را پاكدامن نگاه داشت، و از روح خويش در او دميديم و او و پسرش را براى جهانيان آيتى قرار داديم.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmdlxxv{اين است امت شما كه امتى يگانه است، و منم پروردگار شما، پس مرا بپرستيد.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmdlxxvi{و[لى‌] دينشان را ميان خود پاره پاره كردند. همه به سوى ما بازمى‌گردند.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmdlxxvii{پس هر كه كارهاى شايسته انجام دهد و مؤمن [هم‌] باشد، براى تلاش او ناسپاسى نخواهد بود، و ماييم كه به سود او ثبت مى‌كنيم.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmdlxxviii{و بر [مردم‌] شهرى كه آن را هلاك كرده‌ايم، بازگشتشان [به دنيا] حرام است.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmdlxxix{تا وقتى كه يأجوج و مأجوج [راهشان‌] گشوده شود و آنها از هر پشته‌اى بتازند،\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmdlxxx{و وعده حق نزديك گردد، ناگهان ديدگان كسانى كه كفر ورزيده‌اند خيره مى‌شود [و مى‌گويند:] «اى واى بر ما كه از اين [روز] در غفلت بوديم، بلكه ما ستمگر بوديم.»\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mmdlxxxi{در حقيقت، شما و آنچه غير از خدا مى‌پرستيد، هيزم دوزخيد. شما در آن وارد خواهيد شد.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mmdlxxxii{اگر اينها خدايانى [واقعى‌] بودند در آن وارد نمى‌شدند، و حال آنكه جملگى در آن ماندگارند.\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mmdlxxxiii{براى آنها در آنجا ناله‌اى زار است و در آنجا [چيزى‌] نمى‌شنوند.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mmdlxxxiv{بى‌گمان كسانى كه قبلا از جانب ما به آنان وعده نيكو داده شده است از آن [آتش‌] دور داشته خواهند شد.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mmdlxxxv{صداى آن را نمى‌شنوند، و آنان در ميان آنچه دلهايشان بخواهد جاودانند.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mmdlxxxvi{دلهره بزرگ، آنان را غمگين نمى‌كند و فرشتگان از آنها استقبال مى‌كنند [و به آنان مى‌گويند:] اين همان روزى است كه به شما وعده مى‌دادند.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mmdlxxxvii{روزى كه آسمان را همچون در پيچيدن صفحه نامه‌ها در مى‌پيچيم. همان گونه كه بار نخست آفرينش را آغاز كرديم، دوباره آن را بازمى‌گردانيم. وعده‌اى است بر عهده ما، كه ما انجام‌دهنده آنيم.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mmdlxxxviii{و در حقيقت، در زبور پس از تورات نوشتيم كه زمين را بندگان شايسته ما به ارث خواهند برد.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mmdlxxxix{به راستى در اين [امور] براى مردم عبادت‌پيشه ابلاغى [حقيقى‌] است.\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mmdxc{و تو را جز رحمتى براى جهانيان نفرستاديم.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mmdxci{بگو: «جز اين نيست كه به من وحى مى‌شود كه خداى شما خدايى يگانه است. پس آيا مسلمان مى‌شويد؟»\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mmdxcii{پس اگر روى برتافتند بگو: «به [همه‌] شما به طور يكسان اعلام كردم، و نمى‌دانم آنچه وعده داده شده‌ايد آيا نزديك است يا دور.»\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mmdxciii{[آرى،] او سخن آشكار را مى‌داند و آنچه را پوشيده مى‌داريد مى‌داند.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mmdxciv{و نمى‌دانم، شايد آن براى شما آزمايشى و تا چند گاهى [وسيله‌] برخوردارى باشد.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mmdxcv{گفت: «پروردگارا، [خودت‌] به حق داورى كن، و به رغم آنچه وصف مى‌كنيد، پروردگار ما همان بخشايشگر دستگير است.»\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mmdxcvi{\basmalahfa اى مردم، از پروردگار خود پروا كنيد، چرا كه زلزله رستاخيز امرى هولناك است.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmdxcvii{روزى كه آن را ببينيد، هر شيردهنده‌اى آن را كه شير مى‌دهد [از ترس‌] فرو مى‌گذارد، و هر آبستنى بار خود را فرو مى‌نهد، و مردم را مست مى‌بينى و حال آنكه مست نيستند، ولى عذاب خدا شديد است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmdxcviii{و برخى از مردم در باره خدا بدون هيچ علمى مجادله مى‌كنند و از هر شيطان سركشى پيروى مى‌نمايند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmdxcix{بر [شيطان‌] مقرر شده است كه هر كس او را به دوستى گيرد، قطعاً او وى را گمراه مى‌سازد و به عذاب آتشش مى‌كشاند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmdc{اى مردم، اگر در باره برانگيخته شدن در شكّيد، پس [بدانيد] كه ما شما را از خاك آفريده‌ايم، سپس از نطفه، سپس از علقه، آنگاه از مضغه، داراى خلقت كامل و [احياناً] خلقت ناقص، تا [قدرت خود را] بر شما روشن گردانيم. و آنچه را اراده مى‌كنيم تا مدتى معين در رحمها قرار مى‌دهيم، آنگاه شما را [به صورت‌] كودك برون مى‌آوريم، سپس [حيات شما را ادامه مى‌دهيم‌] تا به حد رشدتان برسيد، و برخى از شما [زودرس‌] مى‌ميرد، و برخى از شما به غايت پيرى مى‌رسد به گونه‌اى كه پس از دانستن [بسى چيزها] چيزى نمى‌داند. و زمين را خشكيده مى‌بينى و[لى‌] چون آب بر آن فرود آوريم به جنبش درمى‌آيد و نمو مى‌كند و از هر نوع [رستنيهاى‌] نيكو مى‌روياند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmdci{اين [قدرت نماييها] بدان سبب است كه خدا خود حق است، و اوست كه مردگان را زنده مى‌كند و [هم‌] اوست كه بر هر چيزى تواناست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmdcii{و [هم‌] آنكه رستاخيز آمدنى است [و] شكى در آن نيست، و در حقيقت، خداست كه كسانى را كه در گورهايند برمى‌انگيزد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmdciii{و از [ميان‌] مردم كسى است كه در باره خدا بدون هيچ دانش و بى‌هيچ رهنمود و كتاب روشنى به مجادله مى‌پردازد،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmdciv{[آن هم‌] از سرِ نِخْوت، تا [مردم را] از راه خدا گمراه كند. در اين دنيا براى او رسوايى است، و در روز رستاخيز او را عذاب آتش سوزان مى‌چشانيم.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmdcv{اين [كيفر] به سزاى چيزهايى است كه دستهاى تو پيش فرستاده است و [گرنه‌] خدا به بندگان خود بيدادگر نيست.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmdcvi{و از ميان مردم كسى است كه خدا را فقط بر يك حال [و بدون عمل‌] مى‌پرستد. پس اگر خيرى به او برسد بدان اطمينان يابد، و چون بلايى بدو رسد روى برتابد. در دنيا و آخرت زيان ديده است. اين است همان زيان آشكار.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmdcvii{به جاى خدا چيزى را مى‌خواند كه نه زيانى به او مى‌رساند و نه سودش مى‌دهد. اين است همان گمراهى دور و دراز.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmdcviii{كسى را مى‌خواند كه زيانش از سودش نزديكتر است. وه چه بد مولايى و چه بد دمسازى!\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmdcix{بى‌گمان، خدا كسانى را كه گرويده و كارهاى شايسته كرده‌اند به باغهايى درمى‌آورد كه از زير [درختان‌] آن رودبارها روان است. خدا هر چه بخواهد انجام مى‌دهد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmdcx{هر كه مى‌پندارد كه خدا [پيامبرش‌] را در دنيا و آخرت هرگز يارى نخواهد كرد [بگو] تا طنابى به سوى سقف كشد [و خود را حلق‌آويز كند] سپس [آن را] بِبُرَد. آنگاه بنگرد كه آيا نيرنگش چيزى را كه مايه خشم او شده از ميان خواهد برد؟\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmdcxi{و بدين گونه [قرآن‌] را [به صورت‌] آياتى روشنگر نازل كرديم، و خداست كه هر كه را بخواهد راه مى‌نمايد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmdcxii{كسانى كه ايمان آوردند و كسانى كه يهودى شدند و صابئى‌ها و مسيحيان و زرتشتيان و كسانى كه شرك ورزيدند، البته خدا روز قيامت ميانشان داورى خواهد كرد، زيرا خدا بر هر چيزى گواه است.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmdcxiii{آيا ندانستى كه خداست كه هر كس در آسمانها و هر كس در زمين است، و خورشيد و ماه و [تمام‌] ستارگان و كوهها و درختان و جنبندگان و بسيارى از مردم براى او سجده مى‌كنند؟ و بسيارى‌اند كه عذاب بر آنان واجب شده است. و هر كه را خدا خوار كند او را گرامى‌دارنده‌اى نيست، چرا كه خدا هر چه بخواهد انجام مى‌دهد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmdcxiv{اين دو [گروه،] دشمنان يكديگرند كه در باره پروردگارشان با هم ستيزه مى‌كنند، و كسانى كه كفر ورزيدند، جامه‌هايى از آتش برايشان بريده شده است [و] از بالاى سرشان آب جوشان ريخته مى‌شود.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmdcxv{آنچه در شكم آنهاست با پوست [بدن‌]شان بدان گداخته مى‌گردد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmdcxvi{و براى [وارد كردن ضربت بر سر] آنان گرزهايى آهنين است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmdcxvii{هر بار بخواهند از [شدت‌] غم، از آن بيرون روند در آن باز گردانيده مى‌شوند [كه هان‌] بچشيد عذاب آتش سوزان را.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmdcxviii{خدا كسانى را كه ايمان آورده و كارهاى شايسته كرده‌اند در باغهايى كه از زير [درختان‌] آن نهرها روان است درمى‌آورد: در آنجا با دستبندهايى از طلا و مرواريد آراسته مى‌شوند، و لباسشان در آنجا از پرنيان است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmdcxix{و به گفتار پاك هدايت مى‌شوند و به سوى راه [خداى‌] ستوده هدايت مى‌گردند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmdcxx{بى‌گمان، كسانى كه كافر شدند و از راه خدا و مسجدالحرام -كه آن را براى مردم، اعم از مقيم در آنجا و باديه‌نشين، يكسان قرار داده‌ايم- جلو گيرى مى‌كنند، و [نيز] هر كه بخواهد در آنجا به ستم [از حق ]منحرف شود، او را از عذابى دردناك مى‌چشانيم.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmdcxxi{و چون براى ابراهيم جاى خانه را معين كرديم [بدو گفتيم:] «چيزى را با من شريك مگردان و خانه‌ام را براى طواف‌كنندگان و قيام‌كنندگان و ركوع‌كنندگان [و] سجده‌كنندگان پاكيزه دار.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmdcxxii{و در ميان مردم براى [اداى‌] حج بانگ برآور تا [زايران‌] پياده و [سوار] بر هر شتر لاغرى -كه از هر راه دورى مى‌آيند- به سوى تو روى آورند،\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmdcxxiii{تا شاهد منافع خويش باشند، و نام خدا را در روزهاى معلومى بر دامهاى زبان‌بسته‌اى كه روزىِ آنان كرده است ببرند. پس، از آنها بخوريد و به درمانده مستمند بخورانيد.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmdcxxiv{سپس بايد آلودگى خود را بزدايند و به نذرهاى خود وفا كنند و بر گِرد آن خانه كهن [=كعبه‌] طواف به جاى آورند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmdcxxv{اين است [آنچه مقرر شده‌] و هر كس مقررات خدا را بزرگ دارد، آن براى او نزد پروردگارش بهتر است، و براى شما دامها حلال شده است، مگر آنچه بر شما خوانده مى‌شود. پس، از پليدى بتها دورى كنيد، و از گفتار باطل اجتناب ورزيد.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmdcxxvi{در حالى كه گروندگان خالص به خدا باشيد؛ نه شريك‌گيرندگان [براى‌] او! و هر كس به خدا شرك ورزد چنان است كه گويى از آسمان فرو افتاده و مرغان [شكارى‌] او را ربوده‌اند يا باد او را به جايى دور افكنده است.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmdcxxvii{اين است [فرايض خدا] و هر كس شعاير خدا را بزرگ دارد در حقيقت، آن [حاكى‌] از پاكى دلهاست.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmdcxxviii{براى شما در آن [دامها] تا مدتى معين سودهايى است، سپس جايگاه [قربانى‌كردن آنها و ساير فرايض‌] در خانه كهن [=كعبه‌] است.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmdcxxix{و براى هر امتى مناسكى قرار داديم، تا نام خدا را بر دامهاى زبان‌بسته‌اى كه روزى آنها گردانيده ياد كنند. پس [بدانيد كه‌] خداى شما خدايى يگانه است، پس به [فرمان‌] او گردن نهيد. و فروتنان را بشارت ده.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmdcxxx{همانان كه چون [نام‌] خدا ياد شود، دلهايشان خشيت يابد و [آنان كه‌] بر هر چه برسرشان آيد صبر پيشه‌گانند و برپا دارندگان نمازند، و از آنچه روزيشان داده‌ايم انفاق مى‌كنند.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmdcxxxi{و شتران فربه را براى شما از [جمله‌] شعاير خدا قرار داديم: در آنها براى شما خير است. پس نام خدا را بر آنها -در حالى كه برپاى ايستاده‌اند- ببَريد و چون به پهلو درغلتيدند از آنها بخوريد و به تنگدست [سائل‌] و به بينوا[ى غير سائل ]بخورانيد. اين گونه آنها را براى شما رام كرديم، اميد كه شكرگزار باشيد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmdcxxxii{هرگز [نه‌] گوشتهاى آنها و نه خونهايشان به خدا نخواهد رسيد، ولى [اين‌] تقواى شماست كه به او مى‌رسد. اين گونه [خداوند] آنها را براى شما رام كرد، تا خدا را به پاس آنكه شما را هدايت نموده به بزرگى ياد كنيد، و نيكوكاران را مژده ده.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmdcxxxiii{قطعاً خداوند از كسانى كه ايمان آورده‌اند دفاع مى‌كند، زيرا خدا هيچ خيانتكار ناسپاسى را دوست ندارد.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmdcxxxiv{به كسانى كه جنگ بر آنان تحميل شده، رخصت [جهاد] داده شده است، چرا كه مورد ظلم قرار گرفته‌اند، و البته خدا بر پيروزى آنان سخت تواناست.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmdcxxxv{همان كسانى كه بناحق از خانه‌هايشان بيرون رانده شدند. [آنها گناهى نداشتند] جز اينكه مى‌گفتند: «پروردگار ما خداست» و اگر خدا بعضى از مردم را با بعض ديگر دفع نمى‌كرد، صومعه‌ها و كليساها و كنيسه‌ها و مساجدى كه نام خدا در آنها بسيار برده مى‌شود، سخت ويران مى‌شد، و قطعاً خدا به كسى كه [دين‌] او را يارى مى‌كند، يارى مى‌دهد، چرا كه خدا سخت نيرومند شكست‌ناپذير است.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmdcxxxvi{همان كسانى كه چون در زمين به آنان توانايى دهيم، نماز برپا مى‌دارند و زكات مى‌دهند و به كارهاى پسنديده وامى‌دارند، و از كارهاى ناپسند باز مى‌دارند، و فرجام همه كارها از آنِ خداست.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmdcxxxvii{و اگر تو را تكذيب كنند، قطعاً پيش از آنان قوم نوح و عاد و ثمود [نيز] به تكذيب پرداختند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmdcxxxviii{و [نيز] قوم ابراهيم و قوم لوط.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmdcxxxix{و [همچنين‌] اهل مدين. و موسى تكذيب شد، پس كافران را مهلت دادم، سپس [گريبان‌] آنها را گرفتم. بنگر، عذاب من چگونه بود؟\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmdcxl{و چه بسيار شهرها را -كه ستمكار بودند- هلاكشان كرديم و [اينك‌] آن [شهرها] سقفهايش فرو ريخته است، و [چه بسيار] چاههاى متروك و كوشكهاى افراشته را.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmdcxli{آيا در زمين گردش نكرده‌اند، تا دلهايى داشته باشند كه با آن بينديشند يا گوشهايى كه با آن بشنوند؟ در حقيقت، چشمها كور نيست ليكن دلهايى كه در سينه‌هاست كور است.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmdcxlii{و از تو با شتاب تقاضاى عذاب مى‌كنند، با آنكه هرگز خدا وعده‌اش را خلاف نمى كند، و در حقيقت، يك روز [از قيامت‌] نزد پروردگارت مانند هزار سال است از آنچه مى‌شمريد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmdcxliii{و چه بسا شهرى كه مهلتش دادم، در حالى كه ستمكار بود؛ سپس [گريبان‌] آن را گرفتم، و فرجام به سوى من است.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmdcxliv{بگو: «اى مردم، من براى شما فقط هشداردهنده‌اى آشكارم.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmdcxlv{پس آنان كه گرويده و كارهاى شايسته كرده‌اند، آمرزش و روزىِ نيكو براى ايشان خواهد بود.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmdcxlvi{و كسانى كه در [تخطئه‌] آيات ما مى‌كوشند [و به خيال خود] عاجزكنندگان ما هستند، آنان اهل دوزخند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmdcxlvii{و پيش از تو [نيز] هيچ رسول و پيامبرى را نفرستاديم جز اينكه هر گاه چيزى تلاوت مى‌نمود، شيطان در تلاوتش القاىِ [شبهه‌] مى‌كرد. پس خدا آنچه را شيطان القا مى‌كرد محو مى‌گردانيد، سپس خدا آيات خود را استوار مى‌ساخت، و خدا داناى حكيم است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmdcxlviii{تا آنچه را كه شيطان القا مى‌كند، براى كسانى كه در دلهايشان بيمارى است و [نيز] براى سنگدلان آزمايشى گرداند، و ستمگران در ستيزه‌اى بس دور و درازند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmdcxlix{و تا آنان كه دانش يافته‌اند بدانند كه اين [قرآن‌] حق است [و] از جانب پروردگار توست. و بدان ايمان آورند و دلهايشان براى او خاضع گردد. و به راستى خداوند كسانى را كه ايمان آورده‌اند، به سوى راهى راست راهبر است.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmdcl{و[لى‌] كسانى كه كفر ورزيده‌اند، همواره از آن در ترديدند، تا بناگاه قيامت براى آنان فرا رسد، يا عذاب روزى بدفرجام به سراغشان بيايد.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmdcli{در آن روز، پادشاهى از آنِ خداست: ميان آنان داورى مى‌كند، و [در نتيجه‌] كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند در باغهاى پرناز و نعمت خواهند بود.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmdclii{و كسانى كه كفر ورزيده و نشانه‌هاى ما را دروغ پنداشته‌اند، براى آنان عذابى خفّت‌آور خواهد بود.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmdcliii{و آنان كه در راه خدا مهاجرت كرده‌اند، و آنگاه كشته شده يا مرده‌اند، قطعاً خداوند به آنان رزقى نيكو مى‌بخشد. و راستى اين خداست كه بهترين روزى‌دهندگان است.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmdcliv{آنان را به جايگاهى كه آن را مى‌پسندند درخواهد آورد، و شك نيست كه خداوند دانايى بردبار است.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmdclv{آرى چنين است، و هر كس نظير آنچه بر او عقوبت رفته است دست به عقوبت زند، سپس مورد ستم قرار گيرد، قطعاً خدا او را يارى خواهد كرد، چرا كه خدا بخشايشگر و آمرزنده است.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmdclvi{اين بدان سبب است كه خدا شب را در روز درمى‌آورد و روز را [نيز] در شب درمى‌آورد، و خداست كه شنواى بيناست.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmdclvii{[آرى،] اين بدان سبب است كه خدا خود حق است و آنچه به جاى او مى‌خوانند آن باطل است، و اين خداست كه والا و بزرگ است.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmdclviii{آيا نديده‌اى كه خدا از آسمان، آبى فرو فرستاد و زمين سرسبز گرديد؟ آرى، خداست كه دقيق و آگاه است.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmdclix{آنچه در آسمانها و آنچه در زمين است از آنِ اوست، و در حقيقت، اين خداست كه خود بى‌نياز ستوده‌[صفات‌] است.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmdclx{آيا نديده‌اى كه خدا آنچه را در زمين است به نفع شما رام گردانيد، و كشتيها در دريا به فرمان او روانند، و آسمان را نگاه مى‌دارد تا [مبادا] بر زمين فرو افتد، مگر به اذن خودش [باشد]. در حقيقت، خداوند نسبت به مردم سخت رئوف و مهربان است.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmdclxi{و اوست كه شما را زندگى بخشيد، سپس شما را مى‌ميراند، و باز زندگى [نو] مى دهد. حقا كه انسان سخت ناسپاس است.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmdclxii{براى هر امتى مناسكى قرار داديم كه آنها بدان عمل مى‌كنند، پس نبايد در اين امر با تو به ستيزه برخيزند، به راه پروردگارت دعوت كن، زيرا تو بر راهى راست قرار دارى.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmdclxiii{و اگر با تو مجادله كردند، بگو: «خدا به آنچه مى‌كنيد داناتر است.»\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmdclxiv{خدا روز قيامت در مورد آنچه با يكديگر در آن اختلاف مى‌كرديد، داورى خواهد كرد.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmdclxv{آيا ندانسته‌اى كه خداوند آنچه را در آسمان و زمين است مى‌داند؟ اينها [همه‌] در كتابى [مندرج‌] است. قطعاً اين بر خدا آسان است.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmdclxvi{و به جاى خدا چيزى را مى‌پرستند كه بر [تأييد] آن حجّتى نازل نكرده و بدان دانشى ندارند، و براى ستمكاران ياورى نخواهد بود.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmdclxvii{و چون آيات روشن ما بر آنان خوانده مى‌شود، در چهره كسانى كه كفر ورزيده‌اند [اثر] انكار را تشخيص مى‌دهى: چيزى نمانده كه بر كسانى كه آيات ما را برايشان تلاوت مى‌كنند حمله‌ور شوند. بگو: «آيا شما را به بدتر از اين خبر دهم؟ [همان ]آتش است كه خدا آن را به كسانى كه كفر ورزيده‌اند وعده داده، و چه بد سرانجامى است.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmdclxviii{اى مردم، مَثَلى زده شد. پس بدان گوش فرا دهيد: كسانى را كه جز خدا مى‌خوانيد هرگز [حتى‌] مگسى نمى‌آفرينند، هر چند براى [آفريدن‌] آن اجتماع كنند، و اگر آن مگس چيزى از آنان بربايد نمى‌توانند آن را بازپس گيرند. طالب و مطلوب هر دو ناتوانند.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmdclxix{قدر خدا را چنانكه در خور اوست نشناختند. در حقيقت، خداست كه نيرومند شكست‌ناپذير است.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmdclxx{خدا از ميان فرشتگان رسولانى برمى‌گزيند، و نيز از ميان مردم. بى‌گمان خدا شنواى بيناست.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmdclxxi{آنچه در دسترس آنان و آنچه پشت سرشان است مى‌داند و [همه‌] كارها به خدا بازگردانيده مى‌شود.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmdclxxii{اى كسانى كه ايمان آورده‌ايد، ركوع و سجود كنيد و پروردگارتان را بپرستيد و كار خوب انجام دهيد، باشد كه رستگار شويد.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmdclxxiii{و در راه خدا چنانكه حق جهاد [در راه‌] اوست جهاد كنيد، اوست كه شما را [براى خود] برگزيده و در دين بر شما سختى قرار نداده است. آيين پدرتان ابراهيم [نيز چنين بوده است‌] او بود كه قبلاً شما را مسلمان ناميد، و در اين [قرآن نيز همين مطلب آمده است‌] تا اين پيامبر بر شما گواه باشد و شما بر مردم گواه باشيد. پس نماز را برپا داريد و زكات بدهيد و به پناه خدا رويد. او مولاى شماست؛ چه نيكو مولايى و چه نيكو ياورى.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmdclxxiv{\basmalahfa به راستى كه مؤمنان رستگار شدند،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmdclxxv{همانان كه در نمازشان فروتنند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmdclxxvi{و آنان كه از بيهوده رويگردانند،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmdclxxvii{و آنان كه زكات مى‌پردازند،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmdclxxviii{و كسانى كه پاكدامنند،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmdclxxix{مگر در مورد همسرانشان يا كنيزانى كه به دست آورده‌اند، كه در اين صورت بر آنان نكوهشى نيست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmdclxxx{پس هر كه فراتر از اين جويد، آنان از حد درگذرندگانند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmdclxxxi{و آنان كه امانتها و پيمان خود را رعايت مى‌كنند،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmdclxxxii{و آنان كه بر نمازهايشان مواظبت مى‌نمايند،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmdclxxxiii{آنانند كه خود وارثانند،\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmdclxxxiv{همانان كه بهشت را به ارث مى‌برند و در آنجا جاودان مى‌مانند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmdclxxxv{و به يقين، انسان را از عصاره‌اى از گِل آفريديم.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmdclxxxvi{سپس او را [به صورت‌] نطفه‌اى در جايگاهى استوار قرار داديم.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmdclxxxvii{آنگاه نطفه را به صورت علقه درآورديم. پس آن علقه را [به صورت‌] مضغه گردانيديم، و آنگاه مضغه را استخوانهايى ساختيم، بعد استخوانها را با گوشتى پوشانيديم، آنگاه [جنين را در] آفرينشى ديگر پديد آورديم. آفرين باد بر خدا كه بهترين آفرينندگان است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmdclxxxviii{بعد از اين [مراحل‌] قطعاً خواهيد مُرد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmdclxxxix{آنگاه شما در روز رستاخيز برانگيخته خواهيد شد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmdcxc{و به راستى [ما] بالاى سر شما هفت راه [آسمانى‌] آفريديم و از [كار] آفرينش غافل نبوده‌ايم.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmdcxci{و از آسمان، آبى به اندازه [معيّن‌] فرود آورديم، و آن را در زمين جاى داديم، و ما براى از بين بردن آن مسلّماً تواناييم.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmdcxcii{پس براى شما به وسيله آن باغهايى از درختان خرما و انگور پديدار كرديم كه در آنها براى شما ميوه‌هاى فراوان است و از آنها مى‌خوريد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmdcxciii{و از طور سينا درختى برمى‌آيد كه روغن و نان خورشى براى خورندگان است.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmdcxciv{و البته براى شما در دامها[ى گلّه درس‌] عبرتى است: از [شيرى‌] كه در شكم آنهاست، به شما مى‌نوشانيم، و براى شما در آنها سودهاى فراوان است و از آنها مى‌خوريد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmdcxcv{و بر آنها و بر كشتيها سوار مى‌شويد.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmdcxcvi{و به يقين نوح را به سوى قومش فرستاديم. پس [به آنان‌] گفت: «اى قوم من، خدا را بپرستيد. شما را جز او خدايى نيست. مگر پروا نداريد؟»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmdcxcvii{و اشراف قومش كه كافر بودند گفتند: «اين [مرد] جز بشرى چون شما نيست، مى‌خواهد بر شما برترى جويد، و اگر خدا مى‌خواست قطعاً فرشتگانى مى‌فرستاد. [ما]در ميان پدران نخستين خود، چنين [چيزى‌] نشنيده‌ايم.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmdcxcviii{او نيست جز مردى كه در وى [حال‌] جنون است، پس تا چندى در باره‌اش دست نگاه داريد.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmdcxcix{[نوح‌] گفت: «پروردگارا، از آن روى كه دروغزنم خواندند مرا يارى كن.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmdcc{پس به او وحى كرديم كه: زير نظر ما و [به‌] وحى ما كشتى را بساز، و چون فرمان ما دررسيد و تنور به فوران آمد، پس در آن از هر نوع [حيوانى‌] دو تا [يكى نر و ديگرى ماده‌] با خانواده‌ات -بجز كسى از آنان كه حكم [عذاب ] بر او پيشى گرفته است- وارد كن، در باره كسانى كه ظلم كرده‌اند با من سخن مگوى، زيرا آنها غرق خواهند شد.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmdcci{و چون تو با آنان كه همراه تواند بر كشتى نشستى بگو: «ستايش خدايى را كه ما را از [چنگ‌] گروه ظالمان رهانيد.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmdccii{و بگو: «پروردگارا، مرا در جايى پربركت فرود آور [كه‌] تو نيكترين مهمان‌نوازانى.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmdcciii{در حقيقت، در اين [ماجرا] عبرتهايى است، و قطعاً ما آزمايش‌كننده بوديم.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmdcciv{سپس، بعد از آنان نسل‌[هايى‌] ديگر پديد آورديم.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmdccv{و در ميانشان پيامبرى از خودشان روانه كرديم كه: خدا را بپرستيد. جز او براى شما معبودى نيست. آيا سرِ پرهيزگارى نداريد؟\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmdccvi{و اشراف قومش كه كافر شده، و ديدار آخرت را دروغ پنداشته بودند، و در زندگى دنيا آنان را مرفّه ساخته بوديم گفتند: «اين [مرد] جز بشرى چون شما نيست: از آنچه مى‌خوريد، مى‌خورد؛ و از آنچه مى‌نوشيد، مى‌نوشد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmdccvii{و اگر بشرى مثل خودتان را اطاعت كنيد در آن صورت قطعاً زيانكار خواهيد بود.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmdccviii{آيا به شما وعده مى‌دهد كه وقتى مُرديد و خاك و استخوان شديد [باز] شما [از گور زنده‌] بيرون آورده مى‌شويد؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmdccix{وه، چه دور است آنچه كه وعده داده مى‌شويد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmdccx{جز اين زندگانى دنياى ما چيزى نيست. مى‌ميريم و زندگى مى‌كنيم و ديگر برانگيخته نخواهيم شد.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmdccxi{او جز مردى كه بر خدا دروغ مى‌بندد نيست، و ما به او اعتقاد نداريم.»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmdccxii{گفت: «پروردگارا، از آن روى كه مرا دروغزن خواندند ياريم كن.»\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmdccxiii{فرمود: «به زودى سخت پشيمان خواهند شد.»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmdccxiv{پس فرياد [مرگبار] آنان را به حقّ فرو گرفت، و آنها را [چون‌] خاشاكى كه بر آب افتد، گردانيديم. دور باد [از رحمت خدا] گروه ستمكاران.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmdccxv{آنگاه پس از آنان نسلهاى ديگرى پديد آورديم.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmdccxvi{هيچ امّتى نه از اجل خود پيشى مى‌گيرد و نه باز پس مى‌ماند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmdccxvii{باز فرستادگان خود را پياپى روانه كرديم. هر بار براى [هدايت‌] امتى پيامبرش آمد، او را تكذيب كردند؛ پس [ما امتهاى سركش را] يكى پس از ديگرى آورديم و آنها را مايه عبرت [و زبانزد مردم‌] گردانيديم. دور باد [از رحمت خدا] مردمى كه ايمان نمى‌آورند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmdccxviii{سپس موسى و برادرش هارون را با آيات خود و حجتى آشكار فرستاديم،\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmdccxix{به سوى فرعون و سران [قوم‌] او، ولى تكبّر نمودند و مردمى گردنكش بودند،\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmdccxx{پس گفتند: «آيا به دو بشر كه مثل خود ما هستند و طايفه آنها بندگان ما مى‌باشند ايمان بياوريم؟»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmdccxxi{در نتيجه، آن دو را دروغزن خواندند، پس از زمره هلاك‌شدگان گشتند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmdccxxii{و به يقين، ما به موسى كتاب [آسمانى‌] داديم، باشد كه آنان به راه راست روند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmdccxxiii{و پسر مريم و مادرش را نشانه‌اى گردانيديم و آن دو را در سرزمين بلندى كه جاى زيست و [داراى‌] آب زلال بود جاى داديم.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmdccxxiv{اى پيامبران، از چيزهاى پاكيزه بخوريد و كار شايسته كنيد، كه من به آنچه انجام مى‌دهيد دانايم.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmdccxxv{و در حقيقت، اين امّت شماست كه امتى يگانه است، و من پروردگار شمايم؛ پس، از من پروا داريد.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmdccxxvi{تا كار [دين‌]شان را ميان خود قطعه قطعه كردند [و] دسته دسته شدند: هر دسته‌اى به آنچه نزدشان بود، دل خوش كردند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmdccxxvii{پس آنها را در ورطه گمراهى‌شان تا چندى واگذار.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmdccxxviii{آيا مى‌پندارند كه آنچه از مال و پسران كه بديشان مدد مى‌دهيم،\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmdccxxix{[از آن روى است كه‌] مى‌خواهيم به سودشان در خيرات شتاب ورزيم؟ [نه،] بلكه نمى‌فهمند.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmdccxxx{در حقيقت، كسانى كه از بيم پروردگارشان هراسانند،\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmdccxxxi{و كسانى كه به نشانه‌هاى پروردگارشان ايمان مى‌آورند،\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmdccxxxii{و آنان كه به پروردگارشان شرك نمى‌آورند،\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmdccxxxiii{و كسانى كه آنچه را دادند [در راه خدا] مى‌دهند، در حالى كه دلهايشان ترسان است [و مى‌دانند] كه به سوى پروردگارشان بازخواهند گشت،\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmdccxxxiv{آنانند كه در كارهاى نيك شتاب مى‌ورزند و آنانند كه در انجام آنها سبقت مى‌جويند.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmdccxxxv{و هيچ كس را جز به قدر توانش تكليف نمى‌كنيم، و نزد ما كتابى است كه به حق سخن مى‌گويد و آنان مورد ستم قرار نخواهند گرفت.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmdccxxxvi{[نه،] بلكه دلهاى آنان از اين [حقيقت‌] در غفلت است، و آنان غير از اين [گناهان‌] كردارهايى [ديگر] دارند كه به انجام آن مبادرت مى‌ورزند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmdccxxxvii{تا وقتى خوشگذرانانِ آنها را به عذاب گرفتار ساختيم، بناگاه به زارى درمى‌آيند.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmdccxxxviii{امروز زارى مكنيد كه قطعاً شما از جانب ما يارى نخواهيد شد.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmdccxxxix{در حقيقت، آيات من بر شما خوانده مى‌شد و شما بوديد كه همواره به قهقرا مى‌رفتيد.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmdccxl{در حالى كه از [پذيرفتن‌] آن تكبّر مى‌ورزيديد و شب هنگام [در محافل خود] بدگويى مى‌كرديد.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmdccxli{آيا در [عظمت‌] اين سخن نينديشيده‌اند، يا چيزى براى آنان آمده كه براى پدران پيشين آنها نيامده است؟\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmdccxlii{يا پيامبر خود را [درست‌] نشناخته و [لذا] به انكار او پرداخته‌اند؟\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmdccxliii{يا مى‌گويند او جنونى دارد؟ [نه،] بلكه [او] حق را براى ايشان آورده و[لى‌] بيشترشان حقيقت را خوش ندارند.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmdccxliv{و اگر حق از هوسهاى آنها پيروى مى‌كرد، قطعاً آسمانها و زمين و هر كه در آنهاست تباه مى‌شد. [نه!] بلكه يادنامه‌شان را به آنان داده‌ايم، ولى آنها از [پيروى‌] يادنامه خود رويگردانند.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmdccxlv{يا از ايشان مزدى مطالبه مى‌كنى؟ و مزد پروردگارت بهتر است، و اوست كه بهترين روزى‌دهندگان است.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmdccxlvi{و در حقيقت، اين تويى كه جدّاً آنها را به راه راست مى‌خوانى.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmdccxlvii{و به راستى كسانى كه به آخرت ايمان ندارند، از راه [درست‌] سخت منحرفند.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmdccxlviii{و اگر ايشان را ببخشاييم، و آنچه از صدمه بر آنان [وارد آمده‌] است برطرف كنيم، در طغيان خود كوردلانه اصرار مى‌ورزند.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmdccxlix{و به راستى ايشان را به عذاب گرفتار كرديم و[لى‌] نسبت به پروردگارشان فروتنى نكردند و به زارى درنيامدند.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmdccl{تا وقتى كه درى از عذاب دردناك بر آنان گشوديم، بناگاه ايشان در آن [حال‌] نوميد شدند.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmdccli{و اوست آن كس كه براى شما گوش و چشم و دل پديد آورد. چه اندك سپاسگزاريد.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmdcclii{و اوست آن كس كه شما را در زمين پديد آورد، و به سوى اوست كه گرد آورده خواهيد شد.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmdccliii{و اوست آن كس كه زنده مى‌كند و مى‌ميراند، و اختلاف شب و روز از اوست. مگر نمى‌انديشيد؟\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmdccliv{[نه،] بلكه آنان [نيز] مثل آنچه پيشينيان گفته بودند، گفتند.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmdcclv{گفتند: «آيا چون بميريم و خاك و استخوان شويم، آيا واقعاً باز ما زنده خواهيم شد؟\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmdcclvi{درست همين را قبلاً به ما و پدرانمان وعده دادند. اين جز افسانه‌هاى پيشينيان [چيزى‌] نيست.»\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmdcclvii{بگو: «اگر مى‌دانيد [بگوييد] زمين و هر كه در آن است به چه كسى تعلق دارد؟»\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmdcclviii{خواهند گفت: «به خدا.» بگو: «آيا عبرت نمى‌گيريد؟»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmdcclix{بگو: «پروردگار آسمانهاى هفتگانه و پروردگار عرش بزرگ كيست؟»\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmdcclx{خواهند گفت: «خدا.» بگو: «آيا پرهيزگارى نمى‌كنيد؟»\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmdcclxi{بگو: «فرمانروايى هر چيزى به دست كيست؟ و اگر مى‌دانيد [كيست آنكه‌] او پناه مى‌دهد و در پناه كسى نمى‌رود؟»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmdcclxii{خواهند گفت: «خدا.» بگو: «پس چگونه دستخوش افسون شده‌ايد؟»\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmdcclxiii{[نه!] بلكه حقيقت را بر ايشان آورديم، و قطعاً آنان دروغگويند.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmdcclxiv{خدا فرزندى اختيار نكرده و با او معبودى [ديگر] نيست، و اگر جز اين بود، قطعاً هر خدايى آنچه را آفريده [بود] باخود مى‌برد، و حتماً بعضى از آنان بر بعضى ديگر تفوّق مى‌جستند. منزه است خدا از آنچه وصف مى‌كنند.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmdcclxv{داناى نهان و آشكار، و برتر است از آنچه [با او] شريك مى‌گردانند.\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmdcclxvi{بگو: «پروردگارا، اگر آنچه را كه [از عذاب‌] به آنان وعده داده شده است به من نشان دهى،\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmdcclxvii{پروردگارا، پس مرا در ميان قوم ستمكار قرار مده.»\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmdcclxviii{و به راستى كه ما تواناييم كه آنچه را به آنان وعده داده‌ايم بر تو بنمايانيم.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmdcclxix{بدى را به شيوه‌اى نيكو دفع كن. ما به آنچه وصف مى‌كنند داناتريم.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmdcclxx{و بگو: «پروردگارا، از وسوسه‌هاى شيطانها به تو پناه مى‌برم.\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mmdcclxxi{و پروردگارا، از اينكه [آنها] به پيش من حاضر شوند به تو پناه مى‌برم.»\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mmdcclxxii{تا آنگاه كه مرگ يكى از ايشان فرا رسد، مى‌گويد: «پروردگارا، مرا بازگردانيد،\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mmdcclxxiii{شايد من در آنچه وانهاده‌ام كار نيكى انجام دهم. نه چنين است، اين سخنى است كه او گوينده آن است و پشاپيش آنان برزخى است تا روزى كه برانگيخته خواهند شد.\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mmdcclxxiv{پس آنگاه كه در صور دميده شود، [ديگر] ميانشان نسبت خويشاوندى وجود ندارد، و از [حال‌] يكديگر نمى‌پرسند.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mmdcclxxv{پس كسانى كه كفه ميزان [اعمال‌] آنان سنگين باشد، ايشان رستگارانند.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mmdcclxxvi{و كسانى كه كفه ميزان [اعمال‌]شان سبك باشد، آنان به خويشتن زيان زده [و] هميشه در جهنم مى‌مانند.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mmdcclxxvii{آتش چهره آنها را مى‌سوزاند، و آنان در آنجا ترش‌رويند.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mmdcclxxviii{آيا آيات من بر شما خوانده نمى‌شد و [همواره‌] آن را مورد تكذيب قرار نمى‌داديد؟\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mmdcclxxix{مى‌گويند: «پروردگارا، شقاوت ما بر ما چيره شد و ما مردمى گمراه بوديم.»\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mmdcclxxx{پروردگارا، ما را از اينجا بيرون بر، پس اگر باز هم [به بدى‌] برگشتيم، در آن صورت ستمگر خواهيم بود.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxi{مى‌فرمايد: «[برويد] در آن گم شويد و با من سخن مگوييد.»\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxii{در حقيقت، دسته‌اى از بندگان من بودند كه مى‌گفتند: «پروردگارا، ايمان آورديم. بر ما ببخشاى و به ما رحم كن [كه‌] تو بهترينِ مهربانى.»\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxiii{و شما آنان [=مؤمنان‌] را به ريشخند گرفتيد، تا [با اين كار] ياد مرا از خاطرتان بردند و شما بر آنان مى‌خنديديد.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxiv{من [هم‌] امروز به [پاس‌] آنكه صبر كردند، بدانان پاداش دادم. آرى، ايشانند كه رستگارانند.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxv{مى‌فرمايد: «چه مدت به عدد سالها در زمين مانديد؟»\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxvi{مى‌گويند: «يك روز يا پاره‌اى از يك روز مانديم. از شمارگران [خود] بپرس.»\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxvii{مى‌فرمايد: «جز اندكى درنگ نكرديد، كاش شما مى‌دانستيد.»\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxviii{آيا پنداشتيد كه شما را بيهوده آفريده‌ايم و اينكه شما به سوى ما بازگردانيده نمى‌شويد؟\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@mmdcclxxxix{پس والاست خدا، فرمانرواى برحق، خدايى جز او نيست. [اوست‌] پروردگار عرش گرانمايه.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@mmdccxc{و هر كس با خدا معبود ديگرى بخواند، براى آن برهانى نخواهد داشت، و حسابش فقط با پروردگارش مى‌باشد، در حقيقت، كافران رستگار نمى‌شوند.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@mmdccxci{و بگو: «پروردگارا، ببخشاى و رحمت كن [كه‌] تو بهترين بخشايندگانى.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@mmdccxcii{\basmalahfa [اين‌] سوره‌اى است كه آن را نازل و آن را فرض گردانيديم و در آن آياتى روشن فرو فرستاديم، باشد كه شما پند پذيريد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmdccxciii{به هر زن زناكار و مرد زناكارى صد تازيانه بزنيد، و اگر به خدا و روز بازپسين ايمان داريد، در [كار] دين خدا، نسبت به آن دو دلسوزى نكنيد، و بايد گروهى از مؤمنان در كيفر آن دو حضور يابند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmdccxciv{مرد زناكار، جز زن زناكار يا مشرك را به همسرى نگيرد، و زن زناكار، جز مرد زناكار يا مشرك را به زنى نگيرد، و بر مؤمنان اين [امر] حرام گرديده است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmdccxcv{و كسانى كه نسبت زنا به زنان شوهردار مى‌دهند، سپس چهار گواه نمى‌آورند، هشتاد تازيانه به آنان بزنيد، و هيچگاه شهادتى از آنها نپذيريد، و اينانند كه خود فاسقند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmdccxcvi{مگر كسانى كه بعد از آن [بهتان‌] توبه كرده و به صلاح آمده باشند كه خدا البته آمرزنده مهربان است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmdccxcvii{و كسانى كه به همسران خود نسبت زنا مى‌دهند، و جز خودشان گواهانى [ديگر] ندارند، هر يك از آنان [بايد] چهار بار به خدا سوگند ياد كند كه او قطعاً از راستگويان است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmdccxcviii{و [گواهى در دفعه‌] پنجم اين است كه [شوهر بگويد:] لعنت خدا بر او باد اگر از دروغگويان باشد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmdccxcix{و از [زن،] كيفر ساقط مى‌شود، در صورتى كه چهار بار به خدا سوگند ياد كند كه [شوهر] او جداً از دروغگويان است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmdccc{و [گواهى‌] پنجم آنكه خشم خدا بر او باد اگر [شوهرش‌] از راستگويان باشد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmdccci{و اگر فضل و رحمت خدا بر شما نبود و اينكه خدا توبه‌پذير سنجيده‌كار است [رسوا مى‌شديد].\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmdcccii{در حقيقت، كسانى كه آن بهتان [داستان اِفك‌] را [در ميان‌] آوردند، دسته‌اى از شما بودند. آن [تهمت‌] را شرّى براى خود تصوّر مكنيد بلكه براى شما در آن مصلحتى [بوده‌] است. براى هر مردى از آنان [كه در اين كار دست داشته‌] همان گناهى است كه مرتكب شده است، و آن كس از ايشان كه قسمت عمده آن را به گردن گرفته است عذابى سخت خواهد داشت.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmdccciii{چرا هنگامى كه آن [بهتان‌] را شنيديد، مردان و زنان مؤمن گمان نيك به خود نبردند و نگفتند: «اين بهتانى آشكار است»؟\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmdccciv{چرا چهار گواه بر [صحت‌] آن [بهتان‌] نياوردند؟ پس چون گواهان [لازم‌] را نياورده‌اند، اينانند كه نزد خدا دروغگويانند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmdcccv{و اگر فضل خدا و رحمتش در دنيا و آخرت بر شما نبود، قطعاً به [سزاى‌] آنچه در آن به دخالت پرداختيد، به شما عذابى بزرگ مى‌رسيد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmdcccvi{آنگاه كه آن [بهتان‌] را از زبان يكديگر مى‌گرفتيد و با زبانهاى خود چيزى را كه بدان علم نداشتيد، مى‌گفتيد و مى‌پنداشتيد كه كارى سهل و ساده است با اينكه آن [امر] نزد خدا بس بزرگ بود.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmdcccvii{و [گر نه‌] چرا وقتى آن را شنيديد نگفتيد: «براى ما سزاوار نيست كه در اين [موضوع‌] سخن گوييم. [خداوندا،] تو منزهى، اين بهتانى بزرگ است.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmdcccviii{خدا اندرزتان مى‌دهد كه هيچ گاه ديگر مثل آن را -اگر مؤمنيد- تكرار نكنيد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmdcccix{و خدا براى شما آيات [خود] را بيان مى‌كند، و خدا داناى سنجيده‌كار است.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmdcccx{كسانى كه دوست دارند كه زشتكارى در ميان آنان كه ايمان آورده‌اند، شيوع پيدا كند، براى آنان در دنيا و آخرت عذابى پر درد خواهد بود، و خدا[ست كه‌] مى‌داند و شما نمى‌دانيد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmdcccxi{و اگر فضل و رحمت خدا بر شما نبود و اينكه خدا رئوف و مهربان است [مجازات سختى در انتظارتان بود].\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmdcccxii{اى كسانى كه ايمان آورده‌ايد، پاى از پى گامهاى شيطان منهيد، و هر كس پاى بر جاى گامهاى شيطان نهد [بداند كه‌] او به زشتكارى و ناپسند وامى‌دارد، و اگر فضل خدا و رحمتش بر شما نبود، هرگز هيچ كس از شما پاك نمى‌شد، ولى [اين‌] خداست كه هر كس را بخواهد پاك مى‌گرداند و خدا[ست كه‌] شنواى داناست.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmdcccxiii{و سرمايه‌داران و فراخ‌دولتان شما نبايد از دادن [مال‌] به خويشاوندان و تهيدستان و مهاجران راه خدا دريغ ورزند، و بايد عفو كنند و گذشت نمايند. مگر دوست نداريد كه خدا بر شما ببخشايد؟ و خدا آمرزنده مهربان است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmdcccxiv{بى‌گمان، كسانى كه به زنان پاكدامن بى‌خبر [از همه جا] و با ايمان نسبت زنا مى‌دهند، در دنيا و آخرت لعنت شده‌اند، و براى آنها عذابى سخت خواهد بود،\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmdcccxv{در روزى كه زبان و دستها و پاهايشان، بر ضد آنان براى آنچه انجام مى‌دادند، شهادت مى‌دهند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmdcccxvi{آن روز خدا جزاى شايسته آنان را به طور كامل مى‌دهد و خواهند دانست كه خدا همان حقيقت آشكار است.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmdcccxvii{زنان پليد براى مردان پليدند، و مردان پليد براى زنان پليد. و زنان پاك براى مردان پاكند، و مردان پاك براى زنان پاك. اينان از آنچه در باره ايشان مى‌گويند بر كنارند، براى آنان آمرزش و روزىِ نيكو خواهد بود.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmdcccxviii{اى كسانى كه ايمان آورده‌ايد، به خانه‌هايى كه خانه‌هاى شما نيست داخل مشويد تا اجازه بگيريد و بر اهل آن سلام گوييد. اين براى شما بهتر است، باشد كه پند گيريد.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmdcccxix{و اگر كسى را در آن نيافتيد، پس داخلِ آن مشويد تا به شما اجازه داده شود؛ و اگر به شما گفته شد: «برگرديد» برگرديد، كه آن براى شما سزاوارتر است، و خدا به آنچه انجام مى‌دهيد داناست.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmdcccxx{بر شما گناهى نيست كه به خانه‌هاى غيرمسكونى -كه در آنها براى شما استفاده‌اى است- داخل شويد، و خدا آنچه را آشكار و آنچه را پنهان مى‌داريد مى‌داند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmdcccxxi{به مردان با ايمان بگو: «ديده فرو نهند و پاكدامنى ورزند، كه اين براى آنان پاكيزه‌تر است، زيرا خدا به آنچه مى‌كنند آگاه است.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmdcccxxii{و به زنان با ايمان بگو: «ديدگان خود را [از هر نامحرمى‌] فرو بندند و پاكدامنى ورزند و زيورهاى خود را آشكار نگردانند مگر آنچه كه طبعاً از آن پيداست. و بايد روسرى خود را بر گردن خويش [فرو ]اندازند، و زيورهايشان را جز براى شوهرانشان يا پدرانشان يا پدران شوهرانشان يا پسرانشان يا پسران شوهرانشان يا برادرانشان يا پسران برادرانشان يا پسران خواهرانشان يا زنان [همكيش‌] خود يا كنيزانشان يا خدمتكاران مرد كه [از زن‌] بى‌نيازند يا كودكانى كه بر عورتهاى زنان وقوف حاصل نكرده‌اند، آشكار نكنند؛ و پاهاى خود را [به گونه‌اى به زمين‌] نكوبند تا آنچه از زينتشان نهفته مى‌دارند معلوم گردد. اى مؤمنان، همگى [از مرد و زن‌] به درگاه خدا توبه كنيد، اميد كه رستگار شويد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmdcccxxiii{بى‌همسران خود، و غلامان و كنيزان درستكارتان را همسر دهيد. اگر تنگدستند، خداوند آنان را از فضل خويش بى‌نياز خواهد كرد، و خدا گشايشگر داناست.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmdcccxxiv{و كسانى كه [وسيله‌] زناشويى نمى‌يابند، بايد عفت ورزند تا خدا آنان را از فضل خويش بى‌نياز گرداند. و از ميان غلامانتان، كسانى كه در صددند با قرارداد كتبى، خود را آزاد كنند، اگر در آنان خيرى [و توانايى پرداخت مال‌] مى‌يابيد، قرارِ بازخريدِ آنها را بنويسيد، و از آن مالى كه خدا به شما داده است به ايشان بدهيد [تا تدريجاً خود را آزاد كنند]، و كنيزان خود را -در صورتى كه تمايل به پاكدامنى دارند- براى اينكه متاع زندگى دنيا را بجوييد، به زنا وادار مكنيد، و هر كس آنان را به زور وادار كند، در حقيقت، خدا پس از اجبار نمودن ايشان، [نسبت به آنها] آمرزنده مهربان است.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmdcccxxv{و قطعاً به سوى شما آياتى روشنگر و خبرى از كسانى كه پيش از شما روزگار به سر برده‌اند، و موعظه‌اى براى اهل تقوا فرود آورده‌ايم.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmdcccxxvi{خدا نور آسمانها و زمين است. مَثَل نور او چون چراغدانى است كه در آن چراغى، و آن چراغ در شيشه‌اى است. آن شيشه گويى اخترى درخشان است كه از درخت خجسته زيتونى كه نه شرقى است و نه غربى، افروخته مى‌شود. نزديك است كه روغنش -هر چند بدان آتشى نرسيده باشد- روشنى بخشد. روشنىِ بر روى روشنى است. خدا هر كه را بخواهد با نور خويش هدايت مى‌كند، و اين مَثَلها را خدا براى مردم مى‌زند و خدا به هر چيزى داناست.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmdcccxxvii{در خانه‌هايى كه خدا رخصت داده كه [قدر و منزلت‌] آنها رفعت يابد و نامش در آنها ياد شود. در آن [خانه‌]ها هر بامداد و شامگاه او را نيايش مى‌كنند:\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmdcccxxviii{مردانى كه نه تجارت و نه داد و ستدى، آنان را از ياد خدا و برپا داشتن نماز و دادن زكات، به خود مشغول نمى‌دارد، و از روزى كه دلها و ديده‌ها در آن زيرورو مى‌شود مى‌هراسند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmdcccxxix{تا خدا بهتر از آنچه انجام مى‌دادند، به ايشان جزا دهد و از فضل خود بر آنان بيفزايد، و خدا[ست كه‌] هر كه را بخواهد بى‌حساب روزى مى‌دهد.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmdcccxxx{و كسانى كه كفر ورزيدند، كارهايشان چون سرابى در زمينى هموار است كه تشنه، آن را آبى مى‌پندارد، تا چون بدان رسد آن را چيزى نيابد و خدا را نزد خويش يابد و حسابش را تمام به او دهد و خدا زودشمار است.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxi{يا [كارهايشان‌] مانند تاريكيهايى است كه در دريايى ژرف است كه موجى آن را مى‌پوشاند [و] روى آن موجى [ديگر] است [و] بالاى آن ابرى است. تاريكيهايى است كه بعضى بر روى بعضى قرار گرفته است. هر گاه [غرقه‌] دستش را بيرون آورد، به زحمت آن را مى‌بيند، و خدا به هر كس نورى نداده باشد او را هيچ نورى نخواهد بود.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxii{آيا ندانسته‌اى كه هر كه [و هر چه‌] در آسمانها و زمين است براى خدا تسبيح مى‌گويند، و پرندگان [نيز] در حالى كه در آسمان پر گشوده‌اند [تسبيح او مى‌گويند]؟ همه ستايش و نيايش خود را مى‌دانند، و خدا به آنچه مى‌كنند داناست.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxiii{و فرمانروايى آسمانها و زمين از آنِ خداست، و بازگشت [همه‌] به سوى خداست.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxiv{آيا ندانسته‌اى كه خدا[ست كه‌] ابر را به آرامى مى‌راند، سپس ميان [اجزاء] آن پيوند مى‌دهد، آنگاه آن را متراكم مى‌سازد، پس دانه‌هاى باران را مى‌بينى كه از خلال آن بيرون مى‌آيد، و [خداست كه‌] از آسمان از كوههايى [از ابر يخ‌زده ]كه در آنجاست تگرگى فرو مى‌ريزد؛ و هر كه را بخواهد بدان گزند مى‌رساند، و آن را از هر كه بخواهد باز مى‌دارد. نزديك است روشنىِ برقش چشمها را بِبَرَد.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxv{خداست كه شب و روز را با هم جابجا مى‌كند. قطعاً در اين [تبديل‌] براى ديده‌وران [درس‌] عبرتى است.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxvi{و خداست كه هر جنبنده‌اى را [ابتدا] از آبى آفريد. پس پاره‌اى از آنها بر روى شكم راه مى‌روند و پاره‌اى از آنها بر روى دو پا و بعضى از آنها بر روى چهار [پا] راه مى‌روند. خدا هر چه بخواهد مى‌آفريند. در حقيقت، خدا بر هر چيزى تواناست.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxvii{قطعاً آياتى روشنگر فرود آورده‌ايم، و خدا هر كه را بخواهد به راه راست هدايت مى‌كند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxviii{و مى‌گويند: «به خدا و پيامبر [او] گرويديم و اطاعت كرديم.» آنگاه دسته‌اى از ايشان پس از اين [اقرار] روى برمى‌گردانند، و آنان مؤمن نيستند.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmdcccxxxix{و چون به سوى خدا و پيامبر او خوانده شوند، تا ميان آنان داورى كند، بناگاه دسته‌اى از آنها روى برمى‌تابند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmdcccxl{و اگر حق به جانب ايشان باشد، به حال اطاعت به سوى او مى‌آيند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmdcccxli{آيا در دلهايشان بيمارى است، يا شك دارند، يا از آن مى‌ترسند كه خدا و فرستاده‌اش بر آنان ستم ورزند؟ [نه،] بلكه خودشان ستمكارند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmdcccxlii{گفتار مؤمنان -وقتى به سوى خدا و پيامبرش خوانده شوند تا ميانشان داورى كند- تنها اين است كه مى‌گويند: «شنيديم و اطاعت كرديم.» اينانند كه رستگارند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmdcccxliii{و كسى كه خدا و فرستاده او را فرمان برد، و از خدا بترسد و از او پروا كند؛ آنانند كه خود كاميابند.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmdcccxliv{و با سوگندهاى سخت خود به خدا سوگند ياد كردند كه اگر به آنان فرمان دهى، بى شك [براى جهاد] بيرون خواهند آمد. بگو: «سوگند مخوريد. اطاعتى پسنديده [بهتر است‌] كه خدا به آنچه مى‌كنيد داناست.»\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmdcccxlv{بگو: «خدا و پيامبر را اطاعت كنيد. پس اگر پشت نموديد، [بدانيد كه‌] بر عهده اوست آنچه تكليف شده و بر عهده شماست آنچه موظّف هستيد. و اگر اطاعتش كنيد راه خواهيد يافت، و بر فرستاده [خدا] جز ابلاغ آشكار [مأموريتى‌] نيست.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmdcccxlvi{خدا به كسانى از شما كه ايمان آورده و كارهاى شايسته كرده‌اند، وعده داده است كه حتماً آنان را در اين سرزمين جانشين [خود] قرار دهد؛ همان گونه كه كسانى را كه پيش از آنان بودند جانشين [خود] قرار داد، و آن دينى را كه برايشان پسنديده است به سودشان مستقر كند، و بيمشان را به ايمنى مبدل گرداند، [تا] مرا عبادت كنند و چيزى را با من شريك نگردانند، و هر كس پس از آن به كفر گرايد؛ آنانند كه نافرمانند.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmdcccxlvii{و نماز را برپا كنيد و زكات را بدهيد و پيامبر [خدا] را فرمان بريد تا مورد رحمت قرار گيريد.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmdcccxlviii{و مپندار كسانى كه كفر ورزيدند [ما را] در زمين درمانده مى‌كنند؛ جايگاهشان در آتش است و چه بد بازگشتگاهى است.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmdcccxlix{اى كسانى كه ايمان آورده‌ايد، قطعاً بايد غلام و كنيزهاى شما و كسانى از شما كه به [سنِ‌] بلوغ نرسيده‌اند سه بار در شبانه روز از شما كسب اجازه كنند: پيش از نماز بامداد، و نيمروز كه جامه‌هاى خود را بيرون مى‌آوريد، و پس از نماز شامگاهان. [اين،] سه هنگام برهنگى شماست، نه بر شما و نه بر آنان گناهى نيست كه غير از اين [سه هنگام‌] گرد يكديگر بچرخيد [و با هم معاشرت نماييد]. خداوند آيات [خود] را اين گونه براى شما بيان مى‌كند، و خدا داناى سنجيده‌كار است.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmdcccl{و چون كودكان شما به [سنِ‌] بلوغ رسيدند، بايد از شما كسب اجازه كنند؛ همان گونه كه آنان كه پيش از ايشان بودند كسب اجازه كردند. خدا آيات خود را اين گونه براى شما بيان مى‌دارد، و خدا داناى سنجيده‌كار است.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmdcccli{و بر زنان از كار افتاده‌اى كه [ديگر] اميد زناشويى ندارند گناهى نيست كه پوشش خود را كنار نهند [به شرطى كه‌] زينتى را آشكار نكنند؛ و عفّت ورزيدن براى آنها بهتر است، و خدا شنواى داناست.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmdccclii{بر نابينا و لنگ و بيمار و بر شما ايرادى نيست كه از خانه‌هاى خودتان بخوريد، يا از خانه‌هاى پدرانتان يا خانه‌هاى مادرانتان يا خانه‌هاى برادرانتان يا خانه‌هاى خواهرانتان يا خانه‌هاى عموهايتان يا خانه‌هاى عمّه‌هايتان يا خانه‌هاى داييهايتان يا خانه‌هاى خاله‌هايتان يا آن [خانه‌هايى‌] كه كليدهايش را در اختيار داريد يا [خانه‌] دوستتان. [هم چنين‌] بر شما باكى نيست كه با هم بخوريد يا پراكنده. پس چون به خانه‌هايى [كه گفته شد ]درآمديد، به يكديگر سلام كنيد؛ درودى كه نزد خدا مبارك و خوش است. خداوند آيات [خود] را اين گونه براى شما بيان مى‌كند، اميد كه بينديشيد.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmdcccliii{جز اين نيست كه مؤمنان كسانى‌اند كه به خدا و پيامبرش گرويده‌اند، و هنگامى كه با او بر سر كارى اجتماع كردند، تا از وى كسب اجازه نكنند نمى‌روند. در حقيقت، كسانى كه از تو كسب اجازه مى‌كنند؛ آنانند كه به خدا و پيامبرش ايمان دارند. پس چون براى برخى از كارهايشان از تو اجازه خواستند، به هر كس از آنان كه خواستى اجازه ده و برايشان آمرزش بخواه كه خدا آمرزنده مهربان است.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmdcccliv{خطاب كردن پيامبر را در ميان خود، مانند خطاب كردن بعضى از خودتان به بعضى [ديگر] قرار مدهيد. خدا مى‌داند [چه‌] كسانى از شما دزدانه [از نزد او] مى‌گريزند. پس كسانى كه از فرمان او تمرّد مى‌كنند بترسند كه مبادا بلايى بديشان رسد يا به عذابى دردناك گرفتار شوند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmdccclv{هش‌دار كه آنچه در آسمانها و زمين است از آنِ خداست. به يقين آنچه را كه بر آنيد مى‌داند، و روزى كه به سوى او بازگردانيده مى‌شوند آنان را [از حقيقت‌] آنچه انجام داده‌اند خبر مى‌دهد، و خدا به هر چيزى داناست.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmdccclvi{\basmalahfa بزرگ [و خجسته‌] است كسى كه بر بنده خود، فرقان [=كتاب جداسازنده حق از باطل‌] را نازل فرمود، تا براى جهانيان هشداردهنده‌اى باشد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmdccclvii{همان كس كه فرمانروايى آسمانها و زمين از آنِ اوست، و فرزندى اختيار نكرده و براى او شريكى در فرمانروايى نبوده است، و هر چيزى را آفريده و بدان گونه كه درخور آن بوده اندازه‌گيرى كرده است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmdccclviii{و به جاى او خدايانى براى خود گرفته‌اند كه چيزى را خلق نمى‌كنند و خود خلق شده‌اند و براى خود نه زيانى را در اختيار دارند و نه سودى را، و نه مرگى را در اختيار دارند و نه حياتى و نه رستاخيزى را.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmdccclix{و كسانى كه كفر ورزيدند، گفتند: «اين [كتاب‌] جز دروغى كه آن را بربافته [چيزى‌] نيست، و گروهى ديگر او را بر آن يارى كرده‌اند.» و قطعاً [با چنين نسبتى‌] ظلم و بهتانى به پيش آوردند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmdccclx{و گفتند: «افسانه‌هاى پيشينيان است كه آنها را براى خود نوشته، و صبح و شام بر او املا مى‌شود.»\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmdccclxi{بگو: «آن را كسى نازل ساخته است كه راز نهانها را در آسمانها و زمين مى‌داند، و هموست كه همواره آمرزنده مهربان است.»\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmdccclxii{و گفتند: «اين چه پيامبرى است كه غذا مى‌خورد و در بازارها راه مى‌رود؟ چرا فرشته‌اى به سوى او نازل نشده تا همراه وى هشداردهنده باشد؟\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmdccclxiii{يا گنجى به طرف او افكنده نشده يا باغى ندارد كه از [بار و بَر] آن بخورد؟» و ستمكاران گفتند: « جز مردى افسون‌شده را دنبال نمى‌كنيد.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmdccclxiv{بنگر چگونه براى تو مَثَلها زدند و گمراه شدند؛ در نتيجه نمى‌توانند راهى بيابند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmdccclxv{بزرگ [و خجسته‌] است كسى كه اگر بخواهد بهتر از اين را براى تو قرار مى‌دهد: باغهايى كه جويبارها از زير [درختان‌] آن روان خواهد بود، و براى تو كاخها پديد مى‌آورد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmdccclxvi{[نه!] بلكه [آنها] رستاخيز را دروغ خواندند، و براى هر كس كه رستاخيز را دروغ خوانَد آتش سوزان آماده كرده‌ايم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmdccclxvii{چون [دوزخ‌] از فاصله‌اى دور، آنان را ببيند، خشم و خروشى از آن مى‌شنوند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmdccclxviii{و چون آنان را در تنگنايى از آن به زنجير كشيده بيندازند، آنجاست كه مرگ [خود] را مى‌خواهند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmdccclxix{«امروز يك بار هلاك [خود] را مخواهيد و بسيار هلاك [خود] را بخواهيد.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmdccclxx{بگو: «آيا اين [عقوبت‌] بهتر است يا بهشت جاويدان كه به پرهيزگاران وعده داده شده است كه پاداش و سرانجام آنان است؟»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmdccclxxi{جاودانه هر چه بخواهند در آنجا دارند. پروردگار تو مسؤول [تحقق‌] اين وعده است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmdccclxxii{و روزى كه آنان را با آنچه به جاى خدا مى‌پرستند، محشور مى‌كند، پس مى‌فرمايد: «آيا شما اين بندگان مرا به بيراهه كشانديد يا خود گمراه شدند؟»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmdccclxxiii{مى‌گويند: «منزهى تو، ما را نسزد كه جز تو دوستى براى خود بگيريم، ولى تو آنان و پدرانشان را برخوردار كردى تا [آنجا كه‌] ياد [تو] را فراموش كردند و گروهى هلاك‌شده، بودند.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmdccclxxiv{قطعاً [خدايانتان‌] در آنچه مى‌گفتيد، شما را تكذيب كردند؛ در نتيجه نه مى‌توانيد [عذاب را از خود] دفع كنيد و نه [خود را] يارى نماييد و هر كس از شما شرك ورزد عذابى سهمگين به او مى‌چشانيم.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmdccclxxv{و پيش از تو پيامبران [خود] را نفرستاديم جز اينكه آنان [نيز] غذا مى‌خوردند و در بازارها راه مى‌رفتند، و برخى از شما را براى برخى ديگر [وسيله‌] آزمايش قرار داديم. آيا شكيبايى مى‌كنيد؟ و پروردگار تو همواره بيناست.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmdccclxxvi{و كسانى كه به لقاى ما اميد ندارند، گفتند: «چرا فرشتگان بر ما نازل نشدند يا پروردگارمان را نمى‌بينيم؟» قطعاً در مورد خود تكبر ورزيدند و سخت سركشى كردند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmdccclxxvii{روزى كه فرشتگان را ببينند، آن روز براى گناهكاران بشارتى نيست، و مى‌گويند: «دور و ممنوع [آيد از رحمت خدا].»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmdccclxxviii{و به هر گونه كارى كه كرده‌اند مى‌پردازيم و آن را [چون‌] گَردى پراكنده مى‌سازيم.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmdccclxxix{آن روز، جايگاه اهل بهشت بهتر و استراحتگاهشان نيكوتر است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmdccclxxx{و روزى كه آسمان با ابرى سپيد از هم مى‌شكافد و فرشتگان نزول يابند!\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxi{آن روز، فرمانروايى بحق، از آنِ [خداىِ‌] رحمان است و روزى است كه بر كافران بسى دشوار است.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxii{و روزى است كه ستمكار دستهاى خود را مى‌گزد [و] مى‌گويد: «اى كاش با پيامبر راهى برمى‌گرفتم.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxiii{«اى واى، كاش فلانى را دوست [خود] نگرفته بودم.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxiv{او [بود كه‌] مرا به گمراهى كشانيد پس از آنكه قرآن به من رسيده بود.» و شيطان همواره فروگذارنده انسان است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxv{و پيامبر [خدا] گفت: «پروردگارا، قوم من اين قرآن را رها كردند.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxvi{و اين گونه براى هر پيامبرى دشمنى از گناهكاران قرار داديم، و همين بس كه پروردگارت راهبر و ياور توست.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxvii{و كسانى كه كافر شدند، گفتند: «چرا قرآن يكجا بر او نازل نشده است؟» اين گونه [ما آن را به تدريج نازل كرديم‌] تا قلبت را به وسيله آن استوار گردانيم، و آن را به آرامى [بر تو] خوانديم.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxviii{و براى تو مَثَلى نياوردند، مگر آنكه [ما] حق را با نيكوترين بيان براى تو آورديم.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmdccclxxxix{كسانى كه -به رو درافتاده- به سوى جهنم رانده مى‌شوند، آنان بدترين جاى و گم‌ترين راه را دارند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmdcccxc{و به يقين [ما] به موسى كتاب [آسمانى‌] عطا كرديم، و برادرش هارون را همراه او دستيار[ش‌] گردانيديم.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmdcccxci{پس گفتيم: «هر دو به سوى قومى كه نشانه‌هاى ما را به دروغ گرفتند برويد.» پس [ما] آنان را به سختى هلاك نموديم.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmdcccxcii{و قوم نوح را آنگاه كه پيامبران [خدا] را تكذيب كردند غرقشان ساختيم، و آنان را براى [همه‌] مردم عبرتى گردانيديم و براى ستمكاران عذابى پر درد آماده كرده‌ايم.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmdcccxciii{و [نيز] عاديان و ثموديان و اصحاب رَسّ و نسلهاى بسيارى ميان اين [جماعتها] را [هلاك كرديم‌].\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmdcccxciv{و براى همه آنان مَثَلها زديم و همه را زير و زَبَر كرديم.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmdcccxcv{و قطعاً بر شهرى كه باران بلا بر آن بارانده شد گذشته‌اند؛ مگر آن را نديده‌اند؟ [چرا،] ولى اميد به زنده‌شدن ندارند.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmdcccxcvi{و چون تو را ببينند، جز به ريشخندت نگيرند، [كه:] «آيا اين همان كسى است كه خدا او را به رسالت فرستاده است؟\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmdcccxcvii{چيزى نمانده بود كه ما را از خدايانمان -اگر بر آن ايستادگى نمى‌كرديم- منحرف كند. «و هنگامى كه عذاب را مى‌بينند به زودى خواهند دانست چه كسى گمراه‌تر است.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmdcccxcviii{آيا آن كس كه هواى [نفس‌] خود را معبود خويش گرفته است ديدى؟ آيا [مى‌توانى‌] ضامن او باشى؟\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmdcccxcix{يا گمان دارى كه بيشترشان مى‌شنوند يا مى‌انديشند؟ آنان جز مانند ستوران نيستند، بلكه گمراه‌ترند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmcm{آيا نديده‌اى كه پروردگارت چگونه سايه را گسترده است؟ و اگر مى‌خواست، آن را ساكن قرار مى‌داد، آنگاه خورشيد را بر آن دليل گردانيديم.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmcmi{سپس آن [سايه‌] را اندك اندك به سوى خود بازمى‌گيريم.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmcmii{و اوست كسى كه شب را براى شما پوششى قرار داد و خواب را [مايه‌] آرامشى. و روز را زمان برخاستن [شما] گردانيد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmcmiii{و اوست آن كس كه بادها را نويدى پيشاپيش رحمت خويش [=باران‌] فرستاد و از آسمان، آبى پاك فرود آورديم،\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmcmiv{تا به وسيله آن سرزمينى پژمرده را زنده گردانيم و آن را به آنچه خلق كرده‌ايم -از دامها و انسانهاى بسيار- بنوشانيم.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmcmv{و قطعاً آن [پند] را ميان آنان گوناگون ساختيم تا توجه پيدا كنند، و[لى ] بيشتر مردم جز ناسپاسى نخواستند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmcmvi{و اگر مى‌خواستيم قطعاً در هر شهرى هشداردهنده‌اى برمى‌انگيختيم.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmcmvii{پس، از كافران اطاعت مكن، و با [الهام گرفتن از] قرآن با آنان به جهادى بزرگ بپرداز.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmcmviii{و اوست كسى كه دو دريا را موج‌زنان به سوى هم روان كرد: اين يكى شيرين [و] گوارا و آن يكى شور [و] تلخ است؛ و ميان آن دو، مانع و حريمى استوار قرار داد.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmcmix{و اوست كسى كه از آب، بشرى آفريد و او را [داراى خويشاوندى‌] نسبى و دامادى قرار داد، و پروردگار تو همواره تواناست.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmcmx{و غير از خدا چيزى را مى‌پرستند كه نه سودشان مى‌دهد و نه زيانشان مى‌رساند؛ و كافر همواره در برابر پروردگار خود همپشت [شيطان‌] است.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmcmxi{و تو را جز بشارتگر و بيم‌دهنده نفرستاديم.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmcmxii{بگو: «بر اين [رسالت‌] اجرى از شما طلب نمى‌كنم، جز اينكه هر كس بخواهد راهى به سوى پروردگارش [در پيش‌] گيرد.»\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmcmxiii{و بر آن زنده كه نمى‌ميرد توكل كن و به ستايش او تسبيح گوى؛ و همين بس كه او به گناهان بندگانش آگاه است.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmcmxiv{همان كسى كه آسمانها و زمين، و آنچه را كه ميان آن دو است، در شش روز آفريد. آنگاه بر عرش استيلا يافت. رحمتگر عام [اوست‌]. در باره وى از خبره‌اى بپرس [كه مى‌داند].\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmcmxv{و چون به آنان گفته شود: «[خداى‌] رحمان را سجده كنيد»، مى‌گويند: «رحمان چيست؟ آيا براى چيزى كه ما را [بدان‌] فرمان مى‌دهى سجده كنيم؟» و بر رميدنشان مى‌افزايد.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmcmxvi{[فرخنده و] بزرگوار است آن كسى كه در آسمان برجهايى نهاد، و در آن، چراغ و ماهى نوربخش قرار داد.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmcmxvii{و اوست كسى كه براى هر كس كه بخواهد عبرت گيرد يا بخواهد سپاسگزارى نمايد، شب و روز را جانشين يكديگر گردانيد.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmcmxviii{و بندگان خداى رحمان كسانى‌اند كه روى زمين به نرمى گام برمى‌دارند؛ و چون نادانان ايشان را طرف خطاب قرار دهند به ملايمت پاسخ مى‌دهند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmcmxix{و آنانند كه در حال سجده يا ايستاده، شب را به روز مى‌آورند.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmcmxx{و كسانى‌اند كه مى‌گويند: «پروردگارا، عذاب جهنم را از ما بازگردان كه عذابش سخت و دايمى است.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmcmxxi{و در حقيقت، آن بد قرارگاه و جايگاهى است.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmcmxxii{و كسانى‌اند كه چون انفاق كنند، نه ولخرجى مى‌كنند و نه تنگ مى‌گيرند، و ميان اين دو [روش‌] حد وسط را برمى‌گزينند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmcmxxiii{و كسانى‌اند كه با خدا معبودى ديگر نمى‌خوانند و كسى را كه خدا [خونش را] حرام كرده است جز به حق نمى‌كُشند، و زنا نمى‌كنند، و هر كس اينها را انجام دهد سزايش را دريافت خواهد كرد.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmcmxxiv{براى او در روز قيامت عذاب دو چندان مى‌شود و پيوسته در آن خوار مى‌ماند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmcmxxv{مگر كسى كه توبه كند و ايمان آورد و كار شايسته كند. پس خداوند بديهايشان را به نيكيها تبديل مى‌كند، و خدا همواره آمرزنده مهربان است.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmcmxxvi{و هر كس توبه كند و كار شايسته انجام دهد، در حقيقت به سوى خدا بازمى‌گردد.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmcmxxvii{و كسانى‌اند كه گواهى دروغ نمى‌دهند؛ و چون بر لغو بگذرند با بزرگوارى مى‌گذرند.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmcmxxviii{و كسانى‌اند كه چون به آيات پروردگارشان تذكر داده شوند، كر و كور روى آن نمى‌افتند.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmcmxxix{و كسانى‌اند كه مى‌گويند: «پروردگارا، به ما از همسران و فرزندانمان آن ده كه مايه روشنى چشمان [ما] باشد، و ما را پيشواى پرهيزگاران گردان.»\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmcmxxx{اينانند كه به پاس آنكه صبر كردند، غرفه‌[هاى بهشت را] پاداش خواهند يافت و در آنجا با سلام و درود مواجه خواهند شد.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmcmxxxi{در آنجا، جاودانه خواهند ماند. چه خوش قرارگاه و مقامى!\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmcmxxxii{بگو: «اگر دعاى شما نباشد، پروردگارم هيچ اعتنايى به شما نمى‌كند. در حقيقت شما به تكذيب پرداخته‌ايد و به زودى [عذاب بر شما] لازم خواهد شد.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmcmxxxiii{\basmalahfa طا، سين، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmcmxxxiv{اين است آيه‌هاى كتاب روشنگر.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmcmxxxv{شايد تو از اينكه [مشركان‌] ايمان نمى‌آورند، جان خود را تباه سازى.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmcmxxxvi{اگر بخواهيم، معجزه‌اى از آسمان بر آنان فرود مى‌آوريم، تا در برابر آن، گردنهايشان خاضع گردد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmcmxxxvii{و هيچ تذكر جديدى از سوى [خداى‌] رحمان برايشان نيامد جز اينكه همواره از آن روى برمى‌تافتند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmcmxxxviii{[آنان‌] در حقيقت به تكذيب پرداختند، و به زودى خبر آنچه كه بدان ريشخند مى كردند، بديشان خواهد رسيد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmcmxxxix{مگر در زمين ننگريسته‌اند كه چه قدر در آن از هر گونه جفتهاى زيبا رويانيده‌ايم؟\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmcmxl{قطعاً در اين [هنرنمايى‌] عبرتى است و[لى‌] بيشترشان ايمان‌آورنده نيستند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmcmxli{و در حقيقت، پروردگار تو همان شكست‌ناپذير مهربان است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmcmxlii{و [ياد كن‌] هنگامى را كه پروردگارت موسى را ندا درداد كه به سوى قوم ستمكار برو:\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmcmxliii{قوم فرعون؛ آيا پروا ندارند؟!\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmcmxliv{گفت: «پروردگارا، مى‌ترسم مرا تكذيب كنند،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmcmxlv{و سينه‌ام تنگ مى‌گردد، و زبانم باز نمى‌شود، پس به سوى هارون بفرست.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmcmxlvi{و [از طرفى‌] آنان بر [گردن‌] من خونى دارند و مى‌ترسم مرا بكشند.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmcmxlvii{فرمود: «نه، چنين نيست؛ نشانه‌هاى ما را [براى آنان‌] بِبَريد كه ما با شما شنونده‌ايم.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmcmxlviii{پس به سوى فرعون برويد و بگوييد: «ما پيامبر پروردگار جهانيانيم،\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmcmxlix{فرزندان اسرائيل را با ما بفرست.»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmcml{[فرعون‌] گفت: «آيا تو را از كودكى در ميان خود نپرورديم و ساليانى چند از عمرت را پيش ما نماندى؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmcmli{و [سرانجام‌] كار خود را كردى، و تو از ناسپاسانى.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmcmlii{گفت: «آن را هنگامى مرتكب شدم كه از گمراهان بودم،\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmcmliii{و چون از شما ترسيدم، از شما گريختم، تا پروردگارم به من دانش بخشيد و مرا از پيامبران قرار داد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmcmliv{و [آيا] اينكه فرزندان اسرائيل را بنده [خود] ساخته‌اى نعمتى است كه منّتش را بر من مى‌نهى؟»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmcmlv{فرعون گفت: «و پروردگار جهانيان چيست؟»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmcmlvi{گفت: «پروردگار آسمانها و زمين و آنچه ميان آن دو است-اگر اهل يقين باشيد.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmcmlvii{[فرعون‌] به كسانى كه پيرامونش بودند گفت: «آيا نمى‌شنويد؟»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmcmlviii{[موسى دوباره‌] گفت: «پروردگار شما و پروردگار پدران پيشين شما.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmcmlix{[فرعون‌] گفت: «واقعاً اين پيامبرى كه به سوى شما فرستاده شده، سخت ديوانه است.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmcmlx{[موسى‌] گفت: «پروردگار خاور و باختر و آنچه ميان آن دو است-اگر تعقّل كنيد.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmcmlxi{[فرعون‌] گفت: «اگر خدايى غير از من اختيار كنى قطعاً تو را از [جمله‌] زندانيان خواهم ساخت.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmcmlxii{گفت: «گر چه براى تو چيزى آشكار بياورم؟»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmcmlxiii{گفت: «اگر راست مى‌گويى آن را بياور.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmcmlxiv{پس عصاى خود بيفكند و بناگاه آن اژدرى نمايان شد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmcmlxv{و دستش را بيرون كشيد و بناگاه آن براى تماشاگران سپيد مى‌نمود.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmcmlxvi{[فرعون‌] به سرانى كه پيرامونش بودند گفت: «واقعاً اين ساحرى بسيار داناست.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmcmlxvii{مى‌خواهد با سحر خود، شما را از سرزمينتان بيرون كند، اكنون چه رأى مى‌دهيد؟»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmcmlxviii{گفتند: «او و برادرش را در بند دار و گردآورندگان را به شهرها بفرست،\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmcmlxix{تا هر ساحر ماهرى را نزد تو بياورند.»\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmcmlxx{پس ساحران براى موعدِ روزى معلوم گردآورى شدند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmcmlxxi{و به توده مردم گفته شد: «آيا شما هم جمع خواهيد شد؟\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmcmlxxii{بدين اميد كه اگر ساحران غالب شدند از آنان پيروى كنيم؟»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmcmlxxiii{و چون ساحران پيش فرعون آمدند، گفتند: «آيا اگر ما غالب آييم واقعاً براى ما مزدى خواهد بود؟»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmcmlxxiv{گفت: «آرى، و در آن صورت شما حتماً از [زمره‌] مقرّبان خواهيد شد.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmcmlxxv{موسى به آنان گفت: «آنچه را شما مى‌اندازيد بيندازيد.»\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmcmlxxvi{پس ريسمانها و چوبدستى‌هايشان را انداختند و گفتند: «به عزّت فرعون كه ما حتماً پيروزيم.»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmcmlxxvii{پس موسى عصايش را انداخت و بناگاه هر چه را به دروغ برساخته بودند بلعيد.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmcmlxxviii{در نتيجه، ساحران به حالت سجده درافتادند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmcmlxxix{گفتند: «به پروردگار جهانيان ايمان آورديم:\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmcmlxxx{پروردگار موسى و هارون.»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxi{گفت: « [آيا] پيش از آنكه به شما اجازه دهم به او ايمان آورديد؟ قطعاً او همان بزرگ شماست كه به شما سحر آموخته است. به زودى خواهيد دانست. حتماً دستها و پاهاى شما را از چپ و راست خواهم بريد و همه‌تان را به دار خواهم آويخت.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxii{گفتند: «باكى نيست، ما روى به سوى پروردگار خود مى‌آوريم.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxiii{ما اميدواريم كه پروردگارمان گناهانمان را بر ما ببخشايد، [چرا] كه نخستين ايمان‌آورندگان بوديم.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxiv{و به موسى وحى كرديم كه: «بندگان مرا شبانه حركت ده، زيرا شما مورد تعقيب قرار خواهيد گرفت.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxv{پس فرعون مأمورانِ جمع‌آورىِ [خود را] به شهرها فرستاد،\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxvi{[و گفت:] «اينها عده‌اى ناچيزند.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxvii{و راستى آنها ما را بر سر خشم آورده‌اند،\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxviii{و[لى‌] ما همگى به حال آماده‌باش درآمده‌ايم.»\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmcmlxxxix{سرانجام، ما آنان را از باغستانها و چشمه‌سارها،\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmcmxc{و گنجينه‌ها و جايگاه‌هاى پر ناز و نعمت بيرون كرديم.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmcmxci{[اراده ما] چنين بود، و آن [نعمتها] را به فرزندان اسرائيل ميراث داديم.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmcmxcii{پس هنگام برآمدن آفتاب، آنها را تعقيب كردند.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmcmxciii{چون دو گروه، همديگر را ديدند، ياران موسى گفتند: «ما قطعاً گرفتار خواهيم شد.»\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmcmxciv{گفت: «چنين نيست، زيرا پروردگارم با من است و به زودى مرا راهنمايى خواهد كرد.»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmcmxcv{پس به موسى وحى كرديم: «با عصاى خود بر اين دريا بزن.» تا از هم شكافت، و هر پاره‌اى همچون كوهى سترگ بود.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmcmxcvi{و ديگران را بدانجا نزديك گردانيديم.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmcmxcvii{و موسى و همه كسانى را كه همراه او بودند نجات داديم؛\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmcmxcviii{آنگاه ديگران را غرق كرديم.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmcmxcix{مسلماً در اين [واقعه‌] عبرتى بود، و[لى‌] بيشترشان ايمان‌آورنده نبودند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmm{و قطعاً پروردگار تو همان شكست‌ناپذير مهربان است.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmi{و بر آنان گزارش ابراهيم را بخوان.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmii{آنگاه كه به پدر خود و قومش گفت: «چه مى‌پرستيد؟»\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmiii{گفتند: «بتانى را مى‌پرستيم و همواره ملازم آنهاييم.»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmiv{گفت: «آيا وقتى دعا مى‌كنيد، از شما مى‌شنوند؟\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmv{يا به شما سود يا زيان مى‌رسانند؟»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmvi{گفتند: «نه، بلكه پدران خود را يافتيم كه چنين مى‌كردند.»\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmvii{گفت: «آيا در آنچه مى‌پرستيده‌ايد تأمّل كرده‌ايد؟\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmviii{شما و پدران پيشين شما؟\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmix{قطعاً همه آنها -جز پروردگار جهانيان- دشمن منند.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmx{آن كس كه مرا آفريده و همو راهنماييم مى‌كند،\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmxi{و آن كس كه او به من خوراك مى‌دهد و سيرابم مى‌گرداند،\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmxii{و چون بيمار شوم او مرا درمان مى‌بخشد،\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmxiii{و آن كس كه مرا مى‌ميراند و سپس زنده‌ام مى‌گرداند،\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmxiv{و آن كس كه اميد دارم روز پاداش، گناهم را بر من ببخشايد.»\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmxv{پروردگارا، به من دانش عطا كن و مرا به صالحان ملحق فرماى،\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmxvi{و براى من در [ميان‌] آيندگان آوازه نيكو گذار،\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmmxvii{و مرا از وارثان بهشت پر نعمت گردان،\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmmxviii{و بر پدرم ببخشاى كه او از گمراهان بود،\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmmxix{و روزى كه [مردم‌] برانگيخته مى‌شوند رسوايم مكن:\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmmxx{روزى كه هيچ مال و فرزندى سود نمى‌دهد،\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmmxxi{مگر كسى كه دلى پاك به سوى خدا بياورد.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmmxxii{و [آن روز] بهشت براى پرهيزگاران نزديك مى‌گردد.\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmmxxiii{و جهنم براى گمراهان نمودار مى‌شود.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmmxxiv{و به آنان گفته مى‌شود: «آنچه جز خدا مى‌پرستيديد كجايند؟\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmmxxv{آيا ياريتان مى‌كنند يا خود را يارى مى‌دهند؟\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmmxxvi{پس آنها و همه گمراهان در آن [آتش‌] افكنده مى‌شوند،\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmmxxvii{و [نيز] همه سپاهيان ابليس.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmmxxviii{آنها در آنجا با يكديگر ستيزه مى‌كنند [و] مى‌گويند:\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmmxxix{«سوگند به خدا كه ما در گمراهى آشكارى بوديم،\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mmmxxx{آنگاه كه شما را با پروردگار جهانيان برابر مى‌كرديم،\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mmmxxxi{و جز تباهكاران ما را گمراه نكردند،\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mmmxxxii{در نتيجه شفاعتگرانى نداريم،\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mmmxxxiii{و نه دوستى نزديك.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mmmxxxiv{و اى كاش كه بازگشتى براىِ ما بود و از مؤمنان مى‌شديم.\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mmmxxxv{حقاً در اين [سرگذشت درس‌] عبرتى است و[لى‌] بيشترشان مؤمن نبودند.\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mmmxxxvi{و در حقيقت، پروردگار تو همان شكست‌ناپذير مهربان است.\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mmmxxxvii{قوم نوح پيامبران را تكذيب كردند.\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mmmxxxviii{چون برادرشان نوح به آنان گفت: «آيا پروا نداريد؟\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mmmxxxix{من براى شما فرستاده‌اى در خور اعتمادم؛\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mmmxl{از خدا پروا كنيد و فرمانم ببريد،\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mmmxli{و بر اين [رسالت‌] اجرى از شما طلب نمى‌كنم. اجر من جز بر عهده پروردگار جهانيان نيست.\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mmmxlii{پس، از خدا پروا كنيد و فرمانم ببريد.»\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mmmxliii{گفتند: «آيا به تو ايمان بياوريم و حال آنكه فرومايگان از تو پيروى كرده‌اند؟»\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mmmxliv{[نوح‌] گفت: «به [جزئيات‌] آنچه مى‌كرده‌اند چه آگاهى دارم؟\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mmmxlv{حسابشان -اگر درمى‌يابيد- جز با پروردگارم نيست.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@mmmxlvi{و من طردكننده مؤمنان نيستم.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@mmmxlvii{من جز هشداردهنده‌اى آشكار [بيش‌] نيستم.»\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@mmmxlviii{گفتند: «اى نوح، اگر دست برندارى قطعاً از [جمله‌] سنگسارشدگان خواهى بود.»\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@mmmxlix{گفت: «پروردگارا، قوم من مرا تكذيب كردند؛\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@mmml{ميان من و آنان فيصله ده، و من و هر كس از مؤمنان را كه با من است نجات بخش.»\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@mmmli{پس او و هر كه را در آن كشتى آكنده با او بود، رهانيديم؛\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@mmmlii{آنگاه باقى‌ماندگان را غرق كرديم.\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@mmmliii{قطعاً در اين [ماجرا درس‌] عبرتى بود، و[لى‌] بيشترشان ايمان‌آورنده نبودند.\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@mmmliv{و در حقيقت، پروردگار تو همان شكست‌ناپذير مهربان است.\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@mmmlv{عاديان، پيامبران [خدا] را تكذيب كردند.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@mmmlvi{آنگاه كه برادرشان هود به آنان گفت: «آيا پروا نداريد؟\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@mmmlvii{من براى شما فرستاده‌اى در خور اعتمادم.\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@mmmlviii{از خدا پروا كنيد و فرمانم ببريد.\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@mmmlix{و بر اين [رسالت‌] اجرى از شما طلب نمى‌كنم. اجر من جز بر عهده پروردگار جهانيان نيست.\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@mmmlx{آيا بر هر تپه‌اى بنايى مى‌سازيد كه [در آن‌] دست به بيهوده‌كارى زنيد؟\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@mmmlxi{و كاخهاى استوار مى‌گيريد به اميد آنكه جاودانه بمانيد؟\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@mmmlxii{و چون حمله‌ور مى‌شويد [چون‌] زورگويان حمله‌ور مى‌شويد؟\qt@no{(130)}}
\qt@newcmd\qurantrans@fa@mmmlxiii{پس، از خدا پروا داريد و فرمانم ببريد.\qt@no{(131)}}
\qt@newcmd\qurantrans@fa@mmmlxiv{و از آن كس كه شما را به آنچه مى‌دانيد مدد كرد پروا داريد:\qt@no{(132)}}
\qt@newcmd\qurantrans@fa@mmmlxv{شما را به [دادن‌] دامها و پسران مدد كرد،\qt@no{(133)}}
\qt@newcmd\qurantrans@fa@mmmlxvi{و به [دادن‌] باغها و چشمه‌ساران؛\qt@no{(134)}}
\qt@newcmd\qurantrans@fa@mmmlxvii{من از عذاب روزى هولناك بر شما مى‌ترسم.\qt@no{(135)}}
\qt@newcmd\qurantrans@fa@mmmlxviii{گفتند: «خواه اندرز دهى و خواه از اندرزدهندگان نباشى براى ما يكسان است.\qt@no{(136)}}
\qt@newcmd\qurantrans@fa@mmmlxix{اين جز شيوه پيشينيان نيست.\qt@no{(137)}}
\qt@newcmd\qurantrans@fa@mmmlxx{و ما عذاب نخواهيم شد.»\qt@no{(138)}}
\qt@newcmd\qurantrans@fa@mmmlxxi{پس تكذيبش كردند و هلاكشان كرديم. قطعاً در اين [ماجرا درس‌] عبرتى بود، و[لى‌] بيشترشان ايمان‌آورنده نبودند.\qt@no{(139)}}
\qt@newcmd\qurantrans@fa@mmmlxxii{و در حقيقت، پروردگار تو همان شكست‌ناپذير مهربان است.\qt@no{(140)}}
\qt@newcmd\qurantrans@fa@mmmlxxiii{ثموديان، پيامبران [خدا] را تكذيب كردند؛\qt@no{(141)}}
\qt@newcmd\qurantrans@fa@mmmlxxiv{آنگاه كه برادرشان صالح به آنان گفت: «آيا پروا نداريد؟\qt@no{(142)}}
\qt@newcmd\qurantrans@fa@mmmlxxv{من براى شما فرستاده‌اى در خور اعتمادم.\qt@no{(143)}}
\qt@newcmd\qurantrans@fa@mmmlxxvi{از خدا پروا كنيد و فرمانم ببريد.\qt@no{(144)}}
\qt@newcmd\qurantrans@fa@mmmlxxvii{و بر اين [رسالت‌] اجرى از شما طلب نمى‌كنم. اجر من جز بر عهده پروردگار جهانيان نيست.\qt@no{(145)}}
\qt@newcmd\qurantrans@fa@mmmlxxviii{آيا شما را در آنچه اينجا داريد آسوده رها مى‌كنند؟\qt@no{(146)}}
\qt@newcmd\qurantrans@fa@mmmlxxix{در باغها و در كنار چشمه‌ساران،\qt@no{(147)}}
\qt@newcmd\qurantrans@fa@mmmlxxx{و كشتزارها و خرمابنانى كه شكوفه‌هايشان لطيف است؟\qt@no{(148)}}
\qt@newcmd\qurantrans@fa@mmmlxxxi{و هنرمندانه براى خود از كوهها خانه‌هايى مى‌تراشيد.\qt@no{(149)}}
\qt@newcmd\qurantrans@fa@mmmlxxxii{از خدا پروا كنيد و فرمانم ببريد.\qt@no{(150)}}
\qt@newcmd\qurantrans@fa@mmmlxxxiii{و فرمان افراطگران را پيروى مكنيد:\qt@no{(151)}}
\qt@newcmd\qurantrans@fa@mmmlxxxiv{آنان كه در زمين فساد مى‌كنند و اصلاح نمى‌كنند.»\qt@no{(152)}}
\qt@newcmd\qurantrans@fa@mmmlxxxv{گفتند: «قطعاً تو از افسون‌شدگانى.\qt@no{(153)}}
\qt@newcmd\qurantrans@fa@mmmlxxxvi{تو جز بشرى مانند ما [بيش‌] نيستى. اگر راست مى‌گويى معجزه‌اى بياور.\qt@no{(154)}}
\qt@newcmd\qurantrans@fa@mmmlxxxvii{گفت: «اين ماده‌شترى است كه نوبتى از آب او راست و روزى معين نوبت آب شماست.\qt@no{(155)}}
\qt@newcmd\qurantrans@fa@mmmlxxxviii{و به آن گزندى مرسانيد كه عذاب روزى هولناك شما را فرو مى‌گيرد.\qt@no{(156)}}
\qt@newcmd\qurantrans@fa@mmmlxxxix{پس آن را پى كردند و پشيمان گشتند.\qt@no{(157)}}
\qt@newcmd\qurantrans@fa@mmmxc{آنگاه آنان را عذاب فرو گرفت. قطعاً در اين [ماجرا] عبرتى است، و[لى‌] بيشترشان ايمان‌آورنده نبودند.\qt@no{(158)}}
\qt@newcmd\qurantrans@fa@mmmxci{و در حقيقت، پروردگار تو همان شكست‌ناپذير مهربان است.\qt@no{(159)}}
\qt@newcmd\qurantrans@fa@mmmxcii{قوم لوط فرستادگان را تكذيب كردند.\qt@no{(160)}}
\qt@newcmd\qurantrans@fa@mmmxciii{آنگاه برادرشان لوط به آنان گفت: «آيا پروا نداريد؟\qt@no{(161)}}
\qt@newcmd\qurantrans@fa@mmmxciv{من براى شما فرستاده‌اى در خور اعتمادم.\qt@no{(162)}}
\qt@newcmd\qurantrans@fa@mmmxcv{از خدا پروا داريد و فرمانم ببريد.\qt@no{(163)}}
\qt@newcmd\qurantrans@fa@mmmxcvi{و بر اين [رسالت‌] اجرى از شما طلب نمى‌كنم. اجر من جز بر عهده پروردگار جهانيان نيست.\qt@no{(164)}}
\qt@newcmd\qurantrans@fa@mmmxcvii{آيا از ميان مردم جهان، با مردها در مى‌آميزيد؟\qt@no{(165)}}
\qt@newcmd\qurantrans@fa@mmmxcviii{و آنچه را پروردگارتان از همسرانتان براى شما آفريده وامى‌گذاريد؟ [نه،] بلكه شما مردمى تجاوزكاريد.\qt@no{(166)}}
\qt@newcmd\qurantrans@fa@mmmxcix{گفتند: «اى لوط، اگر دست برندارى، قطعاً از اخراج‌شدگان خواهى بود.»\qt@no{(167)}}
\qt@newcmd\qurantrans@fa@mmmc{گفت: «به راستى من دشمن كردار شمايم.\qt@no{(168)}}
\qt@newcmd\qurantrans@fa@mmmci{پروردگارا، مرا و كسان مرا از آنچه انجام مى‌دهند رهايى بخش.»\qt@no{(169)}}
\qt@newcmd\qurantrans@fa@mmmcii{پس او و كسانش را همگى، رهانيديم-\qt@no{(170)}}
\qt@newcmd\qurantrans@fa@mmmciii{جز پيرزنى كه از باقى‌ماندگان [در خاكستر آتش‌] بود.\qt@no{(171)}}
\qt@newcmd\qurantrans@fa@mmmciv{سپس ديگران را سخت هلاك كرديم.\qt@no{(172)}}
\qt@newcmd\qurantrans@fa@mmmcv{و بر [سر] آنان بارانى [از آتش گوگرد] فرو ريختيم. و چه بد بود باران بيم‌داده‌شدگان.\qt@no{(173)}}
\qt@newcmd\qurantrans@fa@mmmcvi{قطعاً در اين [عقوبت‌] عبرتى است، و[لى‌] بيشترشان ايمان‌آورنده نبودند.\qt@no{(174)}}
\qt@newcmd\qurantrans@fa@mmmcvii{و در حقيقت، پروردگار تو همان شكست‌ناپذير مهربان است.\qt@no{(175)}}
\qt@newcmd\qurantrans@fa@mmmcviii{اصحاب ايكه فرستادگان را تكذيب كردند.\qt@no{(176)}}
\qt@newcmd\qurantrans@fa@mmmcix{آنگاه كه شعيب به آنان گفت: «آيا پروا نداريد؟\qt@no{(177)}}
\qt@newcmd\qurantrans@fa@mmmcx{من براى شما فرستاده‌اى در خور اعتمادم.\qt@no{(178)}}
\qt@newcmd\qurantrans@fa@mmmcxi{از خدا پروا داريد و فرمانم ببريد.\qt@no{(179)}}
\qt@newcmd\qurantrans@fa@mmmcxii{و بر اين [رسالت‌] اجرى از شما طلب نمى‌كنم. اجر من جز بر عهده پروردگار جهانيان نيست.\qt@no{(180)}}
\qt@newcmd\qurantrans@fa@mmmcxiii{پيمانه را تمام دهيد و از كم‌فروشان مباشيد.\qt@no{(181)}}
\qt@newcmd\qurantrans@fa@mmmcxiv{و با ترازوى درست بسنجيد.\qt@no{(182)}}
\qt@newcmd\qurantrans@fa@mmmcxv{و از ارزش اموال مردم مكاهيد و در زمين سر به فساد بر مداريد.\qt@no{(183)}}
\qt@newcmd\qurantrans@fa@mmmcxvi{و از آن كس كه شما و خلق [انبوه‌] گذشته را آفريده است پروا كنيد.»\qt@no{(184)}}
\qt@newcmd\qurantrans@fa@mmmcxvii{گفتند: «تو واقعاً از افسون‌شدگانى.»\qt@no{(185)}}
\qt@newcmd\qurantrans@fa@mmmcxviii{«و تو جز بشرى مانند ما [بيش‌] نيستى، و قطعاً تو را از دروغگويان مى‌دانيم.\qt@no{(186)}}
\qt@newcmd\qurantrans@fa@mmmcxix{پس اگر از راستگويانى، پاره‌اى از آسمان بر [سر] ما بيفكن.»\qt@no{(187)}}
\qt@newcmd\qurantrans@fa@mmmcxx{[شعيب‌] گفت: «پروردگارم به آنچه مى‌كنيد داناتر است.»\qt@no{(188)}}
\qt@newcmd\qurantrans@fa@mmmcxxi{پس او را تكذيب كردند، و عذابِ روزِ ابر [آتشبار] آنان را فرو گرفت. به راستى آن، عذاب روزى هولناك بود.\qt@no{(189)}}
\qt@newcmd\qurantrans@fa@mmmcxxii{قطعاً در اين [عقوبت درسِ‌] عبرتى است، و[لى‌] بيشترشان ايمان آورنده نبودند.\qt@no{(190)}}
\qt@newcmd\qurantrans@fa@mmmcxxiii{و در حقيقت، پروردگار تو همان شكست‌ناپذير مهربان است.\qt@no{(191)}}
\qt@newcmd\qurantrans@fa@mmmcxxiv{و راستى كه اين [قرآن‌] وحى پروردگار جهانيان است.\qt@no{(192)}}
\qt@newcmd\qurantrans@fa@mmmcxxv{«روح الامين» آن را بر دلت نازل كرد،\qt@no{(193)}}
\qt@newcmd\qurantrans@fa@mmmcxxvi{تا از [جمله‌] هشداردهندگان باشى؛\qt@no{(194)}}
\qt@newcmd\qurantrans@fa@mmmcxxvii{به زبان عربى روشن،\qt@no{(195)}}
\qt@newcmd\qurantrans@fa@mmmcxxviii{و [وصف‌] آن در كتابهاى پيشينيان آمده است.\qt@no{(196)}}
\qt@newcmd\qurantrans@fa@mmmcxxix{آيا براى آنان، اين خود دليلى روشن نيست كه علماى بنى‌اسرائيل از آن اطّلاع دارند؟\qt@no{(197)}}
\qt@newcmd\qurantrans@fa@mmmcxxx{و اگر آن را بر برخى از غير عرب زبانان نازل مى‌كرديم،\qt@no{(198)}}
\qt@newcmd\qurantrans@fa@mmmcxxxi{و پيامبر آن را برايشان مى‌خواند به آن ايمان نمى‌آوردند.\qt@no{(199)}}
\qt@newcmd\qurantrans@fa@mmmcxxxii{اين گونه در دلهاى گناهكاران، [انكار را] راه مى‌دهيم:\qt@no{(200)}}
\qt@newcmd\qurantrans@fa@mmmcxxxiii{كه به آن نگروند تا عذاب پردرد را ببينند،\qt@no{(201)}}
\qt@newcmd\qurantrans@fa@mmmcxxxiv{كه به طور ناگهانى -در حالى كه بى‌خبرند- بديشان برسد.\qt@no{(202)}}
\qt@newcmd\qurantrans@fa@mmmcxxxv{و بگويند: «آيا مهلت خواهيم يافت؟»\qt@no{(203)}}
\qt@newcmd\qurantrans@fa@mmmcxxxvi{پس آيا عذاب ما را به شتاب مى‌خواهند؟\qt@no{(204)}}
\qt@newcmd\qurantrans@fa@mmmcxxxvii{مگر نمى‌دانى كه اگر سالها آنان را برخوردار كنيم،\qt@no{(205)}}
\qt@newcmd\qurantrans@fa@mmmcxxxviii{و آنگاه آنچه كه [بدان‌] بيم داده مى‌شوند بديشان برسد،\qt@no{(206)}}
\qt@newcmd\qurantrans@fa@mmmcxxxix{آنچه از آن برخوردار مى‌شدند، به كارشان نمى‌آيد [و عذاب را از آنان دفع نمى‌كند]؟\qt@no{(207)}}
\qt@newcmd\qurantrans@fa@mmmcxl{و هيچ شهرى را هلاك نكرديم مگر آنكه براى آن هشداردهندگانى بود.\qt@no{(208)}}
\qt@newcmd\qurantrans@fa@mmmcxli{[تا آنان را] تذكر [دهند]؛ و ما ستمكار نبوده‌ايم.\qt@no{(209)}}
\qt@newcmd\qurantrans@fa@mmmcxlii{و شيطانها آن را فرود نياورده‌اند.\qt@no{(210)}}
\qt@newcmd\qurantrans@fa@mmmcxliii{و آنان را نسزد و نمى‌توانند [وحى كنند].\qt@no{(211)}}
\qt@newcmd\qurantrans@fa@mmmcxliv{در حقيقت آنها از شنيدن، معزول [و محروم‌]اند.\qt@no{(212)}}
\qt@newcmd\qurantrans@fa@mmmcxlv{پس با خدا، خداى ديگر مخوان كه از عذاب‌شدگان خواهى شد.\qt@no{(213)}}
\qt@newcmd\qurantrans@fa@mmmcxlvi{و خويشان نزديكت را هشدار ده.\qt@no{(214)}}
\qt@newcmd\qurantrans@fa@mmmcxlvii{و براى آن مؤمنانى كه تو را پيروى كرده‌اند، بال خود را فرو گستر.\qt@no{(215)}}
\qt@newcmd\qurantrans@fa@mmmcxlviii{و اگر تو را نافرمانى كردند، بگو: «من از آنچه مى‌كنيد بيزارم.»\qt@no{(216)}}
\qt@newcmd\qurantrans@fa@mmmcxlix{و بر [خداىِ‌] عزيزِ مهربان توكل كن،\qt@no{(217)}}
\qt@newcmd\qurantrans@fa@mmmcl{آن كس كه چون [به نماز] برمى‌خيزى تو را مى‌بيند،\qt@no{(218)}}
\qt@newcmd\qurantrans@fa@mmmcli{و حركت تو را در ميان سجده‌كنندگان [مى‌نگرد].\qt@no{(219)}}
\qt@newcmd\qurantrans@fa@mmmclii{او همان شنواى داناست.\qt@no{(220)}}
\qt@newcmd\qurantrans@fa@mmmcliii{آيا شما را خبر دهم كه شياطين بر چه كسى فرود مى‌آيند؟\qt@no{(221)}}
\qt@newcmd\qurantrans@fa@mmmcliv{بر هر دروغزن گناهكارى فرود مى‌آيند،\qt@no{(222)}}
\qt@newcmd\qurantrans@fa@mmmclv{كه [دزدانه‌] گوش فرا مى‌دارند و بيشترشان دروغگويند،\qt@no{(223)}}
\qt@newcmd\qurantrans@fa@mmmclvi{و شاعران را گمراهان پيروى مى‌كنند.\qt@no{(224)}}
\qt@newcmd\qurantrans@fa@mmmclvii{آيا نديده‌اى كه آنان در هر واديى سرگردانند؟\qt@no{(225)}}
\qt@newcmd\qurantrans@fa@mmmclviii{و آنانند كه چيزهايى مى‌گويند كه انجام نمى‌دهند.\qt@no{(226)}}
\qt@newcmd\qurantrans@fa@mmmclix{مگر كسانى كه ايمان آورده و كارهاى شايسته كرده و خدا را بسيار به ياد آورده و پس از آنكه مورد ستم قرار گرفته‌اند يارى خواسته‌اند. و كسانى كه ستم كرده‌اند به زودى خواهند دانست به كدام بازگشتگاه برخواهند گشت.\qt@no{(227)}}
\qt@newcmd\qurantrans@fa@mmmclx{\basmalahfa طا، سين. اين است آيات قرآن و [آيات‌] كتابى روشنگر،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmclxi{كه [مايه‌] هدايت و بشارت براى مؤمنان است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmclxii{همانان كه نماز برپا مى‌دارند و زكات مى‌دهند و خود به آخرت يقين دارند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmclxiii{كسانى كه به آخرت ايمان ندارند، كردارهايشان را در نظرشان بياراستيم [تا همچنان‌] سرگشته بمانند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmclxiv{آنان كسانى‌اند كه عذاب سخت براى ايشان خواهد بود، و در آخرت، خود زيانكارترين [مردم‌]اند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmclxv{و حقاً تو قرآن را از سوى حكيمى دانا دريافت مى‌دارى.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmclxvi{[يادكن‌] هنگامى را كه موسى به خانواده خود گفت: «من آتشى به نظرم رسيد، به زودى براى شما خبرى از آن خواهم آورد، يا شعله آتشى براى شما مى‌آورم، باشد كه خود را گرم كنيد.»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmclxvii{چون نزد آن آمد، آوا رسيد كه: «خجسته [و مبارك گرديد] آنكه در كنار اين آتش و آنكه پيرامون آن است، و منزه است خدا، پروردگار جهانيان.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmclxviii{«اى موسى، اين منم خداى عزيز حكيم.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmclxix{و عصايت را بيفكن. پس چون آن را همچون مارى ديد كه مى‌جنبد، پشت گردانيد و به عقب بازنگشت. «اى موسى، مترس كه فرستادگان پيش من نمى‌ترسند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmclxx{ليكن كسى كه ستم كرده سپس -بعد از بدى- نيكى را جايگزين [آن‌] گردانيده، [بداند] كه من آمرزنده مهربانم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmclxxi{و دستت را در گريبانت كن تا سپيد بى‌عيب بيرون آيد. [اينها] از [جمله‌] نشانه‌هاى نُه‌گانه‌اى است [كه بايد] به سوى فرعون و قومش [ببَرى‌]، زيرا كه آنان مردمى نافرمانند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmclxxii{و هنگامى كه آيات روشنگر ما به سويشان آمد گفتند: «اين سحرى آشكار است.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmclxxiii{و با آنكه دلهايشان بدان يقين داشت، از روى ظلم و تكبر آن را انكار كردند. پس ببين فرجام فسادگران چگونه بود.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmclxxiv{و به راستى به داوود و سليمان دانشى عطا كرديم، و آن دو گفتند: «ستايش خدايى را كه ما را بر بسيارى از بندگان باايمانش برترى داده است.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmclxxv{و سليمان از داوود ميراث يافت و گفت: «اى مردم، ما زبان پرندگان را تعليم يافته‌ايم و از هر چيزى به ما داده شده است. راستى كه اين همان امتياز آشكار است.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmclxxvi{و براى سليمان سپاهيانش از جن و انس و پرندگان جمع‌آورى شدند و [براى رژه‌] دسته دسته گرديدند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmclxxvii{تا آنگاه كه به وادى مورچگان رسيدند. مورچه‌اى [به زبان خويش‌] گفت: «اى مورچگان، به خانه‌هايتان داخل شويد، مبادا سليمان و سپاهيانش -نديده و ندانسته- شما را پايمال كنند.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmclxxviii{[سليمان‌] از گفتار او دهان به خنده گشود و گفت: «پروردگارا، در دلم افكن تا نعمتى را كه به من و پدر و مادرم ارزانى داشته‌اى سپاس بگزارم، و به كار شايسته‌اى كه آن را مى‌پسندى بپردازم، و مرا به رحمت خويش در ميان بندگان شايسته‌ات داخل كن.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmclxxix{و جوياى [حال‌] پرندگان شد و گفت: «مرا چه شده است كه هدهد را نمى‌بينم؟ يا شايد از غايبان است؟\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmclxxx{قطعاً او را به عذابى سخت عذاب مى‌كنم يا سرش را مى‌برم مگر آنكه دليلى روشن براى من بياورد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmclxxxi{پس ديرى نپاييد كه [هدهد آمد و] گفت: «از چيزى آگاهى يافتم كه از آن آگاهى نيافته‌اى، و براى تو از «سبا» گزارشى درست آورده‌ام.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmclxxxii{من [آنجا] زنى را يافتم كه بر آنها سلطنت مى‌كرد و از هر چيزى به او داده شده بود و تختى بزرگ داشت.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmclxxxiii{او و قومش را چنين يافتم كه به جاى خدا به خورشيد سجده مى‌كنند، و شيطان اعمالشان را برايشان آراسته و آنان را از راه [راست‌] باز داشته بود، در نتيجه [به حق‌] راه نيافته بودند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmclxxxiv{[آرى، شيطان چنين كرده بود] تا براى خدايى كه نهان را در آسمانها و زمين بيرون مى‌آورد و آنچه را پنهان مى‌داريد و آنچه را آشكار مى‌نماييد مى‌داند، سجده نكنند؛\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmclxxxv{خداى يكتا كه هيچ خدايى جز او نيست، پروردگار عرش بزرگ است.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmclxxxvi{گفت: «خواهيم ديد آيا راست گفته‌اى يا از دروغگويان بوده‌اى.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmclxxxvii{«اين نامه مرا ببر و به سوى آنها بيفكن، آنگاه از ايشان روى برتاب، پس ببين چه پاسخ مى‌دهند.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmclxxxviii{[ملكه سبا] گفت: «اى سران [كشور] نامه‌اى ارجمند براى من آمده است،\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmclxxxix{كه از طرف سليمان است و [مضمون آن‌] اين است: به نام خداوند رحمتگر مهربان.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmcxc{بر من بزرگى مكنيد و مرا از در اطاعت درآييد.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmcxci{گفت: «اى سران [كشور] در كارم به من نظر دهيد كه بى‌حضور شما [تا به حال‌] كارى را فيصله نداده‌ام.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmcxcii{گفتند: «ما سخت نيرومند و دلاوريم، و[لى‌] اختيار كار با توست، بنگر چه دستور مى‌دهى؟»\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmcxciii{[ملكه‌] گفت: «پادشاهان چون به شهرى درآيند، آن را تباه و عزيزانش را خوار مى‌گردانند، و اين گونه مى‌كنند.»\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmcxciv{«و [اينك‌] من ارمغانى به سويشان مى‌فرستم و مى‌نگرم كه فرستادگان [من‌] با چه چيز بازمى‌گردند.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmcxcv{و چون [فرستاده‌] نزد سليمان آمد، [سليمان‌] گفت: «آيا مرا به مالى كمك مى‌دهيد؟ آنچه خدا به من عطا كرده، بهتر است از آنچه به شما داده‌است. [نه،] بلكه شما به ارمغان خود شادمانى مى‌نماييد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmcxcvi{به سوى آنان بازگرد كه قطعاً سپاهيانى بر [سر] ايشان مى‌آوريم كه در برابر آنها تاب ايستادگى نداشته باشند و از آن [ديار] به خوارى و زبونى بيرونشان مى‌كنيم.»\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmcxcvii{[سپس‌] گفت: «اى سران [كشور] كدام يك از شما تخت او را -پيش از آنكه مطيعانه نزد من آيند- براى من مى‌آورد؟»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmcxcviii{عفريتى از جن گفت: «من آن را پيش از آنكه از مجلس خود برخيزى براى تو مى‌آورم و بر اين [كار] سخت توانا و مورد اعتمادم.»\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmcxcix{كسى كه نزد او دانشى از كتاب [الهى‌] بود، گفت: «من آن را پيش از آنكه چشم خود را بر هم زنى برايت مى‌آورم.» پس چون [سليمان‌] آن [تخت‌] را نزد خود مستقر ديد، گفت: «اين از فضل پروردگار من است، تا مرا بيازمايد كه آيا سپاسگزارم يا ناسپاسى مى‌كنم. و هر كس سپاس گزارد، تنها به سود خويش سپاس مى‌گزارد، و هر كس ناسپاسى كند، بى‌گمان پروردگارم بى‌نياز و كريم است.»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmcc{گفت: «تخت [ملكه‌] را برايش ناشناس گردانيد تا ببينيم آيا پى مى‌برد يا از كسانى است كه پى نمى‌برند.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmcci{پس وقتى [ملكه‌] آمد، [بدو] گفته شد: «آيا تخت تو همين گونه است؟» گفت: «گويا اين همان است و پيش از اين، ما آگاه شده و از در اطاعت درآمده بوديم.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmccii{و [در حقيقت قبلاً] آنچه غير از خدا مى‌پرستيد مانع [ايمان‌] او شده بود و او از جمله گروه كافران بود.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmcciii{به او گفته شد: «وارد ساحت كاخ [پادشاهى‌] شو.» و چون آن را ديد، بركه‌اى پنداشت و ساقهايش را نمايان كرد. [سليمان‌] گفت: «اين كاخى مفروش از آبگينه است.» [ملكه‌] گفت: «پروردگارا، من به خود ستم كردم و [اينك‌] با سليمان در برابر خدا، پروردگار جهانيان، تسليم شدم.»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmcciv{و به راستى، به سوى ثمود، برادرشان صالح را فرستاديم كه: «خدا را بپرستيد.» پس به ناگاه آنان دو دسته متخاصم شدند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmccv{[صالح‌] گفت: «اى قوم من، چرا پيش از [جستن‌] نيكى، شتابزده خواهان بدى هستيد؟ چرا از خدا آمرزش نمى‌خواهيد؟ باشد كه مورد رحمت قرار گيريد.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmccvi{گفتند: «ما به تو و به هر كس كه همراه توست شگون بد زديم.» گفت: «سرنوشت خوب و بدتان پيش خداست، بلكه شما مردمى هستيد كه مورد آزمايش قرار گرفته‌ايد.»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmccvii{و در آن شهر، نُه دسته بودند كه در آن سرزمين فساد مى‌كردند و از در اصلاح درنمى‌آمدند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmccviii{[با هم‌] گفتند: «با يكديگر سوگند بخوريد كه: حتماً به [صالح‌] و كسانش شبيخون مى‌زنيم، سپس به ولىّ او خواهيم گفت: ما در محل قتل كسانش حاضر نبوديم، و ما قطعاً راست مى‌گوييم.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmccix{و دست به نيرنگ زدند و [ما نيز] دست به نيرنگ زديم و خبر نداشتند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmccx{پس بنگر كه فرجام نيرنگشان چگونه بود: ما آنان و قومشان را همگى هلاك كرديم.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmccxi{و اين [هم‌] خانه‌هاى خالى آنهاست به [سزاى‌] بيدادى كه كرده‌اند. قطعاً در اين [كيفر] براى مردمى كه مى‌دانند عبرتى خواهد بود.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmccxii{و كسانى را كه ايمان آورده و تقوا پيشه كرده بودند رهانيديم.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmccxiii{و [ياد كن‌] لوط را كه چون به قوم خود گفت: «آيا ديده و دانسته مرتكب عمل ناشايست [لواط] مى‌شويد؟\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmccxiv{آيا شما به جاى زنان، از روى شهوت با مردها در مى‌آميزيد؟ [نه!] بلكه شما مردمى جهالت‌پيشه‌ايد.»\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmccxv{و[لى‌] پاسخ قومش غير از اين نبود كه گفتند: «خاندان لوط را از شهرتان بيرون كنيد كه آنها مردمى هستند كه به پاكى تظاهر مى‌نمايند.»\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmccxvi{پس او و خانواده‌اش را نجات داديم، جز زنش را كه مقدّر كرديم از باقى‌ماندگان [در خاكستر آتش‌] باشد.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmccxvii{و بارانى [از سجّيل‌] بر ايشان فرو باريديم، و باران هشدارداده‌شدگان، چه بد بارانى بود.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmccxviii{بگو: «سپاس براى خداست، و درود بر آن بندگانش كه [آنان را] برگزيده است.» آيا خدا بهتر است يا آنچه [با او] شريك مى‌گردانند؟\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmccxix{[آيا آنچه شريك مى‌پندارند بهتر است‌] يا آن كس كه آسمانها و زمين را خلق كرد و براى شما آبى از آسمان فرود آورد، پس به وسيله آن، باغهاى بهجت‌انگيز رويانيديم. كار شما نبود كه درختانش را برويانيد. آيا معبودى با خداست؟ [نه،] بلكه آنان قومى منحرفند.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmccxx{[آيا شريكانى كه مى‌پندارند بهتر است‌] يا آن كس كه زمين را قرارگاهى ساخت و در آن رودها پديد آورد و براى آن، كوه‌ها را [مانند لنگر] قرار داد، و ميان دو دريا برزخى گذاشت؟ آيا معبودى با خداست؟ [نه،] بلكه بيشترشان نمى‌دانند.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmccxxi{يا [كيست‌] آن كس كه درمانده را -چون وى را بخواند- اجابت مى‌كند، و گرفتارى را برطرف مى‌گرداند، و شما را جانشينان اين زمين قرار مى‌دهد؟ آيا معبودى با خداست؟ چه كم پند مى‌پذيريد.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmccxxii{يا آن كس كه شما را در تاريكيهاى خشكى و دريا راه مى‌نمايد و آن كس كه بادها[ى باران زا] را پيشاپيش رحمتش بشارتگر مى‌فرستد؟ آيا معبودى با خداست؟ خدا برتر [و بزرگتر] است از آنچه [با او ]شريك مى‌گردانند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmccxxiii{يا آن كس كه خلق را آغاز مى‌كند و سپس آن را بازمى‌آورد، و آن كس كه از آسمان و زمين به شما روزى مى‌دهد؟ آيا معبودى با خداست؟ بگو: «اگر راست مى‌گوييد، برهان خويش را بياوريد.»\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmccxxiv{بگو: «هر كه در آسمانها و زمين است -جز خدا- غيب را نمى‌شناسند و نمى‌دانند كى برانگيخته خواهند شد؟»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmccxxv{[نه،] بلكه علم آنان در باره آخرت نارساست؛ [نه،] بلكه ايشان در باره آن ترديد دارند؛ [نه،] بلكه آنان در مورد آن كوردلند.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmccxxvi{و كسانى كه كفر ورزيدند، گفتند: «آيا وقتى ما و پدرانمان خاك شديم، آيا حتماً [زنده از گور] بيرون آورده مى‌شويم؟\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmccxxvii{در حقيقت، اين را به ما و پدرانمان قبلاً وعده داده‌اند؛ اين جز افسانه‌هاى پيشينيان نيست.»\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmccxxviii{بگو: «در زمين بگرديد و بنگريد فرجام گنه‌پيشگان چگونه بوده است.»\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmccxxix{و بر آنان غم مخور، و از آنچه مكر مى‌كنند تنگدل مباش.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmccxxx{و مى‌گويند: «اگر راست مى‌گوييد، اين وعده كى خواهد بود؟»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmccxxxi{بگو: «شايد برخى از آنچه را به شتاب مى‌خواهيد در پى شما باشد.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmccxxxii{و راستى پروردگارت بر [اين‌] مردم داراى بخشش است، ولى بيشترشان سپاس نمى‌دارند.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmccxxxiii{و در حقيقت، پروردگار تو آنچه را در سينه‌هايشان نهفته و آنچه را آشكار مى‌دارند نيك مى‌داند.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmccxxxiv{و هيچ پنهانى در آسمان و زمين نيست، مگر اينكه در كتابى روشن [درج‌] است.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmccxxxv{بى‌گمان، اين قرآن بر فرزندان اسرائيل بيشتر آنچه را كه آنان در باره‌اش اختلاف دارند حكايت مى‌كند.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmccxxxvi{و به راستى كه آن، رهنمود و رحمتى براى مؤمنان است.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmccxxxvii{در حقيقت، پروردگار تو طبق حكم خود ميان آنان داورى مى‌كند، و اوست شكست‌ناپذير دانا.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmccxxxviii{پس بر خدا توكل كن كه تو واقعاً بر حق آشكارى.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmccxxxix{البته تو مردگان را شنوا نمى‌گردانى، و اين ندا را به كران -چون پشت بگردانند- نمى‌توانى بشنوانى.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmccxl{و راهبر كوران [و بازگرداننده‌] از گمراهى‌شان نيستى. تو جز كسانى را كه به نشانه‌هاى ما ايمان آورده‌اند و مسلمانند، نمى‌توانى بشنوانى.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmccxli{و چون قول [عذاب‌] بر ايشان واجب گردد، جنبنده‌اى را از زمين براى آنان بيرون مى‌آوريم كه با ايشان سخن گويد كه: مردم [چنانكه بايد] به نشانه‌هاى ما يقين نداشتند.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmccxlii{و آن روز كه از هر امتى، گروهى از كسانى را كه آيات ما را تكذيب كرده‌اند محشور مى‌گردانيم، پس آنان نگاه داشته مى‌شوند تا همه به هم بپيوندند.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmccxliii{تا چون [همه كافران‌] بيايند، [خدا] مى‌فرمايد: «آيا نشانه‌هاى مرا به دروغ گرفتيد و حال آنكه از نظر علم، بدانها احاطه نداشتيد؟ آيا [در طول حيات‌] چه مى‌كرديد؟»\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmmccxliv{و به [كيفر] آنكه ستم كردند، حكم [عذاب‌] بر آنان واجب گردد، در نتيجه ايشان دَم برنيارند.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmmccxlv{آيا نديده‌اند كه ما شب را قرار داده‌ايم تا در آن بياسايند، و روز را روشنى‌بخش [گردانيديم‌]؟ قطعاً در اين [امر] براى مردمى كه ايمان مى‌آورند مايه‌هاى عبرت است.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmmccxlvi{و روزى كه در صور دميده شود، پس هر كه در آسمانها و هر كه در زمين است به هراس افتد، مگر آن كس كه خدا بخواهد. و جملگى با زبونى رو به سوى او آورند.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmmccxlvii{و كوهها را مى‌بينى [و] مى‌پندارى كه آنها بى‌حركتند و حال آنكه آنها ابرآسا در حركتند. [اين‌] صُنعِ خدايى است كه هر چيزى را در كمال استوارى پديد آورده است. در حقيقت، او به آنچه انجام مى‌دهيد آگاه است.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmmccxlviii{هر كس نيكى به ميان آورد، پاداشى بهتر از آن خواهد داشت، و آنان از هراس آن روز ايمنند.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmmccxlix{و هر كس بدى به ميان آورد، به رو در آتش [دوزخ‌] سرنگون شوند. آيا جز آنچه مى‌كرديد سزا داده مى‌شويد؟\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmmccl{من مأمورم كه تنها پروردگار اين شهر را كه آن را مقدس شمرده و هر چيزى از آنِ اوست پرستش كنم، و مأمورم كه از مسلمانان باشم،\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmmccli{و اينكه قرآن را بخوانم. پس هر كه راه يابد تنها به سود خود راه يافته است؛ و هر كه گمراه شود بگو: «من فقط از هشداردهندگانم.»\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmmcclii{و بگو: «ستايش از آنِ خداست. به زودى آياتش را به شما نشان خواهد داد و آن را خواهيد شناخت.» و پروردگار تو از آنچه مى‌كنيد غافل نيست.\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmmccliii{\basmalahfa طا، سين، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmccliv{اين است آيات كتاب روشنگر.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmcclv{[بخشى‌] از گزارش [حال‌] موسى و فرعون را براى [آگاهى‌] مردمى كه ايمان مى‌آورند، به درستى بر تو مى‌خوانيم:\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmcclvi{فرعون در سرزمين [مصر] سر برافراشت، و مردم آن را طبقه طبقه ساخت؛ طبقه‌اى از آنان را زبون مى‌داشت: پسرانشان را سر مى‌بريد، و زنانشان را [براى بهره‌كشى‌] زنده بر جاى مى‌گذاشت، كه وى از فسادكاران بود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmcclvii{و خواستيم بر كسانى كه در آن سرزمين فرو دست شده بودند منّت نهيم و آنان را پيشوايان [مردم‌] گردانيم، و ايشان را وارث [زمين‌] كنيم،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmcclviii{و در زمين قدرتشان دهيم و [از طرفى‌] به فرعون و هامان و لشكريانشان آنچه را كه از جانب آنان بيمناك بودند، بنمايانيم.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmcclix{و به مادر موسى وحى كرديم كه: «او را شير ده، و چون بر او بيمناك شدى او را در نيل بينداز، و مترس و اندوه مدار كه ما او را به تو بازمى‌گردانيم و از [زمره‌] پيمبرانش قرار مى‌دهيم.»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmcclx{پس خاندان فرعون، او را [از آب‌] برگرفتند تا سرانجام دشمنِ [جانِ‌] آنان و مايه اندوهشان باشد. آرى، فرعون و هامان و لشكريان آنها خطاكار بودند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmcclxi{و همسر فرعون گفت: «[اين كودك‌] نور چشم من و تو خواهد بود. او را مكشيد. شايد براى ما سودمند باشد يا او را به فرزندى بگيريم، ولى آنها خبر نداشتند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmcclxii{و دل مادر موسى [از هر چيز، جز از فكر فرزند] تهى گشت. اگر قلبش را استوار نساخته بوديم تا از ايمان‌آورندگان باشد، چيزى نمانده بود كه آن [راز] را افشا كند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmcclxiii{و به خواهر [موسى‌] گفت: «از پى او برو.» پس او را از دور ديد، در حالى كه آنان متوجه نبودند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmcclxiv{و از پيش، شير دايگان را بر او حرام گردانيده بوديم. پس [خواهرش آمد و] گفت: «آيا شما را بر خانواده‌اى راهنمايى كنم كه براى شما از وى سرپرستى كنند و خيرخواه او باشند؟»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmcclxv{پس او را به مادرش بازگردانيديم تا چشمش [بدو] روشن شود و غم نخورد و بداند كه وعده خدا درست است، ولى بيشترشان نمى‌دانند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmcclxvi{و چون به رشد و كمال خويش رسيد، به او حكمت و دانش عطا كرديم، و نيكوكاران را چنين پاداش مى‌دهيم.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmcclxvii{و داخل شهر شد بى‌آنكه مردمش متوجه باشند. پس دو مرد را با هم در زد و خورد يافت: يكى، از پيروان او و ديگرى از دشمنانش [بود]. آن كس كه از پيروانش بود، بر ضد كسى كه دشمن وى بود، از او يارى خواست. پس موسى مشتى بدو زد و او را كشت. گفت: «اين كار شيطان است، چرا كه او دشمنى گمراه‌كننده [و] آشكار است.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmcclxviii{گفت: «پروردگارا، من بر خويشتن ستم كردم، مرا ببخش.» پس خدا از او درگذشت كه وى آمرزنده مهربان است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmcclxix{[موسى‌] گفت: «پروردگارا به پاس نعمتى كه بر من ارزانى داشتى هرگز پشتيبان مجرمان نخواهم بود.»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmcclxx{صبحگاهان در شهر، بيمناك و در انتظار [حادثه‌اى‌] بود. ناگاه همان كسى كه ديروز از وى يارى خواسته بود [باز] با فرياد از او يارى خواست. موسى به او گفت: «به راستى كه تو آشكارا گمراهى.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmcclxxi{و چون خواست به سوى آنكه دشمن هر دوشان بود حمله آورد، گفت: «اى موسى، آيا مى‌خواهى مرا بكشى چنانكه ديروز شخصى را كشتى؟ تو مى‌خواهى در اين سرزمين فقط زورگو باشى، و نمى‌خواهى از اصلاحگران باشى.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmcclxxii{و از دورافتاده‌ترين [نقطه‌] شهر، مردى دوان دوان آمد [و] گفت: «اى موسى، سران قوم در باره تو مشورت مى‌كنند تا تو را بكشند. پس [از شهر] خارج شو. من جداً از خيرخواهان توام.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmcclxxiii{موسى ترسان و نگران از آنجا بيرون رفت [در حالى كه مى‌]گفت: «پروردگارا، مرا از گروه ستمكاران نجات بخش.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmcclxxiv{و چون به سوى [شهر] مدين رو نهاد [با خود] گفت: «اميد است پروردگارم مرا به راه راست هدايت كند.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmcclxxv{و چون به آب مدين رسيد، گروهى از مردم را بر آن يافت كه [دامهاى خود را ] آب مى‌دادند، و پشت سرشان دو زن را يافت كه [گوسفندان خود را] دور مى‌كردند. [موسى‌] گفت: «منظورتان [از اين كار ]چيست؟» گفتند: « [ما به گوسفندان خود] آب نمى‌دهيم تا شبانان [همگى گوسفندانشان را] برگردانند، و پدر ما پيرى سالخورده است.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmcclxxvi{پس براى آن دو، [گوسفندان را] آب داد، آنگاه به سوى سايه برگشت و گفت: «پروردگارا، من به هر خيرى كه سويم بفرستى سخت نيازمندم.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmcclxxvii{پس يكى از آن دو زن -در حالى كه به آزرم گام بر مى‌داشت- نزد وى آمد [و] گفت: «پدرم تو را مى‌طلبد تا تو را به پاداش آب‌دادن [گوسفندان‌] براى ما، مزد دهد.» و چون [موسى‌] نزد او آمد و سرگذشت [خود] را بر او حكايت كرد، [وى‌] گفت: «مترس كه از گروه ستمگران نجات يافتى.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmcclxxviii{يكى از آن دو [دختر] گفت: «اى پدر، او را استخدام كن، چرا كه بهترين كسى است كه استخدام مى‌كنى: هم نيرومند [و هم‌] در خور اعتماد است.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmcclxxix{[شعيب‌] گفت: «من مى‌خواهم يكى از اين دو دختر خود را [كه مشاهده مى‌كنى‌] به نكاح تو در آورم، به اين [شرط] كه هشت سال براى من كار كنى، و اگر ده سال را تمام گردانى اختيار با تو است، و نمى‌خواهم بر تو سخت گيرم، و مرا ان شاء الله از درستكاران خواهى يافت.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmcclxxx{[موسى‌] گفت: «اين [قرار داد] ميان من و تو باشد كه هر يك از دو مدت را به انجام رسانيدم، بر من تعدى [روا] نباشد، و خدا بر آنچه مى‌گوييم وكيل است.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxi{و چون موسى آن مدت را به پايان رسانيد و همسرش را [همراه‌] برد، آتشى را از دور در كنار طور مشاهده كرد، به خانواده خود گفت: «[اينجا] بمانيد، كه من آتشى از دور ديدم، شايد خبرى از آن يا شعله‌اى آتش برايتان بياورم، باشد كه خود را گرم كنيد.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxii{پس چون به آن [آتش‌] رسيد، از جانب راست وادى، در آن جايگاه مبارك، از آن درخت ندا آمد كه: «اى موسى، منم، من، خداوند، پروردگار جهانيان.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxiii{و [فرمود:] «عصاى خود را بيفكن.» پس چون ديد آن مِثْل مارى مى‌جنبد، پشت كرد و برنگشت. «اى موسى، پيش آى و مترس كه تو در امانى.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxiv{«دست خود را به گريبانت ببر تا سپيد بى‌گزند بيرون بيايد، و [براى رهايى ] از اين هراس بازويت را به خويشتن بچسبان. اين دو [نشانه‌] دو برهان از جانب پروردگار تو است [كه بايد] به سوى فرعون و سران [كشور] او [ببرى‌]، زيرا آنان همواره قومى نافرمانند.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxv{گفت: «پروردگارا، من كسى از ايشان را كشته‌ام، مى‌ترسم مرا بكشند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxvi{و برادرم هارون از من زبان‌آورتر است، پس او را با من به دستيارى گسيل دار تا مرا تصديق كند، زيرا مى‌ترسم مرا تكذيب كنند.»\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxvii{فرمود: «به زودى بازويت را به [وسيله‌] برادرت نيرومند خواهيم كرد و براى شما هر دو، تسلطى قرار خواهيم داد كه با [وجود] آيات ما، به شما دست نخواهند يافت شما و هر كه شما را پيروى كند چيره خواهيد بود.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxviii{پس چون موسى آيات روشن ما را براى آنان آورد، گفتند: «اين جز سحرى ساختگى نيست و از پدران پيشين خود چنين [چيزى‌] نشنيده‌ايم.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmcclxxxix{و موسى گفت: «پروردگارم به [حال‌] كسى كه از جانب او رهنمودى آورده و [نيز] كسى كه فرجام [نيكوىِ‌] آن سرا براى اوست، داناتر است. در حقيقت، ظالمان رستگار نمى‌شوند.»\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmccxc{و فرعون گفت: «اى بزرگان قوم، من جز خويشتن براى شما خدايى نمى‌شناسم. پس اى هامان؛ برايم بر گل آتش بيفروز و برجى [بلند] براى من بساز، شايد به [حال‌] خداى موسى اطّلاع يابم، و من جداً او را از دروغگويان مى‌پندارم.»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmccxci{و او و سپاهيانش در آن سرزمين به ناحق سركشى كردند و پنداشتند كه به سوى ما بازگردانيده نمى‌شوند.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmccxcii{تا او و سپاهيانش را فرو گرفتيم و آنان را در دريا افكنديم، بنگر كه فرجام كار ستمكاران چگونه بود.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmccxciii{و آنان را پيشوايانى كه به سوى آتش مى‌خوانند گردانيديم، و روز رستاخيز يارى نخواهند شد.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmccxciv{و در اين دنيا لعنتى بدرقه [نام‌] آنان كرديم و روز قيامت [نيز] ايشان از [جمله‌] زشت‌رويانند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmccxcv{و به راستى، پس از آنكه نسلهاى نخستين را هلاك كرديم، به موسى كتاب داديم كه [دربردارنده‌] روشنگرى‌ها و رهنمود و رحمتى براى مردم بود، اميد كه آنان پند گيرند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmccxcvi{و چون امر [پيامبرى‌] را به موسى واگذاشتيم، تو در جانب غربى [طور] نبودى و از گواهان [نيز] نبودى.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmccxcvii{ليكن ما نسلهايى پديد آورديم و عمرشان طولانى شد. و تو در ميان ساكنان [شهر] مَدْين مقيم نبودى تا آيات ما را بر ايشان بخوانى، ليكن ما بوديم كه فرستنده [پيامبران‌] بوديم.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmccxcviii{و آندم كه [موسى را] ندا درداديم، تو در جانب طور نبودى، ولى [اين اطّلاع تو] رحمتى است از پروردگار تو، تا قومى را كه هيچ هشداردهنده‌اى پيش از تو برايشان نيامده است بيم دهى، باشد كه آنان پندپذيرند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmccxcix{و اگر نبود كه وقتى به [سزاى‌] پيش‌فرست دستهايشان مصيبتى به ايشان برسد، بگويند: «پروردگارا، چرا فرستاده‌اى به سوى ما نفرستادى تا از احكام تو پيروى كنيم و از مؤمنان باشيم» [قطعاً در كيفر آنان شتاب مى‌كرديم‌].\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmccc{پس چون حق از جانب ما برايشان آمد، گفتند: «چرا نظير آنچه به موسى داده شد، به او داده نشده است؟» آيا به آنچه قبلاً به موسى داده شد كفر نورزيدند؟ گفتند: «دو ساحر با هم ساخته‌اند.» و گفتند: «ما همه را منكريم.»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmccci{بگو: «پس اگر راست مى‌گوييد، كتابى از جانب خدا بياوريد كه از اين دو هدايت كننده‌تر باشد تا پيرويش كنم.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmcccii{پس اگر تو را اجابت نكردند، بدان كه فقط هوسهاى خود را پيروى مى‌كنند؛ و كيست گمراه‌تر از آنكه بى‌راهنمايى خدا از هوسش پيروى كند؟ بى‌ترديد خدا مردم ستمگر را راهنمايى نمى‌كند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmccciii{و به راستى، اين گفتار را براى آنان پى در پى و به هم پيوسته نازل ساختيم، اميد كه آنان پند پذيرند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmccciv{كسانى كه قبل از آن، كتاب [آسمانى‌] به ايشان داده‌ايم، آنان به [قرآن‌] مى‌گروند.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmcccv{و چون بر ايشان فرو خوانده مى‌شود، مى‌گويند: «بدان ايمان آورديم كه آن درست است [و] از طرف پروردگار ماست؛ ما پيش از آن [هم‌] از تسليم‌شوندگان بوديم.»\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmcccvi{آنانند كه به [پاس‌] آنكه صبر كردند و [براى آنكه‌] بدى را با نيكى دفع مى‌نمايند و از آنچه روزى‌شان داده‌ايم انفاق مى‌كنند، دو بار پاداش خواهند يافت.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmcccvii{و چون لغوى بشنوند از آن روى برمى‌تابند و مى‌گويند: «كردارهاى ما از آنِ ما و كردارهاى شما از آنِ شماست، سلام بر شما، جوياى [مصاحبت‌] نادانان نيستيم.»\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmcccviii{در حقيقت، تو هر كه را دوست دارى نمى‌توانى راهنمايى كنى، ليكن خداست كه هر كه را بخواهد راهنمايى مى‌كند، و او به راه‌يافتگان داناتر است.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmcccix{و گفتند: «اگر با تو از [نورِ] هدايت پيروى كنيم، از سرزمين خود ربوده خواهيم شد.» آيا آنان را در حرمى امن جاى نداديم كه محصولات هر چيزى -كه رزقى از جانب ماست- به سوى آن سرازير مى‌شود؟ ولى بيشترشان نمى‌دانند.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmcccx{و چه بسيار شهرها كه هلاكش كرديم، [زيرا] زندگى خوش، آنها را سرمست كرده بود. اين است سراهايشان كه پس از آنان -جز براى عدّه كمى- مورد سكونت قرار نگرفته، و ماييم كه وارث آنان بوديم.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmcccxi{و پروردگار تو [هرگز] ويرانگر شهرها نبوده است تا [پيشتر] در مركز آنها پيامبرى برانگيزد كه آيات ما را بر ايشان بخواند، و ما شهرها را -تا مردمشان ستمگر نباشند- ويران‌كننده نبوده‌ايم.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmcccxii{و هر آنچه به شما داده شده است، كالاى زندگى دنيا و زيور آن است، و[لى‌] آنچه پيش خداست بهتر و پايدارتر است؛ مگر نمى‌انديشيد؟\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmcccxiii{آيا كسى كه وعده نيكو به او داده‌ايم و او به آن خواهد رسيد، مانند كسى است كه از كالاى زندگى دنيا بهره‌مندش گردانيده‌ايم [ولى‌] او روز قيامت از [جمله‌] احضارشدگان [در آتش‌] است؟\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmcccxiv{و [به ياد آور] روزى را كه آنان را ندا مى‌دهد و مى‌فرمايد: «آن شريكان من، كه مى‌پنداشتيد كجايند؟»\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmcccxv{آنان كه حكم [عذاب‌] بر ايشان واجب آمده، مى‌گويند: «پروردگارا، اينانند كسانى كه گمراه كرديم، گمراهشان كرديم همچنانكه خود گمراه شديم، [از آنان‌] به سوى تو بيزارى مى‌جوييم، ما را نمى‌پرستيدند [بلكه پندار خود را دنبال مى‌كردند].»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmcccxvi{و [به آنان‌] گفته مى‌شود: «شريكان خود را فرا خوانيد.» [پس آنها را مى‌خوانند] ولى پاسخشان نمى‌دهند و عذاب را مى‌بينند [و آرزو مى‌كنند كه‌] اى كاش هدايت‌يافته بودند.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmcccxvii{و روزى را كه [خدا] آنان را ندا درمى‌دهد و مى‌فرمايد: «فرستادگان [ما] را چه پاسخ داديد؟»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmcccxviii{پس در آن روز اخبار بر ايشان پوشيده گردد و از يكديگر نمى‌توانند بپرسند.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmcccxix{و امّا كسى كه توبه كند و ايمان آورد و به كار شايسته پردازد، اميد كه از رستگاران باشد.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmcccxx{و پروردگار تو هر چه را بخواهد مى‌آفريند و برمى‌گزيند، و آنان اختيارى ندارند. منزه است خدا، و از آنچه [با او] شريك مى‌گردانند برتر است.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmcccxxi{و آنچه را سينه‌هايشان پوشيده يا آشكار مى‌دارد، پروردگارت مى‌داند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmcccxxii{و اوست خدا[يى كه‌] جز او معبودى نيست. در اين [سراى‌] نخستين و در آخرت، ستايش از آنِ اوست، و فرمان، او راست و به سوى او بازگردانيده مى‌شويد.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmcccxxiii{بگو: «هان، چه مى‌پنداريد اگر خدا تا روز رستاخيز شب را بر شما جاويد بدارد؛ جز خداوند كدامين معبود براى شما روشنى مى‌آورد؟ آيا نمى‌شنويد؟»\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmcccxxiv{بگو: «هان، چه مى‌پنداريد اگر خدا تا روز قيامت روز را بر شما جاويد بدارد؛ جز خداوند كدامين معبود براى شما شبى مى‌آورد كه در آن آرام گيريد، آيا نمى‌بينيد؟»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmcccxxv{و از رحمتش برايتان شب و روز را قرار داد تا در اين [يك‌] بياراميد و [در آن يك‌] از فزون‌بخشى او [روزى خود] بجوييد، باشد كه سپاس بداريد.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmcccxxvi{و [ياد كن‌] روزى را كه ندايشان مى‌كند و مى‌فرمايد: «آن شريكان كه مى‌پنداشتيد كجايند؟»\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmcccxxvii{و از ميان هر امتى گواهى بيرون مى‌كشيم و مى‌گوييم: «برهان خود را بياوريد.» پس بدانند كه حقّ از آنِ خداست، و آنچه برمى‌بافتند از دستشان مى‌رود.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmcccxxviii{قارون از قوم موسى بود و بر آنان ستم كرد، و از گنجينه‌ها آن قدر به او داده بوديم كه كليدهاى آنها بر گروه نيرومندى سنگين مى‌آمد، آنگاه كه قوم وى بدو گفتند: «شادى مكن كه خدا شادى‌كنندگان را دوست نمى‌دارد.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmcccxxix{و با آنچه خدايت داده سراى آخرت را بجوى و سهم خود را از دنيا فراموش مكن، و همچنانكه خدا به تو نيكى كرده نيكى كن و در زمين فساد مجوى كه خدا فسادگران را دوست نمى‌دارد.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmcccxxx{[قارون‌] گفت: «من اينها را در نتيجه دانش خود يافته‌ام.» آيا وى ندانست كه خدا نسلهايى را پيش از او نابود كرد كه از او نيرومندتر و مال‌اندوزتر بودند؟ و[لى اين گونه‌] مجرمان را [نيازى‌] به پرسيده شدن از گناهانشان نيست.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxi{پس [قارون‌] با كوكبه خود بر قومش نمايان شد؛ كسانى كه خواستار زندگى دنيا بودند گفتند: «اى كاش مثل آنچه به قارون داده شده به ما [هم‌] داده مى‌شد، واقعاً او بهره بزرگى [از ثروت‌] دارد.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxii{و كسانى كه دانش [واقعى‌] يافته بودند، گفتند: «واى بر شما! براى كسى كه گرويده و كار شايسته كرده پاداش خدا بهتر است، و جز شكيبايان آن را نيابند.»\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxiii{آنگاه [قارون‌] را با خانه‌اش در زمين فرو برديم، و گروهى نداشت كه در برابر [عذاب‌] خدا او را يارى كنند و [خود نيز] نتوانست از خود دفاع كند.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxiv{و همان كسانى كه ديروز آرزو داشتند به جاى او باشند، صبح مى‌گفتند: «واى، مثل اينكه خدا روزى را براى هر كس از بندگانش كه بخواهد گشاده يا تنگ مى‌گرداند، و اگر خدا بر ما منّت ننهاده بود، ما را [هم‌] به زمين فرو برده بود؛ واى، گويى كه كافران رستگار نمى‌گردند.»\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxv{آن سراى آخرت را براى كسانى قرار مى‌دهيم كه در زمين خواستار برترى و فساد نيستند، و فرجام [خوش‌] از آنِ پرهيزگاران است.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxvi{هر كس نيكى به ميان آورد، براى او [پاداشى‌] بهتر از آن خواهد بود، و هر كس بدى به ميان آورد، كسانى كه كارهاى بد كرده‌اند جز سزاى آنچه كرده‌اند نخواهند يافت.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxvii{در حقيقت، همان كسى كه اين قرآن را بر تو فرض كرد، يقيناً تو را به سوى وعده‌گاه بازمى‌گرداند. بگو: «پروردگارم بهتر مى‌داند چه كس هدايت آورده و چه كس در گمراهى آشكارى است؟»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxviii{و تو اميدوار نبودى كه بر تو كتاب القا شود، بلكه اين رحمتى از پروردگار تو بود. پس تو هرگز پشتيبان كافران مباش.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmmcccxxxix{و البته نبايد تو را از آيات خدا -بعد از آنكه بر تو نازل شده است- باز دارند، و به سوى پروردگارت دعوت كن، و زنهار از مشركان مباش.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmmcccxl{و با خدا معبودى ديگر مخوان. خدايى جز او نيست. جز ذات او همه چيز نابودشونده است. فرمان از آنِ اوست. و به سوى او بازگردانيده مى‌شويد.\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmmcccxli{\basmalahfa الف، لام، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmcccxlii{آيا مردم پنداشتند كه تا گفتند ايمان آورديم، رها مى‌شوند و مورد آزمايش قرار نمى‌گيرند؟\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmcccxliii{و به يقين، كسانى را كه پيش از اينان بودند آزموديم، تا خدا آنان را كه راست گفته‌اند معلوم دارد و دروغگويان را [نيز] معلوم دارد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmcccxliv{آيا كسانى كه كارهاى بد مى‌كنند، مى‌پندارند كه بر ما پيشى خواهند جست؟ چه بد داورى مى‌كنند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmcccxlv{كسى كه به ديدار خدا اميد دارد [بداند كه‌] اَجَل [او از سوى‌] خدا آمدنى است، و اوست شنواى دانا.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmcccxlvi{و هر كه بكوشد، تنها براى خود مى‌كوشد، زيرا خدا از جهانيان سخت بى‌نياز است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmcccxlvii{و كسانى كه ايمان آورده، و كارهاى شايسته كرده‌اند، قطعاً گناهانشان را از آنان مى زداييم، و بهتر از آنچه مى‌كردند پاداششان مى‌دهيم.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmcccxlviii{و به انسان سفارش كرديم كه به پدر و مادر خود نيكى كند، و[لى‌] اگر آنها با تو دركوشند تا چيزى را كه بدان علم ندارى با من شريك گردانى، از ايشان اطاعت مكن. سرانجامتان به سوى من است، و شما را از [حقيقت‌] آنچه انجام مى‌داديد باخبر خواهم كرد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmcccxlix{و كسانى كه گرويده و كارهاى شايسته كرده‌اند، البتّه آنان را در زمره شايستگان درمى‌آوريم.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmcccl{و از ميان مردم كسانى‌اند كه مى‌گويند: «به خدا ايمان آورده‌ايم» و چون در [راه‌] خدا آزار كشند، آزمايش مردم را مانند عذاب خدا قرار مى‌دهند؛ و اگر از جانب پروردگارت پيروزى رسد حتماً خواهند گفت: «ما با شما بوديم.» آيا خدا به آنچه در دلهاى جهانيان است داناتر نيست؟\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmcccli{و قطعاً خدا كسانى را كه ايمان آورده‌اند مى‌شناسد، و يقيناً منافقان را [نيز] مى‌شناسد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmccclii{و كسانى كه كافر شده‌اند، به كسانى كه ايمان آورده‌اند مى‌گويند: «راه ما را پيروى كنيد و گناهانتان به گردن ما.» و[لى‌] چيزى از گناهانشان را به گردن نخواهند گرفت؛ قطعاً آنان دروغگويانند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmcccliii{و قطعاً بارهاى گران خودشان و بارهاى گران [ديگر] را با بارهاى گران خود برخواهند گرفت، و مسلّماً روز قيامت از آنچه به دروغ برمى‌بستند پرسيده خواهند شد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmcccliv{و به راستى، نوح را به سوى قومش فرستاديم، پس در ميان آنان نهصد و پنجاه سال درنگ كرد، تا طوفان آنها را در حالى كه ستمكار بودند فرا گرفت.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmccclv{و او را با كشتى‌نشينان برهانيديم و آن [سفينه‌] را براى جهانيان عبرتى گردانيديم.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmccclvi{و [ياد كن‌] ابراهيم را چون به قوم خويش گفت: «خدا را بپرستيد و از او پروا بداريد؛ اگر بدانيد اين [كار] براى شما بهتر است.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmccclvii{واقعاً آنچه را كه شما سواى خدا مى‌پرستيد جز بتانى [بيش‌] نيستند و دروغى برمى‌سازيد. در حقيقت، كسانى را كه جز خدا مى‌پرستيد اختيار روزى شما را در دست ندارند. پس روزى را پيش خدا بجوييد و او را بپرستيد و وى را سپاس گوييد، كه به سوى او بازگردانيده مى‌شويد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmccclviii{و اگر تكذيب كنيد، قطعاً امّتهاى پيش از شما [هم‌] تكذيب كردند، و بر پيامبر [خدا] جز ابلاغ آشكار [وظيفه‌اى‌] نيست.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmccclix{آيا نديده‌اند كه خدا چگونه آفرينش را آغاز مى‌كند سپس آن را باز مى‌گرداند؟ در حقيقت، اين [كار] بر خدا آسان است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmccclx{بگو: «در زمين بگرديد و بنگريد چگونه آفرينش را آغاز كرده است سپس [باز ] خداست كه نشأه آخرت را پديد مى‌آورد؛ خداست كه بر هر چيزى تواناست.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmccclxi{هر كه را بخواهد عذاب و هر كه را بخواهد رحمت مى‌كند و به سوى او بازگردانيده مى شويد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmccclxii{و شما نه در زمين و نه در آسمان درمانده‌كننده [او] نيستيد، و جز خدا براى شما يار و ياورى نيست.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmccclxiii{و كسانى كه آيات خدا و لقاى او را منكر شدند، آنانند كه از رحمت من نوميدند و ايشان را عذابى پر درد خواهد بود.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmccclxiv{و پاسخ قومش جز اين نبود كه گفتند: «بكشيدش يا بسوزانيدش.» ولى خدا او را از آتش نجات بخشيد. آرى، در اين [نجات بخشى خدا] براى مردمى كه ايمان دارند قطعاً دلايلى است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmccclxv{و [ابراهيم‌] گفت: «جز خدا، فقط بتهايى را اختيار كرده‌ايد كه آن هم براى دوستى ميان شما در زندگى دنياست، آنگاه روز قيامت بعضى از شما بعضى ديگر را انكار و برخى از شما برخى ديگر را لعنت مى‌كنند و جايتان در آتش است و براى شما ياورانى نخواهد بود.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmccclxvi{پس لوط به او ايمان آورد و [ابراهيم‌] گفت: «من به سوى پروردگار خود روى مى آورم، كه اوست ارجمند حكيم.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmccclxvii{و اسحاق و يعقوب را به او عطا كرديم و در ميان فرزندانش پيامبرى و كتاب قرار داديم و در دنيا پاداشش را به او بخشيديم و قطعاً او در آخرت [نيز] از شايستگان خواهد بود.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmccclxviii{و [ياد كن‌] لوط را هنگامى كه به قوم خود گفت: «شما به كارى زشت مى‌پردازيد كه هيچ يك از مردم زمين در آن [كار] بر شما پيشى نگرفته است.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmccclxix{آيا شما با مردها درمى‌آميزيد و راه [توالد و تناسل‌] را قطع مى‌كنيد و در محافل [اُنس‌] خود پليدكارى مى‌كنيد؟» و[لى‌] پاسخ قومش جز اين نبود كه گفتند: «اگر راست مى گويى عذاب خدا را براى ما بياور.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmccclxx{[لوط] گفت: «پروردگارا، مرا بر قوم فسادكار غالب گردان.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmccclxxi{و چون فرستادگان ما براى ابراهيم مژده آوردند، گفتند: «ما اهل اين شهر را هلاك خواهيم كرد، زيرا مردمش ستمكار بوده‌اند.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmccclxxii{گفت: «لوط [نيز] در آنجاست.» گفتند: «ما بهتر مى‌دانيم چه كسانى در آنجا هستند؛ او و كسانش را -جز زنش كه از باقى ماندگان [در خاكستر آتش‌] است- حتماً نجات خواهيم داد.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmccclxxiii{و هنگامى كه فرستادگان ما به سوى لوط آمدند، به علت [حضور] ايشان ناراحت شد و دستش از [حمايت‌] آنها كوتاه گرديد. گفتند: «مترس و غم مدار كه ما تو و خانواده‌ات را -جز زنت كه از باقى‌ماندگان [در خاكستر آتش‌] است- حتماً مى رهانيم.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmccclxxiv{ما بر مردم اين شهر به [سزاى‌] فسقى كه مى‌كردند، عذابى از آسمان فرو خواهيم فرستاد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmccclxxv{و از آن [شهر سوخته‌] براى مردمى كه مى‌انديشند نشانه‌اى روشن باقى گذاشتيم.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmccclxxvi{و به سوى [مردم‌] مَدْيَن، برادرشان شعيب را [فرستاديم‌]. گفت: «اى قوم من، خدا را بپرستيد و به روز بازپسين اميد داشته باشيد و در زمين سر به فساد برمداريد.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmccclxxvii{پس او را دروغگو خواندند و زلزله آنان را فرو گرفت و بامدادان در خانه‌هايشان از پا درآمدند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmccclxxviii{و عاد و ثمود را [نيز هلاك نموديم‌]. قطعاً [فرجام آنان‌] از سراهايشان بر شما آشكار گرديده است، و شيطان كارهايشان را در نظرشان بياراست و از راه بازشان داشت با آنكه [در كار دنيا] بينا بودند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmccclxxix{و قارون و فرعون و هامان را [هم هلاك كرديم‌]. و به راستى موسى براى آنان دلايل آشكار آورد، و[لى آنها] در آن سرزمين سركشى نمودند و [با اين همه بر ما] پيشى نجستند.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmccclxxx{و هر يك [از ايشان‌] را به گناهش گرفتار [عذاب‌] كرديم: از آنان كسانى بودند كه بر [سر] ايشان بادى همراه با شن فرو فرستاديم؛ و از آنان كسانى بودند كه فرياد [مرگبار] آنها را فرو گرفت؛ و برخى از آنان را در زمين فرو برديم؛ و بعضى را غرق كرديم؛ و [اين‌] خدا نبود كه بر ايشان ستم كرد بلكه خودشان بر خود ستم مى‌كردند.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxi{داستان كسانى كه غير از خدا دوستانى اختيار كرده‌اند، همچون عنكبوت است كه [با آب دهان خود] خانه‌اى براى خويش ساخته، و در حقيقت -اگر مى‌دانستند- سست‌ترين خانه‌ها همان خانه عنكبوت است.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxii{خدا مى‌داند هر آنچه را كه جز او مى‌خوانند، و هم اوست شكست‌ناپذير سنجيده‌كار.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxiii{و اين مَثَلها را براى مردم مى‌زنيم و[لى‌] جز دانشوران آنها را درنيابند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxiv{خداوند آسمانها و زمين را به حق آفريد. قطعاً در اين [آفرينش‌] براى مؤمنان عبرتى است.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxv{آنچه از كتاب به سوى تو وحى شده است بخوان، و نماز را برپا دار، كه نماز از كار زشت و ناپسند باز مى‌دارد، و قطعاً ياد خدا بالاتر است، و خدا مى‌داند چه مى‌كنيد.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxvi{و با اهل كتاب، جز به [شيوه‌اى‌] كه بهتر است، مجادله مكنيد -مگر [با] كسانى از آنان كه ستم كرده‌اند- و بگوييد: «به آنچه به سوى ما نازل شده و [آنچه‌] به سوى شما نازل گرديده، ايمان آورديم؛ و خداى ما و خداى شما يكى است و ما تسليم اوييم.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxvii{و همچنين ما قرآن را بر تو نازل كرديم. پس آنان كه بديشان كتاب داده‌ايم بدان ايمان مى‌آورند، و از ميان اينان كسانى‌اند كه به آن مى‌گروند، و جز كافران [كسى‌] آيات ما را انكار نمى‌كند.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxviii{و تو هيچ كتابى را پيش از اين نمى‌خواندى و با دست [راست‌] خود [كتابى‌] نمى‌نوشتى، و گر نه باطل‌انديشان قطعاً به شك مى‌افتادند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmccclxxxix{بلكه [قرآن‌] آياتى روشن در سينه‌هاى كسانى است كه علم [الهى‌] يافته‌اند، و جز ستمگران منكر آيات ما نمى‌شوند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmcccxc{و گفتند: «چرا بر او از جانب پروردگارش نشانه‌هايى [معجزه‌آسا] نازل نشده است؟» بگو: «آن نشانه‌ها پيش خداست، و من تنها هشداردهنده‌اى آشكارم.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmcccxci{آيا براى ايشان بس نيست كه اين كتاب را كه بر آنان خوانده مى‌شود بر تو فرو فرستاديم؟ در حقيقت، در اين [كار] براى مردمى كه ايمان دارند، رحمت و يادآورى است.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmcccxcii{بگو: «كافى است خدا ميان من و شما شاهد باشد. آنچه را كه در آسمانها و زمين است مى‌داند، و آنان كه به باطل گرويده و خدا را انكار كرده‌اند همان زيانكارانند.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmcccxciii{و از تو به شتاب درخواست عذاب [الهى را] دارند، و اگر سرآمدى معين نبود، قطعاً عذاب به آنان مى‌رسيد و بى‌آنكه خبردار شوند غافلگيرشان مى‌كرد.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmcccxciv{و شتابزده از تو عذاب مى‌خواهند، و حال آنكه جهنم قطعاً بر كافران احاطه دارد.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmcccxcv{آن روز كه عذاب از بالاى [سر] آنها و از زير پاهايشان آنها را فرو گيرد، و [خدا] مى‌فرمايد: « [نتيجه‌] آنچه را مى‌كرديد بچشيد.»\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmcccxcvi{«اى بندگان من كه ايمان آورده‌ايد، زمين من فراخ است؛ تنها مرا بپرستيد.»\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmcccxcvii{هر نفسى چشنده مرگ است، آنگاه به سوى ما بازگردانيده خواهيد شد.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmcccxcviii{و كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، قطعاً آنان را در غرفه‌هايى از بهشت جاى مى‌دهيم كه از زير آنها جويها روان است، جاودان در آنجا خواهند بود؛ چه نيكوست پاداش عمل‌كنندگان!\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmcccxcix{همان كسانى كه شكيبايى ورزيده و بر پروردگارشان توكل نموده‌اند.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmcd{و چه بسيار جاندارانى كه نمى‌توانند متحمّل روزى خود شوند. خداست كه آنها و شما را روزى مى‌دهد، و اوست شنواى دانا.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmcdi{و اگر از ايشان بپرسى: «چه كسى آسمانها و زمين را آفريده و خورشيد و ماه را [چنين‌] رام كرده است؟» حتماً خواهند گفت: «الله»؛ پس چگونه [از حق‌] بازگردانيده مى‌شوند؟\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmcdii{خدا بر هر كس از بندگانش كه بخواهد روزى را گشاده مى‌گرداند و [يا] بر او تنگ مى‌سازد، زيرا خدا به هر چيزى داناست.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmcdiii{و اگر از آنان بپرسى: «چه كسى از آسمان، آبى فرو فرستاده و زمين را پس از مرگش به وسيله آن زنده گردانيده است؟» حتماً خواهند گفت: «الله.» بگو: «ستايش از آنِ خداست با اين همه، بيشترشان نمى‌انديشند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmcdiv{اين زندگى دنيا جز سرگرمى و بازيچه نيست، و زندگى حقيقى همانا [در] سراى آخرت است؛ اى كاش مى‌دانستند.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmcdv{و هنگامى كه بر كشتى سوار مى‌شوند، خدا را پاكدلانه مى‌خوانند، و[لى‌] چون به سوى خشكى رساند و نجاتشان داد، بناگاه شرك مى‌ورزند.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmcdvi{بگذار تا به آنچه بِديشان داده‌ايم انكار آورند و بگذار تا برخوردار شوند، زودا كه بدانند.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmcdvii{آيا نديده‌اند كه ما [براى آنان‌] حرمى امن قرار داديم و حال آنكه مردم از حوالى آنان ربوده مى‌شوند؟ آيا به باطل ايمان مى‌آورند و به نعمت خدا كفر مى‌ورزند؟\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmcdviii{و كيست ستمكارتر از آن كس كه بر خدا دروغ بندد يا چون حق به سوى او آيد آن را تكذيب كند؟ آيا جاى كافران [در] جهنم نيست؟\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmcdix{و كسانى كه در راه ما كوشيده‌اند، به يقين راه‌هاى خود را بر آنان مى‌نماييم و در حقيقت، خدا با نيكوكاران است.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmcdx{\basmalahfa الف، لام، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmcdxi{روميان شكست خوردند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmcdxii{در نزديكترين سرزمين، و[لى‌] بعد از شكستشان، در ظرف چند سالى، به زودى پيروز خواهند گرديد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmcdxiii{[فرجام‌] كار در گذشته و آينده از آن خداست، و در آن روز است كه مؤمنان از يارى خدا شاد مى‌گردند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmcdxiv{هر كه را بخواهد يارى مى‌كند، و اوست شكست‌ناپذير مهربان.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmcdxv{وعده خداست. خدا وعده‌اش را خلاف نمى‌كند، ولى بيشتر مردم نمى‌دانند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmcdxvi{از زندگى دنيا، ظاهرى را مى‌شناسند، و حال آنكه از آخرت غافلند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmcdxvii{آيا در خودشان به تفكر نپرداخته‌اند؟ خداوند آسمانها و زمين و آنچه را كه ميان آن دو است، جز به حق و تا هنگامى معين، نيافريده است، و [با اين همه‌] بسيارى از مردم لقاى پروردگارشان را سخت منكرند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmcdxviii{آيا در زمين نگرديده‌اند تا ببينند فرجام كسانى كه پيش از آنان بودند، چگونه بوده است؟ آنها بس نيرومندتر از ايشان بودند، و زمين را زير و رو كردند و بيش از آنچه آنها آبادش كردند آن را آباد ساختند، و پيامبرانشان دلايل آشكار برايشان آوردند. بنابراين خدا بر آن نبود كه بر ايشان ستم كند، ليكن خودشان بر خود ستم مى‌كردند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmcdxix{آنگاه فرجام كسانى كه بدى كردند [بسى‌] بدتر بود، [چرا] كه آيات خدا را تكذيب كردند و آنها را به ريشخند مى‌گرفتند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmcdxx{خداست كه آفرينش را آغاز و سپس آن را تجديد مى‌كند، آنگاه به سوى او بازگردانيده مى‌شويد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmcdxxi{و روزى كه قيامت برپا شود مجرمان نوميد مى‌گردند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmcdxxii{و براى آنان از شريكانشان شفيعانى نيست، و خود منكر شريكان خود مى‌شوند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmcdxxiii{و روزى كه رستاخيز برپا گردد، آن روز [مردم‌] پراكنده مى‌شوند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmcdxxiv{اما كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، در گلستانى، شادمان مى‌گردند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmcdxxv{و اما كسانى كه كافر شده و آيات ما و ديدار آخرت را به دروغ گرفته‌اند، پس آنان در عذاب حاضر آيند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmcdxxvi{پس خدا را تسبيح گوييد آنگاه كه به عصر درمى‌آييد و آنگاه كه به بامداد درمى‌شويد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmcdxxvii{و ستايش از آنِ اوست در آسمانها و زمين و شامگاهان و وقتى كه به نيمروز مى‌رسيد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmcdxxviii{زنده را از مرده بيرون مى‌آورد، و مرده را از زنده بيرون مى‌آورد، و زمين را بعد از مرگش زنده مى‌سازد؛ و بدين گونه [از گورها] بيرون آورده مى‌شويد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmcdxxix{و از نشانه‌هاى او اين است كه شما را از خاك آفريد؛ پس بناگاه شما [به صورت‌] بشرى هر سو پراكنده شديد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmcdxxx{و از نشانه‌هاى او اينكه از [نوع‌] خودتان همسرانى براى شما آفريد تا بدانها آرام گيريد، و ميانتان دوستى و رحمت نهاد. آرى، در اين [نعمت‌] براى مردمى كه مى‌انديشند قطعاً نشانه‌هايى است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxi{و از نشانه‌هاى [قدرت‌] او آفرينش آسمانها و زمين و اختلاف زبانهاى شما و رنگهاى شماست. قطعاً در اين [امر نيز] براى دانشوران نشانه‌هايى است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxii{و از نشانه‌هاى [حكمت‌] او خواب شما در شب و [نيم‌] روز و جستجوى شما [روزى خود را] از فزون‌بخشى اوست. در اين [معنى نيز] براى مردمى كه مى‌شنوند، قطعاً نشانه‌هايى است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxiii{و از نشانه‌هاى او [اينكه‌] برق را براى شما بيم‌آور و اميدبخش مى‌نماياند، و از آسمان به تدريج آبى فرو مى‌فرستد، كه به وسيله آن، زمين را پس از مرگش زنده مى‌گرداند. در اين [امر هم‌] براى مردمى كه تعقل مى‌كنند، قطعاً نشانه‌هايى است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxiv{و از نشانه‌هاى او اين است كه آسمان و زمين به فرمانش برپايند؛ پس چون شما را با يك بار خواندن فرا خوانَد، بناگاه [از گورها] خارج مى‌شويد.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxv{و هر كه در آسمانها و زمين است از آنِ اوست؛ همه او را گردن نهاده‌اند.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxvi{و اوست آن كس كه آفرينش را آغاز مى‌كند و باز آن را تجديد مى‌نمايد؛ و اين [كار] بر او آسانتر است. و در آسمانها و زمين نمونه والا[ى هر صفت برتر] از آن اوست، و اوست شكست‌ناپذير سنجيده‌كار.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxvii{[خداوند] براى شما از خودتان مَثَلى زده است: آيا در آنچه به شما روزى داده‌ايم شريكانى از بردگانتان داريد كه در آن [مال با هم‌] مساوى باشيد و همان طور كه شما از يكديگر بيم داريد از آنها بيم داشته باشيد؟ اين گونه، آيات خود را براى مردمى كه مى‌انديشند، به تفصيل بيان مى‌كنيم.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxviii{نه، [اين چنين نيست‌] بلكه كسانى كه ستم كرده‌اند، بدون هيچ گونه دانشى هوسهاى خود را پيروى كرده‌اند. پس آن كس را كه خدا گمراه كرده، چه كسى هدايت مى‌كند؟ و براى آنان ياورانى نخواهد بود.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmcdxxxix{پس روى خود را با گرايش تمام به حق، به سوى اين دين كن، با همان سرشتى كه خدا مردم را بر آن سرشته است. آفرينش خداى تغييرپذير نيست. اين است همان دين پايدار، ولى بيشتر مردم نمى‌دانند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmcdxl{به سويش توبه بريد و از او پروا بداريد و نماز را برپا كنيد و از مشركان مباشيد:\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmcdxli{از كسانى كه دين خود را قطعه قطعه كردند و فرقه فرقه شدند؛ هر حزبى بدانچه پيش آنهاست دلخوش شدند.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmcdxlii{و چون مردم را زيانى رسد، پروردگار خود را، در حالى كه به درگاه او توبه مى‌كنند، مى‌خوانند، و آنگاه كه از جانب خود رحمتى به آنان چشانيد، بناگاه دسته‌اى از ايشان به پروردگارشان شرك مى‌آورند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmcdxliii{بگذار تا به آنچه بدانها عطا كرده‌ايم كفران ورزند. [بگو:] برخوردار شويد، زودا كه خواهيد دانست.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmcdxliv{يا [مگر] حجّتى بر آنان نازل كرده‌ايم كه آن [حجّت‌] در باره آنچه با [خدا] شريك مى‌گردانيده‌اند سخن مى‌گويد؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmcdxlv{و چون مردم را رحمتى بچشانيم، بدان شاد مى‌گردند؛ و چون به [سزاى‌] آنچه دستاورد گذشته آنان است، صدمه‌اى به ايشان برسد، بناگاه نوميد مى‌شوند.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmcdxlvi{آيا ندانسته‌اند كه [اين‌] خداست كه روزى را براى هر كس كه بخواهد فراخ يا تنگ مى‌گرداند؟ قطعاً در اين [امر] براى مردمى كه ايمان مى‌آورند عبرتهاست.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmcdxlvii{پس حق خويشاوند و تنگدست و در راه‌مانده را بده. اين [انفاق‌] براى كسانى كه خواهان خشنودى خدايند بهتر است، و اينان همان رستگارانند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmcdxlviii{و آنچه [به قصد] ربا مى‌دهيد تا در اموال مردم سود و افزايش بردارد، نزد خدا فزونى نمى‌گيرد؛ و[لى‌] آنچه را از زكات -در حالى كه خشنودى خدا را خواستاريد- داديد، پس آنان همان فزونى‌يافتگانند [و مضاعف مى‌شود].\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmcdxlix{خدا همان كسى است كه شما را آفريد، سپس به شما روزى بخشيد، آنگاه شما را مى‌ميراند و پس از آن زنده مى‌گرداند. آيا در ميان شريكان شما كسى هست كه كارى از اين [قبيل‌] كند؟ منزه است او، و برتر است از آنچه [با وى‌] شريك مى‌گردانند.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmcdl{به سبب آنچه دستهاى مردم فراهم آورده، فساد در خشكى و دريا نمودار شده است، تا [سزاى‌] بعضى از آنچه را كه كرده‌اند به آنان بچشاند، باشد كه بازگردند.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmcdli{بگو: «در زمين بگرديد و بنگريد فرجام كسانى كه پيشتر بوده [و] بيشترشان مشرك بودند چگونه بوده است.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmcdlii{پس به سوى اين دين پايدار روى بياور، پيش از آنكه روزى از جانب خدا فرا رسد كه برگشت‌ناپذير باشد، و در آن روز [مردم‌] دسته دسته مى‌شوند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmcdliii{هر كه كفر ورزد، كفرش به زيان اوست، و كسانى كه كار شايسته كنند، [فرجام نيك را] به سود خودشان آماده مى‌كنند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmcdliv{تا [خدا] كسانى را كه ايمان آورده و كارهاى شايسته كرده‌اند، به فضل خويش پاداش دهد، كه او كافران را دوست نمى‌دارد.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmcdlv{و از نشانه‌هاى او اين است كه بادهاى بشارت‌آور را مى‌فرستد، تا بخشى از رحمتش را به شما بچشاند و تا كشتى به فرمانش روان گردد، و تا از فضل او [روزى‌] بجوييد، و اميد كه سپاسگزارى كنيد.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmcdlvi{و در حقيقت، پيش از تو فرستادگانى به سوى قومشان گسيل داشتيم، پس دلايل آشكار برايشان آوردند، و از كسانى كه مرتكب جرم شدند انتقام گرفتيم، و يارى‌كردن مؤمنان بر ما فرض است.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmcdlvii{خدا همان كسى است كه بادها را مى‌فرستد و ابرى برمى‌انگيزد و آن را در آسمان -هر گونه بخواهد- مى‌گستراند و انبوهش مى‌گرداند، پس مى‌بينى باران از لابلاى آن بيرون مى‌آيد. و چون آن را به هر كس از بندگانش كه بخواهد، رسانيد، بناگاه آنان شادمانى مى‌كنند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmcdlviii{و قطعاً پيش از آنكه بر ايشان فرو ريزد، [آرى،] پيش از آن سخت نوميد بودند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmcdlix{پس به آثار رحمت خدا بنگر كه چگونه زمين را پس از مرگش زنده مى‌گرداند. در حقيقت، هم اوست كه قطعاً زنده‌كننده مردگان است، و اوست كه بر هر چيزى تواناست.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmcdlx{و اگر بادى [آفت‌زا] بفرستيم و [كِشت خود را] زردشده ببينند، قطعاً پس از آن كفران مى‌كنند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmcdlxi{و در حقيقت، تو مردگان را شنوا نمى‌گردانى، و اين دعوت را به كران -آنگاه كه به ادبار پشت مى‌گردانند- نمى‌توانى بشنوانى.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmcdlxii{و تو كوران را از گمراهى‌شان به راه نمى‌آورى. تو تنها كسانى را مى‌شنوانى كه به آيات ما ايمان مى‌آورند و خود تسليمند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmcdlxiii{خداست آن كس كه شما را ابتدا ناتوان آفريد، آنگاه پس از ناتوانى قوّت بخشيد، سپس بعد از قوّت، ناتوانى و پيرى داد. هر چه بخواهد مى‌آفريند و هموست داناى توانا.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmcdlxiv{و روزى كه رستاخيز بر پا شود، مجرمان سوگند ياد مى‌كنند كه جز ساعتى [بيش‌] درنگ نكرده‌اند؛ [در دنيا هم‌] اين گونه به دروغ كشانيده مى‌شدند.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmcdlxv{و[لى‌] كسانى كه دانش و ايمان يافته‌اند، مى‌گويند: «قطعاً شما [به موجب آنچه‌] در كتاب خدا[ست‌] تا روز رستاخيز مانده‌ايد، و اين، روز رستاخيز است ولى شما خودتان نمى‌دانستيد.»\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmcdlxvi{و در چنين روزى، [ديگر] پوزش آنان كه ستم كرده‌اند سود نمى‌بخشد، و بازگشت به سوى حق از آنان خواسته نمى‌شود.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmcdlxvii{و به راستى در اين قرآن براى مردم از هر گونه مَثَلى آورديم، و چون براى ايشان آيه‌اى بياورى، آنان كه كفر ورزيده‌اند حتماً خواهند گفت: «شما جز بر باطل نيستيد.»\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmcdlxviii{اين گونه، خدا بر دلهاى كسانى كه نمى‌دانند مُهر مى‌نهد.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmcdlxix{پس صبر كن كه وعده خدا حق است، و زنهار تا كسانى كه يقين ندارند، تو را به سبكسرى واندارند.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmcdlxx{\basmalahfa الف، لام، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxi{اين است آيات كتاب حكمت‌آموز،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxii{[كه‌] براى نيكوكاران رهنمود و رحمتى است،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxiii{[همان‌] كسانى كه نماز برپا مى‌دارند و زكات مى‌دهند، و [هم‌] ايشانند كه به آخرت يقين دارند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxiv{آنانند كه از جانب پروردگارشان از هدايت برخوردارند، و ايشانند كه رستگارانند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxv{و برخى از مردم كسانى‌اند كه سخن بيهوده را خريدارند تا [مردم را] بى‌[هيچ‌] دانشى از راه خدا گمراه كنند، و [راه خدا] را به ريشخند گيرند؛ براى آنان عذابى خواركننده خواهد بود.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxvi{و چون آيات ما بر او خوانده شود، با نِخوت روى برمى‌گرداند، چنانكه گويى آن را نشنيده [يا] گويى در گوشهايش سنگينى است؛ پس او را از عذابى پر درد خبر ده.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxvii{در حقيقت، كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، باغهاى پر نعمت خواهند داشت،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxviii{كه در آن جاودان مى‌مانند؛ وعده خداست كه حق است و هموست شكست‌ناپذير سنجيده‌كار.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxix{آسمانها را بى‌هيچ ستونى كه آن را ببينيد خلق كرد و در زمين كوههاى استوار بيفكند تا [مبادا زمين‌] شما را بجنباند، و در آن از هر گونه جنبنده‌اى پراكنده گردانيد، و از آسمان آبى فرو فرستاديم و از هر نوع [گياه‌] نيكو در آن رويانيديم.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxx{اين، خلق خداست. [اينك‌] به من نشان دهيد كسانى كه غير از اويند چه آفريده‌اند؟ [هيچ!] بلكه ستمگران در گمراهى آشكارند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxi{و به راستى، لقمان را حكمت داديم كه: خدا را سپاس بگزار و هر كه سپاس بگزارد، تنها براى خود سپاس مى‌گزارد؛ و هر كس كفران كند، در حقيقت، خدا بى‌نياز ستوده است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxii{و [ياد كن‌] هنگامى را كه لقمان به پسر خويش -در حالى كه وى او را اندرز مى‌داد- گفت: «اى پسرك من، به خدا شرك مياور كه به راستى شرك ستمى بزرگ است.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxiii{و انسان را در باره پدر و مادرش سفارش كرديم؛ مادرش به او باردار شد، سستى بر روى سستى. و از شير باز گرفتنش در دو سال است. [آرى، به او سفارش كرديم‌] كه شكرگزارِ من و پدر و مادرت باش كه بازگشت [همه‌] به سوى من است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxiv{و اگر تو را وادارند تا در باره چيزى كه تو را بدان دانشى نيست به من شرك ورزى، از آنان فرمان مبر، و[لى‌] در دنيا به خوبى با آنان معاشرت كن، و راه كسى را پيروى كن كه توبه‌كنان به سوى من بازمى‌گردد؛ و [سرانجام‌] بازگشت شما به سوى من است، و از [حقيقت‌] آنچه انجام مى‌داديد شما را با خبر خواهم كرد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxv{«اى پسرك من، اگر [عمل تو] هموزن دانه خَردلى و در تخته‌سنگى يا در آسمانها يا در زمين باشد، خدا آن را مى‌آورد، كه خدا بس دقيق و آگاه است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxvi{اى پسرك من، نماز را برپا دار و به كار پسنديده وادار و از كار ناپسند باز دار، و بر آسيبى كه بر تو وارد آمده است شكيبا باش. اين [حاكى‌] از عزم [و اراده تو در] امور است.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxvii{و از مردم [به نِخوت‌] رُخ برمتاب، و در زمين خرامان راه مرو كه خدا خودپسند لافزن را دوست نمى‌دارد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxviii{و در راه‌رفتن خود ميانه‌رو باش، و صدايت را آهسته‌ساز، كه بدترين آوازها بانگ خران است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmcdlxxxix{آيا ندانسته‌ايد كه خدا آنچه را كه در آسمانها و آنچه را كه در زمين است، مسخّر شما ساخته و نعمتهاى ظاهر و باطن خود را بر شما تمام كرده است؟ و برخى از مردم در باره خدا بى‌[آنكه‌] دانش و رهنمود و كتابى روشن [داشته باشند] به مجادله برمى‌خيزند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmcdxc{و چون به آنان گفته شود: «آنچه را كه خدا نازل كرده پيروى كنيد»، مى‌گويند: «[نه!] بلكه آنچه كه پدرانمان را بر آن يافته‌ايم پيروى مى‌كنيم»؛ آيا هر چند شيطان آنان را به سوى عذاب سوزان فرا خواند؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmcdxci{و هر كس خود را -در حالى كه نيكوكار باشد- تسليم خدا كند، قطعاً در ريسمان استوارترى چنگ درزده، و فرجام كارها به سوى خداست.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmcdxcii{و هر كس كفر ورزد، نبايد كفر او تو را غمگين گرداند. بازگشتشان به سوى ماست، و به [حقيقت‌] آنچه كرده‌اند آگاهشان خواهيم كرد. در حقيقت، خدا به راز دلها داناست.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmcdxciii{[ما] آنان را اندكى برخوردار مى‌سازيم، سپس ايشان را در عذابى پر فشار درمانده مى‌كنيم.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmcdxciv{و اگر از آنها بپرسى: «چه كسى آسمانها و زمين را آفريده است؟ مسلماً خواهند گفت: «خدا.» بگو: «ستايش از آنِ خداست» ولى بيشترشان نمى‌دانند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmcdxcv{آنچه در آسمانها و زمين است از آنِ خداست، در حقيقت، خدا همان بى‌نياز ستوده‌[صفات‌] است.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmcdxcvi{و اگر آن چه درخت در زمين است قلم باشد و دريا را هفت درياى ديگر به يارى آيد، سخنان خدا پايان نپذيرد. قطعاً خداست كه شكست‌ناپذير حكيم است.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmcdxcvii{آفرينش و برانگيختن شما [در نزد ما] جز مانند [آفرينش‌] يك تن نيست، كه خدا شنواى بيناست.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmcdxcviii{آيا نديده‌اى كه خدا شب را در روز درمى‌آورد، و روز را [نيز] در شب درمى‌آورد، و آفتاب و ماه را تسخير كرده است [كه‌] هر يك تا وقت معلومى روانند و [نيز] خدا به آنچه مى‌كنيد آگاه است؟\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmcdxcix{اين‌[ها همه‌] دليل آن است كه خدا خود حق است و غير از او هر چه را كه مى‌خوانند باطل است، و خدا همان بلندمرتبه بزرگ است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmd{آيا نديده‌اى كه كشتيها به نعمت خدا در دريا روان مى‌گردند تا برخى از نشانه‌هاى [قدرت‌] خود را به شما بنماياند؟ قطعاً در اين [قدرت نمايى،] براى هر شكيباى سپاسگزارى، نشانه‌هاست.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmdi{و چون موجى كوه‌آسا آنان را فرا گيرد، خدا را بخوانند و اعتقاد [خود] را براى او خالص گردانند، و[لى‌] چون نجاتشان داد و به خشكى رساند برخى از آنان ميانه‌رو هستند، و نشانه‌هاى ما را جز هر خائن ناسپاسگزارى انكار نمى‌كند.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmdii{اى مردم، از پروردگارتان پروا بداريد، و بترسيد از روزى كه هيچ پدرى به كار فرزندش نمى‌آيد، و هيچ فرزندى [نيز] به كار پدرش نخواهد آمد. آرى، وعده خدا حق است. زنهار تا اين زندگى دنيا شما را نفريبد، و زنهار تا شيطان شما را مغرور نسازد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmdiii{در حقيقت، خداست كه علم [به‌] قيامت نزد اوست، و باران را فرو مى‌فرستد، و آنچه را كه در رحمهاست مى‌داند و كسى نمى‌داند فردا چه به دست مى‌آورد، و كسى نمى‌داند در كدامين سرزمين مى‌ميرد. در حقيقت، خداست [كه‌] داناى آگاه است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmdiv{\basmalahfa الف، لام، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmdv{نازل شدن اين كتاب -كه هيچ [جاى‌] شك در آن نيست- از طرف پروردگار جهانهاست.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmdvi{آيا مى‌گويند: «آن را بربافته است»؟ [نه چنين است‌] بلكه آن حقّ و از جانب پروردگار توست، تا مردمى را كه پيش از تو بيم‌دهنده‌اى براى آنان نيامده است هشدار دهى، اميد كه راه يابند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmdvii{خدا كسى است كه آسمانها و زمين و آنچه را كه ميان آن دو است، در شش هنگام آفريد، آنگاه بر عرش [قدرت‌] استيلا يافت، براى شما غير از او سرپرست و شفاعتگرى نيست؛ آيا باز هم پند نمى‌گيريد؟\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmdviii{كار [جهان‌] را از آسمان [گرفته‌] تا زمين، اداره مى‌كند؛ آنگاه [نتيجه و گزارش آن‌] در روزى كه مقدارش -آن چنان كه شما [آدميان‌] برمى‌شماريد- هزار سال است، به سوى او بالا مى‌رود.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmdix{اوست داناى نهان و آشكار، كه شكوهمند مهربان است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmdx{همان كسى كه هر چيزى را كه آفريده است نيكو آفريده، و آفرينش انسان را از گِل آغاز كرد؛\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmdxi{سپس [تداوم‌] نسل او را از چكيده آبى پست مقرر فرمود؛\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmdxii{آنگاه او را درست‌اندام كرد، و از روح خويش در او دميد، و براى شما گوش و ديدگان و دلها قرار داد؛ چه اندك سپاس مى‌گزاريد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmdxiii{و گفتند: «آيا وقتى در [دلِ‌] زمين گم شديم، آيا [باز] ما در خلقت جديدى خواهيم بود؟» [نه،] بلكه آنها به لقاى پروردگارشان [و حضور او] كافرند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmdxiv{بگو: «فرشته مرگى كه بر شما گمارده شده، جانتان را مى‌ستاند، آنگاه به سوى پروردگارتان بازگردانيده مى‌شويد.»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmdxv{و كاش هنگامى را كه مجرمان پيش پروردگارشان سرهاشان را به زير افكنده‌اند مى‌ديدى [كه مى‌گويند:] «پروردگارا، ديديم و شنيديم؛ ما را بازگردان تا كار شايسته كنيم، چرا كه ما يقين داريم.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmdxvi{و اگر مى‌خواستيم، حتماً به هر كسى [از روى جبر] هدايتش را مى‌داديم، ليكن سخن من محقَقَ گرديده كه: «هر آينه جهنم را از همه جنيان و آدميان خواهم آكند.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmdxvii{پس به [سزاى‌] آنكه ديدار اين روزتان را از ياد برديد [عذاب را] بچشيد؛ ما [نيز] فراموشتان كرديم، و به [سزاى‌] آنچه انجام مى‌داديد عذاب جاودان را بچشيد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmdxviii{تنها كسانى به آيات ما مى‌گروند كه چون آن [آيات‌] را به ايشان يادآورى كنند، سجده‌كنان به روى درمى‌افتند، و به ستايش پروردگارشان تسبيح مى‌گويند و آنان بزرگى نمى‌فروشند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmdxix{پهلوهايشان از خوابگاهها جدا مى‌گردد [و] پروردگارشان را از روى بيم و طمع مى‌خوانند، و از آنچه روزيشان داده‌ايم انفاق مى‌كنند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmdxx{هيچ كس نمى‌داند چه چيز از آنچه روشنى‌بخش ديدگان است به [پاداش‌] آنچه انجام مى‌دادند براى آنان پنهان كرده‌ام.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmdxxi{آيا كسى كه مؤمن است، چون كسى است كه نافرمان است؟ يكسان نيستند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmdxxii{اما كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، به [پاداش‌] آنچه انجام مى‌دادند در باغهايى كه در آن جايگزين مى‌شوند، پذيرايى مى‌گردند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmdxxiii{و اما كسانى كه نافرمانى كرده‌اند، پس جايگاهشان آتش است. هر بار كه بخواهند از آن بيرون بيايند، در آن بازگردانيده مى‌شوند و به آنان گفته مى‌شود: «عذاب آن آتشى را كه دروغش مى‌پنداشتيد بچشيد.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmdxxiv{و قطعاً غير از آن عذاب بزرگتر، از عذاب اين دنيا [نيز] به آنان مى‌چشانيم، اميد كه آنها [به خدا] بازگردند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmdxxv{و كيست بيدادگرتر از آن كس كه به آيات پروردگارش پند داده شود [و] آنگاه از آن روى بگرداند؟ قطعاً ما از مجرمان انتقام‌كِشنده‌ايم.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmdxxvi{و به راستى [ما] به موسى كتاب داديم. پس در لقاى او [با خدا]ترديد مكن، و آن [كتاب‌] را براى فرزندان اسرائيل [مايه‌] هدايت قرار داديم.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmdxxvii{و چون شكيبايى كردند و به آيات ما يقين داشتند، برخى از آنان را پيشوايانى قرار داديم كه به فرمان ما [مردم را] هدايت مى‌كردند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmdxxviii{در حقيقت، پروردگار تو، خود روز قيامت در آنچه با يكديگر در باره آن اختلاف مى‌كردند، ميانشان داورى خواهد كرد.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmdxxix{آيا براى آنان روشن نگرديده كه چه بسيار نسلها را پيش از آنها نابود گردانيديم [كه اينان‌] در سراهايشان راه مى‌روند؟ قطعاً در اين [امر] عبرتهاست، مگر نمى‌شنوند؟\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmdxxx{آيا ننگريسته‌اند كه ما باران را به سوى زمين باير مى‌رانيم، و به وسيله آن كِشته‌اى را برمى‌آوريم كه دامهايشان و خودشان از آن مى‌خورند؟ مگر نمى‌بينند؟\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmdxxxi{و مى‌پرسند: «اگر راست مى‌گوييد، اين پيروزى [شما] چه وقت است؟»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmdxxxii{بگو: «روز پيروزى، ايمان كسانى كه كافر شده‌اند سود نمى‌بخشد و آنان مهلت نمى‌يابند.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmdxxxiii{پس، از ايشان روى برتاب و منتظر باش كه آنها نيز در انتظارند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmdxxxiv{\basmalahfa اى پيامبر، از خدا پروا بدار و كافران و منافقان را فرمان مبر، كه خدا همواره داناى حكيم است.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmdxxxv{و آنچه را كه از جانب پروردگارت به سوى تو وحى مى‌شود، پيروى كن كه خدا همواره به آنچه مى‌كنيد آگاه است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmdxxxvi{و بر خدا اعتماد كن، همين بس كه خدا نگهبان [تو]ست.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmdxxxvii{خداوند براى هيچ مردى در درونش دو دل ننهاده است، و آن همسرانتان را كه مورد «ظهار» قرار مى‌دهيد مادران شما نگردانيده، و پسرخواندگانتان را پسران [واقعى‌] شما قرار نداده است. اين، گفتار شما به زبان شماست، و[لى‌] خدا حقيقت را مى‌گويد، و او[ست كه‌] به راه راست هدايت مى‌كند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmdxxxviii{آنان را به [نام‌] پدرانشان بخوانيد، كه اين نزد خدا عادلانه‌تر است، و اگر پدرانشان را نمى‌شناسيد پس برادران دينى و موالى شمايند، و در آنچه اشتباهاً مرتكب آن شده‌ايد بر شما گناهى نيست، ولى در آنچه دلهايتان عمد داشته است [مسؤوليد ]و خداست كه همواره آمرزنده مهربان است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmdxxxix{پيامبر به مؤمنان از خودشان سزاوارتر [و نزديكتر] است و همسرانش مادران ايشانند، و خويشاوندان [طبق‌] كتاب خدا، بعضى [نسبت‌] به بعضى اولويت دارند [و] بر مؤمنان و مهاجران [مقدّمند]، مگر آنكه بخواهيد به دوستان [مؤمن‌] خود [وصيت يا ]احسانى كنيد، و اين در كتاب [خدا] نگاشته شده است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmdxl{و [ياد كن‌] هنگامى را كه از پيامبران پيمان گرفتيم، و از تو و از نوح و ابراهيم و موسى و عيسى پسر مريم، و از [همه‌] آنان پيمانى استوار گرفتيم.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmdxli{تا راستان را از صدقشان باز پرسد، و براى كافران عذابى دردناك آماده كرده است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmdxlii{اى كسانى كه ايمان آورده‌ايد، نعمت خدا را بر خود به ياد آريد، آنگاه كه لشكرهايى به سوى شما [در]آمدند، پس بر سر آنان تندبادى و لشكرهايى كه آنها را نمى‌ديديد فرستاديم، و خدا به آنچه مى‌كنيد همواره بيناست.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmdxliii{هنگامى كه از بالاى [سر] شما و از زير [پاى‌] شما آمدند، و آنگاه كه چشمها خيره شد و جانها به گلوگاهها رسيد و به خدا گمانهايى [نابجا] مى‌برديد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmdxliv{آنجا [بود كه‌] مؤمنان در آزمايش قرار گرفتند و سخت تكان خوردند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmdxlv{و هنگامى كه منافقان و كسانى كه در دلهايشان بيمارى است مى‌گفتند: «خدا و فرستاده‌اش جز فريب به ما وعده‌اى ندادند.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmdxlvi{و چون گروهى از آنان گفتند: «اى مردم مدينه، ديگر شما را جاى درنگ نيست، برگرديد.» و گروهى از آنان از پيامبر اجازه مى‌خواستند و مى‌گفتند: «خانه‌هاى ما بى‌حفاظ است» و[لى خانه‌هايشان‌] بى‌حفاظ نبود، [آنان‌] جز گريز [از جهاد] چيزى نمى‌خواستند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmdxlvii{و اگر از اطراف [مدينه‌] مورد هجوم واقع مى‌شدند و آنگاه آنان را به ارتداد مى‌خواندند، قطعاً آن را مى‌پذيرفتند و جز اندكى در اين [كار] درنگ نمى‌كردند؛\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmdxlviii{با آنكه قبلاً با خدا سخت پيمان بسته بودند كه پشت [به دشمن‌] نكنند، و پيمان خدا همواره بازخواست دارد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmdxlix{بگو: «اگر از مرگ يا كشته شدن بگريزيد، هرگز اين گريز براى شما سود نمى‌بخشد، و در آن صورت جز اندكى برخوردار نخواهيد شد.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmdl{بگو: «چه كسى مى‌تواند در برابر خدا از شما حمايت كند اگر او بخواهد براى شما بد بياورد يا بخواهد شما را رحمت كند؟ و غير از خدا براى خود يار و ياورى نخواهند يافت.»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmdli{خداوند كارشكنان [و مانع‌شوندگان‌] شما و آن كسانى را كه به برادرانشان مى گفتند: «نزد ما بياييد» و جز اندكى روى به جنگ نمى‌آورند [خوب‌] مى‌شناسد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmdlii{بر شما بخيلانند، و چون خطر فرا رسد آنان را مى‌بينى كه مانند كسى كه مرگ او را فرو گرفته، چشمانشان در حدقه مى‌چرخد [و] به سوى تو مى‌نگرند؛ و چون ترس برطرف شود شما را با زبانهايى تند نيش مى‌زنند؛ بر مال حريصند. آنان ايمان نياورده‌اند و خدا اعمالشان را تباه گردانيده، و اين [كار] همواره بر خدا آسان است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmdliii{اينان [چنين‌] مى‌پندارند كه دسته‌هاى دشمن نرفته‌اند، و اگر دسته‌هاى دشمن بازآيند آرزو مى‌كنند: كاش ميان اعراب باديه‌نشين بودند و از اخبار [مربوط به‌] شما جويا مى‌شدند، و اگر در ميان شما بودند، جز اندكى جنگ نمى‌كردند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmdliv{قطعاً براى شما در [اقتدا به‌] رسول خدا سرمشقى نيكوست: براى آن كس كه به خدا و روز بازپسين اميد دارد و خدا را فراوان ياد مى‌كند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmdlv{و چون مؤمنان دسته‌هاى دشمن را ديدند، گفتند: «اين همان است كه خدا و فرستاده‌اش به ما وعده دادند و خدا و فرستاده‌اش راست گفتند»، و جز بر ايمان و فرمانبردارى آنان نيفزود.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmdlvi{از ميان مؤمنان مردانى‌اند كه به آنچه با خدا عهد بستند صادقانه وفا كردند. برخى از آنان به شهادت رسيدند و برخى از آنها در [همين‌] انتظارند و [هرگز عقيده خود را] تبديل نكردند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmdlvii{تا خدا راستگويان را به [پاداش‌] راستى‌شان پاداش دهد، و منافقان را اگر بخواهد، عذاب كند يا بر ايشان ببخشايد كه خدا همواره آمرزنده مهربان است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmdlviii{و خداوند آنان را كه كفر ورزيده‌اند، بى‌آنكه به مالى رسيده باشند، به غيظ [و حسرت‌] برگرداند، و خدا [زحمت‌] جنگ را از مؤمنان برداشت، و خدا همواره نيرومند شكست‌ناپذير است.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmdlix{و كسانى از اهل كتاب را كه با [مشركان‌] همپُشتى كرده بودند، از دژهايشان به زير آورد و در دلهايشان هراس افكند: گروهى را مى‌كشتيد و گروهى را اسير مى‌كرديد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmdlx{و زمينشان و خانه‌ها و اموالشان و سرزمينى را كه در آن پا ننهاده بوديد به شما ميراث داد، و خدا بر هر چيزى تواناست.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmdlxi{اى پيامبر، به همسرانت بگو: «اگر خواهان زندگى دنيا و زينت آنيد، بياييد تا مَهرتان را بدهم و [خوش و] خُرّم شما را رها كنم.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmdlxii{و اگر خواستار خدا و فرستاده وى و سراى آخرتيد، پس به راستى خدا براى نيكوكاران شما پاداش بزرگى آماده گردانيده است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmdlxiii{اى همسران پيامبر، هر كس از شما مبادرت به كار زشتِ آشكارى كند، عذابش دو چندان خواهد بود؛ و اين بر خدا همواره آسان است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmdlxiv{و هر كس از شما خدا و فرستاده‌اش را فرمان بَرَد و كار شايسته كند، پاداشش را دو چندان مى‌دهيم و برايش روزىِ نيكو فراهم خواهيم ساخت.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmdlxv{اى همسران پيامبر، شما مانند هيچ يك از زنان [ديگر] نيستيد، اگر سر پروا داريد پس به ناز سخن مگوييد تا آنكه در دلش بيمارى است طمع ورزد؛ و گفتارى شايسته گوييد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmdlxvi{و در خانه‌هايتان قرار گيريد و مانند روزگار جاهليت قديم زينتهاى خود را آشكار مكنيد و نماز برپا داريد و زكات بدهيد و خدا و فرستاده‌اش را فرمان بريد. خدا فقط مى‌خواهد آلودگى را از شما خاندان [پيامبر ]بزدايد و شما را پاك و پاكيزه گرداند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmdlxvii{و آنچه را كه از آيات خدا و [سخنان‌] حكمت‌[آميز] در خانه‌هاى شما خوانده مى‌شود ياد كنيد. در حقيقت، خدا همواره دقيق و آگاه است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmdlxviii{مردان و زنان مسلمان، و مردان و زنان با ايمان، و مردان و زنان عبادت‌پيشه، و مردان و زنان راستگو، و مردان و زنان شكيبا، و مردان و زنان فروتن، و مردان و زنان صدقه‌دهنده، و مردان و زنان روزه‌دار، و مردان و زنان پاكدامن، و مردان و زنانى كه خدا را فراوان ياد مى‌كنند، خدا براى [همه‌] آنان آمرزشى و پاداشى بزرگ فراهم ساخته است.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmdlxix{و هيچ مرد و زن مؤمنى را نرسد كه چون خدا و فرستاده‌اش به كارى فرمان دهند، براى آنان در كارشان اختيارى باشد؛ و هر كس خدا و فرستاده‌اش را نافرمانى كند قطعاً دچار گمراهى آشكارى گرديده است.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmdlxx{و آنگاه كه به كسى كه خدا بر او نعمت ارزانى داشته بود و تو [نيز] به او نعمت داده بودى، مى‌گفتى: «همسرت را پيش خود نگاه دار و از خدا پروا بدار» و آنچه را كه خدا آشكاركننده آن بود، در دل خود نهان مى‌كردى و از مردم مى‌ترسيدى، با آنكه خدا سزاوارتر بود كه از او بترسى. پس چون زيد از آن [زن‌] كام برگرفت [و او را ترك گفت‌] وى را به نكاح تو درآورديم تا [در آينده‌] در مورد ازدواج مؤمنان با زنان پسرخواندگانشان -چون آنان را طلاق گفتند- گناهى نباشد، و فرمان خدا صورت اجرا پذيرد.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmdlxxi{بر پيامبر در آنچه خدا براى او فرض گردانيده گناهى نيست. [اين‌] سنّت خداست كه از ديرباز در ميان گذشتگان [معمول‌] بوده، و فرمان خدا همواره به اندازه مقرر [و متناسب با توانايى‌] است.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmdlxxii{همان كسانى كه پيامهاى خدا را ابلاغ مى‌كنند و از او مى‌ترسند و از هيچ كس جز خدا بيم ندارند. و خدا براى حسابرسى كفايت مى‌كند.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmdlxxiii{محمّد پدر هيچ يك از مردان شما نيست، ولى فرستاده خدا و خاتم پيامبران است. و خدا همواره بر هر چيزى داناست.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmdlxxiv{اى كسانى كه ايمان آورده‌ايد، خدا را ياد كنيد، يادى بسيار.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmdlxxv{و صبح و شام او را به پاكى بستاييد.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmdlxxvi{اوست كسى كه با فرشتگان خود بر شما درود مى‌فرستد تا شما را از تاريكيها به سوى روشنايى برآورد، و به مؤمنان همواره مهربان است.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmdlxxvii{درودشان -روزى كه ديدارش كنند- سلام خواهد بود، و براى آنان پاداشى نيكو آماده كرده است.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmdlxxviii{اى پيامبر، ما تو را [به سِمَت‌] گواه و بشارتگر و هشداردهنده فرستاديم،\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmdlxxix{و دعوت‌كننده به سوى خدا به فرمان او، و چراغى تابناك.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmdlxxx{و مؤمنان را مژده دِه كه براى آنان از جانب خدا بخشايشى فراوان خواهد بود.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxi{و كافران و منافقان را فرمان مبر، و از آزارشان بگذر و بر خدا اعتماد كن و كارسازى [چون‌] خدا كفايت مى‌كند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxii{اى كسانى كه ايمان آورده‌ايد، اگر زنان مؤمن را به نكاح خود درآورديد، آنگاه پيش از آنكه با آنان همخوابگى كنيد، طلاقشان داديد، ديگر بر عهده آنها عده‌اى كه آن را بشماريد، نيست؛ پس مَهْرشان را بدهيد و خوش و خرّم آنها را رها كنيد.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxiii{اى پيامبر، ما براى تو آن همسرانى را كه مَهْرشان را داده‌اى حلال كرديم، و [كنيزانى‌] را كه خدا از غنيمت جنگى در اختيار تو قرار داده، و دختران عمويت و دختران عمه‌هايت و دختران دايى تو و دختران خاله‌هايت كه با تو مهاجرت كرده‌اند، و زن مؤمنى كه خود را [داوطلبانه‌] به پيامبر ببخشد-در صورتى كه پيامبر بخواهد او را به زنى گيرد. [اين ازدواج از روى بخشش‌] ويژه توست نه ديگر مؤمنان. ما نيك مى‌دانيم كه در مورد زنان و كنيزانشان چه بر آنان مقرر كرده‌ايم، تا براى تو مشكلى پيش نيايد، و خدا همواره آمرزنده مهربان است.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxiv{نوبت هر كدام از آن زنها را كه مى‌خواهى به تأخير انداز و هر كدام را كه مى‌خواهى پيش خود جاى ده، و بر تو باكى نيست كه هر كدام را كه ترك كرده‌اى [دوباره‌] طلب كنى. اين نزديكتر است براى اينكه چشمانشان روشن گردد و دلتنگ نشوند و همگى‌شان به آنچه به آنان داده‌اى خشنود گردند، و آنچه در دلهاى شماست خدا مى‌داند، و خدا همواره داناى بردبار است.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxv{از اين پس، ديگر [گرفتن‌] زنان و نيز اينكه به جاى آنان، زنان ديگرى بر تو حلال نيست، هر چند زيبايى آنها براى تو مورد پسند افتد، به استثناى كنيزان، و خدا همواره بر هر چيزى مراقب است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxvi{اى كسانى كه ايمان آورده‌ايد، داخل اتاقهاى پيامبر مشويد، مگر آنكه براى [خوردن‌] طعامى به شما اجازه داده شود، [آن هم‌] بى‌آنكه در انتظار پخته‌شدن آن باشيد؛ ولى هنگامى كه دعوت شديد داخل گرديد، و وقتى غذا خورديد پراكنده شويد بى‌آنكه سرگرم سخنى گرديد. اين [رفتار] شما پيامبر را مى‌رنجاند و[لى‌] از شما شرم مى‌دارد، و حال آنكه خدا از حق‌[گويى‌] شرم نمى‌كند، و چون از زنان [پيامبر] چيزى خواستيد از پشت پرده از آنان بخواهيد؛ اين براى دلهاى شما و دلهاى آنان پاكيزه‌تر است، و شما حق نداريد رسول خدا را برنجانيد، و مطلقاً [نبايد] زنانش را پس از [مرگ‌] او به نكاح خود درآوريد، چرا كه اين [كار] نزد خدا همواره [گناهى‌] بزرگ است.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxvii{اگر چيزى را فاش كنيد يا آن را پنهان داريد قطعاً خدا به هر چيزى داناست.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxviii{بر زنان در مورد پدران و پسران و برادران و پسران برادران و پسران خواهران و زنان [همكيش‌] و بردگانشان گناهى نيست [كه ديده شوند]؛ و بايد از خدا پروا بداريد كه خدا همواره بر هر چيزى گواه است.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmdlxxxix{خدا و فرشتگانش بر پيامبر درود مى‌فرستند. اى كسانى كه ايمان آورده‌ايد، بر او درود فرستيد و به فرمانش بخوبى گردن نهيد.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmdxc{بى‌گمان، كسانى كه خدا و پيامبر او را آزار مى‌رسانند، خدا آنان را در دنيا و آخرت لعنت كرده و برايشان عذابى خفت‌آور آماده ساخته است.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmdxci{و كسانى كه مردان و زنان مؤمن را بى‌آنكه مرتكب [عمل زشتى‌] شده باشند آزار مى‌رسانند، قطعاً تهمت و گناهى آشكار به گردن گرفته‌اند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmdxcii{اى پيامبر، به زنان و دخترانت و به زنان مؤمنان بگو: «پوششهاى خود را بر خود فروتر گيرند. اين براى آنكه شناخته شوند و مورد آزار قرار نگيرند [به احتياط] نزديكتر است، و خدا آمرزنده مهربان است.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmdxciii{اگر منافقان و كسانى كه در دلهايشان مرضى هست و شايعه‌افكنان در مدينه، [از كارشان‌] باز نايستند، تو را سخت بر آنان مسلط مى‌كنيم تا جز [مدتى‌] اندك در همسايگى تو نپايند.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmdxciv{از رحمت خدا دور گرديده و هر كجا يافته شوند گرفته و سخت كشته خواهند شد.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmdxcv{در باره كسانى كه پيشتر بوده‌اند [همين‌] سنّت خدا [جارى بوده‌] است؛ و در سنّت خدا هرگز تغييرى نخواهى يافت.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmdxcvi{مردم از تو در باره رستاخيز مى‌پرسند؛ بگو: «علم آن فقط نزد خداست.» و چه مى دانى؟ شايد رستاخيز نزديك باشد.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmdxcvii{خدا كافران را لعنت كرده و براى آنها آتش فروزانى آماده كرده است.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmdxcviii{جاودانه در آن مى‌مانند، نه يارى مى‌يابند و نه ياورى.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmdxcix{روزى كه چهره‌هايشان را در آتش زيرورو مى‌كنند، مى‌گويند: «اى كاش ما خدا را فرمان مى‌برديم و پيامبر را اطاعت مى‌كرديم.»\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmdc{و مى‌گويند: «پروردگارا، ما رؤسا و بزرگتران خويش را اطاعت كرديم و ما را از راه به در كردند.»\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmdci{«پروردگارا، آنان را دو چندان عذاب ده و لعنتشان كن لعنتى بزرگ.»\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmdcii{اى كسانى كه ايمان آورده‌ايد، مانند كسانى مباشيد كه موسى را [با اتهام خود] آزار دادند، و خدا او را از آنچه گفتند مبرّا ساخت و نزد خدا آبرومند بود.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmdciii{اى كسانى كه ايمان آورده‌ايد، از خدا پروا داريد و سخنى استوار گوييد.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmdciv{تا اعمال شما را به صلاح آورد و گناهانتان را بر شما ببخشايد، و هر كس خدا و پيامبرش را فرمان برد قطعاً به رستگارى بزرگى نايل آمده است.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmdcv{ما امانت [الهى و بار تكليف‌] را بر آسمانها و زمين و كوهها عرضه كرديم، پس، از برداشتن آن سر باز زدند و از آن هراسناك شدند، و[لى‌] انسان آن را برداشت؛ راستى او ستمگرى نادان بود.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmdcvi{[آرى، چنين است‌] تا خدا مردان و زنان منافق، و مردان و زنان مشرك را عذاب كند و توبه مردان و زنان با ايمان را بپذيرد، و خدا همواره آمرزنده مهربان است.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmdcvii{\basmalahfa سپاس خدايى را كه آنچه در آسمانها و آنچه در زمين است از آنِ اوست، و در آخرت [نيز] سپاس از آنِ اوست، و هم اوست سنجيده‌كار آگاه.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmdcviii{آنچه در زمين فرو مى‌رود و آنچه از آن بر مى‌آيد و آنچه از آسمان فرو مى‌شود و آنچه در آن بالا مى‌رود [همه را] مى‌داند، و اوست مهربان آمرزنده.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmdcix{و كسانى كه كافر شدند، گفتند: «رستاخيز براى ما نخواهد آمد.» بگو: «چرا، سوگند به پروردگارم كه حتماً براى شما خواهد آمد. [همان‌] داناى نهان‌[ها] كه هموزن ذره‌اى، نه در آسمانها و نه در زمين، از وى پوشيده نيست، و نه كوچكتر از آن و نه بزرگتر از آن است مگر اينكه در كتابى روشن [درج شده‌] است.»\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmdcx{تا كسانى را كه ايمان آورده و كارهاى شايسته كرده‌اند به پاداش رساند؛ آنانند كه آمرزش و روزىِ خوش برايشان خواهد بود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmdcxi{و كسانى كه در [ابطال‌] آيات ما كوشش مى‌ورزند كه ما را درمانده كنند، برايشان عذابى از بلايى دردناك باشد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmdcxii{و كسانى كه از دانش بهره يافته‌اند، مى‌دانند كه آنچه از جانب پروردگارت به سوى تو نازل شده، حق است و به راه آن عزيز ستوده‌[صفات‌] راهبرى مى‌كند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmdcxiii{و كسانى كه كفر ورزيدند، گفتند: «آيا مردى را به شما نشان دهيم كه شما را خبر مى‌دهد كه چون كاملا متلاشى شديد، [باز] قطعاً در آفرينشى جديد خواهيد بود؟\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmdcxiv{آيا [اين مرد] بر خدا دروغى بسته يا جنونى در اوست؟ «[نه!] بلكه آنان كه به آخرت ايمان ندارند در عذاب و گمراهى دور و درازند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmdcxv{آيا به آنچه -از آسمان و زمين- در دسترسشان و پشت سرشان است ننگريسته‌اند؟ اگر بخواهيم آنان را در زمين فرو مى‌بريم، يا پاره‌سنگهايى از آسمان بر سرشان مى‌افكنيم. قطعاً در اين [تهديد] براى هر بنده توبه‌كارى عبرت است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmdcxvi{و به راستى داوود را از جانب خويش مزيتى عطا كرديم. [و گفتيم:] اى كوهها، با او [در تسبيح خدا] همصدا شويد، و اى پرندگان [هماهنگى كنيد]. و آهن را براى او نرم گردانيديم.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmdcxvii{[كه‌] زره‌هاى فراخ بساز و حلقه‌ها را درست اندازه‌گيرى كن. و كار شايسته كنيد، زيرا من به آنچه انجام مى‌دهيد بينايم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmdcxviii{و باد را براى سليمان [رام كرديم:] كه رفتن آن بامداد، يك ماه، و آمدنش شبانگاه، يك ماه [راه‌] بود، و معدن مس را براى او ذوب [و روان‌] گردانيديم، و برخى از جن به فرمان پروردگارشان پيش او كار مى‌كردند، و هر كس از آنها از دستور ما سر برمى‌تافت، از عذاب سوزان به او مى‌چشانيديم.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmdcxix{[آن متخصصان‌] براى او هر چه مى‌خواست: از نمازخانه‌ها و مجسمه‌ها و ظروف بزرگ مانند حوضچه‌ها و ديگهاى چسبيده به زمين مى‌ساختند. اى خاندان داوود، شكرگزار باشيد. و از بندگان من اندكى سپاسگزارند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmdcxx{پس چون مرگ را بر او مقرر داشتيم، جز جنبنده‌اى خاكى [=موريانه‌] كه عصاى او را [به تدريج‌] مى‌خورد، [آدميان را] از مرگ او آگاه نگردانيد، پس چون [سليمان‌] فرو افتاد براى جنيان روشن گرديد كه اگر غيب مى‌دانستند، در آن عذاب خفت‌آور [باقى‌] نمى‌ماندند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmdcxxi{قطعاً براى [مردم‌] سبا در محل سكونتشان نشانه [رحمتى‌] بود: دو باغستان از راست و چپ [به آنان گفتيم:] از روزى پروردگارتان بخوريد و او را شكر كنيد. شهرى است خوش و خدايى آمرزنده.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmdcxxii{پس روى گردانيدند، و بر آن سيل [سدّ] عَرِم را روانه كرديم، و دو باغستان آنها را به دو باغ كه ميوه‌هاى تلخ و شوره‌گز و نوعى از كُنار تنك داشت تبديل كرديم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmdcxxiii{اين [عقوبت‌] را به [سزاى‌] آنكه كفران كردند به آنان جزا داديم؛ و آيا جز ناسپاس را به مجازات مى‌رسانيم؟\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmdcxxiv{و ميان آنان و ميان آبادانيهايى كه در آنها بركت نهاده بوديم شهرهاى متصل به هم قرار داده بوديم، و در ميان آنها مسافت را، به اندازه، مقرر داشته بوديم. در اين [راه‌]ها، شبان و روزان آسوده‌خاطر بگرديد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmdcxxv{تا گفتند: «پروردگارا، ميان [منزلهاى‌] سفرهايمان فاصله انداز.» و بر خويشتن ستم كردند. پس آنها را [براى آيندگان، موضوع‌] حكايتها گردانيديم، و سخت تارومارشان كرديم؛ قطعاً در اين [ماجرا] براى هر شكيباى سپاسگزارى عبرتهاست.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmdcxxvi{و قطعاً شيطان گمان خود را در مورد آنها راست يافت. و جز گروهى از مؤمنان، [بقيه‌] از او پيروى كردند!\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmdcxxvii{و [شيطان‌] را بر آنان تسلطى نبود، جز آنكه كسى را كه به آخرت ايمان دارد از كسى كه در باره آن در ترديد است باز شناسيم. و پروردگار تو بر هر چيزى نگاهبان است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmdcxxviii{بگو: «كسانى را كه جز خدا [معبود خود] پنداشته‌ايد بخوانيد؛ هموزن ذرّه‌اى نه در آسمانها و نه در زمين مالك نيستند، و در آن دو شركتى ندارند، و براى وى از ميان آنان هيچ پشتيبانى نيست.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmdcxxix{و شفاعتگرى در پيشگاه او سود نمى‌بخشد، مگر براى آن كس كه به وى اجازه دهد. تا چون هراس از دلهايشان برطرف شود، مى‌گويند: «پروردگارتان چه فرمود؟» مى گويند: «حقيقت؛ و هموست بلندمرتبه و بزرگ.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmdcxxx{بگو: «كيست كه شما را از آسمانها و زمين روزى مى‌دهد؟» بگو: «خدا؛ و در حقيقت يا ما، يا شما بر هدايت يا گمراهى آشكاريم.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxi{بگو: «[شما] از آنچه ما مرتكب شده‌ايم بازخواست نخواهيد شد، و [ما نيز] از آنچه شما انجام مى‌دهيد بازخواست نخواهيم شد.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxii{بگو: «پروردگارمان ما و شما را جمع خواهد كرد؛ سپس ميان ما به حق داورى مى كند، و اوست داور دانا.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxiii{بگو: «كسانى را كه [به عنوان‌] شريك به او ملحق گردانيده‌ايد، به من نشان دهيد.» چنين نيست، بلكه اوست خداى عزيز حكيم.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxiv{و ما تو را جز [به سمت‌] بشارتگر و هشداردهنده براى تمام مردم، نفرستاديم؛ ليكن بيشتر مردم نمى‌دانند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxv{و مى‌گويند: «اگر راست مى‌گوييد، اين وعده چه وقت است؟»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxvi{بگو: «ميعاد شما روزى است كه نه ساعتى از آن پس توانيد رفت، و نه پيشى توانيد جُست.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxvii{و كسانى كه كافر شدند گفتند: «نه به اين قرآن و نه به آن [توراتى‌] كه پيش از آن است هرگز ايمان نخواهيم آورد.» و اى كاش بيدادگران را هنگامى كه در پيشگاه پروردگارشان بازداشت شده‌اند مى‌ديدى [كه چگونه‌] برخى از آنان با برخى [ديگر جدل و] گفتگو مى‌كنند؛ كسانى كه زيردست بودند به كسانى كه [رياست و] برترى داشتند، مى‌گويند: «اگر شما نبوديد قطعاً ما مؤمن بوديم.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxviii{كسانى كه [رياست و] برترى داشتند، به كسانى كه زيردست بودند، مى‌گويند: «مگر ما بوديم كه شما را از هدايت -پس از آنكه به سوى شما آمد- بازداشتيم؟ [نه،] بلكه خودتان گناهكار بوديد.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmdcxxxix{و كسانى كه زيردست بودند به كسانى كه [رياست و] برترى داشتند، مى‌گويند: «[نه،] بلكه نيرنگ شب و روز [شما بود] آنگاه كه ما را وادار مى‌كرديد كه به خدا كافر شويم و براى او همتايانى قرار دهيم.» و هنگامى كه عذاب را ببينند پشيمانى خود را آشكار كنند. و در گردنهاى كسانى كه كافر شده‌اند غُلها مى‌نهيم؛ آيا جز به سزاى آنچه انجام مى‌دادند مى‌رسند؟\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmdcxl{و [ما] در هيچ شهرى هشداردهنده‌اى نفرستاديم جز آنكه خوشگذرانان آنها گفتند: «ما به آنچه شما بدان فرستاده شده‌ايد كافريم.»\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmdcxli{و گفتند: «ما دارايى و فرزندانمان از همه بيشتر است و ما عذاب نخواهيم شد.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmdcxlii{بگو: «پروردگار من است كه روزى را براى هر كس كه بخواهد گشاده يا تنگ مى گرداند؛ ليكن بيشتر مردم نمى‌دانند.»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmdcxliii{و اموال و فرزندانتان چيزى نيست كه شما را به پيشگاه ما نزديك گرداند، مگر كسانى كه ايمان آورده و كار شايسته كرده باشند. پس براى آنان دو برابر آنچه انجام داده‌اند پاداش است و آنها در غرفه‌ها[ى بهشتى‌] آسوده خاطر خواهند بود.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmdcxliv{و كسانى كه در [ابطال‌] آيات ما مى‌كوشند كه [ما را به خيال خود] درمانده كنند؛ آنانند كه در عذاب احضار مى‌شوند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmdcxlv{بگو: «در حقيقت، پروردگار من است كه روزى را براى هر كس از بندگانش كه بخواهد گشاده يا براى او تنگ مى‌گرداند. و هر چه را انفاق كرديد عوضش را او مى‌دهد. و او بهترين روزى دهندگان است.»\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmdcxlvi{و [ياد كن‌] روزى را كه همه آنان را محشور مى‌كند، آنگاه به فرشتگان مى‌فرمايد: «آيا اينها بودند كه شما را مى‌پرستيدند؟»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmdcxlvii{مى‌گويند: «منزّهى تو، سرپرست ما تويى نه آنها بلكه جنّيان را مى‌پرستيدند؛ بيشترشان به آنها اعتقاد داشتند.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmdcxlviii{اكنون براى يكديگر سود و زيانى نداريد، و به كسانى كه ستم كرده‌اند مى‌گوييم: «بچشيد عذاب آتشى را كه آن را دروغ مى‌شمرديد.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmdcxlix{و چون آيات تابناك ما بر آنان خوانده مى‌شود مى‌گويند: «اين جز مردى نيست كه مى‌خواهد شما را از آنچه پدرانتان مى‌پرستيدند باز دارد.» و [نيز] مى‌گويند: «اين جز دروغى بربافته نيست.» و كسانى كه به حق -چون به سويشان آمد- كافر شدند مى‌گويند: «اين جز افسونى آشكار نيست.»\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmdcl{و ما كتابهايى به آنان نداده بوديم كه آن را بخوانند، و پيش از تو هشداردهنده‌اى به سويشان نفرستاده بوديم.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmdcli{و كسانى كه پيش از اينان بودند، [نيز] تكذيب كردند، در حالى كه اينان به ده‌يك آنچه بديشان داده بوديم نرسيده‌اند. [آرى،] فرستادگانِ مرا دروغ شمردند؛ پس چگونه بود كيفر من؟\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmdclii{بگو: «من فقط به شما يك اندرز مى‌دهم كه: دو دو و به تنهايى براى خدا به پا خيزيد، سپس بينديشيد كه رفيق شما هيچ گونه ديوانگى ندارد. او شما را از عذاب سختى كه در پيش است جز هشداردهنده‌اى [بيش‌] نيست.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmdcliii{بگو: «هر مزدى كه از شما خواستم آن از خودتان مزد من جز بر خدا نيست، و او بر هر چيزى گواه است.»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmdcliv{بگو: «بى‌گمان، پروردگارم حقيقت را القا مى‌كند؛ [اوست‌] داناى نهانها.»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmdclv{بگو: «حق آمد و [ديگر] باطل از سر نمى‌گيرد و برنمى‌گردد.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmdclvi{بگو: «اگر گمراه شوم، فقط به زيان خود گمراه شده‌ام، و اگر هدايت يابم [اين از بركتِ‌] چيزى است كه پروردگارم به سويم وحى مى‌كند، كه اوست شنواى نزديك.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmdclvii{و اى كاش مى‌ديدى هنگامى را كه [كافران‌] وحشت‌زده‌اند [آنجا كه راهِ‌] گريزى نمانده است و از جايى نزديك گرفتار آمده‌اند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmdclviii{و مى‌گويند: «به او ايمان آورديم.» و چگونه از جايى [چنين‌] دور، دست يافتن [به ايمان‌] براى آنان ميسّر است؟\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmdclix{و حال آنكه پيش از اين منكر او شدند، و از جايى دور، به ناديده [تير تهمت‌] مى‌افكندند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmdclx{و ميان آنان و ميان آنچه [به آرزو] مى‌خواستند حايلى قرار مى‌گيرد؛ همان گونه كه از ديرباز با امثال ايشان چنين رفت، زيرا آنها [نيز] در دودلىِ سختى بودند.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmdclxi{\basmalahfa سپاس خداى را كه پديدآورنده آسمان و زمين است [و] فرشتگان را كه داراى بالهاى دوگانه و سه‌گانه و چهارگانه‌اند پيام‌آورنده قرار داده است. در آفرينش، هر چه بخواهد مى‌افزايد، زيرا خدا بر هر چيزى تواناست.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmdclxii{هر رحمتى را كه خدا براى مردم گشايد، بازدارنده‌اى براى آن نيست، و آنچه را كه باز دارد، پس از [باز گرفتن‌] گشاينده‌اى ندارد، و اوست همان شكست‌ناپذير سنجيده‌كار.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmdclxiii{اى مردم، نعمت خدا را بر خود ياد كنيد. آيا غير از خدا آفريدگارى است كه شما را از آسمان و زمين روزى دهد؟ خدايى جز او نيست. پس چگونه [از حق‌] انحراف مى‌يابيد؟\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmdclxiv{و اگر تو را تكذيب كنند، قطعاً پيش از تو [هم‌] فرستادگانى تكذيب شدند. و [همه‌] كارها به سوى خدا بازگردانيده مى‌شود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmdclxv{اى مردم، همانا وعده خدا حق است. زنهار تا اين زندگى دنيا شما را فريب ندهد، و زنهار تا [شيطانِ‌] فريبنده شما را در باره خدا نفريبد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmdclxvi{در حقيقت، شيطان دشمن شماست، شما [نيز] او را دشمن گيريد. [او] فقط دار و دسته خود را مى‌خوانَد تا آنها از ياران آتش باشند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmdclxvii{كسانى كه كفر ورزيده‌اند، عذابى سخت خواهند داشت. و كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، براى آنان آمرزش و پاداشى بزرگ است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmdclxviii{آيا آن كس كه زشتى كردارش براى او آراسته شده و آن را زيبا مى‌بيند [مانند مؤمن نيكوكار است‌]؟ خداست كه هر كه را بخواهد بى‌راه مى‌گذارد و هر كه را بخواهد هدايت مى‌كند. پس مبادا به سبب حسرتها[ى گوناگون‌] بر آنان، جانت [از كف ]برود؛ قطعاً خدا به آنچه مى‌كنند داناست.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmdclxix{و خدا همان كسى است كه بادها را روانه مى‌كند؛ پس [بادها] ابرى را برمى‌انگيزند، و [ما] آن را به سوى سرزمينى مرده رانديم، و آن زمين را بدان [وسيله‌]، پس از مرگش زندگى بخشيديم؛ رستاخيز [نيز ]چنين است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmdclxx{هر كس سربلندى مى‌خواهد، سربلندى يكسره از آنِ خداست. سخنان پاكيزه به سوى او بالا مى‌رود، و كار شايسته به آن رفعت مى‌بخشد. و كسانى كه با حيله و مكر كارهاى بد مى‌كنند، عذابى سخت خواهند داشت، و نيرنگشان خود تباه مى‌گردد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmdclxxi{و خدا[ست كه‌] شما را از خاكى آفريد، سپس از نطفه‌اى، آنگاه شما را جفت جفت گردانيد، و هيچ مادينه‌اى بار نمى‌گيرد و بار نمى‌نهد مگر به علم او. و هيچ سالخورده‌اى عمر دراز نمى‌يابد و از عمرش كاسته نمى‌شود، مگر آنكه در كتابى [مندرج ]است. در حقيقت، اين [كار] بر خدا آسان است!\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmdclxxii{و دو دريا يكسان نيستند: اين يك، شيرين تشنگى‌زدا [و] نوشيدنش گواراست؛ و آن يك، شور تلخ‌مزه است؛ و از هر يك گوشتى تازه مى‌خوريد و زيورى كه آن را بر خود مى‌پوشيد بيرون مى‌آوريد؛ و كشتى را در آن، موج‌شكاف مى‌بينى تا از فضل او [روزى خود را] جستجو كنيد، و اميد كه سپاس بگزاريد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmdclxxiii{شب را به روز درمى‌آورد و روز را به شب درمى‌آورد، و آفتاب و ماه را تسخير كرده است [كه‌] هر يك تا هنگامى معين روانند؛ اين است خدا پروردگار شما؛ فرمانروايى از آنِ اوست. و كسانى را كه بجز او مى‌خوانيد، مالك پوست هسته خرمايى [هم ]نيستند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmdclxxiv{اگر آنها را بخوانيد، دعاى شما را نمى‌شنوند، و اگر [فرضاً] بشنوند اجابتتان نمى‌كنند، و روز قيامت شركِ شما را انكار مى‌كنند؛ و [هيچ كس‌] چون [خداى‌] آگاه، تو را خبردار نمى‌كند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmdclxxv{اى مردم، شما به خدا نيازمنديد، و خداست كه بى‌نياز ستوده است.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmdclxxvi{و اگر بخواهد شما را مى‌بَرد و خلقى نو [بر سر كار] مى‌آورد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmdclxxvii{و اين [امر] براى خدا دشوار نيست.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmdclxxviii{و هيچ باربَردارنده‌اى بار [گناه‌] ديگرى را برنمى‌دارد، و اگر گرانبارى [ديگرى را به يارى‌] به سوى بارش فرا خواند چيزى از آن برداشته نمى‌شود، هر چند خويشاوند باشد. [تو] تنها كسانى را كه از پروردگارشان در نهان مى‌ترسند و نماز برپا مى‌دارند، هشدار مى‌دهى؛ و هر كس پاكيزگى جويد تنها براى خود پاكيزگى مى‌جويد، و فرجام [كارها] به سوى خداست.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmdclxxix{و نابينا و بينا يكسان نيستند،\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmdclxxx{و نه تيرگيها و روشنايى،\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxi{و نه سايه و گرماى آفتاب.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxii{و زندگان و مردگان يكسان نيستند. خداست كه هر كه را بخواهد شنوا مى‌گرداند؛ و تو كسانى را كه در گورهايند نمى‌توانى شنوا سازى.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxiii{تو جز هشداردهنده‌اى [بيش‌] نيستى.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxiv{ما تو را بحق، [به سِمَت‌] بشارتگر و هشداردهنده گسيل داشتيم، و هيچ امتى نبوده مگر اينكه در آن هشداردهنده‌اى گذشته است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxv{و اگر تو را تكذيب كنند، قطعاً كسانى كه پيش از آنها بودند [نيز] به تكذيب پرداختند. پيامبرانشان دلايل آشكار و نوشته‌ها و كتاب روشن براى آنان آوردند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxvi{آنگاه كسانى را كه كافر شده بودند فرو گرفتم؛ پس چگونه بود كيفر من؟\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxvii{آيا نديده‌اى كه خدا از آسمان، آبى فرود آورد و به [وسيله‌] آن ميوه‌هايى كه رنگهاى آنها گوناگون است بيرون آورديم؟ و از برخى كوهها، راهها [و رگه‌ها]ى سپيد و گلگون به رنگهاى مختلف و سياه پر رنگ [آفريديم‌].\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxviii{و از مردمان و جانوران و دامها كه رنگهايشان همان گونه مختلف است [پديد آورديم‌]. از بندگان خدا تنها دانايانند كه از او مى‌ترسند. آرى، خدا ارجمند آمرزنده است.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmdclxxxix{در حقيقت، كسانى كه كتاب خدا را مى‌خوانند و نماز برپا مى‌دارند و از آنچه بديشان روزى داده‌ايم، نهان و آشكارا انفاق مى‌كنند، اميد به تجارتى بسته‌اند كه هرگز زوال نمى‌پذيرد.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmdcxc{تا پاداششان را تمام بديشان عطا كند و از فزون‌بخشى خود در حق آنان بيفزايد كه او آمرزنده حق‌شناس است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmdcxci{و آنچه از كتاب به سوى تو وحى كرده‌ايم، خود حق [و] تصديق‌كننده [كتابهاى‌] پيش از آن است. قطعاً خدا نسبت به بندگانش آگاه بيناست.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmdcxcii{سپس اين كتاب را به آن بندگان خود كه [آنان را] برگزيده بوديم، به ميراث داديم؛ پس برخى از آنان بر خود ستمكارند و برخى از ايشان ميانه‌رو، و برخى از آنان در كارهاى نيك به فرمان خدا پيشگامند؛ و اين خود توفيق بزرگ است.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmdcxciii{[در] بهشتهاى هميشگى [كه‌] به آنها درخواهندآمد. در آنجا با دستبندهايى از زر و مرواريد زيور يابند و در آنجا جامه‌شان پَرنيان خواهد بود.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmdcxciv{و مى‌گويند: «سپاس خدايى را كه اندوه را از ما بزدود، به راستى پروردگار ما آمرزنده [و] حق‌شناس است؛\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmdcxcv{همان [خدايى‌] كه ما را به فضل خويش در سراى ابدى جاى داد. در اينجا رنجى به ما نمى‌رسد و در اينجا درماندگى به ما دست نمى‌دهد.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmdcxcvi{و[لى‌] كسانى كه كافر شده‌اند، آتش جهنم براى آنان خواهد بود. حكم به مرگ بر ايشان [جارى‌] نمى‌شود تا بميرند، و نه عذاب آن از ايشان كاسته شود. [آرى،] هر ناسپاسى را چنين كيفر مى‌دهيم.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmdcxcvii{و آنان در آنجا فرياد برمى‌آورند: «پروردگارا، ما را بيرون بياور، تا غير از آنچه مى‌كرديم، كار شايسته كنيم.» مگر شما را [آن قدر] عمر دراز نداديم كه هر كس كه بايد در آن عبرت گيرد، عبرت مى‌گرفت؛ و [آيا ]براى شما هشداردهنده نيامد؟ پس بچشيد كه براى ستمگران ياورى نيست.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmdcxcviii{خدا[ست كه‌] داناى نهان آسمانها و زمين است، و اوست كه به راز دلها داناست.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmdcxcix{اوست آن كس كه شما را در اين سرزمين جانشين گردانيد. پس هر كس كفر ورزد كفرش به زيان اوست، و كافران را كفرشان جز دشمنى نزد پروردگارشان نمى‌افزايد، و كافران را كفرشان غير از زيان نمى‌افزايد.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmdcc{بگو: «به من خبر دهيد از شريكان خودتان كه به جاى خدا مى‌خوانيد؛ به من نشان دهيد كه چه چيزى از زمين را آفريده‌اند؟ يا آنان در [كار] آسمانها همكارى داشته‌اند؟ يا به ايشان كتابى داده‌ايم كه دليلى بر [حقّانيّت‌] خود از آن دارند؟» [نه،] بلكه ستمكاران جز فريب به يكديگر وعده نمى‌دهند.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmdcci{همانا خدا آسمانها و زمين را نگاه مى‌دارد تا نيفتند، و اگر بيفتند بعد از او هيچ كس آنها را نگاه نمى‌دارد؛ اوست بردبار آمرزنده.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmdccii{و با سوگندهاى سخت خود به خدا سوگند ياد كردند كه اگر هرآينه هشداردهنده‌اى براى آنان بيايد، قطعاً از هر يك از امتها[ى ديگر] راه‌يافته‌تر شوند، و[لى‌] چون هشداردهنده‌اى براى ايشان آمد، جز بر نفرتشان نيفزود.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmdcciii{[انگيزه‌] اين كارشان فقط گردنكشى در [روى‌] زمين و نيرنگ زشت بود، و نيرنگ زشت جز [دامن‌] صاحبش را نگيرد. پس آيا جز سنّت [و سرنوشت شوم‌] پيشينيان را انتظار مى‌برند؟ و هرگز براى سنّت خدا دگرگونى نخواهى يافت.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmdcciv{آيا در زمين نگرديده‌اند تا فرجام [كار] كسانى را كه پيش از ايشان [زيسته‌] و نيرومندتر از ايشان بودند بنگرند؟ و هيچ چيز، نه در آسمانها و نه در زمين، خدا را درمانده نكرده است، چرا كه او همواره داناى تواناست.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmdccv{و اگر خدا مردم را به [سزاى‌] آنچه انجام داده‌اند مؤاخذه مى‌كرد، هيچ جنبنده‌اى را بر پشت زمين باقى نمى‌گذاشت؛ ولى تا مدتى معين مهلتشان مى‌دهد، و چون اجلشان فرا رسد خدا به [كار] بندگانش بيناست.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmdccvi{\basmalahfa يس‌[/ياسين‌]\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmdccvii{سوگند به قرآن حكمت‌آموز،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmdccviii{كه قطعاً تو از [جمله‌] پيامبرانى،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmdccix{بر راهى راست!\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmdccx{[و كتابت‌] از جانب آن عزيز مهربان نازل شده است،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmdccxi{تا قومى را كه پدرانشان بيم‌داده نشدند و در غفلت ماندند، بيم دهى.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmdccxii{آرى، گفته [خدا] در باره بيشترشان محقق گرديده است، در نتيجه آنها نخواهند گرويد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmdccxiii{ما در گردنهاى آنان، تا چانه‌هايشان، غُلهايى نهاده‌ايم، به طورى كه سرهايشان را بالا نگاه داشته و ديده فرو هشته‌اند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmdccxiv{و [ما] فراروى آنها سدى و پشت سرشان سدى نهاده و پرده‌اى بر [چشمان‌] آنان فرو گسترده‌ايم، در نتيجه نمى‌توانند ببينند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmdccxv{و آنان را چه بيم دهى [و] چه بيم ندهى، به حالشان تفاوت نمى‌كند: نخواهند گرويد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmdccxvi{بيم دادن تو، تنها كسى را [سودمند] است كه كتاب حق را پيروى كند و از [خداى‌] رحمان در نهان بترسد. [چنين كسى را] به آمرزش و پاداشى پر ارزش مژده ده.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmdccxvii{آرى! ماييم كه مردگان را زنده مى‌سازيم و آنچه را از پيش فرستاده‌اند، با آثار [و اعمال‌]شان درج مى‌كنيم، و هر چيزى را در كارنامه‌اى روشن برشمرده‌ايم.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmdccxviii{[داستان‌] مردم آن شهرى را كه رسولان بدانجا آمدند براى آنان مَثَل زن:\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmdccxix{آنگاه كه دو تن سوى آنان فرستاديم، و[لى‌] آن دو را دروغزن پنداشتند، تا با [فرستاده‌] سومين [آنان را] تأييد كرديم، پس [رسولان‌] گفتند: «ما به سوى شما به پيامبرى فرستاده شده‌ايم.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmdccxx{[ناباوران آن ديار] گفتند: «شما جز بشرى مانند ما نيستيد، و [خداى‌] رحمان چيزى نفرستاده، و شما جز دروغ نمى‌پردازيد.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmdccxxi{گفتند: «پروردگار ما مى‌داند كه ما واقعاً به سوى شما به پيامبرى فرستاده شده‌ايم.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmdccxxii{و بر ما [وظيفه‌اى‌] جز رسانيدن آشكار [پيام‌] نيست.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmdccxxiii{پاسخ دادند: «ما [حضور] شما را به شگون بد گرفته‌ايم. اگر دست برنداريد، سنگسارتان مى‌كنيم و قطعاً عذاب دردناكى از ما به شما خواهد رسيد.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmdccxxiv{[رسولان‌] گفتند: «شومىِ شما با خود شماست. آيا اگر شما را پند دهند [باز كفر مى‌ورزيد]؟ نه! بلكه شما قومى اسرافكاريد.»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmdccxxv{و [در اين ميان‌] مردى از دورترين جاى شهر دوان دوان آمد، [و] گفت: «اى مردم، از اين فرستادگان پيروى كنيد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmdccxxvi{از كسانى كه پاداشى از شما نمى‌خواهند و خود [نيز] بر راه راست قرار دارند، پيروى كنيد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmdccxxvii{آخر چرا كسى را نپرستم كه مرا آفريده است و [همه‌] شما به سوى او بازگشت مى‌يابيد؟\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmdccxxviii{آيا به جاى او خدايانى را بپرستم كه اگر [خداى‌] رحمان بخواهد به من گزندى برساند، نه شفاعتشان به حالم سود مى‌دهد و نه مى‌توانند مرا برهانند؟\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmdccxxix{در آن صورت، من قطعاً در گمراهى آشكارى خواهم بود.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmdccxxx{من به پروردگارتان ايمان آوردم. [اقرار] مرا بشنويد.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxi{[سرانجام به جرم ايمان كشته شد، و بدو] گفته شد: «به بهشت درآى.» گفت: «اى كاش، قوم من مى‌دانستند،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxii{كه پروردگارم چگونه مرا آمرزيد و در زمره عزيزانم قرار داد.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxiii{پس از [شهادت‌] وى هيچ سپاهى از آسمان بر قومش فرود نياورديم و [پيش از اين هم‌] فروفرستنده نبوديم.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxiv{تنها يك فرياد بود و بس. و بناگاه [همه‌] آنها سرد بر جاى فسردند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxv{دريغا بر اين بندگان! هيچ فرستاده‌اى بر آنان نيامد مگر آنكه او را ريشخند مى‌كردند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxvi{مگر نديده‌اند كه چه بسيار نسلها را پيش از آنان هلاك گردانيديم كه ديگر آنها به سويشان بازنمى‌گردند؟\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxvii{و قطعاً همه آنان در پيشگاه ما احضار خواهند شد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxviii{و زمين مرده، برهانى است براى ايشان، كه آن را زنده گردانيديم و دانه از آن برآورديم كه از آن مى‌خورند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmdccxxxix{و در آن [زمين‌] باغهايى از درختان خرما و تاك قرار داديم و چشمه‌ها در آن روان كرديم.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmdccxl{تا از ميوه آن و [از] كاركرد دستهاى خودشان بخورند، آيا باز [هم‌] سپاس نمى‌گزارند؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmdccxli{پاك [خدايى‌] كه از آنچه زمين مى‌روياند و [نيز] از خودشان و از آنچه نمى‌دانند، همه را نر و ماده گردانيده است.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmdccxlii{و نشانه‌اى [ديگر] براى آنها شب است كه روز را [مانند پوست‌] از آن برمى‌كنيم و بناگاه آنان در تاريكى فرو مى‌روند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmdccxliii{و خورشيد به [سوى‌] قرارگاه ويژه خود روان است. تقدير آن عزيز دانا اين است.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmdccxliv{و براى ماه منزلهايى معين كرده‌ايم، تا چون شاخك خشك خوشه خرما برگردد.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmdccxlv{نه خورشيد را سزد كه به ماه رسد، و نه شب بر روز پيشى جويد، و هر كدام در سپهرى شناورند.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmdccxlvi{و نشانه‌اى [ديگر] براى آنان اينكه: ما نياكانشان را در كشتى انباشته، سوار كرديم.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmdccxlvii{و مانند آن براى ايشان مركوبها[ى ديگرى‌] خلق كرديم.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmdccxlviii{و اگر بخواهيم غرقشان مى‌كنيم و هيچ فريادرسى نمى‌يابند و روى نجات نمى‌بينند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmdccxlix{مگر رحمتى از جانب ما [شامل آنها گردد] و تا چندى [آنها را] برخوردار سازيم.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmdccl{و چون به ايشان گفته شود: «از آنچه در پيش رو و پشت سر داريد بترسيد، اميد كه مورد رحمت قرار گيريد» [نمى‌شنوند].\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmdccli{و هيچ نشانه‌اى از نشانه‌هاى پروردگارشان بر آنان نيامد، جز اينكه از آن رويگردان شدند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmdcclii{و چون به آنان گفته شود: «از آنچه خدا به شما روزى داده انفاق كنيد»، كسانى كه كافر شده‌اند، به آنان كه ايمان آورده‌اند، مى‌گويند: «آيا كسى را بخورانيم كه اگر خدا مى‌خواست [خودش‌] وى را مى‌خورانيد؟ شما جز در گمراهىِ آشكارى [بيش‌] نيستيد.»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmdccliii{و مى‌گويند: «اگر راست مى‌گوييد، پس اين وعده [عذاب‌] كى خواهد بود؟»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmdccliv{جز يك فرياد [مرگبار] را انتظار نخواهند كشيد كه هنگامى كه سرگرم جدالند غافلگيرشان كند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmdcclv{آنگاه نه توانايى وصيّتى دارند و نه مى‌توانند به سوى كسان خود برگردند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmdcclvi{و در صور دميده خواهد شد، پس بناگاه از گورهاى خود شتابان به سوى پروردگار خويش مى‌آيند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmdcclvii{مى‌گويند: «اى واى بر ما، چه كسى ما را از آرامگاهمان برانگيخت؟ اين است همان وعده خداى رحمان، و پيامبران راست مى‌گفتند.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmdcclviii{[باز هم‌] يك فرياد است و بس؛ و بناگاه همه در پيشگاه ما حاضر آيند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmdcclix{امروز بر كسى هيچ ستم نمى‌رود، جز در برابر آنچه كرده‌ايد پاداشى نخواهيد يافت.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmdcclx{در اين روز، اهل بهشت كار و بارى خوش در پيش دارند.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmdcclxi{آنها با همسرانشان در زير سايه‌ها بر تختها تكيه مى‌زنند.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmdcclxii{در آنجا براى آنها [هر گونه‌] ميوه است و هر چه دلشان بخواهد.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmdcclxiii{از جانب پروردگار[ى‌] مهربان [به آنان‌] سلام گفته مى‌شود.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmdcclxiv{و اى گناهكاران، امروز [از بى‌گناهان‌] جدا شويد.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmdcclxv{اى فرزندان آدم، مگر با شما عهد نكرده بودم كه شيطان را مپرستيد، زيرا وى دشمن آشكار شماست؟\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmdcclxvi{و اينكه مرا بپرستيد؛ اين است راه راست!\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmdcclxvii{و [او] گروهى انبوه از ميان شما را سخت گمراه كرد؛ آيا تعقل نمى‌كرديد؟\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmdcclxviii{اين است جهنّمى كه به شما وعده داده مى‌شد!\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmdcclxix{به [جرم‌] آنكه كفر مى‌ورزيديد، اكنون در آن درآييد.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmdcclxx{امروز بر دهانهاى آنان مُهر مى‌نهيم، و دستهايشان با ما سخن مى‌گويند، و پاهايشان بدانچه فراهم مى‌ساختند گواهى مى‌دهند.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxi{و اگر بخواهيم، هر آينه فروغ از ديدگانشان مى‌گيريم تا در راه [كج‌] بر هم پيشى جويند؛ ولى [راه راست را] از كجا مى‌توانند ببينند؟\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxii{و اگر بخواهيم، هرآينه ايشان را در جاى خود مسخ مى‌كنيم [به گونه‌اى‌] كه نه بتوانند بروند و نه برگردند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxiii{و هر كه را عمر دراز دهيم، او را [از نظر] خلقت فروكاسته [و شكسته‌] گردانيم، آيا نمى‌انديشند؟\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxiv{و [ما] به او شعر نياموختيم و در خور وى نيست، اين [سخن‌] جز اندرز و قرآنى روشن نيست.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxv{تا هر كه را [دلى‌] زنده است بيم دهد، و گفتار [خدا] در باره كافران محقق گردد.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxvi{آيا نديده‌اند كه ما به قدرت خويش براى ايشان چهارپايانى آفريده‌ايم تا آنان مالك آنها باشند؟\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxvii{و آنها را براى ايشان رام گردانيديم. از برخى‌شان سوارى مى‌گيرند و از بعضى مى‌خورند.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxviii{و از آنها سودها و نوشيدنيها دارند. پس چرا شكرگزار نيستيد؟\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxix{و غير از خدا[ى يگانه‌] خدايانى به پرستش گرفتند، تا مگر يارى شوند.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxx{[ولى بتان‌] نمى‌توانند آنان را يارى كنند و آنانند كه براى [بتان‌] چون سپاهى احضار شده‌اند.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxi{پس، گفتار آنان تو را غمگين نگرداند كه ما آنچه را پنهان و آنچه را آشكار مى‌كنند، مى‌دانيم.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxii{مگر آدمى ندانسته است كه ما او را از نطفه‌اى آفريده‌ايم، پس بناگاه وى ستيزه‌جويى آشكار شده است.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxiii{و براى ما مَثَلى آورد و آفرينش خود را فراموش كرد؛ گفت: «چه كسى اين استخوانها را كه چنين پوسيده است زندگى مى‌بخشد؟»\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxiv{بگو: «همان كسى كه نخستين‌بار آن را پديد آورد و اوست كه به هر [گونه‌] آفرينشى داناست.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxv{همو كه برايتان در درخت سبزفام اخگر نهاد كه از آن [چون نيازتان افتد] آتش مى‌افروزيد.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxvi{آيا كسى كه آسمانها و زمين را آفريده توانا نيست كه [باز] مانند آنها را بيافريند؟ آرى، اوست آفريننده دانا.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxvii{چون به چيزى اراده فرمايد، كارش اين بس كه مى‌گويد: «باش»؛ پس [بى‌درنگ‌] موجود مى‌شود.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxviii{پس [شكوهمند و] پاك است آن كسى كه ملكوت هر چيزى در دست اوست، و به سوى اوست كه بازگردانيده مى‌شويد.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmdcclxxxix{\basmalahfa سوگند به صف بستگان -كه صفى [با شكوه‌] بسته‌اند-\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmdccxc{و به زجركنندگان -كه به سختى زجر مى‌كنند-\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmdccxci{و به تلاوت‌كنندگان [آيات الهى‌]!\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmdccxcii{كه قطعاً معبود شما يگانه است!\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmdccxciii{پروردگار آسمانها و زمين و آنچه ميان آن دو است، و پروردگار خاورها!\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmdccxciv{ما آسمان اين دنيا را به زيور اختران آراستيم!\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmdccxcv{و [آن را] از هر شيطان سركشى نگاه داشتيم!\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmdccxcvi{[به طورى كه‌] نمى‌توانند به انبوه [فرشتگان‌] عالَم بالا گوش فرا دهند، و از هر سوى پرتاب مى‌شوند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmdccxcvii{با شدت به دور رانده مى‌شوند، و برايشان عذابى دايم است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmdccxcviii{مگر كسى كه [از سخن بالاييان‌] يكباره استراق سمع كند، كه شهابى شكافنده از پى او مى‌تازد!\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmdccxcix{پس، [از كافران‌] بپرس: آيا ايشان [از نظر] آفرينش سخت‌ترند يا كسانى كه [در آسمانها] خلق كرديم؟ ما آنان را از گِلى چسبنده پديد آورديم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmdccc{بلكه عجب مى‌دارى و [آنها] ريشخند مى‌كنند!\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmdccci{و چون پند داده شوند عبرت نمى‌گيرند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmdcccii{و چون آيتى ببينند به ريشخند مى‌پردازند!\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmdccciii{و مى‌گويند: «اين جز سحرى آشكار نيست.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmdccciv{«آيا چون مرديم و خاك و استخوانهاى [خُرد] گرديديم، آيا راستى برانگيخته مى‌شويم؟\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmdcccv{و همين طور پدران اوّليه ما؟!»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmdcccvi{بگو: «آرى! در حالى كه شما خواريد!»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmdcccvii{و آن تنها يك فرياد است و بس! و بناگاه آنان به تماشا خيزند!\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmdcccviii{و مى‌گويند: «اى واى بر ما! اين است روز جزا!»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmdcccix{اين است همان روز داورى كه آن را تكذيب مى‌كرديد!\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmdcccx{كسانى را كه ستم كرده‌اند، با همرديفانشان و آنچه غير از خدا مى‌پرستيده‌اند،\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmdcccxi{گِرد آوريد و به سوى راه جهنم رهبرى‌شان كنيد!\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmdcccxii{و بازداشتشان نماييد كه آنها مسؤولند!\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmdcccxiii{شما را چه شده است كه همديگر را يارى نمى‌كنيد؟!\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmdcccxiv{[نه!] بلكه امروز آنان از در تسليم درآمدگانند!\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmdcccxv{و بعضى روى به بعضى ديگر مى‌آورند [و] از يكديگر مى‌پرسند!\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmdcccxvi{[و] مى‌گويند: «شما [ظاهراً] از درِ راستى با ما درمى‌آمديد [و خود را حق به جانب مى‌نموديد]!»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmdcccxvii{[متّهمان‌] مى‌گويند: «[نه!] بلكه با ايمان نبوديد.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmdcccxviii{و ما را بر شما هيچ تسلطى نبود، بلكه خودتان سركش بوديد.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmdcccxix{پس فرمان پروردگارمان بر ما سزاوار آمد؛ ما واقعاً بايد [عذاب را] بچشيم!\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmdcccxx{و شما را گمراه كرديم، زيرا خودمان گمراه بوديم!»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxi{پس، در حقيقت، آنان در آن روز در عذاب شريك يكديگرند!\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxii{[آرى،] ما با مجرمان چنين رفتار مى‌كنيم!\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxiii{چرا كه آنان بودند كه وقتى به ايشان گفته مى‌شد: «خدايى جز خداى يگانه نيست»، تكبر مى‌ورزيدند!\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxiv{و مى‌گفتند: «آيا ما براى شاعرى ديوانه دست از خدايانمان برداريم؟!»\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxv{ولى نه! [او] حقيقت را آورده و فرستادگان را تصديق كرده است.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxvi{در واقع، شما عذاب پر درد را خواهيد چشيد!\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxvii{و جز آنچه مى‌كرديد جزا نمى‌يابيد!\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxviii{مگر بندگان پاكدل خدا!\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxix{آنان روزىِ معيّن خواهند داشت.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxx{[انواع‌] ميوه‌ها! و آنان مورد احترام خواهند بود.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxi{در باغهاى پر نعمت!\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxii{بر سريرها در برابر همديگر [مى‌نشينند].\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxiii{با جامى از باده ناب پيرامونشان به گردش درمى‌آيند؛\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxiv{[باده‌اى‌] سخت سپيد كه نوشندگان را لذتى [خاص‌] مى‌دهد؛\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxv{نه در آن فساد عقل است و نه ايشان از آن به بدمستى [و فرسودگى‌] مى‌افتند!\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxvi{و نزدشان [دلبرانى‌] فروهشته‌نگاه و فراخ‌ديده باشند!\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxvii{[از شدّت سپيدى‌] گويى تخم شتر مرغ [زير پَرَ]ند!\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxviii{پس برخى‌شان به برخى روى نموده و از همديگر پرس‌وجو مى‌كنند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmdcccxxxix{گوينده‌اى از آنان مى‌گويد: «راستى من [در دنيا] همنشينى داشتم،\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmdcccxl{[كه به من‌] مى‌گفت: «آيا واقعاً تو از باوردارندگانى؟\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmdcccxli{آيا وقتى مُرديم و خاك و [مشتى‌] استخوان شديم، آيا واقعاً جزا مى‌يابيم؟»\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmdcccxlii{[مؤمن‌] مى‌پرسد: «آيا شما اطلاع داريد [كجاست‌]؟»\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmdcccxliii{پس اطلاع حاصل مى‌كند، و او را در ميان آتش مى‌بيند!\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmdcccxliv{[و] مى‌گويد: «به خدا سوگند، چيزى نمانده بود كه تو مرا به هلاكت اندازى.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmdcccxlv{و اگر رحمت پروردگارم نبود، هرآينه من [نيز] از احضارشدگان بودم.»\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmdcccxlvi{[و از روى شوق مى‌گويد:] «آيا ديگر روى مرگ نمى‌بينيم،\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmdcccxlvii{جز همان مرگ نخستين خود؟ و ما هرگز عذاب نخواهيم شد؟!\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmdcccxlviii{راستى كه اين همان كاميابى بزرگ است!»\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmdcccxlix{براى چنين [پاداشى‌] بايد كوشندگان بكوشند.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmdcccl{آيا از نظر پذيرايى اين بهتر است يا درخت زقوم؟!\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmdcccli{در حقيقت، ما آن را براى ستمگران [مايه آزمايش و] عذابى گردانيديم.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmdccclii{آن، درختى است كه از قعر آتش سوزان مى‌رويد،\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmdcccliii{ميوه‌اش گويى چون كله‌هاى شياطين است،\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmdcccliv{پس [دوزخيان‌] حتماً از آن مى‌خورند و شكمها را از آن پر مى‌كنند،\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmdccclv{سپس ايشان را بر سر آن، آميغى از آب جوشان است؛\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmdccclvi{آنگاه بازگشتشان بى‌گمان به سوى دوزخ است.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmdccclvii{آنها پدران خود را گمراه يافتند،\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmdccclviii{پس ايشان به دنبال آنها مى‌شتابند!\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmdccclix{و قطعاً پيش از آنها بيشتر پيشينيان به گمراهى افتادند.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmdccclx{و حال آنكه مسلماً در ميانشان هشداردهندگانى فرستاديم.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmdccclxi{پس ببين فرجام هشدارداده‌شدگان چگونه بود!\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmdccclxii{به استثناى بندگان پاكدل خدا!\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmdccclxiii{و نوح، ما را ندا داد، و چه نيك اجابت‌كننده بوديم!\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmdccclxiv{و او و كسانش را از اندوه بزرگ رهانيديم.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmdccclxv{و [تنها] نسل او را باقى گذاشتيم.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmdccclxvi{و در ميان آيندگان [آوازه نيك‌] او را بر جاى گذاشتيم.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmdccclxvii{درود بر نوح در ميان جهانيان!\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmdccclxviii{ما اين گونه نيكوكاران را پاداش مى‌دهيم.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmdccclxix{به راستى او از بندگان مؤمن ما بود.\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmdccclxx{سپس ديگران را غرق كرديم.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxi{و بى‌گمان، ابراهيم از پيروان اوست.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxii{آنگاه كه با دلى پاك به [پيشگاه‌] پروردگارش آمد.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxiii{چون به پدر[خوانده‌] و قوم خود گفت: «چه مى‌پرستيد؟\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxiv{آيا غير از آنها، به دروغ، خدايانى [ديگر] مى‌خواهيد؟!\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxv{پس گمانتان به پروردگار جهانها چيست؟»\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxvi{پس نظرى به ستارگان افكند،\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxvii{و گفت: «من كسالت دارم!»\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxviii{پس پشت‌كنان از او روى برتافتند!\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxix{تا نهانى به سوى خدايانشان رفت و [به ريشخند] گفت: «آيا غذا نمى‌خوريد؟\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxx{شما را چه شده كه سخن نمى‌گوييد؟!»\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxi{پس با دست راست، بر سر آنها زدن گرفت!\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxii{تا دوان دوان سوى او روى‌آور شدند.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxiii{[ابراهيم‌] گفت: «آيا آنچه را مى‌تراشيد، مى‌پرستيد؟\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxiv{با اينكه خدا شما و آنچه را كه برمى‌سازيد آفريده است!»\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxv{گفتند: «برايش [كوره‌]خانه‌اى بسازيد و در آتشش بيندازيد»\qt@no{(97)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxvi{پس خواستند به از نيرنگى زنند؛ و[لى‌] ما آنان را پست گردانيديم.\qt@no{(98)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxvii{و [ابراهيم‌] گفت: «من به سوى پروردگارم رهسپارم، زودا كه مرا راه نمايد!»\qt@no{(99)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxviii{«اى پروردگار من! مرا [فرزندى‌] از شايستگان بخش.»\qt@no{(100)}}
\qt@newcmd\qurantrans@fa@mmmdccclxxxix{پس او را به پسرى بردبار مژده داديم.\qt@no{(101)}}
\qt@newcmd\qurantrans@fa@mmmdcccxc{و وقتى با او به جايگاه «سعى» رسيد، گفت: «اى پسرك من! من در خواب [چنين‌] مى‌بينم كه تو را سَرْ مى‌بُرم، پس ببين چه به نظرت مى‌آيد؟» گفت: «اى پدر من! آنچه را مأمورى بكن! ان شاء الله مرا از شكيبايان خواهى يافت.»\qt@no{(102)}}
\qt@newcmd\qurantrans@fa@mmmdcccxci{پس وقتى هر دو تن دردادند [و همديگر را بدرود گفتند] و [پسر] را به پيشانى بر خاك افكند،\qt@no{(103)}}
\qt@newcmd\qurantrans@fa@mmmdcccxcii{او را ندا داديم كه اى ابراهيم!\qt@no{(104)}}
\qt@newcmd\qurantrans@fa@mmmdcccxciii{رؤيا[ى خود] را حقيقت بخشيدى! ما نيكوكاران را چنين پاداش مى‌دهيم!\qt@no{(105)}}
\qt@newcmd\qurantrans@fa@mmmdcccxciv{راستى كه اين همان آزمايش آشكار بود!\qt@no{(106)}}
\qt@newcmd\qurantrans@fa@mmmdcccxcv{و او را در ازاى قربانى بزرگى باز رهانيديم.\qt@no{(107)}}
\qt@newcmd\qurantrans@fa@mmmdcccxcvi{و در [ميان‌] آيندگان براى او [آوازه نيك‌] به جاى گذاشتيم.\qt@no{(108)}}
\qt@newcmd\qurantrans@fa@mmmdcccxcvii{درود بر ابراهيم!\qt@no{(109)}}
\qt@newcmd\qurantrans@fa@mmmdcccxcviii{نيكوكاران را چنين پاداش مى‌دهيم.\qt@no{(110)}}
\qt@newcmd\qurantrans@fa@mmmdcccxcix{در حقيقت، او از بندگان با ايمان ما بود.\qt@no{(111)}}
\qt@newcmd\qurantrans@fa@mmmcm{و او را به اسحاق كه پيامبرى از [جمله‌] شايستگان است مژده داديم.\qt@no{(112)}}
\qt@newcmd\qurantrans@fa@mmmcmi{و به او و به اسحاق بركت داديم، و از نسل آن دو برخى نيكوكار و [برخى‌] آشكارا به خود ستمكار بودند.\qt@no{(113)}}
\qt@newcmd\qurantrans@fa@mmmcmii{و در حقيقت، بر موسى و هارون منت نهاديم.\qt@no{(114)}}
\qt@newcmd\qurantrans@fa@mmmcmiii{و آن دو و قومشان را از اندوه بزرگ رهانيديم.\qt@no{(115)}}
\qt@newcmd\qurantrans@fa@mmmcmiv{و آنان را يارى داديم تا ايشان غالب آمدند.\qt@no{(116)}}
\qt@newcmd\qurantrans@fa@mmmcmv{و آن دو را كتاب روشن داديم.\qt@no{(117)}}
\qt@newcmd\qurantrans@fa@mmmcmvi{و هر دو را به راه راست هدايت كرديم.\qt@no{(118)}}
\qt@newcmd\qurantrans@fa@mmmcmvii{و براى آن دو در [ميان‌] آيندگان [نام نيك‌] به جاى گذاشتيم.\qt@no{(119)}}
\qt@newcmd\qurantrans@fa@mmmcmviii{درود بر موسى و هارون!\qt@no{(120)}}
\qt@newcmd\qurantrans@fa@mmmcmix{ما نيكوكاران را چنين پاداش مى‌دهيم،\qt@no{(121)}}
\qt@newcmd\qurantrans@fa@mmmcmx{زيرا آن دو از بندگان با ايمان ما بودند.\qt@no{(122)}}
\qt@newcmd\qurantrans@fa@mmmcmxi{و به راستى الياس از فرستادگان [ما] بود.\qt@no{(123)}}
\qt@newcmd\qurantrans@fa@mmmcmxii{چون به قوم خود گفت: «آيا پروا نمى‌داريد؟\qt@no{(124)}}
\qt@newcmd\qurantrans@fa@mmmcmxiii{آيا «بعل» را مى‌پرستيد و بهترين آفرينندگان را وامى‌گذاريد؟!\qt@no{(125)}}
\qt@newcmd\qurantrans@fa@mmmcmxiv{[يعنى:] خدا را كه پروردگار شما و پروردگار پدران پيشين شماست؟!\qt@no{(126)}}
\qt@newcmd\qurantrans@fa@mmmcmxv{پس او را دروغگو شمردند، و قطعاً آنها [در آتش‌] احضار خواهند شد-\qt@no{(127)}}
\qt@newcmd\qurantrans@fa@mmmcmxvi{مگر بندگان پاكدين خدا.\qt@no{(128)}}
\qt@newcmd\qurantrans@fa@mmmcmxvii{و براى او در [ميان‌] آيندگان [آوازه نيك‌] به جاى گذاشتيم.\qt@no{(129)}}
\qt@newcmd\qurantrans@fa@mmmcmxviii{درود بر پيروان الياس!\qt@no{(130)}}
\qt@newcmd\qurantrans@fa@mmmcmxix{ما نيكوكاران را اين گونه پاداش مى‌دهيم،\qt@no{(131)}}
\qt@newcmd\qurantrans@fa@mmmcmxx{زيرا او از بندگان با ايمان ما بود.\qt@no{(132)}}
\qt@newcmd\qurantrans@fa@mmmcmxxi{و در حقيقت، لوط از زمره فرستادگان بود.\qt@no{(133)}}
\qt@newcmd\qurantrans@fa@mmmcmxxii{آنگاه كه او و همه كسانش را رهانيديم-\qt@no{(134)}}
\qt@newcmd\qurantrans@fa@mmmcmxxiii{جز پيرزنى كه در ميان باقى‌ماندگان [و خاكسترشدگان‌] بود-\qt@no{(135)}}
\qt@newcmd\qurantrans@fa@mmmcmxxiv{سپس ديگران را هلاك كرديم.\qt@no{(136)}}
\qt@newcmd\qurantrans@fa@mmmcmxxv{و در حقيقت، شما بر آنان صبحگاهان\qt@no{(137)}}
\qt@newcmd\qurantrans@fa@mmmcmxxvi{و شامگاهان مى‌گذريد! آيا به فكر فرو نمى‌رويد؟!\qt@no{(138)}}
\qt@newcmd\qurantrans@fa@mmmcmxxvii{و در حقيقت، يونس از زمره فرستادگان بود.\qt@no{(139)}}
\qt@newcmd\qurantrans@fa@mmmcmxxviii{آنگاه كه به سوى كشتى پر، بگريخت!\qt@no{(140)}}
\qt@newcmd\qurantrans@fa@mmmcmxxix{پس [سرنشينان‌] با هم قرعه انداختند و [يونس‌] از باختگان شد.\qt@no{(141)}}
\qt@newcmd\qurantrans@fa@mmmcmxxx{[او را به دريا افكندند] و عنبرماهى او را بلعيد در حالى كه او نكوهشگر خويش بود!\qt@no{(142)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxi{و اگر او از زمره تسبيح‌كنندگان نبود،\qt@no{(143)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxii{قطعاً تا روزى كه برانگيخته مى‌شوند، در شكم آن [ماهى‌] مى‌ماند!\qt@no{(144)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxiii{پس او را در حالى كه ناخوش بود به زمين خشكى افكنديم!\qt@no{(145)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxiv{و بر بالاى [سرِ] او درختى از [نوع‌] كدوبُن رويانيديم.\qt@no{(146)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxv{و او را به سوى يكصدهزار [نفر از ساكنان نينوا] يا بيشتر روانه كرديم.\qt@no{(147)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxvi{پس ايمان آوردند و تا چندى برخوردارشان كرديم.\qt@no{(148)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxvii{پس، از مشركان جويا شو: آيا پروردگارت را دختران و آنان را پسران است؟!\qt@no{(149)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxviii{يا فرشتگان را مادينه آفريديم و آنان شاهد بودند؟\qt@no{(150)}}
\qt@newcmd\qurantrans@fa@mmmcmxxxix{هش‌دار كه اينان از دروغ پردازى خود قطعاً خواهند گفت:\qt@no{(151)}}
\qt@newcmd\qurantrans@fa@mmmcmxl{«خدا فرزند آورده!» در حالى كه آنها قطعاً دروغگويانند!\qt@no{(152)}}
\qt@newcmd\qurantrans@fa@mmmcmxli{آيا [خدا] دختران را بر پسران برگزيده است؟\qt@no{(153)}}
\qt@newcmd\qurantrans@fa@mmmcmxlii{شما را چه شده؟ چگونه داورى مى‌كنيد؟\qt@no{(154)}}
\qt@newcmd\qurantrans@fa@mmmcmxliii{آيا سرِ پند گرفتن نداريد؟!\qt@no{(155)}}
\qt@newcmd\qurantrans@fa@mmmcmxliv{يا دليلى آشكار [در دست‌] داريد؟\qt@no{(156)}}
\qt@newcmd\qurantrans@fa@mmmcmxlv{پس اگر راست مى‌گوييد كتابتان را بياوريد.\qt@no{(157)}}
\qt@newcmd\qurantrans@fa@mmmcmxlvi{و ميان خدا و جن‌ها پيوندى انگاشتند و حال آنكه جنيان نيك دانسته‌اند كه [براى حساب پس‌دادن،] خودشان احضار خواهند شد.\qt@no{(158)}}
\qt@newcmd\qurantrans@fa@mmmcmxlvii{خدا منزه است از آنچه در وصف مى‌آورند.\qt@no{(159)}}
\qt@newcmd\qurantrans@fa@mmmcmxlviii{به استثناى بندگان پاكدل خدا.\qt@no{(160)}}
\qt@newcmd\qurantrans@fa@mmmcmxlix{در حقيقت، شما و آنچه [كه شما آن را] مى‌پرستيد،\qt@no{(161)}}
\qt@newcmd\qurantrans@fa@mmmcml{بر ضد او گمراه‌گر نيستيد،\qt@no{(162)}}
\qt@newcmd\qurantrans@fa@mmmcmli{مگر كسى را كه به دوزخ رفتنى است!\qt@no{(163)}}
\qt@newcmd\qurantrans@fa@mmmcmlii{و هيچ يك از ما [فرشتگان‌] نيست مگر [اينكه‌] براى او [مقام و] مرتبه‌اى معيّن است.\qt@no{(164)}}
\qt@newcmd\qurantrans@fa@mmmcmliii{و در حقيقت، ماييم كه [براى انجام فرمان خدا] صف بسته‌ايم.\qt@no{(165)}}
\qt@newcmd\qurantrans@fa@mmmcmliv{و ماييم كه خود تسبيح‌گويانيم.\qt@no{(166)}}
\qt@newcmd\qurantrans@fa@mmmcmlv{و [مشركان‌] به تأكيد مى‌گفتند:\qt@no{(167)}}
\qt@newcmd\qurantrans@fa@mmmcmlvi{«اگر پند [نامه‌ا]ى از پيشينيان نزد ما بود،\qt@no{(168)}}
\qt@newcmd\qurantrans@fa@mmmcmlvii{قطعاً از بندگان خالص خدا مى‌شديم!»\qt@no{(169)}}
\qt@newcmd\qurantrans@fa@mmmcmlviii{ولى [وقتى قرآن آمد] به آن كافر شدند، و زودا كه بدانند!\qt@no{(170)}}
\qt@newcmd\qurantrans@fa@mmmcmlix{و قطعاً فرمان ما در باره بندگان فرستاده ما از پيش [چنين‌] رفته است:\qt@no{(171)}}
\qt@newcmd\qurantrans@fa@mmmcmlx{كه آنان [بر دشمنان خودشان‌] حتماً پيروز خواهند شد.\qt@no{(172)}}
\qt@newcmd\qurantrans@fa@mmmcmlxi{و سپاه ما هرآينه غالب‌آيندگانند.\qt@no{(173)}}
\qt@newcmd\qurantrans@fa@mmmcmlxii{پس تا مدتى [معيّن‌] از آنان روى برتاب.\qt@no{(174)}}
\qt@newcmd\qurantrans@fa@mmmcmlxiii{و آنان را بنگر كه خواهند ديد.\qt@no{(175)}}
\qt@newcmd\qurantrans@fa@mmmcmlxiv{آيا عذاب ما را شتابزده خواستارند؟\qt@no{(176)}}
\qt@newcmd\qurantrans@fa@mmmcmlxv{[پس هشدارداده‌شدگان را] آنگاه كه عذاب به خانه آنان فرود آيد چه بد صبحگاهى است!\qt@no{(177)}}
\qt@newcmd\qurantrans@fa@mmmcmlxvi{و از ايشان تا مدتى [معيّن‌] روى برتاب.\qt@no{(178)}}
\qt@newcmd\qurantrans@fa@mmmcmlxvii{و بنگر كه خواهند ديد!\qt@no{(179)}}
\qt@newcmd\qurantrans@fa@mmmcmlxviii{منزه است پروردگار تو، پروردگار شكوهمند، از آنچه وصف مى‌كنند.\qt@no{(180)}}
\qt@newcmd\qurantrans@fa@mmmcmlxix{و درود بر فرستادگان!\qt@no{(181)}}
\qt@newcmd\qurantrans@fa@mmmcmlxx{و ستايش، ويژه خدا، پروردگار جهانهاست.\qt@no{(182)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxi{\basmalahfa صاد. سوگند به قرآن پراندرز!\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxii{آرى، آنان كه كفر ورزيدند در سركشى و ستيزه‌اند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxiii{چه بسيار نسلها كه پيش از ايشان هلاك كرديم كه [ما را] به فرياد خواندند، و[لى‌] ديگر مجال گريز نبود.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxiv{و از اينكه هشداردهنده‌اى از خودشان برايشان آمده درشگفتند، و كافران مى گويند: «اين، ساحرى شيّاد است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxv{آيا خدايان [متعدد] را خداى واحدى قرار داده؟ اين واقعاً چيز عجيبى است.»\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxvi{و بزرگانشان روان شدند [و گفتند:] «برويد و بر خدايان خود ايستادگى نماييد كه اين امر قطعاً هدف [ما]ست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxvii{[از طرفى‌] اين [مطلب‌] را در آيين اخير [عيسوى هم‌] نشنيده‌ايم، اين [ادّعا] جز دروغ‌بافى نيست.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxviii{آيا از ميان ما قرآن بر او نازل شده است؟» [نه!] بلكه آنان در باره قرآنِ من دودلند. [نه،] بلكه هنوز عذاب [مرا] نچشيده‌اند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxix{آيا گنجينه‌هاى رحمت پروردگار ارجمندِ بسيار بخشنده تو نزد ايشان است؟\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxx{آيا فرمانروايى آسمانها و زمين و آنچه ميان آن دو است از آنِ ايشان است؟ [اگر چنين است‌] پس [با چنگ زدن‌] در آن اسباب به بالا روند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxi{اين سپاهك دسته‌هاى دشمن در آنجا [=بَدْر] در هم شكستنى‌اند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxii{پيش از ايشان قوم نوح و عاد و فرعونِ صاحب [عمارت و] خرگاهها تكذيب كردند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxiii{و ثمود و قوم لوط و اصحاب ايكه [نيز به تكذيب پرداختند] آنها دسته‌هاى مخالف بودند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxiv{هيچ كدام نبودند كه پيامبران [ما] را تكذيب نكنند، پس عقوبت [من بر آنان‌] سزاوار آمد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxv{و اينان جز يك فرياد را انتظار نمى‌بَرند كه هيچ [مجال‌] سر خاراندنى در آن نيست.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxvi{و گفتند: «پروردگارا، پيش از [رسيدن‌] روز حساب، بهره ما را [از عذاب‌] به شتاب به ما بده.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxvii{بر آنچه مى‌گويند صبر كن، و داوود، بنده ما را كه داراى امكانات [متعدّد] بود به ياد آور؛ آرى، او بسيار بازگشت‌كننده [به سوى خدا] بود.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxviii{ما كوهها را با او مسخّر ساختيم [كه‌] شامگاهان و بامدادان خداوند را نيايش مى‌كردند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmcmlxxxix{و پرندگان را از هر سو [بر او] گرد [آورديم‌] همگى [به نواى دلنوازش‌] به سوى او بازگشت‌كننده [و خدا را ستايشگر] بودند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmcmxc{و پادشاهيش را استوار كرديم و او را حكمت و كلام فيصله‌دهنده عطا كرديم.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmcmxci{و آيا خبر دادخواهان -چون از نمازخانه [او] بالا رفتند- به تو رسيد؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmcmxcii{وقتى [به طور ناگهانى‌] بر داوود درآمدند، و او از آنان به هراس افتاد، گفتند: «مترس، [ما] دو مدّعى [هستيم‌] كه يكى از ما بر ديگرى تجاوز كرده، پس ميان ما به حق داورى كن، و از حق دور مشو، و ما را به راه راست راهبر باش.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmcmxciii{«اين [شخص‌] برادر من است. او را نود و نه ميش، و مرا يك ميش است، و مى‌گويد: آن را به من بسپار، و در سخنورى بر من غالب آمده است.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmcmxciv{[داوود] گفت: «قطعاً او در مطالبه ميش تو [اضافه‌] بر ميش‌هاى خودش، بر تو ستم كرده، و در حقيقت بسيارى از شريكان به همديگر ستم روا مى‌دارند، به استثناى كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، و اينها بس اندكند، و داوود دانست كه ما او را آزمايش كرده‌ايم. پس، از پروردگارش آمرزش خواست و به رو درافتاد و توبه كرد.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmcmxcv{و بر او اين [ماجرا] را بخشوديم؛ و در حقيقت براى او پيش ما تقرّب و فرجامى خوش خواهد بود.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmcmxcvi{اى داوود، ما تو را در زمين خليفه [و جانشين‌] گردانيديم؛ پس ميان مردم به حق داورى كن، و زنهار از هوس پيروى مكن كه تو را از راه خدا به در كند. در حقيقت كسانى كه از راه خدا به در مى‌روند، به [سزاى‌] آنكه روز حساب را فراموش كرده‌اند عذابى سخت خواهند داشت!\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmcmxcvii{و آسمان و زمين و آنچه را كه ميان اين دو است به باطل نيافريديم، اين گمان كسانى است كه كافر شده [و حق‌پوشى كرده‌]اند، پس واى از آتش بر كسانى كه كافر شده‌اند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmcmxcviii{يا [مگر] كسانى را كه گرويده و كارهاى شايسته كرده‌اند، چون مفسدان در زمين مى‌گردانيم، يا پرهيزگاران را چون پليدكاران قرار مى‌دهيم؟\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmcmxcix{[اين‌] كتابى مبارك است كه آن را به سوى تو نازل كرده‌ايم تا در [باره‌] آيات آن بينديشند، و خردمندان پند گيرند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmm{و سليمان را به داوود بخشيديم. چه نيكو بنده‌اى. به راستى او توبه‌كار [و ستايشگر] بود.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmi{هنگامى كه [طرف‌] غروب، اسبهاى اصيل را بر او عرضه كردند،\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmii{[سليمان‌] گفت: «واقعاً من دوستى اسبان را بر ياد پروردگارم ترجيح دادم تا [هنگام نماز گذشت و خورشيد] در پس حجاب ظلمت شد.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmiii{[گفت: « اسبها] را نزد من باز آوريد.» پس شروع كرد به دست كشيدن بر ساقها و گردن آنها [و سرانجام وقف كردن آنها در راه خدا].\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmiv{و قطعاً سليمان را آزموديم و بر تخت او جسدى بيفكنديم؛ پس به توبه باز آمد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmv{گفت: «پروردگارا، مرا ببخش و مُلكى به من ارزانى دار كه هيچ كس را پس از من سزاوار نباشد، در حقيقت، تويى كه خود بسيار بخشنده‌اى.»\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmvi{پس باد را در اختيار او قرار داديم كه هر جا تصميم مى‌گرفت، به فرمان او نرم، روان مى‌شد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmvii{و شيطانها را [از] بنّا و غواص،\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmviii{تا [وحشيان‌] ديگر را كه جفت جفت با زنجيرها به هم بسته بودند [تحت فرمانش درآورديم‌].\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmix{[گفتيم:] «اين بخشش ماست، [آن را] بى‌شمار ببخش يا نگاه دار.»\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmx{و قطعاً براى او در پيشگاه ما تقرّب و فرجام نيكوست.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmxi{و بنده ما ايوب را به ياد آور، آنگاه كه پروردگارش را ندا داد كه: «شيطان مرا به رنج و عذاب مبتلا كرد.»\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmxii{[به او گفتيم:] «با پاى خود [به زمين‌] بكوب، اينك اين چشمه‌سارى است سرد و آشاميدنى.»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmxiii{و [مجدداً] كسانش را و نظاير آنها را همراه آنها به او بخشيديم، تا رحمتى از جانب ما و عبرتى براى خردمندان باشد.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmxiv{[و به او گفتيم:] «يك بسته تركه به دستت برگير و [همسرت را] با آن بزن و سوگند مشكن.» ما او را شكيبا يافتيم. چه نيكوبنده‌اى! به راستى او توبه‌كار بود.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmxv{و بندگان ما ابراهيم و اسحاق و يعقوب را كه نيرومند و ديده‌ور بودند به يادآور.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmxvi{ما آنان را با موهبت ويژه‌اى -كه يادآورى آن سراى بود- خالص گردانيديم.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmxvii{و آنان در پيشگاه ما جداً از برگزيدگان نيكانند.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmxviii{و اسماعيل و يسع و ذوالكفل را به ياد آور [كه‌] همه از نيكانند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmxix{اين يادكردى است، و قطعاً براى پرهيزگاران فرجامى نيك است.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmxx{باغهاى هميشگى در حالى كه درهاى [آنها] برايشان گشوده‌است.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmxxi{در آنجا تكيه مى‌زنند [و] ميوه‌هاى فراوان و نوشيدنى در آنجا طلب مى‌كنند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmxxii{و نزدشان [دلبران‌] فروهشته‌نگاه همسال است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmxxiii{اين است آنچه براى روز حساب به شما وعده داده مى‌شد.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmxxiv{[مى‌گويند:] «در حقيقت، اين روزىِ ماست و آن را پايانى نيست.»\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmxxv{اين است [حال بهشتيان‌] و [اما] براى طغيانگران واقعاً بد فرجامى است.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmxxvi{به جهنّم درمى‌آيند، و چه بد آرامگاهى است.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmxxvii{اين جوشاب و چركاب است، بايد آن را بچشند.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmxxviii{و از همين گونه، انواع ديگر [عذابها]!\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmxxix{اينها گروهى‌اند كه با شما به اجبار [در آتش‌] درمى‌آيند. بدا به حال آنها، زيرا آنان داخل آتش مى‌شوند.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmxxx{[به رؤساى خود] مى‌گويند: «بلكه بر خود شما خوش مباد! اين [عذاب‌] را شما خود براى ما از پيش فراهم آورديد، و چه بد قرارگاهى است.»\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmmxxxi{مى‌گويند: «پروردگارا، هر كس اين [عذاب‌] را از پيش براى ما فراهم آورده، عذاب او را در آتش دو چندان كن.»\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmmxxxii{و مى‌گويند: «ما را چه شده است كه مردانى را كه ما آنان را از [زمره‌] اشرار مى‌شمرديم نمى‌بينيم؟\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmmxxxiii{آيا آنان را [در دنيا] به ريشخند مى‌گرفتيم يا چشمها[ى ما] بر آنها نمى‌افتد؟»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmmxxxiv{اين مجادله اهل آتش قطعاً راست است.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmmxxxv{بگو: «من فقط هشداردهنده‌اى هستم، و جز خداى يگانه قهار معبودى ديگر نيست.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmmxxxvi{پروردگار آسمانها و زمين و آنچه ميان آن دو است، همان شكست‌ناپذير آمرزنده.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmmxxxvii{بگو: «اين خبرى بزرگ است،\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmmxxxviii{[كه‌] شما از آن روى برمى‌تابيد.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmmxxxix{مرا در باره ملاء اعلى هيچ دانشى نبود آنگاه كه مجادله مى‌كردند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmmxl{به من هيچ [چيز] وحى نمى‌شود، جز اينكه من هشداردهنده‌اى آشكارم.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmmxli{آنگاه كه پروردگارت به فرشتگان گفت: «من بشرى را از گِل خواهم آفريد.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmmxlii{پس چون او را [كاملاً] درست كردم و از روح خويش در آن دميدم، سجده‌كنان براى او [به خاك‌] بيفتيد.»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmmxliii{پس همه فرشتگان يكسره سجده كردند.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmmxliv{مگر ابليس [كه‌] تكبر نمود و از كافران شد.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmmxlv{فرمود: «اى ابليس، چه چيز تو را مانع شد كه براى چيزى كه به دستان قدرت خويش خلق كردم سجده آورى؟ آيا تكبر نمودى يا از [جمله‌] برترى‌جويانى؟»\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmmxlvi{گفت: «من از او بهترم؛ مرا از آتش آفريده‌اى و او را از گِل آفريده‌اى.»\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmmxlvii{فرمود: «پس، از آن [مقام‌] بيرون شو، كه تو رانده‌اى.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmmxlviii{و تا روز جزا لعنت من بر تو باد.»\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmmxlix{گفت: «پروردگارا، پس مرا تا روزى كه برانگيخته مى‌شوند مهلت ده.»\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmml{فرمود: «در حقيقت، تو از مهلت‌يافتگانى،\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmmli{تا روز معين معلوم.»\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmmlii{[شيطان‌] گفت: «پس به عزّت تو سوگند كه همگى را جداً از راه به در مى‌برم،\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmmliii{مگر آن بندگان پاكدل تو را.»\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmmliv{فرمود: «حق [از من‌] است و حق را مى‌گويم:\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmmmlv{هرآينه جهنّم را از تو و از هر كس از آنان كه تو را پيروى كند، از همگى‌شان، خواهم انباشت.»\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmmmlvi{بگو: «مزدى بر اين [رسالت‌] از شما طلب نمى‌كنم و من از كسانى نيستم كه چيزى از خود بسازم و به خدا نسبت دهم.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmmmlvii{اين [قرآن‌] جز پندى براى جهانيان نيست.\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmmmlviii{و قطعاً پس از چندى خبر آن را خواهيد دانست.»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmmmlix{\basmalahfa نازل شدن [اين كتاب‌] از جانب خداى شكست‌ناپذير سنجيده‌كار است.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmlx{ما [اين‌] كتاب را به حق به سوى تو فرود آورديم، پس خدا را -در حالى كه اعتقاد [خود] را براى او خالص‌كننده‌اى- عبادت كن.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmlxi{آگاه باشيد: آيين پاك از آنِ خداست، و كسانى كه به جاى او دوستانى براى خود گرفته‌اند [به اين بهانه كه:] ما آنها را جز براى اينكه ما را هر چه بيشتر به خدا نزديك گردانند، نمى‌پرستيم، البته خدا ميان آنان در باره آنچه كه بر سر آن اختلاف دارند، داورى خواهد كرد. در حقيقت، خدا آن كسى را كه دروغ‌پرداز ناسپاس است هدايت نمى‌كند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmlxii{اگر خدا مى‌خواست براى خود فرزندى بگيرد، قطعاً از [ميان‌] آنچه خلق مى‌كند، آنچه را مى‌خواست برمى‌گزيد. منزّه است او، اوست خداى يگانه قهار.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmlxiii{آسمانها و زمين را به حق آفريد. شب را به روز درمى‌پيچد، و روز را به شب درمى‌پيچد و آفتاب و ماه را تسخير كرد. هر كدام تا مدتى معين روانند. آگاه باش كه او همان شكست‌ناپذير آمرزنده است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmlxiv{شما را از نفسى واحد آفريد، سپس جفتش را از آن قرار داد، و براى شما از دامها هشت قسم پديد آورد. شما را در شكمهاى مادرانتان آفرينشى پس از آفرينشى [ديگر] در تاريكيهاى سه گانه: [مَشيمه و رحم و شكم‌] خلق كرد. اين است خدا، پروردگار شما، فرمانروايى [و حكومت مطلق‌] از آنِ اوست. خدايى جز او نيست، پس چگونه [و كجا از حق‌] برگردانيده مى‌شويد؟\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmlxv{اگر كفر ورزيد، خدا از شما سخت بى‌نياز است و براى بندگانش كفران را خوش نمى‌دارد، و اگر سپاس داريد آن را براى شما مى‌پسندد، و هيچ بردارنده‌اى بار [گناه‌] ديگرى را برنمى‌دارد، آنگاه بازگشت شما به سوى پروردگارتان است، و شما را به آنچه مى‌كرديد خبر خواهد داد، كه او به راز دلها داناست.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmlxvi{و چون به انسان آسيبى رسد، پروردگارش را -در حالى كه به سوى او بازگشت‌كننده است- مى‌خواند؛ سپس چون او را از جانب خود نعمتى عطا كند، آن [مصيبتى‌] را كه در رفع آن پيشتر به درگاه او دعا مى‌كرد، فراموش مى‌نمايد و براى خدا همتايانى قرار مى‌دهد تا [خود و ديگران را] از راه او گمراه گرداند. بگو: «به كفرت اندكى برخوردار شو كه تو از اهل آتشى.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmlxvii{[آيا چنين كسى بهتر است‌] يا آن كسى كه او در طول شب در سجده و قيام اطاعت [خدا] مى‌كند [و] از آخرت مى‌ترسد و رحمت پروردگارش را اميد دارد؟ بگو: «آيا كسانى كه مى‌دانند و كسانى كه نمى‌دانند يكسانند؟» تنها خردمندانند كه پندپذيرند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmlxviii{بگو: «اى بندگان من كه ايمان آورده‌ايد، از پروردگارتان پروا بداريد. براى كسانى كه در اين دنيا خوبى كرده‌اند، نيكى خواهد بود، و زمين خدا فراخ است. بى‌ترديد، شكيبايان پاداش خود را بى‌حساب [و] به تمام خواهند يافت.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmlxix{بگو: «من مأمورم كه خدا را -در حالى كه آيينم را براى او خالص گردانيده‌ام- بپرستم،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmlxx{و مأمورم كه نخستين مسلمانان باشم.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmlxxi{بگو: «من اگر به پروردگارم عصيان ورزم، از عذاب روزى هولناك مى‌ترسم.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmlxxii{بگو: «خدا را مى‌پرستم در حالى كه دينم را براى او بى‌آلايش مى‌گردانم.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmlxxiii{پس هر چه را غير از او مى‌خواهيد، بپرستيد «[ولى به آنان‌] بگو:» زيانكاران در حقيقت كسانى‌اند كه به خود و كسانشان در روز قيامت زيان رسانده‌اند؛ آرى، اين همان خسران آشكار است.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmlxxiv{آنها از بالاى سرشان چترهايى از آتش خواهند داشت و از زير پايشان [نيز] طبق‌هايى [آتشين است‌]، اين [كيفرى‌] است كه خدا بندگانش را به آن بيم مى‌دهد. اى بندگان من، از من بترسيد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmlxxv{و[لى‌] آنان كه خود را از طاغوت به دور مى‌دارند تا مبادا او را بپرستند و به سوى خدا بازگشته‌اند آنان را مژده باد، پس بشارت ده به آن بندگان من كه:\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmlxxvi{به سخن گوش فرامى‌دهند و بهترين آن را پيروى مى‌كنند؛ اينانند كه خدايشان راه نموده و اينانند همان خردمندان.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmlxxvii{پس آيا كسى كه فرمان عذاب بر او واجب آمده [كجا روى رهايى دارد]؟ آيا تو كسى را كه در آتش است مى‌رهانى؟\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmlxxviii{ليكن كسانى كه از پروردگارشان پروا داشتند، براى ايشان غرفه‌هايى است كه بالاى آنها غرفه‌هايى [ديگر] بنا شده است؛ نهرها از زير آن روان است. وعده خداست؛ خدا خلاف وعده نمى‌كند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmlxxix{مگر نديده‌اى كه خدا از آسمان، آبى فرود آورد پس آن را به چشمه‌هايى كه در [طبقات زيرين‌] زمين است راه داد، آنگاه به وسيله آن كشتزارى را كه رنگهاى آن گوناگون است بيرون مى‌آورد، سپس خشك مى‌گردد، آنگاه آن را زرد مى‌بينى، سپس خاشاكش مى‌گرداند. قطعاً در اين [دگرگونيها] براى صاحبان خرد عبرتى است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmlxxx{پس آيا كسى كه خدا سينه‌اش را براى [پذيرش‌] اسلام گشاده، و [در نتيجه‌] برخوردار از نورى از جانب پروردگارش مى‌باشد [همانند فرد تاريكدل است‌]؟ پس واى بر آنان كه از سخت‌دلى ياد خدا نمى‌كنند؛ اينانند كه در گمراهى آشكارند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxi{خدا زيباترين سخن را [به صورت‌] كتابى متشابه، متضمّن وعد و وعيد، نازل كرده است. آنان كه از پروردگارشان مى‌هراسند، پوست بدنشان از آن به لرزه مى‌افتد، سپس پوستشان و دلشان به ياد خدا نرم مى‌گردد. اين است هدايت خدا، هر كه را بخواهد، به آن راه نمايد، و هر كه را خدا گمراه كند او را راهبرى نيست.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxii{پس آيا آن كس كه [به جاى دستها] با چهره خود، گزند عذاب را روز قيامت دفع مى‌كند [مانند كسى است كه از عذاب ايمن است‌]؟ و به ستمگران گفته مى‌شود: «آنچه را كه دستاوردتان بوده است بچشيد.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxiii{كسانى [هم‌] كه پيش از آنان بودند به تكذيب پرداختند، و از آنجا كه حدس نمى‌زدند عذاب برايشان آمد.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxiv{پس خدا در زندگى دنيا رسوايى را به آنان چشانيد، و اگر مى‌دانستند، قطعاً عذاب آخرت بزرگتر است.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxv{و در اين قرآن از هر گونه مثَلى براى مردم آورديم، باشد كه آنان پندگيرند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxvi{قرآنى عربى، بى‌هيچ كژى؛ باشد كه آنان راه تقوا پويند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxvii{خدا مثَلى زده است: مردى است كه چند خواجه ناسازگار در [مالكيّت‌] او شركت دارند [و هر يك او را به كارى مى‌گمارند] و مردى است كه تنها فرمانبر يك مرد است. آيا اين دو در مثَل يكسانند؟ سپاس خداى را. [نه،] بلكه بيشترشان نمى‌دانند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxviii{قطعاً تو خواهى مُرد، و آنان [نيز] خواهند مُرد؛\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmlxxxix{سپس شما روز قيامت پيش پروردگارتان مجادله خواهيد كرد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmxc{پس كيست ستمگرتر از آن كس كه بر خدا دروغ بست، و [سخن‌] راست را چون به سوى او آمد، دروغ پنداشت؟ آيا جاى كافران در جهنّم نيست؟\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmxci{و آن كس كه راستى آورد و آن را باور نمود؛ آنانند كه خود پرهيزگارانند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmxcii{براى آنان، هر چه بخواهند پيش پروردگارشان خواهد بود. اين است پاداش نيكوكاران.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmxciii{تا خدا، بدترين عملى را كه كرده‌اند، از ايشان بزدايد، و آنان را به بهترين كارى كه مى‌كرده‌اند، پاداش دهد.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmxciv{آيا خدا كفايت‌كننده بنده‌اش نيست؟ و [كافران‌] تو را از آنها كه غير اويند مى‌ترسانند و هر كه را خدا گمراه گرداند برايش راهبرى نيست.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmxcv{و هر كه را خدا هدايت كند گمراه‌كننده‌اى ندارد. مگر خدا نيست كه نيرومند كيفرخواه است؟\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmxcvi{و اگر از آنها بپرسى: «چه كسى آسمانها و زمين را خلق كرده؟» قطعاً خواهند گفت: «خدا.» بگو: «[هان‌] چه تصور مى‌كنيد، اگر خدا بخواهد صدمه‌اى به من برساند؛ آيا آنچه را به جاى خدا مى‌خوانيد، مى‌توانند صدمه او را برطرف كنند؛ يا اگر او رحمتى براى من اراده كند آيا آنها مى‌توانند رحمتش را بازدارند؟» بگو: «خدا مرا بس است. اهل توكّل تنها بر او توكّل مى‌كنند.»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmxcvii{بگو: «اى قوم من، شما بر حسب امكانات خود عمل كنيد، من [نيز] عمل مى‌كنم، پس به زودى خواهيد دانست:\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmxcviii{[كه‌] چه كس را عذابى كه رسوايش كند خواهد آمد و عذابى پايدار بر او نازل مى‌شود.»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmxcix{ما اين كتاب را براى [رهبرى‌] مردم به حق بر تو فروفرستاديم. پس هر كس هدايت شود، به سود خود اوست، و هر كس بيراهه رود، تنها به زيان خودش گمراه مى‌شود، و تو بر آنها وكيل نيستى.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmc{خدا روح مردم را هنگام مرگشان به تمامى باز مى‌ستاند، و [نيز] روحى را كه در [موقع‌] خوابش نمرده است [قبض مى‌كند]؛ پس آن [نفسى‌] را كه مرگ را بر او واجب كرده نگاه مى‌دارد، و آن ديگر [نفسها] را تا هنگامى معيّن [به سوى زندگى دنيا] بازپس مى‌فرستد. قطعاً در اين [امر] براى مردمى كه مى‌انديشند نشانه‌هايى [از قدرت خدا]ست.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmci{آيا غير از خدا شفاعتگرانى براى خود گرفته‌اند؟ بگو: «آيا هر چند اختيار چيزى را نداشته باشند و نينديشند؟»\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmcii{بگو: «شفاعت، يكسره از آن خداست. فرمانروايى آسمانها و زمين خاص اوست؛ سپس به سوى او باز گردانيده مى‌شويد.»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmciii{و چون خدا به تنهايى ياد شود، دلهاى كسانى كه به آخرت ايمان ندارند، منزجر مى‌گردد، و چون كسانى غير از او ياد شوند، بناگاه آنان شادمانى مى‌كنند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmciv{بگو: «بار الها، اى پديدآورنده آسمانها و زمين، [اى‌] داناى نهان و آشكار، تو خود در ميان بندگانت بر سر آنچه اختلاف مى‌كردند، داورى مى‌كنى.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmcv{و اگر آنچه در زمين است، يكسره براى كسانى كه ظلم كرده‌اند باشد و نظيرش [نيز] با آن باشد، قطعاً [همه‌] آن را براى رهايى خودشان از سختى عذاب روز قيامت خواهند داد، و آنچه تصوّر[ش را ]نمى‌كردند، از جانب خدا بر ايشان آشكار مى‌گردد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmcvi{و [نتيجه‌] گناهانى كه مرتكب شده‌اند، برايشان ظاهر مى‌شود، و آنچه را كه بدان ريشخند مى‌كردند، آنها را فرا مى‌گيرد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmcvii{و چون انسان را آسيبى رسد، ما را فرا مى‌خواند؛ سپس چون نعمتى از جانب خود به او عطا كنيم مى‌گويد: «تنها آن را به دانش خود يافته‌ام». نه چنان است، بلكه آن آزمايشى است، ولى بيشترشان نمى‌دانند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmcviii{قطعاً كسانى كه پيش از آنان بودند [نيز] اين [سخن‌] را گفتند و آنچه به دست آورده بودند، كارى برايشان نكرد.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmcix{تا [آنكه‌] كيفر آنچه مرتكب شده بودند، بديشان رسيد و كسانى از اين [گروه‌] كه ستم كرده‌اند، به زودى نتايج سوء آنچه مرتكب شده‌اند، بديشان خواهد رسيد و آنان درمانده‌كننده [ما] نيستند.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmcx{آيا ندانسته‌اند كه خداست كه روزى را براى هر كس كه بخواهد، گشاده يا تنگ مى‌گرداند؟ قطعاً در اين [اندازه‌گيرى‌] براى مردمى كه ايمان دارند نشانه‌هايى [از حكمت‌] است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmcxi{بگو: «اى بندگان من -كه بر خويشتن زياده‌روى روا داشته‌ايد- از رحمت خدا نوميد مشويد. در حقيقت، خدا همه گناهان را مى‌آمرزد، كه او خود آمرزنده مهربان است.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmcxii{و پيش از آنكه شما را عذاب در رسد، و ديگر يارى نشويد، به سوى پروردگارتان بازگرديد، و تسليم او شويد.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmcxiii{و پيش از آنكه به طور ناگهانى و در حالى كه حدس نمى‌زنيد شما را عذاب دررسد، نيكوترين چيزى را كه از جانب پروردگارتان به سوى شما نازل آمده است پيروى كنيد.»\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmcxiv{تا آنكه [مبادا] كسى بگويد: «دريغا بر آنچه در حضور خدا كوتاهى ورزيدم؛ بى‌ترديد من از ريشخندكنندگان بودم.»\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmcxv{يا بگويد: «اگر خدايم هدايت مى‌كرد، مسلماً از پرهيزگاران بودم.»\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmcxvi{يا چون عذاب را ببيند، بگويد: «كاش مرا برگشتى بود تا از نيكوكاران مى‌شدم.»\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmcxvii{[به او گويند:] آرى، نشانه‌هاى من بر تو آمد و آنها را تكذيب كردى و تكبّر ورزيدى و از [جمله‌] كافران شدى.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmcxviii{و روز قيامت كسانى را كه بر خدا دروغ بسته‌اند رو سياه مى‌بينى، آيا جاى سركشان در جهنم نيست؟\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmmcxix{و خدا كسانى را كه تقوا پيشه كرده‌اند، به [پاس‌] كارهايى كه مايه رستگارى‌شان بوده، نجات مى‌دهد. عذاب به آنان نمى‌رسد و غمگين نخواهند گرديد.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmmcxx{خدا آفريدگار هر چيزى است، و اوست كه بر هر چيز نگهبان است.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmmcxxi{كليدهاى آسمان و زمين از آن اوست، و كسانى كه نشانه‌هاى خدا را انكار كردند، آنانند كه زيانكارانند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmmcxxii{بگو: «اى نادانان، آيا مرا وادار مى‌كنيد كه جز خدا را بپرستم؟»\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmmcxxiii{و قطعاً به تو و به كسانى كه پيش از تو بودند وحى شده است: «اگر شرك ورزى حتماً كردارت تباه و مسلماً از زيانكاران خواهى شد.»\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmmcxxiv{بلكه خدا را بپرست و از سپاسگزاران باش.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmmcxxv{و خدا را آنچنان كه بايد به بزرگى نشناخته‌اند، و حال آنكه روز قيامت زمين يكسره در قبضه [قدرت‌] اوست، و آسمانها در پيچيده به دست اوست؛ او منزّه است و برتر است از آنچه [با وى‌] شريك مى‌گردانند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmmcxxvi{و در صور دميده مى‌شود، پس هر كه در آسمانها و هر كه در زمين است بيهوش درمى‌افتد، مگر كسى كه خدا بخواهد؛ سپس بار ديگر در آن دميده مى‌شود و بناگاه آنان بر پاى ايستاده مى‌نگرند.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmmcxxvii{و زمين به نور پروردگارش روشن گردد، و كارنامه [اعمال در ميان‌] نهاده شود، و پيامبران و شاهدان را بياورند، و ميانشان به حق داورى گردد، و مورد ستم قرار نگيرند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmmcxxviii{و هر كسى [نتيجه‌] آنچه انجام داده است به تمام بيابد و او به آنچه مى‌كنند داناتر است.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmmcxxix{و كسانى كه كافر شده‌اند، گروه گروه به سوى جهنّم رانده شوند، تا چون بدان رسند، درهاى آن [به رويشان‌] گشوده گردد و نگهبانانش به آنان گويند: «مگر فرستادگانى از خودتان بر شما نيامدند كه آيات پروردگارتان را بر شما بخوانند و به ديدار چنين روزى شما را هشدار دهند؟» گويند: «چرا»، ولى فرمان عذاب بر كافران واجب آمد.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmmcxxx{و گفته شود: «از درهاى دوزخ درآييد، جاودانه در آن بمانيد؛ وه چه بد [جايى‌] است جاى سركشان!»\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxi{و كسانى كه از پروردگارشان پروا داشته‌اند، گروه گروه به سوى بهشت سوق داده شوند، تا چون بدان رسند و درهاى آن [به رويشان‌] گشوده گردد و نگهبانان آن به ايشان گويند: «سلام بر شما، خوش آمديد، در آن درآييد [و] جاودانه [بمانيد].»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxii{و گويند: «سپاس خدايى را كه وعده‌اش را بر ما راست گردانيد و سرزمين [بهشت‌] را به ما ميراث داد، از هر جاى آن باغ [پهناور] كه بخواهيم جاى مى‌گزينيم.» چه نيك است پاداش عمل‌كنندگان.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxiii{و فرشتگان را مى‌بينى كه پيرامون عرش به ستايش پروردگار خود تسبيح مى‌گويند و ميانشان به حق داورى مى‌گردد و گفته مى‌شود: «سپاس، ويژه پروردگار جهانيان است.»\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxiv{\basmalahfa حاء، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxv{فرو فرستادن اين كتاب، از جانب خداى ارجمند داناست،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxvi{[كه‌] گناه‌بخش و توبه‌پذير [و] سخت‌كيفر [و] فراخ‌نعمت است. خدايى جز او نيست. بازگشت به سوى اوست.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxvii{جز آنهايى كه كفر ورزيدند [كسى‌] در آيات خدا ستيزه نمى‌كند، پس رفت و آمدشان در شهرها تو را دستخوش فريب نگرداند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxviii{پيش از اينان قوم نوح، و بعد از آنان دسته‌هاى مخالف [ديگر] به تكذيب پرداختند، و هر امّتى آهنگ فرستاده خود را كردند تا او را بگيرند، و به [وسيله‌] باطل جدال نمودند تا حقيقت را با آن پايمال كنند. پس آنان را فرو گرفتم؛ آيا چگونه بود كيفر من؟\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmcxxxix{و بدين سان فرمان پروردگارت در باره كسانى كه كفر ورزيده بودند، به حقيقت پيوست كه ايشان همدمان آتش خواهند بود.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmcxl{كسانى كه عرش [خدا] را حمل مى‌كنند، و آنها كه پيرامون آنند، به سپاس پروردگارشان تسبيح مى‌گويند و به او ايمان دارند و براى كسانى كه گرويده‌اند طلب آمرزش مى‌كنند: «پروردگارا، رحمت و دانش [تو بر] هر چيز احاطه دارد؛ كسانى را كه توبه كرده و راه تو را دنبال كرده‌اند ببخش و آنها را از عذاب آتش نگاه دار.»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmcxli{«پروردگارا، آنان را در باغهاى جاويد كه وعده‌شان داده‌اى، با هر كه از پدران و همسران و فرزندانشان كه به صلاح آمده‌اند، داخل كن، زيرا تو خود ارجمند و حكيمى.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmcxlii{و آنان را از بديها نگاه دار، و هر كه را در آن روز از بديها حفظ كنى، البته رحمتش كرده‌اى؛ و اين همان كاميابى بزرگ است.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmcxliii{كسانى كه كافر بوده‌اند مورد ندا قرار مى‌گيرند كه: «قطعاً دشمنى خدا از دشمنى شما نسبت به همديگر سخت‌تر است، آنگاه كه به سوى ايمان فرا خوانده مى‌شديد و انكار مى‌ورزيديد.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmcxliv{مى‌گويند: «پروردگارا، دو بار ما را به مرگ رسانيدى و دو بار ما را زنده گردانيدى. به گناهانمان اعتراف كرديم؛ پس آيا راه بيرون‌شدنى [از آتش‌] هست؟»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmcxlv{اين [كيفر] از آن روى براى شماست كه چون خدا به تنهايى خوانده مى‌شد، كفر مى‌ورزيديد؛ و چون به او شرك آورده مى‌شد، آن را باور مى‌كرديد. پس [امروز] فرمان از آن خداىِ والاىِ بزرگ است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmcxlvi{اوست آن كس كه نشانه‌هاى خود را به شما مى‌نماياند و براى شما از آسمان روزى مى‌فرستد، و جز آن كس كه توبه‌كار است [كسى‌] پند نمى‌گيرد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmcxlvii{پس خدا را پاكدلانه فرا خوانيد، هر چند ناباوران را ناخوش افتد!\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmcxlviii{بالابرنده درجات، خداوند عرش، به هر كس از بندگانش كه خواهد آن روح [=فرشته‌] را، به فرمان خويش مى‌فرستد، تا [مردم را] از روز ملاقات [با خدا] بترساند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmcxlix{آن روز كه آنان ظاهر گردند، چيزى از آنها بر خدا پوشيده نمى‌ماند. امروز فرمانروايى از آنِ كيست؟ از آنِ خداوند يكتاى قهّار است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmcl{امروز هر كسى به [موجب‌] آنچه انجام داده است كيفر مى‌يابد. امروز ستمى نيست؛ آرى، خدا زودشمار است.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmcli{و آنها را از آن روز قريب‌[الوقوع‌] بترسان، آنگاه كه جانها به گلوگاه مى‌رسد در حالى كه اندوه خود را فرو مى‌خورند. براى ستمگران نه يارى است و نه شفاعتگرى كه مورد اطاعت باشد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmclii{[خدا] نگاههاى دزدانه و آنچه را كه دلها نهان مى‌دارند، مى‌داند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmcliii{و خداست كه به حق داورى مى‌كند، و كسانى را كه در برابر او مى‌خوانند [عاجزند و] به چيزى داورى نمى‌كنند؛ در حقيقت، خداست كه خود شنواى بيناست.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmcliv{آيا در زمين نگرديده‌اند تا ببينند فرجام كسانى كه پيش از آنها [زيسته‌]اند چگونه بوده است؟ آنها از ايشان نيرومندتر [بوده‌] و آثار [پايدارترى‌] در روى زمين [از خود باقى گذاشتند]، با اين همه، خدا آنان را به كيفر گناهانشان گرفتار كرد و در برابر خدا حمايتگرى نداشتند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmclv{اين [كيفر] از آن روى بود كه پيامبرانشان دلايل آشكار برايشان مى‌آوردند ولى [آنها] انكار مى‌كردند. پس خدا [گريبان‌] آنها را گرفت، زيرا او نيرومند سخت‌كيفر است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmclvi{و به يقين، موسى را با آيات خود و حجّتى آشكار فرستاديم،\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmclvii{به سوى فرعون و هامان و قارون، [امّا آنان‌] گفتند: «افسونگرى شيّاد است.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmclviii{پس وقتى حقيقت را از جانب ما براى آنان آورد، گفتند: «پسران كسانى را كه با او ايمان آورده‌اند بكشيد و زنانشان را زنده بگذاريد.» و[لى‌] نيرنگ كافران جز در گمراهى نيست.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmclix{و فرعون گفت: «مرا بگذاريد موسى را بكشم تا پروردگارش را بخواند. من مى‌ترسم آيين شما را تغيير دهد يا در اين سرزمين فساد كند.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmclx{و موسى گفت: «من از هر متكبرى كه به روز حساب عقيده ندارد، به پروردگار خود و پروردگار شما پناه برده‌ام.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmclxi{و مردى مؤمن از خاندان فرعون كه ايمان خود را نهان مى‌داشت، گفت: «آيا مردى را مى‌كشيد كه مى‌گويد: پروردگار من خداست؟ و مسلماً براى شما از جانب پروردگارتان دلايل آشكارى آورده، و اگر دروغگو باشد دروغش به زيان اوست، و اگر راستگو باشد برخى از آنچه به شما وعده مى‌دهد به شما خواهد رسيد، چرا كه خدا كسى را كه افراطكار دروغزن باشد هدايت نمى‌كند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmclxii{اى قوم من، امروز فرمانروايى از آنِ شماست [و] در اين سرزمين مسلطيد، و[لى‌] چه كسى ما را از بلاى خدا -اگر به ما برسد- حمايت خواهد كرد؟» فرعون گفت: «جز آنچه مى‌بينم، به شما نمى‌نمايم، و شما را جز به راه راست راهبر نيستم.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmclxiii{و كسى كه ايمان آورده بود، گفت: «اى قوم من، من از [روزى‌] مثل روز دسته‌ها[ى مخالف خدا] بر شما مى‌ترسم.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmclxiv{[از سرنوشتى‌] نظير سرنوشت قوم نوح و عاد و ثمود، و كسانى كه پس از آنها [آمدند]. و [گرنه‌] خدا بر بندگان [خود] ستم نمى‌خواهد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmclxv{و اى قوم من، من بر شما از روزى كه مردم يكديگر را [به يارى هم‌] ندا درمى‌دهند، بيم دارم.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmclxvi{روزى كه پشت‌كنان [به عنف‌] بازمى‌گرديد، براى شما در برابر خدا هيچ حمايتگرى نيست؛ و هر كه را خدا گمراه كند او را راهبرى نيست.»\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmclxvii{و به يقين، يوسف پيش از اين، دلايل آشكار براى شما آورد، و از آنچه براى شما آورد همواره در ترديد بوديد تا وقتى كه از دنيا رفت، گفتيد: «خدا بعد از او هرگز فرستاده‌اى را برنخواهد انگيخت.» اين گونه، خدا هر كه را افراطگر شكّاك است، بى راه مى‌گذارد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmclxviii{كسانى كه در باره آيات خدا -بدون حجتى كه براى آنان آمده باشد- مجادله مى‌كنند، [اين ستيزه‌] در نزد خدا و نزد كسانى كه ايمان آورده‌اند [مايه‌] عداوت بزرگى است. اين گونه، خدا بر دل هر متكبر و زورگويى مُهر مى‌نهد.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmclxix{و فرعون گفت: «اى هامان، براى من كوشكى بلند بساز، شايد من به آن راهها برسم:\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmclxx{راههاى [دستيابى به‌] آسمانها، تا از خداى موسى اطلاع حاصل كنم و من او را سخت دروغپرداز مى‌پندارم.» و اين گونه براى فرعون، زشتى كارش آراسته شد و از راه [راست‌] بازماند؛ و نيرنگ فرعون جز به تباهى نينجاميد.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmclxxi{و آن كس كه ايمان آورده بود گفت: «اى قوم من، مرا پيروى كنيد تا شما را به راه درست هدايت كنم.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmclxxii{اى قوم من، اين زندگى دنيا تنها كالايى [ناچيز] است، و در حقيقت، آن آخرت است كه سراى پايدار است.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmclxxiii{هر كه بدى كند، جز به مانند آن كيفر نمى‌يابد؛ و هر كه كار شايسته كند -چه مرد باشد يا زن- در حالى كه ايمان داشته باشد، در نتيجه آنان داخل بهشت مى‌شوند و در آنجا بى‌حساب روزى مى‌يابند.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmclxxiv{و اى قوم من، چه شده است كه من شما را به نجات فرا مى‌خوانم و [شما] مرا به آتش فرا مى‌خوانيد؟\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmclxxv{مرا فرا مى‌خوانيد تا به خدا كافر شوم و چيزى را كه بدان علمى ندارم با او شريك گردانم؛ و من شما را به سوى آن ارجمند آمرزنده دعوت مى‌كنم.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmclxxvi{آنچه مرا به سوى آن دعوت مى‌كنيد، به ناچار نه در دنيا و نه در آخرت [درخور] خواندن نيست، و در حقيقت، برگشت ما به سوى خداست، و افراطگران همدمان آتشند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmclxxvii{پس به زودى آنچه را به شما مى‌گويم به ياد خواهيد آورد. و كارم را به خدا مى‌سپارم؛ خداست كه به [حال‌] بندگان [خود] بيناست.»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmclxxviii{پس خدا او را از عواقب سوء آنچه نيرنگ مى‌كردند حمايت فرمود، و فرعونيان را عذاب سخت فرو گرفت.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmclxxix{[اينك هر] صبح و شام بر آتش عرضه مى‌شوند، و روزى كه رستاخيز بر پا شود [فرياد مى‌رسد كه:] «فرعونيان را در سخت‌ترين [انواع‌] عذاب درآوريد.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmclxxx{و آنگاه كه در آتش شروع به آوردن حجّت مى‌كنند، زيردستان به كسانى كه گردنكش بودند، مى‌گويند: «ما پيرو شما بوديم؛ پس آيا مى‌توانيد پاره‌اى از اين آتش را از ما دفع كنيد؟»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxi{كسانى كه گردنكشى مى‌كردند، مى‌گويند: «[اكنون‌] همه ما در آن هستيم. خداست كه ميان بندگان [خود] داورى كرده است.»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxii{و كسانى كه در آتشند، به نگهبانان جهنّم مى‌گويند: «پروردگارتان را بخوانيد تا يك روز از اين عذاب را به ما تخفيف دهد.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxiii{مى‌گويند: «مگر پيامبرانتان دلايل روشن به سوى شما نياوردند؟» مى‌گويند: «چرا.» مى‌گويند: «پس بخوانيد. و[لى‌] دعاى كافران جز در بيراهه نيست.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxiv{در حقيقت، ما فرستادگان خود و كسانى را كه گرويده‌اند، در زندگى دنيا و روزى كه گواهان برپاى مى‌ايستند قطعاً يارى مى‌كنيم؛\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxv{[همان‌] روزى كه ستمگران را پوزش‌طلبى‌شان سود نمى‌دهد، و براى آنان لعنت است، و برايشان بدفرجامى آن سراى است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxvi{و قطعاً موسى را هدايت داديم، و به فرزندان اسرائيل تورات را به ميراث نهاديم؛\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxvii{[كه‌] رهنمود و يادكردى براى خردمندان است.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxviii{پس صبر كن كه وعده خدا حق است و براى گناهت آمرزش بخواه و به سپاس پروردگارت، شامگاهان و بامدادان ستايشگر باش.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmclxxxix{در حقيقت، آنان كه در باره نشانه‌هاى خدا -بى‌آنكه حجّتى برايشان آمده باشد- به مجادله برمى‌خيزند در دلهايشان جز بزرگنمايى نيست [و] آنان به آن [بزرگى كه آرزويش را دارند] نخواهند رسيد. پس به خدا پناه جوى، زيرا او خود شنواى بيناست.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmcxc{قطعاً آفرينش آسمانها و زمين بزرگتر [و شكوهمندتر] از آفرينش مردم است، ولى بيشتر مردم نمى‌دانند.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmcxci{و نابينا و بينا يكسان نيستند، و كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند [نيز] با [مردم‌] بدكار [يكسان‌] نيستند؛ چه اندك پند مى‌پذيريد.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmcxcii{در حقيقت، رستاخيز قطعاً آمدنى است؛ در آن ترديدى نيست، ولى بيشتر مردم ايمان نمى‌آورند.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmcxciii{و پروردگارتان فرمود: «مرا بخوانيد تا شما را اجابت كنم. در حقيقت، كسانى كه از پرستش من كبر مى‌ورزند به زودى خوار در دوزخ درمى‌آيند.»\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmmcxciv{خدا [همان‌] كسى است كه شب را براى شما پديد آورد تا در آن آرام گيريد، و روز را روشنى‌بخش [قرار داد]. آرى، خدا بر مردم بسيار صاحب‌تفضل است، ولى بيشتر مردم سپاس نمى‌دارند.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmmcxcv{اين است خدا، پروردگار شما [كه‌] آفريننده هر چيزى است: خدايى جز او نيست. پس چگونه [از او] بازگردانيده مى‌شويد؟\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmmcxcvi{كسانى كه نشانه‌هاى خدا را انكار مى‌كردند، اين گونه [از خدا] رويگردان مى‌شوند.\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmmcxcvii{خدا [همان‌] كسى است كه زمين را براى شما قرارگاه ساخت و آسمان را بنايى [گردانيد] و شما را صورتگرى كرد و صورتهاى شما را نيكو نمود و از چيزهاى پاكيزه به شما روزى داد. اين است خدا پروردگار شما! بلندمرتبه و بزرگ است خدا، پروردگار جهانيان.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmmcxcviii{اوست [همان‌] زنده‌اى كه خدايى جز او نيست. پس او را در حالى كه دين [خود] را براى وى بى‌آلايش گردانيده‌ايد بخوانيد. سپاس‌[ها همه‌] ويژه خدا پروردگار جهانيان است.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmmcxcix{بگو: «من نهى شده‌ام از اينكه جز خدا كسانى را كه [شما] مى‌خوانيد پرستش كنم [آن هم‌] هنگامى كه از جانب پروردگارم مرا دلايل روشن رسيده باشد، و مأمورم كه فرمانبر پروردگار جهانيان باشم.»\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmmcc{او همان كسى است كه شما را از خاكى آفريد، سپس از نطفه‌اى، آنگاه از علقه‌اى، و بعد شما را [به صورت‌] كودكى برمى‌آورد، تا به كمال قوّت خود برسيد و تا سالمند شويد، و از ميان شما كسى است كه مرگ پيش‌رس مى‌يابد، و تا [بالاخره‌] به مدتى كه مقرّر است برسيد، و اميد كه در انديشه فرو رويد.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmmcci{او همان كسى است كه زنده مى‌كند و مى‌ميراند، و چون به كارى حكم كند، همين قدر به آن مى‌گويد: «باش.» بى‌درنگ موجود مى‌شود.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmmccii{آيا كسانى را كه در [ابطال‌] آيات خدا مجادله مى‌كنند نديده‌اى [كه‌] تا كجا [از حقيقت‌] انحراف حاصل كرده‌اند؟\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmmcciii{كسانى كه كتاب [خدا] و آنچه را كه فرستادگان خود را بدان گسيل داشته‌ايم تكذيب كرده‌اند، به زودى خواهند دانست؛\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmmcciv{هنگامى كه غلها در گردنهايشان [افتاده‌] و [با] زنجيرها كشانيده مى‌شوند،\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmmccv{در ميان جوشاب. [و] آنگاه در آتش برافروخته مى‌شوند.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmmccvi{آنگاه به آنان گفته مى‌شود: «آنچه را در برابر خدا [با او] شريك مى‌ساختيد كجايند؟»\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmmccvii{مى‌گويند: «گمشان كرديم، بلكه پيشتر [هم‌] ما چيزى را نمى‌خوانديم.» اين گونه خدا كافران را بى‌راه مى‌گذارد.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmmccviii{اين [عقوبت‌] به سبب آن است كه در زمين به ناروا شادى و سرمستى مى‌كرديد و بدان سبب است كه [سخت به خود] مى‌نازيديد.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmmccix{از درهاى دوزخ درآييد، در آن جاودان [بمانيد]. چه بد است جاى سركشان.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmmccx{پس صبر كن كه وعده خدا راست است. پس -چه پاره‌اى از آنچه را كه به آنان وعده داده‌ايم، به تو بنمايانيم، چه تو را از دنيا ببريم- [در هر صورت آنان‌] به سوى ما بازگردانيده مى‌شوند.\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmmccxi{و مسلّماً پيش از تو فرستادگانى را روانه كرديم. برخى از آنان را [ماجرايشان را] بر تو حكايت كرده‌ايم و برخى از ايشان را بر تو حكايت نكرده‌ايم، و هيچ فرستاده‌اى را نرسد كه بى‌اجازه خدا نشانه‌اى بياورد. پس چون فرمان خدا برسد به حق داورى مى‌شود، و آنجاست كه باطل‌كاران زيان مى‌كنند.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmmccxii{خدا [همان‌] كسى است كه چهارپايان را براى شما پديد آورد تا از برخى از آنها سوارى گيريد و از برخى از آنها بخوريد.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmmccxiii{و در آنها براى شما سودهاست تا با [سوار شدن بر] آنها به مقصودى كه در دلهايتان است برسيد، و بر آنها و بر كشتى حمل مى‌شويد.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmmccxiv{و نشانه‌هاى [قدرت‌] خويش را به شما مى‌نماياند. پس كدام يك از آيات خدا را انكار مى‌كنيد؟\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmmccxv{آيا در زمين نگشته‌اند تا ببينند فرجام كسانى كه پيش از آنان بودند چگونه بوده است؟ [آنها به مراتب از حيث تعداد،] بيشتر از آنان، و [از حيث‌] نيرو و آثار در روى زمين، استوارتر بودند، و[لى‌] آنچه به دست مى‌آوردند، به حالشان سودى نبخشيد.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmmccxvi{و چون پيامبرانشان دلايل آشكار برايشان آوردند، به آن چيز [مختصرى‌] از دانش كه نزدشان بود خرسند شدند، و [سرانجام‌] آنچه به ريشخند مى‌گرفتند آنان را فروگرفت.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmmccxvii{پس چون سختى [عذاب‌] ما را ديدند گفتند: «فقط به خدا ايمان آورديم و بدانچه با او شريك مى‌گردانيديم كافريم.»\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmmmccxviii{و[لى‌] هنگامى كه عذاب ما را مشاهده كردند، ديگر ايمانشان براى آنها سودى نداد. سنّت خداست كه از [ديرباز] در باره بندگانش چنين جارى شده، و آنجاست كه ناباوران زيان كرده‌اند.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmmmccxix{\basmalahfa حاء، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmccxx{وحى [نامه‌]اى است از جانب [خداى‌] رحمتگر مهربان.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmccxxi{كتابى است كه آيات آن، به روشنى بيان شده. قرآنى است به زبان عربى براى مردمى كه مى‌دانند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmccxxii{بشارتگر و هشداردهنده است. و[لى‌] بيشتر آنان رويگردان شدند، در نتيجه [چيزى را] نمى‌شنوند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmccxxiii{و گفتند: «دلهاى ما از آنچه ما را به سوى آن مى‌خوانى سخت محجوب و مهجور است. و در گوشهاى ما سنگينى و ميان ما و تو پرده‌اى است؛ پس تو كار خود را بكن ما [هم‌] كار خود را مى‌كنيم.»\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmccxxiv{بگو: «من، بشرى چون شمايم، جز اينكه به من وحى مى‌شود كه خداى شما خدايى يگانه است. پس مستقيماً به سوى او بشتابيد و از او آمرزش بخواهيد. و واى بر مشركان.»\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmccxxv{همان كسانى كه زكات نمى‌دهند و آنان كه به آخرت ناباورند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmccxxvi{كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند آنان را پاداشى بى‌پايان است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmccxxvii{بگو: «آيا اين شماييد كه واقعاً به آن كسى كه زمين را در دو هنگام آفريد، كفر مى‌ورزيد و براى او همتايانى قرار مى‌دهيد؟ اين است پروردگار جهانيان.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmccxxviii{و در [زمين‌]، از فراز آن [لنگرآسا] كوهها نهاد و در آن خير فراوان پديد آورد، و مواد خوراكى آن را در چهار روز اندازه‌گيرى كرد [كه‌] براى خواهندگان، درست [و متناسب با نيازهايشان‌] است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmccxxix{سپس آهنگ [آفرينش‌] آسمان كرد، و آن بخارى بود. پس به آن و به زمين فرمود: «خواه يا ناخواه بياييد.» آن دو گفتند: «فرمان‌پذير آمديم.»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmccxxx{پس آنها را [به صورت‌] هفت آسمان، در دو هنگام مقرّر داشت و در هر آسمانى كار [مربوط به‌] آن را وحى فرمود، و آسمان [اين‌] دنيا را به چراغها آذين كرديم و [آن را نيك‌] نگاه داشتيم؛ اين است اندازه‌گيرى آن نيرومند دانا.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxi{پس اگر روى برتافتند بگو: «شما را از آذرخشى چون آذرخش عاد و ثمود بر حذر داشتم.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxii{چون فرستادگان [ما] از پيش رو و از پشت سرشان بر آنان آمدند [و گفتند:] «زنهار، جز خدا را مپرستيد»، گفتند: «اگر پروردگار ما مى‌خواست، قطعاً فرشتگانى فرومى‌فرستاد، پس ما به آنچه بدان فرستاده شده‌ايد كافريم.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxiii{و امّا عاديان، به ناحق، در زمين سر برافراشتند و گفتند: «از ما نيرومندتر كيست؟» آيا ندانسته‌اند كه آن خدايى كه خلقشان كرده خود از ايشان نيرومندتر است؟ و در نتيجه آيات ما را انكار مى‌كردند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxiv{پس بر آنان تندبادى توفنده در روزهايى شوم فرستاديم تا در زندگى دنيا عذاب رسوايى را بدانان بچشانيم و قطعاً عذاب آخرت رسواكننده‌تر است و آنان يارى نخواهند شد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxv{و اما ثموديان: پس آنان را راهبرى كرديم و[لى‌] كوردلى را بر هدايت ترجيح دادند، پس به [كيفر] آنچه مرتكب مى‌شدند صاعقه عذاب خفت‌آور آنان را فروگرفت.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxvi{و كسانى را كه ايمان آورده بودند و پروا مى‌داشتند رهانيديم.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxvii{و [ياد كن‌] روزى را كه دشمنان خدا به سوى آتش گردآورده و بازداشت [و دسته دسته تقسيم‌] مى‌شوند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxviii{تا چون بدان رسند، گوششان و ديدگانشان و پوستشان به آنچه مى‌كرده‌اند، بر ضدّشان گواهى دهند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmccxxxix{و به پوست [بدن‌] خود مى‌گويند: «چرا بر ضدّ ما شهادت داديد؟» مى‌گويند: «همان خدايى كه هر چيزى را به زبان درآورده ما را گويا گردانيده است، و او نخستين بار شما را آفريد و به سوى او برگردانيده مى‌شويد.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmccxl{و [شما] از اينكه مبادا گوش و ديدگان و پوستتان بر ضدّ شما گواهى دهند [گناهانتان را] پوشيده نمى‌داشتيد ليكن گمان داشتيد كه خدا بسيارى از آنچه را كه مى‌كنيد نمى‌داند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmccxli{و همين بود گمانتان كه در باره پروردگارتان برديد؛ شما را هلاك كرد و از زيانكاران شديد.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmccxlii{پس اگر شكيبايى نمايند جايشان در آتش است و اگر از در پوزش درآيند مورد اجابت قرار نمى‌گيرند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmccxliii{و براى آنان دمسازانى گذاشتيم، و آنچه در دسترس ايشان و آنچه در پى آنان بود در نظرشان زيبا جلوه دادند و فرمان [عذاب‌] در ميان امّتهايى از جن و انس كه پيش از آنان روزگار به سر برده بودند، بر ايشان واجب آمد، چرا كه آنها زيانكاران بودند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmccxliv{و كسانى كه كافر شدند گفتند: «به اين قرآن گوش مدهيد و سخن لغو در آن اندازيد، شايد شما پيروز شويد.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmccxlv{و قطعاً كسانى را كه كافر شده‌اند عذابى سخت مى‌چشانيم و حتماً آنها را به بدتر از آنچه مى‌كرده‌اند جزا مى‌دهيم.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmccxlvi{آرى، سزاى دشمنان خدا همان آتش است كه در آن، منزل هميشگى دارند. [اين‌] جزا به كيفر آن است كه نشانه‌هاى ما را انكار مى‌كردند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmccxlvii{و كسانى كه كفر ورزيدند گفتند: «پروردگارا، آن دو [گمراه‌گرى‌] از جن و انس كه ما را گمراه كردند به ما نشان ده تا آنها را زير قدمهايمان بگذاريم تا زبون شوند.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmccxlviii{در حقيقت، كسانى كه گفتند: «پروردگار ما خداست»؛ سپس ايستادگى كردند، فرشتگان بر آنان فرود مى‌آيند [و مى‌گويند:] «هان، بيم مداريد و غمين مباشيد، و به بهشتى كه وعده يافته بوديد شاد باشيد.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmccxlix{در زندگى دنيا و در آخرت دوستانتان ماييم، و هر چه دلهايتان بخواهد در [بهشت‌] براى شماست، و هر چه خواستار باشيد در آنجا خواهيد داشت؛\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmccl{روزىِ آماده‌اى از سوى آمرزنده مهربان است.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmccli{و كيست خوشگفتارتر از آن كس كه به سوى خدا دعوت نمايد و كار نيك كند و گويد: «من [در برابر خدا] از تسليم‌شدگانم»؟\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmcclii{و نيكى با بدى يكسان نيست. [بدى را] آنچه خود بهتر است دفع كن؛ آنگاه كسى كه ميان تو و ميان او دشمنى است، گويى دوستى يكدل مى‌گردد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmccliii{و اين [خصلت‌] را جز كسانى كه شكيبا بوده‌اند نمى‌يابند، و آن را جز صاحب بهره‌اى بزرگ، نخواهد يافت.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmccliv{و اگر دمدمه‌اى از شيطان تو را از جاى درآورد، پس به خدا پناه ببر كه او خود شنواى داناست.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmcclv{و از نشانه‌هاى [حضور] او شب و روز و خورشيد و ماه است؛ نه براى خورشيد سجده كنيد و نه براى ماه، و اگر تنها او را مى‌پرستيد آن خدايى را سجده كنيد كه آنها را خلق كرده است.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmcclvi{پس اگر كبر ورزيدند، كسانى كه در پيشگاه پروردگار تواند شبانه‌روز او را نيايش مى‌كنند و خسته نمى‌شوند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmcclvii{و از [ديگر] نشانه‌هاى او اين است كه تو زمين را فسرده مى‌بينى و چون باران بر آن فروريزيم به جنبش درآيد و بردمد. آرى، همان كسى كه آن را زندگى بخشيد قطعاً زنده‌كننده مردگان است. در حقيقت، او بر هر چيزى تواناست.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmcclviii{كسانى كه در [فهم و ارائه‌] آيات ما كژ مى‌روند بر ما پوشيده نيستند. آيا كسى كه در آتش افكنده مى‌شود بهتر است يا كسى كه روز قيامت آسوده‌خاطر مى‌آيد؟ هر چه مى‌خواهيد بكنيد كه او به آنچه انجام مى‌دهيد بيناست.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmcclix{كسانى كه به اين قرآن -چون بديشان رسيد- كفر ورزيدند [به كيفر خود مى‌رسند] و به راستى كه آن كتابى ارجمند است.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmcclx{از پيش روى آن و از پشت سرش باطل به سويش نمى‌آيد؛ وحى [نامه‌]اى است از حكيمى ستوده‌[صفات‌].\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmcclxi{به تو جز آنچه به پيامبران پيش از تو گفته شده است گفته نمى‌شود. به راستى كه پروردگار تو داراى آمرزش و دارنده كيفرى پر درد است.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmcclxii{و اگر [اين كتاب را] قرآنى غير عربى گردانيده بوديم، قطعاً مى‌گفتند: «چرا آيه‌هاى آن روشن بيان نشده؟ كتابى غير عربى و [مخاطب آن‌] عرب زبان؟» بگو: «اين [كتاب‌] براى كسانى كه ايمان آورده‌اند رهنمود و درمانى است، و كسانى كه ايمان نمى‌آورند در گوشهايشان سنگينى است و قرآن برايشان نامفهوم است، و [گويى‌] آنان را از جايى دور ندا مى‌دهند!\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmcclxiii{و به راستى موسى را كتاب [تورات‌] داديم، پس در آن اختلاف واقع شد، و اگر از جانب پروردگارت فرمان [مهلت‌] سبقت نگرفته بود، قطعاً ميانشان داورى شده بود؛ و در حقيقت آنان در باره آن به شكّى سخت دچارند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmcclxiv{هر كه كار شايسته كند، به سود خود اوست؛ و هر كه بدى كند، به زيان خود اوست، و پروردگار تو به بندگان [خود] ستمكار نيست.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmcclxv{دانستن هنگام رستاخيز فقط منحصر به اوست، و ميوه‌ها از غلافهايشان بيرون نمى‌آيند و هيچ مادينه‌اى بار نمى‌گيرد و بار نمى‌گذارد مگر آنكه او به آن علم دارد. و روزى كه [خدا] آنان را ندا مى‌دهد: «شريكان من كجايند؟» مى‌گويند: «با بانگ رسا به تو مى‌گوييم كه هيچ گواهى از ميان ما نيست.»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmcclxvi{و آنچه از پيش مى‌خواندند، از [نظر] آنان ناپديد مى‌شود و مى‌دانند كه آنان را روى گريز نيست.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmcclxvii{انسان از دعاى خير خسته نمى‌شود، و چون آسيبى به او رسد مأيوس [و] نوميد مى‌گردد.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmcclxviii{و اگر از جانب خود رحمتى -پس از زيانى كه به او رسيده است- بچشانيم، قطعاً خواهد گفت: «من سزاوار آنم و گمان ندارم كه رستاخيز برپا شود، و اگر هم به سوى پروردگارم بازگردانيده شوم، قطعاً نزد او برايم خوبى خواهد بود. « پس بدون شكّ، كسانى را كه كفران كرده‌اند، به آنچه انجام داده‌اند آگاه خواهيم كرد، و مسلماً از عذابى سخت به آنان خواهيم چشانيد.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmcclxix{و چون انسان را نعمت بخشيم، روى برتابد و خود را كنار كشد، و چون آسيبى بدو رسد دست به دعاى فراوان بردارد.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmcclxx{بگو: «به من خبر دهيد، اگر [قرآن‌] از نزد خدا [آمده‌] باشد و آن را انكار كرده باشيد، چه كسى گمراه‌تر از آن كس خواهد بود كه به مخالفتى دور و دراز [دچار] آمده باشد؟»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxi{به زودى نشانه‌هاى خود را در افقها[ى گوناگون‌] و در دلهايشان بديشان خواهيم نمود، تا برايشان روشن گردد كه او خود حق است. آيا كافى نيست كه پروردگارت خود شاهد هر چيزى است؟\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxii{آرى، آنان در لقاى پروردگارشان ترديد دارند. آگاه باش كه مسلماً او به هر چيزى احاطه دارد.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxiii{\basmalahfa حاء، ميم،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxiv{عين، سين، قاف.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxv{اين گونه، خداى نيرومند حكيم به سوى تو و به سوى كسانى كه پيش از تو بودند، وحى مى‌كند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxvi{آنچه در آسمانها و آنچه در زمين است از آنِ اوست و او بلندمرتبه بزرگ است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxvii{چيزى نمانده كه آسمانها از فرازشان بشكافند و [حال آنكه‌] فرشتگان به سپاس پروردگارشان تسبيح مى‌گويند و براى كسانى كه در زمين هستند آمرزش مى‌طلبند. آگاه باش، در حقيقت خداست كه آمرزنده مهربان است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxviii{و كسانى كه به جاى او دوستانى براى خود گرفته‌اند، خدا بر ايشان نگهبان است و تو بر آنان گمارده نيستى.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxix{و بدين گونه قرآن عربى به سوى تو وحى كرديم تا [مردم‌] مكّه و كسانى را كه پيرامون آنند هشدار دهى، و از روز گردآمدن [خلق‌] -كه ترديدى در آن نيست- بيم دهى؛ گروهى در بهشتند و گروهى در آتش.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxx{و اگر خدا مى‌خواست، قطعاً آنان را امتى يگانه مى‌گردانيد، ليكن هر كه را بخواهد، به رحمت خويش درمى‌آورد و ستمگران نه يارى دارند و نه ياورى.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxi{آيا به جاى او دوستانى براى خود گرفته‌اند؟ خداست كه دوست راستين است، و اوست كه مردگان را زنده مى‌كند، و هموست كه بر هر چيزى تواناست.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxii{و در باره هر چيزى اختلاف پيدا كرديد، داوريش به خدا [ارجاع مى‌گردد]. چنين خدايى پروردگار من است. بر او توكل كردم و به سوى او بازمى‌گردم.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxiii{پديدآورنده آسمانها و زمين است. از خودتان براى شما جفتهايى قرار داد، و از دامها [نيز] نر و ماده [قرار داد]. بدين وسيله شما را بسيار مى‌گرداند. چيزى مانند او نيست و اوست شنواى بينا.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxiv{كليدهاى آسمانها و زمين از آنِ اوست. براى هر كس كه بخواهد روزى را گشاده يا تنگ مى‌گرداند. اوست كه بر هر چيزى داناست.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxv{از [احكام‌] دين، آنچه را كه به نوح در باره آن سفارش كرد، براى شما تشريع كرد و آنچه را به تو وحى كرديم و آنچه را كه در باره آن به ابراهيم و موسى و عيسى سفارش نموديم كه: «دين را برپا داريد و در آن تفرقه‌اندازى مكنيد.» بر مشركان آنچه كه ايشان را به سوى آن فرا مى‌خوانى، گران مى‌آيد. خدا هر كه را بخواهد، به سوى خود برمى‌گزيند، و هر كه را كه از در توبه درآيد، به سوى خود راه مى‌نمايد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxvi{و فقط پس از آنكه علم برايشان آمد، راه تفرقه پيمودند [آن هم‌] به صرف حسد [و برترى جويى‌] ميان همديگر. و اگر سخنى [داير بر تأخير عذاب‌] از جانب پروردگارت تا زمانى معيّن، پيشى نگرفته بود، قطعاً ميانشان داورى شده بود. و كسانى كه بعد از آنان كتاب [تورات‌] را ميراث يافتند واقعاً در باره او در ترديدى سخت [دچار]اند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxvii{بنابراين به دعوت پرداز، و همان گونه كه مأمورى ايستادگى كن، و هوسهاى آنان را پيروى مكن و بگو: «به هر كتابى كه خدا نازل كرده است ايمان آوردم و مأمور شدم كه ميان شما عدالت كنم؛ خدا پروردگار ما و پروردگار شماست؛ اعمال ما از آنِ ما و اعمال شما از آنِ شماست؛ ميان ما و شما خصومتى نيست؛ خدا ميان ما را جمع مى‌كند، و فرجام به سوى اوست.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxviii{و كسانى كه در باره خدا پس از اجابت [دعوت‌] او به مجادله مى‌پردازند، حجّتشان پيش پروردگارشان باطل است، و خشمى [از خدا] برايشان است و براى آنان عذابى سخت خواهد بود.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmcclxxxix{خدا همان كسى است كه كتاب و وسيله سنجش را به حق فرود آورد، و تو چه مى‌دانى شايد رستاخيز نزديك باشد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmccxc{كسانى كه به آن ايمان ندارند شتابزده آن را مى‌خواهند، و كسانى كه ايمان آورده‌اند، از آن هراسناكند و مى‌دانند كه آن حقّ است. بدان كه آنان كه در مورد قيامت ترديد مى‌ورزند، قطعاً در گمراهى دور و درازى‌اند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmccxci{خدا نسبت به بندگانش مهربان است: هر كه را بخواهد روزى مى‌دهد و اوست نيرومند غالب.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmccxcii{كسى كه كِشت آخرت بخواهد، براى وى در كِشته‌اش مى‌افزاييم، و كسى كه كِشت اين دنيا را بخواهد به او از آن مى‌دهيم و[لى‌] در آخرت او را نصيبى نيست.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmccxciii{آيا براى آنان شريكانى است كه در آنچه خدا بدان اجازه نداده، برايشان بنياد آيينى نهاده‌اند؟ و اگر فرمان قاطع [در باره تأخير عذاب در كار] نبود مسلماً ميانشان داورى مى‌شد؛ و براى ستمكاران شكنجه‌اى پر درد است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmccxciv{[در قيامت‌] ستمگران را از آنچه انجام داده‌اند، هراسناك مى‌بينى و [جزاى عملشان‌] به آنان خواهد رسيد، و كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند در باغهاى بهشتند. آنچه را بخواهند نزد پروردگارشان خواهند داشت؛ اين است همان فضل عظيم.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmccxcv{اين همان [پاداشى‌] است كه خدا بندگان خود را كه ايمان آورده و كارهاى شايسته كرده‌اند [بدان‌] مژده داده است. بگو: «به ازاى آن [رسالت‌] پاداشى از شما خواستار نيستم، مگر دوستى در باره خويشاوندان.» و هر كس نيكى به جاى آورد [و طاعتى اندوزد]، براى او در ثواب آن خواهيم افزود. قطعاً خدا آمرزنده و قدرشناس است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmccxcvi{آيا مى‌گويند: «بر خدا دروغى بسته است؟» پس اگر خدا بخواهد بر دلت مُهر مى نهد؛ و خدا باطل را محو و حقيقت را با كلمات خويش پا برجا مى‌كند. اوست كه به راز دلها داناست.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmccxcvii{و اوست كسى كه توبه را از بندگان خود مى‌پذيرد و از گناهان درمى‌گذرد و آنچه مى‌كنيد مى‌داند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmccxcviii{و [درخواست‌] كسانى را كه ايمان آورده و كارهاى شايسته انجام داده‌اند اجابت مى‌كند و از فضل خويش به آنان زياده مى‌دهد، و[لى‌] براى كافران عذاب سختى خواهد بود.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmccxcix{و اگر خدا روزى را بر بندگانش فراخ گرداند، مسلماً در زمين سر به عصيان برمى‌دارند، ليكن آنچه را بخواهد به اندازه‌اى [كه مصلحت است‌] فرو مى‌فرستد. به راستى كه او به [حال‌] بندگانش آگاهِ بيناست.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmccc{و اوست كسى كه باران را -پس از آنكه [مردم‌] نوميد شدند- فرود مى‌آورد، و رحمت خويش را مى‌گسترد و هموست سرپرست ستوده.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmccci{و از نشانه‌هاى [قدرت‌] اوست آفرينش آسمانها و زمين و آنچه از [انواع‌] جنبنده در ميان آن دو پراكنده است، و او هرگاه بخواهد بر گردآوردن آنان تواناست.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmcccii{و هر [گونه‌] مصيبتى به شما برسد به سبب دستاورد خود شماست، و [خدا] از بسيارى درمى‌گذرد.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmccciii{و شما در زمين درمانده كننده [خدا] نيستيد، و جز خدا شما را سرپرست و ياورى نيست.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmccciv{و از نشانه‌هاى او سفينه‌هاى كوه‌آسا در درياست.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmcccv{اگر بخواهد باد را ساكن مى‌گرداند و [سفينه‌ها] بر پشت [آب‌] متوقف مى‌مانند. قطعاً در اين [امر] براى هر شكيباى شكرگزارى نشانه‌هاست.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmcccvi{يا به [سزاى‌] آنچه [كشتى‌نشينان‌] مرتكب شده‌اند هلاكشان كند، و[لى‌] از بسيارى درمى‌گذرد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmcccvii{و [تا] آنان كه در آيات ما مجادله مى‌كنند، بدانند كه ايشان را [روى‌] گريزى نيست.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmcccviii{و آنچه به شما داده شده، برخوردارى [و كالاى‌] زندگى دنياست، و آنچه پيش خداست براى كسانى كه گرويده‌اند و به پروردگارشان اعتماد دارند بهتر و پايدارتر است.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmcccix{و كسانى كه از گناهان بزرگ و زشتكاريها خود را به دور مى‌دارند و چون به خشم درمى‌آيند درمى‌گذرند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmcccx{و كسانى كه [نداى‌] پروردگارشان را پاسخ [مثبت‌] داده و نماز برپا كرده‌اند و كارشان در ميانشان مشورت است و از آنچه روزيشان داده‌ايم انفاق مى‌كنند.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmcccxi{و كسانى كه چون ستم بر ايشان رسد، يارى مى‌جويند [و به انتقام بر مى‌خيزند].\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmcccxii{و جزاى بدى، مانند آن، بدى است. پس هر كه درگذرد و نيكوكارى كند، پاداش او بر [عهده‌] خداست. به راستى او ستمگران را دوست نمى‌دارد.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmcccxiii{و هر كه پس از ستم [ديدن‌] خود، يارى جويد [و انتقام گيرد] راه [نكوهشى‌] بر ايشان نيست.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmcccxiv{راه [نكوهش‌] تنها بر كسانى است كه به مردم ستم مى‌كنند، و در [روى‌] زمين به ناحق سر برمى‌دارند. آنان عذابى دردناك [در پيش‌] خواهند داشت.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmcccxv{و هر كه صبر كند و درگذرد، مسلماً اين [خويشتن دارى، حاكى‌] از اراده قوى [در] كارهاست.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmcccxvi{و هر كه را خدا بى‌راه گذارد، پس از او يار [و ياور]ى نخواهد داشت، و ستمگران را مى‌بينى كه چون عذاب را بنگرند مى‌گويند: «آيا راهى براى برگشتن [به دنيا] هست؟»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmcccxvii{آنان را مى‌بينى [كه چون‌] بر [آتش‌] عرضه مى‌شوند، از [شدت‌] زبونى، فروتن شده‌اند: زيرچشمى مى‌نگرند. و كسانى كه گرويده‌اند مى‌گويند: «در حقيقت، زيانكاران كسانى‌اند كه روز قيامت خودشان و كسانشان را دچار زيان كرده‌اند.» آرى، ستمكاران در عذابى پايدارند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmcccxviii{و جز خدا براى آنان دوستانى [ديگر] نيست كه آنها را يارى كنند، و هر كه را خدا بى‌راه كذارد هيچ راهى براى او نخواهد بود.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmcccxix{پيش از آنكه روزى فرا رسد كه آن را از جانب خدا برگشتى نباشد، پروردگارتان را اجابت كنيد. آن روز نه براى شما پناهى و نه برايتان [مجال‌] انكارى هست.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmcccxx{پس اگر روى برتابند، ما تو را بر آنان نگهبان نفرستاده‌ايم. بر عهده تو جز رسانيدن [پيام‌] نيست، و ما چون رحمتى از جانب خود به انسان بچشانيم، بدان شاد و سرمست گردد، و چون به [سزاى‌] دستاورد پيشين آنها، به آنان بدى رسد، انسان ناسپاسى مى‌كند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxi{فرمانروايى [مطلق‌] آسمانها و زمين از آنِ خداست؛ هر چه بخواهد مى‌آفريند؛ به هر كس بخواهد فرزند دختر و به هركس بخواهد فرزند پسر مى‌دهد.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxii{يا آنها را پسر[ان‌] و دختر[انى‌] توأم با يكديگر مى‌گرداند، و هر كه را بخواهد عقيم مى‌سازد. اوست داناى توانا.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxiii{و هيچ بشرى را نرسد كه خدا با او سخن گويد جز [از راه‌] وحى يا از فراسوى حجابى، يا فرستاده‌اى بفرستد و به اذن او هر چه بخواهد وحى نمايد. آرى، اوست بلندمرتبه سنجيده‌كار.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxiv{وهمين گونه، روحى از امر خودمان به سوى تو وحى كرديم. تو نمى‌دانستى كتاب چيست و نه ايمان [كدام است؟] ولى آن را نورى گردانيديم كه هر كه از بندگان خود را بخواهيم به وسيله آن راه مى‌نماييم، و به راستى كه تو به خوبى به راه راست هدايت مى‌كنى.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxv{راه همان خدايى كه آنچه در آسمانها و آنچه در زمين است از آنِ اوست. هش‌دار كه [همه‌] كارها به خدا بازمى‌گردد.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxvi{\basmalahfa حاء، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxvii{سوگند به كتاب روشنگر.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxviii{ما آن را قرآنى عربى قرار داديم، باشد كه بينديشيد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxix{و همانا كه آن در كتاب اصلى [=لوح محفوظ] به نزد ما سخت والا و پر حكمت است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxx{آيا به [صِرف‌] اينكه شما قومى منحرفيد [بايد] قرآن را از شما باز داريم؟\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxi{و چه بسا پيامبرانى كه در [ميان‌] گذشتگان روانه كرديم.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxii{و هيچ پيامبرى به سوى ايشان نيامد، مگر اينكه او را به ريشخند مى‌گرفتند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxiii{و نيرومندتر از آنان را به هلاكت رسانيديم و سنّت پيشينيان تكرار شد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxiv{و اگر از آنان بپرسى: «آسمانها و زمين را چه كسى آفريده؟» قطعاً خواهند گفت: «آنها را همان قادر دانا آفريده است.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxv{همان كسى كه اين زمين را براى شما گهواره‌اى گردانيد و براى شما در آن راهها نهاد، باشد كه راه يابيد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxvi{و آن كس كه آبى به اندازه از آسمان فرود آورد، پس به وسيله آن، سرزمينى مرده را زنده گردانيديم؛ همين گونه [از گورها] بيرون آورده مى‌شويد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxvii{و همان كسى كه جفتها را يكسره آفريد، و براى شما از كشتيها و دامها [وسيله‌اى كه‌] سوار شويد قرار داد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxviii{تا بر پشت آن‌[ها] قرار گيريد، پس چون بر آن‌[ها] برنشستيد، نعمت پروردگار خود را ياد كنيد و بگوييد: «پاك است كسى كه اين را براى ما رام كرد و[گرنه‌] ما را ياراى [رام‌ساختن‌] آنها نبود.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmcccxxxix{«و به راستى كه ما به سوى پروردگارمان بازخواهيم گشت.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmcccxl{و براى او بعضى از بندگان [خدا] را جزئى [چون فرزند و شريك‌] قرار دادند. به راستى كه انسان بس ناسپاس آشكار است.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmcccxli{آيا از آنچه مى‌آفريند، خود، دخترانى برگرفته و به شما پسران را اختصاص داده است؟\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmcccxlii{و چون يكى از آنان را به آنچه به [خداى‌] رحمان نسبت مى‌دهد خبر دهند، چهره او سياه مى‌گردد، در حالى كه خشم و تأسف خود را فرو مى‌خورد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmcccxliii{آيا كسى [را شريك خدا مى‌كنند] كه در زر و زيور پرورش يافته و در [هنگام‌] مجادله، بيانش غير روشن است؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmcccxliv{و فرشتگانى را كه خود، بندگان رحمانند، مادينه [و دختران او] پنداشتند. آيا در خلقت آنان حضور داشتند؟ گواهى ايشان به زودى نوشته مى‌شود و [از آن‌] پرسيده خواهند شد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmcccxlv{و مى‌گويند: «اگر [خداى‌] رحمان مى‌خواست، آنها را نمى‌پرستيديم.» آنان به اين [دعوى‌] دانشى ندارند [و] جز حدس نمى‌زنند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmcccxlvi{آيا به آنان پيش از آن [قرآن‌] كتابى داده‌ايم كه بدان تمسك مى‌جويند؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmcccxlvii{[نه،] بلكه گفتند: «ما پدران خود را بر آيينى يافتيم و ما [هم با] پى گيرى از آنان، راه يافتگانيم.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmcccxlviii{و بدين گونه در هيچ شهرى پيش از تو هشداردهنده‌اى نفرستاديم مگر آنكه خوشگذرانان آن گفتند: «ما پدران خود را بر آيينى [و راهى‌] يافته‌ايم و ما از پى ايشان راهسپريم.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmcccxlix{گفت «هر چند هدايت كننده‌تر از آنچه پدران خود را بر آن يافته‌ايد براى شما بياورم؟» گفتند: «ما [نسبت‌] به آنچه بدان فرستاده شده‌ايد كافريم.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmcccl{پس، از آنان انتقام گرفتيم. پس بنگر فرجام تكذيب‌كنندگان چگونه بوده است.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmcccli{و چون ابراهيم به [نا]پدرى خود و قومش گفت: «من واقعاً از آنچه مى‌پرستيد بيزارم،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmccclii{مگر [از] آن كس كه مرا پديد آورد؛ و البته او مرا راهنمايى خواهد كرد.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmcccliii{و او آن را در پى خود سخنى جاويدان كرد، باشد كه آنان [به توحيد] بازگردند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmcccliv{بلكه اينان و پدرانشان را برخودارى دادم تا حقيقت و فرستاده‌اى آشكار به سويشان آمد.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmccclv{و چون حقيقت به سويشان آمد، گفتند: «اين افسونى است و ما منكر آنيم.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmccclvi{و گفتند: «چرا اين قرآن بر مردى بزرگ از [آن‌] دو شهر فرود نيامده است؟»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmccclvii{آيا آنانند كه رحمت پروردگارت را تقسيم مى‌كنند؟ ما [وسايل‌] معاش آنان را در زندگى دنيا ميانشان تقسيم كرده‌ايم، و برخى از آنان را از [نظر] درجات، بالاتر از بعضى [ديگر] قرار داده‌ايم تا بعضى از آنها بعضى [ديگر] را در خدمت گيرند، و رحمت پروردگار تو از آنچه آنان مى‌اندوزند بهتر است.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmccclviii{و اگر نه آن بود كه [همه‌] مردم [در انكار خدا] امتى واحد گردند، قطعاً براى خانه‌هاى آنان كه به [خداى‌] رحمان كفر مى‌ورزيدند، سقفها و نردبانهايى از نقره كه بر آنها بالا روند قرار مى‌داديم.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmccclix{و براى خانه‌هايشان نيز درها و تختهايى كه بر آنها تكيه زنند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmccclx{و زر و زيورهاى [ديگر نيز]. و همه اينها جز متاع زندگى دنيا نيست، و آخرت پيش پروردگار تو براى پرهيزگاران است.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmccclxi{و هر كس از ياد [خداى‌] رحمان دل بگرداند، بر او شيطانى مى‌گماريم تا براى وى دمسازى باشد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmccclxii{و مسلماً آنها ايشان را از راه باز مى‌دارند و [آنها] مى‌پندارند كه راه يافتگانند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmccclxiii{تا آنگاه كه او [با دمسازش‌] به حضور ما آيد، [خطاب به شيطان‌] گويد: «اى كاش ميان من و تو، فاصله خاور و باختر بود، كه چه بد دمسازى هستى!»\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmccclxiv{و امروز هرگز [پشيمانى‌] براى شما سود نمى‌بخشد، چون ستم كرديد؛ در حقيقت، شما در عذاب، مشترك خواهيد بود.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmccclxv{پس آيا تو مى‌توانى كران را شنوا كنى، يا نابينايان و كسى را كه همواره در گمراهى آشكارى است راه نمايى؟\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmccclxvi{پس اگر ما تو را [از دنيا] ببريم، قطعاً از آنان انتقام مى‌كشيم،\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmccclxvii{يا [اگر] آنچه را به آنان وعده داده‌ايم به تو نشان دهيم؛ حتماً ما بر آنان قدرت داريم.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmccclxviii{پس به آنچه به سوى تو وحى شده است چنگ دَرْزَنْ، كه تو بر راهى راست قرار دارى.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmccclxix{و به راستى كه [قرآن‌] براى تو و براى قوم تو [مايه‌] تذكّرى است، و به زودى [در مورد آن‌] پرسيده خواهيد شد.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmccclxx{و از رسولان ما كه پيش از تو گسيل داشتيم جويا شو؛ آيا در برابر [خداى‌] رحمان، خدايانى كه مورد پرستش قرار گيرند مقرر داشته‌ايم؟\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxi{و همانا موسى را با نشانه‌هاى خويش به سوى فرعون و سران [قوم‌] او روانه كرديم. پس گفت: «من فرستاده پروردگار جهانيانم.»\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxii{پس چون آيات ما را براى آنان آورد، ناگهان ايشان بر آنها خنده زدند.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxiii{و [ما] نشانه‌اى به ايشان نمى‌نموديم مگر اينكه آن از نظير [و مشابه‌] آن بزرگتر بود، و به عذاب گرفتارشان كرديم تا مگر به راه آيند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxiv{و گفتند: «اى فسونگر، پروردگارت را به [پاس‌] آنچه با تو عهد كرده، براى ما بخوان، كه ما واقعاً به راه درست درآمده‌ايم.»\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxv{و چون عذاب را از آنها برداشتيم، بناگاه آنان پيمان شكستند.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxvi{و فرعون در [ميان‌] قوم خود ندا درداد [و] گفت: «اى مردم [كشور] من، آيا پادشاهى مصر و اين نهرها كه از زير [كاخهاى‌] من روان است از آنِ من نيست؟ پس مگر نمى‌بينيد؟\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxvii{آيا [نه‌] من از اين كس كه خود بى‌مقدار است و نمى‌تواند درست بيان كند بهترم؟\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxviii{پس چرا بر او دستبندهايى زرين آويخته نشده؟ يا با او فرشتگانى همراه نيامده‌اند؟\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxix{پس قوم خود را سبك‌مغز يافت [و آنان را فريفت‌] و اطاعتش كردند، چرا كه آنها مردمى منحرف بودند.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxx{و چون ما را به خشم درآوردند، از آنان انتقام گرفتيم و همه آنان را غرق كرديم.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxi{و آنان را پيشينه‌اى [بد] و عبرتى براى آيندگان گردانيديم.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxii{و هنگامى كه [در مورد] پسر مريم مثالى آورده شد، بناگاه قوم تو از آن [سخن‌] هِلهِله درانداختند [و اعراض كردند]،\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxiii{و گفتند: «آيا معبودان ما بهترند يا او؟» آن [مثال‌] را جز از راه جدل براى تو نزدند، بلكه آنان مردمى جدل‌پيشه‌اند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxiv{[عيسى‌] جز بنده‌اى كه بر وى منت نهاده و او را براى فرزندان اسرائيل سرمشق [و آيتى‌] گردانيده‌ايم نيست.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxv{و اگر بخواهيم قطعاً به جاى شما فرشتگانى كه در [روى‌] زمين جانشين [شما] گردند قرار دهيم.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxvi{و همانا آن، نشانه‌اى براى [فهم‌] رستاخيز است، پس زنهار در آن ترديد مكن، و از من پيروى كنيد؛ اين است راه راست!\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxvii{و مبادا شيطان شما را از راه به در برد، زيرا او براى شما دشمنى آشكار است.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxviii{و چون عيسى دلايل آشكار آورد، گفت: «به راستى براى شما حكمت آوردم، و تا در باره بعضى از آنچه در آن اختلاف مى‌كرديد برايتان توضيح دهم. پس، از خدا بترسيد و فرمانم ببريد.»\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmmccclxxxix{در حقيقت، خداست كه خود پروردگار من و پروردگار شماست. پس او را بپرستيد؛ اين است راه راست.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmmcccxc{تا [آنكه‌] از ميانشان، احزاب دست به اختلاف زدند، پس واى بر كسانى كه ستم كردند از عذاب روزى دردناك!\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmmcccxci{آيا جز [اين‌] انتظار مى‌برند كه رستاخيز -در حالى كه حدس نمى‌زنند- ناگهان بر آنان در رسد؟\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmmcccxcii{در آن روز، ياران -جز پرهيزگاران- بعضى‌شان دشمن بعضى ديگرند.\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmmcccxciii{اى بندگان من، امروز بر شما بيمى نيست و غمگين نخواهيد شد.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmmcccxciv{همان كسانى كه به آيات ما ايمان آورده و تسليم بودند.\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmmcccxcv{شما با همسرانتان شادمانه داخل بهشت شويد.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmmcccxcvi{سينيهايى از طلا و جام‌هايى در برابر آنان مى‌گردانند، و در آنجا آنچه دلها آن را بخواهند و ديدگان را خوش آيد [هست‌] و شما در آن جاودانيد.\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmmcccxcvii{و اين است همان بهشتى كه به [پاداش‌] آنچه مى‌كرديد ميراث يافتيد.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmmcccxcviii{در آنجا براى شما ميوه‌هايى فراوان خواهد بود كه از آنها مى‌خوريد.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmmcccxcix{بى‌گمان، مجرمان در عذاب جهنم ماندگارند.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmmcd{[عذاب‌] از آنان تخفيف نمى‌يابد و آنها در آنجا نوميدند.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmmcdi{و ما بر ايشان ستم نكرديم، بلكه خود ستمكار بودند.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmmcdii{و فرياد كشند: «اى مالك، [بگو:] پروردگارت جان ما را بستاند.» پاسخ دهد: « شما ماندگاريد.»\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmmcdiii{قطعاً حقيقت را برايتان آورديم، ليكن بيشتر شما حقيقت را خوش نداشتيد.\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmmcdiv{يا در كارى ابرام ورزيده‌اند؟ ما [نيز] ابرام مى‌ورزيم.\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmmcdv{آيا مى‌پندارند كه ما راز آنها و نجوايشان را نمى‌شنويم؟ چرا، و فرشتگان ما پيش آنان [حاضرند و] ثبت مى‌كنند.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmmcdvi{بگو: «اگر براى [خداى‌] رحمان فرزندى بود، خود من نخستين پرستندگان بودم.»\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmmcdvii{پروردگار آسمانها و زمين [و] پروردگار عرش، از آنچه وصف مى‌كنند منزه است.\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmmcdviii{پس آنان را رها كن تا در ياوه‌گويى خود فرو روند و بازى كنند تا آن روزى را كه بدان وعده داده مى‌شوند ديدار كنند.\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmmcdix{و اوست كه در آسمان خداست و در زمين خداست، و هموست سنجيده‌كار دانا.\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmmmcdx{و خجسته است كسى كه فرمانروايى آسمانها و زمين و آنچه ميان آن دو است از آنِ اوست، و علم قيامت پيش اوست و به سوى او برگردانيده مى‌شويد.\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmmmcdxi{و كسانى كه به جاى او مى‌خوانند [و مى‌پرستند] اختيار شفاعت ندارند، مگر آن كسانى كه آگاهانه به حق گواهى داده باشند.\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmmmcdxii{و اگر از آنان بپرسى: «چه كسى آنان را خلق كرده؟» مسلماً خواهند گفت: «خدا.» پس چگونه [از حقيقت‌] بازگردانيده مى‌شوند؟\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmmmcdxiii{و گويد: «اى پروردگار من، اينها جماعتى‌اند كه ايمان نخواهند آورد.»\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmmmcdxiv{[و خدا فرمود:] از ايشان روى برتاب و بگو: «به سلامت.» پس زودا كه بدانند.\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmmmcdxv{\basmalahfa حاء، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmcdxvi{سوگند به كتاب روشنگر،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmcdxvii{[كه‌] ما آن را در شبى فرخنده نازل كرديم، [زيرا] كه ما هشداردهنده بوديم.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmcdxviii{در آن [شب‌] هر [گونه‌] كارى [به نحوى‌] استوار فيصله مى‌يابد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmcdxix{[اين‌] كارى است [كه‌] از جانب ما [صورت مى‌گيرد]. ما فرستنده [پيامبران‌] بوديم.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmcdxx{[و اين‌] رحمتى از پروردگار توست، كه او شنواى داناست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxi{پروردگار آسمانها و زمين و آنچه ميان آن دو است، اگر يقين داريد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxii{خدايى جز او نيست؛ او زندگى مى‌بخشد و مى‌ميراند؛ پروردگار شما و پروردگار پدران شماست.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxiii{ولى نه، آنها به شك و شبهه خويش سرگرمند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxiv{پس در انتظار روزى باش كه آسمان دودى نمايان برمى‌آورد،\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxv{كه مردم را فرو مى‌گيرد؛ اين است عذاب پر درد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxvi{[مى‌گويند:] «پروردگارا، اين عذاب را از ما دفع كن كه ما ايمان داريم.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxvii{آنان را كجا [جاى‌] پند[گرفتن‌] باشد، و حال آنكه به يقين براى آنان پيامبرى روشنگر آمده است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxviii{پس، از او روى برتافتند و گفتند: «تعليم‌يافته‌اى ديوانه است.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxix{ما اين عذاب را اندكى از شما برمى‌داريم [ولى شما] در حقيقت باز از سر مى‌گيريد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxx{روزى كه دست به حمله مى‌زنيم، همان حمله بزرگ؛ [آنگاه‌] ما انتقام‌كشنده‌ايم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxi{و به يقين، پيش از آنان قوم فرعون را بيازموديم، و پيامبرى بزرگوار برايشان آمد،\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxii{كه [به آنان گفت:] «بندگان خدا را به من بسپاريد، زيرا كه من شما را فرستاده‌اى امينم.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxiii{و بر خدا برترى مجوييد كه من براى شما حجتى آشكار آورده‌ام.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxiv{و من به پروردگار خود و پروردگار شما پناه مى‌برم از اينكه مرا سنگباران كنيد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxv{و اگر به من ايمان نمى‌آوريد، پس، از من كناره گيريد.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxvi{پس پروردگار خود را خواند كه: «اينها مردمى گناهكارند.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxvii{[فرمود:] «بندگانم را شبانه ببر، زيرا شما مورد تعقيب واقع خواهيد شد.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxviii{و دريا را هنگامى كه آرام است پشت سر بگذار، كه آنان سپاهى غرق‌شدنى‌اند.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmcdxxxix{[وه،] چه باغها و چشمه‌سارانى [كه آنها بعد از خود] بر جاى نهادند،\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmcdxl{و كشتزارها و جايگاه‌هاى نيكو،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmcdxli{و نعمتى كه از آن برخوردار بودند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmcdxlii{[آرى،] اين چنين [بود] و آنها را به مردمى ديگر ميراث داديم.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmcdxliii{و آسمان و زمين بر آنان زارى نكردند و مهلت نيافتند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmcdxliv{و به راستى، فرزندان اسرائيل را از عذاب خفت‌آور رهانيديم:\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmcdxlv{از [دست‌] فرعون كه متكبّرى از افراطكاران بود.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmcdxlvi{و قطعاً آنان را دانسته بر مردم جهان ترجيح داديم.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmcdxlvii{و از نشانه‌ها [ى الهى‌] آنچه را كه در آن آزمايشى آشكار بود، بديشان داديم.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmcdxlviii{هر آينه اين [كافران‌] مى‌گويند:\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmcdxlix{«جز مرگ نخستين، ديگر [واقعه‌اى‌] نيست و ما زنده‌شدنى نيستيم.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmcdl{اگر راست مى‌گوييد، پس پدران ما را [باز] آوريد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmcdli{آيا ايشان بهترند يا قوم «تُبّع» و كسانى كه پيش از آنها بودند؟ آنها را هلاك كرديم، زيرا كه گنهكار بودند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmcdlii{و آسمانها و زمين و آنچه را كه ميان آن دو است به بازى نيافريده‌ايم؛\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmcdliii{آنها را جز به حق نيافريده‌ايم، ليكن بيشترشان نمى‌دانند.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmcdliv{در حقيقت، روز «جدا سازى» موعد همه آنهاست.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmcdlv{همان روزى كه هيچ دوستى از هيچ دوستى نمى‌تواند حمايتى كند، و آنان يارى نمى‌شوند،\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmcdlvi{مگر كسى را كه خدا رحمت كرده است، زيرا كه اوست همان ارجمند مهربان.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmcdlvii{آرى! درخت زقوم،\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmcdlviii{خوراك گناه پيشه است.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmcdlix{چون مس گداخته در شكمها مى‌گدازد؛\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmcdlx{همانند جوشش آب جوشان.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxi{او را بگيريد و به ميان دوزخش بكشانيد،\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxii{آنگاه از عذاب آب جوشان بر سرش فرو ريزيد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxiii{بچش كه تو همان ارجمند بزرگوارى!\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxiv{اين است همان چيزى كه در باره آن ترديد مى‌كرديد.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxv{به راستى پرهيزگاران در جايگاهى آسوده [اند]،\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxvi{در بوستانها و كنار چشمه‌سارها.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxvii{پرنيان نازك و ديباى ستبر مى‌پوشند [و] برابر هم نشسته‌اند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxviii{[آرى،] چنين [خواهد بود] و آنها را با حوريان درشت‌چشم همسر مى‌گردانيم.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxix{در آنجا هر ميوه‌اى را [كه بخواهند] آسوده خاطر مى‌طلبند.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxx{در آنجا جز مرگ نخستين، مرگ نخواهند چشيد و [خدا] آنها را از عذاب دوزخ نگاه مى‌دارد.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxi{[اين‌] بخششى است از جانب پروردگار تو. اين است همان كاميابى بزرگ.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxii{در حقيقت، [قرآن‌] را بر زبان تو آسان گردانيديم، اميد كه پند پذيرند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxiii{پس مراقب باش، زيرا كه آنان هم مراقبند.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxiv{\basmalahfa حاء، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxv{فرو فرستادن اين كتاب، از جانب خداى ارجمند سنجيده‌كار است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxvi{به راستى در آسمانها و زمين، براى مؤمنان نشانه‌هايى است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxvii{و در آفرينش خودتان و آنچه از [انواع‌] جنبنده‌[ها] پراكنده مى‌گرداند، براى مردمى كه يقين دارند نشانه‌هايى است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxviii{و [نيز در] پياپى آمدن شب و روز، و آنچه خدا از روزى از آسمان فرود آورده و به [وسيله‌] آن، زمين را پس از مرگش زنده گردانيده است؛ و [همچنين در] گردش بادها [به هر سو،] براى مردمى كه مى‌انديشند نشانه‌هايى است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxix{اين‌[ها]ست آيات خدا كه به راستى آن را بر تو مى‌خوانيم. پس، بعد از خدا و نشانه‌هاى او به كدام سخن خواهند گرويد؟\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxx{واى بر هر دروغزن گناه‌پيشه!\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxi{[كه‌] آيات خدا را كه بر او خوانده مى‌شود، مى‌شنود و باز به حال تكبر -چنانكه گويى آن را نشنيده است- سماجت مى‌ورزد. پس او را از عذابى پردرد خبر ده.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxii{و چون از نشانه‌هاى ما چيزى بداند، آن را به ريشخند مى‌گيرد. آنان عذابى خفت‌آور خواهند داشت.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxiii{پيشاپيش آنها دوزخ است، و نه آنچه را اندوخته و نه آن دوستانى را كه غير از خدا اختيار كرده‌اند، به كارشان مى‌آيد، و عذابى بزرگ خواهند داشت.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxiv{اين رهنمودى است؛ و كسانى كه آيات پروردگارشان را انكار كردند، بر ايشان عذابى دردناك از پليدى است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxv{خدا همان كسى است كه دريا را به سود شما رام گردانيد، تا كشتيها در آن به فرمانش روان شوند، و تا از فزون بخشى او [روزى خويش را] طلب نماييد، و باشد كه سپاس داريد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxvi{و آنچه را در آسمانها و آنچه را در زمين است به سود شما رام كرد؛ همه از اوست. قطعاً در اين [امر] براى مردمى كه مى‌انديشند نشانه‌هايى است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxvii{به كسانى كه ايمان آورده‌اند بگو تا از كسانى كه به روزهاى [پيروزى‌] خدا اميد ندارند درگذرند، تا [خدا هر] گروهى را به [سبب‌] آنچه مرتكب مى‌شده‌اند به مجازات رساند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxviii{هر كه كارى شايسته كند، به سود خود اوست، و هر كه بدى كند به زيانش باشد. سپس به سوى پروردگارتان برگردانيده مى‌شويد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmcdlxxxix{و به يقين، فرزندان اسرائيل را كتاب [تورات‌] و حكم و پيامبرى داديم و از چيزهاى پاكيزه روزيشان كرديم و آنان را بر مردم روزگار برترى داديم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmcdxc{و دلايل روشنى در امر [دين‌] به آنان عطا كرديم، و جز بعد از آنكه علم برايشان [حاصل‌] آمد، [آن هم‌] از روى رشك و رقابت ميان خودشان، دستخوش اختلاف نشدند. قطعاً پروردگارت روز قيامت ميانشان در باره آنچه در آن اختلاف مى‌كردند، داورى خواهد كرد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmcdxci{سپس تو را در طريقه آيينى [كه ناشى‌] از امر [خداست‌] نهاديم. پس آن را پيروى كن، و هوسهاى كسانى را كه نمى‌دانند پيروى مكن.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmcdxcii{آنان هرگز در برابر خدا از تو حمايت نمى‌كنند [و به هيچ وجه به كار تو نمى‌آيند ] و ستمگران بعضى‌شان دوستان بعضى [ديگر]ند، و خدا يار پرهيزگاران است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmcdxciii{اين [كتاب‌] براى مردم، بينش‌بخش و براى قومى كه يقين دارند، رهنمود و رحمتى است.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmcdxciv{آيا كسانى كه مرتكب كارهاى بد شده‌اند پنداشته‌اند كه آنان را مانند كسانى قرار مى‌دهيم كه ايمان آورده و كارهاى شايسته كرده‌اند [به طورى كه‌] زندگى آنها و مرگشان يكسان باشد؟ چه بد داورى مى‌كنند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmcdxcv{و خدا آسمانها و زمين را به حق آفريده است، و تا هر كسى به [موجب‌] آنچه به دست آورده پاداش يابد، و آنان مورد ستم قرار نخواهند گرفت.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmcdxcvi{پس آيا ديدى كسى را كه هوس خويش را معبود خود قرار داده و خدا او را دانسته گمراه گردانيده و بر گوش او و دلش مُهر زده و بر ديده‌اش پرده نهاده است؟ آيا پس از خدا چه كسى او را هدايت خواهد كرد؟ آيا پند نمى‌گيريد؟\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmcdxcvii{و گفتند: «غير از زندگانى دنياى ما [چيز ديگرى‌] نيست؛ مى‌ميريم و زنده مى‌شويم، و ما را جز طبيعت هلاك نمى‌كند.» و[لى‌] به اين [مطلب‌] هيچ دانشى ندارند [و] جز [طريق‌] گمان نمى‌سپرند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmcdxcviii{و چون آيات روشن ما بر آنان خوانده شود، دليلشان همواره جز اين نيست كه مى گويند: «اگر راست مى‌گوييد پدران ما را [حاضر] آوريد.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmcdxcix{بگو: «خدا[ست كه‌] شما را زندگى مى‌بخشد، سپس مى‌ميراند، آنگاه شما را به سوى روز رستاخيز -كه ترديدى در آن نيست- گرد مى‌آورد، ولى بيشتر مردم [اين را] نمى‌دانند.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmd{و فرمانروايى آسمانها و زمين از آن خداست، و روزى كه رستاخيز بر پا شود، آن روز است كه باطل‌انديشان زيان خواهند ديد.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdi{و هر امتى را به زانو در آمده مى‌بينى؛ هر امتى به سوى كارنامه خود فراخوانده مى‌شود [و بديشان مى‌گويند:] «آنچه را مى‌كرديد امروز پاداش مى‌يابيد.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdii{اين است كتاب ما كه عليه شما به حق سخن مى‌گويد. ما از آنچه مى‌كرديد، نسخه بر مى‌داشتيم.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdiii{و اما كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، پس پروردگارشان آنان را در جوار رحمت خويش داخل مى‌گرداند. اين همان كاميابى آشكار است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmdiv{و اما كسانى كه كافر شدند [بدانها مى‌گويند:] «پس مگر آيات من بر شما خوانده نمى‌شد؟ و[لى‌] تكبر نموديد و مردمى بدكار بوديد.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmdv{و چون گفته شد: «وعده خدا راست است و شكى در رستاخيز نيست»، گفتيد: «ما نمى‌دانيم رستاخيز چيست. جز گمان نمى‌ورزيم و ما يقين نداريم.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmdvi{و [حقيقت‌] بديهايى كه كرده‌اند، بر آنان پديدار مى‌شود و آنچه را كه بدان ريشخند مى‌كردند، آنان را فرو مى‌گيرد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmdvii{و گفته شود: «همان‌گونه كه ديدار امروزتان را فراموش كرديد، امروز شما را فراموش خواهيم كرد، و جايگاهتان در آتش است و براى شما ياورانى نخواهد بود.»\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmdviii{اين بدان سبب است كه شما آيات خدا را به ريشخند گرفتيد و زندگى دنيا فريبتان داد. پس امروز نه از اين [آتش‌] بيرون آورده مى‌شوند، و نه عذرشان پذيرفته مى‌گردد.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmdix{پس سپاس از آن خداست: پروردگار آسمانها و پروردگار زمين، پروردگار جهانيان.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmdx{و در آسمانها و زمين، بزرگى از آن اوست، و اوست شكست‌ناپذير سنجيده‌كار.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmdxi{\basmalahfa حاء، ميم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdxii{فرو فرستادن اين كتاب، از جانب خداى ارجمند حكيم است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdxiii{[ما] آسمانها و زمين و آنچه را كه ميان آن دو است جز به حق و [تا] زمانى معيّن نيافريديم، و كسانى كه كافر شده‌اند، از آنچه هشدار داده شده‌اند رويگردانند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdxiv{بگو: «به من خبر دهيد، آنچه را به جاى خدا فرا مى‌خوانيد به من نشان دهيد كه چه چيزى از زمين [را] آفريده يا [مگر] آنان را در [كار] آسمانها مشاركتى است؟ اگر راست مى‌گوييد، كتابى پيش از اين [قرآن ]يا بازمانده‌اى از دانش نزد من آوريد.»\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdxv{و كيست گمراه‌تر از آن كس كه به جاى خدا كسى را مى‌خواند كه تا روز قيامت او را پاسخ نمى‌دهد، و آنها از دعايشان بى‌خبرند؟\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdxvi{و چون مردم محشور گردند، دشمنان آنان باشند و به عبادتشان انكار ورزند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdxvii{و چون آيات روشن ما بر ايشان خوانده شود، آنان كه چون حقيقت به سويشان آمد منكر آن شدند، گفتند: «اين سحرى آشكار است.»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdxviii{يا مى‌گويند: «اين [كتاب‌] را بربافته است.» بگو: «اگر آن را بربافته باشم؛ در برابر خدا اختيار چيزى براى من نداريد. او آگاه‌تر است به آنچه [با طعنه‌] در آن فرو مى‌رويد. گواه بودن او ميان من و شما بس است، و اوست آمرزنده مهربان.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdxix{بگو: «من از [ميان‌] پيامبران، نودرآمدى نبودم و نمى‌دانم با من و با شما چه معامله‌اى خواهد شد. جز آنچه را كه به من وحى مى‌شود، پيروى نمى‌كنم؛ و من جز هشداردهنده‌اى آشكار [بيش‌] نيستم.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdxx{بگو: «به من خبر دهيد، اگر اين [قرآن‌] از نزد خدا باشد و شما بدان كافر شده باشيد و شاهدى از فرزندان اسرائيل به مشابهت آن [با تورات‌] گواهى داده و ايمان آورده باشد، و شما تكبّر نموده باشيد [آيا باز هم شما ستمكار نيستيد؟] البته خدا قوم ستمگر را هدايت نمى‌كند.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdxxi{و كسانى كه كافر شدند، به آنان كه گرويده‌اند گفتند: «اگر [اين دين‌] خوب بود، بر ما بدان پيشى نمى‌گرفتند.» و چون بدان هدايت نيافته‌اند، به زودى خواهند گفت: «اين دروغى كهنه است.»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdxxii{و [حال آنكه‌] پيش از آن، كتاب موسى، راهبر و [مايه‌] رحمتى بود؛ و اين [قرآن‌] كتابى است به زبان عربى كه تصديق‌كننده [آن‌] است، تا كسانى را كه ستم كرده‌اند هشدار دهد و براى نيكوكاران مژده‌اى باشد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdxxiii{محققاً كسانى كه گفتند: «پروردگار ما خداست» سپس ايستادگى كردند، بيمى بر آنان نيست و غمگين نخواهند شد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdxxiv{ايشان اهل بهشتند كه به پاداش آنچه انجام مى‌دادند جاودانه در آن مى‌مانند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdxxv{و انسان را [نسبت‌] به پدر و مادرش به احسان سفارش كرديم. مادرش با تحمّل رنج به او باردار شد و با تحمّل رنج او را به دنيا آورد. و باربرداشتن و از شيرگرفتن او سى ماه است، تا آنگاه كه به رشد كامل خود برسد و به چهل سال برسد، مى‌گويد: «پروردگارا، بر دلم بيفكن تا نعمتى را كه به من و به پدر و مادرم ارزانى داشته‌اى سپاس گويم و كار شايسته‌اى انجام دهم كه آن را خوش دارى، و فرزندانم را برايم شايسته گردان؛ در حقيقت، من به درگاه تو توبه آوردم و من از فرمان‌پذيرانم.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdxxvi{اينانند كسانى كه بهترين آنچه را انجام داده‌اند از ايشان خواهيم پذيرفت و از بديهايشان درخواهيم گذشت؛ در [زمره‌] بهشتيانند؛ [همان‌] وعده راستى كه بدانان وعده داده مى‌شده است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdxxvii{و آن كس كه به پدر و مادر خود گويد: «اف بر شما، آيا به من وعده مى‌دهيد كه زنده خواهم شد و حال آنكه پيش از من نسلها سپرى [و نابود] شدند.» و آن دو به [درگاه‌] خدا زارى مى‌كنند: «واى بر تو، ايمان بياور. وعده [و تهديد] خدا حق است.» و[لى پسر] پاسخ مى‌دهد: «اينها جز افسانه‌هاى گذشتگان نيست.»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdxxviii{آنان كسانى‌اند كه گفتار [خدا] عليه ايشان -همراه با امتهايى از جنيان و آدميان كه پيش از آنان روزگار به سر بردند- به حقيقت پيوست، بى‌گمان آنان زيانكار بودند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdxxix{و براى هر يك در [نتيجه‌] آنچه انجام داده‌اند درجاتى است، و تا [خدا پاداش‌] اعمالشان را تمام بدهد؛ و آنان مورد ستم قرار نخواهند گرفت.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmdxxx{و آن روز كه آنهايى را كه كفر ورزيده‌اند، بر آتش عرضه مى‌دارند [به آنان مى گويند:] «نعمتهاى پاكيزه خود را در زندگى دنيايتان [خودخواهانه‌] صَرف كرديد و از آنها برخوردار شديد؛ پس امروز به [سزاى ]آنكه در زمين بناحق سركشى مى‌نموديد و به سبب آنكه نافرمانى مى‌كرديد، به عذاب خفت‌[آور] كيفر مى‌يابيد.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxi{و برادر عاديان را به ياد آور، آنگاه كه قوم خويش را در ريگستان بيم داد -در حالى كه پيش از او و پس از او [نيز] قطعاً هشداردهندگانى گذشته بودند- كه: «جز خدا را مپرستيد؛ واقعاً من بر شما از عذاب روزى هولناك مى‌ترسم.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxii{گفتند: «آيا آمده‌اى كه ما را از خدايانمان برگردانى؟ پس اگر راست مى‌گويى، آنچه به ما وعده مى‌دهى [بر سرمان‌] بياور.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxiii{گفت: «آگاهى فقط نزد خداست، و آنچه را بدان فرستاده شده‌ام به شما مى‌رسانم، ولى من شما را گروهى مى‌بينم كه در جهل اصرار مى‌ورزيد.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxiv{پس چون آن [عذاب‌] را [به صورت‌] ابرى روى‌آورنده به سوى واديهاى خود ديدند، گفتند: «اين ابرى است كه بارش‌دهنده ماست.» [هود گفت: «نه،] بلكه همان چيزى است كه به شتاب خواستارش بوديد: بادى است كه در آن عذابى پر درد [نهفته‌] است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxv{همه چيز را به دستور پروردگارش بنيان‌كن مى‌كند.» پس چنان شدند كه جز سراهايشان ديده نمى‌شد. اين چنين گروه بدكاران را سزا مى‌دهيم.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxvi{و به راستى در چيزهايى به آنان امكانات داده بوديم كه به شما در آنها [چنان‌] امكاناتى نداده‌ايم، و براى آنان گوش و ديده‌ها و دلهايى [نيرومندتر از شما] قرار داده بوديم، و[لى‌] چون به نشانه‌هاى خدا انكار ورزيدند [نه‌] گوششان و نه ديدگانشان و نه دلهايشان، به هيچ وجه به دردشان نخورد، و آنچه ريشخندش مى‌كردند به سرشان آمد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxvii{و بى‌گمان، همه شهرهاى پيرامون شما را هلاك كرده و آيات خود را گونه‌گون بيان داشته‌ايم، اميد كه آنان بازگردند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxviii{پس چرا آن كسانى را كه غير از خدا، به منزله معبودانى، براى تقرّب [به خدا] اختيار كرده بودند، آنان را يارى نكردند بلكه از دستشان دادند؟ و اين بود دروغ آنان و آنچه برمى‌بافتند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdxxxix{و چون تنى چند از جِن را به سوى تو روانه كرديم كه قرآن را بشنوند؛ پس چون بر آن حاضر شدند [به يكديگر] گفتند: «گوش فرا دهيد.» و چون به انجام رسيد، هشداردهنده به سوى قوم خود بازگشتند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdxl{گفتند: «اى قوم ما، ما كتابى را شنيديم كه بعد از موسى نازل شده [و] تصديق‌كننده [كتابهاى‌] پيش از خود است، و به سوى حق و به سوى راهى راست راهبرى مى‌كند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmdxli{اى قوم ما، دعوت‌كننده خدا را پاسخ [مثبت‌] دهيد و به او ايمان آوريد تا [خدا] برخى از گناهانتان را بر شما ببخشايد و از عذابى پر درد پناهتان دهد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmdxlii{و كسى كه دعوت‌كننده خدا را اجابت نكند، در زمين درمانده‌كننده [خدا] نيست و در برابر او دوستانى ندارد. آنان در گمراهى آشكارى‌اند.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmdxliii{مگر ندانسته‌اند كه آن خدايى كه آسمانها و زمين را آفريده و در آفريدن آنها درمانده نگرديد؛ مى‌تواند مردگان را [نيز] زنده كند؟ آرى، اوست كه بر همه چيز تواناست.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmdxliv{و روزى كه كافران بر آتش عرضه مى‌شوند [از آنان مى‌پرسند:] «آيا اين راست نيست؟» مى‌گويند: «سوگند به پروردگارمان كه آرى.» مى‌فرمايد: «پس به [سزاى‌] آنكه انكار مى‌كرديد عذاب را بچشيد.»\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmdxlv{پس همان گونه كه پيامبران نستوه، صبر كردند، صبر كن، و براى آنان شتابزدگى به خرج مده. روزى كه آنچه را وعده داده مى‌شوند بنگرند، گويى كه آنان جز ساعتى از روز را [در دنيا] نمانده‌اند؛ [اين‌] ابلاغى است. پس آيا جز مردم نافرمان هلاكت خواهند يافت؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmdxlvi{\basmalahfa كسانى كه كفر ورزيدند و [مردم را] از راه خدا باز داشتند، [خدا] اعمال آنان را تباه خواهد كرد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdxlvii{و آنان كه ايمان آورده و كارهاى شايسته كرده‌اند و به آنچه بر محمد [ص‌] نازل آمده گرويده‌اند -[كه‌] آن خود حق [و] از جانب پروردگارشان است- [خدا نيز] بديهايشان را زدود و حال [و روز]شان را بهبود بخشيد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdxlviii{اين بدان سبب است كه آنان كه كفر ورزيدند، از باطل پيروى كردند، و كسانى كه ايمان آوردند از همان حق -كه از جانب پروردگارشان است- پيروى كردند. اين گونه خدا براى [بيدارى‌] مردم مثالهايشان را مى‌زند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdxlix{پس چون با كسانى كه كفر ورزيده‌اند برخورد كنيد، گردنها[يشان‌] را بزنيد. تا چون آنان را [در كشتار] از پاى درآورديد، پس [اسيران را] استوار در بند كشيد؛ سپس يا [بر آنان‌] منّت نهيد [و آزادشان كنيد] و يا فديه [و عوض از ايشان بگيريد]، تا در جنگ، اسلحه بر زمين گذاشته شود. اين است [دستور خدا]؛ و اگر خدا مى‌خواست، از ايشان انتقام مى‌كشيد، ولى [فرمان پيكار داد] تا برخى از شما را به وسيله برخى [ديگر] بيازمايد، و كسانى كه در راه خدا كشته شده‌اند، هرگز كارهايشان را ضايع نمى‌كند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdl{به زودى آنان را راه مى‌نمايد و حالشان را نيكو مى‌گرداند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdli{و در بهشتى كه براى آنان وصف كرده، آنان را درمى‌آورد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdlii{اى كسانى كه ايمان آورده‌ايد، اگر خدا را يارى كنيد ياريتان مى‌كند و گامهايتان را استوار مى‌دارد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdliii{و كسانى كه كفر ورزيدند، نگونسارى بر آنان باد؛ و [خدا] اعمالشان را برباد داد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdliv{اين بدان سبب است كه آنان آنچه را خدا نازل كرده است خوش نداشتند، و [خدا نيز] كارهايشان را باطل كرد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdlv{مگر در زمين نگشته‌اند، تا ببينند فرجام كسانى كه پيش از آنها بودند به كجا انجاميده است؟ خدا زير و زبرشان كرد و كافران را نظاير [همين كيفرها در پيش‌] است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdlvi{چرا كه خدا سرپرست كسانى است كه ايمان آورده‌اند، ولى كافران را سرپرست [و يارى‌] نيست.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdlvii{خدا كسانى را كه ايمان آورده و كارهاى شايسته كرده‌اند، در باغهايى كه از زير [درختان‌] آنها نهرها روان است درمى‌آورد، و [حال آنكه‌] كسانى كه كافر شده‌اند، [در ظاهر] بهره مى‌برند و همان گونه كه چارپايان مى‌خورند، مى‌خورند، و[لى ]جايگاه آنها آتش است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdlviii{و بسا شهرها كه نيرومندتر از آن شهرى بود كه تو را [از خود] بيرون راند، كه ما هلاكشان كرديم و براى آنها يار [و ياورى‌] نبود.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdlix{آيا كسى كه بر حجتى از جانب پروردگار خويش است، چون كسى است كه بدى كردارش براى او زيبا جلوه داده شده و هوسهاى خود را پيروى كرده‌اند؟\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdlx{مَثَل بهشتى كه به پرهيزگاران وعده داده شده [چون باغى است كه‌] در آن نهرهايى است از آبى كه [رنگ و بو و طعمش‌] برنگشته؛ و جويهايى از شيرى كه مزه‌اش دگرگون نشود؛ و رودهايى از باده‌اى كه براى نوشندگان لذتى است؛ و جويبارهايى از انگبين ناب. و در آنجا از هر گونه ميوه براى آنان [فراهم‌] است و [از همه بالاتر] آمرزش پروردگار آنهاست. [آيا چنين كسى در چنين باغى دل‌انگيز] مانند كسى است كه جاودانه در آتش است و آبى جوشان به خوردشان داده مى‌شود [تا] روده‌هايشان را از هم فرو پاشد؟\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdlxi{و از ميان [منافقان‌] كسانى‌اند كه [در ظاهر] به [سخنان‌] تو گوش مى‌دهند، ولى چون از نزد تو بيرون مى‌روند، به دانش يافتگان مى‌گويند: «هم اكنون چه گفت؟» اينان همانانند كه خدا بر دلهايشان مهر نهاده است و از هوسهاى خود پيروى كرده‌اند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdlxii{و[لى‌] آنان كه به هدايت گراييدند [خدا] آنان را هر چه بيشتر هدايت بخشيد و [توفيق‌] پرهيزگارى‌شان داد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdlxiii{آيا [كافران‌] جز اين انتظار مى‌برند كه رستاخيز به ناگاه بر آنان فرا رسد؟ و علامات آن اينك پديد آمده است. پس اگر [رستاخيز] بر آنان دررسد، ديگر كجا جاى اندرزشان است؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdlxiv{پس بدان كه هيچ معبودى جز خدا نيست؛ و براى گناه خويش آمرزش جوى؛ و براى مردان و زنان با ايمان [طلب مغفرت كن‌]؛ و خداست كه فرجام و م‌آل [هر يك از] شما را مى‌داند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmdlxv{و كسانى كه ايمان آورده‌اند مى‌گويند: «چرا سوره‌اى [در باره جهاد] نازل نمى شود؟» اما چون سوره‌اى صريح نازل شد و در آن نام كارزار آمد، آنان كه در دلهايشان مرضى هست، مانند كسى كه به حال بيهوشى مرگ افتاده به تو مى‌نگرند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmdlxvi{[ولى‌] فرمان‌پذيرى و سخنى شايسته برايشان بهتر است. و چون كار به تصميم كشد، قطعاً خير آنان در اين است كه با خدا راست‌[دل‌] باشند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmdlxvii{پس [اى منافقان،] آيا اميد بستيد كه چون [از خدا] برگشتيد [يا سرپرست مردم شديد] در [روى‌] زمين فساد كنيد و خويشاونديهاى خود را از هم بگسليد؟\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmdlxviii{اينان همان كسانند كه خدا آنان را لعنت نموده و [گوش دل‌] ايشان را ناشنوا و چشمهايشان را نابينا كرده است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmdlxix{آيا به آيات قرآن نمى‌انديشند؟ يا [مگر] بر دلهايشان قفلهايى نهاده شده است؟\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmdlxx{بى‌گمان، كسانى كه پس از آنكه [راه‌] هدايت بر آنان روشن شد [به حقيقت‌] پشت كردند، شيطان آنان را فريفت و به آرزوهاى دور و درازشان انداخت.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxi{چرا كه آنان به كسانى كه آنچه را خدا نازل كرده خوش نمى‌داشتند، گفتند: «ما در كار [مخالفت‌] تا حدودى از شما اطاعت خواهيم كرد.» و خدا از همداستانى آنان آگاه است.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxii{پس چگونه [تاب مى‌آورند] وقتى كه فرشتگان [عذاب‌]، جانشان را مى‌ستانند و بر چهره و پشت آنان تازيانه مى‌نوازند؟\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxiii{زيرا آنان از آنچه خدا را به خشم آورده پيروى كرده‌اند و خرسنديش را خوش نداشتند؛ پس اعمالشان را باطل گردانيد.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxiv{آيا كسانى كه در دلهايشان مرضى هست، پنداشتند كه خدا هرگز كينه آنان را آشكار نخواهد كرد؟\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxv{و اگر بخواهيم، قطعاً آنان را به تو مى‌نمايانيم، در نتيجه ايشان را به سيماى [حقيقى‌]شان مى‌شناسى و از آهنگ سخن به [حال‌] آنان پى خواهى برد؛ و خداست كه كارهاى شما را مى‌داند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxvi{و البته شما را مى‌آزماييم تا مجاهدان و شكيبايان شما را باز شناسانيم، و گزارشهاى [مربوط به‌] شما را رسيدگى كنيم.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxvii{كسانى كه كافر شدند و [مردم را] از راه خدا باز داشتند و پس از آنكه راه هدايت بر آنان آشكار شد، با پيامبر [خدا] در افتادند، هرگز به خدا گزندى نمى‌رسانند؛ و به زودى [خدا] كرده‌هايشان را تباه خواهد كرد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxviii{اى كسانى كه ايمان آورده‌ايد، خدا را اطاعت كنيد و از پيامبر [او نيز] اطاعت نماييد، و كرده‌هاى خود را تباه مكنيد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxix{آنان كه كفر ورزيدند و مانع راه خدا شدند، سپس در حال كفر مردند، هرگز خدا از آنان درنخواهد گذشت.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxx{پس سستى نورزيد و [كافران را] به آشتى مخوانيد [كه‌] شما برتريد و خدا با شماست و از [ارزش‌] كارهايتان هرگز نخواهد كاست.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxi{زندگى اين دنيا لهو و لعبى بيش نيست، و اگر ايمان بياوريد و پروا بداريد [خدا] پاداش شما را مى‌دهد و اموالتان را [در عوض‌] نمى‌خواهد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxii{اگر [اموال‌] شما را بخواهد و به اصرار از شما طلب كند بخل مى‌ورزيد، و كينه‌هاى شما را برملا مى‌كند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxiii{شما همان [مردمى‌] هستيد كه براى انفاق در راه خدا فرا خوانده شده‌ايد. پس برخى از شما بخل مى‌ورزند، و هر كس بخل ورزد تنها به زيان خود بخل ورزيده، و [گرنه‌] خدا بى‌نياز است و شما نيازمنديد؛ و اگر روى برتابيد [خدا] جاى شما را به مردمى غير از شما خواهد داد كه مانند شما نخواهند بود.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxiv{\basmalahfa ما تو را پيروزى بخشيديم [چه‌] پيروزى درخشانى!\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxv{تا خداوند از گناه گذشته و آينده تو درگذرد و نعمت خود را بر تو تمام گرداند و تو را به راهى راست هدايت كند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxvi{و تو را به نصرتى ارجمند يارى نمايد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxvii{اوست آن كس كه در دلهاى مؤمنان آرامش را فرو فرستاد تا ايمانى بر ايمان خود بيفزايند. و سپاهيان آسمانها و زمين از آن خداست، و خدا همواره داناى سنجيده‌كار است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxviii{تا مردان و زنانى را كه ايمان آورده‌اند در باغهايى كه از زير [درختان‌] آن جويبارها روان است، درآورد و در آن جاويدان بدارد، و بديهايشان را از آنان بزدايد؛ و اين [فرجام نيك‌] در پيشگاه خدا كاميابى بزرگى است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdlxxxix{و [تا] مردان و زنان نفاق‌پيشه و مردان و زنان مشرك را كه به خدا گمان بد برده‌اند، عذاب كند؛ بد زمانه بر آنان باد. و خدا بر ايشان خشم نموده و لعنتشان كرده و جهنم را براى آنان آماده گردانيده و [چه‌] بد سرانجامى است،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdxc{و سپاهيان آسمانها و زمين از آن خداست، و خدا همواره شكست‌ناپذير سنجيده‌كار است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdxci{[اى پيامبر،] ما تو را [به سمت‌] گواه و بشارتگر و هشداردهنده‌اى فرستاديم.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdxcii{تا به خدا و فرستاده‌اش ايمان آوريد و او را يارى كنيد و ارجش نهيد، و [خدا] را بامدادان و شامگاهان به پاكى بستاييد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdxciii{در حقيقت، كسانى كه با تو بيعت مى‌كنند، جز اين نيست كه با خدا بيعت مى‌كنند؛ دست خدا بالاى دستهاى آنان است. پس هر كه پيمان‌شكنى كند، تنها به زيان خود پيمان مى‌شكند، و هر كه بر آنچه با خدا عهد بسته وفادار بماند، به زودى خدا پاداشى بزرگ به او مى‌بخشد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdxciv{برجاى‌ماندگان باديه‌نشين به زودى به تو خواهند گفت: «اموال ما و كسانمان ما را گرفتار كردند، براى ما آمرزش بخواه.» چيزى را كه در دلهايشان نيست بر زبان خويش مى‌رانند. بگو: «اگر خدا بخواهد به شما زيانى يا سودى برساند چه كسى در برابر او براى شما اختيار چيزى را دارد؟ بلكه [اين‌] خداست كه به آنچه مى‌كنيد همواره آگاه است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdxcv{[نه چنان بود،] بلكه پنداشتيد كه پيامبر و مؤمنان هرگز به خانمان خود بر نخواهند گشت، و اين [پندار] در دلهايتان نمودى خوش يافت، و گمان بد كرديد، و شما مردمى در خور هلاكت بوديد.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdxcvi{و هر كس به خدا و پيامبر او ايمان نياورده است [بداند كه‌] ما براى كافران آتشى سوزان آماده كرده‌ايم.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdxcvii{و فرمانروايى آسمانها و زمين از آن خداست: هر كه را بخواهد مى‌بخشايد و هر كه را بخواهد عذاب مى‌كند، و خدا همواره آمرزنده مهربان است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdxcviii{چون به [قصد] گرفتن غنايم روانه شديد، به زودى برجاى‌ماندگان خواهند گفت: «بگذاريد ما [هم‌] به دنبال شما بياييم.» [اين گونه‌] مى‌خواهند دستور خدا را دگرگون كنند. بگو: «هرگز از پى ما نخواهيد آمد. آرى، خدا از پيش در باره شما چنين فرموده.» پس به زودى خواهند گفت: «[نه،] بلكه بر ما رشگ مى‌بريد.» [نه چنين است‌] بلكه جز اندكى درنمى‌يابند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdxcix{به برجاى‌ماندگان باديه‌نشين بگو: «به زودى به سوى قومى سخت زورمند دعوت خواهيد شد كه با آنان بجنگيد يا اسلام آورند. پس اگر فرمان بريد خدا شما را پاداش نيك مى‌بخشد، و اگر -همچنان كه پيشتر پشت كرديد- [باز هم‌] روى بگردانيد، شما را به عذابى پردرد معذب مى‌دارد.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdc{بر نابينا گناهى نيست و بر لنگ گناهى نيست و بر بيمار گناهى نيست [كه در جهاد شركت نكنند]؛ و هر كس خدا و پيامبر او را فرمان برد، وى را در باغهايى كه از زير [درختان‌] آن نهرهايى روان است درمى‌آورد، و هر كس روى برتابد، به عذابى دردناك معذبش مى‌دارد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdci{به راستى خدا هنگامى كه مؤمنان، زير آن درخت با تو بيعت مى‌كردند از آنان خشنود شد، و آنچه در دلهايشان بود بازشناخت و بر آنان آرامش فرو فرستاد و پيروزى نزديكى به آنها پاداش داد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdcii{و [نيز] غنيمتهاى فراوانى خواهند گرفت، و خدا همواره نيرومند سنجيده‌كار است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmdciii{و خدا به شما غنيمتهاى فراوان [ديگرى‌] وعده داده كه به زودى آنها را خواهيد گرفت، و اين [پيروزى‌] را براى شما پيش انداخت، و دستهاى مردم را از شما كوتاه ساخت، و تا براى مؤمنان نشانه‌اى باشد و شما را به راه راست هدايت كند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmdciv{و [غنيمتهاى‌] ديگر[ى نيز هست‌] كه شما بر آنها دست نيافته‌ايد [و] خدا بر آنها نيك احاطه دارد، و همواره خداوند بر هر چيزى تواناست.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmdcv{و اگر كسانى كه كافر شدند، به جنگ با شما برخيزند، قطعاً پشت خواهند كرد، و ديگر يار و ياورى نخواهند يافت.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmdcvi{سنّت الهى از پيش همين بوده، و در سنّت الهى هرگز تغييرى نخواهى يافت.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmdcvii{و اوست همان كسى كه در دل مكه -پس از پيروزكردن شما بر آنان- دستهاى آنها را از شما و دستهاى شما را از ايشان كوتاه گردانيد، و خدا به آنچه مى‌كنيد همواره بيناست.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmdcviii{آنها بودند كه كفر ورزيدند و شما را از مسجد الحرام بازداشتند و نگذاشتند قربانى [شما] كه بازداشته شده بود به محلش برسد، و اگر [در مكه‌] مردان و زنان با ايمانى نبودند كه [ممكن بود] بى‌آنكه آنان را بشناسيد، ندانسته پايمالشان كنيد و تاوانشان بر شما بماند [فرمان حمله به مكه مى‌داديم‌] تا خدا هر كه را بخواهد در جوار رحمت خويش درآورد. اگر [كافر و مؤمن‌] از هم متمايز مى‌شدند، قطعاً كافران را به عذاب دردناكى معذب مى‌داشتيم.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmdcix{آنگاه كه كافران در دلهاى خود، تعصّب [آن هم‌] تعصّب جاهليّت ورزيدند، پس خدا آرامش خود را بر فرستاده خويش و بر مؤمنان فرو فرستاد، و آرمان تقوا را ملازم آنان ساخت، و [در واقع‌] آنان به [رعايت ]آن [آرمان‌] سزاوارتر و شايسته [اتصاف به‌] آن بودند، و خدا همواره بر هر چيزى داناست.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmdcx{حقاً خدا رؤياى پيامبر خود را تحقّق بخشيد [كه ديده بود:] شما بدون شكّ، به خواست خدا در حالى كه سر تراشيده و موى [و ناخن‌] كوتاه كرده‌ايد، با خاطرى آسوده در مسجد الحرام درخواهيد آمد. خدا آنچه را كه نمى‌دانستيد دانست، و غير از اين، پيروزى نزديكى [براى شما] قرار داد.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdcxi{اوست كسى كه پيامبر خود را به [قصد] هدايت، با آيين درست روانه ساخت، تا آن را بر تمام اديان پيروز گرداند و گواه‌بودن خدا كفايت مى‌كند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdcxii{محمد [ص‌] پيامبر خداست؛ و كسانى كه با اويند، بر كافران، سختگير [و] با همديگر مهربانند. آنان را در ركوع و سجود مى‌بينى. فضل و خشنودى خدا را خواستارند. علامت [مشخصّه‌] آنان بر اثر سجود در چهره‌هايشان است. اين صفت ايشان است در تورات، و مثَل آنها در انجيل چون كشته‌اى است كه جوانه خود برآورد و آن را مايه دهد تا ستبر شود و بر ساقه‌هاى خود بايستد و دهقانان را به شگفت آورد، تا از [انبوهى‌] آنان [خدا] كافران را به خشم دراندازد. خدا به كسانى از آنان كه ايمان آورده و كارهاى شايسته كرده‌اند، آمرزش و پاداش بزرگى وعده داده‌است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdcxiii{\basmalahfa اى كسانى كه ايمان آورده‌ايد، در برابر خدا و پيامبرش [در هيچ كارى‌] پيشى مجوييد و از خدا پروا بداريد كه خدا شنواى داناست.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdcxiv{اى كسانى كه ايمان آورده‌ايد، صدايتان را بلندتر از صداى پيامبر مكنيد، و همچنانكه بعضى از شما با بعضى ديگر بلند سخن مى‌گوييد با او به صداى بلند سخن مگوييد، مبادا بى‌آنكه بدانيد كرده‌هايتان تباه شود.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdcxv{كسانى كه پيش پيامبر خدا صدايشان را فرو مى‌كشند همان كسانند كه خدا دلهايشان را براى پرهيزگارى امتحان كرده است؛ آنان را آمرزش و پاداشى بزرگ است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdcxvi{كسانى كه تو را از پشت اتاقها[ى مسكونى تو] به فرياد مى‌خوانند، بيشترشان نمى‌فهمند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdcxvii{و اگر صبر كنند تا بر آنان درآيى، مسلماً برايشان بهتر است و خدا آمرزنده و مهربان است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdcxviii{اى كسانى كه ايمان آورده‌ايد، اگر فاسقى برايتان خبرى آورد، نيك وارسى كنيد، مبادا به نادانى گروهى را آسيب برسانيد و [بعد،] از آنچه كرده‌ايد پشيمان شويد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdcxix{و بدانيد كه پيامبر خدا در ميان شماست. اگر در بسيارى از كارها از [رأى و ميل‌] شما پيروى كند، قطعاً دچار زحمت مى‌شويد، ليكن خدا ايمان را براى شما دوست‌داشتنى گردانيد و آن را در دلهاى شما بياراست و كفر و پليدكارى و سركشى را در نظرتان ناخوشايند ساخت. آنان [كه چنين‌اند] ره‌يافتگانند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdcxx{[و اين‌] بخششى از خدا و نعمتى [از اوست‌]، و خدا داناى سنجيده‌كار است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxi{و اگر دو طايفه از مؤمنان با هم بجنگند، ميان آن دو را اصلاح دهيد، و اگر [باز] يكى از آن دو بر ديگرى تعدّى كرد، با آن [طايفه‌اى‌] كه تعدّى مى‌كند بجنگيد تا به فرمان خدا بازگردد. پس اگر باز گشت، ميان آنها را دادگرانه سازش دهيد و عدالت كنيد، كه خدا دادگران را دوست مى‌دارد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxii{در حقيقت مؤمنان با هم برادرند، پس ميان برادرانتان را سازش دهيد و از خدا پروا بداريد، اميد كه مورد رحمت قرار گيريد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxiii{اى كسانى كه ايمان آورده‌ايد، نبايد قومى قوم ديگر را ريشخند كند، شايد آنها از اينها بهتر باشند، و نبايد زنانى زنان [ديگر] را [ريشخند كنند ]، شايد آنها از اينها بهتر باشند، و از يكديگر عيب مگيريد، و به همديگر لقبهاى زشت مدهيد؛ چه ناپسنديده است نام زشت پس از ايمان. و هر كه توبه نكرد آنان خود ستمكارند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxiv{اى كسانى كه ايمان آورده‌ايد، از بسيارى از گمانها بپرهيزيد كه پاره‌اى از گمانها گناه است، و جاسوسى مكنيد، و بعضى از شما غيبت بعضى نكند؛ آيا كسى از شما دوست دارد كه گوشت برادر مرده‌اش را بخورد؟ از آن كراهت داريد. [پس‌] از خدا بترسيد، كه خدا توبه‌پذير مهربان است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxv{اى مردم، ما شما را از مرد و زنى آفريديم، و شما را ملّت ملّت و قبيله قبيله گردانيديم تا با يكديگر شناسايى متقابل حاصل كنيد. در حقيقت ارجمندترين شما نزد خدا پرهيزگارترين شماست. بى‌ترديد، خداوند داناى آگاه است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxvi{[برخى از] باديه‌نشينان گفتند: «ايمان آورديم.» بگو: «ايمان نياورده‌ايد، ليكن بگوييد: اسلام آورديم. و هنوز در دلهاى شما ايمان داخل نشده است. و اگر خدا و پيامبر او را فرمان بريد از [ارزش‌] كرده‌هايتان چيزى كم نمى‌كند. خدا آمرزنده مهربان است.»\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxvii{در حقيقت، مؤمنان كسانى‌اند كه به خدا و پيامبر او گرويده و [ديگر] شكّ نياورده و با مال و جانشان در راه خدا جهاد كرده‌اند؛ اينانند كه راستكردارند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxviii{بگو: «آيا خدا را از دين‌[دارى‌] خود خبر مى‌دهيد؟ و حال آنكه خدا آنچه را كه در زمين است مى‌داند، و خدا به همه چيز داناست.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxix{از اينكه اسلام آورده‌اند بر تو منّت مى‌نهند؛ بگو: «بر من از اسلام‌آوردنتان منّت مگذاريد، بلكه [اين‌] خداست كه با هدايت‌كردن شما به ايمان، بر شما منّت مى‌گذارد، اگر راستگو باشيد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxx{خداست كه نهفته آسمانها و زمين را مى‌داند و خدا[ست كه‌] به آنچه مى‌كنيد بيناست.»\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxi{\basmalahfa قاف، سوگند به قرآن باشكوه،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxii{[كه آنان نگرويدند،] بلكه از اينكه هشداردهنده‌اى از خودشان برايشان آمد، در شگفت شدند و كافران گفتند: «اين [محمّد و حكايت معاد] چيزى عجيب است»\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxiii{«آيا چون مُرديم و خاك شديم [زنده مى‌شويم‌]؟ اين بازگشتى بعيد است.»\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxiv{قطعاً دانسته‌ايم كه زمين [چه مقدار] از اجسادشان فرو مى‌كاهد. و پيش ما كتاب ضبطكننده‌اى است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxv{[نه،] بلكه حقيقت را، وقتى برايشان آمد، دروغ خواندند، و آنها در كارى سردرگم [مانده‌]اند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxvi{مگر به آسمان بالاى سرشان ننگريسته‌اند كه چگونه آن را ساخته و زينتش داده‌ايم و براى آن هيچ گونه شكافتگى نيست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxvii{و زمين را گسترديم و در آن لنگر[آسا كوه‌]ها فرو افكنديم و در آن از هر گونه جفت دل‌انگيز رويانيديم.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxviii{[تا] براى هر بنده توبه‌كارى بينش‌افزا و پندآموز باشد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdcxxxix{و از آسمان، آبى پر بركت فرود آورديم، پس بدان [وسيله‌] باغها و دانه‌هاى دروكردنى رويانيديم.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdcxl{و درختان تناور خرما كه خوشه‌[هاى‌] روى هم چيده دارند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdcxli{[اينها همه‌] براى روزىِ بندگان [من‌] است، و با آن [آب‌] سرزمين مرده‌اى را زنده گردانيديم؛ رستاخيز [نيز] چنين است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdcxlii{پيش از ايشان قوم نوح و اصحاب رَسّ و ثمود،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdcxliii{و عاد و فرعون و برادران لوط،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdcxliv{و بيشه‌نشينان و قوم تُبّع به تكذيب پرداختند؛ همگى فرستادگان [ما] را به دروغ گرفتند و [در نتيجه‌] تهديد [من‌] واجب آمد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdcxlv{مگر از آفرينش نخستين [خود] به تنگ آمديم؟ [نه!] بلكه آنها از خلق جديد در شبهه‌اند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdcxlvi{و ما انسان را آفريده‌ايم و مى‌دانيم كه نفس او چه وسوسه‌اى به او مى‌كند، و ما از شاهرگ [او] به او نزديكتريم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdcxlvii{آنگاه كه دو [فرشته‌] دريافت‌كننده از راست و از چپ، مراقب نشسته‌اند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdcxlviii{[آدمى‌] هيچ سخنى را به لفظ درنمى‌آورد مگر اينكه مراقبى آماده نزد او [آن را ضبط مى‌كند].\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdcxlix{و سكرات مرگ، به راستى در رسيد؛ اين همان است كه از آن مى‌گريختى؛\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmdcl{و در صور دميده شود؛ اين است روز تهديد [من‌].\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmdcli{و هر كسى مى‌آيد [در حالى كه‌] با او سوق‌دهنده و گواهى‌دهنده‌اى است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmdclii{[به او مى‌گويند:] «واقعاً كه از اين [حال‌] سخت در غفلت بودى. و[لى‌] ما پرده‌ات را [از جلوى چشمانت‌] برداشتيم و ديده‌ات امروز تيز است.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmdcliii{و [فرشته‌] همنشين او مى‌گويد: «اين است آنچه پيش من آماده است [و ثبت كرده‌ام‌].»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmdcliv{[به آن دو فرشته خطاب مى‌شود:] «هر كافر سرسختى را در جهنم فروافكنيد،\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmdclv{[هر] بازدارنده از خيرى، [هر] متجاوز شكاكى\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmdclvi{كه با خداوند، خدايى ديگر قرار داد. [اى دو فرشته،] او را در عذاب شديد فرو افكنيد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmdclvii{[شيطان‌] همدمش مى‌گويد: «پروردگار ما، من او را به عصيان وانداشتم، ليكن [خودش‌] در گمراهى دور و درازى بود.»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdclviii{[خدا] مى‌فرمايد: «در پيشگاه من با همديگر مستيزيد [كه‌] از پيش به شما هشدار داده بودم.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdclix{پيش من حكم دگرگون نمى‌شود، و من [نسبت‌] به بندگانم بيدادگر نيستم.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdclx{آن روز كه [ما] به دوزخ مى‌گوييم: «آيا پر شدى؟» و مى‌گويد: «آيا باز هم هست؟»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmdclxi{و بهشت را براى پرهيزگاران نزديك گردانند، بى‌آنكه دور باشد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmdclxii{[و به آنان گويند:] اين همان است كه وعده يافته‌ايد [و] براى هر توبه‌كار نگهبان [حدود خدا] خواهد بود:\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmdclxiii{آنكه در نهان از خداى بخشنده بترسد و با دلى توبه‌كار [باز] آيد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmdclxiv{به سلامت [و شادكامى‌] در آن درآييد [كه‌] اين روز جاودانگى است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmdclxv{هر چه بخواهند در آنجا دارند، و پيش ما فزونتر [هم‌] هست.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmdclxvi{و چه بسا نسلها كه پيش از ايشان هلاك كرديم كه [بس‌] نيرومندتر از اينان بودند و در شهرها پرسه زده بودند [اما سرانجام‌] مگر گريزگاهى بود؟\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmdclxvii{قطعاً در اين [عقوبتها] براى هر صاحبدل و حق نيوشى كه خود به گواهى ايستد، عبرتى است.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmdclxviii{و در حقيقت، آسمانها و زمين و آنچه را كه ميان آن دو است در شش هنگام آفريديم و احساس ماندگى نكرديم.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmdclxix{و بر آنچه مى‌گويند صبر كن، و پيش از برآمدن آفتاب و پيش از غروب، به ستايش پروردگارت تسبيح گوى.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmdclxx{و پاره‌اى از شب و به دنبال سجود [به صورت تعقيب و نافله‌] او را تسبيح گوى.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxi{و روزى كه منادى از جايى نزديك ندا درمى‌دهد، به گوش باش.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxii{روزى كه فرياد [رستاخيز] را به حق مى‌شنوند، آن [روز] روز بيرون آمدن [از زمين‌] است.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxiii{ماييم كه خود، زندگى مى‌بخشيم و به مرگ مى‌رسانيم و برگشت به سوى ماست.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxiv{روزى كه زمين به سرعت از [اجساد] آنان جدا و شكافته مى‌شود؛ اين حشرى است كه بر ما آسان خواهد بود.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxv{ما به آنچه مى‌گويند داناتريم، و تو به زور وادارنده آنان نيستى؛ پس به [وسيله‌] قرآن هر كه را از تهديد [من‌] مى‌ترسد پند ده.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxvi{\basmalahfa سوگند به بادهاى ذره‌افشان،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxvii{و ابرهاى گرانبار،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxviii{و سبك سيران،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxix{و تقسيم‌كنندگان كار[ها]،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxx{كه آنچه وعده داده شده‌ايد راست است،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxi{و [روز] پاداش واقعيت دارد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxii{سوگند به آسمان مشبّك،\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxiii{كه شما [درباره قرآن‌] در سخنى گوناگونيد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxiv{[بگوى‌] تا هر كه از آن برگشته، برگشته باشد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxv{مرگ بر دروغپردازان!\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxvi{همانان كه در ورطه نادانى بى‌خبرند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxvii{پرسند: «روز پاداش كى است؟»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxviii{همان روز كه آنان بر آتش، عقوبت [و آزموده‌] شوند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdclxxxix{عذاب [موعود] خود را بچشيد، اين است همان [بلايى‌] كه با شتاب خواستار آن بوديد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdcxc{پرهيزگاران در باغها و چشمه سارانند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdcxci{آنچه را پروردگارشان عطا فرموده مى‌گيرند، زيرا كه آنها پيش از اين نيكوكار بودند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdcxcii{و از شب اندكى را مى‌غنودند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdcxciii{و در سحرگاهان [از خدا] طلب آمرزش مى‌كردند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdcxciv{و در اموالشان براى سائل و محروم حقى [معين‌] بود.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmdcxcv{و روى زمين براى اهل يقين نشانه‌هايى [متقاعدكننده‌] است،\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmdcxcvi{و در خود شما؛ پس مگر نمى‌بينيد؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmdcxcvii{و روزى شما و آنچه وعده داده شده‌ايد در آسمان است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmdcxcviii{پس سوگند به پروردگار آسمان و زمين، كه واقعاً او حق است همان گونه كه خود شما سخن مى‌گوييد.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmdcxcix{آيا خبر مهمانان ارجمند ابراهيم به تو رسيد؟\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmdcc{چون بر او درآمدند؛ پس سلام گفتند. گفت: «سلام، مردمى ناشناسيد.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmdcci{پس آهسته به سوى زنش رفت و گوساله‌اى فربه [و بريان‌] آورد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmdccii{آن را به نزديكشان برد [و] گفت: «مگر نمى‌خوريد؟»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdcciii{و [در دلش‌] از آنان احساس ترسى كرد. گفتند: «مترس.» و او را به پسرى دانا مژده دادند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdcciv{و زنش با فريادى [از شگفتى‌] سر رسيد و بر چهره خود زد و گفت: «زنى پير نازا [چگونه بزايد]؟»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdccv{گفتند: «پروردگارت چنين فرموده است. او خود حكيم داناست.»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmdccvi{[ابراهيم‌] گفت: «اى فرستادگان، مأموريت شما چيست؟»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmdccvii{گفتند: «ما به سوى مردمى پليدكار فرستاده شده‌ايم،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmdccviii{تا سنگهايى از گِل رُس بر [سر] آنان فرو فرستيم.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmdccix{[كه‌] نزد پروردگارت براى مسرفان نشان‌گذارى شده است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmdccx{پس هر كه از مؤمنان در آن [شهرها] بود بيرون برديم.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmdccxi{و[لى‌] در آنجا جز يك خانه از فرمانبران [خدا بيشتر] نيافتيم.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmdccxii{و در آنجا براى آنها كه از عذاب پر درد مى‌ترسند، عبرتى به جاى گذاشتيم.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmdccxiii{و [نيز] در [ماجراى‌] موسى، چون او را با حجتى آشكار به سوى فرعون گسيل داشتيم.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmdccxiv{پس [فرعون‌] با اركان [دولت‌] خود روى برتافت و گفت: «[اين شخص،] ساحر يا ديوانه‌اى است.»\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmdccxv{[تا] او و سپاهيانش را گرفتيم و آنان را در دريا افكنديم در حالى كه او [در آخرين لحظه‌] نكوهشگر [خود] بود.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmdccxvi{و در [ماجراى‌] عاد [نيز]، چون بر [سر] آنها آن باد مُهلِك را فرستاديم.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmdccxvii{به هر چه مى‌وزيد آن را چون خاكستر استخوان مرده مى‌گردانيد.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmdccxviii{و در [ماجراى‌] ثمود [نيز عبرتى بود]، آنگاه كه به ايشان گفته شد: «تا چندى برخوردار شويد.»\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmdccxix{تا [آنكه‌] از فرمان پروردگار خود سر برتافتند و در حالى كه آنها مى‌نگريستند، آذرخش آنان را فرو گرفت.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmdccxx{در نتيجه نه توانستند به پاى خيزند و نه طلب يارى كنند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxi{و قوم نوح [نيز] پيش از آن [اقوام نامبرده همين گونه هلاك شدند]، زيرا آنها مردمى نافرمان بودند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxii{و آسمان را به قدرت خود برافراشتيم، و بى‌گمان، ما [آسمان‌]گستريم!\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxiii{و زمين را گسترانيده‌ايم و چه نيكو گسترندگانيم.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxiv{و از هر چيزى دو گونه [يعنى نر و ماده‌] آفريديم، اميد كه شما عبرت گيريد.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxv{پس به سوى خدا بگريزيد، كه من شما را از طرف او بيم‌دهنده‌اى آشكارم.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxvi{و با خدا معبودى ديگر قرار مدهيد كه من از جانب او هشداردهنده‌اى آشكارم.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxvii{بدين سان بر كسانى كه پيش از آنها بودند هيچ پيامبرى نيامد جز اينكه گفتند: «ساحر يا ديوانه‌اى است.»\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxviii{آيا همديگر را به اين [سخن‌] سفارش كرده بودند؟ [نه!] بلكه آنان مردمى سركش بودند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxix{پس، از آنان روى بگردان، كه تو در خور نكوهش نيستى.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxx{و پند ده، كه مؤمنان را پند سود بخشد.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxi{و جن و انس را نيافريدم جز براى آنكه مرا بپرستند.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxii{از آنان هيچ روزيى نمى‌خواهم، و نمى‌خواهم كه مرا خوراك دهند.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxiii{خداست كه خود روزى بخش نيرومند استوار است.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxiv{پس براى كسانى كه ستم كردند بهره‌اى است از عذاب، همانند بهره عذاب ياران [قبلى‌]شان. پس [بگو:] در خواستن عذاب از من، شتابزدگى نكنند.\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxv{پس واى بر كسانى كه كافر شده‌اند از آن روزى كه وعده يافته‌اند.\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxvi{\basmalahfa سوگند به طور،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxvii{و كتابى نگاشته شده،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxviii{در طومارى گسترده؛\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdccxxxix{سوگند به آن خانه آباد [خدا]؛\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdccxl{سوگند به بام بلند [آسمان‌]،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdccxli{و آن درياى سرشار [و افروخته‌]،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdccxlii{كه عذاب پروردگارت واقع‌شدنى است؛\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdccxliii{آن را هيچ بازدارنده‌اى نيست.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdccxliv{روزى كه آسمان سخت در تب و تاب افتد،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdccxlv{و كوهها [جمله‌] به حركت درآيند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdccxlvi{پس واى بر تكذيب‌كنندگان در آن روز.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdccxlvii{آنان كه به ياوه سرگرمند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdccxlviii{روزى كه به سوى آتش جهنم كشيده مى‌شوند [چه‌] كشيدنى.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdccxlix{[و به آنان گويند:] «اين همان آتشى است كه دروغش مى‌پنداشتيد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdccl{آيا اين افسون است؟ يا شما [درست‌] نمى‌بينيد؟\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdccli{به آن درآييد؛ خواه بشكيبيد يا نشكيبيد، به حال شما يكسان است. تنها به آنچه مى‌كرديد مجازات مى‌يابيد.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdcclii{پرهيزگاران در باغهايى و [در] ناز و نعمتند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdccliii{به آنچه پروردگارشان به آنان داده دلشادند، و پروردگارشان آنها را از عذاب دوزخ مصون داشته است.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdccliv{[به آنان گويند:] «به [پاداش‌] آنچه به جاى مى‌آورديد بخوريد و بنوشيد؛ گواراتان باد!»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmdcclv{بر تختهايى رديف هم تكيه زده‌اند و حوران درشت‌چشم را همسر آنان گردانده‌ايم.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmdcclvi{و كسانى كه گرويده و فرزندانشان آنها را در ايمان پيروى كرده‌اند، فرزندانشان را به آنان ملحق خواهيم كرد و چيزى از كار[ها]شان را نمى‌كاهيم. هر كسى در گرو دستاورد خويش است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmdcclvii{با [هر نوع‌] ميوه و گوشتى كه دلخواه آنهاست آنان را مدد [و تقويت‌] مى‌كنيم.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmdcclviii{در آنجا جامى از دست هم مى‌ربايند [و بر سرش همچشمى مى‌كنند] كه در آن نه ياوه گويى است و نه گناه.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmdcclix{و براى [خدمت‌] آنان پسرانى است كه بر گردشان همى‌گردند، انگارى آنها مرواريدى‌اند كه [در صدف‌] نهفته است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmdcclx{و برخى‌شان رو به برخى كنند [و] از هم پرسند،\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxi{گويند: «ما پيشتر در ميان خانواده خود بيمناك بوديم.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxii{پس خدا بر ما منت نهاد و ما را از عذاب گرم [مرگبار] حفظ كرد.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxiii{ما از ديرباز او را مى‌خوانديم، كه او همان نيكوكار مهربان است.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxiv{پس اندرز ده كه تو به لطف پروردگارت نه كاهنى و نه ديوانه.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxv{يا مى‌گويند: «شاعرى است كه انتظار مرگش را مى‌بريم [و چشم به راه بد زمانه بر اوييم‌].»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxvi{بگو: «منتظر باشيد كه من [نيز] با شما از منتظرانم.»\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxvii{آيا پندارهايشان آنان را به اين [موضعگيرى‌] وا مى‌دارد يا [نه،] آنها مردمى سركشند؟\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxviii{يا مى‌گويند: «آن را بربافته.» [نه،] بلكه باور ندارند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxix{پس اگر راست مى‌گويند، سخنى مثل آن بياورند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxx{آيا از هيچ خلق شده‌اند؟ يا آنكه خودشان خالق [خود] هستند؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxi{آيا آسمانها و زمين را [آنان‌] خلق كرده‌اند؟ [نه،] بلكه يقين ندارند.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxii{آيا ذخاير پروردگار تو پيش آنهاست؟ يا ايشان تسلط [تام‌] دارند؟\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxiii{آيا نردبانى دارند كه بر آن [بر شوند و] بشنوند؟ پس بايد شنونده آنان برهانى آشكار بياورد.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxiv{آيا خدا را دختران است و شما را پسران؟\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxv{آيا از آنها مزدى مطالبه مى‌كنى و آنان از [تعهّد اداى‌] تاوان گرانبارند؟\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxvi{آيا [علم‌] غيب پيش آنهاست و آنها مى‌نويسند؟\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxvii{يا مى‌خواهند نيرنگى بزنند؟ و [لى‌] آنان كه كافر شده‌اند، خود دچار نيرنگ شده‌اند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxviii{آيا ايشان را جز خدا معبودى است؟ منزّه است خدا از آنچه [با او] شريك مى‌گردانند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxix{و اگر پاره‌سنگى را در حال سقوط از آسمان ببينند مى‌گويند: «ابرى متراكم است.»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxx{پس بگذارشان تا به آن روزى كه در آن بيهوش مى‌افتند برسند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxi{روزى كه نيرنگشان به هيچ‌وجه به كارشان نيايد و حمايت نيابند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxii{و در حقيقت، غير از اين [مجازات‌]، عذابى [ديگر] براى كسانى كه ظلم كرده‌اند خواهد بود، ولى بيشترشان نمى‌دانند [كه آن عذاب چيست‌].\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxiii{و در برابر دستور پروردگارت شكيبايى پيشه كن كه تو خود در حمايت مايى و هنگامى كه [از خواب‌] بر مى‌خيزى به نيايش پروردگارت تسبيح گوى.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxiv{و [نيز] پاره‌اى از شب، و در فروشدن ستارگان تسبيح‌گوى او باش.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxv{\basmalahfa سوگند به اختر [= قرآن‌] چون فرود مى‌آيد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxvi{[كه‌] يار شما نه گمراه شده و نه در نادانى مانده؛\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxvii{و از سر هوس سخن نمى‌گويد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxviii{اين سخن بجز وحيى كه وحى مى‌شود نيست.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdcclxxxix{آن را [فرشته‌] شديدالقوى به او فرا آموخت،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdccxc{[سروش‌] نيرومندى كه [مسلّط] درايستاد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdccxci{در حالى كه او در افق اعلى بود؛\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdccxcii{سپس نزديك آمد و نزديكتر شد،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdccxciii{تا [فاصله‌اش‌] به قدر [طول‌] دو [انتهاى‌] كمان يا نزديكتر شد؛\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdccxciv{آنگاه به بنده‌اش آنچه را بايد وحى كند، وحى فرمود.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdccxcv{آنچه را دل ديد انكار[ش‌] نكرد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdccxcvi{آيا در آنچه ديده است با او جدال مى‌كنيد؟\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdccxcvii{و قطعاً بار ديگرى هم او را ديده است،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdccxcviii{نزديك سدرالمنتهى،\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdccxcix{در همان جا كه جنةالمأوى است.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdccc{آنگاه كه درخت سدر را آنچه پوشيده بود، پوشيده بود.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdccci{ديده [اش‌] منحرف نگشت و [از حدّ] در نگذشت.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdcccii{به راستى كه [برخى‌] از آيات بزرگ پروردگار خود را بديد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdccciii{به من خبر دهيد از لات و عزّى،\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmdccciv{و منات آن سومين ديگر،\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmdcccv{آيا [به خيالتان‌] براى شما پسر است و براى او دختر؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmdcccvi{در اين صورت، اين تقسيم نادرستى است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmdcccvii{[اين بتان‌] جز نامهايى بيش نيستند كه شما و پدرانتان نامگذارى كرده‌ايد [و] خدا بر [حقّانيّت‌] آنها هيچ دليلى نفرستاده است. [آنان‌] جز گمان و آنچه را كه دلخواهشان است پيروى نمى‌كنند، با آنكه قطعاً از جانب پروردگارشان هدايت برايشان آمده است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmdcccviii{مگر انسان آنچه را آرزو كند دارد؟\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmdcccix{آن سرا و اين سرا از آن خداست.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmdcccx{و بسا فرشتگانى كه در آسمانهايند [و] شفاعتشان به كارى نيايد، مگر پس از آنكه خدا به هر كه خواهد و خشنود باشد اذن دهد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxi{در حقيقت، كسانى كه آخرت را باور ندارند، فرشتگان را در نامگذارى به صورت مؤنّث نام مى‌نهند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxii{و ايشان را به اين [كار] معرفتى نيست. جز گمان [خود] را پيروى نمى‌كنند، و در واقع، گمان در [وصول به‌] حقيقت هيچ سودى نمى‌رساند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxiii{پس، از هر كس كه از ياد ما روى برتافته و جز زندگى دنيا را خواستار نبوده است، روى برتاب.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxiv{اين منتهاى دانش آنان است. پروردگار تو، خود به [حال‌] كسى كه از راه او منحرف شده داناتر، و او به كسى كه راه يافته [نيز] آگاه‌تر است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxv{و هر چه در آسمانها و هر چه در زمين است از آن خداست، تا كسانى را كه بد كرده‌اند، به [سزاى‌] آنچه انجام داده‌اند كيفر دهد، و آنان را كه نيكى كرده‌اند، به نيكى پاداش دهد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxvi{آنان كه از گناهان بزرگ و زشتكاريها -جز لغزشهاى كوچك- خوددارى مى‌ورزند، پروردگارت [نسبت به آنها] فراخ‌آمرزش است. وى از آن دم كه شما را از زمين پديد آورد و از همان‌گاه كه در شكمهاى مادرانتان [در زهدان‌] نهفته بوديد به [حال ]شما داناتر است، پس خودتان را پاك مشماريد. او به [حال‌] كسى كه پرهيزگارى نموده داناتر است.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxvii{پس آيا آن كسى را كه [از جهاد] روى برتافت ديدى؟\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxviii{و اندكى بخشيد و [از باقى‌] امتناع ورزيد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxix{آيا علم غيب پيش اوست و او مى‌بيند؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxx{يا بدانچه در صحيفه‌هاى موسى [آمده‌] خبر نيافته است؟\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxi{و [نيز در نوشته‌هاى‌] همان ابراهيمى كه وفا كرد:\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxii{كه هيچ بردارنده‌اى بار گناه ديگرى را بر نمى‌دارد.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxiii{و اينكه براى انسان جز حاصل تلاش او نيست.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxiv{و [نتيجه‌] كوشش او به زودى ديده خواهد شد.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxv{سپس هر چه تمامتر وى را پاداش دهند.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxvi{و اينكه پايان [كار] به سوى پروردگار توست.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxvii{و هم اوست كه مى‌خنداند و مى‌گرياند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxviii{و هم اوست كه مى‌ميراند و زنده مى‌گرداند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxix{و هم اوست كه دو نوع مى‌آفريند: نر و ماده،\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxx{از نطفه‌اى چون فرو ريخته شود.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxi{و هم پديد آوردن [عالم‌] ديگر بر [عهده‌] اوست.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxii{و هم اوست كه [شما را] بى‌نياز كرد و سرمايه بخشيد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxiii{و هم اوست پروردگار ستاره «شِعرى».\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxiv{و هم اوست كه عاديان قديم را هلاك كرد.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxv{و ثمود را [نيز هلاك كرد] و [كسى را] باقى نگذاشت.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxvi{و پيشتر [از همه آنها] قوم نوح را، زيرا كه آنان ستمگرتر و سركش‌تر بودند.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxvii{و شهرها[ى سَدوم و عاموره‌] را فرو افكند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxviii{پوشاند بر آن [دو شهر، از باران گوگردى‌] آنچه را پوشاند.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxxxix{پس به كدام يك از نعمتهاى پروردگارت ترديد روا مى‌دارى؟\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxl{اين [پيامبر نيز] بيم‌دهنده‌اى از [جمله‌] بيم‌دهندگان نخستين است.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxli{[وه چه‌] نزديك گشت قيامت.\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxlii{جز خدا كسى آشكاركننده آن نيست.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxliii{آيا از اين سخن عجب داريد؟\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxliv{و مى‌خنديد و نمى‌گرييد؟\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxlv{و شما در غفلتيد.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxlvi{پس خدا را سجده كنيد و بپرستيد.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxlvii{\basmalahfa نزديك شد قيامت و از هم شكافت ماه.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxlviii{و هر گاه نشانه‌اى ببينند روى بگردانند و گويند: «سحرى دايم است.»\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxlix{و به تكذيب دست زدند و هوسهاى خويش را دنبال كردند، و [لى‌] هر كارى را [آخر] قرارى است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmdcccl{و قطعاً از اخبار، آنچه در آن مايه انزجار [از كفر] است به ايشان رسيد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmdcccli{حكمت بالغه [حق اين بود]، ولى هشدارها سود نكرد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmdccclii{پس، از آنان روى برتاب. روزى كه داعى [حق‌] به سوى امرى دهشتناك دعوت مى‌كند،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmdcccliii{در حالى كه ديدگان خود را فروهشته‌اند، چون ملخهاى پراكنده از گورها[ى خود] برمى‌آيند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmdcccliv{به سرعت سوى آن دعوتگر مى‌شتابند. كافران مى‌گويند: «امروز [چه‌] روز دشوارى است.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmdccclv{پيش از آنان، قوم نوح [نيز] به تكذيب پرداختند و بنده ما را دروغزن خواندند و گفتند: «ديوانه‌اى است.» و [بسى‌] آزار كشيد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmdccclvi{تا پروردگارش را خواند كه: «من مغلوب شدم؛ به داد من برس!»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmdccclvii{پس درهاى آسمان را به آبى ريزان گشوديم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmdccclviii{و از زمين چشمه‌ها جوشانيديم تا آب [زمين و آسمان‌] براى امرى كه مقدّر شده بود به هم پيوستند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmdccclix{و او را بر [كشتى‌] تخته‌دار و ميخ‌آجين سوار كرديم.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmdccclx{[كشتى‌] زير نظر ما روان بود. [اين‌] پاداش كسى بود كه مورد انكار واقع شده بود.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxi{و به راستى آن [سفينه‌] را بر جاى نهاديم [تا] عبرتى [باشد]؛ پس آيا پندگيرنده‌اى هست؟\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxii{پس چگونه بود عذاب من و هشدارها[ى من‌]؟\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxiii{و قطعاً قرآن را براى پندآموزى آسان كرده‌ايم؛ پس آيا پندگيرنده‌اى هست؟\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxiv{عاديان به تكذيب پرداختند. پس چگونه بود عذاب من و هشدارها[ى من‌]؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxv{ما بر [سر] آنان در روز شومى، به طور مداوم، تندبادى توفنده فرستاديم،\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxvi{[كه‌] مردم را از جا مى‌كند؛ گويى تنه‌هاى نخلى بودند كه ريشه‌كن شده بودند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxvii{پس چگونه بود عذاب من و هشدارها[ى من‌]؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxviii{و قطعاً قرآن را براى پندآموزى آسان كرده‌ايم، پس آيا پندگيرنده‌اى هست؟\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxix{قوم ثمود هشداردهندگان را تكذيب كردند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxx{و گفتند: «آيا تنها بشرى از خودمان را پيروى كنيم؟ در اين صورت، ما واقعاً در گمراهى و جنون خواهيم بود.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxi{«آيا از ميان ما [وحى‌] بر او القا شده است؟ [نه،] بلكه او دروغگويى گستاخ است.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxii{به زودى فردا بدانند دروغگوى گستاخ كيست.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxiii{ما براى آزمايش آنان [آن‌] ماده‌شتر را فرستاديم و [به صالح گفتيم:]«مراقب آنان باش و شكيبايى كن.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxiv{و به آنان خبر ده كه آب ميانشان بخش شده‌است: هر كدام را آب به نوبت خواهد بود.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxv{پس رفيقشان را صدا كردند و [او] شمشير كشيد و [شتر را] پى كرد.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxvi{پس چگونه بود عذاب من و هشدارها[ى من‌]؟\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxvii{ما بر [سر]شان يك فرياد [مرگبار] فرستاديم و چون گياه خشكيده [كومه‌ها] ريزريز شدند.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxviii{و قطعاً قرآن را براى پندآموزى آسان كرديم؛ پس آيا پندگيرنده‌اى هست؟\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxix{قوم لوط هشداردهندگان را تكذيب كردند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxx{ما بر [سر] آنان سنگبارانى [انفجارى‌] فروفرستاديم [و] فقط خانواده لوط بودند كه سحرگاهشان رهانيديم.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxi{[و اين‌] رحمتى از جانب ما بود؛ هر كه سپاس دارد، بدين‌سان [او را] پاداش مى‌دهيم.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxii{و [لوط] آنها را از عذاب ما سخت بيم داده بود، و[لى‌] در تهديدها[ى ما] به جدال برخاستند.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxiii{و از مهمان‌[هاى‌] او كام دل خواستند، پس فروغ ديدگانشان را سترديم و [گفتيم:] «[مزه‌] عذاب و هشدارهاى مرا بچشيد.»\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxiv{و به راستى كه سپيده‌دم عذابى پيگير به سر وقت آنان آمد.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxv{پس عذاب و هشدارهاى مرا بچشيد.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxvi{و قطعاً قرآن را براى پندآموزى آسان كرديم؛ پس آيا پندگيرنده‌اى هست؟\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxvii{و در حقيقت هشداردهندگان به جانب فرعونيان آمدند.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxviii{[اما آنها] همه معجزات ما را تكذيب كردند، تا چون زبردستى زورمند [گريبان‌] آنان را گرفتيم.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmdccclxxxix{آيا كافران شما، از اينان [كه برشمرديم‌] برترند، يا شما را در نوشته‌ها[ى آسمانى‌] خط امانى است؟\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxc{يا مى‌گويند: «ما همگى انتقام‌گيرنده [و يار و ياور همديگر]يم!»\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxci{زودا كه اين جمع در هم شكسته شود و پشت كنند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxcii{بلكه موعدشان قيامت است و قيامت [بسى‌] سخت‌تر و تلخ‌تر است.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxciii{قطعاً بزهكاران در گمراهى و جنونند.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxciv{روزى كه در آتش به رو كشيده مى‌شوند [و به آنان گفته مى‌شود:] «لهيب آتش را بچشيد [و احساس كنيد].»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxcv{ماييم كه هر چيزى را به اندازه آفريده‌ايم.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxcvi{و فرمان ما جز يك بار نيست [آن هم‌] چون چشم به هم زدنى.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxcvii{و هم مسلكان شما را سخت به هلاكت رسانديم؛ پس آيا پندگيرنده‌اى هست؟\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxcviii{و هر چه كرده‌اند در كتابها[ى اعمالشان درج‌] است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmdcccxcix{و هر خرد و بزرگى [در آن‌] نوشته شده.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmcm{در حقيقت، مردم پرهيزگار در ميان باغها و نهرها،\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmcmi{در قرارگاه صدق، نزد پادشاهى توانايند.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmcmii{\basmalahfa [خداى‌] رحمان،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmcmiii{قرآن را ياد داد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmcmiv{انسان را آفريد،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmcmv{به او بيان آموخت.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmcmvi{خورشيد و ماه بر حسابى [روان‌]اند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmcmvii{و بوته و درخت چهره‌سايانند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmcmviii{و آسمان را برافراشت و ترازو را گذاشت،\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmcmix{تا مبادا از اندازه درگذريد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmcmx{و وزن را به انصاف برپا داريد و در سنجش مكاهيد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmcmxi{و زمين را براى مردم نهاد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmcmxii{در آن، ميوه [ها] و نخلها با خوشه‌هاى غلاف دار،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmcmxiii{و دانه‌هاى پوست‌دار و گياهان خوشبوست.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmcmxiv{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmcmxv{انسان را از گل خشكيده‌اى سفال مانند، آفريد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmcmxvi{و جن را از تشعشعى از آتش خلق كرد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmcmxvii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmcmxviii{پروردگار دو خاور و پروردگار دو باختر.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmcmxix{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmcmxx{دو دريا را [به گونه‌اى‌] روان كرد [كه‌] با هم برخورد كنند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxi{ميان آن دو، حد فاصلى است كه به هم تجاوز نمى‌كنند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxiii{از هر دو [دريا] مرواريد و مرجان برآيد.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxiv{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxv{و او راست در دريا سفينه‌هاى بادبان‌دار بلند همچون كوهها.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxvi{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxvii{هر چه بر [زمين‌] است فانى‌شونده است.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxviii{و ذات باشكوه و ارجمند پروردگارت باقى خواهد ماند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxix{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxx{هر كه در آسمانها و زمين است از او درخواست مى‌كند. هر زمان، او در كارى است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxi{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxii{اى جن و انس، زودا كه به شما بپردازيم.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxiii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxiv{اى گروه جنّيان و انسيان، اگر مى‌توانيد از كرانه‌هاى آسمانها و زمين به بيرون رخنه كنيد، پس رخنه كنيد. [ولى‌] جز با [به دست آوردن‌] تسلطى رخنه نمى‌كنيد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxv{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxvi{بر سر شما شراره‌هايى از [نوع‌] تفته آهن و مس فرو فرستاده خواهد شد، و [از كسى‌] يارى نتوانيد طلبيد.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxvii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxviii{پس آنگاه كه آسمان از هم شكافد و چون چرم گلگون گردد.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmcmxxxix{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmcmxl{در آن روز، هيچ انس و جنى از گناهش پرسيده نشود.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmcmxli{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmcmxlii{تبهكاران از سيمايشان شناخته مى‌شوند و از پيشانى و پايشان بگيرند.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmcmxliii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmcmxliv{اين است همان جهنمى كه تبهكاران آن را دروغ مى‌خواندند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmcmxlv{ميان [آتش‌] و ميان آب جوشان سرگردان باشند.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmcmxlvi{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmcmxlvii{و هر كس را كه از مقام پروردگارش بترسد دو باغ است.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmcmxlviii{پس كداميك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmcmxlix{كه داراى شاخسارانند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmcml{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmcmli{در آن دو [باغ‌] دو چشمه روان است.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmcmlii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmcmliii{در آن دو [باغ‌] از هر ميوه‌اى دو گونه است.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmcmliv{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmcmlv{بر بسترهايى كه آستر آنها از ابريشم درشت‌بافت است، تكيه آنند و چيدن ميوه [از] آن دو باغ [به آسانى‌] در دسترس است.\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmcmlvi{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmcmlvii{در آن [باغها، دلبرانى‌] فروهشته‌نگاهند كه دست هيچ انس و جنى پيش از ايشان به آنها نرسيده است.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmcmlviii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmcmlix{گويى كه آنها ياقوت و مرجانند.\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmcmlx{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxi{مگر پاداش احسان جز احسان است؟\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxiii{و غير از آن دو [باغ‌]، دو باغ [ديگر نيز] هست.\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxiv{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxv{كه از [شدّت‌] سبزى سيه‌گون مى‌نمايد.\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxvi{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxvii{در آن دو [باغ‌] دو چشمه همواره جوشان است.\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxviii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxix{در آن دو، ميوه و خرما و انار است.\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxx{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxi{در آنجا [زنانى‌] نكوخوى و نكورويند.\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxiii{حورانى پرده‌نشين در [دل‌] خيمه‌ها.\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxiv{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxv{دست هيچ انس و جنى پيش از ايشان به آنها نرسيده است.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxvi{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxvii{بر بالش سبز و فرش نيكو تكيه زده‌اند.\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxviii{پس كدام يك از نعمتهاى پروردگارتان را منكريد؟\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxix{خجسته باد نام پروردگار شكوهمند و بزرگوارت،\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxx{\basmalahfa آن واقعه چون وقوع يابد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxi{[كه‌] در وقوع آن دروغى نيست:\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxii{پست‌كننده [و] بالابرنده است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxiii{چون زمين با تكان [سختى‌] لرزانده شود،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxiv{و كوهها [جمله‌] ريزه ريزه شوند،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxv{و غبارى پراكنده گردند،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxvi{و شما سه دسته شويد:\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxvii{ياران دست راست، كدامند ياران دست راست؟\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxviii{و ياران چپ؛ كدامند ياران چپ؟\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmcmlxxxix{و سبقت‌گيرندگان مقدمند؛\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmcmxc{آنانند همان مقربان [خدا]،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmcmxci{در باغستانهاى پر نعمت.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmcmxcii{گروهى از پيشينيان،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmcmxciii{و اندكى از متأخران.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmcmxciv{بر تختهايى جواهرنشان،\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmcmxcv{كه روبروى هم بر آنها تكيه داده‌اند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmcmxcvi{بر گردشان پسرانى جاودان [به خدمت‌] مى‌گردند،\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmcmxcvii{با جامها و آبريزها و پياله‌[ها]يى از باده ناب روان.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmcmxcviii{[كه‌] نه از آن دردسر گيرند و نه بى‌خرد گردند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmcmxcix{و ميوه از هر چه اختيار كنند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmm{و از گوشت پرنده هر چه بخواهند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmi{و حوران چشم‌درشت،\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmii{مثل لؤلؤ نهان ميان صدف،\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmiii{[اينها] پاداشى است براى آنچه مى‌كردند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmiv{در آنجا نه بيهوده‌اى مى‌شنوند و نه [سخنى‌] گناه‌آلود.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmv{سخنى جز سلام و درود نيست.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmvi{و ياران راست؛ ياران راست كدامند؟\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmvii{در [زير] درختان كُنار بى‌خار،\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmviii{و درختهاى موز كه ميوه‌اش خوشه خوشه روى هم چيده است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmix{و سايه‌اى پايدار.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmx{و آبى ريزان.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmxi{و ميوه‌اى فراوان،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmxii{نه بريده و نه ممنوع.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmxiii{و همخوابگانى بالا بلند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmxiv{ما آنان را پديد آورده‌ايم پديد آوردنى،\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmxv{و ايشان را دوشيزه گردانيده‌ايم،\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmxvi{شوى دوست همسال،\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmxvii{براى ياران راست.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmxviii{كه گروهى از پيشينيانند،\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmxix{و گروهى از متأخران.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmxx{و ياران چپ؛ كدامند ياران چپ؟\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmmxxi{در [ميان‌] باد گرم و آب داغ.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmmxxii{و سايه‌اى از دود تار.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmmxxiii{نه خنك و نه خوش.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmmxxiv{اينان بودند كه پيش از اين ناز پروردگان بودند.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmmxxv{و بر گناه بزرگ پافشارى مى‌كردند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmmxxvi{و مى‌گفتند: «آيا چون مرديم و خاك واستخوان شديم، واقعاً [باز] زنده مى‌گرديم؟\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmmxxvii{يا پدران گذشته ما [نيز]؟»\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmmxxviii{بگو: «در حقيقت، اولين و آخرين،\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmmxxix{قطعاً همه در موعد روزى معلوم گرد آورده شوند.»\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmmxxx{آنگاه شما اى گمراهان دروغپرداز،\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxi{قطعاً از درختى كه از زقّوم است خواهيد خورد.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxii{و از آن شكمهايتان را خواهيد آكند.\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxiii{و روى آن از آب جوش مى‌نوشيد؛\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxiv{[مانند] نوشيدن اشتران تشنه.\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxv{اين است پذيرايى آنان در روز جزا.\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxvi{ماييم كه شما را آفريده‌ايم، پس چرا تصديق نمى‌كنيد؟\qt@no{(57)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxvii{آيا آنچه را [كه به صورت نطفه‌] فرو مى‌ريزيد ديده‌ايد؟\qt@no{(58)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxviii{آيا شما آن را خلق مى‌كنيد يا ما آفريننده‌ايم؟\qt@no{(59)}}
\qt@newcmd\qurantrans@fa@mmmmmxxxix{ماييم كه ميان شما مرگ را مقدر كرده‌ايم و بر ما سبقت نتوانيد جست؛\qt@no{(60)}}
\qt@newcmd\qurantrans@fa@mmmmmxl{[و مى‌توانيم‌] امثال شما را به جاى شما قرار دهيم و شما را [به صورت‌] آنچه نمى‌دانيد پديدار گردانيم.\qt@no{(61)}}
\qt@newcmd\qurantrans@fa@mmmmmxli{و قطعاً پديدار شدن نخستين خود را شناختيد؛ پس چرا سر عبرت گرفتن نداريد؟\qt@no{(62)}}
\qt@newcmd\qurantrans@fa@mmmmmxlii{آيا آنچه را كشت مى‌كنيد، ملاحظه كرده‌ايد؟\qt@no{(63)}}
\qt@newcmd\qurantrans@fa@mmmmmxliii{آيا شما آن را [بى‌يارى ما] زراعت مى‌كنيد، يا ماييم كه زراعت مى‌كنيم؟\qt@no{(64)}}
\qt@newcmd\qurantrans@fa@mmmmmxliv{اگر بخواهيم قطعاً خاشاكش مى‌گردانيم، پس در افسوس [و تعجب‌] مى‌افتيد.\qt@no{(65)}}
\qt@newcmd\qurantrans@fa@mmmmmxlv{[و مى‌گوييد:] «واقعاً ما زيان زده‌ايم،\qt@no{(66)}}
\qt@newcmd\qurantrans@fa@mmmmmxlvi{بلكه ما محروم شدگانيم.»\qt@no{(67)}}
\qt@newcmd\qurantrans@fa@mmmmmxlvii{آيا آبى را كه مى‌نوشيد ديده‌ايد؟\qt@no{(68)}}
\qt@newcmd\qurantrans@fa@mmmmmxlviii{آيا شما آن را از [دل‌] ابر سپيد فرود آورده‌ايد، يا ما فرودآورنده‌ايم؟\qt@no{(69)}}
\qt@newcmd\qurantrans@fa@mmmmmxlix{اگر بخواهيم آن را تلخ مى‌گردانيم، پس چرا سپاس نمى‌داريد؟\qt@no{(70)}}
\qt@newcmd\qurantrans@fa@mmmmml{آيا آن آتشى را كه برمى‌افروزيد ملاحظه كرده‌ايد؟\qt@no{(71)}}
\qt@newcmd\qurantrans@fa@mmmmmli{آيا شما [چوب‌] درخت آن را پديدار كرده‌ايد، يا ما پديدآورنده‌ايم؟\qt@no{(72)}}
\qt@newcmd\qurantrans@fa@mmmmmlii{ما آن را [مايه‌] عبرت و [وسيله‌] استفاده براى بيابانگردان قرار داده‌ايم.\qt@no{(73)}}
\qt@newcmd\qurantrans@fa@mmmmmliii{پس به نام پروردگار بزرگت تسبيح گوى.\qt@no{(74)}}
\qt@newcmd\qurantrans@fa@mmmmmliv{نه [چنين است كه مى‌پنداريد]، سوگند به جايگاه‌هاى [ويژه و فواصل معيّن‌] ستارگان.\qt@no{(75)}}
\qt@newcmd\qurantrans@fa@mmmmmlv{اگر بدانيد، آن سوگندى سخت بزرگ است!\qt@no{(76)}}
\qt@newcmd\qurantrans@fa@mmmmmlvi{كه اين [پيام‌] قطعاً قرآنى است ارجمند،\qt@no{(77)}}
\qt@newcmd\qurantrans@fa@mmmmmlvii{در كتابى نهفته،\qt@no{(78)}}
\qt@newcmd\qurantrans@fa@mmmmmlviii{كه جز پاك‌شدگان بر آن دست ندارند،\qt@no{(79)}}
\qt@newcmd\qurantrans@fa@mmmmmlix{وحيى است از جانب پروردگار جهانيان.\qt@no{(80)}}
\qt@newcmd\qurantrans@fa@mmmmmlx{آيا شما اين سخن را سبك [و سست‌] مى‌گيريد؟\qt@no{(81)}}
\qt@newcmd\qurantrans@fa@mmmmmlxi{و تنها نصيب خود را در تكذيب [آن‌] قرار مى‌دهيد؟\qt@no{(82)}}
\qt@newcmd\qurantrans@fa@mmmmmlxii{پس چرا آنگاه كه [جان شما] به گلو مى‌رسد،\qt@no{(83)}}
\qt@newcmd\qurantrans@fa@mmmmmlxiii{و در آن هنگام خود نظاره گريد -\qt@no{(84)}}
\qt@newcmd\qurantrans@fa@mmmmmlxiv{و ما به آن [محتضر] از شما نزديكتريم ولى نمى‌بينيد-\qt@no{(85)}}
\qt@newcmd\qurantrans@fa@mmmmmlxv{پس چرا، اگر شما بى‌جزا مى‌مانيد [و حساب و كتابى در كار نيست‌]،\qt@no{(86)}}
\qt@newcmd\qurantrans@fa@mmmmmlxvi{اگر راست مى‌گوييد، [روح‌] را برنمى‌گردانيد؟\qt@no{(87)}}
\qt@newcmd\qurantrans@fa@mmmmmlxvii{و اما اگر [او] از مقربان باشد،\qt@no{(88)}}
\qt@newcmd\qurantrans@fa@mmmmmlxviii{[در] آسايش و راحت و بهشت پر نعمت [خواهد بود].\qt@no{(89)}}
\qt@newcmd\qurantrans@fa@mmmmmlxix{و اما اگر از ياران راست باشد،\qt@no{(90)}}
\qt@newcmd\qurantrans@fa@mmmmmlxx{از ياران راست بر تو سلام باد.\qt@no{(91)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxi{و اما اگر از دروغزنان گمراه است،\qt@no{(92)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxii{پس با آبى جوشان پذيرايى خواهد شد،\qt@no{(93)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxiii{و [فرجامش‌] درافتادن به جهنم است.\qt@no{(94)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxiv{اين است همان حقيقت راست [و] يقين.\qt@no{(95)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxv{پس به نام پروردگار بزرگ خود تسبيح گوى.\qt@no{(96)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxvi{\basmalahfa آنچه در آسمانها و زمين است، خدا را به پاكى مى‌ستايند، و اوست ارجمند حكيم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxvii{فرمانروايى آسمانها و زمين از آنِ اوست: زنده مى‌كند و مى‌ميراند، و او بر هر چيزى تواناست.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxviii{اوست اول و آخر و ظاهر و باطن، و او به هر چيزى داناست.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxix{اوست آن كس كه آسمانها و زمين را در شش هنگام آفريد؛ آنگاه بر عرش استيلا يافت. آنچه در زمين درآيد و آنچه از آن برآيد و آنچه در آن بالارود [همه را] مى‌داند. و هر كجا باشيد او با شماست، و خدا به هر چه مى‌كنيد بيناست.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxx{فرمانروايى [مطلق‌] آسمانها و زمين از آن اوست، و [جمله‌] كارها به سوى خدا بازگردانيده مى‌شود.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxi{شب را در روز درمى‌آورد و روز را [نيز] در شب درمى‌آورد، و او به راز دلها داناست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxii{به خدا و پيامبر او ايمان آوريد، و از آنچه شما را در [استفاده از] آن، جانشين [ديگران‌] كرده، انفاق كنيد. پس كسانى از شما كه ايمان آورده و انفاق كرده باشند، پاداش بزرگى خواهند داشت.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxiii{و شما را چه شده كه به خدا ايمان نمى‌آوريد و [حال آنكه‌] پيامبر [خدا] شما را دعوت مى‌كند تا به پروردگارتان ايمان آوريد، و اگر مؤمن باشيد، بى‌شك [خدا] از شما پيمان گرفته است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxiv{او همان كسى است كه بر بنده خود آيات روشنى فرو مى‌فرستد، تا شما را از تاريكيها به سوى نور بيرون كشاند. و در حقيقت، خدا [نسبت‌] به شما سخت رئوف و مهربان است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxv{و شما را چه شده كه در راه خدا انفاق نمى‌كنيد و [حال آنكه‌] ميراث آسمانها و زمين به خدا تعلق دارد؟ كسانى از شما كه پيش از فتح [مكه‌] انفاق و جهاد كرده‌اند، [با ديگران‌] يكسان نيستند. آنان از [حيث ]درجه بزرگتر از كسانى‌اند كه بعداً به انفاق و جهاد پرداخته‌اند. و خداوند به هر كدام وعده نيكو داده است، و خدا به آنچه مى‌كنيد آگاه است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxvi{كيست آن كس كه به خدا وامى نيكو دهد تا [نتيجه‌اش را] براى وى دوچندان گرداند و او را پاداشى خوش باشد؟\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxvii{آن روز كه مردان و زنان مؤمن را مى‌بينى كه نورشان پيشاپيششان و به جانب راستشان دوان است. [به آنان گويند:] «امروز شما را مژده باد به باغهايى كه از زير [درختان‌] آن نهرها روان است، در آنها جاودانيد. اين است همان كاميابى بزرگ.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxviii{آن روز، مردان و زنان منافق به كسانى كه ايمان آورده‌اند مى‌گويند: «ما را مهلت دهيد تا از نورتان [اندكى‌] برگيريم.» گفته مى‌شود: «بازپس برگرديد و نورى درخواست كنيد.» آنگاه ميان آنها ديوارى زده مى‌شود كه آن را دروازه‌اى است: باطنش رحمت است و ظاهرش روى به عذاب دارد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmlxxxix{[دو رويان،] آنان را ندا درمى‌دهند: «آيا ما با شما نبوديم؟» مى‌گويند: «چرا، ولى شما خودتان را در بلا افكنديد و امروز و فردا كرديد و ترديد آورديد و آرزوها شما را غرّه كرد تا فرمان خدا آمد و [شيطان ]مغروركننده، شما را در باره خدا بفريفت.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmxc{پس امروز نه از شما و نه از كسانى كه كافر شده‌اند عوضى پذيرفته نمى‌شود: جايگاهتان آتش است؛ آن سزاوار شماست و چه بد سرانجامى است.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmxci{آيا براى كسانى كه ايمان آورده‌اند هنگام آن نرسيده كه دلهايشان به ياد خدا و آن حقيقتى كه نازل شده نرم [و فروتن‌] گردد و مانند كسانى نباشند كه از پيش بدانها كتاب داده شد و [عمر و] انتظار بر آنان به درازا كشيد، و دلهايشان سخت گرديد و بسيارى از آنها فاسق بودند؟\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmxcii{بدانيد كه خدا زمين را پس از مرگش زنده مى‌گرداند. به راستى آيات [خود] را براى شما روشن گردانيده‌ايم، باشد كه بينديشيد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmxciii{در حقيقت، مردان و زنان صدقه‌دهنده و [آنان كه‌] به خدا وامى نيكو داده‌اند، ايشان را [پاداش‌] دو چندان گردد، و اجرى نيكو خواهند داشت.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmxciv{و كسانى كه به خدا و پيامبران وى ايمان آورده‌اند، آنان همان راستينانند و پيش پروردگارشان گواه خواهند بود [و] ايشان راست اجر و نورشان؛ و كسانى كه كفر ورزيده و آيات ما را تكذيب كرده‌اند آنان همدمان آتشند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmxcv{بدانيد كه زندگى دنيا، در حقيقت، بازى و سرگرمى و آرايش و فخرفروشى شما به يكديگر و فزون‌جويى در اموال و فرزندان است. [مثَل آنها] چون مثَل بارانى است كه كشاورزان را رستنى آن [باران‌] به شگفتى اندازد، سپس [آن كشت‌] خشك شود و آن را زرد بينى، آنگاه خاشاك شود. و در آخرت [دنيا پرستان را] عذابى سخت است و [مؤمنان را] از جانب خدا آمرزش و خشنودى است، و زندگانى دنيا جز كالاى فريبنده نيست.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmxcvi{[براى رسيدن‌] به آمرزشى از پروردگارتان و بهشتى كه پهنايش چون پهناى آسمان و زمين است [و] براى كسانى آماده شده كه به خدا و پيامبرانش ايمان آورده‌اند، بر يكديگر سبقت جوييد. اين فضل خداست كه به هر كس بخواهد آن را مى‌دهد، و خداوند را فزون‌بخشى بزرگ است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmxcvii{هيچ مصيبتى نه در زمين و نه در نفسهاى شما [= به شما] نرسد، مگر آنكه پيش از آنكه آن را پديد آوريم، در كتابى است. اين [كار] بر خدا آسان است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmxcviii{تا بر آنچه از دست شما رفته اندوهگين نشويد و به [سبب‌] آنچه به شما داده است شادمانى نكنيد، و خدا هيچ خودپسند فخرفروشى را دوست ندارد:\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmxcix{همانان كه بخل مى‌ورزند و مردم را به بخل ورزيدن وامى‌دارند. و هر كه روى گرداند قطعاً خدا بى‌نياز ستوده است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmc{به راستى [ما] پيامبران خود را با دلايل آشكار روانه كرديم و با آنها كتاب و ترازو را فرود آورديم تا مردم به انصاف برخيزند، و آهن را كه در آن براى مردم خطرى سخت و سودهايى است، پديد آورديم، تا خدا معلوم بدارد چه كسى در نهان، او و پيامبرانش را يارى مى‌كند. آرى، خدا نيرومند شكست ناپذير است.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmci{و در حقيقت، نوح و ابراهيم را فرستاديم و در ميان فرزندان آن دو، نبوت و كتاب را قرار داديم: از آنها [برخى‌] راه‌ياب [شد]ند، و[لى‌] بسيارى از آنان بدكار بودند.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmcii{آنگاه به دنبال آنان پيامبران خود را، پى‌درپى، آورديم، و عيسى پسر مريم را در پى [آنان‌] آورديم و به او انجيل عطا كرديم، و در دلهاى كسانى كه از او پيروى كردند رأفت و رحمت نهاديم و [اما] ترك دنيايى كه از پيش خود درآوردند ما آن را بر ايشان مقرّر نكرديم مگر براى آنكه كسب خشنودى خدا كنند، با اين حال آن را چنانكه حقّ رعايت آن بود منظور نداشتند. پس پاداش كسانى از ايشان را كه ايمان آورده بودند بدانها داديم و[لى‌] بسيارى از آنان دستخوش انحرافند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmciii{اى كسانى كه ايمان آورده‌ايد، از خدا پروا داريد و به پيامبر او بگرويد تا از رحمت خويش شما را دو بهره عطا كند و براى شما نورى قرار دهد كه به [بركت‌] آن راه سپريد و بر شما ببخشايد، و خدا آمرزنده مهربان است.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmciv{تا اهل كتاب بدانند كه به هيچ وجه فزون‌بخشى خدا در [حيطه‌] قدرت آنان نيست و فضل [و عنايت، تنها] در دست خداست: به هر كس بخواهد آن را عطا مى‌كند، و خدا داراى كرم بسيار است.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmcv{\basmalahfa خدا گفتار [زنى‌] را كه در باره شوهرش با تو گفتگو و به خدا شكايت مى‌كرد شنيد؛ و خدا گفتگوى شما را مى‌شنود، زيرا خدا شنواى بيناست.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcvi{از ميان شما كسانى كه زنانشان را «ظهار» مى‌كنند [و مى‌گويند: پشت تو چون پشت مادر من است‌] آنان مادرانشان نيستند. مادران آنها تنها كسانى‌اند كه ايشان را زاده‌اند، و قطعاً آنها سخنى زشت و باطل مى‌گويند، و[لى‌] خدا مسلماً درگذرنده آمرزنده است.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcvii{و كسانى كه زنانشان را ظهار مى‌كنند، سپس از آنچه گفته‌اند پشيمان مى‌شوند، بر ايشان [فرض‌] است كه پيش از آنكه با يكديگر همخوابگى كنند، بنده‌اى را آزاد گردانند. اين [حكمى‌] است كه بدان پند داده مى‌شويد، و خدا به آنچه انجام مى‌دهيد آگاه است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcviii{و آن كس كه [بر آزادكردن بنده‌] دسترسى ندارد، بايد پيش از تماس [با زن خود] دو ماه پياپى روزه بدارد؛ و هر كه نتواند، بايد شصت بينوا را خوراك بدهد. اين [حكم‌] براى آن است كه به خدا و فرستاده او ايمان بياوريد، و اين است حدود خدا. و كافران را عذابى پردرد خواهد بود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcix{بى‌گمان، كسانى كه با خدا و فرستاده او مخالفت مى‌كنند ذليل خواهند شد، همان‌گونه كه آنان كه پيش از ايشان بودند ذليل شدند، و به راستى آيات روشن [خود] را فرستاده‌ايم، و كافران را عذابى خفت‌آور خواهد بود.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcx{روزى كه خداوند همه آنان را بر مى‌انگيزد و به آنچه كرده‌اند آگاهشان مى‌گرداند. خدا [كارهايشان را] برشمرده است و حال آنكه آنها آن را فراموش كرده‌اند، و خدا بر هر چيزى گواه است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcxi{آيا ندانسته‌اى كه خدا آنچه را كه در آسمانها و آنچه را كه در زمين است مى‌داند؟ هيچ گفتگوى محرمانه‌اى ميان سه تن نيست مگر اينكه او چهارمين آنهاست، و نه ميان پنج تن مگر اينكه او ششمين آنهاست، و نه كمتر از اين [عدد] و نه بيشتر، مگر اينكه هر كجا باشند او با آنهاست. آنگاه روز قيامت آنان را به آنچه كرده‌اند آگاه خواهد گردانيد، زيرا خدا به هر چيزى داناست.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcxii{آيا كسانى را كه از نجوا منع شده بودند، نديدى كه باز بدانچه از آن منع گرديده‌اند، برمى‌گردند و با همديگر به [منظور] گناه و تعدّى و سرپيچى از پيامبر، محرمانه گفتگو مى‌كنند و چون به نزد تو آيند، تو را بدانچه خدا به آن [شيوه‌] سلام نگفته سلام مى‌دهند و در دلهاى خود مى‌گويند: «چرا به آنچه مى‌گوييم خدا ما را عذاب نمى‌كند؟» جهنم براى آنان كافى است؛ در آن درمى‌آيند، و چه بد سرانجامى است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcxiii{اى كسانى كه ايمان آورده‌ايد، چون با يكديگر محرمانه گفتگو مى‌كنيد، به [قصد] گناه و تعدى و نافرمانى پيامبر با همديگر محرمانه گفتگو نكنيد، و به نيكوكارى و پرهيزگارى نجوا كنيد، و از خدايى كه نزد او محشور خواهيد گشت پروا داريد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcxiv{چنان نجوايى صرفاً از [القاآت‌] شيطان است، تا كسانى را كه ايمان آورده‌اند دلتنگ گرداند، و[لى‌] جز به فرمان خدا هيچ آسيبى به آنها نمى‌رساند، و مؤمنان بايد بر خدا اعتماد كنند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcxv{اى كسانى كه ايمان آورده‌ايد، چون به شما گفته شود: «در مجالس جاى باز كنيد»، پس جاى باز كنيد تا خدا براى شما گشايش حاصل كند، و چون گفته شود: «برخيزيد»، پس برخيزيد. خدا [رتبه‌] كسانى از شما را كه گرويده و كسانى را كه دانشمندند [بر حسب‌] درجات بلند گرداند، و خدا به آنچه مى‌كنيد آگاه است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcxvi{اى كسانى كه ايمان آورده‌ايد، هرگاه با پيامبر [خدا] گفتگوى محرمانه مى‌كنيد، پيش از گفتگوى محرمانه خود صدقه‌اى تقديم بداريد. اين [كار] براى شما بهتر و پاكيزه‌تر است؛ و اگر چيزى نيافتيد بدانيد كه خدا آمرزنده مهربان است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcxvii{آيا ترسيديد كه پيش از گفتگوى محرمانه خود صدقه‌هايى تقديم داريد؟ و چون نكرديد و خدا [هم‌] بر شما بخشود، پس نماز را برپا داريد و زكات را بدهيد و از خدا و پيامبر او فرمان بريد، و خدا به آنچه مى‌كنيد آگاه است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcxviii{آيا نديده‌اى كسانى را كه قومى را كه مورد خشم خدايند به دوستى گرفته‌اند؟ آنها نه از شمايند و نه از ايشان، و به دروغ سوگند ياد مى‌كنند و خودشان [هم‌] مى‌دانند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcxix{خدا براى آنان عذابى سخت آماده كرده است. راستى كه چه بد مى‌كردند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcxx{سوگندهاى خود را [چون‌] سپرى قرار داده بودند و [مردم را] از راه خدا بازداشتند و [در نتيجه‌] براى آنان عذابى خفت‌آور است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxi{در برابر خداوند نه از اموالشان و نه از اولادشان هرگز كارى ساخته نيست. آنها دوزخى‌اند [و] در آن جاودانه [مى‌مانند].\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxii{روزى كه خدا همه آنان را برمى‌انگيزد، همان‌گونه كه براى شما سوگند ياد مى‌كردند براى او [نيز] سوگند ياد مى‌كنند و چنان پندارند كه حق به جانب آنهاست. آگاه باش كه آنان همان دروغگويانند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxiii{شيطان بر آنان چيره شده و خدا را از يادشان برده است؛ آنان حزب شيطانند. آگاه باش كه حزب شيطان همان زيانكارانند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxiv{در حقيقت، كسانى كه با خدا و پيامبر او به دشمنى برمى‌خيزند، آنان در [زمره‌] زبونان خواهند بود.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxv{خدا مقرّر كرده است كه: «حتماً من و فرستادگانم چيره خواهيم گرديد.» آرى، خدا نيرومند شكست‌ناپذير است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxvi{قومى را نيابى كه به خدا و روز بازپسين ايمان داشته باشند [و] كسانى را كه با خدا و رسولش مخالفت كرده‌اند -هر چند پدرانشان يا پسرانشان يا برادرانشان يا عشيره آنان باشند- دوست بدارند. در دل اينهاست كه [خدا] ايمان را نوشته و آنها را با روحى از جانب خود تأييد كرده است، و آنان را به بهشتهايى كه از زير [درختان‌] آن جويهايى روان است در مى‌آورد؛ هميشه در آنجا ماندگارند؛ خدا از ايشان خشنود و آنها از او خشنودند؛ اينانند حزب خدا. آرى، حزب خداست كه رستگارانند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxvii{\basmalahfa آنچه در آسمانها و در زمين است تسبيح‌گوى خداى هستند، و اوست شكست‌ناپذير سنجيده‌كار.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxviii{اوست كسى كه، از ميان اهل كتاب كسانى را كه كفر ورزيدند در نخستين اخراج [از مدينه‌] بيرون كرد. گمان نمى‌كرديد كه بيرون روند و خودشان گمان داشتند كه دژهايشان در برابر خدا مانع آنها خواهد بود، و[لى‌] خدا از آنجايى كه تصوّر نمى‌كردند بر آنان درآمد و در دلهايشان بيم افكند، [به طورى كه‌] خود به دست خود و دست مؤمنان خانه‌هاى خود را خراب مى‌كردند. پس اى ديده‌وران، عبرت گيريد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxix{و اگر خدا اين جلاى وطن را بر آنان مقرّر نكرده بود، قطعاً آنها را در دنيا عذاب مى‌كرد و در آخرت [هم‌] عذاب آتش داشتند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxx{اين [عقوبت‌] براى آن بود كه آنها با خدا و پيامبرش در افتادند؛ و هر كس با خدا درافتد؛ [بداند كه‌] خدا سخت‌كيفر است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxi{آنچه درخت خرما بريديد يا آنها را [دست نخورده‌] بر ريشه‌هايشان بر جاى نهاديد، به فرمان خدا بود، تا نافرمانان را خوار گرداند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxii{و آنچه را خدا از آنان به رسم غنيمت عايد پيامبر خود گردانيد، [شما براى تصاحب آن‌] اسب يا شترى بر آن نتاختيد، ولى خدا فرستادگانش را بر هر كه بخواهد چيره مى‌گرداند، و خدا بر هر كارى تواناست.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxiii{آنچه خدا از [دارايى‌] ساكنان آن قريه‌ها عايد پيامبرش گردانيد، از آن خدا و از آن پيامبر [او] و متعلق به خويشاوندان نزديك [وى‌] و يتيمان و بينوايان و درراه‌ماندگان است، تا ميان توانگران شما دست به دست نگردد. و آنچه را فرستاده [او] به شما داد، آن را بگيريد و از آنچه شما را باز داشت، بازايستيد و از خدا پروا بداريد كه خدا سخت‌كيفر است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxiv{[اين غنايم، نخست‌] اختصاص به بينوايان مهاجرى دارد كه از ديارشان و اموالشان رانده شدند: خواستار فضل خدا و خشنودى [او] مى‌باشند و خدا و پيامبرش را يارى مى‌كنند. اينان همان مردم درست كردارند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxv{و [نيز] كسانى كه قبل از [مهاجران‌] در [مدينه‌] جاى گرفته و ايمان آورده‌اند؛ هر كس را كه به سوى آنان كوچ كرده دوست دارند؛ و نسبت به آنچه به ايشان داده شده است در دلهايشان حسدى نمى‌يابند؛ و هر چند در خودشان احتياجى [مبرم ]باشد، آنها را بر خودشان مقدّم مى‌دارند. و هر كس از خسّت نفس خود مصون ماند، ايشانند كه رستگارانند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxvi{و [نيز] كسانى كه بعد از آنان [=مهاجران و انصار] آمده‌اند [و] مى‌گويند: «پروردگارا، بر ما و بر آن برادرانمان كه در ايمان آوردن بر ما پيشى گرفتند ببخشاى، و در دلهايمان نسبت به كسانى كه ايمان آورده‌اند [هيچ گونه‌] كينه‌اى مگذار! پروردگارا، راستى كه تو رئوف و مهربانى.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxvii{مگر كسانى را كه به نفاق برخاستند نديدى كه به برادران اهل كتاب خود -كه از در كفر درآمده بودند- مى‌گفتند: «اگر اخراج شديد، حتماً با شما بيرون خواهيم آمد، و بر عليه شما هرگز از كسى فرمان نخواهيم برد؛ و اگر با شما جنگيدند، حتماً شما را يارى خواهيم كرد.» و خدا گواهى مى‌دهد كه قطعاً آنان دروغگويانند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxviii{اگر [يهود] اخراج شوند، آنها با ايشان بيرون نخواهند رفت، و اگر با آنان جنگيده شود [منافقان،] آنها را يارى نخواهند كرد، و اگر ياريشان كنند حتماً [در جنگ‌] پشت خواهند كرد و [ديگر] يارى نيابند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcxxxix{شما قطعاً در دلهاى آنان بيش از خدا مايه هراسيد، چرا كه آنان مردمانى‌اند كه نمى‌فهمند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcxl{[آنان، به صورت‌] دسته جمعى، جز در قريه‌هايى كه داراى استحكاماتند، يا از پشت ديوارها، با شما نخواهند جنگيد. جنگشان ميان خودشان سخت است. آنان را متحد مى‌پندارى و[لى‌] دلهايشان پراكنده است، زيرا آنان مردمانى‌اند كه نمى‌انديشند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcxli{درست مانند همان كسانى كه اخيرا [در واقعه بدر] سزاى كار [بد] خود را چشيدند؛ و آنان را عذاب دردناكى خواهد بود.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcxlii{چون حكايت شيطان كه به انسان گفت: «كافر شو.» و چون [وى‌] كافر شد، گفت: «من از تو بيزارم، زيرا من از خدا، پروردگار جهانيان، مى‌ترسم.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcxliii{و فرجام هردوشان آن است كه هر دو در آتش، جاويد مى‌مانند؛ و سزاى ستمگران اين است.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcxliv{اى كسانى كه ايمان آورده‌ايد، از خدا پروا داريد؛ و هر كسى بايد بنگرد كه براى فردا[ى خود] از پيش چه فرستاده است؛ و [باز] از خدا بترسيد. در حقيقت، خدا به آنچه مى‌كنيد آگاه است.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcxlv{و چون كسانى مباشيد كه خدا را فراموش كردند و او [نيز] آنان را دچار خودفراموشى كرد؛ آنان همان نافرمانانند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcxlvi{دوزخيان با بهشتيان يكسان نيستند؛ بهشتيانند كه كاميابانند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcxlvii{اگر اين قرآن را بر كوهى فرومى‌فرستاديم، يقيناً آن [كوه‌] را از بيم خدا فروتن [و] از هم‌پاشيده مى‌ديدى. و اين مَثَلها را براى مردم مى‌زنيم، باشد كه آنان بينديشند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcxlviii{اوست خدايى كه غير از او معبودى نيست، داننده غيب و آشكار است، اوست رحمتگر مهربان.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcxlix{اوست خدايى كه جز او معبودى نيست، همان فرمانرواى پاك سلامت‌[بخش، و] مؤمن [به حقيقت حقه خود كه‌] نگهبان، عزيز، جبّار [و] متكبّر [است‌]. پاك است خدا از آنچه [با او] شريك مى‌گردانند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmcl{اوست خداى خالق نوساز صورتگر [كه‌] بهترين نامها [و صفات‌] از آنِ اوست. آنچه در آسمانها و زمين است [جمله‌] تسبيح او مى‌گويند و او عزيز حكيم است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmcli{\basmalahfa اى كسانى كه ايمان آورده‌ايد، دشمن من و دشمن خودتان را به دوستى برمگيريد [به طورى‌] كه با آنها اظهار دوستى كنيد، و حال آنكه قطعاً به آن حقيقت كه براى شما آمده كافرند [و] پيامبر [خدا] و شما را [از مكه‌] بيرون مى‌كنند كه [چرا ]به خدا، پروردگارتان ايمان آورده‌ايد، اگر براى جهاد در راه من و طلب خشنودى من بيرون آمده‌ايد. [شما] پنهانى با آنان رابطه دوستى برقرار مى‌كنيد در حالى كه من به آنچه پنهان داشتيد و آنچه آشكار نموديد داناترم. و هر كس از شما چنين كند، قطعاً از راه درست منحرف گرديده است.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmclii{اگر بر شما دست يابند، دشمن شما باشند و بر شما به بدى دست و زبان بگشايند و آرزو دارند كه كافر شويد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcliii{روز قيامت نه خويشان شما و نه فرزندانتان هرگز به شما سود نمى‌رسانند. [خدا] ميانتان فيصله مى‌دهد، و خدا به آنچه انجام مى‌دهيد بيناست.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcliv{قطعاً براى شما در [پيروى از] ابراهيم و كسانى كه با اويند سرمشقى نيكوست: آنگاه كه به قوم خود گفتند: «ما از شما و از آنچه به جاى خدا مى‌پرستيد بيزاريم. به شما كفر مى‌ورزيم و ميان ما و شما دشمنى و كينه هميشگى پديدار شده تا وقتى كه فقط به خدا ايمان آوريد.» جز [در] سخن ابراهيم [كه‌] به [نا]پدر[ى‌] خود [گفت:] «حتماً براى تو آمرزش خواهم خواست، با آنكه در برابر خدا اختيار چيزى را براى تو ندارم.» «اى پروردگار ما! بر تو اعتماد كرديم و به سوى تو بازگشتيم و فرجام به سوى توست.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmclv{پروردگارا، ما را وسيله آزمايش [و آماج آزار] براى كسانى كه كفر ورزيده‌اند مگردان، و بر ما ببخشاى كه تو خود تواناى سنجيده‌كارى.»\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmclvi{قطعاً براى شما در [پيروى از] آنان سرمشقى نيكوست [يعنى‌] براى كسى كه به خدا و روز بازپسين اميد مى‌بندد. و هر كس روى برتابد [بداند كه‌] خدا همان بى‌نياز ستوده‌[صفات‌] است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmclvii{اميد است كه خدا ميان شما و ميان كسانى از آنان كه [ايشان را] دشمن داشتيد، دوستى برقرار كند، و خدا تواناست، و خدا آمرزنده مهربان است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmclviii{[اما] خدا شما را از كسانى كه در [كار] دين با شما نجنگيده و شما را از ديارتان بيرون نكرده‌اند، باز نمى‌دارد كه با آنان نيكى كنيد و با ايشان عدالت ورزيد، زيرا خدا دادگران را دوست مى‌دارد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmclix{فقط خدا شما را از دوستى با كسانى باز مى‌دارد كه در [كار] دين با شما جنگ كرده و شما را از خانه‌هايتان بيرون رانده و در بيرون‌راندنتان با يكديگر همپشتى كرده‌اند. و هر كس آنان را به دوستى گيرد، آنان همان ستمگرانند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmclx{اى كسانى كه ايمان آورده‌ايد، چون زنان با ايمان مهاجر، نزد شما آيند آنان را بيازماييد. خدا به ايمان آنان داناتر است. پس اگر آنان را باايمان تشخيص داديد، ديگر ايشان را به سوى كافران بازنگردانيد: نه آن زنان بر ايشان حلالند و نه آن [مردان‌] بر اين زنان حلال. و هر چه خرج [اين زنان‌] كرده‌اند به [شوهران‌] آنها بدهيد، و بر شما گناهى نيست كه -در صورتى كه مَهرشان را به آنان بدهيد- با ايشان ازدواج كنيد، و به پيوندهاى قبلى كافران متمسك نشويد [و پايبند نباشيد ]و آنچه را شما [براى زنان مرتد و فرارى خود كه به كفار پناهنده شده‌اند] خرج كرده‌ايد، [از كافران‌] مطالبه كنيد، و آنها هم بايد آنچه را خرج كرده‌اند [از شما] مطالبه كنند. اين حكم خداست [كه‌] ميان شما داورى مى‌كند، و خدا داناى حكيم است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmclxi{و در صورتى كه [زنى‌] از همسران شما به سوى كفار رفت [و كفار مَهر مورد مطالبه شما را ندادند] و شما غنيمت يافتيد؛ پس به كسانى كه همسرانشان رفته‌اند، معادل آنچه خرج كرده‌اند بدهيد، و از آن خدايى كه به او ايمان داريد بترسيد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmclxii{اى پيامبر، چون زنان باايمان نزد تو آيند كه [با اين شرط] با تو بيعت كنند كه چيزى را با خدا شريك نسازند، و دزدى نكنند، و زنا نكنند، و فرزندان خود را نكشند، و بچه‌هاى حرامزاده پيش دست و پاى خود را با بهتان [و حيله‌] به شوهر نبندند، و در [كار] نيك از تو نافرمانى نكنند، با آنان بيعت كن و از خدا براى آنان آمرزش بخواه، زيرا خداوند آمرزنده مهربان است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmclxiii{اى كسانى كه ايمان آورده‌ايد، مردمى را كه خدا بر آنان خشم رانده، به دوستى مگيريد. آنها واقعاً از آخرت سلب اميد كرده‌اند، همان گونه كه كافران اهل گور قطع اميد نموده‌اند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmclxiv{\basmalahfa آنچه در آسمانها و آنچه در زمين است به تسبيح خدا مى‌پردازند، و اوست ارجمند حكيم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmclxv{اى كسانى كه ايمان آورده‌ايد، چرا چيزى مى‌گوييد كه انجام نمى‌دهيد؟\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmclxvi{نزد خدا سخت ناپسند است كه چيزى را بگوييد و انجام ندهيد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmclxvii{در حقيقت، خدا دوست دارد كسانى را كه در راه او صف در صف، چنانكه گويى بنايى ريخته شده از سرب‌اند، جهاد مى‌كنند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmclxviii{و [ياد كن‌] هنگامى را كه موسى به قوم خود گفت: «اى قوم من، چرا آزارم مى‌دهيد، با اينكه مى‌دانيد من فرستاده خدا به سوى شما هستم؟» پس چون [از حق‌] برگشتند، خدا دلهايشان را برگردانيد، و خدا مردم نافرمان را هدايت نمى‌كند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmclxix{و هنگامى را كه عيسى پسر مريم گفت: «اى فرزندان اسرائيل، من فرستاده خدا به سوى شما هستم. تورات را كه پيش از من بوده تصديق مى‌كنم و به فرستاده‌اى كه پس از من مى‌آيد و نام او «احمد» است بشارتگرم.» پس وقتى براى آنان دلايل روشن آورد، گفتند: «اين سحرى آشكار است.»\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmclxx{و چه كسى ستمگرتر از آن كس است كه با وجود آنكه به سوى اسلام فراخوانده مى شود، بر خدا دروغ مى‌بندد؟ و خدا مردم ستمگر را راه نمى‌نمايد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxi{مى‌خواهند نور خدا را با دهان خود خاموش كنند و حال آنكه خدا -گر چه كافران را ناخوش افتد- نور خود را كامل خواهد گردانيد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxii{اوست كسى كه فرستاده خود را با هدايت و آيين درست روانه كرد، تا آن را بر هر چه دين است فائق گرداند، هر چند مشركان را ناخوش آيد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxiii{اى كسانى كه ايمان آورده‌ايد، آيا شما را بر تجارتى راه نمايم كه شما را از عذابى دردناك مى‌رهاند؟\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxiv{به خدا و فرستاده او بگرويد و در راه خدا با مال و جانتان جهاد كنيد. اين [گذشت و فداكارى‌] اگر بدانيد، براى شما بهتر است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxv{تا گناهانتان را بر شما ببخشايد، و شما را در باغهايى كه از زير [درختان‌] آن جويبارها روان است و [در] سراهايى خوش، در بهشتهاى هميشگى درآورد. اين [خود] كاميابى بزرگ است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxvi{و [رحمتى‌] ديگر كه آن را دوست داريد: يارى و پيروزى نزديكى از جانب خداست. و مؤمنان را [بدان‌] بشارت ده.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxvii{اى كسانى كه ايمان آورده‌ايد، ياران خدا باشيد، همان گونه كه عيسى‌بن‌مريم به حواريون گفت: «ياران من در راه خدا چه كسانى‌اند؟» حواريون گفتند: «ما ياران خداييم.» پس طايفه‌اى كفر ورزيدند، و كسانى را كه گرويده بودند، بر دشمنانشان يارى كرديم تا چيره شدند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxviii{\basmalahfa آنچه در آسمانها و آنچه در زمين است، خدايى را كه پادشاه پاك ارجمند فرزانه است، تسبيح مى‌گويند.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxix{اوست آن كس كه در ميان بى‌سوادان فرستاده‌اى از خودشان برانگيخت، تا آيات او را بر آنان بخواند و پاكشان گرداند و كتاب و حكمت بديشان بياموزد، و [آنان‌] قطعاً پيش از آن در گمراهى آشكارى بودند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxx{و [نيز بر جماعتهايى‌] ديگر از ايشان كه هنوز به آنها نپيوسته‌اند. و اوست ارجمند سنجيده‌كار.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxi{اين فضل خداست، آن را به هر كه بخواهد عطا مى‌كند و خدا داراى فضل بسيار است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxii{مثل كسانى كه [عمل به‌] تورات بر آنان بار شد [و بدان مكلف گرديدند] آنگاه آن را به كار نبستند، همچون مثل خرى است كه كتابهايى را برپشت مى‌كشد. [وه‌] چه زشت است وصف آن قومى كه آيات خدا را به دروغ گرفتند. و خدا مردم ستمگر را راه نمى‌نمايد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxiii{بگو: «اى كسانى كه يهودى شده‌ايد، اگر پنداريد كه شما دوستان خداييد نه مردم ديگر، پس اگر راست مى‌گوييد درخواست مرگ كنيد.»\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxiv{و[لى‌] هرگز آن را به سبب آنچه از پيش به دست خويش كرده‌اند، آرزو نخواهند كرد، و خدا به [حال‌] ستمگران داناست.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxv{بگو: «آن مرگى كه از آن مى‌گريزيد، قطعاً به سر وقت شما مى‌آيد؛ آنگاه به سوى داناى نهان و آشكار بازگردانيده خواهيد شد، و به آنچه [در روى زمين‌] مى‌كرديد، آگاهتان خواهد كرد.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxvi{اى كسانى كه ايمان آورده‌ايد، چون براى نماز جمعه ندا درداده شد، به سوى ذكر خدا بشتابيد، و داد و ستد را واگذاريد. اگر بدانيد اين براى شما بهتر است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxvii{و چون نماز گزارده شد، در [روى‌] زمين پراكنده گرديد و فضل خدا را جويا شويد و خدا را بسيار ياد كنيد، باشد كه شما رستگار گرديد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxviii{و چون داد و ستد يا سرگرميى ببينند، به سوى آن روى‌آور مى‌شوند، و تو را در حالى كه ايستاده‌اى ترك مى‌كنند. بگو: «آنچه نزد خداست از سرگرمى و از داد و ستد بهتر است، و خدا بهترين روزى دهندگان است.»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmclxxxix{\basmalahfa چون منافقان نزد تو آيند گويند: «گواهى مى‌دهيم كه تو واقعاً پيامبر خدايى.» و خدا [هم‌] مى‌داند كه تو واقعاً پيامبر او هستى، و خدا گواهى مى‌دهد كه مردم دوچهره سخت دروغگويند.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcxc{سوگندهاى خود را [چون‌] سپرى بر خود گرفته و [مردم را] از راه خدا بازداشته‌اند. راستى كه آنان چه بد مى‌كنند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcxci{اين بدان سبب است كه آنان ايمان آورده، سپس به انكار پرداخته‌اند و در نتيجه بر دلهايشان مُهر زده شده و [ديگر] نمى‌فهمند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcxcii{و چون آنان را ببينى، هيكلهايشان تو را به تعجب وا مى‌دارد، و چون سخن گويند به گفتارشان گوش فرا مى‌دهى گويى آنان شمعك‌هايى پشت بر ديوارند [كه پوك شده و درخور اعتماد نيستند]: هر فريادى را به زيان خويش مى‌پندارند. خودشان دشمنند؛ از آنان بپرهيز؛ خدا بكشدشان؛ تا كجا [از حقيقت‌] انحراف يافته‌اند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcxciii{و چون بديشان گفته شود: «بياييد تا پيامبر خدا براى شما آمرزش بخواهد»، سرهاى خود را بر مى‌گردانند، و آنان را مى‌بينى كه تكبركنان روى برمى‌تابند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcxciv{براى آنان يكسان است: چه برايشان آمرزش بخواهى يا برايشان آمرزش نخواهى، خدا هرگز بر ايشان نخواهد بخشود. خدا فاسقان را راهنمايى نمى‌كند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcxcv{آنان كسانى‌اند كه مى‌گويند: «به كسانى كه نزد پيامبر خدايند انفاق مكنيد تا پراكنده شوند، و حال آنكه گنجينه‌هاى آسمانها و زمين از آنِ خداست ولى منافقان درنمى‌يابند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcxcvi{مى‌گويند: «اگر به مدينه برگرديم، قطعاً آنكه عزتمندتر است آن زبون‌تر را از آنجا بيرون خواهد كرد.» و[لى‌] عزت از آن خدا و از آن پيامبر او و از آن مؤمنان است؛ ليكن اين دورويان نمى‌دانند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcxcvii{اى كسانى كه ايمان آورده‌ايد، [زنهار] اموال شما و فرزندانتان شما را از ياد خدا غافل نگرداند، و هر كس چنين كند، آنان خود زيانكارانند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcxcviii{و از آنچه روزى شما گردانيده‌ايم، انفاق كنيد، پيش از آنكه يكى از شما را مرگ فرا رسد و بگويد: «پروردگارا، چرا تا مدتى بيشتر [اجل‌] مرا به تأخير نينداختى تا صدقه دهم و از نيكوكاران باشم؟»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcxcix{و[لى‌] هر كس اجلش فرا رسد، هرگز خدا [آن را] به تأخير نمى‌افكند، و خدا به آنچه مى‌كنيد آگاه است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcc{\basmalahfa هر چه در آسمانها و هر چه در زمين است خدا را تسبيح مى‌گويند. او راست فرمانروايى و او راست سپاس و او بر هر چيزى تواناست.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcci{اوست آن كس كه شما را آفريد؛ برخى از شما كافرند و برخى مؤمن و خدا به آنچه مى‌كنيد بيناست.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmccii{آسمانها و زمين را به حق آفريد و شما را صورتگرى كرد و صورتهايتان را نيكوآراست، و فرجام به سوى اوست.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcciii{آنچه را كه در آسمانها و زمين است مى‌داند، و آنچه را كه پنهان مى‌كنيد و آنچه را كه آشكار مى‌داريد [نيز] مى‌داند، و خدا به راز دلها داناست.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcciv{آيا خبر كسانى كه پيش از اين كفر ورزيدند، و فرجام بد كارشان را چشيدند و عذاب پر دردى خواهند داشت، به شما نرسيده است؟\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmccv{اين [بدفرجامى‌] از آن روى بود كه پيامبرانشان دلايل آشكار برايشان مى‌آوردند و[لى‌] آنان [مى‌]گفتند: «آيا بشرى ما را هدايت مى‌كند؟» پس كافر شدند و روى گردانيدند و خدا بى‌نيازى نمود، و خدا بى‌نياز ستوده‌است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmccvi{كسانى كه كفر ورزيدند، پنداشتند كه هرگز برانگيخته نخواهند شد. بگو: «آرى، سوگند به پروردگارم، حتماً برانگيخته خواهيد شد، سپس شما را به [حقيقت‌] آنچه كرده‌ايد قطعاً واقف خواهند ساخت، و اين بر خدا آسان است.»\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmccvii{پس به خدا و پيامبر او و آن نورى كه ما فرو فرستاديم ايمان آوريد، و خدا به آنچه مى‌كنيد آگاه است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmccviii{روزى كه شما را براى روز گردآورى، گرد مى‌آورد، آن [روز]، روز حسرت [خوردن‌] است، و هر كس به خدا ايمان آورده، و كار شايسته‌اى كرده باشد، بديهايش را از او بسترد، و او را در بهشتهايى كه از زير [درختان‌] آن جويبارها روان است درآورد. در آنجا بمانند. اين است همان كاميابى بزرگ.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmccix{و كسانى كه كفر ورزيده، و آيات ما را تكذيب كرده‌اند، آنان اهل آتشند [و ] در آن ماندگار خواهند بود، و چه بد سرانجامى است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmccx{هيچ مصيبتى جز به اذن خدا نرسد، و كسى كه به خدا بگرود، دلش را به راه آورد، و خدا[ست كه‌] به هر چيزى داناست.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmccxi{و خدا را فرمان بريد و پيامبر [او] را اطاعت نماييد، و اگر روى بگردانيد، بر پيامبر ما فقط پيام‌رسانى آشكار است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmccxii{خدا[ست كه‌] جز او معبودى نيست، و مؤمنان بايد تنها بر خدا اعتماد كنند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmccxiii{اى كسانى كه ايمان آورده‌ايد، در حقيقت برخى از همسران شما و فرزندان شما دشمن شمايند، از آنان بر حذر باشيد، و اگر ببخشاييد و درگذريد و بيامرزيد، به راستى خدا آمرزنده مهربان است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmccxiv{اموال شما و فرزندانتان صرفاً [وسيله‌] آزمايشى [براى شما]يند، و خداست كه نزد او پاداشى بزرگ است.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmccxv{پس تا مى‌توانيد از خدا پروا بداريد و بشنويد و فرمان ببريد، و مالى براى خودتان [در راه خدا] انفاق كنيد، و كسانى كه از خسّت نفس خويش مصون مانند، آنان رستگارانند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmccxvi{اگر خدا را وامى نيكو دهيد، آن را براى شما دو چندان مى‌گرداند و بر شما مى‌بخشايد، و خدا[ست كه‌] سپاس‌پذير بردبار است.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmccxvii{داناى نهان و آشكار [و] ارجمند سنجيده‌كار است.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmccxviii{\basmalahfa اى پيامبر، چون زنان را طلاق گوييد، در [زمان‌بندى‌] عدّه آنان طلاقشان گوييد و حساب آن عدّه را نگه داريد، و از خدا، پروردگارتان بترسيد. آنان را از خانه‌هايشان بيرون مكنيد، و بيرون نروند مگر آنكه مرتكب كار زشت آشكارى شده باشند. اين است احكام الهى. و هر كس از مقررات خدا [پاى‌] فراتر نهد، قطعاً به خودش ستم كرده است. نمى‌دانى، شايد خدا پس از اين، پيشامدى پديد آورد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmccxix{پس چون عدّه آنان به سر رسيد، [يا] به شايستگى نگاهشان داريد، يا به شايستگى از آنان جدا شويد، و دو تن [مرد] عادل را از ميان خود گواه گيريد، و گواهى را براى خدا به پا داريد. اين است اندرزى كه به آن كس كه به خدا و روز بازپسين ايمان دارد، داده مى‌شود، و هر كس از خدا پروا كند، [خدا] براى او راه بيرون‌شدنى قرار مى‌دهد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmccxx{و از جايى كه حسابش را نمى‌كند، به او روزى مى‌رساند، و هر كس بر خدا اعتماد كند او براى وى بس است. خدا فرمانش را به انجام‌رساننده است. به راستى خدا براى هر چيزى اندازه‌اى مقرر كرده است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxi{و آن زنان شما كه از خون‌ديدن [ماهانه‌] نوميدند، اگر شك داريد [كه خون مى‌بينند يا نه؟] عدّه آنان سه ماه است، و [دخترانى‌] كه [هنوز] خون نديده‌اند [نيز عدّه‌شان سه ماه است‌]، و زنان آبستن مدّتشان اين است كه وضع حمل كنند، و هر كس از خدا پروا دارد [خدا] براى او در كارش تسهيلى فراهم سازد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxii{اين است فرمان خدا كه آن را به سوى شما فرستاده است؛ و هر كس از خدا پروا كند، بديهايش را از او بزدايد و پاداشش را بزرگ گرداند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxiii{همانجا كه [خود] سكونت داريد، به قدر استطاعت خويش آنان را جاى دهيد و به آنها آسيب [و زيان‌] مرسانيد تا عرصه را بر آنان تنگ كنيد. و اگر باردارند خرجشان را بدهيد تا وضع حمل كنند. و اگر براى شما [بچه‌] شير مى‌دهند مزدشان را به ايشان بدهيد و به شايستگى ميان خود به مشورت پردازيد، و اگر كارتان [در اين مورد] با هم به دشوارى كشيد [زن‌] ديگرى [بچّه را] شير دهد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxiv{بر توانگر است كه از دارايى خود هزينه كند، و هر كه روزى او تنگ باشد بايد از آنچه خدا به او داده خرج كند. خدا هيچ كس را جز [به قدر] آنچه به او داده است تكليف نمى‌كند. خدا به زودى پس از دشوارى آسانى فراهم مى‌كند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxv{و چه بسيار شهرها كه از فرمان پروردگار خود و پيامبرانش سر پيچيدند و از آنها حسابى سخت كشيديم و آنان را به عذابى [بس‌] زشت عذاب كرديم.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxvi{تا كيفر زشت عمل خود را چشيدند، و پايان كارشان زيان بود.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxvii{خدا براى آنان عذابى سخت آماده كرده است. پس اى خردمندانى كه ايمان آورده‌ايد، از خدا بترسيد. راستى كه خدا سوى شما تذكارى فرو فرستاده است:\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxviii{پيامبرى كه آيات روشنگر خدا را بر شما تلاوت مى‌كند، تا كسانى را كه ايمان آورده و كارهاى شايسته كرده‌اند از تاريكيها به سوى روشنايى بيرون برد، و هر كس به خدا بگرود و كار شايسته كند او را در باغهايى كه از زير [درختان‌] آن جويبارها روان است، درمى‌آورد، جاودانه در آن مى‌مانند. قطعاً خدا روزى را براى او خوش كرده است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxix{خدا همان كسى است كه هفت آسمان و همانند آنها هفت زمين آفريد. فرمان [خدا] در ميان آنها فرود مى‌آيد، تا بدانيد كه خدا بر هر چيزى تواناست، و به راستى دانش وى هر چيزى را در بر گرفته است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxx{\basmalahfa اى پيامبر، چرا براى خشنودى همسرانت، آنچه را خدا براى تو حلال گردانيده حرام مى‌كنى؟ خدا[ست كه‌] آمرزنده مهربان است.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxi{قطعاً خدا براى شما [راه‌] گشودن سوگندهايتان را مقرر داشته است، و خدا سرپرست شماست، و اوست داناى حكيم.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxii{و چون پيامبر با يكى از همسرانش سخنى نهانى گفت، و همين كه وى آن را [به زن ديگر] گزارش داد و خدا [پيامبر] را بر آن مطلع گردانيد [پيامبر] بخشى از آن را اظهار كرد و از بخشى [ديگر] اعراض نمود. پس چون [مطلب‌] را به آن [زن‌] خبر داد، وى گفت: «چه كسى اين را به تو خبر داده؟» گفت: «مرا آن داناى آگاه خبر داده است.»\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxiii{اگر [شما دو زن‌] به درگاه خدا توبه كنيد [بهتر است‌]، واقعاً دلهايتان انحراف پيدا كرده است. و اگر عليه او به يكديگر كمك كنيد، در حقيقت، خدا خود سرپرست اوست، و جبرئيل و صالح مؤمنان [نيز ياور اويند] و گذشته از اين، فرشتگان [هم ]پشتيبان [او] خواهند بود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxiv{اگر پيامبر، شما را طلاق گويد، اميد است پروردگارش همسرانى بهتر از شما: مسلمان، مؤمن، فرمانبر، توبه كار، عابد، روزه‌دار، بيوه و دوشيزه به او عوض دهد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxv{اى كسانى كه ايمان آورده‌ايد، خودتان و كسانتان را از آتشى كه سوخت آن، مردم و سنگهاست حفظ كنيد: بر آن [آتش‌] فرشتگانى خشن [و] سختگير [گمارده شده‌] اند. از آنچه خدا به آنان دستور داده سرپيچى نمى‌كنند و آنچه را كه مأمورند انجام مى‌دهند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxvi{اى كسانى كه كافر شده‌ايد، امروز عذر نياوريد، در واقع به آنچه مى‌كرديد كيفر مى‌يابيد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxvii{اى كسانى كه ايمان آورده‌ايد، به درگاه خدا توبه‌اى راستين كنيد، اميد است كه پروردگارتان بديهايتان را از شما بزدايد و شما را به باغهايى كه از زير [درختان‌] آن جويبارها روان است درآورد. در آن روز خدا پيامبر [خود] و كسانى را كه با او ايمان آورده بودند خوار نمى‌گرداند: نورشان از پيشاپيش آنان، و سمت راستشان، روان است. مى‌گويند: «پروردگارا، نور ما را براى ما كامل گردان و بر ما ببخشاى، كه تو بر هر چيز توانايى.»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxviii{اى پيامبر، با كافران و منافقان جهاد كن و بر آنان سخت گير [كه‌] جاى ايشان در جهنّم خواهد بود و چه بد سرانجامى است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmccxxxix{خدا براى كسانى كه كفر ورزيده‌اند، آن نوح و آن لوط را مَثَل آورده [كه‌] هر دو در نكاح دو بنده از بندگان شايسته ما بودند و به آنها خيانت كردند، و كارى از دست [شوهران‌] آنها در برابر خدا ساخته نبود، و گفته شد: «با داخل شوندگان داخل آتش شويد.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmccxl{و براى كسانى كه ايمان آورده‌اند، خدا همسر فرعون را مثل آورده، آنگاه كه گفت: «پروردگارا، پيش خود در بهشت خانه‌اى برايم بساز، و مرا از فرعون و كردارش نجات ده، و مرا از دست مردم ستمگر برهان.»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmccxli{و مريم دخت عمران را، همان كسى كه خود را پاكدامن نگاه داشت و در او از روح خود دميديم و سخنان پروردگار خود و كتابهاى او را تصديق كرد و از فرمانبرداران بود.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmccxlii{\basmalahfa بزرگوار [و خجسته‌] است آنكه فرمانروايى به دست اوست و او بر هر چيزى تواناست.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmccxliii{همانكه مرگ و زندگى را پديد آورد تا شما را بيازمايد كه كدامتان نيكوكارتريد، و اوست ارجمند آمرزنده.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmccxliv{همان كه هفت آسمان را طبقه طبقه بيافريد. در آفرينش آن [خداى‌] بخشايشگر هيچ گونه اختلاف [و تفاوتى‌] نمى‌بينى. بازبنگر، آيا خلل [و نقصانى‌] مى‌بينى؟\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmccxlv{باز دوباره بنگر تا نگاهت زبون و درمانده به سويت بازگردد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmccxlvi{و در حقيقت، آسمان دنيا را با چراغهايى زينت داديم و آن را مايه طرد شياطين [= قواى مزاحم‌] گردانيديم و براى آنها عذاب آتش فروزان آماده كرده‌ايم.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmccxlvii{و كسانى كه به پروردگارشان انكار آوردند، عذاب آتش جهنم خواهند داشت و چه بد سرانجامى است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmccxlviii{چون در آنجا افكنده شوند، از آن خروشى مى‌شنوند در حالى كه مى‌جوشد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmccxlix{نزديك است كه از خشم شكافته شود. هر بار كه گروهى در آن افكنده شوند، نگاهبانان آن از ايشان پرسند: «مگر شما را هشدار دهنده‌اى نيامد؟»\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmccl{گويند: «چرا، هشدار دهنده‌اى به سوى ما آمد و[لى‌] تكذيب كرديم و گفتيم: خدا چيزى فرو نفرستاده است، شما جز در گمراهى بزرگ نيستيد.»\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmccli{و گويند: «اگر شنيده [و پذيرفته‌] بوديم يا تعقل كرده بوديم در [ميان‌] دوزخيان نبوديم.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcclii{پس به گناه خود اقرار مى‌كنند. و مرگ باد بر اهل جهنم\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmccliii{كسانى كه در نهان از پروردگارشان مى‌ترسند، آنان را آمرزش و پاداشى بزرگ خواهد بود.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmccliv{و [اگر] سخن خود را پنهان داريد، يا آشكارش نماييد، در حقيقت وى به راز دلها آگاه است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcclv{آيا كسى كه آفريده است نمى‌داند؟ با اينكه او خود باريك بين آگاه است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcclvi{اوست كسى كه زمين را براى شما رام گردانيد، پس در فراخناى آن رهسپار شويد و از روزى [خدا] بخوريد و رستاخيز به سوى اوست.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcclvii{آيا از آن كس كه در آسمان است ايمن شده‌ايد كه شما را در زمين فرو برد، پس بناگاه [زمين‌] به تپيدن افتد؟\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcclviii{يا از آن كس كه در آسمان است ايمن شده‌ايد كه بر [سر] شما تندبادى از سنگريزه فرو فرستد؟ پس به زودى خواهيد دانست كه بيم دادن من چگونه است\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcclix{و پيش از آنان [نيز] كسانى به تكذيب پرداختند پس عذاب من چگونه بود؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcclx{آيا در بالاى سرشان به پرندگان ننگريسته‌اند [كه گاه‌] بال مى‌گسترند و [گاه‌] بال مى‌آنند؟ جز خداى رحمان [كسى‌] آنها را نگاه نمى‌دارد، او به هر چيزى بيناست.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxi{يا آن كسى كه خود براى شما [چون‌] سپاهى است كه ياريتان مى‌كند، جز خداى رحمان كيست؟ كافران جز گرفتار فريب نيستند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxii{يا كيست آن كه به شما روزى دهد اگر [خدا] روزى خود را [از شما] باز دارد؟ [نه‌] بلكه در سركشى و نفرت پافشارى كردند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxiii{پس آيا آن كس كه نگونسار راه مى‌پيمايد هدايت يافته تر است يا آن كس كه ايستاده بر راه راست مى‌رود؟\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxiv{بگو: «اوست آن كس كه شما را پديد آورده و براى شما گوش و ديدگان و دلها آفريده است. چه كم سپاسگزاريد.»\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxv{بگو: «اوست كه شما را در زمين پراكنده كرده، و به نزد او [ست كه‌] گرد آورده خواهيد شد.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxvi{و مى‌گويند: «اگر راست مى‌گوييد، اين وعده كى خواهد بود؟»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxvii{بگو: «علم [آن‌] فقط پيش خداست و من صرفاً هشدار دهنده‌اى آشكارم.»\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxviii{و آنگاه كه آن [لحظه موعود] را نزديك ببينند، چهره‌هاى كسانى كه كافر شده‌اند در هم رود، و گفته شود: «اين است همان چيزى كه آن را فرا مى‌خوانديد»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxix{بگو: «به من خبر دهيد، اگر خدا مرا و هر كه را با من است هلاك كند يا ما را مورد رحمت قرار دهد، چه كسى كافران را از عذابى پر درد پناه خواهد داد؟»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxx{بگو: «اوست خداى بخشايشگر، به او ايمان آورديم، و بر او توكل كرديم. و به زودى خواهيد دانست چه كسى است كه خود در گمراهى آشكارى است.»\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxi{بگو: «به من خبر دهيد، اگر آب [آشاميدنى‌] شما [به زمين‌] فرو رود، چه كسى آب روان برايتان خواهد آورد؟»\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxii{\basmalahfa نون، سوگند به قلم و آنچه مى‌نويسند،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxiii{[كه‌] تو، به لطف پروردگارت، ديوانه نيستى.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxiv{و بى‌گمان، تو را پاداشى بى‌منت خواهد بود.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxv{و راستى كه تو را خويى والاست\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxvi{به زودى خواهى ديد و خواهند ديد،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxvii{[كه‌] كدام يك از شما دستخوش جنونيد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxviii{پروردگارت خود بهتر مى‌داند چه كسى از راه او منحرف شده، و [هم‌] او به راه يافتگان داناتر است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxix{پس، از دروغزنان فرمان مبر.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxx{دوست دارند كه نرمى كنى تا نرمى نمايند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxi{و از هر قسم خورنده فرو مايه‌اى فرمان مبر:\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxii{[كه‌] عيبجوست و براى خبرچينى گام برمى‌دارد،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxiii{مانع خير، متجاوز، گناه پيشه،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxiv{گستاخ، [و] گذشته از آن زنازاده است،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxv{به صرف اينكه مالدار و پسردار است،\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxvi{چون آيات ما بر او خوانده شود، گويد: «افسانه‌هاى پيشينيان است.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxvii{زودا كه بر بينى‌اش داغ نهيم [و رسوايش كنيم‌].\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxviii{ما آنان را همان گونه كه باغداران را آزموديم، مورد آزمايش قرار داديم، آنگاه كه سوگند خوردند كه صبح برخيزند و [ميوه‌] آن [باغ‌] را حتماً بچينند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcclxxxix{و[لى‌] «ان شاء الله» نگفتند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmccxc{پس در حالى كه آنان غنوده بودند، بلايى از جانب پروردگارت بر آن [باغ‌] به گردش در آمد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmccxci{و [باغ،] آفت زده [و زمين باير] گرديد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmccxcii{پس [باغداران‌] بامدادان يكديگر را صدا زدند،\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmccxciii{كه: «اگر ميوه مى‌چينيد، بامدادان به سوى كشت خويش رويد.»\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmccxciv{پس به راه افتادند و آهسته به هم مى‌گفتند\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmccxcv{«كه: امروز نبايد در باغ بينوايى بر شما در آيد.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmccxcvi{و صبحگاهان در حالى كه خود را بر منع [بينوايان‌] توانا مى‌ديدند، رفتند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmccxcvii{و چون [باغ‌] را ديدند، گفتند: «قطعاً ما راه گم كرده‌ايم.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmccxcviii{[نه‌] بلكه ما محروميم.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmccxcix{خردمندترينشان گفت: «آيا به شما نگفتم: چرا خدا را به پاكى نمى‌ستاييد؟»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmccc{گفتند: «پروردگارا، تو را به پاكى مى‌ستاييم، ما واقعاً ستمگر بوديم. «\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmccci{پس بعضى‌شان رو به بعضى ديگر آوردند و همديگر را به نكوهش گرفتند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmcccii{گفتند: «اى واى بر ما كه سركش بوده‌ايم\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmccciii{اميد است كه پروردگار ما بهتر از آن را به ما عوض دهد، زيرا ما به پروردگارمان مشتاقيم.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmccciv{عذاب [دنيا] چنين است، و عذاب آخرت، اگر مى‌دانستند قطعاً بزرگتر خواهد بود.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmcccv{براى پرهيزگاران، نزد پروردگارشان باغستانهاى پر ناز و نعمت است.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmcccvi{پس آيا فرمانبرداران را چون بدكاران قرار خواهيم داد؟\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmcccvii{شما را چه شده؟ چگونه داورى مى‌كنيد؟\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmcccviii{يا شما را كتابى هست كه در آن فرا مى‌گيريد،\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmcccix{كه هر چه را برمى‌گزينيد، براى شما در آن خواهد بود؟\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmcccx{يا اينكه شما تا روز قيامت [از ما] سوگندهايى رسا گرفته‌ايد كه هر چه دلتان خواست حكم كنيد؟\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxi{از آنان بپرس: كدامشان ضامن اين [ادعا] يند؟\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxii{يا شريكانى دارند؟ پس اگر راست مى‌گويند شريكانشان را بياورند.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxiii{روزى كه كار، زار [و رهايى دشوار] شود و به سجده فرا خوانده شوند و در خود توانايى نيابند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxiv{ديدگانشان به زير افتاده، خوارى آنان را فرو مى‌گيرد، در حالى كه [پيش از اين‌] به سجده دعوت مى‌شدند و تندرست بودند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxv{پس مرا با كسى كه اين گفتار را تكذيب مى‌كند واگذار. به تدريج آنان را به گونه‌اى كه در نيابند [گريبان‌] خواهيم گرفت،\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxvi{و مهلتشان مى‌دهم، زيرا تدبير من [سخت‌] استوار است.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxvii{آيا از آنان مزدى درخواست مى‌كنى، و آنان خود را زير بار تاوان، گرانبار مى‌يابند؟\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxviii{يا [علم‌] غيب پيش آنهاست و آنها مى‌نويسند؟\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxix{پس در [امتثال‌] حكم پروردگارت شكيبايى ورز، و مانند همدم ماهى [=يونس‌] مباش، آنگاه كه اندوه زده ندا درداد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxx{اگر لطفى از جانب پروردگارش تدارك [حال‌] او نمى‌كرد، قطعاً نكوهش شده بر زمين خشك انداخته مى‌شد.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxi{پس پروردگارش وى را برگزيد و از شايستگانش گردانيد.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxii{و آنان كه كافر شدند، چون قرآن را شنيدند چيزى نمانده بود كه تو را چشم بزنند، و مى‌گفتند: «او واقعاً ديوانه‌اى است.»\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxiii{و حال آنكه [قرآن‌] جز تذكارى براى جهانيان نيست.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxiv{\basmalahfa آن رخ دهنده.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxv{چيست آن رخ دهنده؟\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxvi{و چه دانى كه آن رخ دهنده چيست؟\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxvii{ثمود و عاد، آن حادثه كوبنده را تكذيب كردند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxviii{اما ثمود به [سزاى‌] سركشى [خود] به هلاكت رسيدند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxix{و اما عاد، به [وسيله‌] تندبادى توفنده سركش هلاك شدند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxx{[كه خدا] آن را هفت شب و هشت روز پياپى بر آنان بگماشت: در آن [مدت‌] مردم را فرو افتاده مى‌ديدى، گويى آنها تنه‌هاى نخلهاى ميان تهى‌اند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxi{آيا از آنان كسى را بر جاى مى‌بينى؟\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxii{و فرعون و كسانى كه پيش از او بودند و [مردم‌] شهرهاى سرنگون شده [سدوم و عاموره‌] مرتكب خطا شدند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxiii{و از امر فرستاده پروردگارشان سرپيچى كردند، و [خدا هم‌] آنان را به گرفتنى سخت، فرو گرفت.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxiv{ما، چون آب طغيان كرد، شما را بر كشتى سوار نموديم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxv{تا آن را براى شما [مايه‌] تذكرى گردانيم و گوشهاى شنوا آن را نگاه دارد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxvi{پس آنگاه كه در صور يك بار دميده شود.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxvii{و زمين و كوه‌ها از جاى خود برداشته شوند و هر دوى آنها با يك تكان ريز ريز گردند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxviii{پس آن روز است كه واقعه [آنچنانى‌] وقوع يابد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxxxix{و آسمان از هم بشكافد، و در آن روز است كه آن از هم گسسته باشد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxl{و فرشتگان در اطراف [آسمان‌]اند، و عرش پروردگارت را آن روز، هشت [فرشته ] بر سر خود بر مى‌دارند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxli{در آن روز، شما [به پيشگاه خدا] عرضه مى‌شويد، [و] پوشيده‌اى از شما پوشيده نمى‌ماند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxlii{اما كسى كه كارنامه‌اش به دست راستش داده شود، گويد: «بياييد و كتابم را بخوانيد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxliii{من يقين داشتم كه به حساب خود مى‌رسم.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxliv{پس او در يك زندگى خوش است:\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxlv{در بهشتى برين،\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxlvi{[كه‌] ميوه هايش در دسترس است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxlvii{بخوريد و بنوشيد، گواراتان باد، به [پاداش‌] آنچه در روزهاى گذشته انجام داديد.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxlviii{و اما كسى كه كارنامه‌اش به دست چپش داده شود، گويد: «اى كاش كتابم را دريافت نكرده بودم.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxlix{و از حساب خود خبردار نشده بودم.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmcccl{اى كاش آن [مرگ‌] كار را تمام مى‌كرد.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmcccli{مال من، مرا سودى نبخشيد.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmccclii{قدرت من از [كف‌] من برفت.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmcccliii{[گويند:] «بگيريد او را و در غل كشيد.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmcccliv{آنگاه ميان آتشش اندازيد.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmccclv{پس در زنجيرى كه درازى آن هفتاد گز است وى را در بند كشيد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmccclvi{چرا كه او به خداى بزرگ نمى‌گرويد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmccclvii{و به اطعام مسكين تشويق نمى‌كرد.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmccclviii{پس امروز او را در اينجا حمايتگرى نيست.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmccclix{و خوراكى جز چركابه ندارد،\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmccclx{كه آن را جز خطاكاران نمى‌خورند.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxi{پس نه [چنان است كه مى‌پنداريد]، سوگند ياد مى‌كنم به آنچه مى‌بينيد،\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxii{و آنچه نمى‌بينيد،\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxiii{كه [قرآن‌] قطعاً گفتار فرستاده‌اى بزرگوار است.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxiv{و آن گفتار شاعرى نيست [كه‌] كمتر [به آن‌] ايمان داريد.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxv{و نه گفتار كاهنى [كه‌] كمتر [از آن‌] پند مى‌گيريد.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxvi{[پيام‌] فرودآمده‌اى است از جانب پروردگار جهانيان.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxvii{و اگر [او] پاره‌اى گفته‌ها بر ما بسته بود،\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxviii{دست راستش را سخت مى‌گرفتيم،\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxix{سپس رگ قلبش را پاره مى‌كرديم،\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxx{و هيچ يك از شما مانع از [عذاب‌] او نمى‌شد.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxi{و در حقيقت، [قرآن‌] تذكارى براى پرهيزگاران است.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxii{و ما به راستى مى‌دانيم كه از [ميان‌] شما تكذيب‌كنندگانى هستند.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxiii{و آن واقعاً بر كافران حسرتى است.\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxiv{و اين [قرآن‌]، بى‌شبهه، حقيقتى يقينى است.\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxv{پس به [پاس‌] نام پروردگار بزرگت تسبيح گوى.\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxvi{\basmalahfa پرسنده‌اى از عذاب واقع‌شونده‌اى پرسيد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxvii{كه اختصاص به كافران دارد [و] آن را بازدارنده‌اى نيست.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxviii{[و] از جانب خداوند صاحب درجات [و مراتب‌] است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxix{فرشتگان و روح، در روزى كه مقدارش پنجاه هزار سال است به سوى «او» بالا مى‌روند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxx{پس صبر كن، صبرى نيكو.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxi{زيرا آنان [عذاب‌] را دور مى‌بينند،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxii{و [ما] نزديكش مى‌بينيم.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxiii{روزى كه آسمانها چون فلز گداخته شود،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxiv{و كوهها چون پشم زده گردد،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxv{و هيچ دوست صميمى از دوست صميمى [حال‌] نپرسد،\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxvi{آنان را به ايشان نشان مى‌دهند. گناهكار آرزو مى‌كند كه كاش براى رهايى از عذاب آن روز، مى توانست پسران خود را عوض دهد،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxvii{و [نيز] همسرش و برادرش را،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxviii{و قبيله‌اش را كه به او پناه مى‌دهد،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmccclxxxix{و هر كه را كه در روى زمين است همه را [عوض مى‌داد] و آنگاه خود را رها مى‌كرد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxc{نه چنين است. [آتش‌] زبانه مى‌كشد،\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxci{پوست سر و اندام را بركننده است.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxcii{هر كه را پشت كرده و روى برتافته،\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxciii{و گرد آورده و انباشته [و حسابش را نگاه داشته‌] فرا مى‌خواند.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxciv{به راستى كه انسان سخت آزمند [و بى‌تاب‌] خلق شده است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxcv{چون صدمه‌اى به او رسد عجز و لابه كند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxcvi{و چون خيرى به او رسد بخل ورزد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxcvii{غير از نمازگزاران:\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxcviii{همان كسانى كه بر نمازشان پايدارى مى‌كنند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmcccxcix{و همانان كه در اموالشان حقى معلوم است،\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmcd{براى سائل و محروم.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmcdi{و كسانى كه روز جزا را باور دارند.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmcdii{و آنان كه از عذاب پروردگارشان بيمناكند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmcdiii{چرا كه از عذاب پروردگارشان ايمن نمى‌توانند بود.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmcdiv{و كسانى كه دامن خود را حفظ مى‌كنند،\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmcdv{مگر بر همسران خود يا كنيزانشان كه [در اين صورت‌] مورد نكوهش نيستند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmcdvi{و هر كس پا از اين [حد] فراتر نهد، آنان همان از حد درگذرندگانند.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmcdvii{و كسانى كه امانتها و پيمان خود را مراعات مى‌كنند.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmcdviii{و آنان كه بر شهادتهاى خود ايستاده‌اند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmcdix{و كسانى كه بر نمازشان مداومت مى‌ورزند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmcdx{آنها هستند كه در باغهايى [از بهشت‌]، گرامى خواهند بود.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxi{چه شده است كه آنان كه كفر ورزيده‌اند، به سوى تو شتابان،\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxii{گروه گروه، از راست و از چپ [هجوم مى‌آورند]؟\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxiii{آيا هر يك از آنان طمع مى‌بندد كه در بهشت پر نعمت درآورده شود؟\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxiv{نه چنين است. ما آنان را از آنچه [خود] مى‌دانند آفريديم.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxv{[هرگز،] به پروردگار خاوران و باختران سوگند ياد مى‌كنم كه ما تواناييم،\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxvi{كه به جاى آنان بهتر از ايشان را بياوريم؛ و بر ما پيشى نتوانند جست.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxvii{پس بگذارشان ياوه گويند و بازى كنند تا روزى را كه وعده داده شده‌اند ملاقات نمايند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxviii{روزى كه از گورها[ى خود] شتابان برآيند، گويى كه آنان به سوى پرچمهاى افراشته مى دوند.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxix{ديدگانشان فرو افتاده، [غبار] مذلّت آنان را فرو گرفته است. اين است همان روزى كه به ايشان وعده داده مى‌شد.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxx{\basmalahfa ما نوح را به سوى قومش فرستاديم كه: «قومت را، پيش از آنكه عذابى دردناك به آنان رسد، هشدار ده.»\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxi{[نوح‌] گفت: «اى قوم من، من شما را هشدار دهنده‌اى آشكارم،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxii{كه خدا را بپرستيد و از او پروا داريد و مرا فرمان بريد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxiii{[تا] برخى از گناهانتان را بر شما ببخشايد و [اجل‌] شما را تا وقتى معين به تأخير اندازد. اگر بدانيد، چون وقت مقرر خدا برسد، تأخير بر نخواهد داشت.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxiv{[نوح‌] گفت: «پروردگارا، من قوم خود را شب و روز دعوت كردم،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxv{و دعوت من جز بر گريزشان نيفزود.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxvi{و من هر بار كه آنان را دعوت كردم تا ايشان را بيامرزى، انگشتانشان را در گوشهايشان كردند و رداى خويشتن بر سر كشيدند و اصرار ورزيدند و هر چه بيشتر بر كبر خود افزودند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxvii{سپس من آشكارا آنان را دعوت كردم.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxviii{باز من به آنان اعلام نمودم و در خلوت [و] پوشيده نيز به ايشان گفتم.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxix{و گفتم: از پروردگارتان آمرزش بخواهيد كه او همواره آمرزنده است.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxx{[تا] بر شما از آسمان باران پى در پى فرستد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxi{و شما را به اموال و پسران، يارى كند، و برايتان باغها قرار دهد و نهرها براى شما پديد آورد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxii{شما را چه شده است كه از شكوه خدا بيم نداريد؟\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxiii{و حال آنكه شما را مرحله به مرحله خلق كرده است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxiv{مگر ملاحظه نكرده‌ايد كه چگونه خدا هفت آسمان را تُوبرتُو آفريده است؟\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxv{و ماه را در ميان آنها روشنايى‌بخش گردانيد و خورشيد را [چون‌] چراغى قرار داد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxvi{و خدا[ست كه‌] شما را [مانند] گياهى از زمين رويانيد؛\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxvii{سپس شما را در آن بازمى‌گرداند و بيرون مى‌آورد بيرون‌آوردنى [عجيب‌]!\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxviii{و خدا زمين را براى شما فرشى [گسترده‌] ساخت،\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxxxix{تا در راههاى فراخ آن برويد.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxl{نوح گفت: «پروردگارا، آنان نافرمانى من كردند و كسى را پيروى نمودند كه مال و فرزندش جز بر زيان وى نيفزود.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxli{و دست به نيرنگى بس بزرگ زدند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxlii{و گفتند: زنهار، خدايان خود را رها مكنيد، و نه «وَدّ» را واگذاريد و نه «سُواع» و نه «يَغُوث» و نه «يَعُوق» و نه «نَسْر» را.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxliii{و بسيارى را گمراه كرده‌اند. [بار خدايا،] جز بر گمراهى ستمكاران ميفزاى.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxliv{[تا] به سبب گناهانشان غرقه گشتند و [پس از مرگ‌] در آتشى درآورده شدند و براى خود، در برابر خدا يارانى نيافتند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxlv{و نوح گفت: «پروردگارا، هيچ كس از كافران را بر روى زمين مگذار،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxlvi{چرا كه اگر تو آنان را باقى گذارى، بندگانت را گمراه مى‌كنند و جز پليدكار ناسپاس نزايند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxlvii{پروردگارا، بر من و پدر و مادرم و هر مؤمنى كه در سرايم درآيد، و بر مردان و زنان با ايمان ببخشاى، و جز بر هلاكت ستمگران ميفزاى.»\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxlviii{\basmalahfa بگو: «به من وحى شده است كه تنى چند از جنّيان گوش فرا داشتند و گفتند: راستى ما قرآنى شگفت‌آور شنيديم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxlix{[كه‌] به راه راست هدايت مى‌كند. پس به آن ايمان آورديم و هرگز كسى را شريك پروردگارمان قرار نخواهيم داد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcdl{و اينكه او، پروردگار والاى ما، همسر و فرزندى اختيار نكرده است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcdli{و [شگفت‌] آنكه كم خرد ما، در باره خدا سخنانى ياوه مى‌سرايد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlii{و ما پنداشته بوديم كه انس و جن هرگز به خدا دروغ نمى‌بندند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcdliii{و مردانى از آدميان به مردانى از جن پناه مى‌بردند و بر سركشى آنها مى‌افزودند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcdliv{و آنها [نيز] آن گونه كه [شما] پنداشته‌ايد، گمان بردند كه خدا هرگز كسى را زنده نخواهد گردانيد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlv{و ما بر آسمان دست يافتيم و آن را پر از نگهبانان توانا و تيرهاى شهاب يافتيم.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlvi{و در [آسمان‌] براى شنيدن، به كمين مى‌نشستيم، [اما] اكنون هر كه بخواهد به گوش باشد، تير شهابى در كمين خود مى‌يابد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlvii{و ما [درست‌] نمى‌دانيم كه آيا براى كسانى كه در زمينند بدى خواسته شده يا پروردگارشان برايشان هدايت خواسته است؟\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlviii{و از ميان ما برخى درستكارند و برخى غير آن، و ما فرقه‌هايى گوناگونيم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlix{و ما مى‌دانيم كه هرگز نمى‌توانيم در زمين خداى را به ستوه آوريم، و هرگز او را با گريز [خود] درمانده نتوانيم كرد\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlx{و ما چون هدايت را شنيديم بدان گرويديم؛ پس كسى كه به پروردگار خود ايمان آورد، از كمى [پاداش‌] و سختى بيم ندارد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxi{و از ميان ما برخى فرمانبردار و برخى از ما منحرفند: پس كسانى كه به فرمانند، آنان در جستجوى راه درستند،\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxii{ولى منحرفان، هيزم جهنم خواهند بود.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxiii{و اگر [مردم‌] در راه درست، پايدارى ورزند، قطعاً آب گوارايى بديشان نوشانيم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxiv{تا در اين باره آنان را بيازماييم، و هر كس از ياد پروردگار خود دل بگرداند، وى را در قيد عذابى [روز]افزون درآورد.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxv{و مساجد ويژه خداست، پس هيچ كس را با خدا مخوانيد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxvi{و همين كه «بنده خدا» برخاست تا او را بخواند، چيزى نمانده بود كه بر سر وى فرو افتند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxvii{بگو: «من تنها پروردگار خود را مى‌خوانم و كسى را با او شريك نمى‌گردانم.»\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxviii{بگو: «من براى شما اختيار زيان و هدايتى را ندارم.»\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxix{بگو: «هرگز كسى مرا در برابر خدا پناه نمى‌دهد و هرگز پناهگاهى غير از او نمى‌يابم.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxx{[وظيفه من‌] تنها ابلاغى از خدا و [رساندن‌] پيامهاى اوست.» و هر كس خدا و پيامبرش را نافرمانى كند قطعاً آتش دوزخ براى اوست و جاودانه در آن خواهند ماند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxi{[باش‌] تا آنچه را وعده داده مى‌شوند ببينند، آنگاه دريابند كه ياور چه كسى ضعيف‌تر و كدام يك شماره‌اش كمتر است.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxii{بگو: «نمى‌دانم آنچه را كه وعده داده شده‌ايد نزديك است يا پروردگارم براى آن زمانى نهاده است؟»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxiii{داناى نهان است، و كسى را بر غيب خود آگاه نمى‌كند،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxiv{جز پيامبرى را كه از او خشنود باشد، كه [در اين صورت‌] براى او از پيش رو و از پشت سرش نگاهبانانى بر خواهد گماشت،\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxv{تا معلوم بدارد كه پيامهاى پروردگار خود را رسانيده‌اند؛ و [خدا] بدانچه نزد ايشان است احاطه دارد و هر چيزى را به عدد شماره كرده است.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxvi{\basmalahfa اى جامه به خويشتن فرو پيچيده،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxvii{به پا خيز شب را مگر اندكى،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxviii{نيمى از شب يا اندكى از آن را بكاه،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxix{يا بر آن [نصف‌] بيفزاى و قرآن را شمرده شمرده بخوان.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxx{در حقيقت ما به زودى بر تو گفتارى گرانبار القا مى‌كنيم.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxi{قطعاً برخاستن شب، رنجش بيشتر و گفتار [در آن هنگام‌] راستين‌تر است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxii{[و] تو را، در روز، آمد و شدى دراز است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxiii{و نام پروردگار خود را ياد كن و تنها به او بپرداز.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxiv{[اوست‌] پروردگار خاور و باختر، خدايى جز او نيست، پس او را كارساز خويش اختيار كن.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxv{و بر آنچه مى‌گويند شكيبا باش و از آنان با دورى گزيدنى خوش فاصله بگير.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxvi{و مرا با تكذيب‌كنندگان توانگر واگذار و اندكى مهلتشان ده.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxvii{در حقيقت پيش ما زنجيرها و دوزخ،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxviii{و غذايى گلوگير و عذابى پر درد است.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcdlxxxix{روزى كه زمين و كوهها به لرزه درآيند و كوهها به سان ريگ روان گردند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxc{بى‌گمان، ما به سوى شما فرستاده‌اى كه گواه بر شماست روانه كرديم، همان گونه كه فرستاده‌اى به سوى فرعون فرستاديم.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxci{[ولى‌] فرعون به آن فرستاده عصيان ورزيد، پس ما او را به سختى فرو گرفتيم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxcii{پس اگر كفر بورزيد، چگونه از روزى كه كودكان را پير مى‌گرداند، پرهيز توانيد كرد؟\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxciii{آسمان از [بيم‌] آن [روز] در هم شكافد؛ وعده او انجام يافتنى است.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxciv{قطعاً اين [آيات‌] اندرزى است، تا هر كه بخواهد به سوى پروردگار خود راهى در پيش گيرد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxcv{در حقيقت، پروردگارت مى‌داند كه تو و گروهى از كسانى كه با تواند، نزديك به دو سوم از شب يا نصف آن يا يك سوم آن را [به نماز] برمى‌خيزيد، و خداست كه شب و روز را اندازه‌گيرى مى‌كند. [او ]مى‌داند كه [شما] هرگز حساب آن را نداريد، پس بر شما ببخشود، [اينك‌] هر چه از قرآن ميسر مى‌شود بخوانيد. [خدا] مى‌داند كه به زودى در ميانتان بيمارانى خواهند بود، و [عده‌اى‌] ديگر در زمين سفر مى‌كنند [و] در پى روزى خدا هستند، و [گروهى‌] ديگر در راه خدا پيكار مى‌نمايند. پس هر چه از [قرآن‌] ميسر شد تلاوت كنيد و نماز را برپا داريد و زكات را بپردازيد و وام نيكو به خدا دهيد؛ و هر كار خوبى براى خويش از پيش فرستيد آن را نزد خدا بهتر و با پاداشى بيشتر باز خواهيد يافت. و از خدا طلب آمرزش كنيد كه خدا آمرزنده مهربان است.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxcvi{\basmalahfa اى كشيده رداى شب بر سر،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxcvii{برخيز و بترسان.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxcviii{و پروردگار خود را بزرگ دار.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcdxcix{و لباس خويشتن را پاك كن.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmd{و از پليدى دور شو.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdi{و منّت مگذار و فزونى مطلب.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdii{و براى پروردگارت شكيبايى كن.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdiii{پس چون در صور دميده شود،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdiv{آن روز [چه‌] روز ناگوارى است!\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdv{بر كافران آسان نيست.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdvi{مرا با آنكه [او را] تنها آفريدم واگذار.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdvii{و دارايى بسيار به او بخشيدم،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdviii{و پسرانى آماده [به خدمت، دادم‌]،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdix{و برايش [عيش خوش‌] آماده كردم.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdx{باز [هم‌] طمع دارد كه بيفزايم.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdxi{ولى نه، زيرا او دشمن آيات ما بود.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdxii{به زودى او را به بالارفتن از گردنه [عذاب‌] وادار مى‌كنم.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdxiii{آرى، [آن دشمن حق‌] انديشيد و سنجيد.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdxiv{كشته بادا، چگونه [او] سنجيد؟\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdxv{[آرى،] كشته بادا، چگونه [او] سنجيد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdxvi{آنگاه نظر انداخت.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdxvii{سپس رو ترش نمود و چهره در هم كشيد.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdxviii{آنگاه پشت گردانيد و تكبّر ورزيد،\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdxix{و گفت: «اين [قرآن‌] جز سحرى كه [به برخى‌] آموخته‌اند نيست.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdxx{اين غير از سخن بشر نيست.»\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxi{زودا كه او را به سَقَر در آورم.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxii{و تو چه دانى كه آن سَقَر چيست؟\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxiii{نه باقى مى‌گذارد و نه رها مى‌كند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxiv{پوستها را سياه مى‌گرداند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxv{[و] بر آن [دوزخ‌]، نوزده [نگهبان‌] است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxvi{و ما موكّلان آتش را جز فرشتگان نگردانيديم، و شماره آنها را جز آزمايشى براى كسانى كه كافر شده‌اند قرار نداديم، تا آنان كه اهل كتابند يقين به هم رسانند، و ايمان كسانى كه ايمان آورده‌اند افزون گردد، و آنان كه كتاب به ايشان داده شده و [نيز] مؤمنان به شك نيفتند، و تا كسانى كه در دلهايشان بيمارى است و كافران بگويند: «خدا از اين وصف‌كردن، چه چيزى را اراده كرده است؟» اين گونه، خدا هر كه را بخواهد بيراه مى‌گذارد و هر كه را بخواهد هدايت مى كند، و [شماره‌] سپاهيان پروردگارت را جز او نمى‌داند، و اين [آيات‌] جز تذكارى براى بشر نيست.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxvii{نه چنين است [كه مى‌پندارند!] سوگند به ماه،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxviii{و سوگند به شامگاه چون پشت كند،\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxix{و سوگند به بامداد چون آشكار شود،\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxx{كه آيات [قرآن‌] از پديده‌هاى بزرگ است.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxi{بشر را هشداردهنده است.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxii{هر كه از شما را كه بخواهد پيشى جويد يا بازايستد.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxiii{هر كسى در گرو دستاورد خويش است،\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxiv{بجز ياران دست راست:\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxv{در ميان باغها. از يكديگر مى‌پرسند،\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxvi{درباره مجرمان:\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxvii{«چه چيز شما را در آتش [سَقَر] درآورد؟»\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxviii{گويند: «از نمازگزاران نبوديم،\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmmdxxxix{و بينوايان را غذا نمى‌داديم،\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmmdxl{با هرزه‌درايان هرزه‌درايى مى‌كرديم،\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmmdxli{و روز جزا را دروغ مى‌شمرديم،\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmmdxlii{تا مرگ ما در رسيد.»\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmmdxliii{از اين رو شفاعت شفاعت‌كنندگان به حال آنها سودى نمى‌بخشد.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmmdxliv{چرا آنها از تذكر روى گردانند؟!\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmmdxlv{گويى گورخرانى رميده‌اند،\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmmdxlvi{كه از (مقابل) شيرى فرار كرده‌اند!\qt@no{(51)}}
\qt@newcmd\qurantrans@fa@mmmmmdxlvii{بلكه هر كدام از آنها انتظار دارد نامه جداگانه‌اى (از سوى خدا) براى او فرستاده شود!\qt@no{(52)}}
\qt@newcmd\qurantrans@fa@mmmmmdxlviii{چنين نيست كه آنان مى‌گويند، بلكه آنها از آخرت نمى‌ترسند!\qt@no{(53)}}
\qt@newcmd\qurantrans@fa@mmmmmdxlix{چنين نيست كه آنها مى‌گويند، آن (قرآن) يك تذكر و يادآورى است!\qt@no{(54)}}
\qt@newcmd\qurantrans@fa@mmmmmdl{هر كس بخواهد از آن پند مى‌گيرد؛\qt@no{(55)}}
\qt@newcmd\qurantrans@fa@mmmmmdli{و هيچ كس پند نمى‌گيرد مگر اينكه خدا بخواهد؛ او اهل تقوا و اهل آمرزش است!\qt@no{(56)}}
\qt@newcmd\qurantrans@fa@mmmmmdlii{\basmalahfa سوگند به روز قيامت،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdliii{و سوگند به (نفس لوّامه و) وجدان بيدار و ملامتگر (كه رستاخيز حقّ است)!\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdliv{آيا انسان مى‌پندارد كه هرگز استخوانهاى او را جمع نخواهيم كرد؟!\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdlv{آرى قادريم كه (حتى خطوط سر) انگشتان او را موزون و مرتّب كنيم!\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdlvi{(انسان شك در معاد ندارد) بلكه او مى‌خواهد (آزاد باشد و بدون ترس از دادگاه قيامت) در تمام عمر گناه كند!\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdlvii{(از اين‌رو) مى‌پرسد: «قيامت كى خواهد بود»!\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdlviii{(بگو:) در آن هنگام كه چشمها از شدّت وحشت به گردش در آيد،\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdlix{و ماه بى‌نور گردد،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdlx{و خورشيد و ماه يك جا جمع شوند،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxi{آن روز انسان مى‌گويد: «راه فرار كجاست؟!»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxii{هرگز چنين نيست، راه فرار و پناهگاهى وجود ندارد!\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxiii{آن روز قرارگاه نهايى تنها بسوى پروردگار تو است؛\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxiv{و در آن روز انسان را از تمام كارهايى كه از پيش يا پس فرستاده آگاه مى‌كنند!\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxv{بلكه انسان خودش از وضع خود آگاه است،\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxvi{هر چند (در ظاهر) براى خود عذرهايى بتراشد!\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxvii{زبانت را بخاطر عجله براى خواندن آن [= قرآن‌] حركت مده،\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxviii{چرا كه جمع‌كردن و خواندن آن بر عهده ماست!\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxix{پس هر گاه آن را خوانديم، از خواندن آن پيروى كن!\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxx{سپس بيان (و توضيح) آن (نيز) بر عهده ماست!\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxi{چنين نيست كه شما مى‌پنداريد (و دلايل معاد را كافى نمى‌دانيد)؛ بلكه شما دنياى زودگذر را دوست داريد (و هوسرانى بى‌قيد و شرط را)!\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxii{و آخرت را رها مى‌كنيد!\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxiii{(آرى) در آن روز صورتهايى شاداب و مسرور است،\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxiv{و به پروردگارش مى‌نگرد!\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxv{و در آن روز صورتهايى عبوس و در هم كشيده است،\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxvi{زيرا مى‌داند عذابى در پيش دارد كه پشت را در هم مى‌شكند!\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxvii{چنين نيست (كه انسان مى‌پندارد! او ايمان نمى‌آورد) تا موقعى كه جان به گلوگاهش رسد،\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxviii{و گفته شود: «آيا كسى هست كه(اين بيمار را از مرگ) نجات دهد؟!»\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxix{و به جدائى از دنيا يقين پيدا كند،\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxx{و ساق پاها (از سختى جان دادن) به هم بپيچد!\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxi{(آرى) در آن روز مسير همه بسوى (دادگاه) پروردگارت خواهد بود!\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxii{(در آن روز گفته مى‌شود:) او هرگز ايمان نياورد و نماز نخواند،\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxiii{بلكه تكذيب كرد و روى‌گردان شد،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxiv{سپس بسوى خانواده خود باز گشت در حالى كه متكبّرانه قدم برمى‌داشت!\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxv{(با اين اعمال) عذاب الهى براى تو شايسته‌تر است، شايسته‌تر!\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxvi{سپس عذاب الهى براى تو شايسته‌تر است، شايسته‌تر!\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxvii{آيا انسان گمان مى‌كند بى‌هدف رها مى‌شود؟!\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxviii{آيا او نطفه‌اى از منى كه در رحم ريخته مى‌شود نبود؟!\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmdlxxxix{سپس بصورت خون‌بسته در آمد، و خداوند او را آفريد و موزون ساخت،\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmdxc{و از او دو زوج مرد و زن آفريد!\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmdxci{آيا چنين كسى قادر نيست كه مردگان را زنده كند؟!\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmdxcii{\basmalahfa آيا زمانى طولانى بر انسان گذشت كه چيز قابل ذكرى نبود؟!\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdxciii{ما انسان را از نطفه مختلطى آفريديم، و او را مى‌آزماييم؛ (بدين جهت) او را شنوا و بينا قرار داديم!\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdxciv{ما راه را به او نشان داديم، خواه شاكر باشد (و پذيرا گردد) يا ناسپاس!\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdxcv{ما براى كافران، زنجيرها و غُلها و شعله‌هاى سوزان آتش آماده كرده‌ايم!\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdxcvi{به يقين ابرار (و نيكان) از جامى مى‌نوشند كه با عطر خوشى آميخته است،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdxcvii{چشمه‌اى كه بندگان خدا از آن مى‌نوشند و [به دلخواه خويش‌] جاريش مى‌كنند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdxcviii{[همان بندگانى كه‌] به نذر خود وفا مى‌كردند، و از روزى كه گزند آن فراگيرنده است مى‌ترسيدند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdxcix{و به [پاس‌] دوستى [خدا]، بينوا و يتيم و اسير را خوراك مى‌دادند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdc{«ما براى خشنودى خداست كه به شما مى‌خورانيم و پاداش و سپاسى از شما نمى‌خواهيم.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdci{ما از پروردگارمان از روز عبوسى سخت، هراسناكيم.»\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdcii{پس خدا [هم‌] آنان را از آسيب آن روز نگاه داشت و شادابى و شادمانى به آنان ارزانى داشت.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdciii{و به [پاس‌] آنكه صبر كردند، بهشت و پرنيان پاداششان داد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdciv{در آن [بهشت‌] بر تختها[ى خويش‌] تكيه زنند. در آنجا نه آفتابى بينند و نه سرمايى.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdcv{و سايه‌ها[ى درختان‌] به آنان نزديك است، و ميوه‌هايش [براى چيدن‌] رام.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdcvi{و ظروف سيمين و جامهاى بلورين، پيرامون آنان گردانده مى‌شود.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdcvii{جامهايى از سيم كه درست به اندازه [و با كمال ظرافت‌] آنها را از كار در آورده‌اند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdcviii{و در آنجا از جامى كه آميزه زنجبيل دارد به آنان مى‌نوشانند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdcix{از چشمه‌اى در آنجا كه «سلسبيل» ناميده مى‌شود.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdcx{و بر گرد آنان پسرانى جاودانى مى‌گردند. چون آنها را ببينى، گويى كه مرواريدهايى پراكنده‌اند.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxi{و چون بدانجا نگرى [سرزمينى از] نعمت و كشورى پهناور مى‌بينى.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxii{[بهشتيان را] جامه‌هاى ابريشمى سبز و ديباى ستبر در بر است و پيرايه آنان دستبندهاى سيمين است و پروردگارشان باده‌اى پاك به آنان مى‌نوشاند.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxiii{اين [پاداش‌] براى شماست و كوشش شما مقبول افتاده است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxiv{در حقيقت، ما قرآن را بر تو به تدريج فرو فرستاديم.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxv{پس در برابر فرمان پروردگارت شكيبايى كن، و از آنان گناهكار يا ناسپاسگزار را فرمان مبر.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxvi{و نام پروردگارت را بامدادان و شامگاهان ياد كن.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxvii{و بخشى از شب را در برابر او سجده كن و شب‌[هاى‌] دراز، او را به پاكى بستاى.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxviii{اينان دنياى زودگذر را دوست دارند، و روزى گرانبار را [به غفلت‌] پشت سر مى‌افكنند.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxix{ماييم كه آنان را آفريده و پيوند مفاصل آنها را استوار كرده‌ايم، و چون بخواهيم، [آنان را] به نظايرشان تبديل مى‌كنيم.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxx{اين [آيات،] پندنامه‌اى است. تا هر كه خواهد، راهى به سوى پروردگار خود پيش گيرد.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxi{و تا خدا نخواهد، [شما] نخواهيد خواست؛ قطعاً خدا داناى حكيم است.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxii{هر كه را خواهد، به رحمت خويش در مى‌آورد، و براى ظالمان عذابى پردرد آماده كرده است.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxiii{\basmalahfa سوگند به فرستادگان پى‌درپى،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxiv{كه سخت توفنده‌اند.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxv{و سوگند به افشانندگان افشانگر،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxvi{كه [ميان حق و باطل‌] جداگرند،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxvii{و القاكننده وحى‌اند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxviii{خواه عذرى باشد يا هشدارى.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxix{كه آنچه وعده يافته‌ايد قطعاً رخ خواهد داد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxx{پس وقتى كه ستارگان محو شوند،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxi{و آنگاه كه آسمان بشكافد،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxii{و آنگاه كه كوه‌ها از جا كنده شوند،\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxiii{و آنگاه كه پيمبران به ميقات آيند،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxiv{براى چه روزى تعيين وقت شده است؟\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxv{براى روز داورى.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxvi{و تو چه دانى كه روز داورى چيست؟\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxvii{آن روز واى بر تكذيب‌كنندگان!\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxviii{مگر پيشينيان را هلاك نكرديم؟\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxxxix{سپس از پى آنان پسينيان را مى‌بريم.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxl{با مجرمان چنين مى‌كنيم.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxli{آن روز واى بر تكذيب‌كنندگان.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxlii{مگر شما را از آبى بى‌مقدار نيافريديم؟\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxliii{پس آن را در جايگاهى استوار نهاديم،\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxliv{تا مدّتى معيّن!\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxlv{و توانا آمديم، و چه نيك تواناييم.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxlvi{آن روز واى بر تكذيب‌كنندگان.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxlvii{مگر زمين را محل اجتماع نگردانيديم؟\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxlviii{چه براى مردگان چه زندگان.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxlix{و كوه‌هاى بلند در آن نهاديم و به شما آبى گوارا نوشانيديم.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdcl{آن روز واى بر تكذيب‌كنندگان.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdcli{برويد به سوى همان چيزى كه آن را تكذيب مى‌كرديد.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdclii{برويد به سوى [آن‌] دود سه شاخه،\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmdcliii{نه سايه‌دار است و نه از شعله [آتش‌] حفاظت مى‌كند.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmdcliv{[دوزخ‌] چون كاخى [بلند] شراره مى‌افكند،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmdclv{گويى شترانى زرد رنگند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmdclvi{آن روز واى بر تكذيب‌كنندگان.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmdclvii{اين، روزى است كه دم نمى‌زنند.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmdclviii{و رخصت نمى‌يابند تا پوزش خواهند.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmdclix{آن روز واى بر تكذيب‌كنندگان.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmdclx{اين [همان‌] روز داورى است شما و [جمله‌] پيشينيان را گرد مى‌آوريم.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxi{پس اگر حيلتى داريد، در برابر من بسگاليد.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxii{آن روز واى بر تكذيب‌كنندگان.\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxiii{اهل تقوا در زير سايه‌ها و بر كنار چشمه‌سارانند،\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxiv{با هر ميوه‌اى كه خوش داشته باشند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxv{به [پاداش‌] آنچه مى‌كرديد، بخوريد و بياشاميد؛ گواراتان باد.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxvi{ما نيكوكاران را چنين پاداش مى‌دهيم.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxvii{آن روز واى بر تكذيب‌كنندگان.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxviii{[اى كافران،] بخوريد و اندكى برخوردار شويد كه شما گناهكاريد.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxix{[ولى‌] آن روز واى بر تكذيب‌كنندگان.\qt@no{(47)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxx{و چون به آنان گفته شود: «ركوع كنيد»، به ركوع نمى‌روند.\qt@no{(48)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxi{آن روز واى بر تكذيب‌كنندگان.\qt@no{(49)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxii{پس به كدامين سخن پس از [قرآن‌] ايمان مى‌آورند؟\qt@no{(50)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxiii{\basmalahfa درباره چه چيز از يكديگر مى‌پرسند؟\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxiv{از آن خبر بزرگ،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxv{كه در باره آن با هم اختلاف دارند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxvi{نه چنان است، به زودى خواهند دانست.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxvii{باز هم نه چنان است، بزودى خواهند دانست.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxviii{آيا زمين را گهواره‌اى نگردانيديم؟\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxix{و كوهها را [چون‌] ميخهايى [نگذاشتيم‌]؟\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxx{و شما را جفت آفريديم.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxi{و خواب شما را [مايه‌] آسايش گردانيديم.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxii{و شب را [براى شما] پوششى قرار داديم.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxiii{و روز را [براى‌] معاش [شما] نهاديم.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxiv{و بر فراز شما هفت [آسمان‌] استوار بنا كرديم.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxv{و چراغى فروزان گذارديم.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxvi{و از ابرهاى متراكم، آبى ريزان فرود آورديم،\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxvii{تا بدان دانه و گياه برويانيم،\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxviii{و باغهاى در هم پيچيده و انبوه.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdclxxxix{قطعاً وعدگاه [ما با شما] روز داورى است:\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxc{روزى كه در «صور» دميده شود، و گروه گروه بياييد؛\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxci{و آسمان، گشوده و درهايى [پديد] شود؛\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxcii{و كوهها را روان كنند، و [چون‌] سرابى گردند.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxciii{[آرى،] جهنم [از دير باز] كمينگاهى بوده،\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxciv{[كه‌] براى سركشان، بازگشتگاهى است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxcv{روزگارى دراز در آن درنگ كنند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxcvi{در آنجا نه خنكى چشند و نه شربتى،\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxcvii{جز آب جوشان و چركابه‌اى.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxcviii{كيفرى مناسب [با جرم آنها].\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdcxcix{آنان بودند كه به [روز] حساب اميد نداشتند؛\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdcc{و آيات ما را سخت تكذيب مى‌كردند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdcci{و حال آنكه هر چيزى را برشمرده [به صورت‌] كتابى در آورده‌ايم.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdccii{پس بچشيد كه جز عذاب، هرگز [چيزى‌] بر شما نمى‌افزاييم.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmdcciii{مسلماً پرهيزگاران را رستگارى است:\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmdcciv{باغچه‌ها و تاكستانها،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmdccv{و دخترانى همسال با سينه‌هاى برجسته،\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmdccvi{و پياله‌هاى لبالب.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmdccvii{در آنجا نه بيهوده‌اى شنوند، و نه [يكديگر را] تكذيب [كنند].\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmdccviii{[اين است‌] پاداشى از پروردگار تو، عطايى از روى حساب.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmdccix{پروردگار آسمانها و زمين و آنچه ميان آن دو است، بخشايشگرى كه كس را ياراى خطاب با او نيست.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmdccx{روزى كه «روح» و فرشتگان به صف مى‌ايستند، و [مردم‌] سخن نگويند، مگر كسى كه [خداى‌] رحمان به او رخصت دهد، و سخن راست گويد.\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxi{آن [روز]، روز حق است؛ پس هر كه خواهد، راه بازگشتى به سوى پروردگار خود بجويد.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxii{ما شما را از عذابى نزديك هشدار داديم: روزى كه آدمى آنچه را با دست خويش پيش فرستاده است بنگرد؛ و كافر گويد: «كاش من خاك بودم.»\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxiii{\basmalahfa سوگند به فرشتگانى كه [از كافران‌] به سختى جان ستانند،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxiv{و به فرشتگانى كه جان [مؤمنان‌] را به آرامى گيرند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxv{و به فرشتگانى كه [در درياى بى‌مانند] شناكنان شناورند،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxvi{پس در پيشى گرفتن [در فرمان خدا] سبقت‌گيرنده‌اند،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxvii{و كار [بندگان‌] را تدبير مى‌كنند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxviii{آن روز كه لرزنده بلرزد،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxix{و از پى آن لرزه‌اى [دگر] افتد،\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxx{در آن روز، دلهايى سخت هراسانند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxi{ديدگان آنها فرو افتاده.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxii{گويند: «آيا [باز] ما به [مغاك‌] زمين برمى‌گرديم؟\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxiii{آيا وقتى ما استخوان‌ريزه‌هاى پوسيده شديم [زندگى را از سر مى‌گيريم‌]؟»\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxiv{[و با خود] گويند: «در اين صورت، اين برگشتى زيان‌آور است.»\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxv{و[لى‌] در حقيقت، آن [بازگشت، بسته به‌] يك فرياد است [و بس‌].\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxvi{و بناگاه آنان در زمين هموار خواهند بود.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxvii{آيا سرگذشت موسى بر تو آمد؟\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxviii{آنگاه كه پروردگارش او را در وادى مقدس «طوى» ندا درداد:\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxix{«به سوى فرعون برو كه وى سر برداشته است؛\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxx{و بگو: آيا سر آن دارى كه به پاكيزگى گرايى،\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxi{و تو را به سوى پروردگارت راه نمايم تا پروا بدارى؟»\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxii{پس معجزه بزرگ [خود] را بدو نمود.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxiii{و[لى فرعون‌] تكذيب نمود و عصيان كرد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxiv{سپس پشت كرد [و] به كوشش برخاست،\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxv{و گروهى را فراهم آورد [و] ندا درداد،\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxvi{و گفت: «پروردگار بزرگتر شما منم!»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxvii{و خدا [هم‌] او را به كيفر دنيا و آخرت گرفتار كرد.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxviii{در حقيقت، براى هر كس كه [از خدا] بترسد، در اين [ماجرا] عبرتى است.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxxxix{آيا آفرينش شما دشوارتر است يا آسمانى كه [او] آن را برپا كرده است؟\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxl{سقفش را برافراشت و آن را [به اندازه معين‌] درست كرد،\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxli{و شبش را تيره و روزش را آشكار گردانيد،\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxlii{و پس از آن، زمين را با غلتانيدن گسترد،\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxliii{آبش و چراگاهش را از آن بيرون آورد،\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxliv{و كوهها را لنگر آن گردانيد،\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxlv{[تا وسيله‌] استفاده براى شما و دامهايتان باشد.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxlvi{پس آنگاه كه آن هنگامه بزرگ دررسد،\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxlvii{[آن‌] روز است كه انسان آنچه را كه در پى آن كوشيده است به ياد آورد\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxlviii{و جهنم براى هر كه بيند آشكار گردد.\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxlix{اما هر كه طغيان كرد،\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmdccl{و زندگى پست دنيا را برگزيد،\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmdccli{پس جايگاه او همان آتش است.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclii{و اما كسى كه از ايستادن در برابر پروردگارش هراسيد، و نفس خود را از هوس باز داشت...\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmdccliii{پس جايگاه او همان بهشت است.\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmmdccliv{در باره رستاخيز از تو مى‌پرسند كه فرارسيدنش چه وقت است؟\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclv{تو را چه به گفتگو در آن.\qt@no{(43)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclvi{علم آن با پروردگار تو است.\qt@no{(44)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclvii{تو فقط كسى را كه از آن مى‌ترسد هشدار مى‌دهى.\qt@no{(45)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclviii{روزى كه آن را مى‌بينند، گويى كه آنان جز شبى يا روزى درنگ نكرده‌اند.\qt@no{(46)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclix{\basmalahfa چهره در هم كشيد و روى گردانيد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclx{كه آن مرد نابينا پيش او آمد؛\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxi{و تو چه دانى، شايد او به پاكى گرايد،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxii{يا پند پذيرد و اندرز سودش دهد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxiii{اما آن كس كه خود را بى‌نياز مى‌پندارد،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxiv{تو بدو مى‌پردازى؛\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxv{با آنكه اگر پاك نگردد، بر تو [مسؤوليتى‌] نيست.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxvi{و اما آن كس كه شتابان پيش تو آمد،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxvii{در حالى كه [از خدا] مى‌ترسيد،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxviii{تو از او به ديگران مى‌پردازى.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxix{زنهار [چنين مكن‌] اين [آيات‌] پندى است.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxx{تا هر كه خواهد، از آن پند گيرد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxi{در صحيفه‌هايى ارجمند،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxii{والا و پاك‌شده،\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxiii{به دست فرشتگانى،\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxiv{ارجمند و نيكوكار.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxv{كشته باد انسان، چه ناسپاس است\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxvi{او را از چه چيز آفريده است؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxvii{از نطفه‌اى خلقش كرد و اندازه مقررش بخشيد.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxviii{سپس راه را بر او آسان گردانيد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxix{آنگاه به مرگش رسانيد و در قبرش نهاد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxx{سپس چون بخواهد او را برانگيزد.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxi{ولى نه! هنوز آنچه را به او دستور داده، به جاى نياورده است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxii{پس انسان بايد به خوراك خود بنگرد،\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxiii{كه ما آب را به صورت بارشى فرو ريختيم؛\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxiv{آنگاه زمين را با شكافتنى [لازم‌] شكافتيم؛\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxv{پس در آن، دانه رويانيديم.\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxvi{و انگور و سبزى،\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxvii{و زيتون و درخت خرما،\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxviii{و باغهاى انبوه،\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmdcclxxxix{و ميوه و چراگاه،\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxc{[تا وسيله‌] استفاده شما و دامهايتان باشد.\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxci{پس چون فرياد گوش‌خراش دررسد؛\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxcii{روزى كه آدمى از برادرش،\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxciii{و از مادرش و پدرش.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxciv{و از همسرش و پسرانش مى‌گريزد،\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxcv{در آن روز، هر كسى از آنان را كارى است كه او را به خود مشغول مى‌دارد.\qt@no{(37)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxcvi{در آن روز، چهره‌هايى درخشانند،\qt@no{(38)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxcvii{خندان [و] شادانند.\qt@no{(39)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxcviii{و در آن روز، چهره‌هايى است كه بر آنها غبار نشسته،\qt@no{(40)}}
\qt@newcmd\qurantrans@fa@mmmmmdccxcix{[و] آنها را تاريكى پوشانده است؛\qt@no{(41)}}
\qt@newcmd\qurantrans@fa@mmmmmdccc{آنان همان كافران بدكارند.\qt@no{(42)}}
\qt@newcmd\qurantrans@fa@mmmmmdccci{\basmalahfa آنگاه كه خورشيد به هم درپيچد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccii{و آنگه كه ستارگان همى‌تيره شوند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdccciii{و آنگاه كه كوهها به رفتار آيند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdccciv{وقتى شتران ماده وانهاده شوند،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccv{و آنگه كه وحوش را همى‌گرد آرند،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccvi{درياها آنگه كه جوشان گردند،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccvii{و آنگاه كه جانها به هم درپيوندند،\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccviii{پرسند چو زان دخترك زنده به‌گور:\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccix{به كدامين گناه كشته شده است؟\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccx{و آنگاه كه نامه‌ها زهم بگشايند،\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxi{و آنگاه كه آسمان زجا كنده شود،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxii{و آنگه كه جحيم را برافروزانند،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxiii{و آنگه كه بهشت را فرا پيش آرند،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxiv{هر نَفْس بداند چه فراهم ديده.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxv{نه، نه! سوگند به اختران گردان،\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxvi{[كز ديده‌] نهان شوند و از نو آيند،\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxvii{سوگند به شب چون پشت گرداند،\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxviii{سوگند به صبح چون دميدن گيرد،\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxix{كه [قرآن‌] سخن فرشته بزرگوارى است.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxx{نيرومند [كه‌] پيش خداوند عرش، بلندپايگاه است.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxi{در آنجا [هم‌] مطاع [و هم‌] امين است.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxii{و رفيق شما مجنون نيست؛\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxiii{و قطعاً آن [فرشته وحى‌] را در افق رخشان ديده.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxiv{و او در امر غيب بخيل نيست.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxv{و [قرآن‌] نيست سخن ديو رجيم.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxvi{پس به كجا مى‌رويد؟\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxvii{اين [سخن‌] بجز پندى براى عالميان نيست؛\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxviii{براى هر يك از شما كه خواهد به راه راست رود.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxix{و تا خدا، پروردگار جهانها، نخواهد، [شما نيز] نخواهيد خواست.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxx{\basmalahfa آنگاه كه آسمان زهم بشكافد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxi{و آنگاه كه اختران پراكنده شوند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxii{و آنگاه كه درياها از جا بركنده گردند،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxiii{و آنگاه كه گورها زير و زبر شوند،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxiv{هر نفسى آنچه را پيش فرستاده و بازپس گذاشته، بداند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxv{اى انسان، چه چيز تو را در باره پروردگار بزرگوارت مغرور ساخته؟\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxvi{همان كس كه تو را آفريد، و [اندام‌] تو را درست كرد، و [آنگاه‌] تو را سامان بخشيد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxvii{و به هر صورتى كه خواست، تو را تركيب كرد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxviii{با اين همه، شما منكر [روز] جزاييد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxxxix{و قطعاً بر شما نگهبانانى [گماشته شده‌]اند:\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxl{[فرشتگان‌] بزرگوارى كه نويسندگان [اعمال شما] هستند؛\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxli{آنچه را مى‌كنيد، مى‌دانند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxlii{قطعاً نيكان به بهشت اندرند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxliii{و بى‌شك، بدكاران در دوزخند.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxliv{روز جزا در آنجا درآيند،\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxlv{و از آن [عذاب‌] دور نخواهند بود.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxlvi{و تو چه دانى كه چيست روز جزا؟\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxlvii{باز چه دانى كه چيست روز جزا؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxlviii{روزى كه كسى براى كسى هيچ اختيارى ندارد؛ و در آن روز، فرمان از آنِ خداست.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxlix{\basmalahfa واى بر كم‌فروشان،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccl{كه چون از مردم پيمانه ستانند، تمام ستانند؛\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccli{و چون براى آنان پيمانه يا وزن كنند، به ايشان كم دهند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclii{مگر آنان گمان نمى‌دارند كه برانگيخته خواهند شد؟\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccliii{[در] روزى بزرگ:\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccliv{روزى كه مردم در برابر پروردگار جهانيان به پاى ايستند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclv{نه چنين است [كه مى‌پندارند]، كه كارنامه بدكاران در «سجّين» است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclvi{و تو چه دانى كه «سجّين» چيست؟\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclvii{كتابى است نوشته‌شده.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclviii{واى بر تكذيب‌كنندگان در آن هنگام:\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclix{آنان كه روز جزا را دروغ مى‌پندارند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclx{و جز هر تجاوزپيشه گناهكارى آن را به دروغ نمى‌گيرد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxi{[همان كه‌] چون آيات ما بر او خوانده شود، گويد: «[اينها] افسانه‌هاى پيشينيان است.»\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxii{نه چنين است، بلكه آنچه مرتكب مى‌شدند زنگار بر دلهايشان بسته است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxiii{زهى پندار، كه آنان در آن روز، از پروردگارشان سخت محجوبند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxiv{آنگاه به يقين، آنان به جهنم درآيند.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxv{سپس [به ايشان‌] گفته خواهد شد: «اين همان است كه آن را به دروغ مى‌گرفتيد.»\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxvi{نه چنين است، در حقيقت، كتاب نيكان در «علّيّون» است.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxvii{و تو چه دانى كه «علّيّون» چيست؟\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxviii{كتابى است نوشته‌شده.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxix{مقرّبان آن را مشاهده خواهند كرد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxx{براستى نيكوكاران در نعيم [الهى‌] خواهند بود.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxi{بر تختها [نشسته‌] مى‌نگرند.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxii{از چهره‌هايشان طراوت نعمت [بهشت‌] را درمى‌يابى.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxiii{از باده‌اى مُهر شده نوشانيده شوند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxiv{[باده‌اى كه‌] مُهر آن، مُشك است، و در اين [نعمتها] مشتاقان بايد بر يكديگر پيشى گيرند.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxv{و تركيبش از [چشمه‌] «تسنيم» است:\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxvi{چشمه‌اى كه مقرّبان [خدا] از آن نوشند.\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxvii{[آرى، در دنيا] كسانى كه گناه مى‌كردند، آنان را كه ايمان آورده بودند به ريشخند مى‌گرفتند.\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxviii{و چون بر ايشان مى‌گذشتند، اشاره چشم و ابرو با هم رد و بدل مى‌كردند.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxix{و هنگامى كه نزد خانواده‌[هاى‌] خود بازمى‌گشتند، به شوخ‌طبعى مى‌پرداختند.\qt@no{(31)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxx{و چون مؤمنان را مى‌ديدند، مى‌گفتند: «اينها [جماعتى‌] گمراهند.»\qt@no{(32)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxi{و حال آنكه آنان براى بازرسى [كار]شان فرستاده نشده بودند.\qt@no{(33)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxii{و[لى‌] امروز، مؤمنانند كه بر كافران خنده مى‌زنند.\qt@no{(34)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxiii{بر تختها[ى خود نشسته‌]، نظاره مى‌كنند.\qt@no{(35)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxiv{[تا ببينند] آيا كافران به پاداش آنچه مى‌كردند رسيده‌اند؟\qt@no{(36)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxv{\basmalahfa آنگاه كه آسمان زهم بشكافد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxvi{و پروردگارش را فرمان برد و [چنين‌] سزد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxvii{و آنگاه كه زمين كشيده شود،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxviii{و آنچه را كه در آن است بيرون افكند و تهى شود،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmdccclxxxix{و پروردگارش را فرمان برد و [چنين‌] سزد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxc{اى انسان، حقاً كه تو به سوى پروردگار خود بسختى در تلاشى، و او را ملاقات خواهى كرد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxci{اما كسى كه كارنامه‌اش به دست راستش داده شود،\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxcii{بزودى‌اش حسابى بس آسان كنند،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxciii{و شادمان به سوى كسانش باز گردد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxciv{و اما كسى كه كارنامه‌اش از پشت سرش به او داده شود،\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxcv{زودا كه هلاك [خويش‌] خواهد،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxcvi{و در آتش افروخته درآيد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxcvii{او در [ميان‌] خانواده خود شادمان بود.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxcviii{او مى‌پنداشت كه هرگز برنخواهد گشت.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmdcccxcix{آرى، در حقيقت، پروردگارش به او بينا بود.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcm{نه، نه، سوگند به شفق،\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcmi{سوگند به شب و آنچه [شب‌] فروپوشاند،\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcmii{سوگند به ماه چون [بَدر] تمام شود،\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcmiii{كه قطعاً از حالى به حالى برخواهيد نشست.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcmiv{پس چرا آنان باور نمى‌دارند؟\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcmv{و چون بر آنان قرآن تلاوت مى‌شود چهره بر خاك نمى‌سايند؟\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcmvi{[نه!] بلكه آنان كه كفر ورزيده‌اند، تكذيب مى‌كنند.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcmvii{و خدا به آنچه در سينه دارند داناتر است.\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmcmviii{پس آنان را از عذابى دردناك خبر ده،\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmcmix{مگر كسانى كه گرويده و كارهاى شايسته كرده‌اند، كه آنان را پاداشى بى‌منّت خواهد بود.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmcmx{\basmalahfa سوگند به آسمان آكنده ز برج،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxi{و به روز موعود،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxii{و به گواه و مورد گواهى،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxiii{مرگ بر آدم‌سوزان خندق.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxiv{همان آتش مايه‌دار [و انبوه‌].\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxv{آنگاه كه آنان بالاى آن [خندق به تماشا] نشسته بودند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxvi{و خود بر آنچه بر [سر] مؤمنان مى‌آوردند، گواه بودند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxvii{و بر آنان عيبى نگرفته بودند جز اينكه به خداى ارجمند ستوده ايمان آورده بودند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxviii{همان [خدايى‌] كه فرمانروايى آسمانها و زمين از آن اوست و خدا[ست كه‌] بر هر چيزى گواه است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxix{كسانى كه مردان و زنان مؤمن را آزار كرده و بعد توبه نكرده‌اند، ايشان راست عذاب جهنم، و ايشان راست عذاب سوزان.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxx{كسانى كه ايمان آورده و كارهاى شايسته كرده‌اند، براى آنان باغهايى است كه از زير [درختان‌] آن جويها روان است؛ اين است [همان‌] رستگارى بزرگ.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxi{آرى، عقاب پروردگارت سخت سنگين است.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxii{هم اوست كه [آفرينش را] آغاز مى‌كند و بازمى‌گرداند.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxiii{و اوست آن آمرزنده دوستدار [مؤمنان‌].\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxiv{صاحب ارجمند عرش.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxv{هر چه را بخواهد انجام مى‌دهد.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxvi{آيا حديث [آن‌] سپاهيان:\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxvii{فرعون و ثمود بر تو آمد؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxviii{[نه،] بلكه آنان كه كافر شده‌اند در تكذيب‌اند؛\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxix{با آنكه خدا از هر سو بر ايشان محيط است.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxx{آرى، آن قرآنى ارجمند است،\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxi{كه در لوحى محفوظ است.\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxii{\basmalahfa سوگند به آسمان و آن اختر شبگرد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxiii{و تو چه دانى كه اختر شبگرد چيست؟\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxiv{آن اختر فروزان.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxv{هيچ كس نيست مگر اينكه نگاهبانى بر او [گماشته شده‌] است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxvi{پس انسان بايد بنگرد كه از چه آفريده شده است؟\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxvii{از آب جهنده‌اى خلق شده،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxviii{[كه‌] از صلب مرد و ميان استخوانهاى سينه زن بيرون مى‌آيد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxxxix{در حقيقت، او [= خدا] بر بازگردانيدن وى بخوبى تواناست.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxl{آن روز كه رازها [همه‌] فاش شود،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxli{پس او را نه نيرويى ماند و نه يارى.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxlii{سوگند به آسمان بارش‌انگيز،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxliii{سوگند به زمين شكافدار [آماده كشت‌]،\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxliv{[كه‌] در حقيقت، قرآن گفتارى قاطع و روشنگر است؛\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxlv{و آن شوخى نيست.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxlvi{آنان دست به نيرنگ مى‌زنند.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxlvii{و [من نيز] دست به نيرنگ مى‌زنم.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxlviii{پس كافران را مهلت ده، و كمى آنان را به حال خود واگذار.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxlix{\basmalahfa نام پروردگار والاى خود را به پاكى بستاى:\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcml{همان كه آفريد و هماهنگى بخشيد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcmli{و آنكه اندازه‌گيرى كرد و راه نمود.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlii{و آنكه چمنزار را برآورد؛\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcmliii{و پس [از چندى‌] آن را خاشاكى تيره‌گون گردانيد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcmliv{ما بزودى [آيات خود را به وسيله سروش غيبى‌] بر تو خواهيم خواند، تا فراموش نكنى؛\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlv{جز آنچه خدا خواهد، كه او آشكار و آنچه را كه نهان است مى‌داند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlvi{و براى تو آسانترين [راه‌] را فراهم مى‌گردانيم.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlvii{پس پند ده، اگر پند سود بخشد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlviii{آن كس كه ترسد، بزودى عبرت گيرد.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlix{و نگون‌بخت، خود را از آن دور مى‌دارد؛\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlx{همان كس كه در آتشى بزرگ در آيد؛\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxi{آنگاه نه در آن مى‌ميرد و نه زندگانى مى‌يابد.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxii{رستگار آن كس كه خود را پاك گردانيد؛\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxiii{و نام پروردگارش را ياد كرد و نماز گزارد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxiv{ليكن [شما] زندگى دنيا را بر مى‌گزينيد؛\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxv{با آنكه [جهان‌] آخرت نيكوتر و پايدارتر است.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxvi{قطعاً در صحيفه‌هاى گذشته اين [معنى‌] هست،\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxvii{صحيفه‌هاى ابراهيم و موسى.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxviii{\basmalahfa آيا خبر «غاشيه» به تو رسيده است؟\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxix{در آن روز، چهره‌هايى زبونند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxx{كه تلاش كرده، رنج [بيهوده‌] برده‌اند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxi{[ناچار] در آتشى سوزان درآيند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxii{از چشمه‌اى داغ نوشانيده شوند.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxiii{خوراكى جز خار خشك ندارند،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxiv{[كه‌] نه فربه كند، و نه گرسنگى را باز دارد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxv{در آن روز، چهره‌هايى شادابند.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxvi{از كوشش خود خشنودند.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxvii{در بهشت برين‌اند.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxviii{سخن بيهوده‌اى در آنجا نشنوند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxix{در آن، چشمه‌اى روان باشد.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxx{تختهايى بلند در آنجاست.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxi{و قدحهايى نهاده شده.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxii{و بالشهايى پهلوى هم [چيده‌].\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxiii{و فرشهايى [زربفت‌] گسترده.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxiv{آيا به شتر نمى‌نگرند كه چگونه آفريده شده؟\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxv{و به آسمان كه چگونه برافراشته شده؟\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxvi{و به كوه‌ها كه چگونه برپا داشته شده؟\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxvii{و به زمين كه چگونه گسترده شده است؟\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxviii{پس تذكر ده كه تو تنها تذكردهنده‌اى.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmcmlxxxix{بر آنان تسلّطى ندارى،\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxc{مگر كسى كه روى بگرداند و كفر ورزد،\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxci{كه خدا او را به آن عذاب بزرگتر عذاب كند.\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxcii{در حقيقت، بازگشت آنان به سوى ماست،\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxciii{آنگاه حساب [خواستن از] آنان به عهده ماست.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxciv{\basmalahfa سوگند به سپيده‌دم،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxcv{و به شبهاى دهگانه،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxcvi{و به جفت و تاق،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxcvii{و به شب، وقتى سپرى شود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxcviii{آيا در اين، براى خردمند [نياز به‌] سوگندى [ديگر] است؟\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmcmxcix{مگر ندانسته‌اى كه پروردگارت با عاد چه كرد؟\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmm{با عمارات ستون‌دار ارم،\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmi{كه مانندش در شهرها ساخته نشده بود؟\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmii{و با ثمود، همانان كه در درّه، تخته‌سنگها را مى‌بريدند؟\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmiii{و با فرعون، صاحب خرگاه‌ها [و بناهاى بلند]؟\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmmiv{همانان كه در شهرها سر به طغيان برداشتند،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmmv{و در آنها بسيار تبهكارى كردند.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmmvi{[تا آنكه‌] پروردگارت بر سر آنان تازيانه عذاب را فرونواخت،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmmvii{زيرا پروردگار تو سخت در كمين است.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmmviii{اما انسان، هنگامى كه پروردگارش وى را مى‌آزمايد، و عزيزش مى‌دارد و نعمت فراوان به او مى‌دهد، مى‌گويد: «پروردگارم مرا گرامى داشته است.»\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmmix{و اما چون وى را مى‌آزمايد و روزى‌اش را بر او تنگ مى‌گرداند، مى‌گويد: «پروردگارم مرا خوار كرده است.»\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmmx{ولى نه، بلكه يتيم را نمى‌نوازيد؛\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmmxi{و بر خوراك‌[دادن‌] بينوا همديگر را بر نمى‌انگيزيد؛\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmmxii{و ميراث [ضعيفان‌] را چپاولگرانه مى‌خوريد؛\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmmxiii{و مال را دوست داريد، دوست داشتنى بسيار.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmmxiv{نه چنان است، آنگاه كه زمين، سخت در هم كوبيده شود،\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmmxv{و [فرمان‌] پروردگارت و فرشته‌[ها] صف‌درصف آيند،\qt@no{(22)}}
\qt@newcmd\qurantrans@fa@mmmmmmxvi{و جهنم را در آن روز [حاضر] آورند، آن روز است كه انسان پند گيرد؛ و[لى‌] كجا او را جاى پندگرفتن باشد؟\qt@no{(23)}}
\qt@newcmd\qurantrans@fa@mmmmmmxvii{گويد: «كاش براى زندگانى خود [چيزى‌] پيش فرستاده بودم.»\qt@no{(24)}}
\qt@newcmd\qurantrans@fa@mmmmmmxviii{پس در آن روز هيچ كس چون عذاب‌كردن او، عذاب نكند.\qt@no{(25)}}
\qt@newcmd\qurantrans@fa@mmmmmmxix{و هيچ كس چون دربندكشيدن او، دربند نكشد.\qt@no{(26)}}
\qt@newcmd\qurantrans@fa@mmmmmmxx{اى نفس مطمئنّه،\qt@no{(27)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxi{خشنود و خداپسند به سوى پروردگارت بازگرد،\qt@no{(28)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxii{و در ميان بندگان من درآى،\qt@no{(29)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxiii{و در بهشت من داخل شو.\qt@no{(30)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxiv{\basmalahfa سوگند به اين شهر،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxv{و حال آنكه تو در اين شهر جاى دارى؛\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxvi{سوگند به پدرى [چنان‌] و آن كسى را كه به وجود آورد؛\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxvii{براستى كه انسان را در رنج آفريده‌ايم.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxviii{آيا پندارد كه هيچ كس هرگز بر او دست نتواند يافت؟\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxix{گويد: «مال فراوانى تباه كردم.»\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxx{آيا پندارد كه هيچ كس او را نديده است؟\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxi{آيا دو چشمش نداده‌ايم؟\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxii{و زبانى و دو لب.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxiii{و هر دو راه [خير و شر] را بدو نموديم.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxiv{و[لى‌] نخواست از گردنه [عاقبت‌نگرى‌] بالا رود!\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxv{و تو چه دانى كه آن گردنه [سخت‌] چيست؟\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxvi{بنده‌اى را آزادكردن،\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxvii{يا در روز گرسنگى، طعام‌دادن:\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxviii{به يتيمى خويشاوند،\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmmxxxix{يا بينوايى خاك‌نشين.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmmxl{علاوه بر اين از زمره كسانى باشد كه گرويده و يكديگر را به شكيبايى و مهربانى سفارش كرده‌اند؛\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmmxli{اينانند خجستگان.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmmxlii{و كسانى كه به انكار نشانه‌هاى ما پرداخته‌اند، آنانند ناخجستگان شوم.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmmxliii{بر آنان آتشى سرپوشيده احاطه دارد.\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmmxliv{\basmalahfa سوگند به خورشيد و تابندگى‌اش،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmxlv{سوگند به مه چون پى [خورشيد] رود.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmxlvi{سوگند به روز چون [زمين را] روشن گرداند،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmxlvii{سوگند به شب چو پرده بر آن پوشد،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmxlviii{سوگند به آسمان و آن كس كه آن را برافراشت،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmxlix{سوگند به زمين و آن كس كه آن را گسترد،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmml{سوگند به نفس و آن كس كه آن را درست كرد؛\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmli{سپس پليدكارى و پرهيزگارى‌اش را به آن الهام كرد،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmlii{كه هر كس آن را پاك گردانيد، قطعاً رستگار شد،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmliii{و هر كه آلوده‌اش ساخت، قطعاً درباخت.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmmliv{[قوم‌] ثمود به سبب طغيان خود به تكذيب پرداختند.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmmlv{آنگاه كه شقى‌ترينشان بر[پا] خاست.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmmlvi{پس فرستاده خدا به آنان گفت: «زنهار! ماده‌شتر خدا و [نوبت‌] آب‌خوردنش را [حرمت نهيد]».\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmmlvii{و[لى‌] دروغزنش خواندند و آن [ماده‌شتر] را پى كردند، و پروردگارشان به [سزاى‌] گناهشان بر سرشان عذاب آورد و آنان را با خاك يكسان كرد.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmmlviii{و از پيامد كار خويش، بيمى به خود راه نداد.\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmmlix{\basmalahfa سوگند به شب چون پرده افكند،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmlx{سوگند به روز چون جلوه‌گرى آغازد،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxi{و [سوگند به‌] آنكه نر و ماده را آفريد،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxii{كه همانا تلاش شما پراكنده است.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxiii{اما آنكه [حق خدا را] داد و پروا داشت،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxiv{و [پاداش‌] نيكوتر را تصديق كرد،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxv{بزودى راه آسانى پيش پاى او خواهيم گذاشت.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxvi{و اما آنكه بخل ورزيد و خود را بى‌نياز ديد،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxvii{و [پاداش‌] نيكوتر را به دروغ گرفت،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxviii{بزودى راه دشوارى به او خواهيم نمود.\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxix{و چون هلاك شد، [ديگر] مال او به كارش نمى‌آيد.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxx{همانا هدايت بر ماست.\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxi{و در حقيقت، دنيا و آخرت از آن ماست.\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxii{پس شما را به آتشى كه زبانه مى‌كشد هشدار دادم.\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxiii{جز نگون‌بخت‌تر[ين مردم‌] در آن درنيايد:\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxiv{همان كه تكذيب كرد و رخ برتافت.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxv{و پاك‌رفتارتر[ين مردم‌] از آن دور داشته خواهد شد:\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxvi{همان كه مال خود را مى‌دهد [براى آنكه‌] پاك شود،\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxvii{و هيچ كس را به قصد پاداش‌يافتن نعمت نمى‌بخشد،\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxviii{جز خواستن رضاى پروردگارش كه بسى برتر است [منظورى ندارد].\qt@no{(20)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxix{و قطعاً بزودى خشنود خواهد شد.\qt@no{(21)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxx{\basmalahfa سوگند به روشنايى روز،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxi{سوگند به شب چون آرام گيرد،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxii{[كه‌] پروردگارت تو را وانگذاشته، و دشمن نداشته است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxiii{و قطعاً آخرت براى تو از دنيا نيكوتر خواهد بود.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxiv{و بزودى پروردگارت تو را عطا خواهد داد، تا خرسند گردى.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxv{مگر نه تو را يتيم يافت، پس پناه داد؟\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxvi{و تو را سرگشته يافت، پس هدايت كرد؟\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxvii{و تو را تنگدست يافت و بى‌نياز گردانيد؟\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxviii{و اما [تو نيز به پاس نعمت ما] يتيم را ميازار،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmlxxxix{و گدا را مران،\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmmxc{و از نعمت پروردگار خويش [با مردم‌] سخن گوى.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmmxci{\basmalahfa آيا براى تو سينه‌ات را نگشاده‌ايم؟\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmxcii{و بار گرانت را از [دوش‌] تو برنداشتيم؟\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmxciii{[بارى‌] كه [گويى‌] پشت تو را شكست.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmxciv{و نامت را براى تو بلند گردانيديم.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmxcv{پس [بدان كه‌] با دشوارى، آسانى است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmxcvi{آرى، با دشوارى، آسانى است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmxcvii{پس چون فراغت يافتى، به طاعت دركوش؛\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmxcviii{و با اشتياق، به سوى پروردگارت روى آور.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmxcix{\basmalahfa سوگند به [كوه‌] تين و زيتون،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmc{و طور سينا،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmci{و اين شهر امن [و امان‌]،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcii{[كه‌] براستى انسان را در نيكوترين اعتدال آفريديم.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmciii{سپس او را به پست‌ترين [مراتب‌] پستى بازگردانيديم؛\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmciv{مگر كسانى را كه گرويده و كارهاى شايسته كرده‌اند، كه پاداشى بى‌منّت خواهند داشت.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmcv{پس چه چيز، تو را بعد [از اين‌] به تكذيب جزا وامى‌دارد؟\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmcvi{آيا خدا نيكوترين داوران نيست؟\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmcvii{\basmalahfa بخوان به نام پروردگارت كه آفريد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmcviii{انسان را از عَلَق آفريد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmcix{بخوان، و پروردگار تو كريمترين [كريمان‌] است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcx{همان كس كه به وسيله قلم آموخت.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxi{آنچه را كه انسان نمى‌دانست [بتدريج به او] آموخت.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxii{حقاً كه انسان سركشى مى‌كند،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxiii{همين كه خود را بى‌نياز پندارد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxiv{در حقيقت، بازگشت به سوى پروردگار توست.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxv{آيا ديدى آن كس را كه باز مى‌داشت،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxvi{بنده‌اى را آنگاه كه نماز مى‌گزارد؟\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxvii{چه پندارى اگر او بر هدايت باشد،\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxviii{يا به پرهيزگارى وادارد [براى او بهتر نيست‌]؟\qt@no{(12)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxix{[و باز] آيا چه پندارى [كه‌] اگر او به تكذيب پردازد و روى برگرداند [چه كيفرى در پيش دارد]؟\qt@no{(13)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxx{مگر ندانسته كه خدا مى‌بيند؟\qt@no{(14)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxi{زنهار، اگر باز نايستد، موى پيشانى [او] را سخت بگيريم؛\qt@no{(15)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxii{[همان‌] موى پيشانى دروغزن گناه‌پيشه را.\qt@no{(16)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxiii{[بگو] تا گروه خود را بخواند.\qt@no{(17)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxiv{بزودى آتشبانان را فرا خوانيم.\qt@no{(18)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxv{زنهار! فرمانش مَبَر، و سجده كن، و خود را [به خدا] نزديك گردان.\qt@no{(19)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxvi{\basmalahfa ما [قرآن را] در شب قدر نازل كرديم.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxvii{و از شب قدر، چه آگاهت كرد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxviii{شب قدر از هزار ماه ارجمندتر است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxix{در آن [شب‌] فرشتگان، با روح، به فرمان پروردگارشان، براى هر كارى [كه مقرّر شده است‌] فرود آيند؛\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxx{[آن شب‌] تا دمِ صبح، صلح و سلام است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxi{\basmalahfa كافران اهل كتاب و مشركان، دست‌بردار نبودند تا دليلى آشكار بر ايشان آيد:\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxii{فرستاده‌اى از جانب خدا كه [بر آنان‌] صحيفه‌هايى پاك را تلاوت كند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxiii{كه در آنها نوشته‌هاى استوار است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxiv{و اهل كتاب دستخوش پراكندگى نشدند، مگر پس از آنكه برهان آشكار براى آنان آمد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxv{و فرمان نيافته بودند جز اينكه خدا را بپرستند، و در حالى كه به توحيد گراييده‌اند، دين [خود] را براى او خالص گردانند، و نماز برپا دارند و زكات بدهند، و دين [ثابت و] پايدار همين است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxvi{كسانى از اهل كتاب كه كفر ورزيده‌اند و [نيز] مشركان در آتش دوزخند، [و] در آن همواره مى‌مانند؛ اينانند كه بدترين آفريدگانند.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxvii{در حقيقت كسانى كه گرويده و كارهاى شايسته كرده‌اند، آنانند كه بهترين آفريدگانند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxviii{پاداش آنان نزد پروردگارشان باغهاى هميشگى است كه از زير [درختان‌] آن، نهرها روان است، جاودانه در آن «همى» مانند؛ خدا از آنان خشنود است و [آنان نيز] از او خشنود، اين [پاداش‌] براى كسى است كه از پروردگارش بترسد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxxxix{\basmalahfa آنگاه كه زمين به لرزش [شديد] خود لرزانيده شود،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxl{و زمين بارهاى سنگين خود را برون افكند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxli{و انسان گويد: «[زمين‌] را چه شده است؟»\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxlii{آن روز است كه [زمين‌] خبرهاى خود را باز گويد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxliii{[همان گونه‌] كه پروردگارت بدان وحى كرده است.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxliv{آن روز، مردم [به حال‌] پراكنده برآيند تا [نتيجه‌] كارهايشان به آنان نشان داده شود.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxlv{پس هر كه هموزن ذرّه‌اى نيكى كند [نتيجه‌] آن را خواهد ديد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxlvi{و هر كه هموزن ذرّه‌اى بدى كند [نتيجه‌] آن را خواهد ديد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxlvii{\basmalahfa سوگند به ماديانهائى كه با همهمه تازانند و با سم‌[هاى‌] خود از سنگ آتش مى‌جهانند!\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxlviii{و برق [از سنگ‌] همى جهانند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxlix{و صبحگاهان هجوم آرند،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcl{و با آن [يورش‌]، گردى برانگيزند،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmcli{و بدان [هجوم‌]، در دل گروهى درآيند،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmclii{كه انسان نسبت به پروردگارش سخت ناسپاس است،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmcliii{و او خود بر اين [امر]، نيك گواه است.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmcliv{و راستى او سخت شيفته مال است.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmclv{مگر نمى‌داند كه چون آنچه در گورهاست بيرون ريخته گردد،\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmclvi{و آنچه در سينه‌هاست فاش شود،\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmmclvii{در چنان روزى پروردگارشان به [حال‌] ايشان نيك آگاه است؟\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmmclviii{\basmalahfa كوبنده،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmclix{چيست كوبنده؟\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmclx{و تو چه دانى كه كوبنده چيست؟\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxi{روزى كه مردم چون پروانه‌[هاى‌] پراكنده گردند،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxii{و كوه‌ها مانند پشم زده‌شده رنگين شود.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxiii{اما هر كه سنجيده‌هايش سنگين برآيد،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxiv{پس وى در زندگى خوشى خواهد بود!\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxv{و اما هر كه سنجيده‌هايش سبك بر آيد،\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxvi{پس جايش «هاويه» باشد.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxvii{و تو چه دانى كه آن چيست؟\qt@no{(10)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxviii{آتشى است سوزنده.\qt@no{(11)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxix{\basmalahfa تفاخر به بيشترداشتن، شما را غافل داشت.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxx{تا كارتان [و پايتان‌] به گورستان رسيد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxi{نه چنين است، زودا كه بدانيد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxii{باز هم نه چنين است، زودا كه بدانيد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxiii{هرگز چنين نيست، اگر علم‌اليقين داشتيد!\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxiv{به يقين دوزخ را مى‌بينيد.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxv{سپس آن را قطعاً به عين‌اليقين درمى‌يابيد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxvi{سپس در همان روز است كه از نعمت [روى زمين‌] پرسيده خواهيد شد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxvii{\basmalahfa سوگند به عصر [غلبه حق بر باطل‌]،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxviii{كه واقعاً انسان دستخوش زيان است؛\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxix{مگر كسانى كه گرويده و كارهاى شايسته كرده و همديگر را به حق سفارش و به شكيبايى توصيه كرده‌اند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxx{\basmalahfa واى بر هر بدگوى عيبجويى،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxi{كه مالى گرد آورد و برشمردش.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxii{پندارد كه مالش او را جاويد كرده،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxiii{ولى نه! قطعاً در آتش خردكننده فرو افكنده خواهد شد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxiv{و تو چه دانى كه آن آتش خردكننده چيست؟\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxv{آتش افروخته خدا[يى‌] است.\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxvi{[آتشى‌] كه به دلها مى‌رسد.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxvii{آنان را در ميان فرامى‌گيرد.\qt@no{(8)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxviii{[آتشى كه‌] در ستونهايى دراز است.\qt@no{(9)}}
\qt@newcmd\qurantrans@fa@mmmmmmclxxxix{\basmalahfa مگر نديدى پروردگارت با پيلداران چه كرد؟\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxc{آيا نيرنگشان را بر باد نداد؟\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxci{و بر سر آنها، دسته دسته پرندگانى «اَبابيل» فرستاد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxcii{[كه‌] بر آنان سنگهايى از گل [سخت‌] مى‌افكندند.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxciii{و [سرانجام، خدا] آنان را مانند كاه جويده‌شده گردانيد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxciv{\basmalahfa براى الفت‌دادن قريش،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxcv{الفتشان هنگام كوچ زمستان و تابستان، [خدا پيلداران را نابود كرد.]\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxcvi{پس بايد خداوندِ اين خانه را بپرستند؛\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxcvii{همان [خدايى‌] كه در گرسنگى غذايشان داد، و از بيم [دشمن‌] آسوده‌خاطرشان كرد.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxcviii{\basmalahfa آيا كسى را كه [روز] جزا را دروغ مى‌خواند، ديدى؟\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmcxcix{اين همان كس است كه يتيم را بسختى مى‌راند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmcc{و به خوراك‌دادن بينوا ترغيب نمى‌كند.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmcci{پس واى بر نمازگزارانى\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmccii{كه از نمازشان غافلند،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmcciii{آنان كه ريا مى‌كنند،\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmcciv{و از [دادن‌] زكات [و وسايل و مايحتاج خانه‌] خوددارى مى‌ورزند.\qt@no{(7)}}
\qt@newcmd\qurantrans@fa@mmmmmmccv{\basmalahfa ما تو را [چشمه‌] كوثر داديم،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmccvi{پس براى پروردگارت نماز گزار و قربانى كن.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmccvii{دشمنت خود بى‌تبار خواهد بود.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmccviii{\basmalahfa بگو: «اى كافران،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmccix{آنچه مى‌پرستيد، نمى‌پرستم.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmccx{و آنچه مى‌پرستم، شما نمى‌پرستيد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxi{و نه آنچه پرستيديد من مى‌پرستم.\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxii{و نه آنچه مى‌پرستم شما مى‌پرستيد.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxiii{دين شما براى خودتان، و دين من براى خودم.»\qt@no{(6)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxiv{\basmalahfa چون يارى خدا و پيروزى فرا رسد،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxv{و ببينى كه مردم دسته‌دسته در دين خدا درآيند،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxvi{پس به ستايش پروردگارت نيايشگر باش و از او آمرزش خواه، كه وى همواره توبه‌پذير است.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxvii{\basmalahfa بريده باد دو دست ابولهب، و مرگ بر او باد.\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxviii{دارايى او و آنچه اندوخت، سودش نكرد.\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxix{بزودى در آتشى پرزبانه درآيد.\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxx{و زنش، آن هيمه‌كش [آتش فروز]،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxi{بر گردنش طنابى از ليف خرماست.\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxii{\basmalahfa بگو: «اوست خداى يگانه،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxiii{خداى صمد [ثابت - متعالى‌]،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxiv{[كسى را] نزاده، و زاده نشده است،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxv{و هيچ كس او را همتا نيست.»\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxvi{\basmalahfa بگو: «پناه مى‌برم به پروردگار سپيده دم،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxvii{از شرّ آنچه آفريده،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxviii{و از شرّ تاريكى چون فراگيرد،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxix{و از شرّ دمندگان افسون در گره‌ها،\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxx{و از شرّ [هر] حسود، آنگاه كه حسد ورزد.»\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxxi{\basmalahfa بگو: «پناه مى‌برم به پروردگار مردم،\qt@no{(1)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxxii{پادشاه مردم،\qt@no{(2)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxxiii{معبود مردم،\qt@no{(3)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxxiv{از شرّ وسوسه‌گر نهانى؛\qt@no{(4)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxxv{آن كس كه در سينه‌هاى مردم وسوسه مى‌كند،\qt@no{(5)}}
\qt@newcmd\qurantrans@fa@mmmmmmccxxxvi{چه از جنّ و [چه از] انس.»\qt@no{(6)}}
