\qt@newcmd\qurantrans@ur@i{شروع کرتا ہوں اللہ تعالیٰ کے نام سے جو بڑا مہربان نہایت رحم واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ii{سب تعریف اللہ تعالیٰ کے لئے ہے جو تمام جہانوں کا پالنے واﻻ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@iii{بڑا مہربان نہایت رحم کرنے واﻻ\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@iv{بدلے کے دن (یعنی قیامت) کا مالک ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@v{ہم صرف تیری ہی عبادت کرتے ہیں اور صرف تجھ ہی سے مدد چاہتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@vi{ہمیں سیدھی (اور سچی) راه دکھا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@vii{ان لوگوں کی راه جن پر تو نے انعام کیا ان کی نہیں جن پر غضب کیا گیا (یعنی وه لوگ جنہوں نے حق کو پہچانا، مگر اس پر عمل پیرا نہیں ہوئے) اور نہ گمراہوں کی (یعنی وه لوگ جو جہالت کے سبب راه حق سے برگشتہ ہوگئے)\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@viii{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ix{اس کتاب (کے اللہ کی کتاب ہونے) میں کوئی شک نہیں پرہیزگاروں کو راه دکھانے والی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@x{جو لوگ غیب پر ایمان ﻻتے ہیں اور نماز کو قائم رکھتے ہیں اور ہمارے دیئے ہوئے (مال) میں سے خرچ کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@xi{اور جو لوگ ایمان ﻻتے ہیں اس پر جو آپ کی طرف اتارا گیا اور جو آپ سے پہلے اتارا گیا، اور وه آخرت پر بھی یقین رکھتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@xii{یہی لوگ اپنے رب کی طرف سے ہدایت پر ہیں اور یہی لوگ فلاح اور نجات پانے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@xiii{کافروں کو آپ کا ڈرانا، یا نہ ڈرانا برابر ہے، یہ لوگ ایمان نہ ﻻئیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@xiv{اللہ تعالیٰ نے ان کے دلوں پر اور ان کے کانوں پر مہر کر دی ہے اور ان کی آنکھوں پر پرده ہے اور ان کے لئے بڑا عذاب ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@xv{بعض لوگ کہتے ہیں کہ ہم اللہ تعالیٰ پر اور قیامت کے دن پر ایمان رکھتے ہیں، لیکن درحقیقت وه ایمان والے نہیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@xvi{وه اللہ تعالیٰ کو اور ایمان والوں کو دھوکا دیتے ہیں، لیکن دراصل وه خود اپنے آپ کو دھوکا دے رہے ہیں، مگر سمجھتے نہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@xvii{ان کے دلوں میں بیماری تھی اللہ تعالیٰ نے انہیں بیماری میں مزید بڑھا دیا اور ان کے جھوٹ کی وجہ سے ان کے لئے دردناک عذاب ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@xviii{اور جب ان سے کہا جاتا ہے کہ زمین میں فساد نہ کرو تو جواب دیتے ہیں کہ ہم تو صرف اصلاح کرنے والے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@xix{خبردار ہو! یقیناً یہی لوگ فساد کرنے والے ہیں، لیکن شعور (سمجھ) نہیں رکھتے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@xx{اور جب ان سے کہا جاتا ہے کہ اور لوگوں (یعنی صحابہ) کی طرح تم بھی ایمان لاؤ تو جواب دیتے ہیں کہ کیا ہم ایسا ایمان ﻻئیں جیسا بیوقوف ﻻئے ہیں، خبردار ہوجاؤ! یقیناً یہی بیوقوف ہیں، لیکن جانتے نہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@xxi{اور جب ایمان والوں سے ملتے ہیں تو کہتے ہیں کہ ہم بھی ایمان والے ہیں اور جب اپنے بڑوں کے پاس جاتے ہیں تو کہتے ہیں کہ ہم تو تمہارے ساتھ ہیں ہم تو ان سے صرف مذاق کرتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@xxii{اللہ تعالیٰ بھی ان سے مذاق کرتا ہے اور انہیں ان کی سرکشی اور بہکاوے میں اور بڑھا دیتا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@xxiii{یہ وه لوگ ہیں جنہوں نے گمراہی کو ہدایت کے بدلے میں خرید لیا، پس نہ تو ان کی تجارت نے ان کو فائده پہنچایا اور نہ یہ ہدایت والے ہوئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@xxiv{ان کی مثال اس شخص کی سی ہے جس نے آگ جلائی، پس آس پاس کی چیزیں روشنی میں آئی ہی تھیں کہ اللہ ان کے نور کو لے گیا اور انہیں اندھیروں میں چھوڑ دیا، جو نہیں دیکھتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@xxv{بہرے، گونگے، اندھے ہیں۔ پس وه نہیں لوٹتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@xxvi{یا آسمانی برسات کی طرح جس میں اندھیریاں اور گرج اور بجلی ہو، موت سے ڈر کر کڑاکے کی وجہ سے اپنی انگلیاں اپنے کانوں میں ڈال لیتے ہیں۔ اور اللہ تعالیٰ کافروں کو گھیرنے واﻻ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@xxvii{قریب ہے کہ بجلی ان کی آنکھیں اُچک لے جائے، جب ان کے لئے روشنی کرتی ہے تو اس میں چلتے پھرتے ہیں اور جب ان پر اندھیرا کرتی ہے تو کھڑے ہوجاتے ہیں اور اگر اللہ تعالیٰ چاہے تو ان کے کانوں اور آنکھوں کو بیکار کردے۔ یقیناً اللہ تعالیٰ ہر چیز پر قدرت رکھنے واﻻ ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@xxviii{اے لوگو! اپنے اس رب کی عبادت کرو جس نے تمہیں اور تم سے پہلے کے لوگوں کو پیدا کیا، یہی تمہارا بچاؤ ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@xxix{جس نے تمہارے لئے زمین کو فرش اور آسمان کو چھت بنایا اور آسمان سے پانی اتار کر اس سے پھل پیدا کرکے تمہیں روزی دی، خبردار باوجود جاننے کے اللہ کے شریک مقرر نہ کرو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@xxx{ہم نے جو کچھ اپنے بندے پر اتارا ہے اس میں اگر تمہیں شک ہو اور تم سچے ہو تو اس جیسی ایک سورت تو بنا لاؤ، تمہیں اختیار ہے کہ اللہ تعالیٰ کے سوا اپنے مددگاروں کو بھی بلا لو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@xxxi{پس اگر تم نے نہ کیا اور تم ہرگز نہیں کرسکتے تو (اسے سچا مان کر) اس آگ سے بچو جس کا ایندھن انسان اور پتھر ہیں، جو کافروں کے لئے تیار کی گئی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@xxxii{اور ایمان والوں اور نیک عمل کرنے والوں کو ان جنتوں کی خوشخبریاں دو، جن کےنیچے نہریں بہہ رہی ہیں۔ جب کبھی وه پھلوں کا رزق دیئے جائیں گے اور ہم شکل ﻻئے جائیں گے تو کہیں گے یہ وہی ہے جو ہم اس سے پہلے دیئے گئے تھے اور ان کے لئے بیویاں ہیں صاف ستھری اور وه ان جنتوں میں ہمیشہ رہنے والے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@xxxiii{یقیناً اللہ تعالیٰ کسی مثال کے بیان کرنے سے نہیں شرماتا، خواه مچھر کی ہو، یا اس سے بھی ہلکی چیز کی۔ ایمان والے تو اسے اپنے رب کی جانب سے صحیح سمجھتے ہیں اور کفار کہتے ہیں کہ اس مثال سے اللہ نے کیا مراد لی ہے؟ اس کے ذریعے بیشتر کو گمراه کرتا ہے اور اکثر لوگوں کو راه راست پر ﻻتا ہے اور گمراه تو صرف فاسقوں کو ہی کرتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@xxxiv{جو لوگ اللہ تعالیٰ کے مضبوط عہد کو توڑ دیتے ہیں اور اللہ تعالیٰ نے جن چیزوں کے جوڑنے کا حکم دیا ہے، انہیں کاٹتے اور زمین میں فساد پھیلاتے ہیں، یہی لوگ نقصان اٹھانے والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@xxxv{تم اللہ کے ساتھ کیسے کفر کرتے ہو؟ حاﻻنکہ تم مرده تھے اس نے تمہیں زنده کیا، پھر تمہیں مار ڈالے گا، پھر زنده کرے گا، پھر اسی کی طرف لوٹائے جاؤ گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@xxxvi{وه اللہ جس نے تمہارے لئے زمین کی تمام چیزوں کو پیدا کیا، پھر آسمان کی طرف قصد کیا اور ان کو ٹھیک ٹھاک سات آسمان بنایا اور وه ہر چیز کو جانتا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@xxxvii{اور جب تیرے رب نے فرشتوں سے کہا کہ میں زمین میں خلیفہ بنانے واﻻ ہوں، تو انہوں نے کہا ایسے شخص کو کیوں پیدا کرتا ہے جو زمین میں فساد کرے اور خون بہائے؟ اور ہم تیری تسبیح، حمد اور پاکیزگی بیان کرنے والے ہیں۔ اللہ تعالیٰ نے فرمایا، جو میں جانتا ہوں تم نہیں جانتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@xxxviii{اور اللہ تعالیٰ نے آدم کو تمام نام سکھا کر ان چیزوں کو فرشتوں کے سامنے پیش کیا اور فرمایا، اگر تم سچے ہو تو ان چیزوں کے نام بتاؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@xxxix{ان سب نے کہا اے اللہ! تیری ذات پاک ہے ہمیں تو صرف اتنا ہی علم ہے جتنا تونے ہمیں سکھا رکھا ہے، پورے علم وحکمت واﻻ تو تو ہی ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@xl{اللہ تعالیٰ نے (حضرت) آدم ﴿علیہ السلام﴾ سے فرمایا تم ان کے نام بتا دو۔ جب انہوں نے بتا دیئے تو فرمایا کہ کیا میں نے تمہیں (پہلے ہی) نہ کہا تھا کہ زمین اور آسمانوں کا غیب میں ہی جانتا ہوں اور میرے علم میں ہے جو تم ﻇاہر کر رہے ہو اور جو تم چھپاتے تھے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@xli{اور جب ہم نے فرشتوں سے کہا کہ آدم کو سجده کرو تو ابلیس کے سوا سب نے سجده کیا۔ اس نے انکار کیا اور تکبر کیا اور وه کافروں میں ہوگیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@xlii{اور ہم نے کہہ دیا کہ اے آدم! تم اور تمہاری بیوی جنت میں رہو اور جہاں کہیں سے چاہو بافراغت کھاؤ پیو، لیکن اس درخت کے قریب بھی نہ جانا ورنہ ﻇالم ہوجاؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@xliii{لیکن شیطان نے ان کو بہکا کر وہاں سے نکلوا ہی دیا اور ہم نے کہہ دیا کہ اتر جاؤ! تم ایک دوسرے کے دشمن ہو اور ایک وقت مقرر تک تمہارے لئے زمین میں ٹھہرنا اور فائده اٹھانا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@xliv{(حضرت) آدم (علیہ السلام) نے اپنے رب سے چند باتیں سیکھ لیں اور اللہ تعالیٰ نے ان کی توبہ قبول فرمائی، بےشک وہی توبہ قبول کرنے واﻻ اور رحم کرنے واﻻ ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@xlv{ہم نے کہا تم سب یہاں سے چلے جاؤ، جب کبھی تمہارے پاس میری ہدایت پہنچے تو اس کی تابعداری کرنے والوں پر کوئی خوف وغم نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@xlvi{اور جو انکار کرکے ہماری آیتوں کو جھٹلائیں، وه جہنمی ہیں اور ہمیشہ اسی میں رہیں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@xlvii{اے بنی اسرائیل! میری اس نعمت کو یاد کرو جو میں نے تم پر انعام کی اور میرے عہد کو پورا کرو میں تمہارے عہد کو پورا کروں گا اور مجھ ہی سے ڈرو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@xlviii{اور اس کتاب پر ایمان لاؤ جو میں نے تمہاری کتابوں کی تصدیق میں نازل فرمائی ہے اور اس کے ساتھ تم ہی پہلے کافر نہ بنو اور میری آیتوں کو تھوڑی تھوڑی قیمت پر نہ فروخت کرو اور صرف مجھ ہی سے ڈرو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@xlix{اور حق کو باطل کے ساتھ خَلط مَلط نہ کرو اور نہ حق کو چھپاؤ، تمہیں تو خود اس کا علم ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@l{اور نمازوں کو قائم کرو اور زکوٰة دو اور رکوع کرنے والوں کے ساتھ رکوع کرو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@li{کیا لوگوں کو بھلائیوں کا حکم کرتے ہو؟ اور خود اپنے آپ کو بھول جاتے ہو باوجودیکہ تم کتاب پڑھتے ہو، کیا اتنی بھی تم میں سمجھ نہیں؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@lii{اور صبر اور نماز کے ساتھ مدد طلب کرو یہ چیز شاق ہے، مگر ڈر رکھنے والوں پر\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@liii{جو جانتے ہیں کہ بے شک وه اپنے رب سے ملاقات کرنے والے اور یقیناً وہ اسی کی طرف لوٹ کر جانے والے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@liv{اے اوﻻد یعقوب! میری اس نعمت کو یاد کرو جو میں نے تم پر انعام کی اور میں نے تمہیں تمام جہانوں پر فضیلت دی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@lv{اس دن سے ڈرتے رہو جب کوئی کسی کو نفع نہ دے سکے گا اور نہ ہی اس کی بابت کوئی سفارش قبول ہوگی اور نہ کوئی بدلہ اس کے عوض لیا جائے گا اور نہ وه مدد کئے جائیں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@lvi{اور جب ہم نے تمہیں فرعونیوں سے نجات دی جو تمہیں بدترین عذاب دیتے تھے جو تمہارے لڑکوں کو مار ڈالتے تھے اور تمہاری لڑکیوں کو چھوڑ دیتے تھے، اس نجات دینے میں تمہارے رب کی بڑی مہربانی تھی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@lvii{اور جب ہم نے تمہارے لئے دریا چیر (پھاڑ) دیا اور تمہیں اس سے پار کردیا اور فرعونیوں کو تمہاری نظروں کے سامنے اس میں ڈبو دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@lviii{اور ہم نے (حضرت) موسیٰ ﴿علیہ السلام﴾ سے چالیس راتوں کا وعده کیا، پھر تم نے اس کے بعد بچھڑا پوجنا شروع کردیا اور ﻇالم بن گئے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@lix{لیکن ہم نے باوجود اس کے پھر بھی تمہیں معاف کردیا، تاکہ تم شکر کرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@lx{اور ہم نے (حضرت) موسیٰ﴿علیہ السلام﴾ کو تمہاری ہدایت کے لئے کتاب اور معجزے عطا فرمائے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@lxi{جب (حضرت موسیٰ) ﴿علیہ السلام﴾ نے اپنی قوم سے کہا کہ اے میری قوم! بچھڑے کو معبود بنا کر تم نے اپنی جانوں پر ﻇلم کیا ہے، اب تم اپنے پیدا کرنے والے کی طرف رجوع کرو، اپنے کو آپس میں قتل کرو، تمہاری بہتری اللہ تعالیٰ کے نزدیک اسی میں ہے، تو اس نے تمہاری توبہ قبول کی، وه توبہ قبول کرنے واﻻ اور رحم وکرم کرنے واﻻ ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@lxii{اور (تم اسے بھی یاد کرو) تم نے (حضرت) موسیٰ ﴿علیہ السلام﴾ سے کہا تھا کہ جب تک ہم اپنے رب کو سامنے نہ دیکھ لیں ہرگز ایمان نہ ﻻئیں گے (جس گستاخی کی سزا میں) تم پر تمہارے دیکھتے ہوئے بجلی گری\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@lxiii{لیکن پھر اس لئے کہ تم شکرگزاری کرو، اس موت کے بعد بھی ہم نے تمہیں زنده کردیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@lxiv{اور ہم نے تم پر بادل کا سایہ کیا اور تم پر من و سلویٰ اتارا (اور کہہ دیا) کہ ہماری دی ہوئی پاکیزه چیزیں کھاؤ، اور انہوں نے ہم پر ﻇلم نہیں کیا، البتہ وه خود اپنی جانوں پر ﻇلم کرتے تھے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@lxv{اور ہم نے تم سے کہا کہ اس بستی میں جاؤ اور جو کچھ جہاں کہیں سے چاہو بافراغت کھاؤ پیو اور دروازے میں سجدے کرتے ہوئے گزرو اور زبان سے حِطّہ کہو ہم تمہاری خطائیں معاف فرمادیں گے اور نیکی کرنے والوں کو اور زیاده دیں گے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@lxvi{پھر ان ﻇالموں نے اس بات کو جو ان سے کہی گئی تھی بدل ڈالی، ہم نے بھی ان ﻇالموں پر ان کے فسق ونافرمانی کی وجہ سے آسمانی عذاب نازل کیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@lxvii{اور جب موسیٰ (علیہ السلام) نے اپنی قوم کے لئے پانی مانگا تو ہم نے کہا کہ اپنی ﻻٹھی پتھر پر مارو، جس سے باره چشمے پھوٹ نکلے اور ہر گروه نے اپنا چشمہ پہچان لیا (اور ہم نے کہہ دیا کہ) اللہ تعالیٰ کا رزق کھاؤ پیو اورزمین میں فساد نہ کرتے پھرو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@lxviii{اور جب تم نے کہا اے موسیٰ! ہم سے ایک ہی قسم کے کھانے پر ہرگز صبر نہ ہوسکے گا، اس لئے اپنے رب سے دعا کیجیئے کہ وه ہمیں زمین کی پیداوار ساگ، ککڑی، گیہوں، مسور اور پیاز دے، آپ نے فرمایا، بہتر چیز کے بدلے ادنیٰ چیز کیوں طلب کرتے ہو! اچھا شہر میں جاؤ وہاں تمہاری چاہت کی یہ سب چیزیں ملیں گی۔ ان پر ذلت اور مسکینی ڈال دی گئی اور اللہ تعالی کا غضب لے کر وه لوٹے یہ اس لئے کہ وه اللہ تعالیٰ کی آیتوں کے ساتھ کفر کرتے تھے اور نبیوں کو ناحق قتل کرتے تھے، یہ ان کی نافرمانیوں اور زیادتیوں کا نتیجہ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@lxix{مسلمان ہوں، یہودی ہوں، نصاریٰ ہوں یا صابی ہوں، جو کوئی بھی اللہ تعالیٰ پر اور قیامت کے دن پر ایمان ﻻئے اور نیک عمل کرے ان کے اجر ان کے رب کے پاس ہیں اور ان پر نہ تو کوئی خوف ہے اور نہ اداسی\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@lxx{اور جب ہم نے تم سے وعده لیا اور تم پر طور پہاڑ ﻻکھڑا کردیا (اور کہا) جو ہم نے تمہیں دیا ہے، اسے مضبوطی سے تھام لو اور جو کچھ اس میں ہے اسے یاد کرو تاکہ تم بچ سکو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@lxxi{لیکن تم اس کے بعد بھی پھر گئے، پھر اگر اللہ تعالیٰ کا فضل اور اس کی رحمت تم پر نہ ہوتی تو تم نقصان والے ہوجاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@lxxii{اور یقیناً تمہیں ان لوگوں کا علم بھی ہے جو تم میں سے ہفتہ کے بارے میں حد سے بڑھ گئے اور ہم نے بھی کہہ دیا کہ تم ذلیل بندر بن جاؤ\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@lxxiii{اسے ہم نے اگلوں پچھلوں کے لئے عبرت کا سبب بنا دیا اور پرہیزگاروں کے لئے وعﻆ ونصیحت کا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@lxxiv{اور (حضرت) موسیٰ﴿علیہ السلام﴾ نے جب اپنی قوم سے کہا کہ اللہ تعالیٰ تمہیں ایک گائے ذبح کرنے کا حکم دیتا ہے تو انہوں نے کہا ہم سے مذاق کیوں کرتے ہیں؟ آپ نے جواب دیا کہ میں ایسا جاہل ہونے سے اللہ تعالیٰ کی پناه پکڑتا ہوں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@lxxv{انہوں نے کہا اے موسیٰ! دعا کیجیئے کہ اللہ تعالیٰ ہمارے لئے اس کی ماہیت بیان کردے، آپ نے فرمایا سنو! وه گائے نہ تو بالکل بڑھیا ہو، نہ بچہ، بلکہ درمیانی عمر کی نوجوان ہو، اب جو تمہیں حکم دیا گیا ہے بجا لاؤ\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@lxxvi{وه پھر کہنے لگے کہ دعا کیجیے کہ اللہ تعالیٰ بیان کرے کہ اس کا رنگ کیا ہے؟ فرمایا وه کہتا ہے کہ وه گائے زرد رنگ کی ہے، چمکیلا اور دیکھنے والوں کو بھلا لگنے واﻻ اس کا رنگ ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@lxxvii{وه کہنے لگے کہ اپنے رب سے اور دعا کیجیئے کہ ہمیں اس کی مزید ماہیت بتلائے، اس قسم کی گائے تو بہت ہیں پتہ نہیں چلتا، اگر اللہ نے چاہا تو ہم ہدایت والے ہوجائیں گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@lxxviii{آپ نے فرمایا کہ اللہ کا فرمان ہے کہ وه گائے کام کرنے والی زمین میں ہل جوتنے والی اور کھیتوں کو پانی پلانے والی نہیں، وه تندرست اور بےداغ ہے۔ انہوں نے کہا، اب آپ نے حق واضح کردیا گو وه حکم برداری کے قریب نہ تھے، لیکن اسے مانا اور وه گائے ذبح کردی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@lxxix{جب تم نے ایک شخص کو قتل کر ڈاﻻ، پھر اس میں اختلاف کرنے لگے اور تمہاری پوشیدگی کو اللہ تعالیٰ ﻇاہر کرنے واﻻ تھا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@lxxx{ہم نے کہا کہ اس گائے کا ایک ٹکڑا مقتول کے جسم پر لگا دو، (وه جی اٹھے گا) اسی طرح اللہ مردوں کو زنده کرکے تمہیں تمہاری عقل مندی کے لئے اپنی نشانیاں دکھاتا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@lxxxi{پھر اس کے بعد تمہارے دل پتھر جیسے بلکہ اس سے بھی زیاده سخت ہوگئے، بعض پتھروں سے تو نہریں بہہ نکلتی ہیں، اور بعض پھٹ جاتے ہیں اور ان سے پانی نکل آتا ہے، اور بعض اللہ تعالیٰ کے ڈر سے گرگر پڑتے ہیں، اور تم اللہ تعالیٰ کو اپنے اعمال سے غافل نہ جانو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@lxxxii{(مسلمانو!) کیا تمہاری خواہش ہے کہ یہ لوگ ایماندار بن جائیں، حاﻻنکہ ان میں ایسے لوگ بھی جو کلام اللہ کو سن کر، عقل وعلم والے ہوتے ہوئے، پھر بھی بدل ڈاﻻ کرتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@lxxxiii{جب ایمان والوں سے ملتے ہیں تو اپنی ایمانداری ﻇاہر کرتے ہیں اور جب آپس میں ملتے ہیں تو کہتے ہیں کہ مسلمانوں کو کیوں وه باتیں پہنچاتے ہو جو اللہ تعالیٰ نے تمہیں سکھائی ہیں، کیا جانتے نہیں کہ یہ تو اللہ تعالیٰ کے پاس تم پر ان کی حجت ہوجائے گی\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@lxxxiv{کیا یہ نہیں جانتے کہ اللہ تعالیٰ ان کی پوشیدگی اور ﻇاہرداری سب کو جانتا ہے؟\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@lxxxv{ان میں سے بعض ان پڑھ ایسے بھی ہیں کہ جو کتاب کے صرف ﻇاہری الفاظ کو ہی جانتے ہیں اور صرف گمان اور اٹکل ہی پر ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@lxxxvi{ان لوگوں کے لئے “ویل” ہے جو اپنے ہاتھوں کی لکھی ہوئی کتاب کو اللہ تعالیٰ کی طرف کی کہتے ہیں اور اس طرح دنیا کماتے ہیں، ان کے ہاتھوں کی لکھائی کو اور ان کی کمائی کو ویل (ہلاکت) اور افسوس ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@lxxxvii{یہ لوگ کہتے ہیں کہ ہم تو صرف چند روز جہنم میں رہیں گے، ان سے کہو کہ کیا تمہارے پاس اللہ تعالیٰ کا کوئی پروانہ ہے؟ اگر ہے تو یقیناً اللہ تعالیٰ اپنے وعدے کا خلاف نہیں کرے گا، (ہرگز نہیں) بلکہ تم تو اللہ کے ذمے وه باتیں لگاتے ہو جنہیں تم نہیں جانتے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@lxxxviii{یقیناً جس نے بھی برے کام کئے اور اس کی نافرمانیوں نے اسے گھیر لیا، وه ہمیشہ کے لئے جہنمی ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@lxxxix{اور جو لوگ ایمان ﻻئیں اور نیک کام کریں وه جنتی ہیں جو جنت میں ہمیشہ رہیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@xc{اور جب ہم نے بنی اسرائیل سے وعده لیا کہ تم اللہ تعالیٰ کے سوا دوسرے کی عبادت نہ کرنا اور ماں باپ کے ساتھ اچھا سلوک کرنا، اسی طرح قرابتداروں، یتیموں اور مسکینوں کے ساتھ اور لوگوں کو اچھی باتیں کہنا، نمازیں قائم رکھنا اور زکوٰة دیتے رہا کرنا، لیکن تھوڑے سے لوگوں کے علاوه تم سب پھر گئے اور منھ موڑ لیا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@xci{اورجب ہم نے تم سے وعده لیا کہ آپس میں خون نہ بہانا (قتل نہ کرنا) اور آپس والوں کو جلا وطن نہ کرنا، تم نے اقرار کیا اور تم اس کے شاہد بنے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@xcii{لیکن پھر بھی تم نے آپس میں قتل کیا اورآپس کے ایک فرقے کو جلا وطن بھی کیا اور گناه اور زیادتی کے کاموں میں ان کے خلاف دوسرے کی طرفداری کی، ہاں جب وه قیدی ہو کر تمہارے پاس آئے تو تم نے ان کے فدیے دیئے، لیکن ان کا نکالنا جو تم پر حرام تھا (اس کا کچھ خیال نہ کیا) کیا بعض احکام پر ایمان رکھتے ہو اور بعض کے ساتھ کفر کرتے ہو؟ تم میں سے جو بھی ایسا کرے، اس کی سزا اس کے سوا کیا ہو کہ دنیا میں رسوائی اور قیامت کے دن سخت عذاب کی مار، اور اللہ تعالیٰ تمہارے اعمال سے بےخبر نہیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@xciii{یہ وه لوگ ہیں جنہوں نے دنیا کی زندگی کو آخرت کے بدلے خرید لیا ہے، ان کے نہ تو عذاب ہلکے ہوں گے اور نہ ان کی مدد کی جائے گی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@xciv{ہم نے (حضرت) موسیٰ کو کتاب دی اور ان کے پیچھے اور رسول بھیجے اور ہم نے (حضرت) عیسیٰ ابن مریم کو روشن دلیلیں دیں اور روح القدس سے ان کی تائید کروائی۔ لیکن جب کبھی تمہارے پاس رسول وه چیز ﻻئے جو تمہاری طبیعتوں کے خلاف تھی، تم نے جھٹ سے تکبر کیا، پس بعض کو تو جھٹلادیا اور بعض کو قتل بھی کرڈاﻻ\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@xcv{یہ کہتے ہیں کہ ہمارے دل غلاف والے ہیں نہیں نہیں بلکہ ان کے کفر کی وجہ سے انہیں اللہ تعالیٰ نے ملعون کردیا ہے، ان کا ایمان بہت ہی تھوڑا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@xcvi{اور ان کے پاس جب اللہ تعالیٰ کی کتاب ان کی کتاب کو سچا کرنے والی آئی، حاﻻنکہ پہلے یہ خود (اس کے ذریعہ) کافروں پر فتح چاہتے تھے تو باوجود آجانے اور باوجود پہچان لینے کے پھر کفر کرنے لگے، اللہ تعالیٰ کی لعنت ہو کافروں پر\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@xcvii{بہت بری ہے وه چیز جس کے بدلے انہوں نے اپنے آپ کو بیچ ڈاﻻ، وه ان کا کفر کرنا ہے۔ اللہ تعالیٰ کی طرف سے نازل شده چیز کے ساتھ محض اس بات سے جل کر کہ اللہ تعالیٰ نے اپنا فضل اپنے جس بنده پر چاہا نازل فرمایا، اس کے باعﺚ یہ لوگ غضب پر غضب کے مستحق ہوگئے اور ان کافروں کے لئے رسوا کرنے واﻻ عذاب ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@xcviii{اور جب ان سے کہا جاتا ہے کہ اللہ تعالیٰ کی اتاری ہوئی کتاب پر ایمان ﻻؤ تو کہہ دیتے ہیں کہ جو ہم پر اتاری گئی اس پر ہمارا ایمان ہے۔ حاﻻنکہ اس کے بعد والی کے ساتھ جو ان کی کتاب کی تصدیق کرنے والی ہے، کفر کرتے ہیں، اچھا ان سے یہ تو دریافت کریں کہ اگر تمہارا ایمان پہلی کتابوں پر ہے تو پھر تم نے اگلے انبیا کو کیوں قتل کیا؟\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@xcix{تمہارے پاس تو موسیٰ یہی دلیلیں لے کر آئے لیکن تم نے پھر بھی بچھڑا پوجا تم ہو ہی ﻇالم\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@c{جب ہم نے تم سے وعده لیا اور تم پر طور کو کھڑا کردیا (اور کہہ دیا) کہ ہماری دی ہوئی چیز کو مضبوط تھامو اور سنو! تو انہوں نے کہا، ہم نے سنا اور نافرمانی کی اور ان کے دلوں میں بچھڑے کی محبت (گویا) پلا دی گئی بسبب ان کے کفر کے۔ ان سے کہہ دیجیئے کہ تمہارا ایمان تمہیں برا حکم دے رہا ہے، اگر تم مومن ہو\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ci{آپ کہہ دیجیئے کہ اگر آخرت کا گھر صرف تمہارے ہی لئے ہے، اللہ کے نزدیک اور کسی کے لئے نہیں، تو آو اپنی سچائی کے ﺛبوت میں موت طلب کرو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@cii{لیکن اپنی کرتوتوں کو دیکھتے ہوئے کبھی بھی موت نہیں مانگیں گے اللہ تعالیٰ ﻇالموں کو خوب جانتا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ciii{بلکہ سب سے زیاده دنیا کی زندگی کا حریص اے نبی! آپ انہیں کو پائیں گے۔ یہ حرص زندگی میں مشرکوں سے بھی زیاده ہیں ان میں سے تو ہر شخص ایک ایک ہزار سال کی عمر چاہتا ہے، گویا یہ عمر دیا جانا بھی انہیں عذاب سے نہیں چھڑا سکتا، اللہ تعالیٰ ان کے کاموں کو بخوبی دیکھ رہا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@civ{(اے نبی!) آپ کہہ دیجیئے کہ جو جبریل کا دشمن ہو جس نے آپ کے دل پر پیغام باری تعالیٰ اتارا ہے، جو پیغام ان کے پاس کی کتاب کی تصدیق کرنے واﻻ اور مومنوں کو ہدایت اور خوشخبری دینے واﻻ ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cv{(تو اللہ بھی اس کا دشمن ہے) جو شخص اللہ کا اور اس کے فرشتوں اور اس کے رسولوں اور جبرائیل اور میکائیل کا دشمن ہو، ایسے کافروں کا دشمن خود اللہ ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cvi{اور یقیناً ہم نے آپ کی طرف روشن دلیلیں بھیجی ہیں جن کا انکار سوائے بدکاروں کے کوئی نہیں کرتا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cvii{یہ لوگ جب کبھی کوئی عہد کرتے ہیں توان کی ایک نہ ایک جماعت اسے توڑ دیتی ہے، بلکہ ان میں سے اکثر ایمان سے خالی ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cviii{جب کبھی ان کے پاس اللہ کا کوئی رسول ان کی کتاب کی تصدیق کرنے واﻻ آیا، ان اہل کتاب کے ایک فرقہ نے اللہ کی کتاب کو اس طرح پیٹھ پیچھے ڈال دیا، گویا جانتے ہی نہ تھے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cix{اور اس چیز کے پیچھے لگ گئے جسے شیاطین (حضرت) سلیمان کی حکومت میں پڑھتے تھے۔ سلیمان نے تو کفر نہ کیا تھا، بلکہ یہ کفر شیطانوں کا تھا، وه لوگوں کو جادو سکھایا کرتے تھے، اور بابل میں ہاروت ماروت دو فرشتوں پرجو اتارا گیا تھا، وه دونوں بھی کسی شخص کو اس وقت تک نہیں سکھاتے تھے جب تک یہ نہ کہہ دیں کہ ہم تو ایک آزمائش ہیں تو کفر نہ کر، پھر لوگ ان سے وه سیکھتے جس سے خاوند وبیوی میں جدائی ڈال دیں اور دراصل وه بغیر اللہ تعالیٰ کی مرضی کے کسی کو کوئی نقصان نہیں پہنچا سکتے، یہ لوگ وه سیکھتے ہیں جو انہیں نقصان پہنچائے اور نفع نہ پہنچا سکے، اور وه بالیقین جانتے ہیں کہ اس کے لینے والے کا آخرت میں کوئی حصہ نہیں۔ اور وه بدترین چیز ہے جس کے بدلے وه اپنے آپ کو فروخت کر رہے ہیں، کاش کہ یہ جانتے ہوتے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cx{اگر یہ لوگ صاحب ایمان متقی بن جاتے تو اللہ تعالیٰ کی طرف سے بہترین ﺛواب انہیں ملتا، اگر یہ جانتے ہوتے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cxi{اے ایمان والو! تم (نبی صلی اللہ علیہ وسلم کو) “راعنا” نہ کہا کرو، بلکہ “انظرنا” کہو یعنی ہماری طرف دیکھئے اور سنتے رہا کرو اور کافروں کے لئے دردناک عذاب ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cxii{نہ تو اہل کتاب کے کافر اور نہ مشرکین چاہتے ہیں کہ تم پر تمہارے رب کی کوئی بھلائی نازل ہو (ان کے اس حسد سے کیا ہوا) اللہ تعالیٰ جسے چاہے اپنی رحمت خصوصیت سے عطا فرمائے، اللہ تعالیٰ بڑے فضل واﻻ ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cxiii{جس آیت کو ہم منسوخ کردیں، یا بھلا دیں اس سے بہتر یا اس جیسی اور ﻻتے ہیں، کیا تو نہیں جانتا کہ اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cxiv{کیا تجھے علم نہیں کہ زمین و آسمان کا ملک اللہ ہی کے لئے ہے اور اللہ کے سوا تمہارا کوئی ولی اور مددگار نہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cxv{کیا تم اپنے رسول سے یہی پوچھنا چاہتے ہو جو اس سے پہلے موسیٰ ﴿علیہ السلام﴾ سے پوچھا گیا تھا؟ (سنو) ایمان کو کفر سے بدلنے واﻻ سیدھی راه سے بھٹک جاتا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cxvi{ان اہل کتاب کے اکثر لوگ باوجود حق واضح ہوجانے کے محض حسد وبغض کی بنا پر تمہیں بھی ایمان سے ہٹا دینا چاہتے ہیں، تم بھی معاف کرو اور چھوڑو یہاں تک کہ اللہ تعالیٰاپنا حکم ﻻئے۔ یقیناً اللہ تعالے ہر چیز پر قدرت رکھتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cxvii{تم نمازیں قائم رکھو اور زکوٰة دیتے رہا کرو اور جو کچھ بھلائی تم اپنے لئے آگے بھیجو گے، سب کچھ اللہ کے پاس پالو گے، بےشک اللہ تعالیٰ تمہارے اعمال کو خوب دیکھ رہا ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cxviii{یہ کہتے ہیں کہ جنت میں یہود ونصاریٰ کے سوا اور کوئی نہ جائے گا، یہ صرف ان کی آرزوئیں ہیں، ان سے کہو کہ اگر تم سچے ہو تو کوئی دلیل تو پیش کرو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cxix{سنو! جو بھی اپنے آپ کو خلوص کے ساتھ اللہ کے سامنے جھکا دے۔ بےشک اسے اس کا رب پورا بدلہ دے گا، اس پر نہ تو کوئی خوف ہوگا، نہ غم اور اداسی\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cxx{یہود کہتے ہیں کہ نصرانی حق پر نہیں اور نصرانی کہتے ہیں کہ یہودی حق پر نہیں، حاﻻنکہ یہ سب لوگ تورات پڑھتے ہیں۔ اسی طرح ان ہی جیسی بات بےعلم بھی کہتے ہیں۔ قیامت کے دن اللہ ان کے اس اختلاف کا فیصلہ ان کے درمیان کردے گا\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cxxi{اس شخص سے بڑھ کر ﻇالم کون ہے جو اللہ تعالیٰ کی مسجدوں میں اللہ تعالیٰ کے ذکر کئے جانے کو روکے اور ان کی بربادی کی کوشش کرے، ایسے لوگوں کو خوف کھاتے ہوئے اس میں جانا چاہیئے، ان کے لئے دنیا میں بھی رسوائی ہے اور آخرت میں بھی بڑا عذاب ہے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cxxii{اور مشرق اور مغرب کا مالک اللہ ہی ہے۔ تم جدھر بھی منھ کرو ادھر ہی اللہ کا منھ ہے، اللہ تعالیٰ کشادگی اور وسعت واﻻ اور بڑے علم واﻻ ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cxxiii{یہ کہتے ہیں کہ اللہ تعالیٰ کی اوﻻد ہے، (نہیں بلکہ) وه پاک ہے زمین و آسمان کی تمام مخلوق اس کی ملکیت میں ہے اور ہر ایک اس کافرمانبردار ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cxxiv{وه زمین اور آسمانوں کا ابتداءً پیدا کرنے واﻻ ہے، وه جس کام کو کرنا چاہے کہہ دیتا ہے کہ ہوجا، بس وه وہیں ہوجاتا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cxxv{اسی طرح بے علم لوگوں نے بھی کہا کہ خود اللہ تعالیٰ ہم سے باتیں کیوں نہیں کرتا، یا ہمارے پاس کوئی نشانی کیوں نہیں آتی؟ اسی طرح ایسی ہی بات ان کے اگلوں نے بھی کہی تھی، ان کے اور ان کے دل یکساں ہوگئے ہم نے تو یقین والوں کے لئے نشانیاں بیان کردیں\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cxxvi{ہم نے آپ کو حق کے ساتھ خوشخبری دینے واﻻ اور ڈرانے واﻻ بنا کر بھیجا ہے اور جہنمیوں کے بارے میں آپ سے پرسش نہیں ہوگی\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cxxvii{آپ سے یہود ونصاریٰ ہرگز راضی نہیں ہوں گے جب تک کہ آپ ان کے مذہب کے تابع نہ بن جائیں، آپ کہہ دیجیئے کہ اللہ کی ہدایت ہی ہدایت ہے اور اگر آپ نے باوجود اپنے پاس علم آجانے کے، پھر ان کی خواہشوں کی پیروی کی تو اللہ کے پاس آپ کا نہ تو کوئی ولی ہوگا اورنہ مددگار\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cxxviii{جنہیں ہم نے کتاب دی ہے اور وه اسے پڑھنے کے حق کے ساتھ پڑھتے ہیں، وه اس کتاب پر بھی ایمان رکھتے ہیں اور جو اس کے ساتھ کفر کرے وه نقصان واﻻ ہے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cxxix{اے اوﻻد یعقوب! میں نے جو نعمتیں تم پر انعام کی ہیں انہیں یاد کرو اور میں نے تو تمہیں تمام جہانوں پر فضیلت دے رکھی تھی\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cxxx{اس دن سے ڈرو جس دن کوئی نفس کسی نفس کو کچھ فائده نہ پہنچا سکے گا، نہ کسی شخص سے کوئی فدیہ قبول کیا جائے گا، نہ اسے کوئی شفاعت نفع دے گی، نہ ان کی مدد کی جائے گی\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cxxxi{جب ابراہیم ﴿علیہ السلام﴾ کو ان کے رب نے کئی کئی باتوں سے آزمایا اور انہوں نے سب کو پورا کردیا تو اللہ نے فرمایا کہ میں تمہیں لوگوں کا امام بنا دوں گا، عرض کرنے لگے: اور میری اوﻻد کو، فرمایا میرا وعده ﻇالموں سے نہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cxxxii{ہم نے بیت اللہ کو لوگوں کے لئے ﺛواب اور امن وامان کی جگہ بنائی، تم مقام ابراہیم کو جائے نماز مقرر کرلو، ہم نے ابراہیم ﴿علیہ السلام﴾ اور اسماعیل ﴿علیہ السلام﴾ سے وعده لیا کہ تم میرے گھر کو طواف کرنے والوں اور اعتکاف کرنے والوں اور رکوع سجده کرنے والوں کے لئے پاک صاف رکھو\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cxxxiii{جب ابراہیم نے کہا، اے پروردگار! تو اس جگہ کو امن واﻻ شہر بنا اور یہاں کے باشندوں کو جو اللہ تعالیٰ پر اور قیامت کے دن پر ایمان رکھنے والے ہوں، پھلوں کی روزیاں دے اللہ تعالیٰ نے فرمایا: میں کافروں کو بھی تھوڑا فائده دوں گا، پھر انہیں آگ کے عذاب کی طرف بےبس کردوں گا، یہ پہنچنے کی جگہ بری ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cxxxiv{ابراہیم ﴿علیہ السلام﴾ اور اسماعیل ﴿علیہ السلام﴾ کعبہ کی بنیادیں اور دیواریں اٹھاتے جاتے تھے اور کہتے جارہے تھے کہ ہمارے پروردگار! تو ہم سے قبول فرما، تو ہی سننے واﻻ اور جاننے واﻻ ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cxxxv{اے ہمارے رب! ہمیں اپنا فرمانبردار بنا لے اور ہماری اوﻻد میں سے بھی ایک جماعت کو اپنی اطاعت گزار رکھ اور ہمیں اپنی عبادتیں سکھا اور ہماری توبہ قبول فرما، تو توبہ قبول فرمانے واﻻ اور رحم وکرم کرنے واﻻ ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cxxxvi{اے ہمارے رب! ان میں انہی میں سے رسول بھیج جو ان کے پاس تیری آیتیں پڑھے، انہیں کتاب وحکمت سکھائے اور انہیں پاک کرے، یقیناً تو غلبہ واﻻ اور حکمت واﻻ ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cxxxvii{دین ابراہیمی سے وہی بےرغبتی کرے گا جو محض بےوقوف ہو، ہم نے تو اسے دنیا میں بھی برگزیده کیا تھا اور آخرت میں بھی وه نیکوکاروں میں سے ہے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cxxxviii{جب کبھی بھی انہیں ان کے رب نے کہا، فرمانبردار ہوجا، انہوں نے کہا، میں نے رب العالمین کی فرمانبرداری کی\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cxxxix{اسی کی وصیت ابراہیم اور یعقوب نے اپنی اوﻻدکو کی، کہ ہمارے بچو! اللہ تعالیٰ نے تمہارے لئے اس دین کو پسند فرمالیا ہے، خبردار! تم مسلمان ہی مرنا\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cxl{کیا (حضرت) یعقوب کے انتقال کے وقت تم موجود تھے؟ جب انہوں نے اپنی اوﻻد کو کہا کہ میرے بعد تم کس کی عبادت کرو گے؟ تو سب نے جواب دیا کہ آپ کے معبود کی اور آپ کے آباواجداد ابرہیم ﴿علیہ السلام﴾ اور اسماعیل ﴿علیہ السلام﴾ اور اسحاق ﴿علیہ السلام﴾ کے معبود کی جو معبود ایک ہی ہے اور ہم اسی کے فرمانبردار رہیں گے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cxli{یہ جماعت تو گزر چکی، جو انہوں نے کیا وه ان کے لئے ہے اور جو تم کرو گے تمہارے لئے ہے۔ ان کے اعمال کے بارے میں تم نہیں پوچھے جاؤ گے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cxlii{یہ کہتے ہیں کہ یہود و نصاریٰ بن جاؤ تو ہدایت پاؤ گے۔ تم کہو بلکہ صحیح راه پر ملت ابراہیمی والے ہیں، اور ابراہیم خالص اللہ کے پرستار تھے اور مشرک نہ تھے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cxliii{اے مسلمانو! تم سب کہو کہ ہم اللہ پر ایمان ﻻئے اور اس چیز پر بھی جو ہماری طرف اتاری گئی اور جو چیز ابراہیم اسماعیل اسحاق یعقوب (علیہم السلام) اور ان کی اوﻻد پر اتاری گئی اور جو کچھ اللہ کی جانب سے موسیٰ اور عیسیٰ (علیہما السلام) اور دوسرے انبیا (علیہم السلام) دیئے گئے۔ ہم ان میں سے کسی کے درمیان فرق نہیں کرتے، ہم اللہ کے فرمانبردار ہیں\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cxliv{اگر وه تم جیسا ایمان ﻻئیں تو ہدایت پائیں، اور اگر منھ موڑیں تو وه صریح اختلاف میں ہیں، اللہ تعالی ان سے عنقریب آپ کی کفایت کرے گا اور وه خوب سننے اور جاننے واﻻ ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cxlv{اللہ کا رنگ اختیار کرو اور اللہ تعالیٰ سے اچھا رنگ کس کا ہوگا؟ ہم تو اسی کی عبادت کرنے والے ہیں\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cxlvi{آپ کہہ دیجیئے کیا تم ہم سے اللہ کے بارے میں جھگڑتے ہو جو ہمارا اور تمہارا رب ہے، ہمارے لئے ہمارے اعمال ہیں اور تمہارے لئے تمہارے اعمال، ہم تو اسی کے لئے مخلص ہیں\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cxlvii{کیا تم کہتے ہو کہ ابراہیم اور اسماعیل اور اسحاق اور یعقوب (علیہم السلام) اور ان کی اوﻻد یہودی یا نصرانی تھے؟ کہہ دو کہ کیا تم زیاده جانتے ہو، یا اللہ تعالیٰ؟ اللہ کے پاس شہادت چھپانے والے سے زیاده ﻇالم اور کون ہے؟ اور اللہ تمہارے کاموں سے غافل نہیں\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cxlviii{یہ امت ہے جو گزرچکی، جو انہوں نے کیا ان کے لئے ہے اور جو تم نے کیا تمہارے لئے، تم ان کےاعمال کے بارے میں سوال نہ کئے جاؤ گے\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cxlix{عنقریب نادان لوگ کہیں گے کہ جس قبلہ پر یہ تھے اس سے انہیں کس چیز نے ہٹایا؟ آپ کہہ دیجیئے کہ مشرق ومغرب کا مالک اللہ تعالیٰ ہی ہے وه جسے چاہے سیدھی راه کی ہدایت کردے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cl{ہم نے اسی طرح تمہیں عادل امت بنایا ہے تاکہ تم لوگوں پر گواه ہوجاؤ اور رسول (صلی اللہ علیہ وسلم) تم پر گواه ہوجائیں، جس قبلہ پر تم پہلے سے تھے اسے ہم نے صرف اس لئے مقرر کیا تھا کہ ہم جان لیں کہ رسول کا سچا تابعدار کون ہے اور کون ہے جو اپنی ایڑیوں کے بل پلٹ جاتا ہے گو یہ کام مشکل ہے، مگر جنہیں اللہ نے ہدایت دی ہے (ان پر کوئی مشکل نہیں) اللہ تعالیٰ تمہارے ایمان ضائع نہ کرے گا اللہ تعالیٰ لوگوں کے ساتھ شفقت اور مہربانی کرنے واﻻ ہے\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cli{ہم آپ کے چہرے کو بار بار آسمان کی طرف اٹھتے ہوئے دیکھ رہے ہیں، اب ہم آپ کو اس قبلہ کی جانب متوجہ کریں گے جس سے آپ خوش ہوجائیں، آپ اپنا منھ مسجد حرام کی طرف پھیر لیں اور آپ جہاں کہیں ہوں اپنا منھ اسی طرف پھیرا کریں۔ اہل کتاب کو اس بات کے اللہ کی طرف سے برحق ہونے کا قطعی علم ہے اور اللہ تعالیٰ ان اعمال سے غافل نہیں جو یہ کرتے ہیں\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@clii{اور آپ اگرچہ اہل کتاب کو تمام دلیلیں دے دیں لیکن وه آپ کے قبلے کی پیروی نہیں کریں گے اور نہ آپ ان کے قبلے کو ماننے والے ہیں اور نہ یہ آپس میں ایک دوسرے کے قبلے کو ماننے والے ہیں اور اگر آپ باوجودیکہ آپ کے پاس علم آچکا پھر بھی ان کی خواہشوں کے پیچھے لگ جائیں تو بالیقین آپ بھی ﻇالموں میں سے ہوجائیں گے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cliii{جنہیں ہم نے کتاب دی ہے وه تو اسے ایسا پہچانتے ہیں جیسے کوئی اپنے بچوں کو پہچانے، ان کی ایک جماعت حق کو پہچان کر پھر چھپاتی ہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cliv{آپ کے رب کی طرف سے یہ سراسر حق ہے، خبردار آپ شک کرنے والوں میں سے نہ ہونا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@clv{ہر شخص ایک نہ ایک طرف متوجہ ہو رہا ہے تم نیکیوں کی طرف دوڑو۔ جہاں کہیں بھی تم ہوگے، اللہ تمہیں لے آئے گا۔ اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@clvi{آپ جہاں سے نکلیں اپنا منھ (نماز کے لئے) مسجد حرام کی طرف کرلیا کریں، یہی حق ہے آپ کے رب کی طرف سے، جو کچھ تم کر رہے ہو اس سے اللہ تعالیٰ بےخبر نہیں\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@clvii{اور جس جگہ سے آپ نکلیں اپنا منھ مسجد حرام کی طرف پھیر لیں اور جہاں کہیں تم ہو اپنے چہرے اسی طرف کیا کرو تاکہ لوگوں کی کوئی حجت تم پر باقی نہ ره جائے سوائے ان لوگوں کے جنہوں نے ان میں سے ﻇلم کیا ہے تم ان سے نہ ڈرو مجھ ہی سے ڈرو اور تاکہ میں اپنی نعمت تم پر پوری کروں اور اس لئے بھی کہ تم راه راست پاؤ\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@clviii{جس طرح ہم نے تم میں تمہی میں سے رسول بھیجا جو ہماری آیتیں تمہارے سامنے تلاوت کرتا ہے اور تمہیں پاک کرتا ہے اور تمہیں کتاب وحکمت اور وه چیزیں سکھاتا ہے جن سے تم بےعلم تھے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@clix{اس لئے تم میرا ذکر کرو، میں بھی تمہیں یاد کروں گا، میری شکر گزاری کرو اور ناشکری سے بچو\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@clx{اے ایمان والو! صبر اور نماز کے ذریعہ مدد چاہو، اللہ تعالی صبر والوں کا ساتھ دیتا ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@clxi{اور اللہ تعالیٰ کی راه کے شہیدوں کو مرده مت کہو وه زنده ہیں، لیکن تم نہیں سمجھتے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@clxii{اور ہم کسی نہ کسی طرح تمہاری آزمائش ضرور کریں گے، دشمن کے ڈر سے، بھوک پیاس سے، مال وجان اور پھلوں کی کمی سے اور ان صبر کرنے والوں کو خوشخبری دے دیجیئے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@clxiii{جنہیں، جب کبھی کوئی مصیبت آتی ہے تو کہہ دیا کرتے ہیں کہ ہم تو خود اللہ تعالیٰ کی ملکیت ہیں اور ہم اسی کی طرف لوٹنے والے ہیں\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@clxiv{ان پر ان کے رب کی نوازشیں اور رحمتیں ہیں اور یہی لوگ ہدایت یافتہ ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@clxv{صفااور مروه اللہ تعالیٰ کی نشانیوں میں سے ہیں، اس لئے بیت اللہ کا حج وعمره کرنے والے پر ان کا طواف کرلینے میں بھی کوئی گناه نہیں اپنی خوشی سے بھلائی کرنے والوں کا اللہ قدردان ہے اور انہیں خوب جاننے واﻻ ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@clxvi{جو لوگ ہماری اتاری ہوئی دلیلوں اور ہدایت کو چھپاتے ہیں باوجودیکہ ہم اسے اپنی کتاب میں لوگوں کے لئے بیان کرچکے ہیں، ان لوگوں پر اللہ کی اور تمام لعنت کرنے والوں کی لعنت ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@clxvii{مگر وه لوگ جو توبہ کرلیں اور اصلاح کرلیں اور بیان کردیں، تو میں ان کی توبہ قبول کرلیتا ہوں اور میں توبہ قبول کرنے واﻻ اور رحم وکرم کرنے واﻻ ہوں\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@clxviii{یقیناً جو کفار اپنے کفر میں ہی مرجائیں، ان پر اللہ تعالیٰ کی، فرشتوں کی اور تمام لوگوں کی لعنت ہے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@clxix{جس میں یہ ہمیشہ رہیں گے، نہ ان سے عذاب ہلکا کیا جائے گا اور نہ انہیں ڈھیل دی جائے گی\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@clxx{تم سب کا معبود ایک ہی معبود ہے، اس کے سوا کوئی معبود برحق نہیں وه بہت رحم کرنے واﻻ اور بڑا مہربان ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@clxxi{آسمانوں اور زمین کی پیدائش، رات دن کا ہیر پھیر، کشتیوں کا لوگوں کو نفع دینے والی چیزوں کو لئے ہوئے سمندروں میں چلنا، آسمان سے پانی اتار کر، مرده زمین کو زنده کردینا، اس میں ہر قسم کے جانوروں کو پھیلا دینا، ہواؤں کے رخ بدلنا، اور بادل، جو آسمان اور زمین کے درمیان مسخر ہیں، ان میں عقلمندوں کے لئے قدرت الٰہی کی نشانیاں ہیں\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@clxxii{بعض لوگ ایسے بھی ہیں جو اللہ کے شریک اوروں کو ٹھہرا کر ان سے ایسی محبت رکھتے ہیں، جیسی محبت اللہ سے ہونی چاہیئے اور ایمان والے اللہ کی محبت میں بہت سخت ہوتے ہیں کاش کہ مشرک لوگ جانتے جب کہ اللہ کے عذاب کو دیکھ کر (جان لیں گے) کہ تمام طاقت اللہ ہی کو ہے اور اللہ تعالیٰ سخت عذاب دینے واﻻ ہے (تو ہرگز شرک نہ کرتے)\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@clxxiii{جس وقت پیشوا لوگ اپنے تابعداروں سے بیزار ہوجائیں گے اور عذاب کو اپنی آنکھوں سے دیکھ لیں گے اور کل رشتے ناتے ٹوٹ جائیں گے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@clxxiv{اور تابعدار لوگ کہنے لگیں گے، کاش ہم دنیا کی طرف دوباره جائیں تو ہم بھی ان سے ایسے ہی بیزار ہوجائیں جیسے یہ ہم سے ہیں، اسی طرح اللہ تعالیٰ انہیں ان کے اعمال دکھائے گا ان کو حسرت دﻻنے کو، یہ ہرگز جہنم سے نہ نکلیں گے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@clxxv{لوگو! زمین میں جتنی بھی حلال اور پاکیزه چیزیں ہیں انہیں کھاؤ پیو اور شیطانی راه پر نہ چلو، وه تمہارا کھلا ہوا دشمن ہے\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@clxxvi{وه تمہیں صرف برائی اور بےحیائی کا اور اللہ تعالیٰ پر ان باتوں کے کہنے کا حکم دیتا ہے جن کا تمہیں علم نہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@clxxvii{اور ان سے جب کبھی کہا جاتا ہے کہ اللہ تعالیٰ کی اتاری ہوئی کتاب کی تابعداری کرو تو جواب دیتے ہیں کہ ہم تو اس طریقے کی پیروی کریں گے جس پر ہم نے اپنے باپ دادوں کو پایا، گو ان کے باپ دادے بےعقل اور گم کرده راه ہوں\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@clxxviii{کفار کی مثال ان جانوروں کی طرح ہے جو اپنے چرواہے کی صرف پکار اور آواز ہی کو سنتے ہیں (سمجھتے نہیں) وه بہرے، گونگے اور ا ندھے ہیں، انہیں عقل نہیں\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@clxxix{اے ایمان والو! جو پاکیزه چیزیں ہم نے تمہیں دے رکھی ہیں انہیں کھاؤ، پیو اور اللہ تعالیٰ کا شکر کرو، اگر تم خاص اسی کی عبادت کرتے ہو\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@clxxx{تم پر مرده اور (بہا ہوا) خون اور سور کا گوشت اور ہر وه چیز جس پر اللہ کے سوا دوسروں کا نام پکارا گیا ہو حرام ہے پھر جو مجبور ہوجائے اور وه حد سے بڑھنے واﻻ اور زیادتی کرنے واﻻ نہ ہو، اس پر ان کے کھانے میں کوئی گناه نہیں، اللہ تعالیٰ بخشش کرنے واﻻ مہربان ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@clxxxi{بے شک جو لوگ اللہ تعالیٰ کی اتاری ہوئی کتاب چھپاتے ہیں اور اسے تھوڑی تھوڑی سی قیمت پر بیچتے ہیں، یقین مانو کہ یہ اپنے پیٹ میں آگ بھر رہے ہیں، قیامت کے دن اللہ تعالیٰ ان سے بات بھی نہ کرے گا، نہ انہیں پاک کرے گا، بلکہ ان کے لئے دردناک عذاب ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@clxxxii{یہ وه لوگ ہیں جنہوں نے گمراہی کو ہدایت کے بدلے اور عذاب کو مغفرت کے بدلے خرید لیا ہے، یہ لوگ آگ کا عذاب کتنا برداشت کرنے والے ہیں\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@clxxxiii{ان عذابوں کا باعﺚ یہی ہے کہ اللہ تعالیٰ نے سچی کتاب اتاری اور اس کتاب میں اختلاف کرنے والے یقیناً دور کے خلاف میں ہیں\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@clxxxiv{ساری اچھائی مشرق ومغرب کی طرف منھ کرنے میں ہی نہیں بلکہ حقیقتاً اچھا وه شخص ہے جو اللہ تعالی پر، قیامت کے دن پر، فرشتوں پر، کتاب اللہ پر اور نبیوں پر ایمان رکھنے واﻻ ہو، جو مال سے محبت کرنے کے باوجود قرابت داروں، یتیموں، مسکینوں، مسافروں اور سوال کرنے والے کو دے، غلاموں کو آزاد کرے، نماز کی پابندی اور زکوٰة کی ادائیگی کرے، جب وعده کرے تب اسے پورا کرے، تنگدستی، دکھ درد اور لڑائی کے وقت صبر کرے، یہی سچے لوگ ہیں اور یہی پرہیزگار ہیں\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@clxxxv{اے ایمان والو! تم پر مقتولوں کا قصاص لینا فرض کیا گیا ہے، آزاد آزاد کے بدلے، غلام غلام کے بدلے، عورت عورت کے بدلے۔ ہاں جس کسی کو اس کے بھائی کی طرف سے کچھ معافی دے دی جائے اسے بھلائی کی اتباع کرنی چاہئے اور آسانی کے ساتھ دیت ادا کرنی چاہئے۔ تمہارے رب کی طرف سے یہ تخفیف اور رحمت ہے اس کے بعد بھی جو سرکشی کرے اسے درد ناک عذاب ہوگا\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@clxxxvi{عقلمندو! قصاص میں تمہارے لئے زندگی ہے اس باعﺚ تم (قتل ناحق سے) رکو گے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@clxxxvii{تم پر فرض کر دیا گیا ہے کہ جب تم میں سے کوئی مرنے لگے اور مال چھوڑ جاتا ہو تو اپنے ماں باپ اور قرابت داروں کے لئے اچھائی کے ساتھ وصیت کرجائے، پرہیزگاروں پر یہ حق اور ﺛابت ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@clxxxviii{اب جو شخص اسے سننے کے بعد بدل دے اس کا گناه بدلنے والے پر ہی ہوگا، واقعی اللہ تعالیٰ سننے واﻻ جاننے واﻻ ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@clxxxix{ہاں جو شخص وصیت کرنے والے کی جانب داری یا گناه کی وصیت کردینے سے ڈرے پس وه ان میں آپس میں اصلاح کرادے تو اس پر گناه نہیں، اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cxc{اے ایمان والو! تم پر روزے رکھنا فرض کیا گیا جس طرح تم سے پہلے لوگوں پر فرض کئے گئے تھے، تاکہ تم تقویٰ اختیار کرو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cxci{گنتی کے چند ہی دن ہیں لیکن تم میں سے جو شخص بیمار ہو یا سفر میں ہو تو وه اور دنوں میں گنتی کو پورا کر لے اور اس کی طاقت رکھنے والے فدیہ میں ایک مسکین کو کھانا دیں، پھر جو شخص نیکی میں سبقت کرے وه اسی کے لئے بہتر ہے لیکن تمہارے حق میں بہتر کام روزے رکھنا ہی ہے اگر تم باعلم ہو\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cxcii{ماه رمضان وه ہے جس میں قرآن اتارا گیا جو لوگوں کو ہدایت کرنے واﻻ ہے اور جس میں ہدایت کی اور حق وباطل کی تمیز کی نشانیاں ہیں، تم میں سے جو شخص اس مہینہ کو پائے اسے روزه رکھنا چاہئے، ہاں جو بیمار ہو یا مسافر ہو اسے دوسرے دنوں میں یہ گنتی پوری کرنی چاہئے، اللہ تعالیٰ کا اراده تمہارے ساتھ آسانی کا ہے، سختی کا نہیں، وه چاہتا ہے کہ تم گنتی پوری کرلو اور اللہ تعالیٰ کی دی ہوئی ہدایت پر اس کی بڑائیاں بیان کرو اور اس کا شکر کرو\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cxciii{جب میرے بندے میرے بارے میں آپ سے سوال کریں تو آپ کہہ دیں کہ میں بہت ہی قریب ہوں ہر پکارنے والے کی پکار کو جب کبھی وه مجھے پکارے، قبول کرتا ہوں اس لئے لوگوں کو بھی چاہئے کہ وه میری بات مان لیا کریں اور مجھ پر ایمان رکھیں، یہی ان کی بھلائی کا باعﺚ ہے\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cxciv{روزے کی راتوں میں اپنی بیویوں سے ملنا تمہارے لئے حلال کیا گیا، وه تمہارا لباس ہیں اور تم ان کے لباس ہو، تمہاری پوشیده خیانتوں کا اللہ تعالیٰ کو علم ہے، اس نے تمہاری توبہ قبول فرما کر تم سے درگزر فرمالیا، اب تمہیں ان سے مباشرت کی اور اللہ تعالیٰ کی لکھی ہوئی چیز کو تلاش کرنے کی اجازت ہے، تم کھاتے پیتے رہو یہاں تک کہ صبح کا سفید دھاگہ سیاه دھاگے سے ﻇاہر ہوجائے۔ پھر رات تک روزے کو پورا کرو اور عورتوں سے اس وقت مباشرت نہ کرو جب کہ تم مسجدوں میں اعتکاف میں ہو۔ یہ اللہ تعالیٰ کی حدود ہیں، تم ان کے قریب بھی نہ جاؤ۔ اسی طرح اللہ تعالیٰ اپنی آیتیں لوگوں کے لئے بیان فرماتا ہے تاکہ وه بچیں\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cxcv{اور ایک دوسرے کا مال ناحق نہ کھایا کرو، نہ حاکموں کو رشوت پہنچا کر کسی کا کچھ مال ﻇلم وستم سے اپنا کر لیا کرو، حاﻻنکہ تم جانتے ہو\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cxcvi{لوگ آپ سے چاند کے بارے میں سوال کرتے ہیں آپ کہہ دیجیئے کہ یہ لوگوں (کی عبادت) کے وقتوں اور حج کے موسم کے لئے ہے (احرام کی حالت میں) اور گھروں کے پیچھے سے تمہارا آنا کچھ نیکی نہیں، بلکہ نیکی واﻻ وه ہے جو متقی ہو۔ اور گھروں میں تو دروازوں میں سے آیا کرو اور اللہ سے ڈرتے رہو، تاکہ تم کامیاب ہوجاؤ\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cxcvii{لڑو اللہ کی راه میں ان سے جو تم سے لڑتے ہیں اور زیادتی نہ کرو، اللہ تعالیٰ زیادتی کرنے والوں کو پسند نہیں فرماتا\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cxcviii{انہیں مارو جہاں بھی پاؤ اور انہیں نکالو جہاں سے انہوں نے تمہیں نکاﻻ ہے اور (سنو) فتنہ قتل سے زیاده سخت ہے اور مسجد حرام کے پاس ان سے لڑائی نہ کرو جب تک کہ یہ خود تم سے نہ لڑیں، اگر یہ تم سے لڑیں تو تم بھی انہیں مارو کافروں کا بدلہ یہی ہے\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cxcix{اگر یہ باز آجائیں تو اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cc{ان سے لڑو جب تک کہ فتنہ نہ مٹ جائے اور اللہ تعالیٰ کا دین غالب نہ آجائے، اگر یہ رک جائیں (تو تم بھی رک جاؤ) زیادتی تو صرف ﻇالموں پر ہی ہے\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cci{حرمت والے مہینے حرمت والے مہینوں کے بدلے ہیں اور حرمتیں ادلے بدلے کی ہیں جو تم پر زیادتی کرے تم بھی اس پر اسی کے مثل زیادتی کرو جو تم پر کی ہے اور اللہ تعالیٰ سے ڈرتے رہا کرو اور جان رکھو کہ اللہ تعالیٰ پرہیزگاروں کے ساتھ ہے\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@ccii{اللہ تعالیٰ کی راه میں خرچ کرو اور اپنے ہاتھوں ہلاکت میں نہ پڑو اور سلوک واحسان کرو، اللہ تعالیٰ احسان کرنے والوں کو دوست رکھتا ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cciii{حج اور عمرے کو اللہ تعالیٰ کے لئے پورا کرو، ہاں اگر تم روک لئے جاؤ تو جو قربانی میسر ہو، اسے کرڈالو اور اپنے سر نہ منڈواؤ جب تک کہ قربانی قربان گاه تک نہ پہنچ جائے البتہ تم میں سے جو بیمار ہو، یا اس کے سر میں کوئی تکلیف ہو (جس کی وجہ سے سر منڈالے) تو اس پر فدیہ ہے، خواه روزے رکھ لے، خواه صدقہ دے دے، خواه قربانی کرے پس جب تم امن کی حالت میں ہوجاؤ تو جو شخص عمرے سے لے کر حج تک تمتع کرے، پس اسے جو قربانی میسر ہو اسے کر ڈالے، جسے طاقت ہی نہ ہو وه تین روزے تو حج کے دنوں میں رکھ لے اور سات واپسی میں، یہ پورے دس ہوگئے۔ یہ حکم ان کے لئے ہے جو مسجد حرام کے رہنے والے نہ ہوں، لوگو! اللہ سے ڈرتے رہو اور جان لو کہ اللہ تعالیٰ سخت عذاب واﻻ ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cciv{حج کے مہینے مقرر ہیں اس لئے جو شخص ان میں حج ﻻزم کرلے وه اپنی بیوی سے میل ملاپ کرنے، گناه کرنے اور لڑائی جھگڑے کرنے سے بچتا رہے، تم جو نیکی کرو گے اس سے اللہ تعالیٰ باخبر ہے اور اپنے ساتھ سفر خرچ لے لیا کرو، سب سے بہتر توشہ اللہ تعالیٰ کا ڈر ہے اور اے عقلمندو! مجھ سے ڈرتے رہا کرو\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@ccv{تم پر اپنے رب کا فضل تلاش کرنے میں کوئی گناه نہیں جب تم عرفات سے لوٹو تو مشعر حرام کے پاس ذکر الٰہی کرو اور اس کا ذکر کرو جیسے کہ اس نے تمہیں ہدایت دی، حاﻻنکہ تم اس سے پہلے راه بھولے ہوئے تھے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@ccvi{پھر تم اس جگہ سے لوٹو جس جگہ سے سب لوگ لوٹتے ہیں اور اللہ تعالیٰ سے طلب بخشش کرتے رہو یقیناً اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@ccvii{پھر جب تم ارکان حج ادا کر چکو تو اللہ تعالیٰ کا ذکر کرو جس طرح تم اپنے باپ دادوں کا ذکر کیا کرتے تھے، بلکہ اس سے بھی زیاده بعض لوگ وه بھی ہیں جو کہتے ہیں اے ہمارے رب! ہمیں دنیا میں دے۔ ایسے لوگوں کا آخرت میں کوئی حصہ نہیں\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@ccviii{اور بعض لوگ وه بھی ہیں جو کہتے ہیں اے ہمارے رب! ہمیں دنیا میں نیکی دے اور آخرت میں بھی بھلائی عطا فرما اور ہمیں عذاب جہنم سے نجات دے\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@ccix{یہ وه لوگ ہیں جن کے لئے ان کے اعمال کا حصہ ہے اور اللہ تعالیٰ جلد حساب لینے واﻻ ہے\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@ccx{اور اللہ تعالیٰ کی یاد ان گنتی کے چند دنوں (ایام تشریق) میں کرو، دو دن کی جلدی کرنے والے پر بھی کوئی گناه نہیں، اور جو پیچھے ره جائے اس پر بھی کوئی گناه نہیں، یہ پرہیزگارکے لئے ہے اور اللہ تعالیٰ سے ڈرتے رہو اور جان رکھو کہ تم سب اسی کی طرف جمع کئے جاؤ گے\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@ccxi{بعض لوگوں کی دنیاوی غرض کی باتیں آپ کو خوش کر دیتی ہیں اور وه اپنے دل کی باتوں پر اللہ کو گواه کرتا ہے، حاﻻنکہ دراصل وه زبردست جھگڑالو ہے\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@ccxii{جب وه لوٹ کر جاتا ہے تو زمین میں فساد پھیلانے کی اور کھیتی اور نسل کی بربادی کی کوشش میں لگا رہتا ہے اور اللہ تعالیٰ فساد کو ناپسند کرتا ہے\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@ccxiii{اور جب اس سے کہا جائے کہ اللہ سے ڈر تو تکبر اور تعصب اسے گناه پر آماده کر دیتا ہے، ایسے کے لئے بس جہنم ہی ہے اور یقیناً وه بد ترین جگہ ہے\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@ccxiv{اور بعض لوگ وه بھی ہیں کہ اللہ تعالیٰ کی رضامندی کی طلب میں اپنی جان تک بیچ ڈالتے ہیں اور اللہ تعالیٰ اپنے بندوں پر بڑی مہربانی کرنے واﻻ ہے\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@ccxv{ایمان والو! اسلام میں پورے پورے داخل ہوجاؤ اور شیطان کے قدموں کی تابعداری نہ کرو وه تمہارا کھلا دشمن ہے\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@ccxvi{اگر تم باوجود تمہارے پاس دلیلیں آجانے کے بھی پھسل جاؤ تو جان لو کہ اللہ تعالیٰ غلبہ واﻻ اور حکمت واﻻ ہے\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@ccxvii{کیا لوگوں کو اس بات کا انتظار ہے کہ ان کے پاس خود اللہ تعالیٰ ابر کے سائبانوں میں آجائے اور فرشتے بھی اور کام انتہا تک پہنچا دیا جائے، اللہ ہی کی طرف تمام کام لوٹائے جاتے ہیں\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@ccxviii{بنی اسرائیل سے پوچھو تو کہ ہم نے انہیں کس قدر روشن نشانیاں عطا فرمائیں اور جو شخص اللہ تعالیٰ کی نعمتوں کو اپنے پاس پہنچ جانے کے بعد بدل ڈالے (وه جان لے) کہ اللہ تعالیٰ بھی سخت عذابوں واﻻ ہے\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@ccxix{کافروں کے لئے دنیا کی زندگی خوب زینت دار کی گئی ہے، وه ایمان والوں سے ہنسی مذاق کرتے ہیں، حاﻻنکہ پرہیزگار لوگ قیامت کے دن ان سے اعلیٰ ہوں گے، اللہ تعالیٰ جسے چاہتا ہے بےحساب روزی دیتا ہے\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@ccxx{دراصل لوگ ایک ہی گروه تھے اللہ تعالیٰ نے نبیوں کو خوشخبریاں دینے اور ڈرانے واﻻ بنا کر بھیجا اور ان کے ساتھ سچی کتابیں نازل فرمائیں، تاکہ لوگوں کے ہر اختلافی امر کا فیصلہ ہوجائے۔ اور صرف ان ہی لوگوں نے جنھیں کتاب دی گئی تھی، اپنے پاس دﻻئل آچکنے کے بعد آپس کے بغض وعناد کی وجہ سے اس میں اختلاف کیا اس لئے اللہ پاک نے ایمان والوں کی اس اختلاف میں بھی حق کی طرف اپنی مشیئت سے رہبری کی اور اللہ جس کو چاہے سیدھی راه کی طرف رہبری کرتا ہے\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@ccxxi{کیا تم یہ گمان کئے بیٹھے ہو کہ جنت میں چلے جاؤ گے، حاﻻنکہ اب تک تم پر وه حاﻻت نہیں آئے جو تم سے اگلے لوگوں پر آئے تھے۔ انہیں بیماریاں اور مصیبتیں پہنچیں اور وہ یہاں تک جھنجھوڑے گئے کہ رسول اور اس کے ساتھ کے ایمان والے کہنے لگے کہ اللہ کی مدد کب آئے گی؟ سن رکھو کہ اللہ کی مدد قریب ہی ہے\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@ccxxii{آپ سے پوچھتے ہیں کہ وه کیا خرچ کریں؟ آپ کہہ دیجیئے جو مال تم خرچ کرو وه ماں باپ کے لئے ہے اور رشتہداروں اور یتیموں اور مسکینوں اور مسافروں کے لئے ہے اور تم جو کچھ بھلائی کرو گے اللہ تعالیٰ کو اس کا علم ہے\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@ccxxiii{تم پر جہاد فرض کیا گیا گو وه تمہیں دشوار معلوم ہو، ممکن ہے کہ تم کسی چیز کو بری جانو اور دراصل وہی تمہارے لئے بھلی ہو اور یہ بھی ممکن ہے کہ تم کسی چیز کو اچھی سمجھو، حاﻻنکہ وه تمہارے لئے بری ہو، حقیقی علم اللہ ہی کو ہے، تم محض بےخبر ہو\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@ccxxiv{لوگ آپ سے حرمت والے مہینوں میں لڑائی کی بابت سوال کرتے ہیں، آپ کہہ دیجیئے کہ ان میں لڑائی کرنا بڑا گناه ہے، لیکن اللہ کی راه سے روکنا، اس کے ساتھ کفر کرنا اور مسجد حرام سے روکنا اور وہاں کے رہنے والوں کو وہاں سے نکالنا، اللہ کے نزدیک اس سے بھی بڑا گناه ہے یہ فتنہ قتل سے بھی بڑا گناه ہے، یہ لوگ تم سے لڑائی بھڑائی کرتے ہی رہیں گے یہاں تک کہ اگر ان سے ہوسکے تو تمہیں تمہارے دین سے مرتد کردیں اور تم میں سے جو لوگ اپنے دین سے پلٹ جائیں اور اسی کفر کی حالت میں مریں، ان کے اعمال دنیوی اور اخروی سب غارت ہوجائیں گے۔ یہ لوگ جہنمی ہوں گے اور ہمیشہ ہمیشہ جہنم میں ہی رہیں گے\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@ccxxv{البتہ ایمان ﻻنے والے، ہجرت کرنے والے، اللہ کی راه میں جہاد کرنے والے ہی رحمت الٰہی کے امیدوار ہیں، اللہ تعالیٰ بہت بخشنے واﻻ اور بہت مہربانی کرنے واﻻ ہے\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@ccxxvi{لوگ آپ سے شراب اور جوئے کا مسئلہ پوچھتے ہیں، آپ کہہ دیجیئے ان دونوں میں بہت بڑا گناه ہے اور لوگوں کو اس سے دنیاوی فائده بھی ہوتا ہے، لیکن ان کا گناه ان کے نفع سے بہت زیاده ہے۔ آپ سے یہ بھی دریافت کرتے ہیں کہ کیا کچھ خرچ کریں؟ تو آپ کہہ دیجیئے حاجت سے زائد چیز، اللہ تعالیٰ اسی طرح اپنے احکام صاف صاف تمہارے لئے بیان فرما رہا ہے، تاکہ تم سوچ سمجھ سکو،\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@ccxxvii{دنیا اور آخرت کے امور کو۔ اور تجھ سے یتیموں کے بارے میں بھی سوال کرتے ہیں آپ کہہ دیجیئے کہ ان کی خیرخواہی بہتر ہے، تم اگر ان کا مال اپنے مال میں ملا بھی لو تو وه تمہارے بھائی ہیں، بدنیت اور نیک نیت ہر ایک کو اللہ خوب جانتا ہے اور اگر اللہ چاہتا تو تمہیں مشقت میں ڈال دیتا، یقیناً اللہ تعالیٰ غلبہ واﻻ اور حکمت واﻻ ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@ccxxviii{اور شرک کرنے والی عورتوں سے تاوقتیکہ وه ایمان نہ ﻻئیں تم نکاح نہ کرو، ایمان والی لونڈی بھی شرک کرنے والی آزاد عورت سے بہت بہتر ہے، گو تمہیں مشرکہ ہی اچھی لگتی ہو اور نہ شرک کرنے والے مردوں کے نکاح میں اپنی عورتوں کو دو جب تک کہ وه ایمان نہ ﻻئیں، ایمان والا غلام آزاد مشرک سے بہتر ہے، گو مشرک تمہیں اچھا لگے۔ یہ لوگ جہنم کی طرف بلاتے ہیں اور اللہ جنت کی طرف اور اپنی بخشش کی طرف اپنے حکم سے بلاتا ہے، وه اپنی آیتیں لوگوں کے لئے بیان فرما رہا ہے، تاکہ وه نصیحت حاصل کریں\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@ccxxix{آپ سے حیض کے بارے میں سوال کرتے ہیں، کہہ دیجیئے کہ وه گندگی ہے، حالت حیض میں عورتوں سے الگ رہو اور جب تک وه پاک نہ ہوجائیں ان کے قریب نہ جاؤ، ہاں جب وه پاک ہوجائیں تو ان کے پاس جاؤ جہاں سے اللہ نے تمہیں اجازت دی ہے، اللہ توبہ کرنے والوں کو اور پاک رہنے والوں کو پسند فرماتا ہے\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@ccxxx{تمہاری بیویاں تمہاری کھیتیاں ہیں، اپنی کھیتیوں میں جس طرح چاہو آؤ اور اپنے لئے (نیک اعمال) آگے بھیجو اور اللہ تعالیٰ سے ڈرتے رہا کرو اور جان رکھو کہ تم اس سے ملنے والے ہو اور ایمان والوں کو خوش خبری سنا دیجیئے\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@ccxxxi{اور اللہ تعالیٰ کو اپنی قسموں کا (اس طرح) نشانہ نہ بناؤ کہ بھلائی اور پرہیزگاری اور لوگوں کے درمیان کی اصلاح کو چھوڑ بیٹھو اور اللہ تعالیٰ سننے واﻻ جاننے واﻻ ہے\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@ccxxxii{اللہ تعالیٰ تمہیں تمہاری ان قسموں پر نہ پکڑے گا جو پختہ نہ ہوں ہاں اس کی پکڑ اس چیز پر ہے جو تمہارے دلوں کا فعل ہو، اللہ تعالیٰ بخشنے واﻻ اور بردبار ہے\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@ccxxxiii{جو لوگ اپنی بیویوں سے (تعلق نہ رکھنے کی) قسمیں کھائیں، ان کے لئے چار مہینے کی مدت ہے، پھر اگر وه لوٹ آئیں تو اللہ تعالیٰ بھی بخشنے واﻻ مہربان ہے\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@ccxxxiv{اور اگر طلاق کا ہی قصد کرلیں تو اللہ تعالیٰ سننے واﻻ، جاننے واﻻ ہے\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@ccxxxv{طلاق والی عورتیں اپنے آپ کو تین حیض تک روکے رکھیں، انہیں حلال نہیں کہ اللہ نے ان کے رحم میں جو پیدا کیا ہو اسے چھپائیں، اگر انہیں اللہ تعالیٰ پر اور قیامت کے دن پر ایمان ہو، ان کے خاوند اس مدت میں انہیں لوٹا لینے کے پورے حقدار ہیں اگر ان کا اراده اصلاح کا ہو۔ اور عورتوں کے بھی ویسے ہی حق ہیں جیسے ان پر مردوں کے ہیں اچھائی کے ساتھ۔ ہاں مردوں کو عورتوں پر فضلیت ہے اور اللہ تعالیٰ غالب ہے حکمت واﻻ ہے\qt@no{(228)}}%
\qt@newcmd\qurantrans@ur@ccxxxvi{یہ طلاقیں دو مرتبہ ہیں، پھر یا تو اچھائی سے روکنا یا عمدگی کے ساتھ چھوڑ دینا ہے اور تمہیں حلال نہیں کہ تم نے انہیں جو دے دیا ہے اس میں سے کچھ بھی لو، ہاں یہ اور بات ہے کہ دونوں کو اللہ کی حدیں قائم نہ رکھ سکنے کا خوف ہو، اس لئے اگر تمہیں ڈر ہو کہ یہ دونوں اللہ کی حدیں قائم نہ رکھ سکیں گے تو عورت رہائی پانے کے لئے کچھ دے ڈالے، اس میں دونوں پر گناه نہیں یہ اللہ کی حدود ہیں خبردار ان سے آگے نہ بڑھنا اور جو لوگ اللہ کی حدوں سے تجاوز کرجائیں وه ﻇالم ہیں\qt@no{(229)}}%
\qt@newcmd\qurantrans@ur@ccxxxvii{پھر اگر اس کو (تیسری بار) طلاق دے دے تو اب اس کے لئے حلال نہیں جب تک وه عورت اس کے سوا دوسرے سے نکاح نہ کرے، پھر اگر وه بھی طلاق دے دے تو ان دونوں کو میل جول کرلینے میں کوئی گناه نہیں بشرطیکہ یہ جان لیں کہ اللہ کی حدوں کو قائم رکھ سکیں گے، یہ اللہ تعالیٰ کی حدود ہیں جنہیں وه جاننے والوں کے لئے بیان فرما رہا ہے۔\qt@no{(230)}}%
\qt@newcmd\qurantrans@ur@ccxxxviii{جب تم عورتوں کو طلاق دو اور وه اپنی عدت ختم کرنے پر آئیں تو اب انہیں اچھی طرح بساؤ، یا بھلائی کے ساتھ الگ کردو اور انہیں تکلیف پہنچانے کی غرض سے ﻇلم وزیادتی کے لئے نہ روکو، جو شخص ایسا کرے اس نے اپنی جان پر ﻇلم کیا۔ تم اللہ کے احکام کو ہنسی کھیل نہ بناؤ اور اللہ کا احسان جو تم پر ہے یاد کرو اور جو کچھ کتاب وحکمت اس نے نازل فرمائی ہے جس سے تمہیں نصیحت کر رہا ہے، اسے بھی۔ اور اللہ تعالیٰ سے ڈرتے رہا کرو اور جان رکھو کہ اللہ تعالیٰ ہر چیز کو جانتا ہے\qt@no{(231)}}%
\qt@newcmd\qurantrans@ur@ccxxxix{اور جب تم اپنی عورتوں کو طلاق دو اور وه اپنی عدت پوری کرلیں تو انہیں ان کے خاوندوں سے نکاح کرنے سے نہ روکو جب کہ وه آپس میں دستور کے مطابق رضامند ہوں۔ یہ نصیحت انہیں کی جاتی ہے جنہیں تم میں سے اللہ تعالیٰ پر اور قیامت کے دن پر یقین وایمان ہو، اس میں تمہاری بہترین صفائی اور پاکیزگی ہے۔ اللہ تعالیٰ جانتا ہے اور تم نہیں جانتے\qt@no{(232)}}%
\qt@newcmd\qurantrans@ur@ccxl{مائیں اپنی اوﻻد کو دو سال کامل دودھ پلائیں جن کا اراده دودھ پلانے کی مدت بالکل پوری کرنے کا ہو اور جن کے بچے ہیں ان کے ذمہ ان کا روٹی کپڑا ہے جو مطابق دستور کے ہو۔ ہر شخص اتنی ہی تکلیف دیا جاتا ہے جتنی اس کی طاقت ہو۔ ماں کو اس کے بچہ کی وجہ سے یا باپ کو اس کی اوﻻدکی وجہ سے کوئی ضرر نہ پہنچایا جائے۔ وارث پر بھی اسی جیسی ذمہ داری ہے، پھر اگر دونوں (یعنی ماں باپ) اپنی رضامندی اور باہمی مشورے سے دودھ چھڑانا چاہیں تو دونوں پر کچھ گناه نہیں اور اگر تمہارا اراده اپنی اوﻻد کو دودھ پلوانے کا ہو تو بھی تم پر کوئی گناه نہیں جب کہ تم ان کو مطابق دستور کے جو دینا ہو وه ان کے حوالے کردو، اللہ تعالیٰ سے ڈرتے رہو اور جانتے رہو کہ اللہ تعالیٰ تمہارے اعمال کی دیکھ بھال کر رہا ہے\qt@no{(233)}}%
\qt@newcmd\qurantrans@ur@ccxli{تم میں سے جو لوگ فوت ہوجائیں اور بیویاں چھوڑ جائیں، وه عورتیں اپنے آپ کو چار مہینے اور دس (دن) عدت میں رکھیں، پھر جب مدت ختم کرلیں تو جو اچھائی کے ساتھ وه اپنے لئے کریں اس میں تم پر کوئی گناه نہیں اور اللہ تعالیٰ تمہارے ہر عمل سے خبردار ہے\qt@no{(234)}}%
\qt@newcmd\qurantrans@ur@ccxlii{تم پر اس میں کوئی گناه نہیں کہ تم اشارةً کنایتہً ان عورتوں سے نکاح کی بابت کہو، یا اپنے دل میں پوشیده اراده کرو، اللہ تعالیٰ کو علم ہے کہ تم ضرور ان کو یاد کرو گے، لیکن تم ان سے پوشیده وعدے نہ کرلو ہاں یہ اور بات ہے کہ تم بھلی بات بوﻻ کرو اور عقد نکاح جب تک کہ عدت ختم نہ ہوجائے پختہ نہ کرو، جان رکھو کہ اللہ تعالیٰ کو تمہارے دلوں کی باتوں کا بھی علم ہے، تم اس سے خوف کھاتے رہا کرو اور یہ بھی جان رکھو کہ اللہ تعالیٰ بخشش اور علم واﻻ ہے\qt@no{(235)}}%
\qt@newcmd\qurantrans@ur@ccxliii{اگر تم عورتوں کو بغیر ہاتھ لگائے اور بغیر مہر مقرر کئے طلاق دے دو تو بھی تم پر کوئی گناه نہیں، ہاں انہیں کچھ نہ کچھ فائده دو۔ خوشحال اپنے انداز سے اور تنگدست اپنی طاقت کے مطابق دستور کے مطابق اچھا فائده دے۔ بھلائی کرنے والوں پر یہ ﻻزم ہے\qt@no{(236)}}%
\qt@newcmd\qurantrans@ur@ccxliv{اور اگر تم عورتوں کو اس سے پہلے طلاق دے دو کہ تم نے انہیں ہاتھ لگایا ہو اور تم نے ان کا مہر بھی مقرر کردیا ہو تو مقرره مہر کا آدھا مہر دے دو، یہ اور بات ہے کہ وه خود معاف کردیں یا وه شخص معاف کردے جس کے ہاتھ میں نکاح کی گره ہے تمہارا معاف کردینا تقویٰ سے بہت نزدیک ہے اور آپس کی فضیلت اور بزرگی کو فراموش نہ کرو، یقیناً اللہ تعالیٰ تمہارے اعمال کو دیکھ رہا ہے\qt@no{(237)}}%
\qt@newcmd\qurantrans@ur@ccxlv{نمازوں کی حفاﻇت کرو، بالخصوص درمیان والی نماز کی اور اللہ تعالیٰ کے لئے باادب کھڑے رہا کرو\qt@no{(238)}}%
\qt@newcmd\qurantrans@ur@ccxlvi{اگر تمہیں خوف ہو تو پیدل ہی سہی یا سوار ہی سہی، ہاں جب امن ہوجائے تو اللہ کا ذکر کرو جس طرح کہ اس نے تمہیں اس بات کی تعلیم دی جسے تم نہیں جانتے تھے\qt@no{(239)}}%
\qt@newcmd\qurantrans@ur@ccxlvii{جو لوگ تم میں سے فوت ہوجائیں اور بیویاں چھوڑ جائیں وه وصیت کر جائیں کہ ان کی بیویاں سال بھر تک فائده اٹھائیں انہیں کوئی نہ نکالے، ہاں اگر وه خود نکل جائیں تو تم پر اس میں کوئی گناه نہیں جو وه اپنے لئے اچھائی سے کریں، اللہ تعالیٰ غالب اور حکیم ہے\qt@no{(240)}}%
\qt@newcmd\qurantrans@ur@ccxlviii{طلاق والیوں کو اچھی طرح فائده دینا پرہیزگاروں پر ﻻزم ہے\qt@no{(241)}}%
\qt@newcmd\qurantrans@ur@ccxlix{اللہ تعالیٰ اسی طرح اپنی آیتیں تم پر ﻇاہر فرما رہا ہے تاکہ تم سمجھو\qt@no{(242)}}%
\qt@newcmd\qurantrans@ur@ccl{کیا تم نے انہیں نہیں دیکھا جو ہزاروں کی تعداد میں تھے اور موت کے ڈر کے مارے اپنے گھروں سے نکل کھڑے ہوئے تھے۔ اللہ تعالیٰ نے انہیں فرمایا مرجاؤ، پھر انہیں زنده کردیا بے شک اللہ تعالیٰ لوگوں پر بڑا فضل واﻻ ہے، لیکن اکثر لوگ ناشکرے ہیں\qt@no{(243)}}%
\qt@newcmd\qurantrans@ur@ccli{اللہ تعالیٰ کی راه میں جہاد کرو اور جان لو کہ اللہ تعالیٰ سنتا، جانتا ہے\qt@no{(244)}}%
\qt@newcmd\qurantrans@ur@cclii{ایسا بھی کوئی ہے جو اللہ تعالیٰ کو اچھا قرض دے پس اللہ تعالیٰ اسے بہت بڑھا چڑھا کر عطا فرمائے، اللہ ہی تنگی اور کشادگی کرتا ہے اور تم سب اسی کی طرف لوٹائے جاؤ گے\qt@no{(245)}}%
\qt@newcmd\qurantrans@ur@ccliii{کیا آپ نے (حضرت) موسیٰ کے بعد والی بنی اسرائیل کی جماعت کو نہیں دیکھا جب کہ انہوں نے اپنے پیغمبر سے کہا کہ کسی کو ہمارا بادشاه بنا دیجیئے تاکہ ہم اللہ کی راه میں جہاد کریں۔ پیغمبر نے کہا کہ ممکن ہے جہاد فرض ہوجانے کے بعد تم جہاد نہ کرو، انہوں نے کہا بھلا ہم اللہ کی راه میں جہاد کیوں نہ کریں گے؟ ہم تو اپنے گھروں سے اجاڑے گئے ہیں اور بچوں سے دور کردیئے گئے ہیں۔ پھر جب ان پر جہاد فرض ہوا تو سوائے تھوڑے سے لوگوں کے سب پھر گئے اور اللہ تعالیٰ ﻇالموں کو خوب جانتا ہے\qt@no{(246)}}%
\qt@newcmd\qurantrans@ur@ccliv{اور انہیں ان کے نبی نے فرمایا کہ اللہ تعالیٰ نے طالوت کو تمہارا بادشاه بنا دیا ہے تو کہنے لگے بھلا اس کی ہم پر حکومت کیسے ہوسکتی ہے؟ اس سے تو بہت زیاده حقدار بادشاہت کے ہم ہیں، اس کو تو مالی کشادگی بھی نہیں دی گئی۔ نبی نے فرمایا سنو، اللہ تعالیٰ نے اسی کو تم پر برگزیده کیا ہے اور اسے علمی اور جسمانی برتری بھی عطا فرمائی ہے بات یہ ہے کہ اللہ جسے چاہے اپنا ملک دے، اللہ تعالیٰ کشادگی واﻻ اور علم واﻻ ہے\qt@no{(247)}}%
\qt@newcmd\qurantrans@ur@cclv{ان کے نبی نے انہیں پھر کہا کہ اس کی بادشاہت کی ﻇاہری نشانی یہ ہے کہ تمہارے پاس وه صندوق آ جائے گا جس میں تمہارے رب کی طرف سے دلجمعی ہے اور آل موسیٰ اور آل ہارون کا بقیہ ترکہ ہے، فرشتے اسے اٹھا کر ﻻئیں گے۔ یقیناً یہ تو تمہارے لئے کھلی دلیل ہے اگر تم ایمان والے ہو\qt@no{(248)}}%
\qt@newcmd\qurantrans@ur@cclvi{جب (حضرت) طالوت لشکروں کو لے کر نکلے تو کہا سنو اللہ تعالیٰ تمہیں ایک نہر سے آزمانے واﻻہے، جس نے اس میں سے پانی پی لیا وه میرا نہیں اور جو اسے نہ چکھے وه میرا ہے، ہاں یہ اور بات ہے کہ اپنے ہاتھ سے ایک چلو بھرلے۔ لیکن سوائے چند کے باقی سب نے وه پانی پی لیا (حضرت) طالوت مومنین سمیت جب نہر سے گزر گئے تو وه لوگ کہنے لگے آج تو ہم میں طاقت نہیں کہ جالوت اور اس کے لشکروں سے لڑیں۔ لیکن اللہ تعالیٰ کی ملاقات پر یقین رکھنے والوں نے کہا، بسا اوقات چھوٹی اور تھوڑی سی جماعتیں بڑی اور بہت سی جماعتوں پر اللہ کے حکم سے غلبہ پالیتی ہیں، اللہ تعالیٰ صبر والوں کے ساتھ ہے\qt@no{(249)}}%
\qt@newcmd\qurantrans@ur@cclvii{جب ان کا جالوت اور اس کے لشکر سے مقابلہ ہوا تو انہوں نے دعا مانگی کہ اے پروردگار ہمیں صبر دے، ﺛابت قدمی دے اور قوم کفار پر ہماری مدد فرما\qt@no{(250)}}%
\qt@newcmd\qurantrans@ur@cclviii{چنانچہ اللہ تعالیٰ کے حکم سے انہوں نے جالوتیوں کو شکست دے دی اور (حضرت) داؤد (علیہ السلام) کے ہاتھوں جالوت قتل ہوا اور اللہ تعالیٰ نے داؤد (علیہ السلام) کو مملکت وحکمت اور جتنا کچھ چاہا علم بھی عطا فرمایا۔ اگر اللہ تعالیٰ بعض لوگوں کو بعض سے دفع نہ کرتا تو زمین میں فساد پھیل جاتا، لیکن اللہ تعالیٰ دنیا والوں پر بڑا فضل وکرم کرنے واﻻ ہے\qt@no{(251)}}%
\qt@newcmd\qurantrans@ur@cclix{یہ اللہ تعالیٰ کی آیتیں ہیں جنہیں ہم حقانیت کے ساتھ آپ پر پڑھتے ہیں، بالیقین آپ رسولوں میں سے ہیں\qt@no{(252)}}%
\qt@newcmd\qurantrans@ur@cclx{یہ رسول ہیں جن میں سے ہم نے بعض کو بعض پر فضیلت دی ہے، ان میں سے بعض وه ہیں جن سے اللہ تعالیٰ نے بات چیت کی ہے اور بعض کے درجے بلند کئے ہیں، اور ہم نے عیسیٰ بن مریم کو معجزات عطا فرمائے اور روح القدس سے ان کی تائید کی۔اگر اللہ تعالیٰ چاہتا تو ان کے بعد والے اپنے پاس دلیلیں آجانے کے بعد ہرگز آپس میں لڑائی بھڑائی نہ کرتے، لیکن ان لوگوں نے اختلاف کیا، ان میں سے بعض تو مومن ہوئے اور بعض کافر، اور اگر اللہ تعالیٰ چاہتا تو یہ آپس میں نہ لڑتے، لیکن اللہ تعالیٰ جو چاہتا ہے کرتا ہے\qt@no{(253)}}%
\qt@newcmd\qurantrans@ur@cclxi{اے ایمان والو! جو ہم نے تمہیں دے رکھا ہے اس میں سے خرچ کرتے رہو اس سے پہلے کہ وه دن آئے جس میں نہ تجارت ہے نہ دوستی اور شفاعت اور کافر ہی ﻇالم ہیں\qt@no{(254)}}%
\qt@newcmd\qurantrans@ur@cclxii{اللہ تعالیٰ ہی معبود برحق ہے جس کے سوا کوئی معبود نہیں جو زنده اور سب کا تھامنے واﻻ ہے، جسے نہ اونگھ آئے نہ نیند، اس کی ملکیت میں زمین اور آسمانوں کی تمام چیزیں ہیں۔ کون ہے جو اس کی اجازت کے بغیر اس کے سامنے شفاعت کرسکے، وه جانتا ہے جو ان کے سامنے ہے اور جو ان کے پیچھے ہے اور وه اس کے علم میں سے کسی چیز کا احاطہ نہیں کرسکتے مگر جتنا وه چاہے، اس کی کرسی کی وسعت نے زمین و آسمان کو گھیر رکھا ہے اور اللہ تعالیٰ ان کی حفاﻇت سے نہ تھکتا اور نہ اکتاتا ہے، وه تو بہت بلند اور بہت بڑا ہے\qt@no{(255)}}%
\qt@newcmd\qurantrans@ur@cclxiii{دین کے بارے میں کوئی زبردستی نہیں، ہدایت ضلالت سے روشن ہوچکی ہے، اس لئے جو شخص اللہ تعالیٰ کے سوا دوسرے معبودوں کا انکار کرکے اللہ تعالیٰ پر ایمان ﻻئے اس نے مضبوط کڑے کو تھام لیا، جو کبھی نہ ٹوٹے گا اور اللہ تعالیٰ سننے واﻻ، جاننے واﻻ ہے\qt@no{(256)}}%
\qt@newcmd\qurantrans@ur@cclxiv{ایمان ﻻنے والوں کا کارساز اللہ تعالیٰ خود ہے، وه انہیں اندھیروں سے روشنی کی طرف نکال لے جاتا ہے اور کافروں کے اولیاء شیاطین ہیں۔ وه انہیں روشنی سے نکال کر اندھیروں کی طرف لے جاتے ہیں، یہ لوگ جہنمی ہیں جو ہمیشہ اسی میں پڑے رہیں گے\qt@no{(257)}}%
\qt@newcmd\qurantrans@ur@cclxv{کیا تونے اسے نہیں دیکھا جو سلطنت پا کر ابراہیم (علیہ السلام) سے اس کے رب کے بارے میں جھگڑ رہا تھا، جب ابراہیم (علیہ السلام) نے کہا کہ میرا رب تو وه ہے جو جلاتا ہے اور مارتا ہے، وه کہنے لگا میں بھی جلاتا اور مارتا ہوں، ابراہیم (علیہ السلام) نے کہا اللہ تعالیٰ سورج کو مشرق کی طرف سے لے آتا ہے تو اسے مغرب کی جانب سے لے آ۔ اب تو وه کافر بھونچکا ره گیا، اور اللہ تعالیٰ ﻇالموں کو ہدایت نہیں دیتا\qt@no{(258)}}%
\qt@newcmd\qurantrans@ur@cclxvi{یا اس شخص کے مانند کہ جس کا گزر اس بستی پر ہوا جو چھت کے بل اوندھی پڑی ہوئی تھی، وه کہنے لگا اس کی موت کے بعد اللہ تعالیٰ اسے کس طرح زنده کرے گا؟ تو اللہ تعالی نے اسے مار دیا سو سال کے لئے، پھر اسے اٹھایا، پوچھا کتنی مدت تجھ پر گزری؟ کہنے لگا ایک دن یا دن کا کچھ حصہ، فرمایا بلکہ تو سو سال تک رہا، پھر اب تو اپنے کھانے پینے کو دیکھ کہ بالکل خراب نہیں ہوا اور اپنے گدھے کو بھی دیکھ، ہم تجھے لوگوں کے لئے ایک نشانی بناتے ہیں تو دیکھ کہ ہم ہڈیوں کو کس طرح اٹھاتے ہیں، پھر ان پر گوشت چڑھاتے ہیں، جب یہ سب ﻇاہر ہو چکا تو کہنے لگا میں جانتا ہوں کہ اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(259)}}%
\qt@newcmd\qurantrans@ur@cclxvii{اور جب ابراہیم (علیہ السلام) نے کہا کہ اے میرے پروردگار! مجھے دکھا تو مُردوں کو کس طرح زنده کرے گا؟ (جناب باری تعالیٰ نے) فرمایا، کیا تمہیں ایمان نہیں؟ جواب دیا ایمان تو ہے لیکن میرے دل کی تسکین ہو جائے گی، فرمایا چار پرند لو، ان کے ٹکڑے کر ڈالو، پھر ہر پہاڑ پر ان کا ایک ایک ٹکڑا رکھ دو پھر انہیں پکارو، تمہارے پاس دوڑتے ہوئے آجائیں گے اور جان رکھو کہ اللہ تعالیٰ غالب ہے حکمتوں واﻻ ہے\qt@no{(260)}}%
\qt@newcmd\qurantrans@ur@cclxviii{جو لوگ اپنا مال اللہ تعالیٰ کی راه میں خرچ کرتے ہیں اس کی مثال اس دانے جیسی ہے جس میں سے سات بالیاں نکلیں اور ہر بالی میں سودانے ہوں، اور اللہ تعالیٰ جسے چاہے بڑھا چڑھا کر دے اور اللہ تعالیٰ کشادگی واﻻ اور علم واﻻ ہے\qt@no{(261)}}%
\qt@newcmd\qurantrans@ur@cclxix{جو لوگ اپنا مال اللہ تعالیٰ کی راه میں خرچ کرتے ہیں پھر اس کے بعد نہ تو احسان جتاتے ہیں نہ ایذا دیتے ہیں، ان کا اجر ان کے رب کے پاس ہے ان پر نہ تو کچھ خوف ہے نہ وه اداس ہوں گے\qt@no{(262)}}%
\qt@newcmd\qurantrans@ur@cclxx{نرم بات کہنا اور معاف کردینا اس صدقہ سے بہتر ہے جس کے بعد ایذا رسانی ہو اور اللہ تعالیٰ بےنیاز اور بردبار ہے\qt@no{(263)}}%
\qt@newcmd\qurantrans@ur@cclxxi{اے ایمان والو! اپنی خیرات کو احسان جتا کر اور ایذا پہنچا کر برباد نہ کرو! جس طرح وه شخص جو اپنا مال لوگوں کے دکھاوے کے لئے خرچ کرے اور نہ اللہ تعالیٰ پر ایمان رکھے نہ قیامت پر، اس کی مثال اس صاف پتھر کی طرح ہے جس پر تھوڑی سی مٹی ہو پھر اس پر زوردار مینہ برسے اور وه اسے بالکل صاف اور سخت چھوڑ دے، ان ریاکاروں کو اپنی کمائی میں سے کوئی چیز ہاتھ نہیں لگتی اور اللہ تعالیٰ کافروں کی قوم کو (سیدھی) راه نہیں دکھاتا\qt@no{(264)}}%
\qt@newcmd\qurantrans@ur@cclxxii{ان لوگوں کی مثال جو اپنا مال اللہ تعالیٰ کی رضامندی کی طلب میں دل کی خوشی اور یقین کے ساتھ خرچ کرتے ہیں اس باغ جیسی ہے جو اونچی زمین پر ہواور زوردار بارش اس پر برسے اور وه اپنا پھل دگنا ﻻوے اور اگر اس پر بارش نہ بھی برسے تو پھوار ہی کافی ہے اور اللہ تمہارے کام دیکھ رہا ہے\qt@no{(265)}}%
\qt@newcmd\qurantrans@ur@cclxxiii{کیا تم میں سے کوئی بھی یہ چاہتا ہے کہ اس کا کھجوروں اور انگوروں کا باغ ہو، جس میں نہریں بہہ رہی ہوں اور ہر قسم کے پھل موجود ہوں، اس شخص کا بڑھاپا آگیا ہو، اس کے ننھے ننھے سے بچے بھی ہوں اور اچانک باغ کو بگوﻻ لگ جائے جس میں آگ بھی ہو، پس وه باغ جل جائے، اسی طرح اللہ تعالیٰ تمہارے لئے آیتیں بیان کرتا ہے تاکہ تم غوروفکر کرو\qt@no{(266)}}%
\qt@newcmd\qurantrans@ur@cclxxiv{اے ایمان والو! اپنی پاکیزه کمائی میں سے اور زمین میں سے تمہارے لئے ہماری نکالی ہوئی چیزوں میں سے خرچ کرو، ان میں سے بری چیزوں کے خرچ کرنے کا قصد نہ کرنا، جسے تم خود لینے والے نہیں ہو، ہاں اگر آنکھیں بند کر لو تو، اور جان لو کہ اللہ تعالیٰ بے پرواه اور خوبیوں واﻻ ہے\qt@no{(267)}}%
\qt@newcmd\qurantrans@ur@cclxxv{شیطان تمہیں فقیری سے دھمکاتا ہے اور بےحیائی کا حکم دیتا ہے، اور اللہ تعالیٰ تم سے اپنی بخشش اور فضل کا وعده کرتا ہے، اللہ تعالیٰ وسعت واﻻ اور علم واﻻ ہے\qt@no{(268)}}%
\qt@newcmd\qurantrans@ur@cclxxvi{وه جسے چاہے حکمت اور دانائی دیتا ہے اور جو شخص حکمت اور سمجھ دیا جائے وه بہت ساری بھلائی دیا گیا اور نصیحت صرف عقلمند ہی حاصل کرتے ہیں\qt@no{(269)}}%
\qt@newcmd\qurantrans@ur@cclxxvii{تم جتنا کچھ خرچ کرو یعنی خیرات اور جو کچھ نذر مانو اسے اللہ تعالیٰ بخوبی جانتا ہے، اور ﻇالموں کا کوئی مددگار نہیں\qt@no{(270)}}%
\qt@newcmd\qurantrans@ur@cclxxviii{اگر تم صدقے خیرات کو ﻇاہر کرو تو وه بھی اچھا ہے اور اگر تم اسے پوشیده پوشیده مسکینوں کو دے دو تو یہ تمہارے حق میں بہتر ہے، اللہ تعالیٰ تمہارے گناہوں کو مٹا دے گا اور اللہ تعالیٰ تمہارے تمام اعمال کی خبر رکھنے واﻻ ہے،\qt@no{(271)}}%
\qt@newcmd\qurantrans@ur@cclxxix{انہیں ہدایت پر ﻻ کھڑا کرنا تیرے ذمہ نہیں بلکہ ہدایت اللہ تعالیٰ دیتا ہے جسے چاہتا ہے اور تم جو بھلی چیز اللہ کی راه میں دو گے اس کا فائده خود پاؤ گے۔ تمہیں صرف اللہ تعالیٰ کی رضامندی کی طلب کے لئے ہی خرچ کرنا چاہئے تم جو کچھ مال خرچ کرو گے اس کا پورا پورا بدلہ تمہیں دیا جائے گا، اور تمہارا حق نہ مارا جائے گا\qt@no{(272)}}%
\qt@newcmd\qurantrans@ur@cclxxx{صدقات کے مستحق صرف وه غربا ہیں جو اللہ کی راه میں روک دیئے گئے، جو ملک میں چل پھر نہیں سکتے نادان لوگ ان کی بے سوالی کی وجہ سے انہیں مالدار خیال کرتے ہیں، آپ ان کے چہرے دیکھ کر قیافہ سے انہیں پہچان لیں گے وه لوگوں سے چمٹ کر سوال نہیں کرتے، تم جو کچھ مال خرچ کرو تو اللہ تعالیٰ اس کا جاننے واﻻ ہے\qt@no{(273)}}%
\qt@newcmd\qurantrans@ur@cclxxxi{جو لوگ اپنے مالوں کو رات دن چھپے کھلے خرچ کرتے ہیں ان کے لئے ان کے رب تعالیٰ کے پاس اجر ہے اور نہ انہیں خوف ہے اور نہ غمگینی\qt@no{(274)}}%
\qt@newcmd\qurantrans@ur@cclxxxii{سود خور لوگ نہ کھڑے ہوں گے مگر اسی طرح جس طرح وہ کھڑا ہوتا ہے جسے شیطان چھو کر خبطی بنا دے یہ اس لئے کہ یہ کہا کرتے تھے کہ تجارت بھی تو سود ہی کی طرح ہے، حالانکہ اللہ تعالیٰ نے تجارت کو حلال کیا اور سود کو حرام، جو شخص اپنے پاس آئی ہوئی اللہ تعالیٰ کی نصیحت سن کر رک گیا اس کے لئے وہ ہے جو گزرا اور اس کا معاملہ اللہ تعالیٰ کی طرف ہے، اور جو پھر دوبارہ ﴿حرام کی طرف﴾ لوٹا، وہ جہنمی ہے، ایسے لوگ ہمیشہ ہی اس میں رہیں گے\qt@no{(275)}}%
\qt@newcmd\qurantrans@ur@cclxxxiii{اللہ تعالیٰ سود کو مٹاتا ہے اور صدقہ کو بڑھاتا ہے اور اللہ تعالیٰ کسی ناشکرے اور گنہگار سے محبت نہیں کرتا\qt@no{(276)}}%
\qt@newcmd\qurantrans@ur@cclxxxiv{بے شک جو لوگ ایمان کے ساتھ ﴿سنت کے مطابق﴾ نیک کام کرتے ہیں، نمازوں کو قائم کرتے ہیں اور زکوٰة ادا کرتے ہیں، ان کا اجر ان کے رب تعالیٰ کے پاس ہے، ان پر نہ تو کوئی خوف ہے، نہ اداسی اور غم\qt@no{(277)}}%
\qt@newcmd\qurantrans@ur@cclxxxv{اے ایمان والو! اللہ تعالیٰ سے ڈرو اور جو سود باقی رہ گیا ہے وہ چھوڑ دو، اگر تم سچ مچ ایمان والے ہو\qt@no{(278)}}%
\qt@newcmd\qurantrans@ur@cclxxxvi{اور اگر ایسا نہیں کرتے تو اللہ تعالیٰ سے اور اس کے رسول سے لڑنے کے لئے تیار ہو جاؤ، ہاں اگر توبہ کرلو تو تمہارا اصل مال تمہارا ہی ہے، نہ تم ظلم کرو نہ تم پر ظلم کیا جائے گا\qt@no{(279)}}%
\qt@newcmd\qurantrans@ur@cclxxxvii{اور اگر کوئی تنگی والا ہو تو اسے آسانی تک مہلت دینی چاہئے اور صدقہ کرو تو تمہارے لئے بہت ہی بہتر ہے، اگر تم میں علم ہو\qt@no{(280)}}%
\qt@newcmd\qurantrans@ur@cclxxxviii{اور اس دن سے ڈرو جس میں تم سب اللہ تعالیٰ کی طرف لوٹائے جاؤگے اور ہر شخص کو اس کے اعمال کا پورا پورا بدلہ دیا جائے گا اور ان پر ظلم نہیں کیا جائے گا\qt@no{(281)}}%
\qt@newcmd\qurantrans@ur@cclxxxix{اے ایمان والو! جب تم آپس میں ایک دوسرے سے میعاد مقرر پر قرض کا معاملہ کرو تو اسے لکھ لیا کرو، اور لکھنے والے کو چاہئے کہ تمہارا آپس کا معاملہ عدل سے لکھے، کاتب کو چاہئے کہ لکھنے سے انکار نہ کرے جیسے اللہ تعالیٰ نے اسے سکھایا ہے، پس اسے بھی لکھ دینا چاہئے اور جس کے ذمہ حق ہو وہ لکھوائے اور اپنے اللہ تعالیٰ سے ڈرے جو اس کا رب ہے اور حق میں سے کچھ گھٹائے نہیں، ہاں جس شخص کے ذمہ حق ہے وہ اگر نادان ہو یا کمزور ہو یا لکھوانے کی طاقت نہ رکھتا ہو تو اس کا ولی عدل کے ساتھ لکھوا دے اور اپنے میں سے دو مرد گواہ رکھ لو، اگر دو مرد نہ ہوں تو ایک مرد اور دو عورتیں جنہیں تم گوہوں میں سے پسند کر لو تاکہ ایک کی بھول چوک کو دوسری یاد دلا دے اور گواہوں کو چاہئے کہ وہ جب بلائے جائیں تو انکار نہ کریں اور قرض کو جس کی مدت مقرر ہے خواہ چھوٹا ہو یا بڑا ہو لکھنے میں کاہلی نہ کرو، اللہ تعالیٰ کے نزدیک یہ بات بہت انصاف والی ہے اور گواہی کو بھی درست رکھنے والی اور شق و شبہ سے بھی زیادہ بچانے والی ہے، ہاں یہ اور بات ہے کہ وہ معاملہ نقد تجارت کی شکل میں ہو جو آپس میں تم لین دین کر رہے ہو تو تم پر اس کے نہ لکھنے میں کوئی گناہ نہیں۔ خرید و فروخت کے وقت بھی گواہ مقرر کر لیا کرو اور ﴿یاد رکھو کہ﴾ نہ تو لکھنے والے کو نقصان پہنچایا جائے نہ گواہ کو اور اگر تم یہ کرو تو یہ تمہاری کھلی نافرمانی ہے، اللہ تعالیٰ سے ڈرو، اللہ تمہیں تعلیم دے رہا ہے اور اللہ تعالیٰ ہر چیز کو خوب جاننے والا ہے\qt@no{(282)}}%
\qt@newcmd\qurantrans@ur@ccxc{اور اگر تم سفر میں ہو اور لکھنے واﻻ نہ پاؤ تو رہن قبضہ میں رکھ لیا کرو، ہاں اگر آپس میں ایک دوسرے سے مطمئن ہو تو جسے امانت دی گئی ہے وه اسے ادا کردے اور اللہ تعالیٰ سے ڈرتا رہے جو اس کا رب ہے۔ اور گواہی کو نہ چھپاؤ اور جو اسے چھپالے وه گنہگار دل واﻻ ہے اور جو کچھ تم کرتے ہو اسے اللہ تعالیٰ خوب جانتا ہے\qt@no{(283)}}%
\qt@newcmd\qurantrans@ur@ccxci{آسمانوں اور زمین کی ہر چیز اللہ تعالیٰ ہی کی ملکیت ہے۔ تمہارے دلوں میں جو کچھ ہے اسے تم ﻇاہر کرو یا چھپاؤ، اللہ تعالیٰ اس کا حساب تم سے لے گا۔ پھر جسے چاہے بخشے اور جسے چاہے سزا دے اور اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(284)}}%
\qt@newcmd\qurantrans@ur@ccxcii{رسول ایمان ﻻیا اس چیز پر جو اس کی طرف اللہ تعالیٰ کی جانب سے اتری اور مومن بھی ایمان ﻻئے، یہ سب اللہ تعالیٰ اور اس کے فرشتوں پر اور اس کی کتابوں پر اور اس کے رسولوں پر ایمان ﻻئے، اس کے رسولوں میں سے کسی میں ہم تفریق نہیں کرتے، انہوں نے کہہ دیا کہ ہم نے سنا اور اطاعت کی، ہم تیری بخشش طلب کرتے ہیں اے ہمارے رب! اور ہمیں تیری ہی طرف لوٹنا ہے،\qt@no{(285)}}%
\qt@newcmd\qurantrans@ur@ccxciii{اللہ تعالیٰ کسی جان کو اس کی طاقت سے زیاده تکلیف نہیں دیتا، جو نیکی وه کرے وه اس کے لئے اور جو برائی وه کرے وه اس پر ہے، اے ہمارے رب! اگر ہم بھول گئے ہوں یا خطا کی ہو تو ہمیں نہ پکڑنا، اے ہمارے رب! ہم پر وه بوجھ نہ ڈال جو ہم سے پہلے لوگوں پر ڈاﻻ تھا، اے ہمارے رب! ہم پر وه بوجھ نہ ڈال جس کی ہمیں طاقت نہ ہو اور ہم سے درگزر فرما! اور ہمیں بخش دے اور ہم پر رحم کر! تو ہی ہمارا مالک ہے، ہمیں کافروں کی قوم پر غلبہ عطا فرما\qt@no{(286)}}%
\qt@newcmd\qurantrans@ur@ccxciv{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ccxcv{اللہ تعالیٰ وه ہے جس کے سوا کوئی معبود نہیں، جو زنده اور سب کا نگہبان ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@ccxcvi{جس نے آپ پر حق کے ساتھ اس کتاب کو نازل فرمایا ہے، جو اپنے سے پہلے کی تصدیق کرنے والی ہے، اسی نے اس سے پہلے تورات اور انجیل کو اتارا تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@ccxcvii{اس سے پہلے، لوگوں کو ہدایت کرنے والی بنا کر، اور قرآن بھی اسی نے اتارا، جو لوگ اللہ تعالیٰ کی آیتوں سے کفر کرتے ہیں ان کے لئے سخت عذاب ہے اور اللہ تعالیٰ غالب ہے، بدلہ لینے واﻻ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@ccxcviii{یقیناً اللہ تعالیٰ پر زمین وآسمان کی کوئی چیز پوشیده نہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@ccxcix{وه ماں کے پیٹ میں تمہاری صورتیں جس طرح چاہتا ہے بناتا ہے۔ اس کے سواکوئی معبود برحق نہیں وه غالب ہے، حکمت واﻻ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@ccc{وہی اللہ تعالیٰ ہے جس نے تجھ پر کتاب اتاری جس میں واضح مضبوط آیتیں ہیں جو اصل کتاب ہیں اوربعض متشابہ آیتیں ہیں۔ پس جن کے دلوں میں کجی ہے وه تواس کی متشابہ آیتوں کے پیچھے لگ جاتے ہیں، فتنے کی طلب اور ان کی مراد کی جستجو کے لئے، حاﻻنکہ ان کے حقیقی مراد کو سوائے اللہ تعالیٰ کے کوئی نہیں جانتا اور پختہ ومضبوط علم والے یہی کہتے ہیں کہ ہم تو ان پر ایمان ﻻچکے، یہ ہمارے رب کی طرف سے ہیں اور نصیحت تو صرف عقلمند حاصل کرتے ہیں۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@ccci{اے ہمارے رب! ہمیں ہدایت دینے کے بعد ہمارے دل ٹیڑھے نہ کردے اور ہمیں اپنے پاس سے رحمت عطا فرما، یقیناً تو ہی بہت بڑی عطا دینے واﻻ ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cccii{اے ہمارے رب! تو یقیناً لوگوں کوایک دن جمع کرنے واﻻ ہے جس کے آنے میں کوئی شک نہیں، یقیناً اللہ تعالیٰ وعده خلافی نہیں کرتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@ccciii{کافروں کوان کے مال اور ان کی اوﻻد اللہ تعالیٰ (کے عذاب) سے چھڑانے میں کچھ کام نہ آئیں گی، یہ تو جہنم کا ایندھن ہی ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@ccciv{جیسا آل فرعون کاحال ہوا، اور ان کا جو ان سے پہلے تھے، انہوں نے ہماری آیتوں کوجھٹلایا، پھر اللہ تعالیٰ نے بھی انہیں ان کے گناہوں پر پکڑ لیا، اور اللہ تعالیٰ سخت عذاب واﻻ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cccv{کافروں سے کہہ دیجئے! کہ تم عنقریب مغلوب کئے جاؤ گے اور جہنم کی طرف جمع کئے جاؤ گے اور وه برا ٹھکانا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cccvi{یقیناً تمہارے لئے عبرت کی نشانی تھی ان دو جماعتوں میں جو گتھ گئی تھیں، ایک جماعت تو اللہ تعالیٰ کی راه میں لڑ رہی تھی اور دوسرا گروه کافروں کا تھا وه انہیں اپنی آنکھوں سے اپنے سے دگنا دیکھتے تھے اور اللہ تعالیٰ جسے چاہے اپنی مدد سے قوی کرتا ہے۔ یقیناً اس میں آنکھوں والوں کے لئے بڑی عبرت ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cccvii{مرغوب چیزوں کی محبت لوگوں کے لئے مزین کر دی گئی ہے، جیسے عورتیں اور بیٹے اور سونے اور چاندی کے جمع کئے ہوئے خزانے اور نشاندار گھوڑے اور چوپائے اور کھیتی، یہ دنیا کی زندگی کا سامان ہے اور لوٹنے کا اچھا ٹھکانا تو اللہ تعالیٰ ہی کے پاس ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cccviii{آپ کہہ دیجئے! کیا میں تمہیں اس سے بہت ہی بہتر چیز بتاؤں؟ تقویٰ والوں کے لئے ان کے رب تعالیٰ کے پاس جنتیں ہیں جن کے نیچے نہریں بہہ رہی ہیں جن میں وه ہمیشہ رہیں گے اور پاکیزه بیویاں اور اللہ تعالیٰ کی رضامندی ہے، سب بندے اللہ تعالیٰ کی نگاه میں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cccix{جو کہتے ہیں کہ اے ہمارے رب! ہم ایمان ﻻ چکے اس لئے ہمارے گناه معاف فرما اور ہمیں آگ کے عذاب سے بچا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cccx{جو صبر کرنے والے اور سچ بولنے والے اور فرمانبرداری کرنے والے اور اللہ کی راه میں خرچ کرنے والے اور پچھلی رات کو بخشش مانگنے والے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cccxi{اللہ تعالیٰ، فرشتے اور اہل علم اس بات کی گواہی دیتے ہیں کہ اللہ کے سوا کوئی معبود نہیں اور وه عدل کو قائم رکھنے واﻻ ہے، اس غالب اور حکمت والے کے سوا کوئی عبادت کے ﻻئق نہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cccxii{بے شک اللہ تعالیٰ کے نزدیک دین اسلام ہی ہے، اور اہل کتاب نے اپنے پاس علم آجانے کے بعد آپس کی سرکشی اور حسد کی بنا پر ہی اختلاف کیا ہے اور اللہ تعالیٰ کی آیتوں کے ساتھ جو بھی کفر کرے اللہ تعالیٰ اس کا جلد حساب لینے واﻻ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cccxiii{پھر بھی اگر یہ آپ سے جھگڑیں توآپ کہہ دیں کہ میں اور میرے تابعداروں نے اللہ تعالیٰ کے سامنے اپنا سر تسلیم خم کر دیا ہے اور اہل کتاب سے اور انپڑھ لوگوں سے کہہ دیجیئے! کہ کیا تم بھی اطاعت کرتے ہو؟ پس اگر یہ بھی تابعدار بن جائیں تو یقیناً ہداہت والے ہیں اور اگر یہ روگردانی کریں، تو آپ پر صرف پہنچا دینا ہے اور اللہ بندوں کو خوب دیکھ بھال رہا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cccxiv{جو لوگ اللہ تعالیٰ کی آیتوں سے کفر کرتے ہیں اورناحق نبیوں کو قتل کر ڈالتے ہیں اور جو لوگ عدل وانصاف کی بات کہیں انہیں بھی قتل کر ڈالتے ہیں، تو اے نبی! انہیں دردناک عذاب کی خبردے دیجئے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cccxv{ان کے اعمال دنیا وآخرت میں غارت ہیں اور ان کا کوئی مددگار نہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cccxvi{کیا آپ نے انہیں نہیں دیکھا جنہیں ایک حصہ کتاب کا دیا گیا ہے وه اپنے آپس کے فیصلوں کے لئے اللہ تعالیٰ کی کتاب کی طرف بلائے جاتے ہیں، پھر بھی ایک جماعت ان کی منھ پھیر کر لوٹ جاتی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cccxvii{اس کی وجہ ان کا یہ کہنا کہ ہمیں تو گنے چنے چند دن ہی آگ جلائے گی، ان کی گڑھی گڑھائی باتوں نے انہیں ان کے دین کے بارے میں دھوکے میں ڈال رکھا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cccxviii{پس کیا حال ہوگا جبکہ ہم انہیں اس دن جمع کرینگے؟ جس کے آنے میں کوئی شک نہیں اور ہر شخص اپنا اپنا کیا پورا پورا دیاجائے گا اور ان پر ﻇلم نہ کیاجائے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cccxix{آپ کہہ دیجئے اے اللہ! اے تمام جہان کے مالک! تو جسے چاہے بادشاہی دے اور جس سے چاہے سلطنت چھین لے اور تو جسے چاہے عزت دے اورجسے چاہے ذلت دے، تیرے ہی ہاتھ میں سب بھلائیاں ہیں، بے شک تو ہر چیز پر قادر ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cccxx{تو ہی رات کو دن میں داخل کرتا ہے اور دن کو رات میں لے جاتا ہے، تو ہی بے جان سے جاندار پیدا کرتا ہے اور تو ہی جاندار سے بے جان پیدا کرتا ہے، تو ہی ہے کہ جسے چاہتا ہے بے شمار روزی دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cccxxi{مومنوں کو چاہئے کہ ایمان والوں کو چھوڑ کر کافروں کو اپنا دوست نہ بنائیں اور جوایسا کرے گا وه اللہ تعالیٰ کی کسی حمایت میں نہیں مگر یہ کہ ان کے شر سے کسی طرح بچاؤ مقصود ہو، اور اللہ تعالیٰ خود تمہیں اپنی ذات سے ڈرا رہا ہے اور اللہ تعالیٰ ہی کی طرف لوٹ جانا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cccxxii{کہہ دیجئے! کہ خواه تم اپنے سینوں کی باتیں چھپاؤ خواه ﻇاہر کرو اللہ تعالیٰ (بہرحال) جانتا ہے، آسمانوں اور زمین میں جو کچھ ہے سب اسے معلوم ہے اور اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cccxxiii{جس دن ہر نفس (شخص) اپنی کی ہوئی نیکیوں کو اور اپنی کی ہوئی برائیوں کو موجود پالے گا، آرزو کرے گا کہ کاش! اس کے اور برائیوں کے درمیان بہت ہی دوری ہوتی۔ اللہ تعالیٰ تمہیں اپنی ذات سے ڈرا رہا ہے اور اللہ تعالیٰ اپنے بندوں پر بڑا ہی مہربان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cccxxiv{کہہ دیجئے! اگر تم اللہ تعالیٰ سے محبت رکھتے ہو تو میری تابعداری کرو، خود اللہ تعالیٰ تم سے محبت کرے گا اور تمہارے گناه معاف فرما دے گا اور اللہ تعالیٰ بڑا بخشنے واﻻ مہربان ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cccxxv{کہہ دیجئے! کہ اللہ تعالیٰ اور رسول کی اطاعت کرو، اگر یہ منھ پھیر لیں تو بے شک اللہ تعالیٰ کافروں سے محبت نہیں کرتا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cccxxvi{بے شک اللہ تعالیٰ نے تمام جہان کے لوگوں میں سے آدم (علیہ السلام) کو اور نوح (علیہ السلام) کو، ابراہیم (علیہ السلام) کے خاندان اور عمران کے خاندان کو منتخب فرما لیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cccxxvii{کہ یہ سب آپس میں ایک دوسرے کی نسل سے ہیں اور اللہ تعالیٰ سنتا جانتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cccxxviii{جب عمران کی بیوی نے کہا کہ اے میرے رب! میرے پیٹ میں جو کچھ ہے، اسے میں نے تیرے نام آزاد کرنے کی نذر مانی، تو میری طرف سے قبول فرما! یقیناً تو خوب سننے واﻻ اور پوری طرح جاننے واﻻ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cccxxix{جب بچی کو جنا تو کہنے لگیں کہ پروردگار! مجھے تو لڑکی ہوئی، اللہ تعالیٰ کو خوب معلوم ہے کہ کیا اوﻻد ہوئی ہے اور لڑکا لڑکی جیسا نہیں میں نے اس کا نام مریم رکھا، میں اسے اور اس کی اوﻻد کو شیطان مردود سے تیری پناه میں دیتی ہوں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cccxxx{پس اسے اس کے پروردگار نے اچھی طرح قبول فرمایا اور اسے بہترین پرورش دی۔ اس کی خیر خبر لینے واﻻ زکریا (علیہ السلام) کو بنایا، جب کبھی زکریا (علیہ السلام) ان کے حجرے میں جاتے ان کے پاس روزی رکھی ہوئی پاتے، وه پوچھتے اے مریم! یہ روزی تمہارے پاس کہاں سے آئی؟ وه جواب دیتیں کہ یہ اللہ تعالیٰ کے پاس سے ہے، بے شک اللہ تعالیٰ جسے چاہے بے شمار روزی دے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cccxxxi{اسی جگہ زکریا (علیہ السلام) نے اپنے رب سے دعا کی، کہا کہ اے میرے پروردگار! مجھے اپنے پاس سے پاکیزه اوﻻد عطا فرما، بے شک تو دعا کا سننے واﻻ ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cccxxxii{پس فرشتوں نے انہیں آواز دی، جب کہ وه حجرے میں کھڑے نماز پڑھ رہے تھے، کہ اللہ تعالیٰ تجھے یحيٰ کی یقینی خوشخبری دیتا ہے جو اللہ تعالیٰ کے کلمہ کی تصدیق کرنے واﻻ، سردار، ضابط نفس اور نبی ہے نیک لوگوں میں سے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cccxxxiii{کہنے لگے اے میرے رب! میرے ہاں بچہ کیسے ہوگا؟ میں بالکل بوڑھا ہو گیا ہوں اور میری بیوی بانجھ ہے، فرمایا، اسی طرح اللہ تعالیٰ جو چاہے کرتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cccxxxiv{کہنے لگے پروردگار! میرے لئے اس کی کوئی نشانی مقرر کر دے، فرمایا، نشانی یہ ہے کہ تین دن تک تو لوگوں سے بات نہ کر سکے گا، صرف اشارے سے سمجھائے گا، تو اپنے رب کا ذکر کثرت سے کر اور صبح وشام اسی کی تسبیح بیان کرتا ره!\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cccxxxv{اور جب فرشتوں نے کہا، اے مریم! اللہ تعالیٰ نے تجھے برگزیده کر لیا اور تجھے پاک کر دیا اور سارے جہان کی عورتوں میں سے تیرا انتخاب کر لیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cccxxxvi{اے مریم! تو اپنے رب کی اطاعت کر اور سجده کر اور رکوع کرنے والوں کے ساتھ رکوع کر\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cccxxxvii{یہ غیب کی خبروں میں سے ہے جسے ہم تیری طرف وحی سے پہنچاتے ہیں، تو ان کے پاس نہ تھا جب کہ وه اپنے قلم ڈال رہے تھے کہ مریم کو ان میں سے کون پالے گا؟ اور نہ تو ان کے جھگڑنے کے وقت ان کے پاس تھا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cccxxxviii{جب فرشتوں نے کہا اے مریم اللہ تعالیٰ تجھے اپنے ایک کلمے کی خوشخبری دیتا ہے جس کا نام مسیح عیسیٰ بن مریم ہے جو دنیا اور آخرت میں ذیعزت ہے اور وه میرے مقربین میں سے ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@cccxxxix{وه لوگوں سے اپنے گہوارے میں باتیں کرے گا اور ادھیڑ عمر میں بھی اور وه نیک لوگوں میں سے ہوگا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@cccxl{کہنے لگیں الٰہی مجھے لڑکا کیسے ہوگا؟ حاﻻنکہ مجھے تو کسی انسان نے ہاتھ بھی نہیں لگایا، فرشتے نے کہا، اسی طرح اللہ تعالیٰ جو چاہے پیدا کرتا ہے، جب کبھی وه کسی کام کو کرنا جاہتا ہے تو صرف یہ کہہ دیتا ہے کہ ہو جا! تو وه ہو جاتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@cccxli{اللہ تعالیٰ اسے لکھنا اور حکمت اور توراة اورانجیل سکھائے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@cccxlii{اور وه بنی اسرائیل کی طرف رسول ہوگا، کہ میں تمہارے پاس تمہارے رب کی نشانی ﻻیا ہوں، میں تمہارے لئے پرندے کی شکل کی طرح مٹی کا پرنده بناتا ہوں، پھر اس میں پھونک مارتا ہوں تو وه اللہ تعالیٰ کے حکم سے پرنده بن جاتاہے اور اللہ تعالیٰ کے حکم سے میں مادرزاد اندھے کو اور کوڑھی کو اچھا کر دیتا ہوں اور مرددوں کو زندہ کرتا ہوں اور جو کچھ تم کھاؤ اور جو اپنے گھروں میں ذخیره کرو میں تمہیں بتا دیتا ہوں، اس میں تمہارے لئے بڑی نشانی ہے، اگر تم ایمان ﻻنے والے ہو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@cccxliii{اور میں توراة کی تصدیق کرنے واﻻ ہوں جو میرے سامنے ہے اور میں اس لئے آیا ہوں کہ تم پر بعض وه چیزیں حلال کروں جو تم پر حرام کر دی گئی ہیں اور میں تمہارے پاس تمہارے رب کی نشانی ﻻیا ہوں، اس لئے تم اللہ تعالیٰ سے ڈرو اور میری فرمانبرداری کرو!\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@cccxliv{یقین مانو! میرا اور تمہارا رب اللہ ہی ہے، تم سب اسی کی عبادت کرو، یہی سیدھی راه ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@cccxlv{مگر جب حضرت عیسیٰ علیہ السلام نے ان کا کفر محسوس کر لیا تو کہنے لگے اللہ تعالیٰ کی راه میں میری مدد کرنے واﻻ کون کون ہے؟ حواریوں نے جواب دیا کہ ہم اللہ تعالیٰ کی راه کے مددگار ہیں، ہم اللہ تعالیٰ پر ایمان ﻻئے اور آپ گواه رہئے کہ ہم تابعدار ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@cccxlvi{اے ہمارے پالنے والے معبود! ہم تیری اتاری ہوئی وحی پر ایمان ﻻئے اور ہم نے تیرے رسول کی اتباع کی، پس تو ہمیں گواہوں میں لکھ لے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@cccxlvii{اور کافروں نے مکر کیا اور اللہ تعالیٰ نے بھی (مکر) خفیہ تدبیر کی اور اللہ تعالیٰ سب خفیہ تدبیر کرنے والوں سے بہتر ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@cccxlviii{جب اللہ تعالیٰ نے فرمایا کہ اے عیسیٰ! میں تجھے پورا لینے واﻻ ہوں اور تجھے اپنی جانب اٹھانے واﻻ ہوں اور تجھے کافروں سے پاک کرنے واﻻ ہوں اور تیرے تابعداروں کو کافروں کے اوپر غالب کرنے واﻻ ہوں قیامت کے دن تک، پھر تم سب کا لوٹنا میری ہی طرف ہے میں ہی تمہارے آپس کے تمام تر اختلافات کا فیصلہ کروں گا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@cccxlix{پھر کافروں کو تو میں دنیا اور آخرت میں سخت تر عذاب دوں گا اور ان کا کوئی مددگار نہ ہوگا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@cccl{لیکن ایمان والوں اور نیک اعمال والوں کو اللہ تعالیٰ ان کا ﺛواب پورا پورا دے گا اور اللہ تعالیٰ ﻇالموں سے محبت نہیں کرتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@cccli{یہ جسے ہم تیرے سامنے پڑھ رہے ہیں آیتیں ہیں اور حکمت والی نصیحت ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@ccclii{اللہ تعالیٰ کے نزدیک عیسیٰ (علیہ السلام) کی مثال ہو بہو آدم (علیہ السلام) کی مثال ہے جسے مٹی سے بنا کر کے کہہ دیا کہ ہو جا! پس وه ہو گیا!\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@cccliii{تیرے رب کی طرف سے حق یہی ہے خبردار شک کرنے والوں میں نہ ہونا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@cccliv{اس لئے جو شخص آپ کے پاس اس علم کے آجانے کے بعد بھی آپ سے اس میں جھگڑے تو آپ کہہ دیں کہ آو ہم تم اپنے اپنے فرزندوں کو اور ہم تم اپنی اپنی عورتوں کواور ہم تم خاص اپنی اپنی جانوں کو بلالیں، پھر ہم عاجزی کے ساتھ التجا کریں اور جھوٹوں پر اللہ کی لعنت کریں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@ccclv{یقیناً صرف یہی سچا بیان ہے اور کوئی معبود برحق نہیں بجز اللہ تعالیٰ کے اور بے شک غالب اور حکمت واﻻ اللہ تعالیٰ ہی ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@ccclvi{پھر بھی اگر قبول نہ کریں تو اللہ تعالیٰ بھی صحیح طور پر فسادیوں کو جاننے واﻻ ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@ccclvii{آپ کہہ دیجئے کہ اے اہل کتاب! ایسی انصاف والی بات کی طرف آو جو ہم میں تم میں برابر ہے کہ ہم اللہ تعالیٰ کے سوا کسی کی عبادت نہ کریں نہ اس کے ساتھ کسی کو شریک بنائیں، نہ اللہ تعالیٰ کو چھوڑ کر آپس میں ایک دوسرے کو ہی رب بنائیں۔ پس اگر وه منھ پھیر لیں تو تم کہہ دو کہ گواه رہو ہم تو مسلمان ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@ccclviii{اے اہل کتاب! تم ابراہیم کی بابت کیوں جھگڑتے ہو حاﻻنکہ تورات وانجیل تو ان کے بعد نازل کی گئیں، کیا تم پھر بھی نہیں سمجھتے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@ccclix{سنو! تم لوگ اس میں جھگڑ چکے جس کا تمہیں علم تھا پھر اب اس بات میں کیوں جھگڑتے ہو جس کا تمہیں علم ہی نہیں؟ اور اللہ تعالیٰ جانتا ہے اور تم نہیں جانتے،\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@ccclx{ابراہیم تو نہ یہودی تھے نہ نصرانی تھے بلکہ وه تو یک طرفہ (خالص) مسلمان تھے، وه مشرک بھی نہیں تھے،\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@ccclxi{سب لوگوں سے زیاده ابراہیم سے نزدیک تر وه لوگ ہیں جنہوں نے ان کا کہا مانا اور یہ نبی اور جو لوگ ایمان ﻻئے، مومنوں کا ولی اور سہارا اللہ ہی ہے،\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@ccclxii{اہل کتاب کی ایک جماعت چاہتی ہے کہ تمہیں گمراه کر دیں۔ دراصل وه خود اپنے آپ کو گمراه کر رہے ہیں اور سمجھتے نہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@ccclxiii{اے اہل کتاب تم (باوجود قائل ہونے کے پھر بھی) دانستہ اللہ کی آیات کا کیوں کفر کر رہے ہو؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@ccclxiv{اے اہل کتاب! باوجود جاننے کے حق وباطل کو کیوں خلط ملط کر رہے ہو اور کیوں حق کو چھپا رہے ہو؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@ccclxv{اور اہل کتاب کی ایک جماعت نے کہا کہ جو کچھ ایمان والوں پر اتارا گیا ہے اس پر دن چڑھے تو ایمان ﻻؤ اور شام کے وقت کافر بن جاؤ، تاکہ یہ لوگ بھی پلٹ جائیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@ccclxvi{اور سوائے تمہارے دین پر چلنے والوں کے اور کسی کا یقین نہ کرو۔ آپ کہہ دیجئے کہ بے شک ہدایت تو اللہ ہی کی ہدایت ہے (اور یہ بھی کہتے ہیں کہ اس بات کا بھی یقین نہ کرو) کہ کوئی اس جیسا دیا جائے جیسا تم دیئے گئے ہو، یا یہ کہ یہ تم سے تمہارے رب کے پاس جھگڑا کریں گے، آپ کہہ دیجئے کہ فضل تو اللہ تعالیٰ ہی کے ہاتھ میں ہے، وه جسے چاہے اسے دے، اللہ تعالیٰ وسعت واﻻ اورجاننے واﻻ ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@ccclxvii{وه اپنی رحمت کے ساتھ جسے چاہے مخصوص کر لے اور اللہ تعالیٰ بڑے فضل واﻻ ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@ccclxviii{بعض اہل کتاب تو ایسے ہیں کہ اگر انہیں تو خزانے کا امین بنا دے تو بھی وه تجھے واپس کر دیں اور ان میں سے بعض ایسے بھی ہیں کہ اگر تو انہیں ایک دینار بھی امانت دے تو تجھے ادا نہ کریں۔ ہاں یہ اوربات ہے کہ تو اس کے سر پر ہی کھڑا رہے، یہ اس لئے کہ انہوں نے کہہ رکھا ہے کہ ہم پر ان جاہلوں (غیر یہودی) کے حق کاکوئی گناه نہیں، یہ لوگ باوجود جاننے کے اللہ تعالیٰ پر جھوٹ کہتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@ccclxix{کیوں نہیں (مواخذہ ہوگا) البتہ جو شخص اپنا قرار پورا کرے اور پرہیزگاری کرے، تو اللہ تعالیٰ بھی ایسے پرہیز گاروں سے محبت کرتاہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@ccclxx{بے شک جو لوگ اللہ تعالیٰ کے عہد اور اپنی قسموں کو تھوڑی قیمت پر بیچ ڈالتے ہیں، ان کے لئے آخرت میں کوئی حصہ نہیں، اللہ تعالیٰ نہ تو ان سے بات چیت کرے گا نہ ان کی طرف قیامت کے دن دیکھے گا، نہ انہیں پاک کرے گا اور ان کے لئے دردناک عذاب ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@ccclxxi{یقیناًان میں ایسا گروه بھی ہے جو کتاب پڑھتے ہوئے اپنی زبان مروڑتا ہے تاکہ تم اسے کتاب ہی کی عبارت خیال کرو حاﻻنکہ دراصل وه کتاب میں سے نہیں، اور یہ کہتے بھی ہیں کہ وه اللہ تعالیٰ کی طرف سے ہے حاﻻنکہ در اصل وه اللہ تعالی کی طرف سے نہیں، وه تو دانستہ اللہ تعالیٰ پر جھوٹ بولتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@ccclxxii{کسی ایسے انسان کو جسے اللہ تعالیٰ کتاب وحکمت اور نبوت دے، یہ ﻻئق نہیں کہ پھر بھی وه لوگوں سے کہے کہ تم اللہ تعالیٰ کو چھوڑ کر میرے بندے بن جاؤ، بلکہ وه تو کہے گا کہ تم سب رب کے ہو جاؤ، تمہارے کتاب سکھانے کے باعﺚ اور تمہارے کتاب پڑھنے کے سبب۔\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@ccclxxiii{اور یہ نہیں (ہو سکتا) کہ وه تمہیں فرشتوں اورنبیوں کو رب بنا لینے کا حکم کرے، کیا وه تمہارے مسلمان ہونے کے بعد بھی تمہیں کفر کا حکم دے گا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@ccclxxiv{جب اللہ تعالیٰ نے نبیوں سے عہد لیا کہ جو کچھ میں تمہیں کتاب وحکمت دوں پھر تمہارے پاس وه رسول آئے جو تمہارے پاس کی چیز کو سچ بتائے تو تمہارے لئے اس پر ایمان ﻻنا اور اس کی مدد کرنا ضروری ہے۔ فرمایا کہ تم اس کے اقراری ہو اور اس پر میرا ذمہ لے رہے ہو؟ سب نے کہا کہ ہمیں اقرار ہے، فرمایا تو اب گواه رہو اور خود میں بھی تمہارے ساتھ گواہوں میں ہوں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@ccclxxv{پس اس کے بعد بھی جو پلٹ جائیں وه یقیناً پورے نافرمان ہیں۔\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@ccclxxvi{کیا وه اللہ تعالیٰ کے دین کے سوا اور دین کی تلاش میں ہیں؟ حاﻻنکہ تمام آسمانوں والے اور سب زمین والے اللہ تعالیٰ ہی کے فرمانبردار ہیں خوشی سے ہوں یا ناخوشی سے، سب اسی کی طرف لوٹائے جائیں گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@ccclxxvii{آپ کہہ دیجئے کہ ہم اللہ تعالیٰ پر اور جو کچھ ہم پر اتارا گیا ہے اور جو کچھ ابراہیم (علیہ السلام) اور اسماعیل (علیہ السلام) اور یعقوب (علیہ السلام) اوران کی اوﻻد پر اتارا گیا اور جو کچھ موسیٰ وعیسیٰ (علیہما السلام) اور دوسرے انبیاء (علیہم السلام) اللہ تعالیٰ کی طرف سے دیئے گئے، ان سب پر ایمان ﻻئے، ہم ان میں سے کسی کے درمیان فرق نہیں کرتے اور ہم اللہ تعالیٰ کے فرمانبردار ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@ccclxxviii{جو شخص اسلام کے سوا اور دین تلاش کرے، اس کا دین قبول نہ کیا جائے گا اور وه آخرت میں نقصان پانے والوں میں ہوگا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@ccclxxix{اللہ تعالیٰ ان لوگوں کو کیسے ہدایت دے گا جو اپنے ایمان ﻻنے اور رسول کی حقانیت کی گواہی دینے اور اپنے پاس روشن دلیلیں آجانے کے بعد کافر ہو جائیں، اللہ تعالیٰ ایسے بے انصاف لوگوں کو راه راست پرنہیں ﻻتا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@ccclxxx{ان کی تو یہی سزا ہے کہ ان پر اللہ تعالیٰ کی اور فرشتوں کی اور تمام لوگوں کی لعنت ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@ccclxxxi{جس میں یہ ہمیشہ پڑے رہیں گے، نہ تو ان سے عذاب ہلکا کیا جائے گا نہ انہیں مہلت دی جائے گی\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@ccclxxxii{مگرجو لوگ اس کے بعد توبہ اور اصلاح کر لیں تو بے شک اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiii{بےشک جو لوگ اپنے ایمان ﻻنے کے بعد کفر کریں پھر کفر میں بڑھ جائیں، ان کی توبہ ہرگز ہرگز قبول نہ کی جائے گی، یہی گمراه لوگ ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiv{ہاں جو لوگ کفر کریں اور مرتے دم تک کافر رہیں ان میں سے کوئی اگر زمین بھر سونا دے، گو فدیئے میں ہی ہو تو بھی ہرگز قبول نہ کیا جائے گا۔ یہی لوگ ہیں جن کے لئے تکلیف دینے واﻻ عذاب ہے اور جن کا کوئی مددگار نہیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@ccclxxxv{جب تک تم اپنی پسندیده چیز سے اللہ تعالیٰ کی راه میں خرچ نہ کروگے ہرگز بھلائی نہ پاؤ گے، اور تم جو خرچ کرو اسے اللہ تعالیٰ بخوبی جانتا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvi{توراة کے نزول سے پہلے (حضرت) یعقوب (علیہ السلام) نے جس چیز کو اپنے اوپر حرام کر لیا تھا اس کے سوا تمام کھانے بنی اسرائیل پر حلال تھے، آپ کہہ دیجئے کہ اگر تم سچے ہو تو توراة لے آو اور پڑھ کر سناؤ\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvii{اس کے بعد بھی جو لوگ اللہ تعالیٰ پر جھوٹ بہتان باندھیں وہی ﻇالم ہیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@ccclxxxviii{کہہ دیجئے کہ اللہ تعالیٰ سچا ہے تم سب ابراہیم حنیف کے ملت کی پیروی کرو، جو مشرک نہ تھے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ccclxxxix{اللہ تعالیٰ کا پہلا گھر جو لوگوں کے لئے مقرر کیا گیا وہی ہے جو مکہ (شریف) میں ہے جو تمام دنیا کے لئے برکت وہدایت واﻻ ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@cccxc{جس میں کھلی کھلی نشانیاں ہیں، مقام ابراہیم ہے، اس میں جو آ جائے امن واﻻ ہو جاتا ہے اللہ تعالیٰ نے ان لوگوں پر جو اس کی طرف راه پا سکتے ہوں اس گھر کا حج فرض کر دیا گیا ہے۔ اور جو کوئی کفر کرے تو اللہ تعالیٰ (اس سے بلکہ) تمام دنیا سے بے پرواه ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cccxci{آپ کہہ دیجئے کہ اے اہل کتاب تم اللہ تعالیٰ کی آیتوں کے ساتھ کفر کیوں کرتے ہو؟ جو کچھ تم کرتے ہو، اللہ تعالیٰ اس پر گواه ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cccxcii{ان اہل کتاب سے کہو کہ تم اللہ تعالیٰ کی راه سے لوگوں کو کیوں روکتے ہو؟ اور اس میں عیب ٹٹولتے ہو، حاﻻنکہ تم خود شاہد ہو، اللہ تعالیٰ تمہارے اعمال سے بے خبر نہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cccxciii{اے ایمان والو! اگر تم اہل کتاب کی کسی جماعت کی باتیں مانو گے تو وه تمہیں تمہارے ایمان ﻻنے کے بعد مرتد کافر بنا دیں گے۔\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cccxciv{﴿گو یہ ظاہر ہے کہ﴾ تم کیسے کفر کر سکتے ہو؟ باوجود یہ کہ تم پر اللہ تعالیٰ کی آیتیں پڑھی جاتی ہیں اور تم میں رسول اللہ ﴿صلی اللہ علیہ وسلم﴾ موجود ہیں۔ جو شخص اللہ تعالیٰ (کے دین) کو مضبوط تھام لے تو بلاشبہ اسے راه راست دکھادی گئی\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cccxcv{اے ایمان والو! اللہ تعالیٰ سے اتنا ڈرو جتنا اس سے ڈرنا چاہئیے اور دیکھو مرتے دم تک مسلمان ہی رہنا\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cccxcvi{اللہ تعالیٰ کی رسی کو سب مل کر مضبوط تھام لو اور پھوٹ نہ ڈالو، اور اللہ تعالیٰ کی اس وقت کی نعمت کو یاد کرو جب تم ایک دوسرے کے دشمن تھے، تو اس نے تمہارے دلوں میں الفت ڈال دی، پس تم اس کی مہربانی سے بھائی بھائی ہوگئے، اور تم آگ کے گڑھے کے کنارے پہنچ چکے تھے تو اس نے تمہیں بچا لیا۔ اللہ تعالیٰ اسی طرح تمہارے لئے اپنی نشانیاں بیان کرتا ہے تاکہ تم ہدایت پاؤ\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cccxcvii{تم میں سے ایک جماعت ایسی ہونی چاہئے جو بھلائی کی طرف بلائے اور نیک کاموں کا حکم کرے اور برے کاموں سے روکے، اور یہی لوگ فلاح ونجات پانے والے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cccxcviii{تم ان لوگوں کی طرح نہ ہو جانا جنہوں نے اپنے پاس روشن دلیلیں آ جانے کے بعد بھی تفرقہ ڈاﻻ، اور اختلاف کیا، انہیں لوگوں کے لئے بڑا عذاب ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cccxcix{جس دن بعض چہرے سفید ہوں گے اور بعض سیاه، سیاه چہرے والوں (سے کہا جائے گا) کہ کیا تم نے ایمان ﻻنے کے بعد کفر کیا؟ اب اپنے کفر کا عذاب چکھو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cd{اور سفید چہرے والے اللہ تعالیٰ کی رحمت میں داخل ہوں گے اور اس میں ہمیشہ رہیں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cdi{اے نبی! ہم ان حقانی آیتوں کی تلاوت آپ پر کر رہے ہیں اور اللہ تعالیٰ کا اراده لوگوں پر ﻇلم کرنے کا نہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cdii{اللہ تعالیٰ ہی کے لئے ہے جو کچھ آسمانوں اور زمین میں ہے اور اللہ تعالیٰ ہی کی طرف تمام کام لوٹائے جاتے ہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cdiii{تم بہترین امت ہو جو لوگوں کے لئے پیدا کی گئی ہے کہ تم نیک باتوں کا حکم کرتے ہو اور بری باتوں سے روکتے ہو، اور اللہ تعالیٰ پر ایمان رکھتے ہو، اگر اہل کتاب بھی ایمان ﻻتے تو ان کے لئے بہتر تھا، ان میں ایمان والے بھی ہیں لیکن اکثر تو فاسق ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cdiv{یہ تمہیں ستانے کے سوا اور زیاده کچھ ضرر نہیں پہنچا سکتے، اگر لڑائی کا موقعہ آجائے تو پیٹھ موڑ لیں گے، پھر مدد نہ کیے جائیں گے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cdv{ان پر ہر جگہ ذلت کی مار پڑی، اﻻّ یہ کہ اللہ تعالیٰ کی یا لوگوں کی پناه میں ہوں، یہ غضب الٰہی کے مستحق ہو گئے اور ان پر فقیری ڈال دی گئی، یہ اس لئے کہ یہ لوگ اللہ تعالیٰ کی آیتوں سے کفر کرتے تھے اور بے وجہ انبیا کو قتل کرتے تھے، یہ بدلہ ہے ان کی نافرمانیوں اور زیادتیوں کا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cdvi{یہ سارے کے سارے یکساں نہیں بلکہ ان اہل کتاب میں ایک جماعت (حق پر) قائم رہنے والی بھی ہے جو راتوں کے وقت بھی کلام اللہ کی تلاوت کرتے ہیں اور سجدے بھی کرتے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cdvii{یہ اللہ تعالیٰ پر اورقیامت کے دن پر ایمان بھی رکھتے ہیں، بھلائیوں کا حکم کرتے ہیں اور برائیوں سے روکتے ہیں اور بھلائی کے کاموں میں جلدی کرتے ہیں۔ یہ نیک بخت لوگوں میں سے ہیں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cdviii{یہ جو کچھ بھی بھلائیاں کریں ان کی ناقدری نہ کی جائے گی اور اللہ تعالیٰ پرہیزگاروں کو خوب جانتا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cdix{کافروں کو ان کے مال اور ان کی اوﻻد اللہ کے ہاں کچھ کام نہ آئیں گی، یہ تو جہنمی ہیں جو ہمیشہ اسی میں پڑے رہیں گے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cdx{یہ کفار جو خرچ اخراجات کریں اس کی مثال یہ ہے کہ ایک تند ہوا چلی جس سے پاﻻ تھا جو ﻇالموں کی کھیتی پر پڑا اور اسے تہس نہس کر دیا۔ اللہ تعالیٰ نے ان پر ﻇلم نہیں کیا بلکہ وه خود اپنی جانوں پر ﻇلم کرتے تھے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cdxi{اے ایمان والو! تم اپنا دلی دوست ایمان والوں کے سوا اور کسی کو نہ بناؤ۔ (تم تو) نہیں دیکھتے دوسرے لوگ تمہاری تباہی میں کوئی کسر اٹھا نہیں رکھتے، وه تو چاہتے ہیں کہ تم دکھ میں پڑو ان کی عداوت تو خود ان کی زبان سے بھی ﻇاہر ہو چکی ہے اور جو ان کے سینوں میں پوشیده ہے وه بہت زیاده ہے، ہم نے تمہارے لئے آیتیں بیان کر دیں\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cdxii{اگر عقلمند ہو (تو غور کرو) ہاں تم تو انہیں چاہتے ہو اور وه تم سے محبت نہیں رکھتے، تم پوری کتاب کو مانتے ہو، (وه نہیں مانتے پھر محبت کیسی؟) یہ تمہارے سامنے تو اپنے ایمان کا اقرار کرتے ہیں لیکن تنہائی میں مارے غصہ کے انگلیاں چباتے ہیں کہہ دو کہ اپنے غصہ ہی میں مر جاؤ، اللہ تعالیٰ دلوں کے راز کو بخوبی جانتا ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cdxiii{تمہیں اگر بھلائی ملے تو یہ ناخوش ہوتے ہیں ہاں! اگر برائی پہنچے تو خوش ہوتے ہیں، تم اگر صبر کرو اور پرہیزگاری کرو تو ان کا مکر تمہیں کچھ نقصان نہ دے گا۔ اللہ تعالیٰ نے انکے اعمال کا احاطہ کر رکھا ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cdxiv{اے نبی! اس وقت کو بھی یاد کرو جب صبح ہی صبح آپ اپنے گھر سے نکل کر مسلمانوں کو میدان جنگ میں لڑائی کے مورچوں پر باقاعده بٹھا رہے تھے اللہ تعالیٰ سننے جاننے واﻻ ہے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cdxv{جب تمہاری دو جماعتیں پست ہمتی کا اراده کر چکی تھیں، اللہ تعالیٰ انکا ولی اور مددگار ہے۔ اور اسی کی پاک ذات پر مومنوں کو بھروسہ رکھنا چاہئے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cdxvi{جنگ بدر میں اللہ تعالیٰ نے عین اس وقت تمہاری مدد فرمائی تھی جب کہ تم نہایت گری ہوئی حالت میں تھے، اس لئے اللہ ہی سے ڈرو! (نہ کسی اور سے) تاکہ تمہیں شکر گزاری کی توفیق ہو\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cdxvii{(اور یہ شکر گزاری باعﺚ نصرت وامداد ہو) جب آپ مومنوں کو تسلی دے رہے تھے، کیا آسمان سے تین ہزار فرشتے اتار کر اللہ تعالیٰ کا تمہاری مدد کرنا تمہیں کافی نہ ہوگا،\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cdxviii{کیوں نہیں، بلکہ اگر تم صبر و پرہیزگاری کرو اور یہ لوگ اسی دم تمہارے پاس آجائیں تو تمہارا رب تمہاری امداد پانچ ہزار فرشتوں سے کرے گا جو نشاندار ہوں گے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cdxix{اور یہ تو محض تمہارے دل کی خوشی اور اطمینان قلب کے لئے ہے، ورنہ مدد تو اللہ ہی کی طرف سے ہے جو غالب اور حکمتوں واﻻ ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cdxx{(اس امداد الٰہی کا مقصد یہ تھا کہ اللہ) کافروں کی ایک جماعت کو کاٹ دے یا انہیں ذلیل کر ڈالے اور (سارے کے سارے) نامراد ہو کر واپس چلے جائیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cdxxi{اے پیغمبر! آپ کے اختیار میں کچھ نہیں، اللہ تعالیٰ چاہے تو ان کی توبہ قبول کرے یا عذاب دے، کیونکہ وه ﻇالم ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cdxxii{آسمانوں اور زمین میں جو کچھ ہے سب اللہ ہی کا ہے، وه جسے چاہے بخشے جسے چاہے عذاب کرے، اللہ تعالیٰ بخشش کرنے واﻻ مہربان ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cdxxiii{اے ایمان والو! بڑھا چڑھا کر سود نہ کھاؤ، اور اللہ تعالیٰ سے ڈرو تاکہ تمہیں نجات ملے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cdxxiv{اور اس آگ سے ڈرو جو کافروں کے لئے تیار کی گئی ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cdxxv{اور اللہ اور اس کے رسول کی فرمانبرداری کرو تاکہ تم پر رحم کیا جائے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cdxxvi{اور اپنے رب کی بخشش کی طرف اور اس جنت کی طرف دوڑو جس کا عرض آسمانوں اور زمین کے برابر ہے، جو پرہیزگاروں کے لئے تیار کی گئی ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cdxxvii{جو لوگ آسانی میں سختی کے موقع پر بھی اللہ کے راستے میں خرچ کرتے ہیں، غصہ پینے والے اور لوگوں سے درگزر کرنے والے ہیں، اللہ تعالیٰ ان نیک کاروں سے محبت کرتا ہے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cdxxviii{جب ان سے کوئی ناشائستہ کام ہو جائے یا کوئی گناه کر بیٹھیں تو فوراً اللہ کا ذکر اور اپنے گناہوں کے لئے استغفار کرتے ہیں، فیالواقع اللہ تعالیٰ کے سوا اور کون گناہوں کو بخش سکتا ہے؟ اور وه لوگ باوجود علم کے کسی برے کام پر اڑ نہیں جاتے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cdxxix{انہیں کا بدلہ ان کے رب کی طرف سے مغفرت ہے اور جنتیں ہیں جن کے نیچے نہریں بہتی ہیں، جن میں وه ہمیشہ رہیں گے، ان نیک کاموں کے کرنے والوں کا ﺛواب کیا ہی اچھا ہے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cdxxx{تم سے پہلے بھی ایسے واقعات گزر چکے ہیں، سو زمین میں چل پھر کر دیکھ لو کہ (آسمانی تعلیم کے) جھٹلانے والوں کا کیا انجام ہوا؟\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cdxxxi{عام لوگوں کے لئے تو یہ (قرآن) بیان ہے اور پرہیزگاروں کے لئے ہدایت ونصیحت ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cdxxxii{تم نہ سستی کرو اور غمگین ہو، تم ہی غالب رہو گے، اگر تم ایماندار ہو\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cdxxxiii{اگر تم زخمی ہوئے ہو تو تمہارے مخالف لوگ بھی تو ایسے ہی زخمی ہو چکے ہیں، ہم ان دنوں کو لوگوں کے درمیان ادلتے بدلتے رہتے ہیں۔ (شکست احد) اس لئے تھی کہ اللہ تعالیٰ ایمان والوں کو ﻇاہر کردے اور تم میں سے بعض کو شہادت کا درجہ عطا فرمائے، اللہ تعالیٰ ﻇالموں سے محبت نہیں کرتا\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cdxxxiv{(یہ وجہ بھی تھی) کہ اللہ تعالیٰ ایمان والوں کو بالکل الگ کر دے اور کافروں کو مٹا دے\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cdxxxv{کیا تم یہ سمجھ بیٹھے ہو کہ تم جنت میں چلے جاؤ گے، حاﻻنکہ اب تک اللہ تعالیٰ نے یہ ﻇاہر نہیں کیا کہ تم سے جہاد کرنے والے کون ہیں اور صبر کرنے والے کون ہیں؟\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cdxxxvi{جنگ سے پہلے تو تم شہادت کی آرزو میں تھے اب اسے اپنی آنکھوں سے اپنے سامنے دیکھ لیا\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cdxxxvii{(حضرت) محمد ﴿صلی اللہ علیہ وسلم﴾ صرف رسول ہی ہیں، ان سے پہلے بہت سے رسول ہو چکے ہیں، کیا اگر ان کا انتقال ہو جائے یا یہ شہید ہو جائیں، تو تم اسلام سے اپنی ایڑیوں کے بل پھر جاؤ گے؟ اور جو کوئی پھر جائے اپنی ایڑیوں پر تو ہرگز اللہ تعالیٰ کا کچھ نہ بگاڑے گا، عنقریب اللہ تعالیٰ شکر گزاروں کو نیک بدلہ دے گا\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cdxxxviii{بغیر اللہ تعالیٰ کے حکم کے کوئی جاندار نہیں مرسکتا، مقرر شده وقت لکھا ہوا ہے، دنیا کی چاہت والوں کو ہم کچھ دنیا دے دیتے ہیں اور آخرت کا ﺛواب چاہنے والوں کو ہم وه بھی دیں گے۔ اوراحسان ماننے والوں کو ہم بہت جلد نیک بدلہ دیں گے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cdxxxix{بہت سے نبیوں کے ہم رکاب ہو کر، بہت سے اللہ والے جہاد کر چکے ہیں، انہیں بھی اللہ کی راه میں تکلیفیں پہنچیں لیکن نہ تو انہوں نے ہمت ہاری نہ سست رہے اور نہ دبے، اور اللہ صبر کرنے والوں کو (ہی) چاہتا ہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cdxl{وه یہی کہتے رہے کہ اے پروردگار! ہمارے گناہوں کو بخش دے اور ہم سے ہمارے کاموں میں جو بے جا زیادتی ہوئی ہے اسے بھی معاف فرما اور ہمیں ﺛابت قدمی عطا فرما اور ہمیں کافروں کی قوم پر مدد دے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cdxli{اللہ تعالیٰ نے انہیں دنیا کا ﺛواب بھی دیا اور آخرت کے ﺛواب کی خوبی بھی عطا فرمائی اور اللہ تعالیٰ نیک لوگوں سے محبت کرتا ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cdxlii{اے ایمان والو! اگر تم کافروں کی باتیں مانو گے تو وه تمہیں تمہاری ایڑیوں کے بل پلٹا دیں گے، (یعنی تمہیں مرتد بنا دیں گے) پھر تم نامراد ہو جاؤ گے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cdxliii{بلکہ اللہ ہی تمہارا موﻻ ہے اور وہی بہترین مددگار ہے\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cdxliv{ہم عنقریب کافروں کے دلوں میں رعب ڈال دیں گے، اس وجہ سے کہ یہ اللہ کے ساتھ ان چیزوں کو شریک کرتے ہیں جس کی کوئی دلیل اللہ نے نہیں اتاری، ان کا ٹھکانہ جہنم ہے، اور ان ﻇالموں کی بری جگہ ہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cdxlv{اللہ تعالیٰ نے تم سے اپنا وعده سچا کر دکھایا جبکہ تم اس کے حکم سے انہیں کاٹ رہے تھے۔ یہاں تک کہ جب تم نے پست ہمتی اختیار کی اور کام میں جھگڑنے لگے اور نافرمانی کی، اس کے بعد کہ اس نے تمہاری چاہت کی چیز تمہیں دکھا دی، تم میں سے بعض دنیا چاہتے تھے اور بعض کا اراده آخرت کا تھا تو پھر اس نے تمہیں ان سے پھیر دیا تاکہ تم کو آزمائے اور یقیناً اس نے تمہاری لغزش سے درگزر فرما دیا اور ایمان والوں پر اللہ تعالیٰ بڑے فضل واﻻ ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cdxlvi{جب کہ تم چڑھے چلے جا رہے تھے اور کسی طرف توجہ تک نہیں کرتے تھے اور اللہ کے رسول تمہیں تمہارے پیچھے سے آوازیں دے رہے تھے، بس تمہیں غم پر غم پہنچا تاکہ تم فوت شده چیز پر غمگین نہ ہو اور نہ پہنچنے والی (تکلیف) پر اداس ہو، اللہ تعالیٰ تمہارے تمام اعمال سے خبردار ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cdxlvii{پھر اس نے اس غم کے بعد تم پر امن نازل فرمایا اور تم میں سے ایک جماعت کو امن کی نیند آنے لگی۔ ہاں کچھ وه لوگ بھی تھے کہ انہیں اپنی جانوں کی پڑی ہوئی تھی، وه اللہ تعالیٰ کے ساتھ ناحق جہالت بھری بدگمانیاں کر رہے تھے اور کہتے تھے کیا ہمیں بھی کسی چیز کا اختیار ہے؟ آپ کہہ دیجئے کہ کام کل کا کل اللہ کے اختیار میں ہے، یہ لوگ اپنے دلوں کے بھید آپ کو نہیں بتاتے، کہتے ہیں کہ اگر ہمیں کچھ بھی اختیار ہوتا تو یہاں قتل نہ کئے جاتے۔ آپ کہہ دیجئے کہ گو تم اپنے گھروں میں ہوتے پھر بھی جن کی قمست میں قتل ہونا تھا وه تو مقتل کی طرف چل کھڑے ہوتے، اللہ تعالیٰ کو تمہارے سینوں کے اندر کی چیز کا آزمانا اور جو کچھ تمہارے دلوں میں ہے، اس کو پاک کرنا تھا، اور اللہ تعالی سینوں کے بھید سے آگاه ہے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cdxlviii{تم میں سے جن لوگوں نے اس دن پیٹھ دکھائی جس دن دونوں جماعتوں کی مدبھیڑ ہوئی تھی یہ لوگ اپنے بعض کرتوتوں کے باعﺚ شیطان کے پھسلانے میں آگئے لیکن یقین جانو کہ اللہ تعالیٰ نے انہیں معاف کر دیا اللہ تعالیٰ ہے بخشنے واﻻ اور تحمل واﻻ\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cdxlix{اے ایمان والو! تم ان لوگوں کی طرح نہ ہو جانا جنہوں نے کفر کیا اور اپنے بھائیوں کے حق میں جب کہ وه سفر میں ہوں یا جہاد میں ہوں، کہا کہ اگر یہ ہمارے پاس ہوتے تو نہ مرتے اور نہ مارے جاتے، اس کی وجہ یہ تھی کہ اس خیال کو اللہ تعالیٰ ان کی دلی حسرت کا سبب بنا دے، اللہ تعالیٰ جلاتا ہے اور مارتا ہے اور اللہ تمہارے عمل کو دیکھ رہا ہے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cdl{قسم ہے اگر اللہ تعالیٰ کی راه میں شہید کئے جاؤ یا اپنی موت مرو تو بے شک اللہ تعالیٰ کی بخشش ورحمت اس سے بہتر ہے جسے یہ جمع کر رہے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cdli{بالیقین خواہ تم مر جاؤ یا مار ڈالے جاؤ جمع تو اللہ تعالیٰ کی طرف ہی کئے جاؤ گے۔\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cdlii{اللہ تعالیٰ کی رحمت کے باعﺚ آپ ان پر نرم دل ہیں اور اگر آپ بد زبان اور سخت دل ہوتے تو یہ سب آپ کے پاس سے چھٹ جاتے، سو آپ ان سے درگزر کریں اور ان کے لئے استغفار کریں اور کام کا مشوره ان سے کیا کریں، پھر جب آپ کا پختہ اراده ہو جائے تو اللہ تعالیٰ پر بھروسہ کریں، بے شک اللہ تعالیٰ توکل کرنے والوں سے محبت کرتا ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cdliii{اگر اللہ تعالیٰ تمہاری مدد کرے تو تم پر کوئی غالب نہیں آسکتا اور اگر وہ تمہیں چھوڑ دے تو اس کے بعد کون ہے جو تمہاری مدد کرے؟ ایمان والوں کو اللہ تعالیٰ ہی پر بھروسہ رکھنا چاہئے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cdliv{ناممکن ہے کہ نبی سے خیانت ہو جائے ہر خیانت کرنے واﻻ خیانت کو لئے ہوئے قیامت کے دن حاضر ہوگا، پھر ہر شخص کو اپنے اعمال کا پورا پورا بدلہ دیا جائے گا، اور وه ﻇلم نہ کئے جائیں گے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cdlv{کیا پس وه شخص جو اللہ تعالیٰ کی خوشنودی کے درپے ہے، اس شخص جیسا ہے جو اللہ تعالیٰ کی ناراضگی لے کر لوٹتا ہے؟ اور جس کی جگہ جہنم ہے جو بدترین جگہ ہے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cdlvi{اللہ تعالیٰ کے پاس ان کے الگ الگ درجے ہیں اور ان کے تمام اعمال کو اللہ بخوبی دیکھ رہا ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cdlvii{بے شک مسلمانوں پر اللہ تعالیٰ کا بڑا احسان ہے کہ ان ہی میں سے ایک رسول ان میں بھیجا، جو انہیں اس کی آیتیں پڑھ کر سناتا ہے اور انہیں پاک کرتا ہے اور انہیں کتاب اور حکمت سکھاتا ہے، یقیناً یہ سب اس سے پہلے کھلی گمراہی میں تھے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cdlviii{(کیا بات ہے) کہ جب تمہیں ایک ایسی تکلیف پہنچی کہ تم اس جیسی دو چند پہنچا چکے، تو یہ کہنے لگے کہ یہ کہاں سے آگئی؟ آپ کہہ دیجئے کہ یہ خود تمہاری طرف سے ہے، بے شک اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cdlix{اور تمہیں جو کچھ اس دن پہنچا جس دن دو جماعتوں میں مڈ بھیڑ ہوئی تھی، وه سب اللہ کے حکم سے تھا اور اس لئے کہ اللہ تعالیٰ ایمان والوں کو ﻇاہری طور پر جان لے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@cdlx{اور منافقوں کو بھی معلوم کر لے جن سے کہا گیا کہ آؤ اللہ کی راه میں جہاد کرو، یا کافروں کو ہٹاو، ٴ تو وه کہنے لگے کہ اگر ہم لڑائی جانتے ہوتے تو ضرور ساتھ دیتے، وه اس دن بہ نسبت ایمان کے کفر سے بہت قریب تھے، اپنے منھ سے وه باتیں بناتے ہیں جو ان کے دلوں میں نہیں، اور اللہ تعالیٰ خوب جانتا ہے جسے وه چھپاتے ہیں\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@cdlxi{یہ وه لوگ ہیں جو خود بھی بیٹھے رہے اور اپنے بھائیوں کی بابت کہا کہ اگر وه بھی ہماری بات مان لیتے تو قتل نہ کئے جاتے۔ کہہ دیجئے! کہ اگر تم سچے ہو تو اپنی جانوں سے موت کو ہٹا دو\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@cdlxii{جو لوگ اللہ کی راه میں شہید کئے گئے ہیں ان کو ہرگز مرده نہ سمجھیں، بلکہ وه زنده ہیں اپنے رب کے پاس روزیاں دیئے جاتے ہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@cdlxiii{اللہ تعالیٰ نے اپنا فضل جو انہیں دے رکھا ہے اس سے بہت خوش ہیں اور خوشیاں منا رہے ہیں ان لوگوں کی بابت جو اب تک ان سے نہیں ملے ان کے پیچھے ہیں، اس پر کہ انہیں نہ کوئی خوف ہے اور نہ وه غمگین ہوں گے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@cdlxiv{وه خوش ہوتے ہیں اللہ کی نعمت اور فضل سے اور اس سے بھی کہ اللہ تعالیٰ ایمان والوں کے اجر کو برباد نہیں کرتا\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@cdlxv{جن لوگوں نے اللہ اور رسول کے حکم کو قبول کیا اس کے بعد کہ انہیں پورے زخم لگ چکے تھے، ان میں سے جنہوں نے نیکی کی اور پرہیزگاری برتی ان کے لئے بہت زیاده اجر ہے\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@cdlxvi{وه لوگ کہ جب ان سے لوگوں نے کہا کہ کافروں نے تمہارے مقابلے پر لشکر جمع کر لئے ہیں، تم ان سے خوف کھاؤ تو اس بات نے انہیں ایمان میں اور بڑھا دیا اور کہنے لگے ہمیں اللہ کافی ہے اور وه بہت اچھا کارساز ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@cdlxvii{(نتیجہ یہ ہوا کہ) اللہ کی نعمت وفضل کے ساتھ یہ لوٹے، انہیں کوئی برائی نہ پہنچی، انہوں نے اللہ تعالیٰ کی رضامندی کی پیروی کی، اللہ بہت بڑے فضل واﻻ ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@cdlxviii{یہ خبر دینے واﻻ صرف شیطان ہی ہے جو اپنے دوستوں سے ڈراتا ہے تم ان کافروں سے نہ ڈرو اور میرا خوف رکھو، اگر تم مومن ہو\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@cdlxix{کفر میں آگے بڑھنے والے لوگ تجھے غمناک نہ کریں، یقین مانو کہ یہ اللہ تعالیٰ کا کچھ نہ بگاڑ سکیں گے، اللہ تعالیٰ کا اراده ہے کہ ان کے لئے آخرت کا کوئی حصہ عطا نہ کرے، اور ان کے لئے بڑا عذاب ہے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@cdlxx{کفر کو ایمان کے بدلے خریدنے والے ہرگز ہرگز اللہ تعالیٰ کو کوئی نقصان نہیں پہنچا سکتے اور ان ہی کے لئے المناک عذاب ہے\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@cdlxxi{کافر لوگ ہماری دی ہوئی مہلت کو اپنے حق میں بہتر نہ سمجھیں، یہ مہلت تو اس لئے ہے کہ وه گناہوں میں اور بڑھ جائیں، ان ہی کے لئے ذلیل کرنے واﻻ عذاب ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@cdlxxii{جس حال میں تم ہو اسی پر اللہ ایمان والوں کو نہ چھوڑ دے گا جب تک کہ پاک اور ناپاک کو الگ الگ نہ کر دے، اور نہ اللہ تعالیٰ ایسا ہے کہ تمہیں غیب سے آگاه کردے، بلکہ اللہ تعالیٰ اپنے رسولوں میں سے جس کا چاہے انتخاب کر لیتا ہے، اس لئے تم اللہ تعالیٰ پر اور اس کے رسولوں پر ایمان رکھو، اگر تم ایمان ﻻؤ اور تقویٰ کرو تو تمہارے لئے بڑا بھاری اجر ہے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@cdlxxiii{جنہیں اللہ تعالیٰ نے اپنے فضل سے کچھ دے رکھا ہے وه اس میں اپنی کنجوسی کو اپنے لئے بہتر خیال نہ کریں بلکہ وه ان کے لئے نہایت بدتر ہے، عنقریب قیامت والے دن یہ اپنی کنجوسی کی چیز کے طوق ڈالے جائیں گے، آسمانوں اور زمین کی میراث اللہ تعالیٰ ہی کے لئے اور جو کچھ تم کر رہے ہو، اس سے اللہ تعالیٰ آگاه ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@cdlxxiv{یقیناً اللہ تعالیٰ نے ان لوگوں کا قول بھی سنا جنہوں نے کہا کہ اللہ تعالیٰ فقیر ہے اور ہم تونگر ہیں ان کے اس قول کو ہم لکھ لیں گے۔ اور ان کا انبیا کو بلا وجہ قتل کرنا بھی، اور ہم ان سے کہیں گے کہ جلنے واﻻ عذاب چکھو!\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@cdlxxv{یہ تمہارے پیش کرده اعمال کا بدلہ ہے اور اللہ تعالیٰ اپنے بندوں پر ﻇلم کرنے واﻻ نہیں\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cdlxxvi{یہ وه لوگ ہیں جنہوں نے کہا کہ اللہ تعالیٰ نے ہمیں حکم دیا ہے کہ کسی رسول کو نہ مانیں جب تک وه ہمارے پاس ایسی قربانی نہ ﻻئے جسے آگ کھا جائے۔ آپ کہہ دیجئے کہ اگر تم سچے ہو تو مجھ سے پہلے تمہارے پاس جو رسول دیگر معجزوں کے ساتھ یہ بھی ﻻئے جسے تم کہہ رہے ہو تو پھر تم نے انہیں کیوں مار ڈاﻻ؟\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cdlxxvii{پھر بھی اگر یہ لوگ آپ کو جھٹلائیں تو آپ سے پہلے بھی بہت سے رسول جھٹلائے گئے ہیں جو روشن دلیلیں صحیفے اور منور کتاب لے کر آئے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cdlxxviii{ہر جان موت کا مزه چکھنے والی ہے اور قیامت کے دن تم اپنے بدلے پورے پورے دیئے جاؤ گے، پس جو شخص آگ سے ہٹا دیا جائے اور جنت میں داخل کر دیا جائے بے شک وه کامیاب ہوگیا، اور دنیا کی زندگی تو صرف دھوکے کی جنس ہے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cdlxxix{یقیناً تمہارے مالوں اور جانوں سے تمہاری آزمائش کی جائے گی اور یہ بھی یقین ہے کہ تمہیں ان لوگوں کی جو تم سے پہلے کتاب دیئے گئے اور مشرکوں کی بہت سی دکھ دینے والی باتیں بھی سننی پڑیں گی اور اگر تم صبر کر لو اور پرہیزگاری اختیار کرو تو یقیناً یہ بہت بڑی ہمت کا کام ہے\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cdlxxx{اور اللہ تعالیٰ نے جب اہل کتاب سے عہد لیا کہ تم اسے سب لوگوں سے ضرور بیان کرو گے اور اسے چھپاؤ گے نہیں، تو پھر بھی ان لوگوں نے اس عہد کو اپنی پیٹھ پیچھے ڈال دیا اور اسے بہت کم قیمت پر بیچ ڈاﻻ۔ ان کا یہ بیوپار بہت برا ہے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cdlxxxi{وه لوگ جو اپنے کرتوتوں پر خوش ہیں اور چاہتے ہیں کہ جو انہوں نے نہیں کیا اس پر بھی ان کی تعریفیں کی جائیں آپ انہیں عذاب سے چھٹکارا میں نہ سمجھئے ان کے لئے تو دردناک عذاب ہے\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cdlxxxii{آسمانوں اور زمین کی بادشاہی اللہ ہی کے لئے ہے اور اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiii{آسمانوں اور زمین کی پیدائش میں اور رات دن کے ہیر پھیر میں یقیناً عقلمندوں کے لئے نشانیاں ہیں\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiv{جو اللہ تعالیٰ کا ذکر کھڑے اور بیٹھے اور اپنی کروٹوں پر لیٹے ہوئے کرتے ہیں اور آسمانوں وزمین کی پیدائش میں غوروفکر کرتے ہیں اور کہتے ہیں اے ہمارے پروردگار! تو نے یہ بے فائده نہیں بنایا، تو پاک ہے پس ہمیں آگ کے عذاب سے بچا لے\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cdlxxxv{اے ہمارے پالنے والے! تو جسے جہنم میں ڈالے یقیناً تو نے اسے رسوا کیا، اور ﻇالموں کا مددگار کوئی نہیں\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvi{اے ہمارے رب! ہم نے سنا کہ منادی کرنے واﻻ بآواز بلند ایمان کی طرف بلا رہا ہے کہ لوگو! اپنے رب پر ایمان لاؤ، پس ہم ایمان ﻻئے۔ یا الٰہی اب تو ہمارے گناه معاف فرما اور ہماری برائیاں ہم سے دور کر دے اور ہماری موت نیکوں کے ساتھ کر\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvii{اے ہمارے پالنے والے معبود! ہمیں وه دے جس کا وعده تو نے ہم سے اپنے رسولوں کی زبانی کیا ہے اور ہمیں قیامت کے دن رسوا نہ کر، یقیناً تو وعده خلافی نہیں کرتا\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@cdlxxxviii{پس ان کے رب نے ان کی دعا قبول فرمالی کہ تم میں سے کسی کام کرنے والے کے کام کو خواه وه مرد ہو یا عورت میں ہرگز ضائع نہیں کرتا، تم آپس میں ایک دوسرے کے ہم جنس ہو، اس لئے وه لوگ جنہوں نے ہجرت کی اور اپنے گھروں سے نکال دیئے گئے اور جنہیں میری راه میں ایذا دی گئی اور جنہوں نے جہاد کیا اور شہید کئے گئے، میں ضرور ضرور ان کی برائیاں ان سے دور کر دوں گا اور بالیقین انہیں ان جنتوں میں لے جاؤں گا جن کے نیچے نہریں بہہ رہی ہیں، یہ ہے ﺛواب اللہ تعالیٰ کی طرف سے اور اللہ تعالیٰ ہی کے پاس بہترین ﺛواب ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cdlxxxix{تجھے کافروں کا شہروں میں چلنا پھرنا فریب میں نہ ڈال دے،\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cdxc{یہ تو بہت ہی تھوڑا فائده ہے، اس کے بعد ان کا ٹھکانہ تو جہنم ہے اور وه بری جگہ ہے\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@cdxci{لیکن جو لوگ اپنے رب سے ڈرتے رہے ان کے لئے جنتیں ہیں جن کے نیچے نہریں جاری ہیں، ان میں وه ہمیشہ رہیں گے یہ مہمانی ہے اللہ کی طرف سے اور نیک کاروں کے لئے جو کچھ اللہ تعالیٰ کے پاس ہے وه بہت ہی بہتر ہے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@cdxcii{یقیناًاہل کتاب میں سے بعض ایسے بھی ہیں جو اللہ تعالیٰ پر ایمان ﻻتے ہیں اور تمہاری طرف جو اتارا گیا ہے اور ان کی جانب جو نازل ہوا اس پر بھی، اللہ تعالیٰ سے ڈرتے ہیں اور اللہ تعالیٰ کی آیتوں کو تھوڑی تھوڑی قیمت پر بیچتے بھی نہیں، ان کا بدلہ ان کے رب کے پاس ہے، یقیناً اللہ تعالیٰ جلد حساب لینے واﻻ ہے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@cdxciii{اے ایمان والو! تم ﺛابت قدم رہو اور ایک دوسرے کو تھامے رکھو اور جہاد کے لئے تیار رہو اور اللہ تعالیٰ سے ڈرتے رہو تاکہ تم مراد کو پہنچو\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@cdxciv{\basmalahur اے لوگو! اپنے پروردگار سے ڈرو، جس نے تمہیں ایک جان سے پیدا کیا اور اسی سے اس کی بیوی کو پیدا کرکے ان دونوں سے بہت سے مرد اور عورتیں پھیلا دیں، اس اللہ سے ڈرو جس کے نام پر ایک دوسرے سے مانگتے ہو اور رشتے ناطے توڑنے سے بھی بچو بے شک اللہ تعالیٰ تم پر نگہبان ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cdxcv{اور یتیموں کو ان کے مال دے دو اور پاک اور حلال چیز کے بدلے ناپاک اور حرام چیز نہ لو، اور اپنے مالوں کے ساتھ ان کے مال ملا کر کھا نہ جاؤ، بے شک یہ بہت بڑا گناه ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cdxcvi{اگر تمہیں ڈر ہو کہ یتیم لڑکیوں سے نکاح کرکے تم انصاف نہ رکھ سکو گے تو اور عورتوں میں سے جو بھی تمہیں اچھی لگیں تم ان سے نکاح کر لو، دو دو، تین تین، چار چار سے، لیکن اگر تمہیں برابری نہ کر سکنے کا خوف ہو تو ایک ہی کافی ہے یا تمہاری ملکیت کی لونڈی یہ زیاده قریب ہے، کہ (ایسا کرنے سے ناانصافی اور) ایک طرف جھک پڑنے سے بچ جاؤ\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cdxcvii{اور عوتوں کو ان کے مہر راضی خوشی دے دو، ہاں اگر وه خود اپنی خوشی سے کچھ مہر چھوڑ دیں تو اسے شوق سے خوش ہو کر کھا لو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cdxcviii{بے عقل لوگوں کو اپنا مال نہ دے دو جس مال کو اللہ تعالیٰ نے تمہاری گزران کے قائم رکھنے کا ذریعہ بنایا ہے، ہاں انہیں اس مال سے کھلاؤ پلاؤ، پہناؤ، اوڑھاؤ اور انہیں معقولیت سے نرم بات کہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cdxcix{اور یتیموں کو ان کے بالﻎ ہو جانے تک سدھارتے اور آزماتے رہو پھر اگر ان میں تم ہوشیاری اور حسن تدبیر پاؤ تو انہیں ان کے مال سونﭗ دو اور ان کے بڑے ہو جانے کے ڈر سے ان کے مالوں کو جلدی جلدی فضول خرچیوں میں تباه نہ کر دو، مال داروں کو چاہئے کہ (ان کے مال سے) بچتے رہیں، ہاں مسکین محتاج ہو تو دستور کے مطابق واجبی طور سے کھالے، پھر جب انہیں ان کے مال سونپو تو گواه بنا لو، دراصل حساب لینے واﻻ اللہ تعالیٰ ہی کافی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@d{ماں باپ اور خویش واقارب کے ترکہ میں مردوں کا حصہ بھی ہے اور عورتوں کا بھی۔ (جو مال ماں باپ اور خویش واقارب چھوڑ مریں) خواه وه مال کم ہو یا زیاده (اس میں) حصہ مقرر کیا ہوا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@di{اور جب تقسیم کے وقت قرابت دار اور یتیم اور مسکین آجائیں تو تم اس میں سے تھوڑا بہت انہیں بھی دے دو اور ان سے نرمی سے بولو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dii{اور چاہئے کہ وه اس بات سے ڈریں کہ اگر وه خود اپنے پیچھے (ننھے ننھے) ناتواں بچے چھوڑ جاتے جن کے ضائع ہو جانے کا اندیشہ رہتا ہے، (تو ان کی چاہت کیا ہوتی) پس اللہ تعالیٰ سے ڈر کر جچی تلی بات کہا کریں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@diii{جو لوگ ناحق ﻇلم سے یتیموں کا مال کھا جاتے ہیں، وه اپنے پیٹ میں آگ ہی بھر رہے ہیں اور عنقریب وه دوزخ میں جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@div{اللہ تعالیٰ تمہیں تمہاری اوﻻد کے بارے میں حکم کرتا ہے کہ ایک لڑکے کا حصہ دو لڑکیوں کے برابر ہے اور اگر صرف لڑکیاں ہی ہوں اور دو سے زیاده ہوں تو انہیں مال متروکہ کا دو تہائی ملے گا۔ اور اگر ایک ہی لڑکی ہو تو اس کے لئے آدھا ہے اور میت کے ماں باپ میں سے ہر ایک کے لئے اس کے چھوڑے ہوئے مال کا چھٹا حصہ ہے، اگر اس (میت) کی اوﻻد ہو، اور اگر اوﻻد نہ ہو اور ماں باپ وارث ہوتے ہوں تو اس کی ماں کے لئے تیسرا حصہ ہے، ہاں اگر میت کے کئی بھائی ہوں تو پھر اس کی ماں کا چھٹا حصہ ہے۔ یہ حصے اس وصیت (کی تکمیل) کے بعد ہیں جو مرنے واﻻ کر گیا ہو یا ادائے قرض کے بعد، تمہارے باپ ہوں یا تمہارے بیٹے تمہیں نہیں معلوم کہ ان میں سے کون تمہیں نفع پہچانے میں زیاده قریب ہے، یہ حصے اللہ تعالیٰ کی طرف سے مقرر کرده ہیں بے شک اللہ تعالیٰ پورے علم اور کامل حکمتوں واﻻ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dv{تمہاری بیویاں جو کچھ چھوڑ مریں اور ان کی اوﻻد نہ ہو تو آدھوں آدھ تمہارا ہے اور اگر ان کی اوﻻد ہو تو ان کے چھوڑے ہوئے مال میں سے تمہارے لئے چوتھائی حصہ ہے۔ اس وصیت کی ادائیگی کے بعد جو وه کر گئی ہوں یا قرض کے بعد۔ اور جو (ترکہ) تم چھوڑ جاؤ اس میں ان کے لئے چوتھائی ہے، اگر تمہاری اوﻻد نہ ہو اور اگر تمہاری اوﻻد ہو تو پھر انہیں تمہارے ترکہ کا آٹھواں حصہ ملے گا، اس وصیت کے بعد جو تم کر گئے ہو اور قرض کی ادائیگی کے بعد۔ اور جن کی میراث لی جاتی ہے وه مرد یا عورت کلالہ ہو یعنی اس کا باپ بیٹا نہ ہو۔ اور اس کا ایک بھائی یا ایک بہن ہو تو ان دونوں میں سے ہر ایک کا چھٹا حصہ ہے اور اس سے زیاده ہوں تو ایک تہائی میں سب شریک ہیں، اس وصیت کے بعد جو کی جائے اور قرض کے بعد جب کہ اوروں کا نقصان نہ کیا گیا ہو یہ مقرر کیا ہوا اللہ تعالیٰ کی طرف سے ہے اور اللہ تعالیٰ دانا ہے بردبار\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dvi{یہ حدیں اللہ تعالیٰ کی مقرر کی ہوئی ہیں اور جو اللہ تعالیٰ کی اور اس کے رسول اللہ ﴿صلی اللہ علیہ وسلم﴾ کی فرمانبرداری کرے گا اسے اللہ تعالیٰ جنتوں میں لے جائے گا جن کے نیچے نہریں بہہ رہی ہیں جن میں وه ہمیشہ رہیں گے اور یہ بہت بڑی کامیابی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dvii{اور جو شخص اللہ تعالیٰ کی اور اس کے رسول اللہ ﴿صلی اللہ علیہ وسلم﴾ کی نافرمانی کرے اور اس کی مقرره حدوں سے آگے نکلے اسے وه جہنم میں ڈال دے گا جس میں وه ہمیشہ رہے گا، ایسوں ہی کے لئے رسوا کن عذاب ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dviii{تمہاری عورتوں میں سے جو بے حیائی کا کام کریں ان پر اپنے میں سے چار گواه طلب کرو، اگر وه گواہی دیں تو ان عورتوں کو گھروں میں قید رکھو، یہاں تک کہ موت ان کی عمریں پوری کردے، یا اللہ تعالیٰ ان کے لئے کوئی اور راستہ نکالے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dix{تم میں سے جو دو افراد ایسا کام کر لیں انہیں ایذا دو اگر وه توبہ اور اصلاح کر لیں تو ان سے منھ پھیر لو، بے شک اللہ تعالیٰ توبہ قبول کرنے واﻻ اور رحم کرنے واﻻ ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dx{اللہ تعالیٰ صرف انہی لوگوں کی توبہ قبول فرماتا ہے جو بوجہ نادانی کوئی برائی کر گزریں پھر جلد اس سے باز آ جائیں اور توبہ کریں تو اللہ تعالیٰ بھی ان کی توبہ قبول کرتا ہے، اللہ تعالیٰ بڑے علم واﻻ حکمت واﻻ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dxi{ان کی توبہ نہیں جو برائیاں کرتے چلے جائیں یہاں تک کہ جب ان میں سے کسی کے پاس موت آجائے تو کہہ دے کہ میں نے اب توبہ کی، اور ان کی توبہ بھی قبول نہیں جو کفر پر ہی مر جائیں، یہی لوگ ہیں جن کے لئے ہم نے المناک عذاب تیار کر رکھا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dxii{ایمان والو! تمہیں حلال نہیں کہ زبردستی عورتوں کو ورﺛے میں لے بیٹھو انہیں اس لئے روک نہ رکھو کہ جو تم نے انہیں دے رکھا ہے، اس میں سے کچھ لے لو ہاں یہ اور بات ہے کہ وه کوئی کھلی برائی اور بے حیائی کریں ان کے ساتھ اچھے طریقے سے بودوباش رکھو، گو تم انہیں ناپسند کرو لیکن بہت ممکن ہے کہ تم کسی چیز کو برا جانو، اور اللہ تعالیٰ اس میں بہت ہی بھلائی کر دے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dxiii{اور اگر تم ایک بیوی کی جگہ دوسری بیوی کرنا ہی چاہو اور ان میں سے کسی کو تم نے خزانہ کا خزانہ دے رکھا ہو، تو بھی اس میں سے کچھ نہ لو کیا تم اسے ناحق اور کھلا گناه ہوتے ہوئے بھی لے لو گے، تم اسے کیسے لے لو گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dxiv{حاﻻنکہ تم ایک دوسرے سے مل چکے ہو اور ان عورتوں نے تم سے مضبوط عہد وپیمان لے رکھا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dxv{اور ان عورتوں سے نکاح نہ کرو جن سے تمہارے باپوں نے نکاح کیا ہے مگر جو گزر چکا ہے، یہ بے حیائی کا کام اور بغض کا سبب ہے اور بڑی بری راه ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dxvi{حرام کی گئیں تم پر تمہاری مائیں اور تمہاری لڑکیاں اور تمہاری بہنیں، تمہاری پھوپھیاں اور تمہاری خاﻻئیں اور بھائی کی لڑکیاں اور بہن کی لڑکیاں اور تمہاری وه مائیں جنہوں نے تمہیں دودھ پلایا ہو اور تمہاری دودھ شریک بہنیں اور تمہاری ساس اور تمہاری وه پرورش کرده لڑکیاں جو تمہاری گود میں ہیں، تمہاری ان عورتوں سے جن سے تم دخول کر چکے ہو، ہاں اگر تم نے ان سے جماع نہ کیا ہو تو تم پر کوئی گناه نہیں اور تمہارے صلبی سگے بیٹوں کی بیویاں اور تمہارا دو بہنوں کا جمع کرنا ہاں جو گزر چکا سو گزر چکا، یقیناً اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dxvii{اور (حرام کی گئیں) شوہر والی عورتیں مگر وه جو تمہاری ملکیت میں آجائیں، اللہ تعالیٰ نے یہ احکام تم پر فرض کر دیئے ہیں، اور ان عورتوں کے سوا اور عورتیں تمہارے لئے حلال کی گئیں کہ اپنے مال کے مہر سے تم ان سے نکاح کرنا چاہو برے کام سے بچنے کے لئے نہ کہ شہوت رانی کرنے کے لئے، اس لئے جن سے تم فائده اٹھاؤ انہیں ان کا مقرر کیا ہوا مہر دے دو، اور مہر مقرر ہو جانے کے بعد تم آپس کی رضامندی سے جو طے کرلو اس میں تم پر کوئی گناه نہیں، بے شک اللہ تعالیٰ علم واﻻ حکمت واﻻ ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dxviii{اور تم میں سے جس کسی کو آزاد مسلمان عورتوں سے نکاح کرنے کی پوری وسعت وطاقت نہ ہو تو وه مسلمان لونڈیوں سے جن کے تم مالک ہو (اپنا نکاح کر لے) اللہ تمہارے اعمال کو بخوبی جاننے واﻻ ہے، تم سب آپس میں ایک ہی تو ہو، اس لئے ان کے مالکوں کی اجازت سے ان سے نکاح کر لو، اور قاعده کے مطالق ان کے مہر ان کو دو، وه پاک دامن ہوں نہ کہ علانیہ بدکاری کرنے والیاں، نہ خفیہ آشنائی کرنے والیاں، پس جب یہ لونڈیاں نکاح میں آجائیں پھر اگر وه بے حیائی کا کام کریں تو انہیں آدھی سزا ہے اس سزا سے جو آزاد عورتوں کی ہے۔ کنیزوں سے نکاح کا یہ حکم تم میں سے ان لوگوں کے لئے ہے جنہیں گناه اور تکلیف کا اندیشہ ہو اور تمہارا ضبط کرنا بہت بہتر ہے اور اللہ تعالیٰ بڑا بخشنے واﻻ اور بڑی رحمت واﻻ ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dxix{اللہ تعالیٰ چاہتا ہے کہ تمہارے واسطے خوب کھول کر بیان کرے اور تمہیں تم سے پہلے کے (نیک) لوگوں کی راه پر چلائے اور تمہاری توبہ قبول کرے، اور اللہ تعالیٰ جاننے واﻻ حکمت واﻻ ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dxx{اور اللہ چاہتا ہے کہ تمہاری توبہ قبول کرے اور جو لوگ خواہشات کے پیرو ہیں وه چاہتے ہیں کہ تم اس سے بہت دور ہٹ جاؤ\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dxxi{اللہ چاہتا ہے کہ تم سے تخفیف کر دے کیونکہ انسان کمزور پیدا کیا گیا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dxxii{اے ایمان والو! اپنے آپس کے مال ناجائز طریقہ سے مت کھاؤ، مگر یہ کہ تمہاری آپس کی رضا مندی سے ہو خرید وفروخت، اور اپنے آپ کو قتل نہ کرو یقیناً اللہ تعالیٰ تم پر نہایت مہربان ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dxxiii{اور جو شخص یہ (نافرمانیاں) سرکشی اور ﻇلم سے کرے گا تو عنقریب ہم اس کو آگ میں داخل کریں گے اور یہ اللہ پرآسان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dxxiv{اگر تم ان بڑے گناہوں سے بچتے رہوگے جن سے تم کو منع کیا جاتا ہے تو ہم تمہارے چھوٹے گناه دور کر دیں گے اور عزت وبزرگی کی جگہ داخل کریں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dxxv{اوراس چیز کی آرزو نہ کرو جس کے باعﺚ اللہ تعالیٰ نے تم میں سے بعض کو بعض پر بزرگی دی ہے، مردوں کا اس میں سے حصہ ہے جو انہوں نے کمایا اور عورتوں کے لئے ان میں سے حصہ ہے جو انہوں نے کمایا، اور اللہ تعالیٰ سے اس کا فضل مانگو، یقیناً اللہ ہر چیز کا جاننے واﻻ ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dxxvi{ماں باپ یا قرابت دار جو چھوڑ مریں اس کے وارث ہم نے ہر شخص کے مقرر کر دیئے ہیں اور جن سے تم نے اپنے ہاتھوں معاہده کیا ہے انہیں ان کا حصہ دو حقیقتاً اللہ تعالیٰ ہر چیز پر حاضر ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dxxvii{مرد عورتوں پر حاکم ہیں اس وجہ سے کہ اللہ تعالیٰ نے ایک کو دوسرے پر فضیلت دی ہے اور اس وجہ سے کہ مردوں نے اپنے مال خرچ کئے ہیں، پس نیک فرمانبردار عورتین خاوند کی عدم موجودگی میں بہ حفاﻇت الٰہی نگہداشت رکھنے والیاں ہیں اور جن عورتوں کی نافرمانی اور بددماغی کا تمہیں خوف ہو انہیں نصیحت کرو اور انہیں الگ بستروں پر چھوڑ دو اور انہیں مار کی سزا دو پھر اگر وه تابعداری کریں تو ان پر کوئی راستہ تلاش نہ کرو، بے شک اللہ تعالیٰ بڑی بلندی اور بڑائی واﻻ ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dxxviii{اگر تمہیں میاں بیوی کے درمیان آپس کی ان بن کا خوف ہو تو ایک منصف مرد والوں میں سے اور ایک عورت کے گھر والوں میں سے مقرر کرو، اگر یہ دونوں صلح کرانا چاہیں گے تو اللہ دونوں میں ملاپ کرا دے گا، یقیناً اللہ تعالیٰ پورے علم واﻻ پوری خبر واﻻ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dxxix{اور اللہ تعالیٰ کی عبادت کرو اور اس کے ساتھ کسی کو شریک نہ کرو اور ماں باپ کے ساتھ سلوک واحسان کرو اور رشتہ داروں سے اور یتیموں سے اور مسکینوں سے اور قرابت دار ہمسایہ سے اور اجنبی ہمسایہ سے اور پہلو کے ساتھی سے اور راه کے مسافر سے اور ان سے جن کے مالک تمہارے ہاتھ ہیں، (غلام کنیز) یقیناً اللہ تعالیٰ تکبر کرنے والوں اور شیخی خوروں کو پسند نہیں فرماتا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dxxx{جو لوگ خود بخیلی کرتے ہیں اور دوسروں کو بھی بخیلی کرنے کو کہتے ہیں اور اللہ تعالیٰ نے جو اپنا فضل انہیں دے رکھا ہے اسے چھپا لیتے ہیں ہم نے ان کافروں کے لئے ذلت کی مار تیار کر رکھی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dxxxi{اور جو لوگ اپنا مال لوگوں کے دکھاوے کے لئے خرچ کرتے ہیں اور اللہ تعالیٰ پر اور قیامت کے دن پر ایمان نہیں رکھتے اور جس کا ہم نشین اور ساتھی شیطان ہو، وه بدترین ساتھی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dxxxii{بھلا ان کا کیا نقصان تھا اگر یہ اللہ تعالیٰ پر اور قیامت کے دن پر ایمان ﻻتے اور اللہ تعالیٰ نے جو انہیں دے رکھا ہے اس میں خرچ کرتے، اللہ تعالیٰ انہیں خوب جاننے واﻻ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dxxxiii{بے شک اللہ تعالیٰ ایک ذره برابر ﻇلم نہیں کرتا اور اگر نیکی ہو تو اسے دوگنی کر دیتا ہے اور خاص اپنے پاس سے بہت بڑا ﺛواب دیتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dxxxiv{پس کیا حال ہوگا جس وقت کہ ہر امت میں سے ایک گواه ہم ﻻئیں گے اور آپ کو ان لوگوں پر گواه بناکر ﻻئیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dxxxv{جس روز کافر اور رسول کے نافرمان آرزو کریں گے کہ کاش! انہیں زمین کے ساتھ ہموار کر دیا جاتا اور اللہ تعالیٰ سے کوئی بات نہ چھپا سکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dxxxvi{اے ایمان والو! جب تم نشے میں مست ہو نماز کے قریب بھی نہ جاؤ، جب تک کہ اپنی بات کو سمجھنے نہ لگو اور جنابت کی حالت میں جب تک کہ غسل نہ کر لو، ہاں اگر راه چلتے گزر جانے والے ہو تو اور بات ہے اور اگر تم بیمار ہو یا سفر میں ہو یا تم میں سے کوئی قضائے حاجت سے آیا ہو یا تم نے عورتوں سے مباشرت کی ہو اور تمہیں پانی نہ ملے تو پاک مٹی کا قصد کرو اور اپنے منھ اور اپنے ہاتھ مل لو۔ بے شک اللہ تعالیٰ معاف کرنے واﻻ، بخشنے واﻻ ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dxxxvii{کیا تم نے انہیں نہیں دیکھا؟ جنہیں کتاب کا کچھ حصہ دیا گیا ہے، وه گمراہی خریدتے ہیں اور چاہتے ہیں کہ تم بھی راه سے بھٹک جاؤ\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dxxxviii{اللہ تعالیٰ تمہارے دشمنوں کو خوب جاننے واﻻ ہے اور اللہ تعالیٰ کا دوست ہونا کافی ہے اور اللہ تعالیٰ کا مددگار ہونا بس ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dxxxix{بعض یہود کلمات کو ان کی ٹھیک جگہ سے ہیر پھیر کر دیتے ہیں اور کہتے ہیں کہ ہم نے سنا اور نافرمانی کی اور سن اس کے بغیر کہ تو سنا جائے اور ہماری رعایت کر! (لیکن اس کے کہنے میں) اپنی زبان کو پیچ دیتے ہیں اور دین میں طعنہ دیتے ہیں اور اگر یہ لوگ کہتے کہ ہم نے سنا اور ہم نے فرمانبرداری کی اور آپ سنئےاور ہمیں دیکھیئے تو یہ ان کے لئے بہت بہتر اور نہایت ہی مناسب تھا، لیکن اللہ تعالیٰ نے ان کے کفر کی وجہ سے انہیں لعنت کی ہے۔ پس یہ بہت ہی کم ایمان ﻻتے ہیں،\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dxl{اے اہل کتاب! جو کچھ ہم نے نازل فرمایا ہے جو اس کی بھی تصدیق کرنے واﻻ ہے جو تمہارے پاس ہے، اس پر ایمان لاؤ اس سے پہلے کہ ہم چہرے بگاڑ دیں اور انہیں لوٹا کر پیٹھ کی طرف کر دیں، یا ان پر لعنت بھیجیں جیسے ہم نے ہفتے کے دن والوں پر لعنت کی ہے، اور اللہ تعالیٰ کا کام کیا گیا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dxli{یقیناً اللہ تعالیٰ اپنے ساتھ شریک کئے جانے کو نہیں بخشتا اور اس کے سوا جسے چاہے بخش دیتا ہے اور جو اللہ تعالیٰ کے ساتھ شریک مقرر کرے اس نے بہت بڑا گناه اور بہتان باندھا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dxlii{کیا آپ نے انہیں نہیں دیکھا جو اپنی پاکیزگی اور ستائش خود کرتے ہیں؟ بلکہ اللہ تعالیٰ جسے چاہے پاکیزه کرتا ہے، کسی پر ایک دھاگے کے برابر ﻇلم نہ کیا جائے گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dxliii{دیکھو یہ لوگ اللہ تعالیٰ پر کس طرح جھوٹ باندھتے ہیں اور یہ (حرکت) صریح گناه ہونے کے لئے کافی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dxliv{کیا آپ نے انہیں نہیں دیکھا جنہیں کتاب کا کچھ حصہ ملا؟ جو بت کا اور باطل معبود کا اعتقاد رکھتے ہیں اور کافروں کے حق میں کہتے ہیں کہ یہ لوگ ایمان والوں سے زیاده راه راست پر ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dxlv{یہی وه لوگ ہیں جنہیں اللہ تعالیٰ نے لعنت کی ہے اور جسے اللہ تعالیٰ لعنت کر دے، تو اس کا کوئی مددگار نہ پائے گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dxlvi{کیا ان کا کوئی حصہ سلطنت میں ہے؟ اگر ایسا ہو تو پھر یہ کسی کو ایک کھجور کی گٹھلی کے شگاف کے برابر بھی کچھ نہ دیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dxlvii{یا یہ لوگوں سے حسد کرتے ہیں اس پر جو اللہ تعالیٰ نے اپنے فضل سے انہیں دیا ہے، پس ہم نے تو آل ابراہیم کو کتاب اور حکمت بھی دی ہے اور بڑی سلطنت بھی عطا فرمائی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dxlviii{پھر ان میں سے بعض نے تو اس کتاب کو مانا اور بعض اس سے رک گئے، اور جہنم کا جلانا کافی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dxlix{جن لوگوں نے ہماری آیتوں سے کفر کیا، انہیں ہم یقیناً آگ میں ڈال دیں گے جب ان کی کھالیں پک جائیں گی ہم ان کے سوا اور کھالیں بدل دیں گے تاکہ وه عذاب چکھتے رہیں، یقیناً اللہ تعالیٰ غالب حکمت واﻻ ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dl{اور جو لوگ ایمان ﻻئے اور شائستہ اعمال کئے ہم عنقریب انہیں ان جنتوں میں لے جائیں گے جن کے نیچے نہریں بہہ رہی ہیں، جن میں وه ہمیشہ ہمیشہ رہیں گے، ان کے لئے وہاں صاف ستھری بیویاں ہوں گی اور ہم انہیں گھنی چھاؤں (اور پوری راحت) میں لے جائیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dli{اللہ تعالیٰ تمہیں تاکیدی حکم دیتا ہے کہ امانت والوں کی امانتیں انہیں پہنچاؤ! اور جب لوگوں کا فیصلہ کرو تو عدل وانصاف سے فیصلہ کرو! یقیناً وه بہتر چیز ہے جس کی نصیحت تمہیں اللہ تعالیٰ کر رہا ہے۔ بے شک اللہ تعالیٰ سنتا ہے، دیکھتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dlii{اے ایمان والو! فرمانبرداری کرو اللہ تعالیٰ کی اور فرمانبرداری کرو رسول (صلی اللہ علیہ وسلم) کی اور تم میں سے اختیار والوں کی۔ پھر اگر کسی چیز میں اختلاف کرو تو اسے لوٹاؤ، اللہ تعالیٰ کی طرف اور رسول کی طرف، اگر تمہیں اللہ تعالیٰ پر اور قیامت کے دن پر ایمان ہے۔ یہ بہت بہتر ہے اور باعتبار انجام کے بہت اچھا ہے۔\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dliii{کیا آپ نے انہیں نہیں دیکھا؟ جن کا دعویٰ تو یہ ہے کہ جو کچھ آپ پر اور جو کچھ آپ سے پہلے اتارا گیا ہے اس پر ان کا ایمان ہے، لیکن وه اپنے فیصلے غیر اللہ کی طرف لے جانا چاہتے ہیں حاﻻنکہ انہین حکم دیا گیا ہے کہ شیطان کا انکار کریں، شیطان تو یہ چاہتا ہے کہ انہیں بہکا کر دور ڈال دے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dliv{ان سے جب کبھی کہا جائے کہ اللہ تعالیٰ کے نازل کرده کلام کی اور رسول (صلی اللہ علیہ وسلم) کی طرف آؤ تو آپ دیکھ لیں گے کہ یہ منافق آپ سے منھ پھیر کر رکے جاتے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dlv{پھر کیا بات ہے کہ جب ان پر ان کے کرتوت کے باعﺚ کوئی مصیبت آپڑتی ہے تو پھر یہ آپ کے پاس آکر اللہ تعالیٰ کی قسمیں کھاتے ہیں کہ ہمارا اراده تو صرف بھلائی اور میل ملاپ ہی کا تھا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dlvi{یہ وه لوگ ہیں کہ ان کے دلوں کا بھید اللہ تعالیٰ پر بخوبی روشن ہے، آپ ان سے چشم پوشی کیجئے، انہیں نصیحت کرتے رہیئے اور انہیں وه بات کہئے! جو ان کے دلوں میں گھر کرنے والی ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dlvii{ہم نے ہر ہر رسول کو صرف اسی لئے بھیجا کہ اللہ تعالیٰ کے حکم سے اس کی فرمانبرداری کی جائے اور اگر یہ لوگ جب انہوں نے اپنی جانوں پر ﻇلم کیا تھا، تیرے پاس آ جاتے اور اللہ تعالیٰ سے استغفار کرتے اور رسول بھی ان کے لئے استغفار کرتے، تو یقیناً یہ لوگ اللہ تعالیٰ کو معاف کرنے واﻻ مہربان پاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dlviii{سو قسم ہے تیرے پروردگار کی! یہ مومن نہیں ہو سکتے، جب تک کہ تمام آپس کے اختلاف میں آپ کو حاکم نہ مان لیں، پھر جو فیصلے آپ ان میں کر دیں ان سے اپنے دل میں اور کسی طرح کی تنگی اور ناخوشی نہ پائیں اور فرمانبرداری کے ساتھ قبول کر لیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dlix{اور اگر ہم ان پر یہ فرض کر دیتے کہ اپنی جانوں کو قتل کر ڈالو! یا اپنے گھروں سے نکل جاؤ! تو اسے ان میں سے بہت ہی کم لوگ بجا ﻻتے اور اگر یہ وہی کریں جس کی انہیں نصیحت کی جاتی ہے تو یقیناً یہی ان کے لئے بہتر اور بہت زیاده مضبوطی واﻻ ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dlx{اور تب تو انہیں ہم اپنے پاس سے بڑا ﺛواب دیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dlxi{اور یقیناً انہیں راه راست دکھا دیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dlxii{اور جو بھی اللہ تعالیٰ کی اور رسول (صلی اللہ علیہ وسلم) کی فرمانبرداری کرے، وه ان لوگوں کے ساتھ ہوگا جن پر اللہ تعالیٰ نے انعام کیا ہے، جیسے نبی اور صدیق اور شہید اور نیک لوگ، یہ بہترین رفیق ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dlxiii{یہ فضل اللہ تعالیٰ کی طرف سے ہے اور کافی ہے اللہ تعالیٰ جاننے واﻻ ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dlxiv{اے مسلمانو! اپنے بچاؤ کا سامان لے لو پھر گروه گروه بن کر کوچ کرو یا سب کے سب اکٹھے ہو کر نکل کھڑے ہو!\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dlxv{اور یقیناً تم میں بعض وه بھی ہیں جو پس وپیش کرتے ہیں، پھر اگر تمہیں کوئی نقصان ہوتا ہے تو وه کہتے ہیں کہ اللہ تعالیٰ نے مجھ پر بڑا فضل کیا کہ میں ان کے ساتھ موجود نہ تھا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dlxvi{اور اگر تمہیں اللہ تعالیٰ کا کوئی فضل مل جائے تو اس طرح کہ گویا تم میں ان میں دوستی تھی ہی نہیں، کہتے ہیں کاش! میں بھی ان کے ہمراه ہوتا تو بڑی کامیابی کو پہنچتا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dlxvii{پس جو لوگ دنیا کی زندگی کو آخرت کے بدلے بیچ چکے ہیں، انہیں اللہ تعالیٰ کی راه میں جہاد کرنا چاہئے اور جو شخص اللہ تعالیٰ کی راه میں جہاد کرتے ہوئے شہادت پا لے یا غالب آجائے، یقیناً ہم اسے بہت بڑا ﺛواب عنایت فرمائیں گے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dlxviii{بھلا کیا وجہ ہے کہ تم اللہ کی راه میں اور ان ناتواں مردوں، عورتوں اور ننھے ننھے بچوں کے چھٹکارے کے لئے جہاد نہ کرو؟ جو یوں دعائیں مانگ رہے ہیں کہ اے ہمارے پروردگار! ان ﻇالموں کی بستی سے ہمیں نجات دے اور ہمارے لئے خود اپنے پاس سے حمایتی مقرر کر دے اور ہمارے لئے خاص اپنے پاس سے مددگار بنا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dlxix{جو لوگ ایمان ﻻئے ہیں وه تو اللہ تعالیٰ کی راه میں جہاد کرتے ہیں اور جن لوگوں نے کفر کیا ہے، وه اللہ تعالیٰ کے سوا اوروں کی راه میں لڑتے ہیں پس تم شیطان کے دوستوں سے جنگ کرو! یقین مانو کہ شیطانی حیلہ (بالکل بودا اور) سخت کمزور ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dlxx{کیا تم نے انہیں نہیں دیکھا جنہیں حکم کیا گیا تھا کہ اپنے ہاتھوں کو روکے رکھو اور نمازیں پڑھتے رہو اور زکوٰة ادا کرتے رہو۔ پھر جب انہیں جہاد کا حکم دیا گیا تو اسی وقت ان کی ایک جماعت لوگوں سے اس قدر ڈرنے لگی جیسے اللہ تعالیٰ کا ڈر ہو، بلکہ اس سے بھی زیاده، اور کہنے لگے اے ہمارے رب! تو نے ہم پر جہاد کیوں فرض کر دیا؟ کیوں ہمیں تھوڑی سی زندگی اور نہ جینے دی؟ آپ کہہ دیجئے کہ دنیا کی سودمندی تو بہت ہی کم ہے اور پرہیزگاروں کے لئے تو آخرت ہی بہتر ہے اور تم پر ایک دھاگے کے برابر بھی ستم روا نہ رکھا جائے گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dlxxi{تم جہاں کہیں بھی ہو موت تمہیں آپکڑے گی، گو تم مضبوط قلعوں میں ہو، اور اگر انہیں کوئی بھلائی ملتی ہے تو کہتے ہیں کہ یہ اللہ تعالیٰ کی طرف سے ہے اور اگر کوئی برائی پہنچتی ہے تو کہہ اٹھتے ہیں کہ یہ تیری طرف سے ہے۔ انہیں کہہ دو کہ یہ سب کچھ اللہ تعالیٰ کی طرف سے ہے۔ انہیں کیا ہوگیا ہے کہ کوئی بات سمجھنے کے بھی قریب نہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dlxxii{تجھے جو بھلائی ملتی ہے وه اللہ تعالیٰ کی طرف سے ہے اور جو برائی پہنچتی ہے وه تیرے اپنے نفس کی طرف سے ہے، ہم نے تجھے تمام لوگوں کو پیغام پہنچانے واﻻ بنا کر بھیجا ہے اور اللہ تعالیٰ گواه کافی ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dlxxiii{اس رسول (صلی اللہ علیہ وسلم) کی جو اطاعت کرے اسی نے اللہ تعالیٰ کی فرمانبرداری کی اور جو منھ پھیر لے تو ہم نے آپ کو کچھ ان پر نگہبان بنا کر نہیں بھیجا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dlxxiv{یہ کہتے تو ہیں کہ اطاعت ہے، پھر جب آپ کے پاس سے اٹھ کر باہر نکلتے ہیں تو ان میں کی ایک جماعت، جو بات آپ نے یا اس نے کہی ہے اس کے خلاف راتوں کو مشورے کرتی ہے، ان کی راتوں کی بات چیت اللہ لکھ رہا ہے، تو آپ ان سے منھ پھیر لیں اور اللہ پر بھروسہ رکھیں، اللہ تعالیٰ کافی کارساز ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dlxxv{کیا یہ لوگ قرآن میں غور نہیں کرتے؟ اگر یہ اللہ تعالیٰ کے سوا کسی اور کی طرف سے ہوتا تو یقیناً اس میں بہت کچھ اختلاف پاتے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dlxxvi{جہاں انہیں کوئی خبر امن کی یا خوف کی ملی انہوں نے اسے مشہور کرنا شروع کر دیا، حاﻻنکہ اگر یہ لوگ اسے رسول (صلی اللہ علیہ وسلم) کے اور اپنے میں سے ایسی باتوں کی تہہ تک پہنچنے والوں کے حوالے کر دیتے، تو اس کی حقیقت وه لوگ معلوم کر لیتے جو نتیجہ اخذ کرتے ہیں اور اگر اللہ تعالیٰ کا فضل اور اس کی رحمت تم پر نہ ہوتی تو معدودے چند کے علاوه تم سب شیطان کے پیروکار بن جاتے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dlxxvii{تو اللہ تعالیٰ کی راه میں جہاد کرتا ره، تجھے صرف تیری ذات کی نسبت حکم دیا جاتا ہے، ہاں ایمان والوں کو رغبت دﻻتا ره، بہت ممکن ہے کہ اللہ تعالیٰ کافروں کی جنگ کو روک دے اور اللہ تعالیٰ سخت قوت واﻻ ہے اور سزادینے میں بھی سخت ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dlxxviii{جو شخص کسی نیکی یا بھلے کام کی سفارش کرے، اسے بھی اس کا کچھ حصہ ملے گا اور جو برائی اور بدی کی سفارش کرے اس کے لئے بھی اس میں سے ایک حصہ ہے، اور اللہ تعالیٰ ہر چیز پر قدرت رکھنے واﻻ ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dlxxix{اور جب تمہیں سلام کیا جائے تو تم اس سے اچھا جواب دو یا انہی الفاظ کو لوٹا دو، بے شبہ اللہ تعالیٰ ہر چیز کا حساب لینے واﻻ ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dlxxx{اللہ وه ہے جس کے سوا کوئی معبود (برحق) نہیں وه تم سب کو یقیناً قیامت کے دن جمع کرے گا، جس کے (آنے) میں کوئی شک نہیں، اللہ تعالیٰ سے زیاده سچی بات واﻻ اور کون ہوگا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dlxxxi{تمہیں کیا ہوگیا ہے؟ کہ منافقوں کے بارے میں دو گروه ہو رہے ہو؟ انہیں تو ان کے اعمال کی وجہ سے اللہ تعالیٰ نے اوندھا کر دیا ہے۔ اب کیا تم یہ منصوبے باندھ رہے ہو کہ اللہ تعالیٰ کے گمراه کئے ہوؤں کو تم راه راست پر ﻻکھڑا کرو، جسے اللہ تعالیٰ راه بھلا دے تو ہرگز اس کے لئے کوئی راه نہ پائے گا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dlxxxii{ان کی تو چاہت ہے کہ جس طرح کے کافر وه ہیں تو بھی ان کی طرح کفر کرنے لگو اور پھر سب یکساں ہو جاؤ، پس جب تک یہ اسلام کی خاطر وطن نہ چھوڑیں ان میں سے کسی کو حقیقی دوست نہ بناؤ، پھر اگر یہ منھ پھیر لیں تو انہیں پکڑو اور قتل کرو جہاں بھی یہ ہاتھ لگ جائیں، خبردار! ان میں سے کسی کو اپنا رفیق اور مددگار نہ سمجھ بیٹھنا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dlxxxiii{سوائے ان کے جو اس قوم سے تعلق رکھتے ہوں جن سے تمہارا معاہده ہو چکا ہے یا جو تمہارے پاس اس حالت میں آئیں کہ تم سے جنگ کرنے سے بھی تنگ دل ہیں اور اپنی قوم سے بھی جنگ کرنے سے تنگ دل ہیں اور اگر اللہ تعالیٰ چاہتا تو انہیں تم پر مسلط کر دیتا اور وه تم سے یقیناً جنگ کرتے، پس اگر یہ لوگ تم سے کناره کشی اختیار کر لیں اور تم سے لڑائی نہ کریں اور تمہاری جانب صلح کا پیغام ڈالیں، تو اللہ تعالیٰ نے تمہارے لئے ان پر کوئی راه لڑائی کی نہیں کی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dlxxxiv{تم کچھ اور لوگوں کو ایسا بھی پاؤ گے جن کی (بظاہر) چاہت ہے کہ تم سے بھی امن میں رہیں۔ اور اپنی قوم سے بھی امن میں رہیں (لیکن) جب کبھی فتنہ انگیزی کی طرف لوٹائے جاتے ہیں تو اوندھے منھ اس میں ڈال دیئے جاتے ہیں، پس اگر یہ لوگ تم سے کناره کشی نہ کریں اور تم سے صلح کا سلسلہ جنبانی نہ کریں اور اپنے ہاتھ نہ روک لیں، تو انہیں پکڑو اور مار ڈالو جہاں کہیں بھی پالو! یہی وه ہیں جن پر ہم نے تمہیں ﻇاہر حجت عنایت فرمائی ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dlxxxv{کسی مومن کو دوسرے مومن کا قتل کر دینا زیبا نہیں مگر غلطی سے ہو جائے (تو اور بات ہے)، جو شخص کسی مسلمان کو بلا قصد مار ڈالے، اس پر ایک مسلمان غلام کی گردن آزاد کرنا اور مقتول کے عزیزوں کو خون بہا پہنچانا ہے۔ ہاں یہ اور بات ہے کہ وه لوگ بطور صدقہ معاف کر دیں اور اگر مقتول تمہاری دشمن قوم کا ہو اور ہو وه مسلمان، تو صرف ایک مومن غلام کی گردن آزاد کرنی ﻻزمی ہے۔ اور اگر مقتول اس قوم سے ہو کہ تم میں اور ان میں عہد و پیماں ہے تو خون بہا ﻻزم ہے، جو اس کے کنبے والوں کو پہنچایا جائے اور ایک مسلمان غلام کا آزاد کرنا بھی (ضروری ہے)، پس جو نہ پائے اس کے ذمے دو مہینے کے لگاتار روزے ہیں، اللہ تعالیٰ سے بخشوانے کے لئےاور اللہ تعالیٰ بخوبی جاننے واﻻ اور حکمت واﻻ ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dlxxxvi{اور جو کوئی کسی مومن کو قصداً قتل کر ڈالے، اس کی سزا دوزخ ہے جس میں وه ہمیشہ رہے گا، اس پر اللہ تعالیٰ کا غضب ہے، اسے اللہ تعالیٰ نے لعنت کی ہے اور اس کے لئے بڑا عذاب تیار رکھا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dlxxxvii{اے ایمان والو! جب تم اللہ کی راه میں جا رہے ہو تو تحقیق کر لیا کرو اور جو تم سے سلام علیک کرے تو اسے یہ نہ کہہ دو کہ تو ایمان واﻻ نہیں۔ تم دنیاوی زندگی کے اسباب کی تلاش میں ہو تو اللہ تعالیٰ کے پاس بہت سی غنیمتیں ہیں۔ پہلے تم بھی ایسے ہی تھے، پھر اللہ تعالیٰ نے تم پر احسان کیا لہٰذا تم ضرور تحقیق وتفتیش کر لیا کرو، بے شک اللہ تعالیٰ تمہارے اعمال سے باخبر ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dlxxxviii{اپنی جانوں اور مالوں سے اللہ کی راه میں جہاد کرنے والے مومن اور بغیر عذر کے بیٹھ رہنے والے مومن برابر نہیں، اپنے مالوں اور اپنی جانوں سے جہاد کرنے والوں کو بیٹھ رہنے والوں پر اللہ تعالیٰ نے درجوں میں بہت فضیلت دے رکھی ہے اور یوں تو اللہ تعالیٰ نے ہر ایک کو خوبی اور اچھائی کا وعده دیا ہے لیکن مجاہدین کو بیٹھ رہنے والوں پر بہت بڑے اجر کی فضیلت دے رکھی ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dlxxxix{اپنی طرف سے مرتبے کی بھی اور بخشش کی بھی اور رحمت کی بھی اور اللہ تعالیٰ بخشش کرنے واﻻ اور رحم کرنے واﻻ ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dxc{جو لوگ اپنی جانوں پر ﻇلم کرنے والے ہیں جب فرشتے ان کی روح قبض کرتے ہیں تو پوچھتے ہیں، تم کس حال میں تھے؟ یہ جواب دیتے ہیں کہ ہم اپنی جگہ کمزور اور مغلوب تھے۔ فرشتے کہتے ہیں کیا اللہ تعالیٰ کی زمین کشاده نہ تھی کہ تم ہجرت کر جاتے؟ یہی لوگ ہیں جن کا ٹھکانا دوزخ ہے اور وه پہنچنے کی بری جگہ ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dxci{مگر جو مرد عورتیں اور بچے بے بس ہیں جنہیں نہ تو کسی چارہٴ کار کی طاقت اور نہ کسی راستے کا علم ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dxcii{بہت ممکن ہے کہ اللہ تعالیٰ ان سے درگزر کرے، اللہ تعالیٰ درگزر کرنے واﻻ اور معاف فرمانے واﻻ ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dxciii{جو کوئی اللہ کی راه میں وطن کو چھوڑے گا، وه زمین میں بہت سی قیام کی جگہیں بھی پائے گا اور کشادگی بھی، اور جو کوئی اپنے گھر سے اللہ تعالیٰ اور اس کے رسول (صلی اللہ علیہ وسلم) کی طرف نکل کھڑا ہوا، پھر اسے موت نے آ پکڑا تو بھی یقیناً اس کا اجر اللہ تعالیٰ کے ذمہ ﺛابت ہو گیا، اور اللہ تعالیٰ بڑا بخشنے واﻻ مہربان ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dxciv{جب تم سفر میں جا رہے ہو تو تم پر نمازوں کے قصر کرنے میں کوئی گناه نہیں، اگر تمہیں ڈر ہو کہ کافر تمہیں ستائیں گے، یقیناً کافر تمہارے کھلے دشمن ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dxcv{جب تم ان میں ہو اور ان کے لئے نماز کھڑی کرو تو چاہئے کہ ان کی ایک جماعت تمہارے ساتھ اپنے ہتھیار لئے کھڑی ہو، پھر جب یہ سجده کر چکیں تو یہ ہٹ کر تمہارے پیچھے آجائیں اور وه دوسری جماعت جس نے نماز نہیں پڑھی وه آجائے اور تیرے ساتھ نماز ادا کرے اور اپنا بچاؤ اور اپنے ہتھیار لئے رہے، کافر چاہتے ہیں کہ کسی طرح تم اپنے ہتھیاروں اور اپنے سامان سے بے خبر ہو جاؤ تو وہ تم پر اچانک دھاوا بول دیں، ہاں اپنے ہتھیار اتار رکھنے میں اس وقت تم پر کوئی گناه نہیں جب کہ تمہیں تکلیف ہو یا بوجہ بارش کے یا بسبب بیمار ہو جانے کے اور اپنے بچاؤ کی چیزیں ساتھ لئے رہو، یقیناً اللہ تعالیٰ نے منکروں کے لئے ذلت کی مار تیار کر رکھی ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dxcvi{پھر جب تم نماز ادا کر چکو تو اٹھتے بیٹھتے اور لیٹے اللہ تعالیٰ کا ذکر کرتے رہو اور جب اطمینان پاؤ تو نماز قائم کرو! یقیناً نماز مومنوں پر مقرره وقتوں پر فرض ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dxcvii{ان لوگوں کا پیچھا کرنے سے ہارے دل ہو کر بیٹھ نہ رہو! اگر تمہیں بے آرامی ہوتی ہے تو انہیں بھی تمہاری طرح بے آرامی ہوتی ہے اور تم اللہ تعالیٰ سے وه امیدیں رکھتے ہو، جو امیدیں انہیں نہیں، اور اللہ تعالیٰ دانا اور حکیم ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dxcviii{یقیناً ہم نے تمہاری طرف حق کے ساتھ اپنی کتاب نازل فرمائی ہے تاکہ تم لوگوں میں اس چیز کے مطابق فیصلہ کرو جس سے اللہ نے تم کو شناسا کیا ہے اور خیانت کرنے والوں کے حمایتی نہ بنو\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dxcix{اور اللہ تعالیٰ سے بخشش مانگو! بے شک اللہ تعالیٰ بخشش کرنے واﻻ، مہربانی کرنے واﻻ ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dc{اور ان کی طرف سے جھگڑا نہ کرو جو خود اپنی ہی خیانت کرتے ہیں، یقیناً دغا باز گنہگار اللہ تعالیٰ کو اچھا نہیں لگتا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dci{وه لوگوں سے تو چھﭗ جاتے ہیں، (لیکن) اللہ تعالیٰ سے نہیں چھﭗ سکتے، وه راتوں کے وقت جب کہ اللہ کی ناپسندیده باتوں کے خفیہ مشورے کرتے ہیں اس وقت بھی اللہ ان کے پاس ہوتا ہے، ان کے تمام اعمال کو وه گھیرے ہوئے ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcii{ہاں تو یہ ہو تم لوگ کہ دنیا میں تم نے ان کی حمایت کی لیکن اللہ تعالیٰ کے سامنے قیامت کے دن ان کی حمایت کون کرے گا؟ اور وه کون ہے جو ان کا وکیل بن کر کھڑا ہو سکے گا؟\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dciii{جو شخص کوئی برائی کرے یا اپنی جان پر ﻇلم کرے پھر اللہ سے استغفار کرے تو وه اللہ کو بخشنے واﻻ، مہربانی کرنے واﻻ پائے گا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dciv{اور جو گناه کرتا ہے اس کا بوجھ اسی پر ہے اور اللہ بخوبی جاننے واﻻ اور پوری حکمت واﻻ ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcv{اور جو شخص کوئی گناه یا خطا کر کے کسی بے گناه کے ذمے تھوپ دے، اس نے بہت بڑا بہتان اٹھایا اور کھلا گناه کیا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcvi{اگر اللہ تعالیٰ کا فضل ورحم تجھ پر نہ ہوتا تو ان کی ایک جماعت نے تو تجھے بہکانے کا قصد کر ہی لیا تھا، مگر دراصل یہ اپنے آپ کو ہی گمراه کرتے ہیں، یہ تیرا کچھ نہیں بگاڑ سکتے، اللہ تعالیٰ نے تجھ پر کتاب وحکمت اتاری ہے اور تجھے وه سکھایا ہے جسے تو نہیں جانتا تھا اور اللہ تعالیٰ کا تجھ پر بڑا بھاری فضل ہے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcvii{ان کے اکثر خفیہ مشوروں میں کوئی خیر نہیں، ہاں! بھلائی اس کے مشورے میں ہے جو خیرات کا یا نیک بات کا یا لوگوں میں صلح کرانے کا حکم کرے اور جو شخص صرف اللہ تعالیٰ کی رضامندی حاصل کرنے کے ارادے سے یہ کام کرے اسے ہم یقیناً بہت بڑا ﺛواب دیں گے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcviii{جو شخص باوجود راه ہدایت کے واضح ہو جانے کے بھی رسول (صلی اللہ علیہ وسلم) کا خلاف کرے اور تمام مومنوں کی راه چھوڑ کر چلے، ہم اسے ادھر ہی متوجہ کردیں گے جدھر وه خود متوجہ ہو اور دوزخ میں ڈال دیں گے، وه پہنچنے کی بہت ہی بری جگہ ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcix{اسے اللہ تعالیٰ قطعاً نہ بخشے گا کہ اس کے ساتھ شرک مقرر کیا جائے، ہاں شرک کے علاوه گناه جس کے چاہے معاف فرما دیتا ہے اور اللہ کے ساتھ شریک کرنے واﻻ بہت دور کی گمراہی میں جا پڑا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcx{یہ تو اللہ تعالیٰ کو چھوڑ کر صرف عورتوں کو پکارتے ہیں اور دراصل یہ صرف سرکش شیطان کو پوجتے ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcxi{جسے اللہ نے لعنت کی ہے اور اس نے بیڑا اٹھایا ہے کہ تیرے بندوں میں سے میں مقرر شده حصہ لے کر رہوں گا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcxii{اور انہیں راه سے بہکاتا رہوں گا اور باطل امیدیں دﻻتا رہوں گا اور انہیں سکھاؤں گا کہ جانوروں کی کان چیر دیں، اور ان سے کہوں گا کہ اللہ تعالیٰ کی بنائی ہوئی صورت کو بگاڑ دیں، سنو! جو شخص اللہ کو چھوڑ کرشیطان کو اپنا رفیق بنائے گا وه صریح نقصان میں ڈوبے گا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcxiii{وه ان سے زبانی وعدے کرتا رہے گا، اور سبز باغ دکھاتا رہے گا، (مگر یاد رکھو!) شیطان کے جو وعدے ان سے ہیں وه سراسر فریب کاریاں ہیں\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dcxiv{یہ وه لوگ ہیں جن کی جگہ جہنم ہے، جہاں سے انہیں چھٹکارا نہ ملے گا\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@dcxv{اور جو ایمان ﻻئیں اور بھلے کام کریں ہم انہیں ان جنتوں میں لے جائیں گے جن کے نیچے چشمے جاری ہیں، جہاں یہ ابداﻻباد رہیں گے، یہ ہے اللہ کا وعده جو سراسر سچا ہے اور کون ہے جو اپنی بات میں اللہ سے زیاده سچا ہو؟\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@dcxvi{حقیقت حال نہ تو تمہاری آرزو کے مطابق ہے اور نہ اہل کتاب کی امیدوں پر موقوف ہے، جو برا کرے گا اس کی سزا پائے گا اور کسی کو نہ پائے گا جو اس کی حمایت ومدد، اللہ کے پاس کر سکے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@dcxvii{جو ایمان واﻻ ہو مرد ہو یا عورت اور وه نیک اعمال کرے، یقیناً ایسے لوگ جنت میں جائیں گے اور کھجور کی گٹھلی کے شگاف برابر بھی ان کا حق نہ مارا جائے گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@dcxviii{باعتبار دین کے اس سے اچھا کون ہے؟ جو اپنے کو اللہ کے تابع کر دے اور ہو بھی نیکو کار، ساتھ ہی یکسوئی والے ابراہیم کے دین کی پیروی کر رہا ہو اور ابراہیم (علیہ السلام) کو اللہ تعالیٰ نے اپنا دوست بنا لیا ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@dcxix{آسمانوں اور زمین میں جو کچھ ہے سب اللہ ہی کا ہے اور اللہ تعالیٰ ہر چیز کو گھیرنے واﻻ ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@dcxx{آپ سے عورتوں کے بارے میں حکم دریافت کرتے ہیں، آپ کہہ دیجئے! کہ خود اللہ ان کے بارے میں حکم دے رہا ہے اور قرآن کی وه آیتیں جو تم پر ان یتیم لڑکیوں کے بارے میں پڑھی جاتی ہیں جنہیں ان کا مقرر حق تم نہیں دیتے اور انہیں اپنے نکاح میں ﻻنے کی رغبت رکھتے ہو اور کمزور بچوں کے بارے میں اور اس بارے میں کہ یتیموں کی کارگزاری انصاف کے ساتھ کرو۔ تم جو نیک کام کرو، بے شبہ اللہ اسے پوری طرح جاننے واﻻ ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@dcxxi{اگر کسی عورت کو اپنے شوہر کی بد دماغی اور بے پرواہی کا خوف ہو تو دونوں آپس میں جو صلح کر لیں اس میں کسی پر کوئی گناه نہیں۔ صلح بہت بہتر چیز ہے، طمع ہر ہر نفس میں شامل کر دی گئی ہے۔ اگر تم اچھا سلوک کرو اور پرہیزگاری کرو تو تم جو کر رہے ہو اس پر اللہ تعالیٰ پوری طرح خبردار ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@dcxxii{تم سے یہ تو کبھی نہ ہو سکے گا کہ اپنی تمام بیویوں میں ہر طرح عدل کرو، گو تم اس کی کتنی ہی خواہش وکوشش کر لو، اس لئے بالکل ہی ایک کی طرف مائل ہو کر دوسری کو ادھڑ لٹکتی ہوئی نہ چھوڑو اور اگر تم اصلاح کرو اور تقویٰ اختیار کرو تو، بے شک اللہ تعالیٰ بڑی مغفرت اور رحمت واﻻ ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@dcxxiii{اور اگر میاں بیوی جدا ہو جائیں تو اللہ تعالیٰ اپنی وسعت سے ہر ایک کو بے نیاز کر دے گا، اللہ تعالیٰ وسعت واﻻ حکمت واﻻ ہے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@dcxxiv{زمین اور آسمانوں کی ہر ہر چیز اللہ تعالیٰ ہی کی ملکیت میں ہے اور واقعی ہم نے ان لوگوں کو جو تم سے پہلے کتاب دیئے گئے تھے اور تم کو بھی یہی حکم کیا ہے کہ اللہ سے ڈرتے رہو اور اگر تم کفر کرو تو یاد رکھو کہ اللہ کے لئے ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اور اللہ بہت بے نیاز اور تعریف کیا گیا ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@dcxxv{اللہ کے اختیار میں ہیں آسمانوں کی سب چیزیں اور زمین کی بھی اور اللہ کار ساز کافی ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@dcxxvi{اگر اسے منظور ہو تو اے لوگو! وه تم سب کو لے جائے اور دوسروں کو لے آئے، اللہ تعالیٰ اس پرپوری قدرت رکھنے واﻻ ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@dcxxvii{جو شخص دنیا کا ﺛواب چاہتا ہو تو (یاد رکھو کہ) اللہ تعالیٰ کے پاس تو دنیا اور آخرت (دونوں) کا ﺛواب موجود ہے اور اللہ تعالیٰ بہت سننے واﻻ اور خوب دیکھنے واﻻ ہے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@dcxxviii{اے ایمان والو! عدل وانصاف پر مضبوطی سے جم جانے والے اور خوشنودی موﻻ کے لئے سچی گواہی دینے والے بن جاؤ، گو وه خود تمہارے اپنے خلاف ہو یا اپنے ماں باپ کے یا رشتہ دار عزیزوں کے، وه شخص اگر امیر ہو تو اور فقیر ہو تو دونوں کے ساتھ اللہ کو زیاده تعلق ہے، اس لئے تم خواہش نفس کے پیچھے پڑ کر انصاف نہ چھوڑ دینا اور اگر تم نے کج بیانی یا پہلو تہی کی تو جان لو کہ جو کچھ تم کرو گے اللہ تعالیٰ اس سے پوری طرح باخبر ہے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@dcxxix{اے ایمان والو! اللہ تعالیٰ پر، اس کے رسول (صلی اللہ علیہ وسلم) پر اور اس کتاب پر جو اس نے اپنے رسول (صلی اللہ علیہ وسلم) پر اتاری ہے اور ان کتابوں پر جو اس سے پہلے اس نے نازل فرمائی ہیں، ایمان لاؤ! جو شخص اللہ تعالیٰ سے اور اس کے فرشتوں سے اور اس کی کتابوں سے اور اس کے رسولوں سے اور قیامت کے دن سے کفر کرے وه تو بہت بڑی دور کی گمراہی میں جا پڑا\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@dcxxx{جن لوگوں نے ایمان قبول کر کے پھر کفر کیا، پھر ایمان ﻻکر پھر کفر کیا، پھر اپنے کفر میں بڑھ گئے، اللہ تعالیٰ یقیناً انہیں نہ بخشے گا اور نہ انہیں راه ہدایت سمجھائے گا\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@dcxxxi{منافقوں کو اس امر کی خبر پہنچا دو کہ ان کے لئے دردناک عذاب یقینی ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@dcxxxii{جن کی یہ حالت ہے کہ مسلمانوں کو چھوڑ کر کافروں کو دوست بناتے پھرتے ہیں، کیا ان کے پاس عزت کی تلاش میں جاتے ہیں؟ (تو یاد رکھیں کہ) عزت تو ساری کی ساری اللہ تعالیٰ کے قبضہ میں ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@dcxxxiii{اور اللہ تعالیٰ تمہارے پاس اپنی کتاب میں یہ حکم اتار چکا ہے کہ تم جب کسی مجلس والوں کو اللہ تعالیٰ کی آیتوں کے ساتھ کفر کرتے اور مذاق اڑاتے ہوئے سنو تو اس مجمع میں ان کے ساتھ نہ بیٹھو! جب تک کہ وه اس کے علاوه اور باتیں نہ کرنے لگیں، (ورنہ) تم بھی اس وقت انہی جیسے ہو، یقیناً اللہ تعالیٰ تمام کافروں اور سب منافقوں کو جہنم میں جمع کرنے واﻻ ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@dcxxxiv{یہ لوگ تمہارے انجام کار کا انتظار کرتے رہتے ہیں پھر اگر تمہیں اللہ فتح دے تو یہ کہتے ہیں کہ کیا ہم تمہارے ساتھی نہیں اور اگر کافروں کو تھوڑا سا غلبہ مل جائے تو (ان سے) کہتے ہیں کہ ہم تم پر غالب نہ آنے لگے تھے اور کیا ہم نے تمہیں مسلمانوں کے ہاتھوں سے نہ بچایا تھا؟ پس قیامت میں خود اللہ تعالیٰ تمہارے درمیان فیصلہ کرے گا اور اللہ تعالیٰ کافروں کو ایمان والوں پر ہرگز راه نہ دے گا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@dcxxxv{بے شک منافق اللہ سے چالبازیاں کر رہے ہیں اور وه انہیں اس چالبازی کا بدلہ دینے واﻻ ہے اور جب نماز کو کھڑے ہوتے ہیں تو بڑی کاہلی کی حالت میں کھڑے ہوتے ہیں صرف لوگوں کو دکھاتے ہیں، اور یاد الٰہی تو یوں ہی سی برائے نام کرتے ہیں\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@dcxxxvi{وه درمیان میں ہی معلق ڈگمگا رہے ہیں، نہ پورے ان کی طرف نہ صحیح طور پر ان کی طرف اور جسے اللہ تعالیٰ گمراہی میں ڈال دے تو تو اس کے لئے کوئی راه نہ پائے گا\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@dcxxxvii{اے ایمان والو! مومنوں کو چھوڑ کر کافروں کو دوست نہ بناؤ، کیا تم یہ چاہتے ہو کہ اپنے اوپر اللہ تعالیٰ کی صاف حجت قائم کر لو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@dcxxxviii{منافق تو یقیناً جہنم کے سب سے نیچے کے طبقہ میں جائیں گے، ناممکن ہے کہ تو ان کا کوئی مددگار پالے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@dcxxxix{ہاں جو توبہ کر لیں اور اصلاح کر لیں اور اللہ تعالیٰ پر کامل یقین رکھیں اور خالص اللہ ہی کے لئے دینداری کریں تو یہ لوگ مومنوں کے ساتھ ہیں، اللہ تعالیٰ مومنوں کو بہت بڑا اجر دے گا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@dcxl{اللہ تعالیٰ تمہیں سزا دے کر کیا کرے گا؟ اگر تم شکر گزاری کرتے رہو اور باایمان رہو، اللہ تعالیٰ بہت قدر کرنے واﻻ اور پورا علم رکھنے واﻻ ہے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@dcxli{برائی کے ساتھ آواز بلند کرنے کو اللہ تعالیٰ پسند نہیں فرماتا مگر مظلوم کی اجازت ہے اور اللہ تعالیٰ خوب سنتا جانتا ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@dcxlii{اگر تم کسی نیکی کو علانیہ کرو یا پوشیده، یا کسی برائی سے درگزر کرو، پس یقیناً اللہ تعالیٰ پوری معافی کرنے واﻻ اور پوری قدرت واﻻ ہے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@dcxliii{جو لوگ اللہ کے ساتھ اور اس کے پیغمبروں کے ساتھ کفر کرتے ہیں اور جو لوگ یہ چاہتے ہیں کہ اللہ اور اس کے رسولوں کے درمیان فرق رکھیں اور جو لوگ کہتے ہیں کہ بعض نبیوں پر تو ہمارا ایمان ہے اور بعض پر نہیں اور چاہتے ہیں کہ اس کے اور اس کے بین بین کوئی راه نکالیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@dcxliv{یقین مانو کہ یہ سب لوگ اصلی کافر ہیں، اور کافروں کے لئے ہم نے اہانت آمیز سزا تیار کر رکھی ہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@dcxlv{اور جو لوگ اللہ پر اور اس کے تمام پیغمبروں پر ایمان ﻻتے ہیں اور ان میں سے کسی میں فرق نہیں کرتے، یہ ہیں جنہیں اللہ ان کو پورا ﺛواب دے گا اور اللہ بڑی مغفرت واﻻ بڑی رحمت واﻻ ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@dcxlvi{آپ سے یہ اہل کتاب درخواست کرتے ہیں کہ آپ ان کے پاس کوئی آسمانی کتاب ﻻئیں، حضرت موسیٰ (علیہ السلام) سے تو انہوں نے اس سے بہت بڑی درخواست کی تھی کہ ہمیں کھلم کھلا اللہ تعالیٰ کو دکھا دے، پس ان کے اس ﻇلم کے باعﺚ ان پر کڑاکے کی بجلی آ پڑی پھر باوجودیکہ ان کے پاس بہت دلیلیں پہنچ چکی تھیں انہوں نے بچھڑے کو اپنا معبود بنا لیا، لیکن ہم نے یہ بھی معاف فرما دیا اور ہم نے موسیٰ کو کھلا غلبہ (اور صریح دلیل) عنایت فرمائی\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@dcxlvii{اور ان کا قول لینے کے لئے ہم نے ان کے سروں پر طور پہاڑ ﻻ کھڑا کردیا اور انہیں حکم دیا کہ سجده کرتے ہوئے دروازے میں جاؤ اور یہ بھی فرمایا کہ ہفتہ کے دن میں تجاوز نہ کرنا اور ہم نے ان سے سخت سے سخت قول وقرار لئے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@dcxlviii{(یہ سزا تھی) بہ سبب ان کی عہد شکنی کے اور احکام الٰہی کے ساتھ کفر کرنے کے اور اللہ کے نبیوں کو ناحق قتل کر ڈالنے کے، اور اس سبب سے کہ یوں کہتے ہیں کہ ہمارے دلوں پر غلاف ہے۔ حاﻻنکہ دراصل ان کے کفر کی وجہ سے ان کے دلوں پر اللہ تعالیٰ نے مہر لگا دی ہے، اس لئے یہ قدر قلیل ہی ایمان ﻻتے ہیں\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@dcxlix{اور ان کے کفر کے باعﺚ اور مریم پر بہت بڑا بہتان باندھنے کے باعﺚ\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@dcl{اور یوں کہنے کے باعﺚ کہ ہم نے اللہ کے رسول مسیح عیسیٰ بن مریم کو قتل کر دیا حاﻻنکہ نہ تو انہوں نے اسے قتل کیا نہ سولی پر چڑھایا بلکہ ان کے لئے ان (عیسیٰ) کا شبیہ بنا دیا گیا تھا۔ یقین جانو کہ حضرت عیسیٰ (علیہ السلام) کے بارے میں اختلاف کرنے والے ان کے بارے میں شک میں ہیں، انہیں اس کا کوئی یقین نہیں بجز تخمینی باتوں پر عمل کرنے کے اتنا یقینی ہے کہ انہوں نے انہیں قتل نہیں کیا\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@dcli{بلکہ اللہ تعالیٰ نے انہیں اپنی طرف اٹھا لیا اور اللہ بڑا زبردست اور پوری حکمتوں واﻻ ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@dclii{اہل کتاب میں ایک بھی ایسا نہ بچے گا جو حضرت عیسیٰ (علیہ السلام) کی موت سے پہلے ان پر ایمان نہ ﻻچکے اور قیامت کے دن آپ ان پر گواه ہوں گے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@dcliii{جو نفیس چیزیں ان کے لئے حلال کی گئی تھیں وه ہم نے ان پر حرام کردیں ان کے ﻇلم کے باعﺚ اور اللہ تعالیٰ کی راه سے اکثر لوگوں کو روکنے کے باعﺚ\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@dcliv{اور سود جس سے منع کئے گئے تھے اسے لینے کے باعﺚ اور لوگوں کا مال ناحق مار کھانے کے باعﺚ اور ان میں جو کفار ہیں ہم نے ان کے لئے المناک عذاب مہیا کر رکھا ہے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@dclv{لیکن ان میں سے جو کامل اور مضبوط علم والے ہیں اور ایمان والے ہیں جو اس پر ایمان ﻻتے ہیں جو آپ کی طرف اتارا گیا اور جو آپ سے پہلے اتارا گیا اور نمازوں کو قائم رکھنے والے ہیں اور زکوٰة کے ادا کرنے والے ہیں اور اللہ پر اور قیامت کے دن پر ایمان رکھنے والے ہیں یہ ہیں جنہیں ہم بہت بڑے اجر عطا فرمائیں گے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@dclvi{یقیناً ہم نے آپ کی طرف اسی طرح وحی کی ہے جیسے کہ نوح (علیہ السلام) اور ان کے بعد والے نبیوں کی طرف کی، اور ہم نے وحی کی ابراہیم اور اسماعیل اور اسحاق اور یعقوب اور ان کی اوﻻد پر اور عیسیٰ اور ایوب اور یونس اور ہارون اور سلیمان کی طرف۔ اور ہم نے داؤد (علیہ السلام) کو زبور عطا فرمائی\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@dclvii{اور آپ سے پہلے کے بہت سے رسولوں کے واقعات ہم نے آپ سے بیان کئے ہیں اور بہت سے رسولوں کے نہیں بھی کئے اور موسیٰ (علیہ السلام) سے اللہ تعالیٰ نے صاف طور پر کلام کیا\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@dclviii{ہم نے انہیں رسول بنایا ہے، خوشخبریاں سنانے والے اور آگاه کرنے والے تاکہ لوگوں کی کوئی حجت اور الزام رسولوں کے بھیجنے کے بعد اللہ تعالیٰ پر ره نہ جائے۔ اللہ تعالی بڑا غالب اور بڑا باحکمت ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@dclix{جو کچھ آپ کی طرف اتارا ہے اس کی بابت خود اللہ تعالیٰ گواہی دیتا ہے کہ اسے اپنے علم سے اتارا ہے اور فرشتے بھی گواہی دیتے ہیں اور اللہ تعالیٰ بطور گواه کافی ہے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@dclx{جن لوگوں نے کفر کیا اور اللہ تعالیٰ کی راه سے اوروں کو روکا وه یقیناً گمراہی میں دور نکل گئے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@dclxi{جن لوگوں نے کفر کیا اور ﻇلم کیا، انہیں اللہ تعالیٰ ہرگز ہرگز نہ بخشے گا اور نہ انہیں کوئی راه دکھائے گا\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@dclxii{بجز جہنم کی راه کے جس میں وه ہمیشہ ہمیشہ پڑے رہیں گے، اور یہ اللہ تعالیٰ پر بالکل آسان ہے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@dclxiii{اے لوگو! تمہارے پاس تمہارے رب کی طرف حق لے کر رسول آگیا ہے، پس تم ایمان ﻻؤ تاکہ تمہارے لئے بہتری ہو اور اگر تم کافر ہوگئے تو اللہ ہی کی ہے ہر وه چیز جو آسمانوں اور زمین میں ہے، اور اللہ دانا ہے حکمت واﻻ ہے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@dclxiv{اے اہل کتاب! اپنے دین کے بارے میں حد سے نہ گزر جاؤ اور اللہ پر بجز حق کے اور کچھ نہ کہو، مسیح عیسیٰ بن مریم (علیہ السلام) تو صرف اللہ تعالیٰ کے رسول اور اس کے کلمہ (کن سے پیدا شده) ہیں، جسے مریم (علیہا السلام) کی طرف ڈال دیا تھا اور اس کے پاس کی روح ہیں اس لئے تم اللہ کو اور اس کے سب رسولوں کو مانو اور نہ کہو کہ اللہ تین ہیں، اس سے باز آجاؤ کہ تمہارے لئے بہتری ہے، اللہ عبادت کے ﻻئق تو صرف ایک ہی ہے اور وه اس سے پاک ہے کہ اس کی اوﻻد ہو، اسی کے لئے ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے۔ اور اللہ کافی ہے کام بنانے واﻻ\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@dclxv{مسیح (علیہ السلام) کو اللہ کا بنده ہونے میں کوئی ننگ و عار یا تکبر وانکار ہرگز ہو ہی نہیں سکتا اور نہ مقرب فرشتوں کو، اس کی بندگی سے جو بھی دل چرائے اور تکبر و انکار کرے، اللہ تعالیٰ ان سب کو اکٹھا اپنی طرف جمع کرے گا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@dclxvi{پس جو لوگ ایمان ﻻئے ہیں اور شائستہ اعمال کئے ہیں ان کو ان کا پورا پورا ﺛواب عنایت فرمائے گا اور اپنے فضل سے انہیں اور زیاده دے گا اور جن لوگوں نے ننگ و عار اور سرکشی اور انکار کیا، انہیں المناک عذاب دے گا اور وه اپنے لئے سوائے اللہ کے کوئی حمایتی، اور امداد کرنے واﻻ نہ پائیں گے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@dclxvii{اے لوگو! تمہارے پاس تمہارے رب کی طرف سے سند اور دلیل آپہنچی اور ہم نے تمہاری جانب واضح اور صاف نور اتار دیا ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@dclxviii{پس جو لوگ اللہ تعالیٰ پر ایمان ﻻئے اور اسے مضبوط پکڑ لیا، انہیں تو وه عنقریب اپنی رحمت اور فضل میں لے لے گا اور انہیں اپنی طرف کی راه راست دکھا دے گا\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@dclxix{آپ سے فتویٰ پوچھتے ہیں، آپ کہہ دیجیئے کہ اللہ تعالیٰ (خود) تمہیں کلالہ کے بارے میں فتویٰ دیتا ہے۔ اگر کوئی شخص مر جائے جس کی اوﻻد نہ ہو اور ایک بہن ہو تو اس کے لئے چھوڑے ہوئے مال کا آدھا حصہ ہے اور وه بھائی اس بہن کا وارث ہوگا اگر اس کے اوﻻد نہ ہو۔ پس اگر بہنیں دو ہوں تو انہیں کل چھوڑے ہوئے کا دو تہائی ملے گا۔ اور اگر کئی شخص اس ناطے کے ہیں مرد بھی اور عورتیں بھی تو مرد کے لئے حصہ ہے مثل دو عورتوں کے، اللہ تعالیٰ تمہارے لئے بیان فرما رہا ہے کہ ایسا نہ ہو کہ تم بہک جاؤ اور اللہ تعالیٰ ہر چیز سے واقف ہے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@dclxx{\basmalahur اے ایمان والو! عہد و پیماں پورے کرو، تمہارے لئے مویشی چوپائے حلال کئے گئے ہیں بجز ان کے جن کے نام پڑھ کر سنا دیئے جائیں گے مگر حالت احرام میں شکار کو حلال جاننے والے نہ بننا، یقیناً اللہ جو چاہے حکم کرتا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dclxxi{اے ایمان والو! اللہ تعالیٰ کے شعائر کی بے حرمتی نہ کرو نہ ادب والے مہینوں کی نہ حرم میں قربان ہونے والے اور پٹے پہنائے گئے جانوروں کی جو کعبہ کو جا رہے ہوں اور نہ ان لوگوں کی جو بیت اللہ کے قصد سے اپنے رب تعالیٰ کے فضل اور اس کی رضاجوئی کی نیت سے جا رہے ہوں، ہاں جب تم احرام اتار ڈالو تو شکار کھیل سکتے ہو، جن لوگوں نے تمہیں مسجد حرام سے روکا تھا ان کی دشمنی تمہیں اس بات پر آماده نہ کرے کہ تم حد سے گزر جاؤ، نیکی اور پرہیزگاری میں ایک دوسرے کی امداد کرتے رہو اور گناه اور ﻇلم و زیادتی میں مدد نہ کرو، اور اللہ تعالیٰ سے ڈرتے رہو، بےشک اللہ تعالیٰ سخت سزا دینے واﻻ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dclxxii{تم پر حرام کیا گیا مردار اور خون اور خنزیر کا گوشت اور جس پر اللہ کے سوا دوسرے کا نام پکارا گیا ہو اور جو گلا گھٹنے سے مرا ہو اور جو کسی ضرب سے مر گیا ہو اور جو اونچی جگہ سے گر کر مرا ہو اور جو کسی کے سینگ مارنے سے مرا ہو اور جسے درندوں نے پھاڑ کھایا ہو لیکن اسے تم ذبح کر ڈالو تو حرام نہیں اور جو آستانوں پر ذبح کیا گیا ہو اور یہ بھی کہ قرعہ کے تیروں کے ذریعے فال گیری کرو یہ سب بدترین گناه ہیں، آج کفار تمہارے دین سے ناامید ہوگئے، خبردار! تم ان سے نہ ڈرنا اور مجھ سے ڈرتے رہنا، آج میں نے تمہارے لئے دین کو کامل کردیا اور تم پر اپنا انعام بھرپور کردیا اور تمہارے لئے اسلام کے دین ہونے پر رضامند ہوگیا۔ پس جو شخص شدت کی بھوک میں بے قرار ہو جائے بشرطیکہ کسی گناه کی طرف اس کا میلان نہ ہو تو یقیناً اللہ تعالیٰ معاف کرنے واﻻ اور بہت بڑا مہربان ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dclxxiii{آپ سے دریافت کرتے ہیں کہ ان کے لئے کیا کچھ حلال ہے؟ آپ کہہ دیجئے کہ تمام پاک چیزیں تمہارے لئے حلال کی گئی ہیں، اور جن شکار کھیلنے والے جانوروں کو تم نے سدھا رکھا ہے یعنی جنہیں تم تھوڑا بہت وه سکھاتے ہو جس کی تعلیم اللہ تعالیٰ نے تمہیں دے رکھی ہے پس جس شکار کو وه تمہارے لئے پکڑ کر روک رکھیں تو تم اس سے کھا لو اور اس پر اللہ تعالیٰ کے نام کا ذکر کر لیا کرو۔ اور اللہ تعالیٰ سے ڈرتے رہو، یقیناً اللہ تعالیٰ جلد حساب لینے واﻻ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dclxxiv{کل پاکیزه چیزیں آج تمہارے لئے حلال کی گئیں اور اہل کتاب کا ذبیحہ تمہارے لئے حلال ہے اور تمہارا ذبیحہ ان کے لئے حلال ہے، اور پاک دامن مسلمان عورتیں اور جو لوگ تم سے پہلے کتاب دیئے گئے ہیں ان کی پاک دامن عورتیں بھی حلال ہیں جب کہ تم ان کے مہر ادا کرو، اس طرح کہ تم ان سے باقاعده نکاح کرو یہ نہیں کہ علانیہ زنا کرو یا پوشیده بدکاری کرو، منکرین ایمان کے اعمال ضائع اور اکارت ہیں اور آخرت میں وه ہارنے والوں میں سے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dclxxv{اے ایمان والو! جب تم نماز کے لئے اٹھو تو اپنے منھ کو، اور اپنے ہاتھوں کو کہنیوں سمیت دھو لو اپنے سروں کا مسح کرو اور اپنے پاؤں کو ٹخنوں سمیت دھو لو، اور اگر تم جنابت کی حالت میں ہو تو غسل کرلو، ہاں اگر تم بیمار ہو یا سفر کی حالت میں ہو یا تم میں سے کوئی حاجت ضروری سے فارغ ہو کر آیا ہو، یا تم عورتوں سے ملے ہو اور تمہیں پانی نہ ملے تو تم پاک مٹی سے تیمم کرلو، اسے اپنے چہروں پر اور ہاتھوں پر مل لو اللہ تعالیٰ تم پر کسی قسم کی تنگی ڈالنا نہیں چاہتا بلکہ اس کا اراده تمہیں پاک کرنے کا اور تمہیں اپنی بھرپور نعمت دینے کا ہے، تاکہ تم شکر ادا کرتے رہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dclxxvi{تم پر اللہ تعالیٰ کی جو نعمتیں نازل ہوئی ہیں انہیں یاد رکھو اور اس کے اس عہد کو بھی جس کا تم سے معاہده ہوا ہے جبکہ تم نے کہا ہم نے سنا اور مانا اور اللہ تعالیٰ سے ڈرتے رہو، یقیناً اللہ تعالیٰ دلوں کی باتوں کا جاننے واﻻ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dclxxvii{اے ایمان والو! تم اللہ کی خاطر حق پر قائم ہو جاؤ، راستی اور انصاف کے ساتھ گواہی دینے والے بن جاؤ، کسی قوم کی عداوت تمہیں خلاف عدل پر آماده نہ کردے، عدل کیا کرو جو پرہیز گاری کے زیاده قریب ہے، اور اللہ تعالیٰ سے ڈرتے رہو، یقین مانو کہ اللہ تعالیٰ تمہارے اعمال سے باخبر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dclxxviii{اللہ تعالیٰ کا وعده ہے کہ جو ایمان ﻻئیں اور نیک کام کریں ان کے لئے وسیع مغفرت اور بہت بڑا اجر و ﺛواب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dclxxix{اور جن لوگوں نے کفر کیا اور ہمارے احکام کو جھٹلایا وه دوزخی ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dclxxx{اے ایمان والو! اللہ تعالیٰ نے جو احسان تم پر کیا ہے اسے یاد کرو جب کہ ایک قوم نے تم پر دست درازی کرنی چاہی تو اللہ تعالیٰ نے ان کے ہاتھوں کو تم تک پہنچنے سے روک دیا اور اللہ تعالیٰ سے ڈرتے رہو اور مومنوں کو اللہ تعالیٰ ہی پر بھروسہ کرنا چاہئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dclxxxi{اور اللہ تعالیٰ نے بنی اسرائیل سے عہد و پیمان لیا اور انہی میں سے باره سردار ہم نے مقرر فرمائے اور اللہ تعالیٰ نے فرما دیا کہ یقیناً میں تمہارے ساتھ ہوں، اگر تم نماز قائم رکھو گے اور زکوٰة دیتے رہو گے اور میرے رسولوں کو مانتے رہو گے اور ان کی مدد کرتے رہو گے اور اللہ تعالیٰ کو بہتر قرض دیتے رہو گے تو یقیناً میں تمہاری برائیاں تم سے دور رکھوں گا اور تمہیں ان جنتوں میں لے جاؤں گا جن کے نیچے چشمے بہہ رہے ہیں، اب اس عہد وپیمان کے بعد بھی تم میں سے جو انکاری ہو جائے وه یقیناً راه راست سے بھٹک گیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dclxxxii{پھر ان کی عہد شکنی کی وجہ سے ہم نے ان پر اپنی لعنت نازل فرمادی اور ان کے دل سخت کردیئے کہ وه کلام کو اس کی جگہ سے بدل ڈالتے ہیں اور جو کچھ نصیحت انہیں کی گئی تھی اس کا بہت بڑا حصہ بھلا بیٹھے، ان کی ایک نہ ایک خیانت پر تجھے اطلاع ملتی ہی رہے گی ہاں تھوڑے سے ایسے نہیں بھی ہیں پس توانہیں معاف کرتا جا اور درگزر کرتا ره، بےشک اللہ تعالیٰ احسان کرنے والوں سے محبت کرتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dclxxxiii{اور جو اپنے آپ کو نصرانی کہتے ہیں ہم نے ان سے بھی عہد وپیمان لیا، انہوں نے بھی اس کا بڑا حصہ فراموش کر دیا جو انہیں نصیحت کی گئی تھی، تو ہم نے بھی ان کے آپس میں بغض وعداوت ڈال دی جو تاقیامت رہے گی اور جو کچھ یہ کرتے تھے عنقریب اللہ تعالیٰ انہیں سب بتا دے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dclxxxiv{اے اہل کتاب! یقیناً تمہارے پاس ہمارا رسول (صلی اللہ علیہ وسلم) آچکا جو تمہارے سامنے کتاب اللہ کی بکثرت ایسی باتیں ﻇاہر کر رہا ہے جنہیں تم چھپا رہے تھے اور بہت سی باتوں سے درگزر کرتا ہے، تمہارے پاس اللہ تعالیٰ کی طرف سے نور اور واضح کتاب آچکی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dclxxxv{جس کے ذریعہ سے اللہ تعالیٰ انہیں جو رضائے رب کے درپے ہوں سلامتی کی راہیں بتلاتا ہے اور اپنی توفیق سے اندھیروں سے نکال کر نور کی طرف ﻻتا ہے اور راه راست کی طرف ان کی رہبری کرتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dclxxxvi{یقیناً وه لوگ کافر ہوگئے جنہوں نے کہا کہ اللہ ہی مسیح ابن مریم ہے، آپ ان سے کہہ دیجیئے کہ اگر اللہ تعالیٰ مسیح ابن مریم اور اس کی والده اور روئے زمین کے سب لوگوں کو ہلاک کر دینا چاہے تو کون ہے جو اللہ تعالیٰ پر کچھ بھی اختیار رکھتا ہو؟ آسمانوں و زمین اور دونوں کے درمیان کا کل ملک اللہ تعالیٰ ہی کا ہے، وه جو چاہتا ہے پیدا کرتا ہے، اور اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dclxxxvii{یہود و نصاریٰ کہتے ہیں کہ ہم اللہ کے بیٹے اور اس کے دوست ہیں، آپ کہہ دیجیئے کہ پھر تمہیں تمہارے گناہوں کے باعﺚ اللہ کیوں سزا دیتا ہے؟ نہیں بلکہ تم بھی اس کی مخلوق میں سے ایک انسان ہو وه جسے چاہتا ہے بخش دیتا ہے، اور جسے چاہتا ہے عذاب کرتا ہے، زمین و آسمان اور ان کے درمیان کی ہر چیز اللہ تعالیٰ کی ملکیت ہے اور اسی کی طرف لوٹنا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dclxxxviii{اے اہل کتاب! بالیقین ہمارا رسول تمہارے پاس رسولوں کی آمد کے ایک وقفے کے بعد آ پہنچا ہے۔ جو تمہارے لئے صاف صاف بیان کر رہا ہے تاکہ تمہاری یہ بات نہ ره جائے کہ ہمارے پاس تو کوئی بھلائی، برائی سنانے واﻻ آیا ہی نہیں، پس اب تو یقیناً خوشخبری سنانے واﻻ اور آگاه کرنے واﻻ آ پہنچا اور اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dclxxxix{اور یاد کرو موسیٰ (علیہ السلام) نے اپنی قوم سے کہا، اے میری قوم کے لوگو! اللہ تعالیٰ کے اس احسان کا ذکر کرو کہ اس نے تم میں سے پیغمبر بنائے اور تمہیں بادشاه بنا دیا اور تمہیں وه دیا جو تمام عالم میں کسی کو نہیں دیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcxc{اے میری قوم والو! اس مقدس زمین میں داخل ہو جاؤ جو اللہ تعالیٰ نے تمہارے نام لکھ دی ہے اور اپنی پشت کے بل روگردانی نہ کرو کہ پھر نقصان میں جا پڑو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcxci{انہوں نے جواب دیا کہ اے موسیٰ وہاں تو زور آور سرکش لوگ ہیں اور جب تک وه وہاں سے نکل نہ جائیں ہم تو ہرگز وہاں نہ جائیں گے ہاں اگر وه وہاں سے نکل جائیں پھر تو ہم (بخوشی) چلے جائیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcxcii{دو شخصوں نے جو خدا ترس لوگوں میں سے تھے، جن پر اللہ تعالیٰ کا فضل تھا کہا کہ تم ان کے پاس دروازے میں تو پہنچ جاؤ، دروازے میں قدم رکھتے ہی یقیناً تم غالب آجاؤ گے، اور تم اگر مومن ہو تو تمہیں اللہ تعالیٰ ہی پر بھروسہ رکھنا چاہیئے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcxciii{قوم نے جواب دیا کہ اے موسیٰ! جب تک وه وہاں ہیں تب تک ہم ہرگز وہاں نہ جائیں گے، اس لئے تم اور تمہارا پروردگار جا کر دونوں ہی لڑ بھڑ لو، ہم یہیں بیٹھے ہوئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcxciv{موسیٰ (علیہ السلام) کہنے لگے الٰہی! مجھے تو بجز اپنے اور میرے بھائی کے کسی اور پر کوئی اختیار نہیں، پس تو ہم میں اور ان نافرمانوں میں جدائی کردے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcxcv{ارشاد ہوا کہ اب زمین ان پر چالیس سال تک حرام کر دی گئی ہے، یہ خانہ بدوش ادھر ادھر سرگرداں پھرتے رہیں گے اس لئے تم ان فاسقوں کے بارے میں غمگین نہ ہونا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcxcvi{آدم (علیہ السلام) کے دونوں بیٹوں کا کھرا کھرا حال بھی انہیں سنا دو، ان دونوں نے ایک نذرانہ پیش کیا، ان میں سے ایک کی نذر تو قبول ہوگئی اور دوسرے کی مقبول نہ ہوئی تو وه کہنے لگا کہ میں تجھے مار ہی ڈالوں گا، اس نے کہا اللہ تعالیٰ تقویٰ والوں کا ہی عمل قبول کرتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcxcvii{گو تو میرے قتل کے لئے دست درازی کرے لیکن میں تیرے قتل کی طرف ہرگز اپنے ہاتھ نہ بڑھاؤں گا، میں تو اللہ تعالیٰ پروردگار عالم سے خوف کھاتا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcxcviii{میں تو چاہتا ہوں کہ تو میرا گناه اور اپنے گناه اپنے سر پر رکھ لے اور دوزخیوں میں شامل ہوجائے، ﻇالموں کا یہی بدلہ ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcxcix{پس اسے اس کے نفس نے اپنے بھائی کے قتل پر آماده کر دیا اور اس نے اسے قتل کر ڈاﻻ، جس سے نقصان پانے والوں میں سے ہوگیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcc{پھر اللہ تعالیٰ نے ایک کوے کو بھیجا جو زمین کھود رہا تھا تاکہ اسے دکھائے کہ وه کس طرح اپنے بھائی کی نعش کو چھپا دے، وه کہنے لگا، ہائے افسوس! کیا میں ایسا کرنے سے بھی گیا گزرا ہوگیا کہ اس کوے کی طرح اپنے بھائی کی ﻻش کو دفنا دیتا؟ پھر تو (بڑا ہی) پشیمان اور شرمنده ہوگیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcci{اسی وجہ سے ہم نے بنی اسرائیل پر یہ لکھ دیا کہ جو شخص کسی کو بغیر اس کے کہ وه کسی کا قاتل ہو یا زمین میں فساد مچانے واﻻ ہو، قتل کر ڈالے تو گویا اس نے تمام لوگوں کو قتل کردیا، اور جو شخص کسی ایک کی جان بچا لے، اس نے گویا تمام لوگوں کو زنده کردیا اور ان کے پاس ہمارے بہت سے رسول ﻇاہر دلیلیں لے کر آئے لیکن پھر اس کے بعد بھی ان میں کے اکثر لوگ زمین میں ﻇلم و زیادتی اور زبردستی کرنے والے ہی رہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dccii{جو اللہ تعالیٰ سے اور اس کے رسول سے لڑیں اور زمین میں فساد کرتے پھریں ان کی سزا یہی ہے کہ وه قتل کر دیئے جائیں یا سولی چڑھا دیئے جائیں یا مخالف جانب سے ان کے ہاتھ پاوں کاٹ دیئے جائیں، یا انہیں جلاوطن کر دیا جائے، یہ تو ہوئی ان کی دنیوی ذلت اور خواری، اور آخرت میں ان کے لئے بڑا بھاری عذاب ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcciii{ہاں جو لوگ اس سے پہلے توبہ کر لیں کہ تم ان پر قابو پالو تو یقین مانو کہ اللہ تعالیٰ بہت بڑی بخشش اور رحم و کرم واﻻ ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcciv{مسلمانو! اللہ تعالیٰ سے ڈرتے رہو اور اس کا قرب تلاش کرو اور اس کی راه میں جہاد کرو تاکہ تمہارا بھلا ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dccv{یقین مانو کہ کافروں کے لئے اگر وه سب کچھ ہو جو ساری زمین میں ہے بلکہ اسی کے مثل اور بھی ہو اور وه اس سب کو قیامت کے دن کے عذاب کے بدلے فدیے میں دینا چاہیں تو بھی ناممکن ہے کہ ان کا فدیہ قبول کرلیا جائے، ان کے لئے تو درد ناک عذاب ہی ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dccvi{یہ چاہیں گے کہ دوزخ میں سے نکل جائیں لیکن یہ ہرگز اس میں سے نہ نکل سکیں گے، ان کے لئے تو دوامی عذاب ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dccvii{چوری کرنے والے مرد اور عورت کے ہاتھ کاٹ دیا کرو۔ یہ بدلہ ہے اس کا جو انہوں نے کیا۔ عذاب، اللہ کی طرف سے اور اللہ تعالیٰ قوت وحکمت واﻻ ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dccviii{جو شخص اپنے گناه کے بعد توبہ کرلے اور اصلاح کرلے تو اللہ تعالیٰ رحمت کے ساتھ اس کی طرف لوٹتا ہے۔ یقیناً اللہ تعالیٰ معاف فرمانے واﻻ مہربانی کرنے واﻻ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dccix{کیا تجھے معلوم نہیں کہ اللہ تعالیٰ ہی کے لئے زمین و آسمان کی بادشاہت ہے؟ جسے چاہے سزا دے اور جسے چاہے معاف کردے، اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dccx{اے رسول! آپ ان لوگوں کے پیچھے نہ کُڑھیے جو کفر میں سبقت کر رہے ہیں خواه وه ان (منافقوں) میں سے ہوں جو زبانی تو ایمان کا دعویٰ کرتے ہیں لیکن حقیقتاً ان کے دل باایمان نہیں اور یہودیوں میں سے کچھ لوگ ایسے ہیں جو غلط باتیں سننے کے عادی ہیں اور ان لوگوں کے جاسوس ہیں جو اب تک آپ کے پاس نہیں آئے، وه کلمات کے اصلی موقعہ کو چھوڑ کر انہیں متغیر کردیا کرتے ہیں، کہتے ہیں کہ اگر تم یہی حکم دیئے جاؤ تو قبول کرلینا اور اگر یہ حکم نہ دیئے جاؤ تو الگ تھلگ رہنا اور جس کا خراب کرنا اللہ کو منظور ہو تو آپ اس کے لئے خدائی ہدایت میں سے کسی چیز کے مختار نہیں۔ اللہ تعالیٰ کا اراده ان کے دلوں کو پاک کرنے کا نہیں، ان کے لئے دنیا میں بھی بڑی ذلت اور رسوائی ہے اور آخرت میں بھی ان کے لئے بڑی سخت سزا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dccxi{یہ کان لگا لگا کر جھوٹ کے سننے والے اور جی بھر بھر کر حرام کے کھانے والے ہیں، اگر یہ تمہارے پاس آئیں تو تمہیں اختیار ہے خواه ان کے آپس کا فیصلہ کرو خواه ان کو ٹال دو، اگر تم ان سے منھ بھی پھیرو گے تو بھی یہ تم کو ہرگز کوئی ضرر نہیں پہنچا سکتے، اور اگر تم فیصلہ کرو تو ان میں عدل وانصاف کے ساتھ فیصلہ کرو، یقیناً عدل والوں کے ساتھ اللہ محبت رکھتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dccxii{(تعجب کی بات ہے کہ) وه کیسے اپنے پاس تورات ہوتے ہوئے جس میں احکام الٰہی ہیں تم کو منصف بناتے ہیں پھر اس کے بعد بھی پھر جاتے ہیں، دراصل یہ ایمان ویقین والے ہیں ہی نہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dccxiii{ہم نے تورات نازل فرمائی ہے جس میں ہدایت ونور ہے، یہودیوں میں اسی تورات کے ساتھ اللہ تعالیٰ کے ماننے والے انبیا (علیہم السلام) اور اہل اللہ اور علما فیصلے کرتے تھے کیونکہ انہیں اللہ کی اس کتاب کی حفاﻇت کا حکم دیا گیا تھا۔ اور وه اس پر اقراری گواه تھے اب تمہیں چاہیئے کہ لوگوں سے نہ ڈرو اور صرف میرا ڈر رکھو، میری آیتوں کو تھوڑے تھوڑے مول پر نہ بیچو، جو لوگ اللہ کی اتاری ہوئی وحی کے ساتھ فیصلے نہ کریں وه (پورے اور پختہ) کافر ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dccxiv{اور ہم نے یہودیوں کے ذمہ تورات میں یہ بات مقرر کر دی تھی کہ جان کے بدلے جان اور آنکھ کے بدلے آنکھ اور ناک کے بدلے ناک اور کان کے بدلے کان اور دانت کے بدلے دانت اور خاص زخموں کا بھی بدلہ ہے، پھر جو شخص اس کو معاف کردے تو وه اس کے لئے کفاره ہے، اور جو لوگ اللہ کے نازل کئے ہوئے کے مطابق حکم نہ کریں، وہی لوگ ﻇالم ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dccxv{اور ہم نے ان کے پیچھے عیسیٰ بن مریم کو بھیجا جو اپنے سے پہلے کی کتاب یعنی تورات کی تصدیق کرنے والے تھے اور ہم نے انہیں انجیل عطا فرمائی جس میں نور اور ہدایت تھی اور وه اپنے سے پہلے کی کتاب تورات کی تصدیق کرتی تھی اور وه سراسر ہدایت ونصیحت تھی پارسا لوگوں کے لئے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dccxvi{اور انجیل والوں کو بھی چاہئے کہ اللہ تعالیٰ نے جو کچھ انجیل میں نازل فرمایا ہے اسی کے مطابق حکم کریں اور جو اللہ تعالیٰ کے نازل کرده سے ہی حکم نہ کریں وه (بدکار) فاسق ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dccxvii{اور ہم نے آپ کی طرف حق کے ساتھ یہ کتاب نازل فرمائی ہے جو اپنے سے اگلی کتابوں کی تصدیق کرنے والی ہے اور ان کی محافﻆ ہے۔ اس لئے آپ ان کے آپس کے معاملات میں اسی اللہ کی اتاری ہوئی کتاب کے ساتھ حکم کیجیئے، اس حق سے ہٹ کر ان کی خواہشوں کے پیچھے نہ جائیے تم میں سے ہر ایک کے لئے ہم نے ایک دستور اور راه مقرر کردی ہے۔ اگر منظور مولیٰ ہوتا تو تم سب کو ایک ہی امت بنا دیتا، لیکن اس کی چاہت ہے کہ جو تمہیں دیا ہے اس میں تمہیں آزمائے، تم نیکیوں کی طرف جلدی کرو، تم سب کا رجوع اللہ ہی کی طرف ہے، پھر وه تمہیں ہر وه چیز بتا دے گا جس میں تم اختلاف کرتے رہتے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dccxviii{آپ ان کے معاملات میں خدا کی نازل کرده وحی کے مطابق ہی حکم کیا کیجیئے، ان کی خواہشوں کی تابعداری نہ کیجیئے اور ان سے ہوشیار رہیئے کہ کہیں یہ آپ کو اللہ کے اتارے ہوئے کسی حکم سے ادھر ادھر نہ کریں، اگر یہ لوگ منھ پھیر لیں تو یقین کریں کہ اللہ کا اراده یہی ہے کہ انہیں ان کے بعض گناہوں کی سزا دے ہی ڈالے اور اکثر لوگ نا فرمان ہی ہوتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dccxix{کیا یہ لوگ پھر سے جاہلیت کا فیصلہ چاہتے ہیں یقین رکھنے والے لوگوں کے لئے اللہ تعالیٰ سے بہتر فیصلے اور حکم کرنے واﻻ کون ہوسکتا ہے؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dccxx{اے ایمان والو! تم یہود ونصاریٰ کو دوست نہ بناؤ یہ تو آپس میں ہی ایک دوسرے کے دوست ہیں۔ تم میں سے جو بھی ان میں کسی سے دوستی کرے وه بےشک انہی میں سے ہے، ﻇالموں کو اللہ تعالیٰ ہرگز راه راست نہیں دکھاتا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dccxxi{آپ دیکھیں گے کہ جن کے دلوں میں بیماری ہے وه دوڑ دوڑ کر ان میں گھس رہے ہیں اور کہتے ہیں کہ ہمیں خطره ہے، ایسا نہ ہو کہ کوئی حادﺛہ ہم پر پڑ جائے بہت ممکن ہے کہ اللہ تعالیٰ فتح دے دے۔ یا اپنے پاس سے کوئی اور چیز ﻻئے پھر تو یہ اپنے دلوں میں چھپائی ہوئی باتوں پر (بے طرح) نادم ہونے لگیں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dccxxii{اور ایمان والے کہیں گے، کیا یہی وه لوگ ہیں جو بڑے مبالغہ سے اللہ کی قسمیں کھا کھا کر کہتے ہیں کہ ہم تمہارے ساتھ ہیں۔ ان کے اعمال غارت ہوئے اور یہ ناکام ہوگئے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dccxxiii{اے ایمان والو! تم میں سے جو شخص اپنے دین سے پھر جائے تو اللہ تعالیٰ بہت جلد ایسی قوم کو ﻻئے گا جو اللہ کی محبوب ہوگی اور وه بھی اللہ سے محبت رکھتی ہوگی وه نرم دل ہوں گے مسلمانوں پر اور سخت اور تیز ہوں گے کفار پر، اللہ کی راه میں جہاد کریں گے اور کسی ملامت کرنے والے کی ملامت کی پرواه بھی نہ کریں گے، یہ ہے اللہ تعالیٰ کا فضل جسے چاہے دے، اللہ تعالیٰ بڑی وسعت واﻻ اور زبردست علم واﻻ ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dccxxiv{(مسلمانو)! تمہارا دوست خود اللہ ہے اور اس کا رسول ہے اور ایمان والے ہیں جو نمازوں کی پابندی کرتے ہیں اور زکوٰة ادا کرتے ہیں اور وه رکوع (خشوع وخضوع) کرنے والے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dccxxv{اور جو شخص اللہ تعالیٰ سے اور اس کے رسول سے اور مسلمانوں سے دوستی کرے، وه یقین مانے کہ اللہ تعالیٰ کی جماعت ہی غالب رہے گی\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dccxxvi{مسلمانو! ان لوگوں کو دوست نہ بناؤ جو تمہارے دین کو ہنسی کھیل بنائے ہوئے ہیں (خواه) وه ان میں سے ہوں جو تم سے پہلے کتاب دیئے گئے یا کفار ہوں اگر تم مومن ہو تو اللہ تعالیٰ سے ڈرتے رہو۔\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dccxxvii{اور جب تم نماز کے لئے پکارتے ہو تو وہ اسے ہنسی کھیل ٹھرا لیتے ہیں۔ یہ اس واسطے کہ بےعقل ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dccxxviii{آپ کہہ دیجیئے اے یہودیوں اور نصرانیو! تم ہم سے صرف اس وجہ سے دشمنیاں کر رہے ہو کہ ہم اللہ تعالیٰ پر اور جو کچھ ہماری جانب نازل کیا گیا ہے اور جو کچھ اس سے پہلے اتارا گیا ہے اس پر ایمان ﻻئے ہیں اور اس لئے بھی کہ تم میں اکثر فاسق ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dccxxix{کہہ دیجیئے کہ کیا میں تمہیں بتاؤں؟ کہ اس سے بھی زیاده برے اجر پانے واﻻ اللہ تعالیٰ کے نزدیک کون ہے؟ وه جس پر اللہ تعالیٰ نے لعنت کی اور اس پر وه غصہ ہوا اور ان میں سے بعض کو بندر اور سور بنا دیا اور جنہوں نے معبودان باطل کی پرستش کی، یہی لوگ بدتر درجے والے ہیں اور یہی راه راست سے بہت زیاده بھٹکنے والے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dccxxx{اور جب تمہارے پاس آتے ہیں تو کہتے ہیں کہ ہم ایمان ﻻئے حاﻻنکہ وه کفر لئے ہوئے ہی آئے تھے اور اسی کفر کے ساتھ ہی گئے بھی اور یہ جو کچھ چھپا رہے ہیں اسے اللہ تعالیٰ خوب جانتا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dccxxxi{آپ دیکھیں گے کہ ان میں سے اکثر گناه کے کاموں کی طرف اور ﻇلم وزیادتی کی طرف اور مال حرام کھانے کی طرف لپک رہے ہیں، جو کچھ یہ کر رہے ہیں وه نہایت برے کام ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccxxxii{انہیں ان کے عابد وعالم جھوٹ باتوں کے کہنے اور حرام چیزوں کے کھانے سے کیوں نہیں روکتے، بےشک برا کام ہے جو یہ کر رہے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dccxxxiii{اور یہودیوں نے کہا کہ اللہ تعالیٰ کے ہاتھ بندھے ہوئے ہیں۔ انہی کے ہاتھ بندھے ہوئے ہیں اور ان کے اس قول کی وجہ سے ان پر لعنت کی گئی، بلکہ اللہ تعالیٰ کے دونوں ہاتھ کھلے ہوئے ہیں۔ جس طرح چاہتا ہے خرچ کرتا ہے اور جو کچھ تیری طرف تیرے رب کی جانب سے اتارا جاتا ہے وه ان میں سے اکثر کو تو سرکشی اور کفر میں اور بڑھا دیتا ہے اور ہم نے ان میں آپس میں ہی قیامت تک کے لئے عداوت اور بغض ڈال دیا ہے، وه جب کبھی لڑائی کی آگ کو بھڑکانا چاہتے ہیں تو اللہ تعالیٰ اسے بجھا دیتا ہے، یہ ملک بھر میں شر وفساد مچاتے پھرتے ہیں اور اللہ تعالیٰ فسادیوں سے محبت نہیں کرتا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dccxxxiv{اور اگر یہ اہل کتاب ایمان ﻻتے اور تقویٰ اختیار کرتے تو ہم ان کی تمام برائیاں معاف فرما دیتے اور ضرور انہیں راحت و آرام کی جنتوں میں لے جاتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccxxxv{اور اگر یہ لوگ تورات وانجیل اور ان کی جانب جو کچھ اللہ تعالیٰ کی طرف سے نازل فرمایا گیا ہے، ان کے پورے پابند رہتے تو یہ لوگ اپنے اوپر سے اور نیچے سے روزیاں پاتے اور کھاتے، ایک جماعت تو ان میں سے درمیانہ روش کی ہے، باقی ان میں سے بہت سے لوگوں کے برے اعمال ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccxxxvi{اے رسول جو کچھ بھی آپ کی طرف آپ کے رب کی جانب سے نازل کیا گیا ہے پہنچا دیجیئے۔ اگر آپ نے ایسا نہ کیا تو آپ نے اللہ کی رسالت ادا نہیں کی، اور آپ کو اللہ تعالیٰ لوگوں سے بچا لے گا بےشک اللہ تعالیٰ کافر لوگوں کو ہدایت نہیں دیتا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccxxxvii{آپ کہہ دیجیئے کہ اے اہل کتاب! تم دراصل کسی چیز پر نہیں جب تک کہ تورات وانجیل کو اور جو کچھ تمہاری طرف تمہارے رب کی سے طرف اتارا گیا ہے قائم نہ کرو، جو کچھ آپ کی جانب آپ کے رب کی طرف سے اترا ہے وه ان میں سے بہتوں کو شرارت اور انکار میں اور بھی بڑھائے گا ہی، تو آپ ان کافروں پر غمگین نہ ہوں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccxxxviii{مسلمان، یہودی، ستاره پرست اور نصرانی کوئی ہو، جو بھی اللہ تعالیٰ پر اور قیامت کے دن پر ایمان ﻻئے اور نیک عمل کرے وه محض بےخوف رہے گا اور بالکل بے غم ہوجائے گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccxxxix{ہم نے بالیقین بنیاسرائیل سے عہد وپیمان لیا اور ان کی طرف رسولوں کو بھیجا، جب کبھی رسول ان کے پاس وه احکام لے کر آئے جو ان کی اپنی منشا کے خلاف تھے تو انہوں نے ان کی ایک جماعت کی تکذیب کی اور ایک جماعت کو قتل کردیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccxl{اور سمجھ بیٹھے کہ کوئی پکڑ نہ ہوگی، پس اندھے بہرے بن بیٹھے، پھر اللہ تعالیٰ نے ان کی توبہ قبول کی، اس کے بعد بھی ان میں سے اکثر اندھے بہرے ہوگئے۔ اللہ تعالیٰ ان کے اعمال کو بخوبی دیکھنے واﻻ ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccxli{بے شک وه لوگ کافر ہوگئے جن کا قول ہے کہ مسیح ابن مریم ہی اللہ ہے حاﻻنکہ خود مسیح نے ان سے کہا تھا کہ اے بنی اسرائیل! اللہ ہی کی عبادت کرو جو میرا اور تمہارا سب کا رب ہے، یقین مانو کہ جو شخص اللہ کے ساتھ شریک کرتا ہے اللہ تعالیٰ نے اس پر جنت حرام کر دی ہے، اس کا ٹھکانہ جہنم ہی ہے اور گنہگاروں کی مدد کرنے واﻻ کوئی نہیں ہوگا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccxlii{وه لوگ بھی قطعاً کافر ہوگئے جنہوں نے کہا، اللہ تین میں کا تیسرا ہے، دراصل سوا اللہ تعالیٰ کے کوئی معبود نہیں۔ اگر یہ لوگ اپنے اس قول سے باز نہ رہے تو ان میں سے جو کفر پر رہیں گے، انہیں المناک عذاب ضرور پہنچے گا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccxliii{یہ لوگ کیوں اللہ تعالیٰ کی طرف نہیں جھکتے اور کیوں استغفار نہیں کرتے؟ اللہ تعالیٰ تو بہت ہی بخشنے واﻻ اور بڑا ہی مہربان ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccxliv{مسیح ابن مریم سوا پیغمبر ہونے کے اور کچھ بھی نہیں، اس سے پہلے بھی بہت سے پیغمبر ہوچکے ہیں ان کی والده ایک راست باز عورت تھیں دونوں ماں بیٹے کھانا کھایا کرتے تھے، آپ دیکھیے کہ کس طرح ہم ان کے سامنے دلیلیں رکھتے ہیں پھر غور کیجیئے کہ کس طرح وه پھرے جاتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccxlv{آپ کہہ دیجیئے کہ کیا تم اللہ کے سوا ان کی عبادت کرتے ہو جو نہ تمہارے کسی نقصان کے مالک ہیں نہ کسی نفع کے، اللہ ہی خوب سننے اور پوری طرح جاننے واﻻ ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccxlvi{کہہ دیجیئے اے اہل کتاب! اپنے دین میں ناحق غلو اور زیادتی نہ کرو اور ان لوگوں کی نفسانی خواہشوں کی پیروی نہ کرو جو پہلے سے بہک چکے ہیں اور بہتوں کو بہکا بھی چکے ہیں اور سیدھی راه سے ہٹ گئے ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccxlvii{بنی اسرائیل کے کافروں پر (حضرت) داؤد (علیہ السلام) اور (حضرت) عیسیٰ بن مریم (علیہ السلام) کی زبانی لعنت کی گئی اس وجہ سے کہ وه نافرمانیاں کرتے تھے اور حد سے آگے بڑھ جاتے تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccxlviii{آپس میں ایک دوسرے کو برے کاموں سے جو وه کرتے تھے روکتے نہ تھے جو کچھ بھی یہ کرتے تھے یقیناً وه بہت برا تھا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccxlix{ان میں سے بہت سے لوگوں کو آپ دیکھیں گے کہ وه کافروں سے دوستیاں کرتے ہیں، جو کچھ انہوں نے اپنے لئے آگے بھیج رکھا ہے وه بہت برا ہے کہ اللہ تعالیٰ ان سے ناراض ہوا اور وه ہمیشہ عذاب میں رہیں گے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccl{اگر انہیں اللہ تعالیٰ پر اور نبی پر اور جو نازل کیا گیا ہے اس پر ایمان ہوتا تو یہ کفار سے دوستیاں نہ کرتے، لیکن ان میں کے اکثر لوگ فاسق ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccli{یقیناً آپ ایمان والوں کا سب سے زیاده دشمن یہودیوں اور مشرکوں کو پائیں گے اور ایمان والوں سے سب سے زیاده دوستی کے قریب آپ یقیناً انہیں پائیں گے جو اپنے آپ کو نصاریٰ کہتے ہیں، یہ اس لئے کہ ان میں علما اور عبادت کے لئے گوشہ نشین افراد پائے جاتے ہیں اور اس وجہ سے کہ وه تکبر نہیں کرتے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dcclii{اور جب وه رسول کی طرف نازل کرده (کلام) کو سنتے ہیں تو آپ ان کی آنکھیں آنسو سے بہتی ہوئی دیکھتے ہیں اس سبب سے کہ انہوں نے حق کو پہچان لیا، وه کہتے ہیں کہ اے ہمارے رب! ہم ایمان لے آئے پس تو ہم کو بھی ان لوگوں کے ساتھ لکھ لے جو تصدیق کرتے ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccliii{اور ہمارے پاس کون سا عذر ہے کہ ہم اللہ تعالیٰ پر اور جو حق ہم کو پہنچا ہے اس پر ایمان نہ ﻻئیں اور ہم اس بات کی امید رکھتے ہیں کہ ہمارا رب ہم کو نیک لوگوں کی رفاقت میں داخل کردے گا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccliv{اس لئے ان کو اللہ تعالیٰ ان کے اس قول کی وجہ سے ایسے باغ دے گا جن کے نیچے نہریں جاری ہوں گی، یہ ان میں ہمیشہ ہمیشہ رہیں گے اور نیک لوگوں کا یہی بدلہ ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dcclv{اور جن لوگوں نے کفر کیا اور ہماری آیات کو جھٹلاتے رہے وه لوگ دوزخ والے ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dcclvi{اے ایمان والو! اللہ تعالیٰ نے جو پاکیزه چیزیں تمہارے واسطے حلال کی ہیں ان کو حرام مت کرو اور حد سے آگے مت نکلو، بےشک اللہ تعالیٰ حد سے نکلنے والوں کو پسند نہیں کرتا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dcclvii{اور اللہ تعالیٰ نے جو چیزیں تم کو دی ہیں ان میں سے حلال مرغوب چیزیں کھاؤ اور اللہ تعالیٰ سے ڈرو جس پر تم ایمان رکھتے ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dcclviii{اللہ تعالیٰ تمہاری قسموں میں لغو قسم پر تم سے مؤاخذہ نہیں فرماتا لیکن مؤاخذہ اس پر فرماتا ہے کہ تم جن قسموں کو مضبوط کردو۔ اس کا کفاره دس محتاجوں کو کھانا دینا ہے اوسط درجے کا جو اپنے گھر والوں کو کھلاتے ہو یا ان کو کپڑا دینا یا ایک غلام یا لونڈی آزاد کرنا ہے اور جس کو مقدور نہ ہو تو تین دن کے روزے ہیں یہ تمہاری قسموں کا کفاره ہے جب کہ تم قسم کھا لو اور اپنی قسموں کا خیال رکھو! اسی طرح اللہ تعالیٰ تمہارے واسطے اپنے احکام بیان فرماتا ہے تاکہ تم شکر کرو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dcclix{اے ایمان والو! بات یہی ہے کہ شراب اور جوا اور تھان اور فال نکالنے کے پانسے کے تیر، یہ سب گندی باتیں، شیطانی کام ہیں ان سے بالکل الگ رہو تاکہ تم فلاح یاب ہو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dcclx{شیطان تو یوں چاہتا ہے کہ شراب اور جوئے کے ذریعے سے تمہارے آپس میں عداوت اور بغض واقع کرا دے اور اللہ تعالیٰ کی یاد سے اور نماز سے تم کو باز رکھے سو اب بھی باز آجاؤ\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dcclxi{اور تم اللہ تعالیٰ کی اطاعت کرتے رہو اور رسول کی اطاعت کرتے رہو اور احتیاط رکھو۔ اگر اعراض کرو گے تو یہ جان رکھو کہ ہمارے رسول کے ذمہ صرف صاف صاف پہنچا دینا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dcclxii{ایسے لوگوں پر جو کہ ایمان رکھتے ہوں اور نیک کام کرتے ہوں اس چیز میں کوئی گناه نہیں جس کو وه کھاتے پیتے ہوں جبکہ وه لوگ تقویٰ رکھتے ہوں اور ایمان رکھتے ہوں اور نیک کام کرتے ہوں پھر پرہیزگاری کرتے ہوں اور ایمان رکھتے ہوں پھر پرہیزگاری کرتے ہوں اور خوب نیک عمل کرتے ہوں، اللہ ایسے نیکوکاروں سے محبت رکھتا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dcclxiii{اے ایمان والو! اللہ تعالیٰ قدرے شکار سے تمہارا امتحان کرے گا جن تک تمہارے ہاتھ اور تمہارے نیزے پہنچ سکیں گے تاکہ اللہ تعالیٰ معلوم کرلے کہ کون شخص اس سے بن دیکھے ڈرتا ہے سو جو شخص اس کے بعد حد سے نکلے گا اس کے واسطے دردناک سزا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dcclxiv{اے ایمان والو! (وحشی) شکار کو قتل مت کرو جب کہ تم حالت احرام میں ہو۔ اور جو شخص تم میں سے اس کو جان بوجھ کر قتل کرے گا تو اس پر فدیہ واجب ہوگا جو کہ مساوی ہوگا اس جانور کے جس کو اس نے قتل کیا ہے جس کا فیصلہ تم میں سے دو معتبر شخص کردیں خواه وه فدیہ خاص چوپایوں میں سے ہو جو نیاز کے طور پر کعبہ تک پہنچایا جائے اور خواه کفاره مساکین کو دے دیا جائے اور خواه اس کے برابر روزے رکھ لئے جائیں تاکہ اپنے کئے شامت کا مزه چکھے، اللہ تعالیٰ نے گذشتہ کو معاف کردیا اور جو شخص پھر ایسی ہی حرکت کرے گا تو اللہ انتقام لے گا اور اللہ زبردست ہے انتقام لینے واﻻ\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dcclxv{تمہارے لئے دریا کا شکار پکڑنا اور اس کا کھانا حلال کیا گیا ہے۔ تمہارے فائده کے واسطے اور مسافروں کے واسطے اور خشکی کا شکار پکڑنا تمہارے لئے حرام کیا گیا ہے جب تک تم حالت احرام میں رہو اور اللہ تعالیٰ سے ڈرو جس کے پاس جمع کئے جاؤ گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dcclxvi{اللہ نے کعبہ کو جو ادب کا مکان ہے لوگوں کے قائم رہنے کا سبب قرار دے دیا اور عزت والے مہینہ کو بھی اور حرم میں قربانی ہونے والے جانور کو بھی اور ان جانوروں کو بھی جن کے گلے میں پٹے ہوں یہ اس لئے تاکہ تم اس بات کا یقین کر لو کہ بےشک اللہ تمام آسمانوں اور زمین کے اندر کی چیزوں کا علم رکھتا ہے اور بےشک اللہ سب چیزوں کو خوب جانتا ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dcclxvii{تم یقین جانو کہ اللہ تعالیٰ سزا بھی سخت دینے واﻻ ہے اور اللہ تعالیٰ بڑی مغفرت اور بڑی رحمت واﻻ بھی ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dcclxviii{رسول کے ذمہ تو صرف پہنچانا ہے۔ اور اللہ تعالیٰ سب جانتا ہے جو کچھ تم ﻇاہر کرتے ہو اور جو کچھ پوشیده رکھتے ہو\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dcclxix{آپ فرما دیجیئے کہ ناپاک اور پاک برابر نہیں گو آپ کو ناپاک کی کثرت بھلی لگتی ہو اللہ تعالیٰ سے ڈرتے رہو اے عقل مندو! تاکہ تم کامیاب ہو\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcclxx{اے ایمان والو! ایسی باتیں مت پوچھو کہ اگر تم پر ﻇاہر کر دی جائیں تو تمہیں ناگوار ہوں اور اگر تم زمانہٴ نزول قرآن میں ان باتوں کو پوچھو گے تو تم پر ﻇاہر کردی جائیں گی سواﻻت گزشتہ اللہ نے معاف کردیئے اور اللہ بڑی مغفرت واﻻ بڑے حلم واﻻ ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcclxxi{ایسی باتیں تم سے پہلے اور لوگوں نے بھی پوچھی تھیں، پھر ان باتوں کے منکر ہوگئے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcclxxii{اللہ تعالیٰ نے نہ بحیره کو مشروع کیا ہے اور نہ سائبہ کو اور نہ وصیلہ کو اور نہ حام کو لیکن جو لوگ کافر ہیں وه اللہ تعالیٰ پر جھوٹ لگاتے ہیں اور اکثر کافر عقل نہیں رکھتے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcclxxiii{اور جب ان سے کہا جاتا ہے کہ اللہ تعالیٰ نے جو احکام نازل فرمائے ہیں ان کی طرف اور رسول کی طرف رجوع کرو تو کہتے ہیں کہ ہم کو وہی کافی ہے جس پر ہم نے اپنے بڑوں کو پایا، کیا اگر چہ ان کے بڑے نہ کچھ سمجھ رکھتے ہوں اور نہ ہدایت رکھتے ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcclxxiv{اے ایمان والوں! اپنی فکر کرو، جب تم راه راست پر چل رہے ہو تو جو شخص گمراه رہے اس سے تمہارا کوئی نقصان نہیں۔ اللہ ہی کے پاس تم سب کو جانا ہے پھر وه تم سب کو بتلا دے گا جو کچھ تم سب کرتے تھے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcclxxv{اے ایمان والو! تمہارے آپس میں دو شخص کا گواه ہونا مناسب ہے جبکہ تم میں سے کسی کو موت آنے لگے اور وصیت کرنے کا وقت ہو وه دو شخص ایسے ہوں کہ دیندار ہوں خواه تم میں سے ہوں یا غیر لوگوں میں سے دو شخص ہوں اگر تم کہیں سفر میں گئے ہو اور تمہیں موت آ جائے اگر تم کو شبہ ہو تو ان دونوں کو بعد نماز روک لو پھر دونوں اللہ کی قسم کھائیں کہ ہم اس قسم کے عوض کوئی نفع نہیں لینا چاہتے اگر چہ کوئی قرابت دار بھی ہو اور اللہ تعالیٰ کی بات کو ہم پوشیده نہ کریں گے، ہم اس حالت میں سخت گنہگار ہوں گے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcclxxvi{پھر اگر اس کی اطلاع ہو کہ وه دونوں گواه کسی گناه کے مرتکب ہوئے ہیں تو ان لوگوں میں سے جن کے مقابلہ میں گناه کا ارتکاب ہوا تھا اور دو شخص جو سب میں قریب تر ہیں جہاں وه دونوں کھڑے ہوئے تھے یہ دونوں کھڑے ہوں پھر دونوں اللہ کی قسم کھائیں کہ بالیقین ہماری یہ قسم ان دونوں کی اس قسم سے زیاده راست ہے اور ہم نے ذرا تجاوز نہیں کیا، ہم اس حالت میں سخت ﻇالم ہوں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcclxxvii{یہ قریب ذریعہ ہے اس امر کا کہ وه لوگ واقعہ کو ٹھیک طور پر ﻇاہر کریں یا اس بات سے ڈر جائیں کہ ان سے قسمیں لینے کے بعد قسمیں الٹی پڑ جائیں گی اور اللہ تعالیٰ سے ڈرو اور سنو! اور اللہ تعالیٰ فاسق لوگوں کو ہدایت نہیں کرتا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcclxxviii{جس روز اللہ تعالیٰ تمام پیغمبروں کو جمع کرے گا، پھر ارشاد فرمائے گا کہ تم کو کیا جواب ملا تھا، وه عرض کریں گے کہ ہم کو کچھ خبر نہیں تو ہی بےشک پوشیده باتوں کو پورا جاننے واﻻ ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcclxxix{جب کہ اللہ تعالیٰ ارشاد فرمائے گا کہ اے عیسیٰ بن مریم! میرا انعام یاد کرو جو تم پر اور تمہاری والده پر ہوا ہے، جب میں نے تم کو روح القدس سے تائید دی۔ تم لوگوں سے کلام کرتے تھے گود میں بھی اور بڑی عمر میں بھی اور جب کہ میں نے تم کو کتاب اور حکمت کی باتیں اور تورات اور انجیل کی تعلیم دی اور جب کہ تم میرے حکم سے گارے سے ایک شکل بناتے تھے جیسے پرنده کی شکل ہوتی ہے پھر تم اس کے اندر پھونک مار دیتے تھے جس سے وه پرند بن جاتا تھا میرے حکم سے اور تم اچھا کر دیتے تھے مادرزاد اندھے کو اور کوڑھی کو میرے حکم سے اور جب کہ تم مردوں کو نکال کر کھڑا کرلیتے تھے میرے حکم سے اور جب کہ میں نے بنی اسرائیل کو تم سے باز رکھا جب تم ان کے پاس دلیلیں لے کر آئے تھے پھر ان میں جو کافر تھے انہوں نے کہا تھا کہ بجز کھلے جادو کے یہ اور کچھ بھی نہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dcclxxx{اور جب کہ میں نے حواریین کو حکم دیا کہ تم مجھ پر اور میرے رسول پر ایمان ﻻؤ، انہوں نے کہا کہ ہم ایمان ﻻئے اور آپ شاہد رہیئے کہ ہم پورے فرماں بردار ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcclxxxi{وه وقت یاد کے قابل ہے جب کہ حواریوں نے عرض کیا کہ اے عیسیٰ بن مریم! کیا آپ کا رب ایسا کرسکتا ہے کہ ہم پر آسمان سے ایک خوان ﴿دسترخوان﴾ نازل فرما دے؟ آپ نے فرمایا کہ اللہ سے ڈرو اگر تم ایمان والے ہو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcclxxxii{وه بولے کہ ہم یہ چاہتے ہیں کہ اس میں سے کھائیں اور ہمارے دلوں کو پورا اطمینان ہوجائے اور ہمارا یہ یقین اور بڑھ جائے کہ آپ نے ہم سے سچ بوﻻ ہے اور ہم گواہی دینے والوں میں سے ہوجائیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiii{عیسیٰ ابن مریم نے دعا کی کہ اے اللہ اے ہمارے پروردگار! ہم پر آسمان سے کھانا نازل فرما! کہ وه ہمارے لئے یعنی ہم میں جو اول ہیں اور جو بعد کے ہیں سب کے لئے ایک خوشی کی بات ہوجائے اور تیری طرف سے ایک نشانی ہوجائے اور تو ہم کو رزق عطا فرمادے اور تو سب عطا کرنے والوں سے اچھا ہے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiv{حق تعالیٰ نے ارشاد فرمایا کہ میں وه کھانا تم لوگوں پر نازل کرنے واﻻ ہوں، پھر جو شخص تم میں سے اس کے بعد ناحق شناسی کرے گا تو میں اس کو ایسی سزا دوں گا کہ وه سزا دنیا جہان والوں میں سے کسی کو نہ دوں گا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcclxxxv{اور وه وقت بھی قابل ذکر ہے جب کہ اللہ تعالیٰ فرمائے گا کہ اے عیسیٰ ابن مریم! کیا تم نے ان لوگوں سے کہہ دیا تھا کہ مجھ کو اور میری ماں کو بھی علاوه اللہ کے معبود قرار دے لو! عیسیٰ عرض کریں گے کہ میں تو تجھ کو منزہ سمجھتا ہوں، مجھ کو کسی طرح زیبا نہ تھا کہ میں ایسی بات کہتا جس کے کہنے کا مجھ کو کوئی حق نہیں، اگر میں نے کہا ہوگا تو تجھ کو اس کا علم ہوگا۔ تو، تو میرے دل کے اندر کی بات بھی جانتا ہے اور میں تیرے نفس میں جو کچھ ہے اس کو نہیں جانتا۔ تمام غیبوں کا جاننے واﻻ تو ہی ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvi{میں نے تو ان سے اور کچھ نہیں کہا مگر صرف وہی جو تو نے مجھ سے کہنے کو فرمایا تھا کہ تم اللہ کی بندگی اختیار کرو جو میرا بھی رب ہے اور تمہارا بھی رب ہے۔ میں ان پر گواه رہا جب تک ان میں رہا۔ پھر جب تو نے مجھ کو اٹھا لیا تو، تو ہی ان پر مطلع رہا۔ اور تو ہر چیز کی پوری خبر رکھتا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvii{اگر تو ان کو سزا دے تو یہ تیرے بندے ہیں اور اگر تو ان کو معاف فرما دے تو، تو زبردست ہے حکمت واﻻ ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcclxxxviii{اللہ ارشاد فرمائے گا کہ یہ وه دن ہے کہ جو لوگ سچے تھے ان کا سچا ہونا ان کے کام آئے گا ان کو باغ ملیں گے جن کے نیچے نہریں جاری ہوں گی جن میں وه ہمیشہ ہمیشہ کو رہیں گے۔ اللہ تعالیٰ ان سے راضی اور خوش اور یہ اللہ سے راضی اور خوش ہیں، یہ بڑی (بھاری) کامیابی ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcclxxxix{اللہ ہی کی ہے سلطنت آسمانوں کی اور زمین کی اور ان چیزوں کی جو ان میں موجود ہیں اور وه ہر شے پر پوری قدرت رکھتا ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dccxc{\basmalahur تمام تعریفیں اللہ ہی کے ﻻئق ہیں جس نے آسمانوں کو اور زمین کو پیدا کیا اور تاریکیوں اور نور کو بنایا پھر بھی کافر لوگ (غیر اللہ کو) اپنے رب کے برابر قرار دیتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dccxci{وه ایسا ہے جس نے تم کو مٹی سے بنایا پھر ایک وقت معین کیا اور (دوسرا) معین وقت خاص اللہ ہی کے نزدیک ہے پھر بھی تم شک رکھتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dccxcii{اور وہی ہے معبود برحق آسمانوں میں بھی اور زمین میں بھی، وه تمہارے پوشیده احوال کو بھی اور تمہارے ﻇاہر احوال کو بھی جانتا ہے اور تم جو کچھ عمل کرتے ہو اس کو بھی جانتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dccxciii{اور ان کے پاس کوئی نشانی بھی ان کے رب کی نشانیوں میں نہیں آتی مگر وه اس سے اعراض ہی کرتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dccxciv{انہوں نے اس سچی کتاب کو بھی جھٹلایا جب کہ وه ان کے پاس پہنچی، سو جلدی ہی ان کو خبر مل جائے گی اس چیز کی جس کے ساتھ یہ لوگ استہزا کیا کرتے تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dccxcv{کیا انہوں نے دیکھا نہیں کہ ہم ان سے پہلے کتنی جماعتوں کو ہلاک کرچکے ہیں جن کو ہم نے دنیا میں ایسی قوت دی تھی کہ تم کو وه قوت نہیں دی اور ہم نے ان پر خوب بارشیں برسائیں اور ہم نے ان کے نیچے سے نہریں جاری کیں۔ پھر ہم نے ان کو ان کے گناہوں کے سبب ہلاک کر ڈاﻻ اور ان کے بعد دوسری جماعتوں کو پیدا کر دیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dccxcvi{اور اگر ہم کاغذ پر لکھا ہوا کوئی نوشتہ آپ پر نازل فرماتے پھر اس کو یہ لوگ اپنے ہاتھوں سے چھو بھی لیتے تب بھی یہ کافر لوگ یہی کہتے کہ یہ کچھ بھی نہیں مگر صریح جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dccxcvii{اور یہ لوگ یوں کہتے ہیں کہ ان کے پاس کوئی فرشتہ کیوں نہیں اتارا گیا اور اگر ہم کوئی فرشتہ بھیج دیتے تو سارا قصہ ہی ختم ہوجاتا۔ پھر ان کو ذرا مہلت نہ دی جاتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dccxcviii{اور اگر ہم اس کو فرشتہ تجویز کرتے تو ہم اس کو آدمی ہی بناتے اور ہمارے اس فعل سے پھر ان پر وہی اشکال ہوتا جو اب اشکال کر رہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dccxcix{اور واقعی آپ سے پہلے جو پیغمبر ہوئے ہیں ان کے ساتھ بھی استہزا کیا گیا ہے۔ پھر جن لوگوں نے ان سے مذاق کیا تھا ان کو اس عذاب نے آ گھیرا جس کا تمسخر اڑاتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dccc{آپ فرما دیجئے کہ ذرا زمین میں چلو پھرو پھر دیکھ لو کہ تکذیب کرنے والوں کا کیا انجام ہوا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dccci{آپ کہئے کہ جو کچھ آسمانوں اور زمین میں موجود ہے یہ سب کس کی ملکیت ہے، آپ کہہ دیجئے کہ سب اللہ ہی کی ملکیت ہے، اللہ نے مہربانی فرمانا اپنے اوپر ﻻزم فرما لیا ہے تم کو اللہ قیامت کے روز جمع کرے گا، اس میں کوئی شک نہیں، جن لوگوں نے اپنے آپ کو گھاٹے میں ڈاﻻ ہے سو وه ایمان نہیں ﻻئیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dcccii{اور اللہ ہی کی ملک ہیں وه سب کچھ جو رات میں اور دن میں رہتی ہیں اور وہی بڑا سننے واﻻ بڑا جاننے واﻻ ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dccciii{آپ کہیے کہ کیا اللہ کے سوا، جو کہ آسمانوں اور زمین کا پیدا کرنے واﻻ ہے اور جو کہ کھانے کو دیتا ہے اور اس کو کوئی کھانے کو نہیں دیتا، اور کسی کو معبود قرار دوں، آپ فرما دیجئے کہ مجھ کو یہ حکم ہوا ہے کہ سب سے پہلے میں اسلام قبول کروں اور تو مشرکین میں ہرگز نہ ہونا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dccciv{آپ کہہ دیجئے کہ میں اگر اپنے رب کا کہنا نہ مانوں تو میں ایک بڑے دن کے عذاب سے ڈرتا ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dcccv{جس شخص سے اس روز وه عذاب ہٹا دیا جائے تو اس پر اللہ نے بڑا رحم کیا اور یہ صریح کامیابی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dcccvi{اور اگر تجھ کو اللہ تعالیٰ کوئی تکلیف پہنچائے تو اس کا دور کرنے واﻻ سوائے اللہ تعالیٰ کے اور کوئی نہیں۔ اور اگر تجھ کو اللہ تعالیٰ کوئی نفع پہنچائے تو وه ہر چیز پر پوری قدرت رکھنے واﻻ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dcccvii{اور وہی اللہ اپنے بندوں کے اوپر غالب ہے برتر ہے اور وہی بڑی حکمت واﻻ اور پوری خبر رکھنے واﻻ ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dcccviii{آپ کہئے کہ سب سے بڑی چیز گواہی دینے کے لئے کون ہے، آپ کہئے کہ میرے اور تمہارے درمیان اللہ گواه ہے اور میرے پاس یہ قرآن بطور وحی کے بھیجا گیا ہے تاکہ میں اس قرآن کے ذریعے سے تم کو اور جس جس کو یہ قرآن پہنچے ان سب کو ڈراؤں کیا تم سچ مچ یہی گواہی دو گے کہ اللہ تعالیٰ کے ساتھ کچھ اور معبود بھی ہیں، آپ کہہ دیجئے کہ میں تو گواہی نہیں دیتا۔ آپ فرما دیجئے کہ بس وه تو ایک ہی معبود ہے اور بےشک میں تمہارے شرک سے بیزار ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dcccix{جن لوگوں کو ہم نے کتاب دی ہے وه لوگ رسول کو پہچانتے ہیں جس طرح اپنے بیٹوں کو پہنچانتے ہیں۔ جن لوگوں نے اپنے آپ کو گھاٹے میں ڈاﻻ ہے سو وه ایمان نہیں ﻻئیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcccx{اور اس سے زیاده بےانصاف کون ہوگا جو اللہ تعالیٰ پر جھوٹ بہتان باندھے یا اللہ کی آیات کو جھوٹا بتلائے ایسے بےانصافوں کو کامیابی نہ ہوگی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcccxi{اور وه وقت بھی یاد کرنے کے قابل ہے جس روز ہم ان تمام خلائق کو جمع کریں گے، پھر ہم مشرکین سے کہیں گے کہ تمہارے وه شرکا، جن کے معبود ہونے کا تم دعویٰ کرتے تھے، کہاں گئے؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcccxii{پھر ان کے شرک کا انجام اس کے سوا اور کچھ بھی نہ ہوگا کہ وه یوں کہیں گے کہ قسم اللہ کی اپنے پروردگار کی ہم مشرک نہ تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcccxiii{ذرا دیکھو تو انہوں نے کس طرح جھوٹ بوﻻ اپنی جانوں پر اور جن چیزوں کو وه جھوٹ موٹ تراشا کرتے تھے وه سب غائب ہوگئے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcccxiv{اور ان میں بعض ایسے ہیں کہ آپ کی طرف کان لگاتے ہیں اور ہم نے ان کے دلوں پر پرده ڈال رکھا ہے اس سے کہ وه اس کو سمجھیں اور ان کے کانوں میں ڈاٹ دے رکھی ہے اور اگر وه لوگ تمام دﻻئل کو دیکھ لیں تو بھی ان پر کبھی ایمان نہ ﻻئیں، یہاں تک کہ جب یہ لوگ آپ کے پاس آتے ہیں تو آپ سے خواه مخواه جھگڑتے ہیں، یہ لوگ جو کافر ہیں یوں کہتے ہیں کہ یہ تو کچھ بھی نہیں صرف بے سند باتیں ہیں جو پہلوں سے چلی آ رہی ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcccxv{اور یہ لوگ اس سے دوسروں کو بھی روکتے ہیں اور خود بھی اس سے دور دور رہتے ہیں اور یہ لوگ اپنے ہی کو تباه کر رہے ہیں اور کچھ خبر نہیں رکھتے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcccxvi{اور اگر آپ اس وقت دیکھیں جب کہ یہ دوزخ کے پاس کھڑے کئے جائیں تو کہیں گے ہائے کیا اچھی بات ہو کہ ہم پھر واپس بھیج دیئے جائیں اور اگر ایسا ہو جائے تو ہم اپنے رب کی آیات کو جھوٹا نہ بتلائیں اور ہم ایمان والوں میں سے ہو جائیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcccxvii{بلکہ جس چیز کو اس کے قبل چھپایا کرتے تھے وه ان کے سامنے آگئی ہے اور اگر یہ لوگ پھر واپس بھیج دیئے جائیں تب بھی یہ وہی کام کریں گے جس سے ان کو منع کیا گیا تھا اور یقیناً یہ بالکل جھوٹے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcccxviii{اور یہ کہتے ہیں کہ صرف یہی دنیاوی زندگی ہماری زندگی ہے اور ہم زنده نہ کئے جائیں گے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcccxix{اور اگر آپ اس وقت دیکھیں جب یہ اپنے رب کے سامنے کھڑے کئے جائیں گے۔ اللہ فرمائے گا کہ کیا یہ امر واقعی نہیں ہے؟ وه کہیں گے بےشک قسم اپنے رب کی۔ اللہ تعالیٰ فرمائے گا تو اب اپنے کفر کے عوض عذاب چکھو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcccxx{بےشک خساره میں پڑے وه لوگ جنہوں نے اللہ سے ملنے کی تکذیب کی، یہاں تک کہ جب وه معین وقت ان پر دفعتاً آ پہنچے گا، کہیں گے کہ ہائے افسوس ہماری کوتاہی پر جو اس کے بارے میں ہوئی، اور حالت ان کی یہ ہوگی کہ وه اپنے بار اپنی پیٹھوں پر ﻻدے ہوں گے، خوب سن لو کہ بری ہوگی وه چیز جس کو وه ﻻدیں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcccxxi{اور دنیاوی زندگانی تو کچھ بھی نہیں بجز لہو ولعب کے۔ اور دار آخرت متقیوں کے لئے بہتر ہے۔ کیا تم سوچتے سمجھتے نہیں ہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dcccxxii{ہم خوب جانتے ہیں کہ آپ کو ان کے اقوال مغموم کرتے ہیں، سو یہ لوگ آپ کو جھوٹا نہیں کہتے لیکن یہ ﻇالم تو اللہ کی آیتوں کا انکار کرتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcccxxiii{اور بہت سے پیغمبر جو آپ سے پہلے ہوئے ہیں ان کی بھی تکذیب کی جا چکی ہے سو انہوں نے اس پر صبر ہی کیا، ان کی تکذیب کی گئی اور ان کو ایذائیں پہنچائی گئیں یہاں تک کہ ہماری امداد ان کو پہنچی اور اللہ کی باتوں کا کوئی بدلنے واﻻ نہیں اور آپ کے پاس بعض پیغمبروں کی بعض خبریں پہنچ چکی ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcccxxiv{اور اگر آپ کو ان کا اعراض گراں گزرتا ہے تو اگر آپ کو یہ قدرت ہے کہ زمین میں کوئی سرنگ یا آسمان میں کوئی سیڑھی ڈھونڈ لو پھر کوئی معجزه لے آؤ تو کرو اور اگر اللہ کو منظور ہوتا تو ان سب کو راه راست پر جمع کر دیتا سو آپ نادانوں میں سے نہ ہوجائیے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dcccxxv{وہی لوگ قبول کرتے ہیں جو سنتے ہیں۔ اور مُردوں کو اللہ زنده کر کے اٹھائے گا پھر سب اللہ ہی کی طرف ﻻئے جائیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dcccxxvi{اور یہ لوگ کہتے ہیں کہ ان پر کوئی معجزه کیوں نہیں نازل کیا گیا ان کے رب کی طرف سے آپ فرما دیجئے کہ اللہ تعالیٰ کو بےشک پوری قدرت ہے اس پر کہ وه معجزه نازل فرمادے۔ لیکن ان میں اکثر بےخبر ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dcccxxvii{اور جتنے قسم کے جاندار زمین پر چلنے والے ہیں اور جتنے قسم کے پرند جانور ہیں کہ اپنے دونوں بازوؤں سے اڑتے ہیں ان میں کوئی قسم ایسی نہیں جو کہ تمہاری طرح کے گروه نہ ہوں، ہم نے دفتر میں کوئی چیز نہیں چھوڑی پھر سب اپنے پروردگار کے پاس جمع کئے جائیں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dcccxxviii{اور جو لوگ ہماری آیتوں کی تکذیب کرتے ہیں وه تو طرح طرح کی ﻇلمتوں میں بہرے گونگے ہو رہے ہیں، اللہ جس کو چاہے بے راه کردے اور وه جس کو چاہے سیدھی راه پر لگا دے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dcccxxix{آپ کہیے کہ اپنا حال تو بتلاؤ کہ اگر تم پر اللہ کا کوئی عذاب آ پڑے یا تم پر قیامت ہی آ پہنچے تو کیا اللہ کے سوا کسی اور کو پکارو گے۔ اگر تم سچے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dcccxxx{بلکہ خاص اسی کو پکارو گے، پھر جس کے لئے تم پکارو گے اگر وه چاہے تو اس کو ہٹا بھی دے اور جن کو تم شریک ٹھہراتے ہو ان سب کو بھول بھال جاؤ گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dcccxxxi{اور ہم نے اور امتوں کی طرف بھی جو کہ آپ سے پہلے گزر چکی ہیں پیغمبر بھیجے تھے، سو ہم نے ان کو تنگدستی اور بیماری سے پکڑا تاکہ وه اﻇہار عجز کرسکیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dcccxxxii{سو جب ان کو ہماری سزا پہنچی تھی تو انہوں نے عاجزی کیوں نہیں اختیار کی؟ لیکن ان کے قلوب سخت ہوگئے اور شیطان نے ان کے اعمال کو ان کے خیال میں آراستہ کردیا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiii{پھر جب وه لوگ ان چیزوں کو بھولے رہے جن کی ان کو نصیحت کی جاتی تھی تو ہم نے ان پر ہر چیز کے دروازے کشاده کردئے یہاں تک کہ جب ان چیزوں پر جو کہ ان کو ملی تھیں وه خوب اترا گئے ہم نے ان کو دفعتاً پکڑ لیا، پھر تو وه بالکل مایوس ہوگئے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiv{پھر ﻇالم لوگوں کی جڑ کٹ گئی اور اللہ تعالیٰ کا شکر ہے جو تمام عالم کا پروردگار ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dcccxxxv{آپ کہئے کہ یہ بتلاؤ اگر اللہ تعالیٰ تمہاری سماعت اور بصارت بالکل لے لے اور تمہارے دلوں پر مہر کردے تو اللہ تعالیٰ کے سوا اور کوئی معبود ہے کہ یہ تم کو پھر دے دے۔ آپ دیکھئے تو ہم کس طرح دﻻئل کو مختلف پہلوؤں سے پیش کر رہے ہیں پھر بھی یہ اعراض کرتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvi{آپ کہئے کہ یہ بتلاؤ اگر تم پر اللہ تعالیٰ کا عذاب آ پڑے خواه اچانک یا اعلانیہ تو کیا بجز ﻇالم لوگوں کے اور بھی کوئی ہلاک کیا جائے گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvii{اور ہم پیغمبروں کو صرف اس واسطے بھیجا کرتے ہیں کہ وه بشارت دیں اور ڈرائیں پھر جو ایمان لے آئے اور درستی کرلے سو ان لوگوں پر کوئی اندیشہ نہیں اور نہ وه مغموم ہوں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dcccxxxviii{اور جو لوگ ہماری آیتوں کو جھوٹا بتلائیں ان کو عذاب پہنچے گا بوجہ اس کے کہ وه نافرمانی کرتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dcccxxxix{آپ کہہ دیجئے کہ نہ تو میں تم سے یہ کہتا ہوں کہ میرے پاس اللہ کے خزانے ہیں اور نہ میں غیب جانتا ہوں اور نہ میں تم سے یہ کہتا ہوں کہ میں فرشتہ ہوں۔ میں تو صرف جو کچھ میرے پاس وحی آتی ہے اس کی اتباع کرتا ہوں آپ کہئے کہ اندھا اور بینا کہیں برابر ہوسکتا ہے۔ سو کیا تم غور نہیں کرتے؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dcccxl{اور ایسے لوگوں کو ڈرائیے جو اس بات سے اندیشہ رکھتے ہیں کہ اپنے رب کے پاس ایسی حالت میں جمع کئے جائیں گے کہ جتنے غیر اللہ ہیں نہ کوئی ان کا مددگار ہوگا اور نہ کوئی شفیع، اس امید پر کہ وه ڈر جائیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dcccxli{اور ان لوگوں کو نہ نکالیے جو صبح وشام اپنے پروردگار کی عبادت کرتے ہیں، خاص اسی کی رضامندی کا قصد رکھتے ہیں۔ ان کا حساب ذرا بھی آپ کے متعلق نہیں اور آپ کا حساب ذرا بھی ان کے متعلق نہیں کہ آپ ان کو نکال دیں۔ ورنہ آپ ﻇلم کرنے والوں میں سے ہو جائیں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dcccxlii{اور اسی طرح ہم نے بعض کو بعض کے ذریعہ سے آزمائش میں ڈال رکھا ہے تاکہ یہ لوگ کہا کریں، کیا یہ لوگ ہیں کہ ہم سب میں سے ان پر اللہ تعالیٰ نے فضل کیا ہے۔ کیا یہ بات نہیں ہے کہ اللہ تعالیٰ شکر گزاروں کو خوب جانتا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dcccxliii{اور یہ لوگ جب آپ کے پاس آئیں جو ہماری آیتوں پر ایمان رکھتے ہیں تو (یوں) کہہ دیجیئے کہ تم پر سلامتی ہے تمہارے رب نے مہربانی فرمانا اپنے ذمہ مقرر کرلیا ہے کہ جو شخص تم میں سے برا کام کر بیٹھے جہالت سے پھر وه اس کے بعد توبہ کر لے اور اصلاح رکھے تو اللہ (کی یہ شان ہے کہ وه) بڑی مغفرت کرنے واﻻ ہے بڑی رحمت واﻻ ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dcccxliv{اسی طرح ہم آیات کی تفصیل کرتے رہتے ہیں اور تاکہ مجرمین کا طریقہ ﻇاہر ہوجائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dcccxlv{آپ کہہ دیجئے کہ مجھ کو اس سے ممانعت کی گئی ہے کہ ان کی عبادت کروں جن کو تم لوگ اللہ تعالیٰ کو چھوڑ کر پکارتے ہو۔ آپ کہہ دیجئے کہ میں تمہاری خواہشات کی اتباع نہ کروں گا کیوں کہ اس حالت میں تو میں بے راه ہوجاؤں گا اور راه راست پر چلنے والوں میں نہ رہوں گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dcccxlvi{آپ کہہ دیجئے کہ میرے پاس تو ایک دلیل ہے میرے رب کی طرف سے اور تم اس کی تکذیب کرتے ہو، جس چیز کی تم جلدبازی کر رہے ہو وه میرے پاس نہیں۔ حکم کسی کا نہیں بجز اللہ تعالیٰ کے اللہ تعالیٰ واقعی بات کو بتلا دیتا ہے اور سب سے اچھا فیصلہ کرنے واﻻ وہی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dcccxlvii{آپ کہہ دیجئے کہ اگر میرے پاس وه چیز ہوتی جس کا تم تقاضا کر رہے ہو تو میرا اور تمہارا باہمی قصہٴ فیصل ہوچکا ہوتا اور ﻇالموں کو اللہ تعالیٰ خوب جانتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dcccxlviii{اور اللہ تعالیٰ ہی کے پاس ہیں غیب کی کنجیاں، (خزانے) ان کو کوئی نہیں جانتا بجز اللہ کے۔ اور وه تمام چیزوں کو جانتا ہے جو کچھ خشکی میں ہیں اور جو کچھ دریاؤں میں ہیں اور کوئی پتا نہیں گرتا مگر وه اس کو بھی جانتا ہے اور کوئی دانہ زمین کے تاریک حصوں میں نہیں پڑتا اور نہ کوئی تر اور نہ کوئی خشک چیز گرتی ہے مگر یہ سب کتاب مبین میں ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dcccxlix{اور وه ایسا ہے کہ رات میں تمہاری روح کو (ایک گونہ) قبض کردیتا ہے اور جو کچھ تم دن میں کرتے ہو اس کو جانتا ہے پھر تم کو جگا اٹھاتا ہے تاکہ میعاد معین تمام کر دی جائے پھر اسی کی طرف تم کو جانا ہے پھر تم کو بتلائے گا جو کچھ تم کیا کرتے تھے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dcccl{اور وہی اپنے بندوں کے اوپر غالب ہے برتر ہے اور تم پر نگہداشت رکھنے والے بھیجتا ہے یہاں تک کہ جب تم میں سے کسی کو موت آ پہنچتی ہے، اس کی روح ہمارے بھیجے ہوئے فرشتے قبض کرلیتے ہیں اور وه ذرا کوتاہی نہیں کرتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dcccli{پھر سب اپنے مالک حقیقی کے پاس ﻻئے جائیں گے۔ خوب سن لو فیصلہ اللہ ہی کا ہوگا اور وه بہت جلد حساب لے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccclii{آپ کہئے کہ وه کون ہے جو تم کو خشکی اور دریا کی ﻇلمات سے نجات دیتا ہے۔ تم اس کو پکارتے ہو گڑگڑا کر چپکے چپکے، کہ اگر تو ہم کو ان سے نجات دے دے تو ہم ضرور شکر کرنے والوں میں سے ہوجائیں گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dcccliii{آپ کہہ دیجئے کہ اللہ ہی تم کو ان سے نجات دیتا ہے اور ہر غم سے، تم پھر بھی شرک کرنے لگتے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dcccliv{آپ کہئے کہ اس پر بھی وہی قادر ہے کہ تم پر کوئی عذاب تمہارے اوپر سے بھیج دے یا تمہارے پاؤں تلے سے یا کہ تم کو گروه گروه کرکے سب کو بھڑا دے اور تمہارے ایک کو دوسرے کی لڑائی چکھا دے۔ آپ دیکھیے تو سہی ہم کس طرح دﻻئل مختلف پہلوؤں سے بیان کرتے ہیں شاید وه سمجھ جائیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccclv{اور آپ کی قوم اس کی تکذیب کرتی ہے حاﻻنکہ وه یقینی ہے۔ آپ کہہ دیجئے کہ میں تم پر تعینات نہیں کیا گیا ہوں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccclvi{ہر خبر (کے وقوع) کا ایک وقت ہے اور جلد ہی تم کو معلوم ہوجائے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccclvii{اور جب آپ ان کو لوگوں کو دیکھیں جو ہماری آیات میں عیب جوئی کر رہے ہیں تو ان لوگوں سے کناره کش ہوجائیں یہاں تک کہ وه کسی اور بات میں لگ جائیں اور اگر آپ کو شیطان بھلا دے تو یاد آنے کے بعد پھر ایسے ﻇالم لوگوں کے ساتھ مت بیٹھیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccclviii{اور جو لوگ پرہیزگار ہیں ان پر ان کی باز پرس کا کوئی اﺛر نہ پہنچے گا اور لیکن ان کے ذمہ نصیحت کردینا ہے شاید وه تقویٰ اختیار کریں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccclix{اور ایسے لوگوں سے بالکل کناره کش رہیں جنہوں نے اپنے دین کو کھیل تماشا بنا رکھا ہے اور دنیوی زندگی نے انہیں دھوکہ میں ڈال رکھا ہے اور اس قرآن کے ذریعہ سے نصیحت بھی کرتے رہیں تاکہ کوئی شخص اپنے کردار کے سبب (اس طرح) نہ پھنس جائے کہ کوئی غیر اللہ اس کا نہ مددگار ہو اور نہ سفارشی اور یہ کیفیت ہو کہ اگر دنیا بھر کا معاوضہ بھی دے ڈالے تب بھی اس سے نہ لیا جائے۔ ایسے ہی ہیں کہ اپنے کردار کے سبب پھنس گئے، ان کے لئے نہایت تیز گرم پانی پینے کے لئے ہوگا اور دردناک سزا ہوگی اپنے کفر کے سبب\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccclx{آپ کہہ دیجئے کہ کیا ہم اللہ تعالیٰ کے سوا ایسی چیز کو پکاریں کہ نہ وه ہم کو نفع پہنچائے اور نہ ہم کو نقصان پہنچائے اور کیا ہم الٹے پھر جائیں اس کے بعد کہ ہم کو اللہ تعالیٰ نے ہدایت کردی ہے، جیسے کوئی شخص ہو کہ اس کو شیطانوں نے کہیں جنگل میں بےراه کردیا ہو اور وه بھٹکتا پھرتا ہو، اس کے کچھ ساتھی بھی ہوں کہ وه اس کو ٹھیک راستہ کی طرف بلا رہے ہوں کہ ہمارے پاس آ۔ آپ کہہ دیجئے کہ یقینی بات ہے کہ راه راست وه خاص اللہ ہی کی راه ہے اور ہم کو یہ حکم ہوا ہے کہ ہم پروردگار عالم کے پورے مطیع ہوجائیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccclxi{اور یہ کہ نماز کی پابندی کرو اور اس سے ڈرو اور وہی ہے جس کے پاس تم سب جمع کئے جاؤ گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccclxii{اور وہی ہے جس نے آسمانوں اور زمین کو برحق پیدا کیا اور جس وقت اللہ تعالیٰ اتنا کہہ دے گا تو ہوجا بس وه ہو پڑے گا۔ اس کا کہنا حق اور بااﺛر ہے۔ اور ساری حکومت خاص اسی کی ہوگی جب کہ صُور میں پھونک ماری جائے گی وه جاننے واﻻ ہے پوشیده چیزوں کا اور ﻇاہر چیزوں کا اور وہی ہے بڑی حکمت واﻻ پوری خبر رکھنے واﻻ\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccclxiii{اور وه وقت بھی یاد کرنے کے قابل ہے جب ابراہیم (علیہ السلام) نے اپنے باپ آزر سے فرمایا کہ کیا تو بتوں کو معبود قرار دیتا ہے؟ بےشک میں تجھ کو اور تیری ساری قوم کو صریح گمراہی میں دیکھتا ہوں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccclxiv{اور ہم نے ایسے ہی طور پر ابراہیم (علیہ السلام) کو آسمانوں اور زمین کی مخلوقات دکھلائیں اور تاکہ کامل یقین کرنے والوں میں سے ہوجائیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccclxv{پھر جب رات کی تاریکی ان پر چھا گئی تو انہوں نے ایک ستاره دیکھا آپ نے فرمایا کہ یہ میرا رب ہے مگر جب وه غروب ہوگیا تو آپ نے فرمایا کہ میں غروب ہوجانے والوں سے محبت نہیں رکھتا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccclxvi{پھر جب چاند کو دیکھا چمکتا ہوا تو فرمایا کہ یہ میرا رب ہے لیکن جب وه غروب ہوگیا تو آپ نے فرمایا کہ اگر مجھ کو میرے رب نے ہدایت نہ کی تو میں گمراه لوگوں میں شامل ہوجاؤں گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccclxvii{پھر جب آفتاب کو دیکھا چمکتا ہوا تو فرمایا کہ یہ میرا رب ہے یہ تو سب سے بڑا ہے پھر جب وه بھی غروب ہوگیا تو آپ نے فرمایا بےشک میں تمہارے شرک سے بیزار ہوں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccclxviii{میں اپنا رخ اس کی طرف کرتا ہوں جس نے آسمانوں اور زمین کو پیدا کیا یکسو ہو کر، اور میں شرک کرنے والوں میں سے نہیں ہوں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccclxix{اور ان سے ان کی قوم نے حجت کرنا شروع کیا، آپ نے فرمایا کیا تم اللہ کے معاملہ میں مجھ سے حجت کرتے ہو حاﻻنکہ اس نے مجھ کو طریقہ بتلا دیا ہے اور میں ان چیزوں سے جن کو تم اللہ کے ساتھ شریک بناتے ہو نہیں ڈرتا ہاں اگر میرا پروردگار ہی کوئی امر چاہے میرا پروردگار ہر چیز کو اپنے علم میں گھیرے ہوئے ہے، کیا تم پھر بھی خیال نہیں کرتے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccclxx{اور میں ان چیزوں سے کیسے ڈروں جن کو تم نے شریک بنایا ہے حاﻻنکہ تم اس بات سے نہیں ڈرتے کہ تم نے اللہ کے ساتھ ایسی چیزوں کو شریک ٹھہرایا ہے جن پر اللہ تعالیٰ نے کوئی دلیل نازل نہیں فرمائی، سو ان دو جماعتوں میں سے امن کا زیاده مستحق کون ہے اگر تم خبر رکھتے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccclxxi{جو لوگ ایمان رکھتے ہیں اور اپنے ایمان کو شرک کے ساتھ مخلوط نہیں کرتے، ایسوں ہی کے لئے امن ہے اور وہی راه راست پر چل رہے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dccclxxii{اور یہ ہماری حجت تھی وه ہم نے ابراہیم (علیہ السلام) کو ان کی قوم کے مقابلے میں دی تھی ہم جس کو چاہتے ہیں مرتبوں میں بڑھا دیتے ہیں۔ بےشک آپ کا رب بڑا حکمت واﻻ بڑا علم واﻻ ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccclxxiii{اور ہم نے ان کو اسحاق دیا اور یعقوب ہر ایک کو ہم نے ہدایت کی اور پہلے زمانہ میں ہم نے نوح کو ہدایت کی اور ان کی اوﻻد میں سے داؤد کو اور سلیمان کو اور ایوب کو اور یوسف کو اور موسیٰ کو اور ہارون کو اور اسی طرح ہم نیک کام کرنے والوں کو جزا دیا کرتے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccclxxiv{اور (نیز) زکریا کو اور یحيٰ کو اور عیسیٰ کو اور الیاس کو، سب نیک لوگوں میں سے تھے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dccclxxv{اور نیز اسماعیل کو اور یسع کو اور یونس کو اور لوط کو اور ہر ایک کو تمام جہان والوں پر ہم نے فضیلت دی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dccclxxvi{اور نیز ان کے کچھ باپ دادوں کو اور کچھ اوﻻد کو اور کچھ بھائیوں کو، اور ہم نے ان کو مقبول بنایا اور ہم نے ان کو راه راست کی ہدایت کی\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dccclxxvii{اللہ کی ہدایت ہی ہے جس کے ذریعے اپنے بندوں میں سے جس کو چاہے اس کی ہدایت کرتا ہے اور اگر فرضاً یہ حضرات بھی شرک کرتے تو جو کچھ یہ اعمال کرتے تھے وه سب اکارت ہوجاتے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dccclxxviii{یہ لوگ ایسے تھے کہ ہم نے ان کو کتاب اور حکمت اور نبوت عطا کی تھی سو اگر یہ لوگ نبوت کا انکار کریں تو ہم نے اس کے لئے ایسے بہت سے لوگ مقرر کردیئے ہیں جو اس کے منکر نہیں ہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dccclxxix{یہی لوگ ایسے تھے جن کو اللہ تعالیٰ نے ہدایت کی تھی، سو آپ بھی ان ہی کے طریق پر چلیئے آپ کہہ دیجیئے کہ میں تم سے اس پر کوئی معاوضہ نہیں چاہتا یہ تو صرف تمام جہان والوں کے واسطے ایک نصیحت ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dccclxxx{اور ان لوگوں نے، اللہ کی جیسی قدر کرنا واجب تھی ویسی قدر نہ کی جب کہ یوں کہہ دیا کہ اللہ نے کسی بشر پر کوئی چیز نازل نہیں کی آپ یہ کہیئے کہ وه کتاب کس نے نازل کی ہے جس کو موسیٰ ﻻئے تھے جس کی کیفیت یہ ہے کہ وه نور ہے اور لوگوں کے لئے وه ہدایت ہے جس کو تم نے ان متفرق اوراق میں رکھ چھوڑا ہے جن کو ﻇاہر کرتے ہو اور بہت سی باتوں کو چھپاتے ہو اور تم کو بہت سی ایسی باتیں بتائی گئی ہیں جن کو تم نہ جانتے تھے اور نہ تمہارے بڑے۔ آپ کہہ دیجیئے کہ اللہ نے نازل فرمایا ہے پھر ان کو ان کے خرافات میں کھیلتے رہنے دیجیئے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dccclxxxi{اور یہ بھی ایسی ہی کتاب ہے جس کو ہم نے نازل کیا ہے جو بڑی برکت والی ہے، اپنے سے پہلی کتابوں کی تصدیق کرنے والی ہے اور تاکہ آپ مکہ والوں کو اور آس پاس والوں کو ڈرائیں۔ اور جو لوگ آخرت کا یقین رکھتے ہیں ایسے لوگ اس پر ایمان لے آتے ہیں اور وه اپنی نماز پر مداومت رکھتے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dccclxxxii{اور اس شخص سے زیاده کون ﻇالم ہوگا جو اللہ تعالیٰ پر جھوٹ تہمت لگائے یا یوں کہے کہ مجھ پر وحی آتی ہے حاﻻنکہ اس کے پاس کسی بات کی بھی وحی نہیں آئی اور جو شخص یوں کہے کہ جیسا کلام اللہ نے نازل کیا ہے اسی طرح کا میں بھی ﻻتا ہوں اور اگر آپ اس وقت دیکھیں جب کہ یہ ﻇالم لوگ موت کی سختیوں میں ہوں گے اور فرشتے اپنے ہاتھ بڑھا رہے ہوں گے کہ ہاں اپنی جانیں نکالو۔ آج تم کو ذلت کی سزا دی جائے گی اس سبب سے کہ تم اللہ تعالیٰ کے ذمہ جھوٹی باتیں لگاتے تھے، اور تم اللہ تعالیٰ کی آیات سے تکبر کرتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiii{اور تم ہمارے پاس تنہا تنہا آگئے جس طرح ہم نے اول بار تم کو پیدا کیا تھا اور جو کچھ ہم نے تم کو دیا تھا اس کو اپنے پیچھے ہی چھوڑ آئے اور ہم تو تمہارے ہمراه تمہارے ان شفاعت کرنے والوں کو نہیں دیکھتے جن کی نسبت تم دعویٰ رکھتے تھے کہ وه تمہارے معاملے میں شریک ہیں۔ واقعی تمہارے آپس میں تو قطع تعلق ہوگیا اور وه تمہارا دعویٰ سب تم سے گیا گزرا ہوا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiv{بےشک اللہ تعالیٰ دانہ کو اور گٹھلیوں کو پھاڑنے واﻻ ہے، وه جاندار کو بے جان سے نکال ﻻتا ہے اور وه بے جان کو جاندار سے نکالنے واﻻ ہے اللہ تعالیٰ یہ ہے، سو تم کہاں الٹے چلے جا رہے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dccclxxxv{وه صبح کا نکالنے واﻻ ہے اور اس نے رات کو راحت کی چیز بنا یا ہے اور سورج اور چاند کو حساب سے رکھا ہے۔ یہ ٹھہرائی بات ہے ایسی ذات کی جو کہ قادر ہے بڑے علم واﻻ ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvi{اور وه ایسا ہے جس نے تمہارے لئے ستاروں کو پیدا کیا، تاکہ تم ان کے ذریعہ سے اندھیروں میں، خشکی میں اور دریا میں بھی راستہ معلوم کرسکو۔ بےشک ہم نے دﻻئل خوب کھول کھول کر بیان کردیئے ہیں ان لوگوں کے لئے جو خبر رکھتے ہیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvii{اور وه ایسا ہے جس نے تم کو ایک شخص سے پیدا کیا پھر ایک جگہ زیاده رہنے کی ہے اور ایک جگہ چندے، رہنے کی بےشک ہم نےدﻻئل خوب کھول کھول کر بیان کردیئے ان لوگوں کے لئے جو سمجھ بوجھ رکھتے ہیں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dccclxxxviii{اور وه ایسا ہے جس نے آسمان سے پانی برسایا پھر ہم نے اس کے ذریعہ سے ہر قسم کے نبات کو نکالا پھر ہم نے اس سے سبز شاخ نکالی کہ اس سے ہم اوپر تلے دانے چڑھے ہوئے نکالتے ہیں اور کھجور کے درختوں سے یعنی ان کے گپھے میں سے، خوشے ہیں جو نیچے کو لٹکے جاتے ہیں اور انگوروں کے باغ اور زیتون اور انار کہ بعض ایک دوسرے سے ملتے جلتے ہوتے ہیں اور کچھ ایک دوسرے سے ملتے جلتے نہیں ہوتے۔ ہر ایک کے پھل کو دیکھو جب وه پھلتا ہے اور اس کے پکنے کو دیکھو ان میں دﻻئل ہیں ان لوگوں کے لئے جو ایمان رکھتے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dccclxxxix{اور لوگوں نے شیاطین کو اللہ تعالیٰ کا شریک قرار دے رکھا ہے حاﻻنکہ ان لوگوں کو اللہ ہی نے پیدا کیا ہے اور ان لوگوں نے اللہ کے حق میں بیٹے اور بیٹیاں بلا سند تراش رکھی ہیں اور وه پاک اور برتر ہے ان باتوں سے جو یہ کرتے ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcccxc{وه آسمانوں اور زمین کا موجد ہے، اللہ تعالیٰ کے اوﻻد کہاں ہوسکتی ہے حاﻻنکہ اس کے کوئی بیوی تو ہے نہیں اور اللہ تعالیٰ نے ہر چیز کو پیدا کیا اور وه ہر چیز کو خوب جانتا ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcccxci{یہ ہے اللہ تعالیٰ تمہارا رب! اس کے سوا کوئی عبادت کے ﻻئق نہیں، ہر چیز کا پیدا کرنے واﻻ ہے، تو تم اس کی عبادت کرو اور وه ہر چیز کا کارساز ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcccxcii{اس کو تو کسی کی نگاه محیط نہیں ہوسکتی اور وه سب نگاہوں کو محیط ہو جاتا ہے اور وہی بڑا باریک بین باخبر ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcccxciii{اب بلاشبہ تمہارے پاس تمہارے رب کی جانب سے حق بینی کے ذرائع پہنچ چکے ہیں سو جو شخص دیکھ لے گا وه اپنا فائده کرے گا اور جو شخص اندھا رہے گا وه اپنا نقصان کرے گا، اور میں تمہارا نگران نہیں ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcccxciv{اور ہم اس طور پر دﻻئل کو مختلف پہلوؤں سے بیان کرتے ہیں تاکہ یہ یوں کہیں کہ آپ نے کسی سے پڑھ لیا ہے اور تاکہ ہم اس کو دانشمندوں کے لئے خوب ﻇاہر کردیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcccxcv{آپ خود اس طریق پر چلتے رہئے جس کی وحی آپ کے رب تعالیٰ کی طرف سے آپ کے پاس آئی ہے، اللہ تعالیٰ کے سوا کوئی ﻻئق عبادت نہیں اور مشرکین کی طرف خیال نہ کیجئے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcccxcvi{اور اگر اللہ تعالیٰ کو منظور ہوتا تو یہ شرک نہ کرتے اور ہم نے آپ کو ان کا نگران نہیں بنایا۔ اور نہ آپ ان پر مختار ہیں!\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcccxcvii{اور گالی مت دو ان کو جن کی یہ لوگ اللہ تعالیٰ کو چھوڑ کر عبادت کرتے ہیں کیونکہ پھر وه براه جہل حد سے گزر کر اللہ تعالیٰ کی شان میں گستاخی کریں گے ہم نے اسی طرح ہر طریقہ والوں کو ان کا عمل مرغوب بنا رکھا ہے۔ پھر اپنے رب ہی کے پاس ان کو جانا ہے سو وه ان کو بتلا دے گا جو کچھ بھی وه کیا کرتے تھے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcccxcviii{اور ان لوگوں نے قسموں میں بڑا زور لگا کر اللہ تعالیٰ کی قسم کھائی کہ اگر ان کے پاس کوئی نشانی آ جائے تو وه ضرور ہی اس پر ایمان لے آئیں گے، آپ کہہ دیجئے کہ نشانیاں سب اللہ کے قبضے میں ہیں اور تم کو اس کی کیا خبر کہ وه نشانیاں جس وقت آجائیں گی یہ لوگ تب بھی ایمان نہ ﻻئیں گے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcccxcix{اور ہم بھی ان کے دلوں کو اور ان کی نگاہوں کو پھیر دیں گے جیسا کہ یہ لوگ اس پر پہلی دفعہ ایمان نہیں ﻻئے اور ہم ان کو ان کی سرکشی میں حیران رہنے دیں گے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cm{اور اگر ہم ان کے پاس فرشتوں کو بھیج دیتے اور ان سے مردے باتیں کرنے لگتے اور ہم تمام موجودات کو ان کے پاس ان کی آنکھوں کے روبرو ﻻ کر جمع کر دیتے ہیں تب بھی یہ لوگ ہرگز ایمان نہ ﻻتے ہاں اگر اللہ ہی چاہے تو اور بات ہے لیکن ان میں زیاده لوگ جہالت کی باتیں کرتے ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cmi{اور اسی طرح ہم نے ہر نبی کے دشمن بہت سے شیطان پیدا کئے تھے کچھ آدمی اور کچھ جن، جن میں سے بعض بعضوں کو چکنی چپڑی باتوں کا وسوسہ ڈالتے رہتے تھے تاکہ ان کو دھوکہ میں ڈال دیں اور اگر اللہ تعالیٰ چاہتا تو یہ ایسے کام نہ کرسکتے سو ان لوگوں کو اور جو کچھ یہ افترا پردازی کر رہے ہیں اس کو آپ رہنے دیجئے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cmii{اور تاکہ اس کی طرف ان لوگوں کے قلوب مائل ہوجائیں جو آخرت پر یقین نہیں رکھتے اور تاکہ اس کو پسند کرلیں اور تاکہ مرتکب ہوجائیں ان امور کے جن کے وه مرتکب ہوتے تھے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cmiii{تو کیا اللہ کے سوا کسی اور فیصلہ کرنے والے کو تلاش کروں حاﻻنکہ وه ایسا ہے کہ اس نے ایک کتاب کامل تمہارے پاس بھیج دی ہے، اس کے مضامین خوب صاف صاف بیان کئے گئے ہیں اور جن لوگوں کو ہم نے کتاب دی ہے وه اس بات کو یقین کے ساتھ جانتے ہیں کہ یہ آپ کے رب کی طرف سے حق کے ساتھ بھیجی گئی ہے، سو آپ شبہ کرنے والوں میں سے نہ ہوں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cmiv{آپ کے رب کا کلام سچائی اور انصاف کے اعتبار سے کامل ہے، اس کے کلام کا کوئی بدلنے واﻻ نہیں اور وه خوب سننے واﻻ خوب جاننے واﻻ ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cmv{اور دنیا میں زیاده لوگ ایسے ہیں کہ اگر آپ ان کا کہنا ماننے لگیں تو وه آپ کو اللہ کی راه سے بے راه کردیں وه محض بے اصل خیاﻻت پر چلتے ہیں اور بالکل قیاسی باتیں کرتے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cmvi{بالیقین آپ کا رب ان کو خوب جانتا ہے جو اس کی راه سے بے راه ہوجاتا ہے۔ اور وه ان کو بھی خوب جانتا ہے جو اس کی راه پر چلتے ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cmvii{سو جس جانور پر اللہ تعالیٰ کا نام لیا جائے اس میں سے کھاؤ! اگر تم اس کے احکام پر ایمان رکھتے ہو\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cmviii{اور آخر کیا وجہ ہے کہ تم ایسے جانور میں سے نہ کھاؤ جس پر اللہ کا نام لیا گیا ہو حاﻻنکہ اللہ تعالیٰ نے ان سب جانوروں کی تفصیل بتادی ہے جن کو تم پر حرام کیا ہے، مگر وه بھی جب تم کو سخت ضرورت پڑجائے تو حلال ہے اور یہ یقینی بات ہے کہ بہت سے آدمی اپنے خیاﻻت پر بلا کسی سند کے گمراه کرتے ہیں۔ اس میں کوئی شبہ نہیں کہ اللہ تعالیٰ حد سے نکل جانے والوں کو خوب جانتا ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cmix{اور تم ﻇاہری گناه کو بھی چھوڑ دو اور باطنی گناه کو بھی چھوڑ دو۔ بلاشبہ جو لوگ گناه کررہے ہیں ان کو ان کے کئے کی عنقریب سزا ملے گی\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cmx{اور ایسے جانوروں میں سے مت کھاؤ جن پر اللہ کا نام نہ لیا گیا ہو اور یہ کام نافرمانی کا ہے اور یقیناً شیاطین اپنے دوستوں کے دل میں ڈالتے ہیں تاکہ یہ تم سے جدال کریں اور اگر تم ان لوگوں کی اطاعت کرنے لگو تو یقیناً تم مشرک ہوجاؤ گے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cmxi{ایسا شخص جو پہلے مرده تھا پھر ہم نے اس کو زنده کردیا اور ہم نے اس کو ایک ایسا نور دے دیا کہ وه اس کو لئے ہوئے آدمیوں میں چلتا پھرتا ہے۔ کیا ایسا شخص اس شخص کی طرح ہوسکتا ہے؟ جو تاریکیوں سے نکل ہی نہیں پاتا۔ اسی طرح کافروں کو ان کے اعمال خوش نما معلوم ہوا کرتے ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cmxii{اور اسی طرح ہم نے ہر بستی میں وہاں کے رئیسوں ہی کو جرائم کا مرتکب بنایا تاکہ وه لوگ وہاں فریب کریں۔ اور وه لوگ اپنے ہی ساتھ فریب کررہے ہیں اور ان کو ذرا خبر نہیں\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cmxiii{اور جب ان کو کوئی آیت پہنچتی ہے تو یوں کہتے ہیں کہ ہم ہرگز ایمان نہ ﻻئیں گے جب تک کہ ہم کو بھی ایسی ہی چیز نہ دی جائے جو اللہ کے رسولوں کو دی جاتی ہے، اس موقع کو تو اللہ ہی خوب جانتا ہے کہ کہاں وه اپنی پیغمبری رکھے؟ عنقریب ان لوگوں کو جنہوں نے جرم کیا ہے اللہ کے پاس پہنچ کر ذلت پہنچے گی اور ان کی شرارتوں کے مقابلے میں سخت سزائیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cmxiv{سو جس شخص کو اللہ تعالیٰ راستہ پر ڈالنا چاہے اس کے سینہ کو اسلام کے لیے کشاده کر دیتا ہے اور جس کو بے راه رکھنا چاہے اس کے سینہ کو بہت تنگ کردیتا ہے جیسے کوئی آسمان میں چڑھتا ہے، اسی طرح اللہ تعالیٰ ایمان نہ ﻻنے والوں پر ناپاکی مسلط کردیتا ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cmxv{اور یہی تیرے رب کا سیدھا راستہ ہے۔ ہم نے نصیحت حاصل کرنے والوں کے واسطے ان آیتوں کو صاف صاف بیان کردیا\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cmxvi{ان لوگوں کے واسطے ان کے رب کے پاس سلامتی کا گھر ہے اور اللہ تعالیٰ ان سے محبت رکھتا ہے ان کے اعمال کی وجہ سے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cmxvii{اور جس روز اللہ تعالیٰ تمام خلائق کو جمع کرے گا، (کہے گا) اے جماعت جنات کی! تم نے انسانوں میں سے بہت سے اپنا لیے جو انسان ان کے ساتھ تعلق رکھنے والے تھے وه کہیں گے کہ اے ہمارے پروردگار! ہم میں ایک نے دوسرے سے فائده حاصل کیا تھا اور ہم اپنی اس معین میعاد تک آپہنچے جو تونے ہمارے لئے معین فرمائی، اللہ فرمائے گا کہ تم سب کا ٹھکانہ دوزخ ہے جس میں ہمیشہ رہو گے، ہاں اگر اللہ ہی کو منظور ہو تو دوسری بات ہے۔ بے شک آپ کا رب بڑی حکمت واﻻ بڑا علم واﻻ ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cmxviii{اور اسی طرح ہم بعض کفار کو بعض کے قریب رکھیں گے ان کے اعمال کے سبب\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cmxix{اے جنات اور انسانوں کی جماعت! کیا تمہارے پاس تم میں سے ہی پیغمبر نہیں آئے تھے، جو تم سے میرے احکام بیان کرتے اور تم کو اس آج کے دن کی خبر دیتے؟ وه سب عرض کریں گے کہ ہم اپنے اوپر اقرار کرتے ہیں اور ان کو دنیاوی زندگی نے بھول میں ڈالے رکھا اور یہ لوگ اقرار کرنے والے ہوں گے کہ وه کافر تھے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cmxx{یہ اس وجہ سے ہے کہ آپ کا رب کسی بستی والوں کو کفر کے سبب ایسی حالت میں ہلاک نہیں کرتا کہ اس بستی کے رہنے والے بے خبر ہوں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cmxxi{اور ہر ایک کے لئے ان کے اعمال کے سبب درجے ملیں گے اور آپ کا رب ان کے اعمال سے بے خبر نہیں ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cmxxii{اور آپ کا رب بالکل غنی ہے رحمت واﻻ ہے۔ اگر وه چاہے تو تم سب کو اٹھا لے اور تمہارے بعد جس کو چاہے تمہاری جگہ آباد کردے جیسا کہ تم کو ایک دوسری قوم کی نسل سے پیدا کیا ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cmxxiii{جس چیز کا تم سے وعده کیا جاتا ہے وه بے شک آنے والی چیز ہے اور تم عاجز نہیں کرسکتے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cmxxiv{آپ یہ فرما دیجئے کہ اے میری قوم! تم اپنی حالت پر عمل کرتے رہو میں بھی عمل کررہا ہوں، سو اب جلد ہی تم کو معلوم ہوا جاتا ہے کہ اس عالم کا انجام کار کس کے لیے نافع ہوگا۔ یہ یقینی بات ہے کہ حق تلفی کرنے والوں کو کبھی فلاح نہ ہوگی\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cmxxv{اور اللہ تعالیٰ نے جو کھیتی اور مواشی پیدا کیے ہیں ان لوگوں نے ان میں سے کچھ حصہ اللہ کا مقرر کیا اور بزعم خود کہتے ہیں کہ یہ تو اللہ کا ہے اور یہ ہمارے معبودوں کا ہے، پھر جو چیز ان کے معبودوں کی ہوتی ہے وه تو اللہ کی طرف نہیں پہنچتی اور جو چیز اللہ کی ہوتی ہے وه ان کے معبودوں کی طرف پہنچ جاتی ہے کیا برا فیصلہ وه کرتے ہیں\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cmxxvi{اور اسی طرح بہت سے مشرکین کے خیال میں ان کے معبودوں نے ان کی اوﻻد کے قتل کرنے کو مستحسن بنا رکھا ہے تاکہ وه ان کو برباد کریں اور تاکہ ان کے دین کو ان پر مشتبہ کردیں اور اگر اللہ کو منظور ہوتا تو یہ ایسا کام نہ کرتے تو آپ ان کو اور جو کچھ یہ غلط باتیں بنا رہے ہیں یونہی رہنے دیجئے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cmxxvii{اور وه اپنے خیال پر یہ بھی کہتے ہیں کہ یہ کچھ مواشی ہیں اور کھیت ہیں جن کا استعمال ہر شخص کو جائز نہیں ان کو کوئی نہیں کھا سکتا سوائے ان کے جن کو ہم چاہیں اور مواشی ہیں جن پر سواری یا باربرداری حرام کردی گئی اور کچھ مواشی ہیں جن پر یہ لوگ اللہ تعالیٰ کا نام نہیں لیتے محض اللہ پر افترا باندھنے کے طور پر۔ ابھی اللہ تعالیٰ ان کو ان کے افترا کی سزا دیئے دیتا ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cmxxviii{اور وه کہتے ہیں کہ جو چیز ان مواشی کے پیٹ میں ہے وه خالص ہمارے مردوں کے لئے ہے اور ہماری عورتوں پر حرام ہے۔ اور اگر وه مرده ہے تو اس میں سب برابر ہیں۔ ابھی اللہ ان کو ان کی غلط بیانی کی سزا دیئے دیتا ہے بلاشبہ وه حکمت واﻻ ہے اور وه بڑا علم واﻻ ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cmxxix{واقعی خرابی میں پڑ گئے وه لوگ جنہوں نے اپنی اوﻻد کو محض براه حماقت بلا کسی سند کے قتل کر ڈاﻻ اور جو چیزیں ان کو اللہ نے کھانے پینے کو دی تھیں ان کو حرام کرلیا محض اللہ پر افترا باندھنے کے طور پر۔ بے شک یہ لوگ گمراہی میں پڑگئے اور کبھی راه راست پر چلنے والے نہیں ہوئے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cmxxx{اور وہی ہے جس نے باغات پیدا کئے وه بھی جو ٹٹیوں پر چڑھائے جاتے ہیں اور وه بھی جو ٹٹیوں پر نہیں چڑھائے جاتے اور کھجور کے درخت اور کھیتی جن میں کھانے کی چیزیں مختلف طور کی ہوتی ہیں اور زیتون اور انار جو باہم ایک دوسرے کے مشابہ بھی ہوتے ہیں اور ایک دوسرے کے مشابہ نہیں بھی ہوتے، ان سب کے پھلوں میں سے کھاؤ جب وه نکل آئے اور اس میں جو حق واجب ہے وه اس کے کاٹنے کے دن دیا کرو اور حد سے مت گزرو یقیناً وه حد سے گزرنے والوں کو ناپسند کرتا ہے\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cmxxxi{اور مواشی میں اونچے قد کے اور چھوٹے قد کے (پیدا کیے)، جو کچھ اللہ نے تم کو دیا ہے کھاؤ اور شیطان کے قدم بقدم مت چلو، بلاشک وه تمہارا صریح دشمن ہے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cmxxxii{(پیدا کیے) آٹھ نر و ماده یعنی بھیڑ میں دو قسم اور بکری میں دو قسم آپ کہیے کہ کیا اللہ نے ان دونوں نروں کو حرام کیا ہے یا دونوں ماده کو؟ یا اس کو جس کو دونوں ماده پیٹ میں لئے ہوئے ہوں؟ تم مجھ کو کسی دلیل سے تو بتاؤ اگر سچے ہو\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cmxxxiii{اور اونٹ میں دو قسم اور گائے میں دو قسم آپ کہیے کہ کیا اللہ تعالیٰ نے ان دونوں نروں کو حرام کیا ہے یا دونوں ماده کو؟ یا اس کو جس کو دونوں ماده پیٹ میں لئے ہوئے ہوں؟ کیا تم حاضر تھے جس وقت اللہ تعالیٰ نے تم کو اس کا حکم دیا؟ تو اس سے زیاده کون ﻇالم ہوگا جو اللہ تعالیٰ پر بلا دلیل جھوٹی تہمت لگائے، تاکہ لوگوں کو گمراه کرے یقیناً اللہ تعالیٰ ﻇالم لوگوں کو راستہ نہیں دکھلاتا\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cmxxxiv{آپ کہہ دیجئے کہ جو کچھ احکام بذریعہ وحی میرے پاس آئے ان میں تو میں کوئی حرام نہیں پاتا کسی کھانے والے کے لئے جو اس کو کھائے، مگر یہ کہ وه مردار ہو یا کہ بہتا ہوا خون ہو یا خنزیر کا گوشت ہو، کیونکہ وه بالکل ناپاک ہے یا جو شرک کا ذریعہ ہو کہ غیراللہ کے لئے نامزد کردیا گیا ہو۔ پھر جو شخص مجبور ہوجائے بشرطیکہ نہ تو طالب لذت ہو اور نہ تجاوز کرنے واﻻ ہو تو واقعی آپ کا رب غفور و رحیم ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cmxxxv{اور یہود پر ہم نے تمام ناخن والے جانور حرام کرد یئے تھے اور گائے اور بکری میں سے ان دونوں کی چربیاں ان پر ہم نے حرام کردی تھیں مگر وه جو ان کی پشت پر یا انتڑیوں میں لگی ہو یا جو ہڈی سے ملی ہو۔ ان کی شرارت کے سبب ہم نے ان کو یہ سزا دی اور ہم یقیناً سچے ہیں\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cmxxxvi{پھر اگر یہ آپ کو کاذب کہیں تو آپ فرما دیجئے کہ تمہارا رب بڑی وسیع رحمت واﻻ ہے اور اس کا عذاب مجرم لوگوں سے نہ ٹلے گا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cmxxxvii{یہ مشرکین (یوں) کہیں گے کہ اگر اللہ تعالیٰ کو منظور ہوتا تو نہ ہم شرک کرتے اور نہ ہمارے باپ دادا اور نہ ہم کسی چیز کو حرام کہہ سکتے۔ اسی طرح جو لوگ ان سے پہلے ہوچکے ہیں انہوں نے بھی تکذیب کی تھی یہاں تک کہ انہوں نے ہمارے عذاب کامزه چکھا۔ آپ کہیے کہ کیا تمہارے پاس کوئی دلیل ہے تو اس کو ہمارے روبرو ﻇاہر کرو۔ تم لوگ محض خیالی باتوں پر چلتے ہو اور تم بالکل اٹکل سے باتیں بناتے ہو\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cmxxxviii{آپ کہیے کہ بس پوری حجت اللہ ہی کی رہی۔ پھر اگر وه چاہتا تو تم سب کو راه راست پر لے آتا\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cmxxxix{آپ کہیے کہ اپنے گواہوں کو لاؤ جو اس بات پر شہادت دیں کہ اللہ نے ان چیزوں کو حرام کردیا ہے، پھر اگر وه گواہی دے دیں تو آپ اس کی شہادت نہ دیجئے اور ایسے لوگوں کے باطل خیاﻻت کا اتباع مت کیجئے! جو ہماری آیتوں کی تکذیب کرتے ہیں اور وه جو آخرت پر ایمان نہیں رکھتے اور وه اپنے رب کے برابر دوسروں کو ٹھہراتے ہیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cmxl{آپ کہیے کہ آؤ میں تم کو وه چیزیں پڑھ کر سناؤں جن (یعنی جن کی مخالفت) کو تمہارے رب نے تم پر حرام فرما دیا ہے، وه یہ کہ اللہ کے ساتھ کسی چیز کو شریک مت ٹھہراؤ اور ماں باپ کے ساتھ احسان کرو اور اپنی اوﻻد کو افلاس کے سبب قتل مت کرو۔ ہم تم کو اور ان کو رزق دیتے ہیں اور بے حیائی کے جتنے طریقے ہیں ان کے پاس بھی مت جاؤ خواه علانیہ ہوں خواه پوشیده، اور جس کا خون کرنا اللہ تعالیٰ نے حرام کردیا ہے اس کو قتل مت کرو، ہاں مگر حق کے ساتھ ان کا تم کو تاکیدی حکم دیا ہے تاکہ تم سمجھو\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cmxli{اور یتیم کے مال کے پاس نہ جاؤ مگر ایسے طریقے سے جو کہ مستحسن ہے یہاں تک کہ وه اپنے سن رشد کو پہنچ جائے اور ناپ تول پوری پوری کرو، انصاف کے ساتھ، ہم کسی شخص کو اس کی طاقت سے زیاده تکلیف نہیں دیتے۔ اور جب تم بات کرو تو انصاف کرو، گو وه شخص قرابت دار ہی ہو اور اللہ تعالیٰ سے جو عہد کیا اس کو پورا کرو، ان کا اللہ تعالیٰ نے تم کو تاکیدی حکم دیا ہے تاکہ تم یاد رکھو\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cmxlii{اور یہ کہ یہ دین میرا راستہ ہے جو مستقیم ہے سو اس راه پر چلو اور دوسری راہوں پر مت چلو کہ وه راہیں تم کو اللہ کی راه سے جدا کردیں گی۔ اس کا تم کو اللہ تعالیٰ نے تاکیدی حکم دیا ہے تاکہ تم پرہیزگاری اختیار کرو\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cmxliii{پھر ہم نے موسیٰ (علیہ السلام) کو کتاب دی تھی جس سے اچھی طرح عمل کرنے والوں پر نعمت پوری ہو اور سب احکام کی تفصیل ہوجائے اور رہنمائی ہو اور رحمت ہو تاکہ وه لوگ اپنے رب کے ملنے پر یقین ﻻئیں\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cmxliv{اور یہ ایک کتاب ہے جس کو ہم نے بھیجا بڑی خیر وبرکت والی، سو اس کا اتباع کرو اور ڈرو تاکہ تم پر رحمت ہو\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cmxlv{کہیں تم لوگ یوں نہ کہو کہ کتاب تو صرف ہم سے پہلے جو دو فرقے تھے ان پر نازل ہوئی تھی، اور ہم ان کے پڑھنے پڑھانے سے محض بے خبر تھے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cmxlvi{یا یوں نہ کہو کہ اگر ہم پر کوئی کتاب نازل ہوتی تو ہم ان سے بھی زیاده راه راست پر ہوتے۔ سو اب تمہارے پاس تمہارے رب کے پاس سے ایک کتاب واضح اور رہنمائی کا ذریعہ اور رحمت آچکی ہے۔ اب اس شخص سے زیاده ﻇالم کون ہوگا جو ہماری ان آیتوں کو جھوٹا بتائے اور اس سے روکے۔ ہم جلد ہی ان لوگوں کو جو کہ ہماری آیتوں سے روکتے ہیں ان کے اس روکنے کے سبب سخت سزا دیں گے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cmxlvii{کیا یہ لوگ صرف اس امر کے منتظر ہیں کہ ان کے پاس فرشتے آئیں یا ان کے پاس آپ کا رب آئے یا آپ کے رب کی کوئی (بڑی) نشانی آئے؟ جس روز آپ کے رب کی کوئی بڑی نشانی آپہنچے گی، کسی ایسے شخص کا ایمان اس کے کام نہ آئے گا جو پہلے سے ایمان نہیں رکھتا۔ یا اس نے اپنے ایمان میں کوئی نیک عمل نہ کیا ہو۔ آپ فرما دیجئے کہ تم منتظر رہو، ہم بھی منتظر ہیں\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cmxlviii{بےشک جن لوگوں نے اپنے دین کو جدا جدا کردیا اور گروه گروه بن گئے، آپ کا ان سے کوئی تعلق نہیں بس ان کا معاملہ اللہ تعالیٰ کے حوالے ہے۔ پھر ان کو ان کا کیا ہوا جتلادیں گے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cmxlix{جو شخص نیک کام کرے گا اس کو اس کے دس گنا ملیں گے اور جو شخص برا کام کرے گا اس کو اس کے برابر ہی سزا ملے گی اور ان لوگوں پر ﻇلم نہ ہوگا\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cml{آپ کہہ دیجئے کہ مجھ کو میرے رب نے ایک سیدھا راستہ بتادیا ہے کہ وه ایک دین مستحکم ہے جو طریقہ ہے ابراہیم (علیہ السلام) کا جو اللہ کی طرف یکسو تھے۔ اور وه شرک کرنے والوں میں سے نہ تھے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cmli{آپ فرما دیجئے کہ بالیقین میری نماز اور میری ساری عبادت اور میرا جینا اور میرا مرنا یہ سب خالص اللہ ہی کا ہے جو سارے جہان کا مالک ہے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cmlii{اس کا کوئی شریک نہیں اور مجھ کو اسی کا حکم ہوا ہے اور میں سب ماننے والوں میں سے پہلا ہوں\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cmliii{آپ فرما دیجئے کہ کیا میں اللہ کے سوا کسی اور کو رب بنانے کے لئے تلاش کروں حاﻻنکہ وه مالک ہے ہر چیز کا اور جو شخص بھی کوئی عمل کرتا ہے وه اسی پر رہتا ہے اور کوئی کسی دوسرے کا بوجھ نہ اٹھائے گا۔ پھر تم سب کو اپنے رب کے پاس جانا ہوگا۔ پھر وه تم کو جتلائے گا جس جس چیز میں تم اختلاف کرتے تھے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cmliv{اور وه ایسا ہے جس نے تم کو زمین میں خلیفہ بنایا اور ایک کا دوسرے پر رتبہ بڑھایا تاکہ تم کو آزمائے ان چیزوں میں جو تم کو دی ہیں۔ بالیقین آپ کا رب جلد سزا دینے واﻻ ہے اور بالیقین وه واقعی بڑی مغفرت کرنے واﻻ مہربانی کرنے واﻻ ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cmlv{\basmalahur المص\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cmlvi{یہ ایک کتاب ہے جو آپ کے پاس اس لئے بھیجی گئی ہے کہ آپ اس کے ذریعہ سے ڈرائیں، سو آپ کے دل میں اس سے بالکل تنگی نہ ہو اور نصیحت ہے ایمان والوں کے لئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cmlvii{تم لوگ اس کا اتباع کرو جو تمہارے رب کی طرف سے آئی ہے اور اللہ تعالیٰ کو چھوڑ کر من گھڑت سرپرستوں کی اتباع مت کرو تم لوگ بہت ہی کم نصیحت پکڑتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cmlviii{اور بہت بستیوں کو ہم نے تباه کردیا اور ان پر ہمارا عذاب رات کے وقت پہنچا یا ایسی حالت میں کہ وه دوپہر کے وقت آرام میں تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cmlix{سو جس وقت ان پر ہمارا عذاب آیا اس وقت ان کے منھ سے بجز اس کے اور کوئی بات نہ نکلی کہ واقعی ہم ﻇالم تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cmlx{پھر ہم ان لوگوں سے ضرور پوچھیں گے جن کے پاس پیغمبر بھیجے گئے تھے اور ہم پیغمبروں سے ضرور پوچھیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@cmlxi{پھر ہم چونکہ پوری خبر رکھتے ہیں ان کے روبرو بیان کردیں گے۔ اور ہم کچھ بے خبر نہ تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@cmlxii{اور اس روز وزن بھی برحق ہے پھر جس شخص کا پلا بھاری ہوگا سو ایسے لوگ کامیاب ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cmlxiii{اور جس شخص کا پلا ہلکا ہوگا سو یہ وه لوگ ہوں گے جنہوں نے اپنا نقصان کرلیا بسبب اس کے کہ ہماری آیتوں کے ساتھ ﻇلم کرتے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@cmlxiv{اور بے شک ہم نے تم کو زمین پر رہنے کی جگہ دی اور ہم نے تمہارے لئے اس میں سامان رزق پیدا کیا، تم لوگ بہت ہی کم شکر کرتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@cmlxv{اور ہم نے تم کو پیدا کیا، پھر ہم ہی نے تمہاری صورت بنائی پھر ہم نے فرشتوں سے کہا کہ آدم کو سجده کرو سو سب نے سجده کیا بجز ابلیس کے، وه سجده کرنے والوں میں شامل نہ ہوا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cmlxvi{حق تعالیٰ نے فرمایا تو جو سجده نہیں کرتا تو تجھ کو اس سے کون امر مانع ہے، جبکہ میں تجھ کو حکم دے چکا، کہنے لگا میں اس سے بہتر ہوں، آپ نے مجھ کو آگ سے پیدا کیا ہے اور اس کو آپ نے خاک سے پیدا کیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cmlxvii{حق تعالیٰ نے فرمایا آسمان سے اتر تجھ کو کوئی حق حاصل نہیں کہ تو آسمان میں ره کر تکبر کرے سو نکل بے شک تو ذلیلوں میں سے ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cmlxviii{اس نے کہا کہ مجھ کو مہلت دیجئے قیامت کے دن تک\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cmlxix{اللہ تعالیٰ نے فرمایا تجھ کو مہلت دی گئی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cmlxx{اس نے کہا بسبب اس کے کہ آپ نے مجھ کو گمراه کیا ہے میں قسم کھاتا ہوں کہ میں ان کے لئے آپ کی سیدھی راه پر بیٹھوں گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cmlxxi{پھر ان پر حملہ کروں گا ان کے آگے سے بھی اور ان کے پیچھے سے بھی اور ان کی داہنی جانب سے بھی اور ان کی بائیں جانب سے بھی اور آپ ان میں سے اکثر کو شکر گزار نہ پائیے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cmlxxii{اللہ تعالیٰ نے فرمایا کہ یہاں سے ذلیل وخوار ہوکر نکل جا جو شخص ان میں سے تیرا کہنا مانے گا میں ضرور تم سب سے جہنم کو بھردوں گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cmlxxiii{اور ہم نے حکم دیا کہ اے آدم! تم اور تمہاری بیوی جنت میں رہو۔ پھر جس جگہ سے چاہو دونوں کھاؤ، اور اس درخت کے پاس مت جاؤ ورنہ تم دونوں ﻇالموں میں سے ہوجاؤ گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cmlxxiv{پھر شیطان نے ان دونوں کے دلوں میں وسوسہ ڈاﻻ تاکہ ان کی شرمگاہیں جو ایک دوسرے سے پوشیده تھیں دونوں کے روبرو بے پرده کردے اور کہنے لگا کہ تمہارے رب نے تم دونوں کو اس درخت سے اور کسی سبب سے منع نہیں فرمایا، مگر محض اس وجہ سے کہ تم دونوں کہیں فرشتے ہوجاؤ یا کہیں ہمیشہ زنده رہنے والوں میں سے ہوجاؤ\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cmlxxv{اور ان دونوں کے روبرو قسم کھالی کہ یقین جانیئے میں تم دونوں کا خیر خواه ہوں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cmlxxvi{سو ان دونوں کو فریب سے نیچے لے آیا پس ان دونوں نے جب درخت کو چکھا دونوں کی شرمگاہیں ایک دوسرے کے روبرو بے پرده ہوگئیں اور دونوں اپنے اوپر جنت کے پتے جوڑ جوڑ کر رکھنے لگے اور ان کے رب نے ان کو پکارا کیا میں تم دونوں کو اس درخت سے منع نہ کرچکا تھا اور یہ نہ کہہ چکا کہ شیطان تمہارا صریح دشمن ہے؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cmlxxvii{دونوں نے کہا اے ہمارے رب! ہم نے اپنا بڑا نقصان کیا اور اگر تو ہماری مغفرت نہ کرے گا اور ہم پر رحم نہ کرے گا تو واقعی ہم نقصان پانے والوں میں سے ہوجائیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cmlxxviii{حق تعالیٰ نے فرمایا کہ نیچے ایسی حالت میں جاؤ کہ تم باہم ایک دوسرے کے دشمن ہوگے اور تمہارے واسطے زمین میں رہنے کی جگہ ہے اور نفع حاصل کرنا ہے ایک وقت تک\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cmlxxix{فرمایا تم کو وہاں ہی زندگی بسر کرنا ہے اور وہاں ہی مرنا ہے اور اسی میں سے پھر نکالے جاؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cmlxxx{اے آدم (علیہ السلام) کی اوﻻد ہم نے تمہارے لئے لباس پیدا کیا جو تمہاری شرم گاہوں کو بھی چھپاتا ہے اور موجب زینت بھی ہے اور تقوے کا لباس، یہ اس سے بڑھ کر ہے۔ یہ اللہ تعالیٰ کی نشانیوں میں سے ہے تاکہ یہ لوگ یاد رکھیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cmlxxxi{اے اوﻻد آدم! شیطان تم کو کسی خرابی میں نہ ڈال دے جیسا اس نے تمہارے ماں باپ کو جنت سے باہر کرا دیا ایسی حالت میں ان کا لباس بھی اتروا دیا تاکہ وه ان کو ان کی شرم گاہیں دکھائے۔ وه اور اس کا لشکر تم کو ایسے طور پر دیکھتا ہے کہ تم ان کو نہیں دیکھتے ہو۔ ہم نے شیطانوں کو ان ہی لوگوں کا دوست بنایا ہے جو ایمان نہیں ﻻتے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cmlxxxii{اور وه لوگ جب کوئی فحش کام کرتے ہیں تو کہتے ہیں کہ ہم نے اپنے باپ دادا کو اسی طریق پر پایا ہے اور اللہ نے بھی ہم کو یہی بتایا ہے۔ آپ کہہ دیجیئے کہ اللہ تعالیٰ فحش بات کی تعلیم نہیں دیتا، کیا اللہ کے ذمہ ایسی بات لگاتے ہو جس کی تم سند نہیں رکھتے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiii{آپ کہہ دیجیئے کہ میرے رب نے حکم دیا ہے انصاف کا اور یہ کہ تم ہر سجده کے وقت اپنا رخ سیدھا رکھا کرو اور اللہ تعالیٰ کی عبادت اس طور پر کرو کہ اس عبادت کو خالص اللہ ہی کے واسطے رکھو۔ تم کو اللہ نے جس طرح شروع میں پیدا کیا تھا اسی طرح تم دوباره پیدا ہوگے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiv{بعض لوگوں کو اللہ نے ہدایت دی ہے اور بعض پر گمراہی ﺛابت ہوگئی ہے۔ ان لوگوں نے اللہ تعالیٰ کو چھوڑ کر شیطانوں کو دوست بنالیا ہے اور خیال رکھتے ہیں کہ وه راست پر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cmlxxxv{اے اوﻻد آدم! تم مسجد کی ہر حاضری کے وقت اپنا لباس پہن لیا کرو۔ اور خوب کھاؤ اور پیو اور حد سے مت نکلو۔ بےشک اللہ حد سے نکل جانے والوں کو پسند نہیں کرتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvi{آپ فرمائیے کہ اللہ تعالیٰ کے پیدا کئے ہوئے اسباب زینت کو، جن کو اس نے اپنے بندوں کے واسطے بنایا ہے اور کھانے پینے کی حلال چیزوں کو کس شخص نے حرام کیا ہے؟ آپ کہہ دیجئے کہ یہ اشیا اس طور پر کہ قیامت کے روز خالص ہوں گی اہل ایمان کے لئے، دنیوی زندگی میں مومنوں کے لئے بھی ہیں۔ ہم اسی طرح تمام آیات کو سمجھ داروں کے واسطے صاف صاف بیان کرتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvii{آپ فرمائیے کہ البتہ میرے رب نے صرف حرام کیا ہے ان تمام فحش باتوں کو جو علانیہ ہیں اور جو پوشیده ہیں اور ہر گناه کی بات کو اور ناحق کسی پر ﻇلم کرنے کو اور اس بات کو کہ تم اللہ کے ساتھ کسی ایسی چیز کو شریک ٹھہراؤ جس کی اللہ نے کوئی سند نازل نہیں کی اور اس بات کو کہ تم لوگ اللہ کے ذمے ایسی بات لگادو جس کو تم جانتے نہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cmlxxxviii{اور ہر گروه کے لئے ایک میعاد معین ہے سو جس وقت ان کی میعاد معین آجائے گی اس وقت ایک ساعت نہ پیچھے ہٹ سکیں گے اور نہ آگے بڑھ سکیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cmlxxxix{اے اوﻻد آدم! اگر تمہارے پاس پیغمبر آئیں جو تم ہی میں سے ہوں جو میرے احکام تم سے بیان کریں تو جو شخص تقویٰ اختیار کرے اور درستی کرے سو ان لوگوں پر نہ کچھ اندیشہ ہے اور نہ وه غمگین ہوں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cmxc{اور جو لوگ ہمارے ان احکام کو جھٹلائیں اور ان سے تکبر کریں وه لوگ دوزخ والے ہوں گے وه اس میں ہمیشہ ہمیشہ رہیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cmxci{سو اس شخص سے زیاده ﻇالم کون ہوگا جو اللہ تعالیٰ پر جھوٹ باندھے یا اس کی آیتوں کو جھوٹا بتائے، ان لوگوں کے نصیب کا جو کچھ کتاب سے ہے وه ان کو مل جائے گا، یہاں تک کہ جب ان کے پاس ہمارے بھیجے ہوئے فرشتے ان کی جان قبض کرنے آئیں گے تو کہیں گے کہ وه کہاں گئے جن کی تم اللہ کو چھوڑ کر عبادت کرتے تھے، وه کہیں گے کہ ہم سے سب غائب ہوگئے اور اپنے کافر ہونے کا اقرار کریں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cmxcii{اللہ تعالیٰ فرمائے گا کہ جو فرقے تم سے پہلے گزر چکے ہیں جنات میں سے بھی اور آدمیوں میں سے بھی، ان کے ساتھ تم بھی دوزخ میں جاؤ۔ جس وقت بھی کوئی جماعت داخل ہوگی اپنی دوسری جماعت کو لعنت کرے گی یہاں تک کہ جب اس میں سب جمع ہوجائیں گے تو پچھلے لوگ پہلے لوگوں کی نسبت کہیں گے کہ ہمارے پروردگار ہم کو ان لوگوں نے گمراه کیا تھا سو ان کو دوزخ کا عذاب دو گنا دے۔ اللہ تعالیٰ فرمائے گا کہ سب ہی کا دوگنا ہے، لیکن تم کو خبر نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cmxciii{اور پہلے لوگ پچھلے لوگوں سے کہیں گے کہ پھر تم کو ہم پر کوئی فوقیت نہیں سو تم بھی اپنی کمائی کے بدلے میں عذاب کامزه چکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cmxciv{جن لوگوں نے ہماری آیتوں کو جھٹلایا اور ان سے تکبر کیا ان کے لئے آسمان کے دروازے نہ کھولے جائیں گے اور وه لوگ کبھی جنت میں نہ جائیں گے جب تک کہ اونٹ سوئی کے ناکہ کے اندر سے نہ چلا جائے اور ہم مجرم لوگوں کو ایسی ہی سزا دیتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cmxcv{ان کے لئے آتش دوزخ کا بچھونا ہوگا اور ان کے اوپر (اسی کا) اوڑھنا ہوگا اور ہم ایسے ﻇالموں کو ایسی ہی سزا دیتے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cmxcvi{اور جو لوگ ایمان ﻻئے اور انہوں نے نیک کام کئے ہم کسی شخص کو اس کی قدرت سے زیاده کسی کا مکلف نہیں بناتے وہی لوگ جنت والے ہیں اور وه اس میں ہمیشہ ہمیشہ رہیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cmxcvii{اور جو کچھ ان کے دلوں میں (کینہ) تھا ہم اس کو دور کردیں گے۔ ان کے نیچے نہریں جاری ہوں گی۔ اور وه لوگ کہیں گے کہ اللہ کا (لاکھ لاکھ) شکر ہے جس نے ہم کو اس مقام تک پہنچایا اور ہماری کبھی رسائی نہ ہوتی اگر اللہ تعالیٰ ہم کو نہ پہنچاتا۔ واقعی ہمارے رب کے پیغمبر سچی باتیں لے کر آئے تھے۔ اور ان سے پکار کر کہا جائے گا کہ اس جنت کے تم وارث بنائے گئے ہو اپنے اعمال کے بدلے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cmxcviii{اور اہل جنت اہل دوزخ کو پکاریں گے کہ ہم سے جو ہمارے رب نے وعده فرمایا تھا ہم نے تو اس کو واقعہ کے مطابق پایا، سو تم سے جو تمہارے رب نے وعده کیا تھا تم نے بھی اس کو واقعہ کے مطابق پایا وه کہیں گے ہاں، پھر ایک پکارنے واﻻ دونوں کے درمیان میں پکارے گا کہ اللہ کی مار ہو ان ﻇالموں پر\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cmxcix{جو اللہ کی راه سے اعراض کرتے تھے اور اس میں کجی تلاش کرتے تھے اور وه لوگ آخرت کے بھی منکر تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@m{اور ان دونوں کے درمیان ایک آڑ ہوگی اور اعراف کے اوپر بہت سے آدمی ہوں گے وه لوگ، ہر ایک کو ان کے قیافہ سے پہچانیں گے اور اہل جنت کو پکار کر کہیں گے، السلام علیکم! ابھی یہ اہل اعراف جنت میں داخل نہیں ہوئے ہوں گے اور اس کے امیدوار ہوں گے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mi{اور جب ان کی نگاہیں اہل دوزخ کی طرف پھریں گی تو کہیں گے اے ہمارے رب! ہم کو ان ﻇالم لوگوں کے ساتھ شامل نہ کر\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mii{اور اہل اعراف بہت سے آدمیوں کو جن کو کہ ان کے قیافہ سے پہچانیں گے پکاریں گے کہیں گے کہ تمہاری جماعت اور تمہارا اپنے کو بڑا سمجھنا تمہارے کچھ کام نہ آیا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@miii{کیا یہ وہی ہیں جن کی نسبت تم قسمیں کھا کھا کر کہا کرتے تھے کہ اللہ تعالیٰ ان پر رحمت نہ کرے گا، ان کو یوں حکم ہوگا کہ جاؤ جنت میں تم پر نہ کچھ خوف ہے اور نہ تم مغموم ہوگے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@miv{اور دوزخ والے جنت والوں کو پکاریں گے، کہ ہمارےاوپر تھوڑا پانی ہی ڈال دو یا اور ہی کچھ دے دو، جو اللہ نے تم کو دے رکھا ہے۔ جنت والے کہیں گے کہ اللہ تعالیٰ نے دونوں چیزوں کی کافروں کے لئے بندش کردی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mv{جنہوں نے دنیا میں اپنے دین کو لہو ولعب بنا رکھا تھا اور جن کو دنیاوی زندگی نے دھوکہ میں ڈال رکھا تھا۔ سو ہم (بھی) آج کے روز ان کا نام بھول جائیں گے جیسا کہ وه اس دن کو بھول گئے اور جیسا یہ ہماری آیتوں کا انکار کرتے تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mvi{اور ہم نے ان لوگوں کے پاس ایک ایسی کتاب پہنچادی ہے جس کو ہم نے اپنے علم کامل سے بہت واضح کر کے بیان کردیا ہے، وه ذریعہ ہدایت اور رحمت ان لوگوں کے لئے ہے جو ایمان ﻻئے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mvii{ان لوگوں کو اور کسی بات کا انتظار نہیں صرف اس کے اخیر نتیجہ کا انتظار ہے، جس روز اس کا اخیر نتیجہ پیش آئے گا اور اس روز جو لوگ اس کو پہلے سے بھولے ہوئے تھے یوں کہیں گے کہ واقعی ہمارے رب کے پیغمبر سچی سچی باتیں ﻻئے تھے، سو اب کیا کوئی ہمارا سفارشی ہے کہ وه ہماری سفارش کردے یا کیا ہم پھر واپس بھیجے جاسکتے ہیں تاکہ ہم لوگ ان اعمال کے، جن کو ہم کیا کرتے تھے برخلاف دوسرے اعمال کریں۔ بےشک ان لوگوں نے اپنے آپ کو خساره میں ڈال دیا اور یہ جو جو باتیں تراشتے تھے سب گم ہوگئیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mviii{بے شک تمہارا رب اللہ ہی ہے جس نے سب آسمانوں اور زمین کو چھ روز میں پیدا کیا ہے، پھر عرش پر قائم ہوا۔ وه شب سے دن کو ایسے طور پر چھپا دیتا ہے کہ وه شب اس دن کو جلدی سے آ لیتی ہے اور سورج اور چاند اور دوسرے ستاروں کو پیدا کیا ایسے طور پر کہ سب اس کے حکم کے تابع ہیں۔ یاد رکھو اللہ ہی کے لئے خاص ہے خالق ہونا اور حاکم ہونا، بڑی خوبیوں سے بھرا ہوا ہے اللہ جو تمام عالم کا پروردگار ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mix{تم لوگ اپنے پروردگار سے دعا کیا کرو گڑگڑا کر کے بھی اور چپکے چپکے بھی۔ واقعی اللہ تعالیٰ ان لوگوں کو ناپسند کرتا ہے جو حد سے نکل جائیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mx{اور دنیا میں اس کے بعد کہ اس کی درستی کردی گئی ہے، فساد مت پھیلاؤ اور تم اللہ کی عبادت کرو اس سے ڈرتے ہوئے اور امیدوار رہتے ہوئے۔ بے شک اللہ تعالیٰ کی رحمت نیک کام کرنے والوں کے نزدیک ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mxi{اور وه ایسا ہے کہ اپنی باران رحمت سے پہلے ہواؤں کو بھیجتا ہے کہ وه خوش کر دیتی ہیں، یہاں تک کہ جب وه ہوائیں بھاری بادلوں کو اٹھا لیتی ہیں، تو ہم اس بادل کو کسی خشک سرزمین کی طرف ہانک لے جاتے ہیں، پھر اس بادل سے پانی برساتے ہیں پھر اس پانی سے ہر قسم کے پھل نکالتے ہیں۔ یوں ہی ہم مردوں کو نکال کھڑا کریں گے تاکہ تم سمجھو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mxii{اور جو ستھری سرزمین ہوتی ہے اس کی پیداوار تو اللہ کے حکم سے خوب نکلتی ہے اور جو خراب ہے اس کی پیداوار بہت کم نکلتی ہے، اسی طرح ہم دﻻئل کو طرح طرح سے بیان کرتے ہیں، ان لوگوں کے لئے جو شکر کرتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mxiii{ہم نے نوح (علیہ السلام) کو ان کی قوم کی طرف بھیجا توانہوں نے فرمایا اے میری قوم! تم اللہ کی عبادت کرو اس کے سوا کوئی تمہارا معبود ہونے کے قابل نہیں، مجھ کو تمہارے لئے ایک بڑے دن کے عذاب کا اندیشہ ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mxiv{ان کی قوم کے بڑے لوگوں نے کہا کہ ہم تم کو صریح غلطی میں دیکھتے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mxv{انہوں نے فرمایا کہ اے میری قوم! مجھ میں تو ذرا بھی گمراہی نہیں لیکن میں پروردگار عالم کا رسول ہوں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mxvi{تم کو اپنے پروردگار کے پیغام پہنچاتا ہوں اور تمہاری خیر خواہی کرتا ہوں اور میں اللہ کی طرف سے ان امور کی خبر رکھتا ہوں جن کی تم کو خبر نہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mxvii{اور کیا تم اس بات سے تعجب کرتے ہو کہ تمہارے پروردگار کی طرف سے تمہارے پاس ایک ایسے شخص کی معرفت، جو تمہاری ہی جنس کا ہے، کوئی نصیحت کی بات آگئی تاکہ وه شخص تم کو ڈرائے اور تاکہ تم ڈرجاؤ اور تاکہ تم پر رحم کیا جائے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mxviii{سو وه لوگ ان کی تکذیب ہی کرتے رہے تو ہم نے نوح (علیہ السلام) کو اور ان کو جو ان کےساتھ کشتی میں تھے، بچالیا اور جن لوگوں نے ہماری آیتوں کو جھٹلایا تھا ان کو ہم نے غرق کردیا۔ بے شک وه لوگ اندھے ہورہے تھے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mxix{اور ہم نے قوم عاد کی طرف ان کے بھائی ہود (علیہ السلام) کو بھیجا۔ انہوں نے فرمایا اے میری قوم! تم اللہ کی عبادت کرو، اس کے سوا کوئی تمہارا معبود نہیں، سو کیا تم نہیں ڈرتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mxx{ان کی قوم میں جو بڑے لوگ کافر تھے انہوں نے کہا ہم تم کو کم عقلی میں دیکھتے ہیں۔ اور ہم بے شک تم کو جھوٹے لوگوں میں سمجھتے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mxxi{انہوں نے فرمایا کہ اے میری قوم! مجھ میں ذرا بھی کم عقلی نہیں لیکن میں پروردگار عالم کا بھیجا ہوا پیغمبر ہوں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mxxii{تم کو اپنے پروردگار کے پیغام پہنچاتا ہوں اور میں تمہارا امانتدار خیرخواه ہوں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mxxiii{اور کیا تم اس بات سے تعجب کرتے ہو کہ تمہارے پروردگار کی طرف سے تمہارے پاس ایک ایسے شخص کی معرفت، جو تمہاری ہی جنس کاہے کوئی نصیحت کی بات آگئی تاکہ وه شخص تم کو ڈرائے اور تم یہ حالت یاد کرو کہ اللہ نے تم کو قوم نوح کے بعد جانشین بنایا اور ڈیل ڈول میں تم کو پھیلاؤ زیاده دیا، سو اللہ کی نعمتوں کو یاد کرو تاکہ تم کو فلاح ہو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mxxiv{انہوں نے کہا کہ کیا آپ ہمارے پاس اس واسطے آئے ہیں کہ ہم صرف اللہ ہی کی عبادت کریں اور جن کو ہمارے باپ دادا پوجتے تھے ان کو چھوڑ دیں، پس ہم کو جس عذاب کی دھمکی دیتے ہو اس کو ہمارے پاس منگوا دو اگر تم سچے ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mxxv{انہوں نے فرمایا کہ بس اب تم پر اللہ کی طرف سے عذاب اور غضب آیا ہی چاہتا ہے کیا تم مجھ سے ایسے ناموں کے باب میں جھگڑتے ہو جن کو تم نے اور تمہارے باپ دادوں نے ٹھہرالیا ہے؟ ان کے معبود ہونے کی اللہ نے کوئی دلیل نہیں بھیجی۔ سو تم منتظر رہو میں بھی تمہارے ساتھ انتظار کر رہا ہوں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mxxvi{غرض ہم نے ان کو اور ان کے ساتھیوں کو اپنی رحمت سے بچالیا اور ان لوگوں کی جڑ کاٹ دی، جنہوں نے ہماری آیتوں کو جھٹلایا تھا اور وه ایمان ﻻنے والے نہ تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mxxvii{اور ہم نے ﺛمود کی طرف ان کے بھائی صالح (علیہ السلام) کو بھیجا۔ انہوں نے فرمایا اے میری قوم! تم اللہ کی عبادت کرو اس کے سوا کوئی تمہارا معبود نہیں۔ تمہارے پاس تمہارے پروردگار کی طرف سے ایک واضح دلیل آچکی ہے۔ یہ اونٹنی ہے اللہ کی جو تمہارے لئے دلیل ہے سو اس کو چھوڑ دو کہ اللہ تعالیٰ کی زمین میں کھاتی پھرے اور اس کو برائی کے ساتھ ہاتھ بھی مت لگانا کہ کہیں تم کو دردناک عذاب آپکڑے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mxxviii{اور تم یہ حالت یاد کرو کہ اللہ تعالیٰ نے تم کو عاد کے بعد جانشین بنایا اور تم کو زمین پر رہنے کا ٹھکانا دیا کہ نرم زمین پر محل بناتے ہو اور پہاڑوں کو تراش تراش کر ان میں گھر بناتے ہو، سو اللہ تعالیٰ کی نعمتوں کو یاد کرو اور زمین میں فساد مت پھیلاؤ\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mxxix{ان کی قوم میں جو متکبر سردار تھے انہوں نے غریب لوگوں سے جو کہ ان میں سے ایمان لے آئے تھے پوچھا، کیا تم کواس بات کا یقین ہے کہ صالح (علیہ السلام) اپنے رب کی طرف سے بھیجے ہوئے ہیں؟ انہوں نے کہا کہ بےشک ہم تو اس پر پورا یقین رکھتے ہیں جو ان کو دے کر بھیجا گیا ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mxxx{وه متکبر لوگ کہنے لگے کہ تم جس بات پر یقین ﻻئے ہوئے ہو، ہم تو اس کے منکر ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mxxxi{پس انہوں نے اس اونٹنی کو مار ڈاﻻ اور اپنے پروردگار کے حکم سے سرکشی کی اور کہنے لگے کہ اے صالح! جس کی آپ ہم کو دھمکی دیتے تھے اس کو منگوائیے اگر آپ پیغمبر ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mxxxii{پس ان کو زلزلہ نے آپکڑا اور وه اپنے گھروں میں اوندھے کے اوندھے پڑے ره گئے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mxxxiii{اس وقت (صالح علیہ السلام) ان سے منھ موڑ کر چلے، اور فرمانے لگے کہ اے میری قوم! میں نے تو تم کو اپنے پروردگار کا حکم پہنچادیا تھا اور میں نے تمہاری خیرخواہی کی لیکن تم لوگ خیرخواہوں کو پسند نہیں کرتے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mxxxiv{اور ہم نے لوط (علیہ السلام) کو بھیجا جبکہ انہوں نے اپنی قوم سے فرمایا کہ تم ایسا فحش کام کرتے ہو جس کو تم سے پہلے کسی نے دنیا جہان والوں میں سے نہیں کیا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mxxxv{تم مردوں کے ساتھ شہوت رانی کرتے ہو عورتوں کو چھوڑ کر، بلکہ تم تو حد ہی سے گزر گئے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mxxxvi{اور ان کی قوم سے کوئی جواب نہ بن پڑا، بجز اس کے کہ آپس میں کہنے لگے کہ ان لوگوں کو اپنی بستی سے نکال دو۔ یہ لوگ بڑے پاک صاف بنتے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mxxxvii{سو ہم نے لوط (علیہ السلام) کو اور ان کے گھر والوں کو بچا لیا بجز ان کی بیوی کے کہ وه ان ہی لوگوں میں رہی جو عذاب میں ره گئے تھے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mxxxviii{اور ہم نے ان پر خاص طرح کا مینہ برسایا پس دیکھو تو سہی ان مجرموں کا انجام کیسا ہوا؟\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mxxxix{اور ہم نے مدین کی طرف ان کے بھائی شعیب (علیہ السلام) کو بھیجا۔ انہوں نے فرمایا اے میری قوم! تم اللہ کی عبادت کرو اس کے سوا کوئی تمہارا معبود نہیں، تمہارے پاس تمہارے پروردگار کی طرف سے واضح دلیل آچکی ہے۔ پس تم ناپ اور تول پورا پورا کیا کرو اور لوگوں کو ان کی چیزیں کم کرکے مت دو اور روئے زمین میں، اس کے بعد کہ اس کی درستی کردی گئی، فساد مت پھیلاؤ، یہ تمہارے لئے نافع ہے اگر تم تصدیق کرو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mxl{اور تم سڑکوں پر اس غرض سے مت بیٹھا کرو کہ اللہ پر ایمان ﻻنے والے کو دھمکیاں دو اور اللہ کی راه سے روکو اور اس میں کجی کی تلاش میں لگے رہو۔ اور اس حالت کو یاد کرو جب کہ تم کم تھے پھر اللہ نے تم کو زیاده کردیا اور دیکھو کہ کیسا انجام ہوا فساد کرنے والوں کا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mxli{اور اگر تم میں سے کچھ لوگ اس حکم پر، جس کو دے کر مجھ کو بھیجا گیا، ایمان لے آئے ہیں اور کچھ ایمان نہیں ﻻئے ہیں تو ذرا ٹھہر جاؤ! یہاں تک کہ ہمارے درمیان اللہ فیصلہ کئے دیتا ہے اور وه سب فیصلہ کرنے والوں سے بہتر ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mxlii{ان کی قوم کے متکبر سرداروں نے کہا کہ اے شعیب! ہم آپ کو اور جو آپ کے ہمراه ایمان والے ہیں ان کو اپنی بستی سے نکال دیں گے الّا یہ کہ تم ہمارے مذہب میں پھر آجاؤ۔ شعیب (علیہ السلام) نے جواب دیا کہ کیا ہم تمہارے مذہب میں آجائیں گو ہم اس کو مکروه ہی سمجھتے ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mxliii{ہم تو اللہ تعالیٰ پر بڑی جھوٹی تہمت لگانے والے ہو جائیں گے اگر ہم تمہارے دین میں آجائیں اس کے بعد کہ اللہ تعالیٰ نے ہم کو اس سے نجات دی اور ہم سے ممکن نہیں کہ تمہارے مذہب میں پھر آجائیں، لیکن ہاں یہ کہ اللہ ہی نے جو ہمارا مالک ہے مقدر کیا ہو۔ ہمارے رب کا علم ہر چیز کو محیط ہے، ہم اللہ ہی پر بھروسہ رکھتے ہیں۔ اے ہمارے پروردگار! ہمارے اور ہماری قوم کے درمیان حق کے موافق فیصلہ کر دے اور تو سب سے اچھا فیصلہ کرنے واﻻ ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mxliv{اور ان کی قوم کے کافر سرداروں نے کہا کہ اگر تم شعیب (علیہ السلام) کی راه پر چلو گے تو بےشک بڑا نقصان اٹھاؤ گے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mxlv{پس ان کو زلزلے نے آپکڑا سو وه اپنے گھروں میں اوندھے کے اوندھے پڑے ره گئے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mxlvi{جنہوں نے شعیب (علیہ السلام) کی تکذیب کی تھی ان کی یہ حالت ہوگئی جیسے ان گھروں میں کبھی بسے ہی نہ تھے۔ جنہوں نے شعیب (علیہ السلام) کی تکذیب کی تھی وہی خسارے میں پڑ گئے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mxlvii{اس وقت شعیب (علیہ السلام) ان سے منھ موڑ کر چلے اور فرمانے لگے کہ اے میری قوم! میں نے تم کو اپنے پروردگار کے احکام پہنچا دیئے تھے اور میں نے تمہاری خیر خواہی کی۔ پھر میں ان کافر لوگوں پر کیوں رنج کروں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mxlviii{اور ہم نے کسی بستی میں کوئی نبی نہیں بھیجا کہ وہاں کے رہنے والوں کو ہم نے سختی اور تکلیف میں نہ پکڑا ہو، تاکہ وه گڑ گڑائیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mxlix{پھر ہم نے اس بدحالی کی جگہ خوش حالی بدل دی، یہاں تک کہ ان کو خوب ترقی ہوئی اور کہنے لگے کہ ہمارے آباواجداد کو بھی تنگی اور راحت پیش آئی تھی تو ہم نے ان کو دفعتاً پکڑ لیا اور ان کو خبر بھی نہ تھی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ml{اور اگر ان بستیوں کے رہنے والے ایمان لے آتے اور پرہیزگاری اختیار کرتے تو ہم ان پر آسمان اور زمین کی برکتیں کھول دیتے لیکن انہوں نے تکذیب کی تو ہم نے ان کے اعمال کی وجہ سے ان کو پکڑ لیا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mli{کیا پھر بھی ان بستیوں کے رہنے والے اس بات سے بے فکر ہوگئے ہیں کہ ان پر ہمارا عذاب شب کے وقت آپڑے جس وقت وه سوتے ہوں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mlii{اور کیا ان بستیوں کے رہنے والے اس بات سے بےفکر ہوگئے ہیں کہ ان پر ہمارا عذاب دن چڑھے آپڑے جس وقت کہ وه اپنے کھیلوں میں مشغول ہوں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mliii{کیا پس وه اللہ کی اس پکڑ سے بےفکر ہوگئے۔ سو اللہ کی پکڑ سے بجز ان کے جن کی شامت ہی آگئی ہو اور کوئی بےفکر نہیں ہوتا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mliv{اور کیا ان لوگوں کو جو زمین کے وارث ہوئے وہاں کے لوگوں کی ہلاکت کے بعد (ان واقعات مذکوره نے) یہ بات نہیں بتلائی کہ اگر ہم چاہیں تو ان کے جرائم کے سبب ان کو ہلاک کر ڈالیں اور ہم ان کے دلوں پر بند لگا دیں، پس وه نہ سن سکیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mlv{ان بستیوں کے کچھ کچھ قصے ہم آپ سے بیان کر رہے ہیں اور ان سب کے پاس ان کے پیغمبر معجزات لے کر آئے، پھر جس چیز کو انہوں نے ابتدا میں جھوٹا کہہ دیا یہ بات نہ ہوئی کہ پھر اس کو مان لیتے، اللہ تعالیٰ اسی طرح کافروں کے دلوں پر بند لگا دیتا ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mlvi{اور اکثر لوگوں میں ہم نے وفائے عہد نہ دیکھا اور ہم نے اکثر لوگوں کو بےحکم ہی پایا\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mlvii{پھر ان کے بعد ہم نے موسیٰ (علیہ السلام) کو اپنے دﻻئل دے کر فرعون اور اس کے امرا کے پاس بھیجا، مگر ان لوگوں نے ان کا بالکل حق ادا نہ کیا۔ سو دیکھئے ان مفسدوں کا کیا انجام ہوا؟\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mlviii{اور موسیٰ (علیہ السلام) نے فرمایا کہ اے فرعون! میں رب العالمین کی طرف سے پیغمبر ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mlix{میرے لیے یہی شایان ہے کہ بجز سچ کے اللہ کی طرف کوئی بات منسوب نہ کروں، میں تمہارے پاس تمہارے رب کی طرف سے ایک بڑی دلیل بھی ﻻیا ہوں، سو تو بنی اسرائیل کو میرے ساتھ بھیج دے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mlx{فرعون نے کہا، اگر آپ کوئی معجزه لے کر آئے ہیں تو اس کو اب پیش کیجئے! اگر آپ سچے ہیں\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mlxi{پس آپ نے اپنا عصا ڈال دیا، سو دفعتاً وه صاف ایک اﮊدھا بن گیا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mlxii{اور اپنا ہاتھ باہر نکالا سو وه یکایک سب دیکھنے والوں کے روبرو بہت ہی چمکتا ہوا ہو گیا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mlxiii{قوم فرعون میں جو سردار لوگ تھے انہوں نے کہا کہ واقعی یہ شخص بڑا ماہر جادوگر ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mlxiv{یہ چاہتا ہے کہ تم کو تمہاری سرزمین سے باہر کر دے سو تم لوگ کیا مشوره دیتے ہو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mlxv{انہوں نے کہا کہ آپ ان کو اور ان کے بھائی کو مہلت دیجئے اور شہروں میں ہرکاروں کو بھیج دیجئے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mlxvi{کہ وه سب ماہر جادو گروں کو آپ کے پاس ﻻ کر حاضر کر دیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mlxvii{اور وه جادوگر فرعون کے پاس حاضر ہوئے، کہنے لگے کہ اگر ہم غالب آئے تو ہم کو کوئی بڑا صلہ ملے گا؟\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mlxviii{فرعون نے کہا کہ ہاں اور تم مقرب لوگوں میں داخل ہو جاؤ گے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mlxix{ان ساحروں نے عرض کیا کہ اے موسیٰ! خواه آپ ڈالئے اور یا ہم ہی ڈالیں؟\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mlxx{(موسیٰ علیہ السلام) نے فرمایا کہ تم ہی ڈالو، پس جب انہوں نے ڈاﻻ تو لوگوں کی نظر بندی کر دی اور ان پر ہیبت غالب کر دی اور ایک طرح کا بڑا جادو دکھلایا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mlxxi{اور ہم نے موسیٰ (علیہ السلام) کو حکم دیا کہ اپنا عصا ڈال دیجئے! سو عصا کا ڈالنا تھا کہ اس نے ان کے سارے بنے بنائے کھیل کو نگلنا شروع کیا\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mlxxii{پس حق ﻇاہر ہوگیا اور انہوں نے جو کچھ بنایا تھا سب جاتا رہا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mlxxiii{پس وه لوگ اس موقع پر ہار گئے اور خوب ذلیل ہوکر پھرے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mlxxiv{اور وه جو ساحر تھے سجده میں گر گئے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mlxxv{کہنے لگے کہ ہم ایمان ﻻئے رب العالمین پر\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mlxxvi{جو موسیٰ اور ہارون کا بھی رب ہے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mlxxvii{فرعون کہنے لگا کہ تم موسیٰ پر ایمان ﻻئے ہو بغیر اس کے کہ میں تم کو اجازت دوں؟ بےشک یہ سازش تھی جس پر تمہارا عمل درآمد ہوا ہے اس شہر میں تاکہ تم سب اس شہر سے یہاں کے رہنے والوں کو باہر نکال دو۔ سو اب تم کو حقیقت معلوم ہوئی جاتی ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mlxxviii{میں تمہارے ایک طرف کے ہاتھ اور دوسری طرف کے پاؤں کاٹوں گا۔ پھر تم سب کو سولی پر لٹکا دوں گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mlxxix{انہوں نے جواب دیا کہ ہم (مر کر) اپنے مالک ہی کے پاس جائیں گے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mlxxx{اور تو نے ہم میں کونسا عیب دیکھا ہے بجز اس کے کہ ہم اپنے رب کے احکام پر ایمان لے آئے، جب وه ہمارے پاس آئے۔ اے ہمارے رب! ہمارے اوپر صبر کا فیضان فرما اور ہماری جان حالت اسلام پر نکال\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mlxxxi{اور قوم فرعون کے سرداروں نے کہا کہ کیا آپ موسیٰ (علیہ السلام) اور ان کی قوم کو یوں ہی رہنے دیں گے کہ وه ملک میں فساد کرتے پھریں، اور وه آپ کو اور آپ کے معبودوں کو ترک کئے رہیں۔ فرعون نے کہا کہ ہم ابھی ان لوگوں کے بیٹوں کو قتل کرنا شروع کر دیں گے اور عورتوں کو زنده رہنے دیں گے اور ہم کو ان پر ہر طرح کا زور ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mlxxxii{موسیٰ (علیہ السلام) نے اپنی قوم سے فرمایا اللہ تعالیٰ کا سہارا حاصل کرو اور صبر کرو، یہ زمین اللہ تعالیٰ کی ہے، اپنے بندوں میں سے جس کو چاہے وه مالک بنا دے اور اخیر کامیابی ان ہی کی ہوتی ہے جو اللہ سے ڈرتے ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mlxxxiii{قوم کے لوگ کہنے لگے کہ ہم تو ہمیشہ مصیبت ہی میں رہے، آپ کی تشریف آوری سے قبل بھی اور آپ کی تشریف آوری کے بعد بھی۔ موسیٰ (علیہ السلام) نے فرمایا کہ بہت جلد اللہ تمہارے دشمن کو ہلاک کر دے گا اور بجائے ان کے تم کو اس سرزمین کا خلیفہ بنا دے گا پھر تمہارا طرز عمل دیکھے گا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mlxxxiv{اور ہم نے فرعون والوں کو مبتلا کیا قحط سالی میں اور پھلوں کی کم پیداواری میں، تاکہ وه نصیحت قبول کریں\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mlxxxv{سو جب ان پر خوشحالی آجاتی تو کہتے کہ یہ تو ہمارے لیے ہونا ہی چاہئے اور اگر ان کو کوئی بدحالی پیش آتی تو موسیٰ (علیہ السلام) اور ان کے ساتھیوں کی نحوست بتلاتے۔ یاد رکھو کہ ان کی نحوست اللہ تعالیٰ کے پاس ہے، لیکن ان کے اکثر لوگ نہیں جانتے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mlxxxvi{اور یوں کہتے کیسی ہی بات ہمارے سامنے لاؤ کہ ان کے ذریعہ سے ہم پر جادو چلاؤ جب بھی ہم تمہاری بات ہر گز نہ مانیں گے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mlxxxvii{پھر ہم نے ان پر طوفان بھیجا اور ٹڈیاں اور گھن کا کیڑا اور مینڈک اور خون، کہ یہ سب کھلے کھلے معجزے تھے۔ سو وه تکبر کرتے رہے اور وه لوگ کچھ تھے ہی جرائم پیشہ\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mlxxxviii{اور جب ان پر کوئی عذاب واقع ہوتا تو یوں کہتے کہ اے موسیٰ! ہمارے لیے اپنے رب سے اس بات کی دعا کر دیجئے! جس کا اس نے آپ سے عہد کر رکھا ہے، اگر آپ اس عذاب کو ہم سے ہٹا دیں تو ہم ضرور ضرور آپ کے کہنے سے ایمان لے آئیں گے اور ہم بنی اسرائیل کو بھی (رہا کر کے) آپ کے ہمراه کر دیں گے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mlxxxix{پھر جب ان سے اس عذاب کو ایک خاص وقت تک کہ اس تک ان کو پہنچنا تھا ہٹا دیتے، تو وه فوراً ہی عہد شکنی کرنے لگتے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mxc{پھر ہم نے ان سے بدلہ لیا یعنی ان کو دریا میں غرق کر دیا اس سبب سے کہ وه ہماری آیتوں کو جھٹلاتے تھے اور ان سے بالکل ہی غفلت کرتے تھے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mxci{اور ہم نے ان لوگوں کو جو کہ بالکل کمزور شمار کئے جاتے تھے۔ اس سرزمین کے پورب پچھم کا مالک بنا دیا، جس میں ہم نے برکت رکھی ہے اور آپ کے رب کا نیک وعده، بنی اسرائیل کے حق میں ان کے صبر کی وجہ سے پورا ہوگیا اور ہم نے فرعون کے اور اس کی قوم کے ساختہ پرداختہ کارخانوں کو اور جو کچھ وه اونچی اونچی عمارتیں بنواتے تھے، سب کو درہم برہم کر دیا\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mxcii{اور ہم نے بنی اسرائیل کو دریا سے پار اتار دیا۔ پس ان لوگوں کا ایک قوم پر گزر ہوا جو اپنے چند بتوں سے لگے بیٹھے تھے، کہنے لگے اے موسیٰ! ہمارے لیے بھی ایک معبود ایسا ہی مقرر کر دیجئے! جیسے ان کے یہ معبود ہیں۔ آپ نے فرمایا کہ واقعی تم لوگوں میں بڑی جہالت ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mxciii{یہ لوگ جس کام میں لگے ہیں یہ تباه کیا جائے گا اور ان کا یہ کام محض بےبنیاد ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mxciv{فرمایا کیا اللہ تعالیٰ کے سوا اور کسی کو تمہارا معبود تجویز کردوں؟ حاﻻنکہ اس نے تم کو تمام جہان والوں پر فوقیت دی ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mxcv{اور وه وقت یاد کرو جب ہم نے تم کو فرعون والوں سے بچا لیا جو تم کو بڑی سخت تکلیفیں پہنچاتے تھے۔ تمہارے بیٹوں کو قتل کر ڈالتے تھے اور تمہاری عورتوں کو زنده چھوڑ دیتے تھے اور اس میں تمہارے پروردگار کی طرف سے بڑی بھاری آزمائش تھی\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mxcvi{اور ہم نے موسیٰ (علیہ السلام) سے تیس راتوں کا وعده کیا اور دس رات مزید سے ان تیس راتوں کو پورا کیا۔ سو ان کے پروردگار کا وقت پورے چالیس رات کا ہوگیا۔ اور موسیٰ (علیہ السلام) نے اپنے بھائی ہارون (علیہ السلام) سے کہا کہ میرے بعد ان کا انتظام رکھنا اور اصلاح کرتے رہنا اور بدنظم لوگوں کی رائے پر عمل مت کرنا\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mxcvii{اور جب موسیٰ (علیہ السلام) ہمارے وقت پر آئے اور ان کے رب نے ان سے باتیں کیں تو عرض کیا کہ اے میرے پروردگار! اپنا دیدار مجھ کو کرا دیجئے کہ میں آپ کو ایک نظر دیکھ لوں ارشاد ہوا کہ تم مجھ کو ہرگز نہیں دیکھ سکتے لیکن تم اس پہاڑ کی طرف دیکھتے رہو وه اگر اپنی جگہ پر برقرار رہا تو تم بھی مجھے دیکھ سکو گے۔ پس جب ان کے رب نے پہاڑ پر تجلی فرمائی تو تجلی نے اس کے پرخچے اڑا دیئے اور موسیٰ (علیہ السلام) بےہوش ہوکر گر پڑے۔ پھر جب ہوش میں آئے تو عرض کیا، بےشک آپ کی ذات منزه ہے میں آپ کی جناب میں توبہ کرتا ہوں اور میں سب سے پہلے آپ پر ایمان ﻻنے واﻻ ہوں\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mxcviii{ارشاد ہوا کہ اے موسیٰ! میں نے پیغمبری اور اپنی ہمکلامی سے اور لوگوں پر تم کو امتیاز دیا ہے تو جو کچھ تم کو میں نے عطا کیا ہے اس کو لو اور شکر کرو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mxcix{اور ہم نے چند تختیوں پر ہر قسم کی نصیحت اور ہر چیز کی تفصیل ان کو لکھ کر دی، تم ان کو پوری طاقت سے پکڑ لو اور اپنی قوم کو حکم کرو کہ ان کے اچھے اچھے احکام پر عمل کریں، اب بہت جلد تم لوگوں کو ان بے حکموں کا مقام دکھلاتا ہوں\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mc{میں ایسے لوگوں کو اپنے احکام سے برگشتہ ہی رکھوں گا جو دنیا میں تکبر کرتے ہیں، جس کا ان کو کوئی حق حاصل نہیں اور اگر تمام نشانیاں دیکھ لیں تب بھی وه ان پر ایمان نہ ﻻئیں، اور اگر ہدایت کا راستہ دیکھیں تو اس کو اپنا طریقہ نہ بنائیں اور اگر گمراہی کا راستہ دیکھ لیں تو اس کو اپنا طریقہ بنالیں۔ یہ اس سبب سے ہے کہ انہوں نے ہماری آیتوں کو جھٹلایا اور ان سے غافل رہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mci{اور یہ لوگ جنہوں نے ہماری آیتوں کو اور قیامت کے پیش آنے کو جھٹلایا ان کے سب کام غارت گئے۔ ان کو وہی سزا دی جائے گی جو کچھ یہ کرتے تھے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mcii{اور موسیٰ (علیہ السلام) کی قوم نے ان کے بعد اپنے زیوروں کا ایک بچھڑا معبود ٹھہرا لیا جو کہ ایک قالب تھا جس میں ایک آواز تھی۔ کیا انہوں نے یہ نہ دیکھا کہ وه ان سے بات نہیں کرتا تھا اور نہ ان کو کوئی راه بتلاتا تھا اس کو انہوں نے معبود قرار دیا اور بڑی بے انصافی کا کام کیا\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mciii{اور جب نادم ہوئے اور معلوم ہوا کہ واقعی وه لوگ گمراہی میں پڑ گئے تو کہنے لگے کہ اگر ہمارا رب ہم پر رحم نہ کرے اور ہمارا گناه معاف نہ کرے تو ہم بالکل گئے گزرے ہو جائیں گے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mciv{اور جب موسیٰ (علیہ السلام) اپنی قوم کی طرف واپس آئے غصہ اور رنج میں بھرے ہوئے تو فرمایا کہ تم نے میرے بعد یہ بڑی بری جانشینی کی؟ کیا اپنے رب کے حکم سے پہلے ہی تم نے جلد بازی کرلی، اور جلدی سے تختیاں ایک طرف رکھیں اور اپنے بھائی کا سر پکڑ کر ان کو اپنی طرف گھسیٹنے لگے۔ ہارون (علیہ السلام) نے کہا کہ اے میرے ماں جائے! ان لوگوں نے مجھ کو بےحقیقت سمجھا اور قریب تھا کہ مجھ کو قتل کر ڈالیں تو تم مجھ پر دشمنوں کو مت ہنساؤ اور مجھ کو ان ﻇالموں کے ذیل میں مت شمار کرو\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mcv{موسیٰ (علیہ السلام) نے کہا کہ اے میرے رب! میری خطا معاف فرما اور میرے بھائی کی بھی اور ہم دونوں کو اپنی رحمت میں داخل فرما اور تو سب رحم کرنے والوں سے زیاده رحم کرنے واﻻ ہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mcvi{بےشک جن لوگوں نے گوسالہ پرستی کی ہے ان پر بہت جلد ان کے رب کی طرف سے غضب اور ذلت اس دنیوی زندگی ہی میں پڑے گی اور ہم افترا پردازوں کو ایسی ہی سزا دیا کرتے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mcvii{اور جن لوگوں نے گناه کے کام کئے پھر وه ان کے بعد توبہ کر لیں اور ایمان لے آئیں تو تمہارا رب اس توبہ کے بعد گناه معاف کر دینے واﻻ، رحمت کرنے واﻻ ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mcviii{اور جب موسیٰ (علیہ السلام) کا غصہ فرد ہوا تو ان تختیوں کو اٹھا لیا اور ان کے مضامین میں ان لوگوں کے لیے جو اپنے رب سے ڈرتے تھے ہدایت اور رحمت تھی\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mcix{اور موسیٰ (علیہ السلام) نے ستر آدمی اپنی قوم میں سے ہمارے وقت معین کے لیے منتخب کئے، سو جب ان کو زلزلہ نے آپکڑا تو موسیٰ (علیہ السلام) عرض کرنے لگے کہ اے میرے پروردگار! اگر تجھ کو یہ منظور ہوتا تو اس سے قبل ہی ان کو اور مجھ کو ہلاک کر دیتا۔ کیا تو ہم میں سے چند بے وقوفوں کی حرکت پر سب کو ہلاک کردے گا؟ یہ واقعہ محض تیری طرف سے ایک امتحان ہے، ایسے امتحانات سے جس کو تو چاہے گمراہی میں ڈال دے اور جس کو چاہے ہدایت پر قائم رکھے۔ تو ہی تو ہمارا کارساز ہے پس ہم پر مغفرت اور رحمت فرما اور تو سب معافی دینے والوں سے زیاده اچھا ہے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mcx{اور ہم لوگوں کے نام دنیا میں بھی نیک حالی لکھ دے اور آخرت میں بھی، ہم تیری طرف رجوع کرتے ہیں۔ اللہ تعالیٰ نے فرمایا کہ میں اپنا عذاب اسی پر واقع کرتا ہوں جس پر چاہتا ہوں اور میری رحمت تمام اشیا پر محیط ہے۔ تو وه رحمت ان لوگوں کے نام ضرور لکھوں گا جو اللہ سے ڈرتے ہیں اور زکوٰة دیتے ہیں اور جو ہماری آیتوں پر ایمان ﻻتے ہیں\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mcxi{جو لوگ ایسے رسول نبی امی کا اتباع کرتے ہیں جن کو وه لوگ اپنے پاس تورات وانجیل میں لکھا ہوا پاتے ہیں۔ وه ان کو نیک باتوں کا حکم فرماتے ہیں اور بری باتوں سے منع کرتے ہیں اور پاکیزه چیزوں کو حلال بتاتے ہیں اور گندی چیزوں کو ان پر حرام فرماتے ہیں اور ان لوگوں پر جو بوجھ اور طوق تھے ان کو دور کرتے ہیں۔ سو جو لوگ اس نبی پر ایمان ﻻتے ہیں اور ان کی حمایت کرتے ہیں اور ان کی مدد کرتے ہیں اور اس نور کا اتباع کرتے ہیں جو ان کے ساتھ بھیجا گیا ہے، ایسے لوگ پوری فلاح پانے والے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mcxii{آپ کہہ دیجئے کہ اے لوگو! میں تم سب کی طرف اس اللہ تعالیٰ کا بھیجا ہوا ہوں، جس کی بادشاہی تمام آسمانوں اور زمین میں ہے اس کے سوا کوئی عبادت کے ﻻئق نہیں وہی زندگی دیتا ہے اور وہی موت دیتا ہے سو اللہ تعالیٰ پر ایمان لاؤ اور اس کے نبی امی پر جو کہ اللہ تعالیٰ پر اور اس کے احکام پر ایمان رکھتے ہیں اور ان کا اتباع کرو تاکہ تم راه پر آجاؤ\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mcxiii{اور قوم موسیٰ میں ایک جماعت ایسی بھی ہے جو حق کے مطابق ہدایت کرتی ہے اور اسی کے مطابق انصاف بھی کرتی ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mcxiv{اور ہم نے ان کو باره خاندانوں میں تقسیم کرکے سب کی الگ الگ جماعت مقرر کر دی اور ہم نے موسیٰ (علیہ السلام) کو حکم دیا جب کہ ان کی قوم نے ان سے پانی مانگا کہ اپنے عصا کو فلاں پتھر پر مارو پس فوراً اس سے باره چشمے پھوٹ نکلے۔ ہر ہر شخص نے اپنے پانی پینے کا موقع معلوم کر لیا۔ اور ہم نے ان پر ابر کو سایہ فگن کیا اور ان کو من وسلوی (ترنجبین اور بٹیریں) پہنچائیں، کھاؤ نفیس چیزوں سے جو کہ ہم نے تم کو دی ہیں اور انہوں نے ہمارا کوئی نقصان نہیں کیا لیکن اپنا ہی نقصان کرتے تھے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mcxv{اور جب ان کو حکم دیا گیا کہ تم لوگ اس آبادی میں جاکر رہو اور کھاؤ اس سے جس جگہ تم رغبت کرو اور زبان سے یہ کہتے جانا کہ توبہ ہے اور جھکے جھکے دروازه میں داخل ہونا ہم تمہاری خطائیں معاف کردیں گے۔ جو لوگ نیک کام کریں گے ان کو مزید برآں اور دیں گے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mcxvi{سو بدل ڈاﻻ ان ﻇالموں نے ایک اور کلمہ جو خلاف تھا اس کلمہ کے جس کی ان سے فرمائش کی گئی تھی، اس پر ہم نے ان پر ایک آفت سماوی بھیجی اس وجہ سے کہ وه حکم کو ضائع کرتے تھے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mcxvii{اور آپ ان لوگوں سے، اس بستی والوں کا جو کہ دریائے (شور) کے قریب آباد تھے اس وقت کا حال پوچھئے! جب کہ وه ہفتہ کے بارے میں حد سے نکل رہے تھے جب کہ ان کے ہفتہ کے روز تو ان کی مچھلیاں ﻇاہر ہو ہو کر ان کے سامنے آتی تھیں، اور جب ہفتہ کا دن نہ ہوتا تو ان کے سامنے نہ آتی تھیں، ہم ان کی اس طرح پر آزمائش کرتے تھے اس سبب سے کہ وه بےحکمی کیا کرتے تھے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mcxviii{اور جب کہ ان میں سے ایک جماعت نے یوں کہا کہ تم ایسے لوگوں کو کیوں نصیحت کرتے ہو جن کو اللہ بالکل ہلاک کرنے واﻻ ہے یا ان کو سخت سزا دینے واﻻ ہے؟ انہو ں نے جواب دیا کہ تمہارے رب کے روبرو عذر کرنے کے لیے اور اس لیے کہ شاید یہ ڈر جائیں\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mcxix{سو جب وه اس کو بھول گئے جو ان کو سمجھایا جاتا تھا تو ہم نے ان لوگوں کو تو بچا لیا جو اس بری عادت سے منع کیا کرتے تھے اور ان لوگوں کو جو کہ زیادتی کرتے تھے ایک سخت عذاب میں پکڑ لیا اس وجہ سے کہ وه بےحکمی کیا کرتے تھے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mcxx{یعنی جب وه، جس کام سے ان کو منع کیا گیا تھا اس میں حد سے نکل گئے تو ہم نے ان کو کہہ دیا تم ذلیل بندر بن جاؤ\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mcxxi{اور وه وقت یاد کرنا چاہیئے کہ آپ کے رب نے یہ بات بتلا دی کہ وه ان یہود پر قیامت تک ایسے شخص کو ضرور مسلط کرتا رہے گا جو ان کو سزائے شدید کی تکلیف پہنچاتا رہے گا، بلاشبہ آپ کا رب جلدی ہی سزا دے دیتا ہے اور بلاشبہ وه واقعی بڑی مغفرت اور بڑی رحمت واﻻ ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mcxxii{اور ہم نے دنیا میں ان کی مختلف جماعتیں کر دیں۔ بعض ان میں نیک تھے اور بعض ان میں اور طرح تھے اور ہم ان کو خوش حالیوں اور بدحالیوں سے آزماتے رہے کہ شاید باز آجائیں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mcxxiii{پھر ان کے بعد ایسے لوگ ان کے جانشین ہوئے کہ کتاب کو ان سے حاصل کیا وه اس دنیائے فانی کا مال متاع لے لیتے ہیں اور کہتے ہیں کہ ہماری ضرور مغفرت ہو جائے گی حاﻻنکہ اگر ان کے پاس ویسا ہی مال متاع آنے لگے تو اس کو بھی لے لیں گے۔ کیا ان سے اس کتاب کے اس مضمون کا عہد نہیں لیا گیا کہ اللہ کی طرف بجز حق بات کے اور کسی بات کی نسبت نہ کریں، اور انہوں نے اس کتاب میں جو کچھ تھا اس کو پڑھ لیا اور آخرت واﻻ گھر ان لوگوں کے لیے بہتر ہے جو تقویٰ رکھتے ہیں، پھر کیا تم نہیں سمجھتے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mcxxiv{اور جو لوگ کتاب کے پابند ہیں اور نماز کی پابندی کرتے ہیں، ہم ایسے لوگوں کا جو اپنی اصلاح کریں ﺛواب ضائع نہ کریں گے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mcxxv{اور وه وقت بھی قابل ذکر ہے جب ہم نے پہاڑ کو اٹھا کر سائبان کی طرح ان کے اوپر معلق کر دیا اور ان کو یقین ہوگیا کہ اب ان پر گرا اور کہا کہ جو کتاب ہم نے تم کو دی ہے اسے مضبوطی کے ساتھ قبول کرو اور یاد رکھو جو احکام اس میں ہیں اس سے توقع ہے کہ تم متقی بن جاؤ\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mcxxvi{اور جب آپ کے رب نے اوﻻد آدم کی پشت سے ان کی اوﻻد کو نکالا اور ان سے ان ہی کے متعلق اقرار لیا کہ کیا میں تمہارا رب نہیں ہوں؟ سب نے جواب دیا کیوں نہیں! ہم سب گواه بنتے ہیں۔ تاکہ تم لوگ قیامت کے روز یوں نہ کہو کہ ہم تو اس سے محض بے خبر تھے\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mcxxvii{یا یوں کہو کہ پہلے پہلے شرک تو ہمارے بڑوں نے کیا اور ہم ان کے بعد ان کی نسل میں ہوئے، سو کیا ان غلط راه والوں کے فعل پر تو ہم کو ہلاکت میں ڈال دے گا؟\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mcxxviii{ہم اسی طرح آیات کو صاف صاف بیان کرتے ہیں اور تاکہ وه باز آجائیں\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mcxxix{اور ان لوگوں کو اس شخص کا حال پڑھ کر سنائیے کہ جس کو ہم نے اپنی آیتیں دیں پھر وه ان سے بالکل ہی نکل گیا، پھر شیطان اس کے پیچھے لگ گیا سو وه گمراه لوگوں میں شامل ہوگیا\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mcxxx{اور اگر ہم چاہتے تو اس کو ان آیتوں کی بدولت بلند مرتبہ کر دیتے لیکن وه تو دنیا کی طرف مائل ہوگیا اور اپنی نفسانی خواہش کی پیروی کرنے لگا سو اس کی حالت کتے کی سی ہوگئی کہ اگر تو اس پر حملہ کرے تب بھی ہانپے یا اس کو چھوڑ دے تب بھی ہانپے، یہی حالت ان لوگوں کی ہے جنہوں نے ہماری آیتوں کو جھٹلایا۔ سو آپ اس حال کو بیان کر دیجئے شاید وه لوگ کچھ سوچیں\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mcxxxi{ان لوگوں کی حالت بھی بری حالت ہے جو ہماری آیات کو جھٹلاتے ہیں اور وه اپنا نقصان کرتے ہیں\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mcxxxii{جس کو اللہ ہدایت کرتا ہے سو ہدایت پانے واﻻ وہی ہوتا ہے اور جس کو وه گمراه کر دے سو ایسے ہی لوگ خسارے میں پڑنے والے ہیں\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mcxxxiii{اور ہم نے ایسے بہت سے جن اور انسان دوزخ کے لیے پیدا کئے ہیں، جن کے دل ایسے ہیں جن سے نہیں سمجھتے اور جن کی آنکھیں ایسی ہیں جن سے نہیں دیکھتے اور جن کے کان ایسے ہیں جن سے نہیں سنتے۔ یہ لوگ چوپایوں کی طرح ہیں بلکہ یہ ان سے بھی زیاده گمراه ہیں۔ یہی لوگ غافل ہیں\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mcxxxiv{اور اچھے اچھے نام اللہ ہی کے لیے ہیں سو ان ناموں سے اللہ ہی کو موسوم کیا کرو اور ایسے لوگوں سے تعلق بھی نہ رکھو جو اس کے ناموں میں کج روی کرتے ہیں، ان لوگوں کو ان کے کئے کی ضرور سزا ملے گی\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mcxxxv{اور ہماری مخلوق میں ایک جماعت ایسی بھی ہے جو حق کے موافق ہدایت کرتی ہے اور اس کے موافق انصاف بھی کرتی ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mcxxxvi{اور جو لوگ ہماری آیات کو جھٹلاتے ہیں ہم ان کو بتدریج (گرفت میں) لئے جارہے ہیں اس طور پر کہ ان کو خبر بھی نہیں\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mcxxxvii{اور ان کو مہلت دیتا ہوں بےشک میری تدبیر بڑی مضبوط ہے\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mcxxxviii{کیا ان لوگوں نے اس بات پر غور نہ کیا کہ ان کے ساتھی کو ذرا بھی جنون نہیں وه تو صرف ایک صاف صاف ڈرانے والے ہیں\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mcxxxix{اور کیا ان لوگوں نے غور نہیں کیا آسمانوں اور زمین کے عالم میں اور دوسری چیزوں میں جو اللہ نے پیدا کی ہیں اور اس بات میں کہ ممکن ہے کہ ان کی اجل قریب ہی آ پہنچی ہو۔ پھر قرآن کے بعد کون سی بات پر یہ لوگ ایمان ﻻئیں گے؟\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mcxl{جس کو اللہ تعالیٰ گمراه کر دے اس کو کوئی راه پر نہیں ﻻ سکتا۔ اور اللہ تعالیٰ ان کو ان کی گمراہی میں بھٹکتے ہوئے چھوڑ دیتا ہے\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mcxli{یہ لوگ آپ سے قیامت کے متعلق سوال کرتے ہیں کہ اس کا وقوع کب ہوگا؟ آپ فرما دیجئے کہ اس کا علم صرف میرے رب ہی کے پاس ہے، اس کے وقت پر اس کو سوا اللہ کے کوئی اور ﻇاہر نہ کرے گا۔ وه آسمانوں اور زمین میں بڑا بھاری (حادﺛہ) ہوگا وه تم پر محض اچانک آپڑے گی۔ وه آپ سے اس طرح پوچھتے ہیں جیسے گویا آپ اس کی تحقیقات کرچکے ہیں۔ آپ فرما دیجئے کہ اس کا علم خاص اللہ ہی کے پاس ہے لیکن اکثر لوگ نہیں جانتے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mcxlii{آپ فرما دیجئے کہ میں خود اپنی ذات خاص کے لیے کسی نفع کا اختیار نہیں رکھتا اور نہ کسی ضرر کا، مگر اتنا ہی کہ جتنا اللہ نے چاہا ہو اور اگر میں غیب کی باتیں جانتا ہوتا تو میں بہت سے منافع حاصل کر لیتا اور کوئی نقصان مجھ کو نہ پہنچتا میں تو محض ڈرانے واﻻ اور بشارت دینے واﻻ ہوں ان لوگوں کو جو ایمان رکھتے ہیں\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mcxliii{وه اللہ تعالیٰ ایسا ہے جس نے تم کو ایک تن واحد سے پیدا کیا اور اسی سے اس کا جوڑا بنایا تاکہ وه اس اپنے جوڑے سے انس حاصل کرے پھر جب میاں نے بیوی سے قربت کی تو اس کو حمل ره گیا ہلکا سا۔ سو وه اس کو لئے ہوئے چلتی پھرتی رہی، پھر جب وه بوجھل ہوگئی تو دونوں میاں بیوی اللہ سے جو ان کا مالک ہے دعا کرنے لگے کہ اگر تو نے ہم کو صحیح سالم اوﻻد دے دی تو ہم خوب شکر گزاری کریں گے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mcxliv{سو جب اللہ نے دونوں کو صحیح سالم اوﻻد دے دی تو اللہ کی دی ہوئی چیز میں وه دونوں اللہ کے شریک قرار دینے لگے، سو اللہ پاک ہے ان کے شرک سے\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mcxlv{کیا ایسوں کو شریک ٹھہراتے ہیں جو کسی چیز کو پیدا نہ کر سکیں اور وه خود ہی پیدا کئے گئے ہوں\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mcxlvi{اور وه ان کو کسی قسم کی مدد نہیں دے سکتے اور وه خود بھی مدد نہیں کرسکتے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mcxlvii{اور اگر تم ان کو کوئی بات بتلانے کو پکارو تو تمہارے کہنے پر نہ چلیں تمہارے اعتبار سے دونوں امر برابر ہیں خواه تم ان کو پکارو یا تم خاموش رہو\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mcxlviii{واقعی تم اللہ کو چھوڑ کر جن کی عبادت کرتے ہو وه بھی تم ہی جیسے بندے ہیں سو تم ان کو پکارو پھر ان کو چاہئے کہ تمہارا کہنا کر دیں اگر تم سچے ہو\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mcxlix{کیا ان کے پاؤں ہیں جن سے وه چلتے ہوں یا ان کے ہاتھ ہیں جن سے وه کسی چیز کو تھام سکیں، یا ان کی آنکھیں ہیں جن سے وه دیکھتے ہوں، یا ان کے کان ہیں جن سے وه سنتے ہیں آپ کہہ دیجئے! تم اپنے سب شرکا کو بلا لو، پھر میری ضرر رسانی کی تدبیر کرو پھر مجھ کو ذرا مہلت مت دو\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mcl{یقیناً میرا مددگار اللہ تعالیٰ ہے جس نے یہ کتاب نازل فرمائی اور وه نیک بندوں کی مدد کرتا ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mcli{اور تم جن لوگوں کی اللہ کو چھوڑ کر عبادت کرتے ہو وه تمہاری کچھ مدد نہیں کرسکتے اور نہ وه اپنی مدد کرسکتے ہیں\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mclii{اور ان کو اگر کوئی بات بتلانے کو پکارو تو اس کو نہ سنیں اور ان کو آپ دیکھتے ہیں کہ گویا وه آپ کو دیکھ رہے ہیں اور وه کچھ بھی نہیں دیکھتے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mcliii{آپ درگزر کو اختیار کریں نیک کام کی تعلیم دیں اور جاہلوں سے ایک کناره ہو جائیں\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mcliv{اور اگر آپ کو کوئی وسوسہ شیطان کی طرف سے آنے لگے تو اللہ کی پناه مانگ لیا کیجئے بلاشبہ وه خوب سننے واﻻ خوب جاننے واﻻ ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mclv{یقیناً جو لوگ خدا ترس ہیں جب ان کو کوئی خطره شیطان کی طرف سے آجاتا ہے تو وه یاد میں لگ جاتے ہیں، سو یکایک ان کی آنکھیں کھل جاتی ہیں\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mclvi{اور جو شیاطین کے تابع ہیں وه ان کو گمراہی میں کھینچے لے جاتے ہیں پس وه باز نہیں آتے\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mclvii{اور جب آپ کوئی معجزه ان کے سامنے ﻇاہر نہیں کرتے تو وه لوگ کہتے ہیں کہ آپ یہ معجزه کیوں نہ ﻻئے؟ آپ فرما دیجئے! کہ میں اس کا اتباع کرتا ہوں جو مجھ پر میرے رب کی طرف سے حکم بھیجا گیا ہے یہ گویا بہت سی دلیلیں ہیں تمہارے رب کی طرف سے اور ہدایت اور رحمت ہے ان لوگوں کے لئے جو ایمان رکھتے ہیں\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mclviii{اور جب قرآن پڑھا جایا کرے تو اس کی طرف کان لگا دیا کرو اور خاموش رہا کرو امید ہے کہ تم پر رحمت ہو\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mclix{اور اے شخص! اپنے رب کی یاد کیا کر اپنے دل میں عاجزی کے ساتھ اور خوف کے ساتھ اور زور کی آواز کی نسبت کم آواز کے ساتھ صبح اور شام اور اہل غفلت میں سے مت ہونا\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mclx{یقیناً جو تیرے رب کے نزدیک ہیں وه اس کی عبادت سے تکبر نہیں کرتے اور اس کی پاکی بیان کرتے ہیں اور اس کو سجده کرتے ہیں\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mclxi{\basmalahur یہ لوگ آپ سے غنیمتو ں کا حکم دریافت کرتے ہیں، آپ فرما دیجئے! کہ یہ غنیمتیں اللہ کی ہیں اور رسول کی ہیں، سو تم اللہ سے ڈرو اور اپنے باہمی تعلقات کی اصلاح کرو اور اللہ تعالیٰ اور اس کے رسول کی اطاعت کرو اگر تم ایمان والے ہو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mclxii{بس ایمان والے تو ایسے ہوتے ہیں کہ جب اللہ تعالیٰ کا ذکر آتا ہے تو ان کے قلوب ڈر جاتے ہیں اور جب اللہ کی آیتیں ان کو پڑھ کر سنائی جاتیں ہیں تو وه آیتیں ان کے ایمان کو اور زیاده کردیتی ہیں اور وه لوگ اپنے رب پر توکل کرتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mclxiii{جو کہ نماز کی پابندی کرتے ہیں اور ہم نے ان کو جو کچھ دیا ہے وه اس میں سے خرچ کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mclxiv{سچے ایمان والے یہ لوگ ہیں ان کے لیے بڑے درجے ہیں ان کے رب کے پاس اور مغفرت اور عزت کی روزی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mclxv{جیسا کہ آپ کے رب نے آپ کے گھر سے حق کے ساتھ آپ کو روانہ کیا اور مسلمانوں کی ایک جماعت اس کو گراں سمجھتی تھی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mclxvi{وه اس حق کے بارے میں، اس کے بعد کہ اس کا ﻇہور ہوگیا تھا آپ سے اس طرح جھگڑ رہے تھے کہ گویا کوئی ان کو موت کی طرف ہانکے لیے جاتا ہے اور وه دیکھ رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mclxvii{اور تم لوگ اس وقت کو یاد کرو! جب کہ اللہ تم سے ان دو جماعتوں میں سے ایک کا وعده کرتا تھا کہ وه تمہارے ہاتھ آجائے گی اور تم اس تمنا میں تھے کہ غیر مسلح جماعت تمہارے ہاتھ آجائے اور اللہ تعالیٰ کو یہ منظور تھا کہ اپنے احکام سے حق کا حق ہونا ﺛابت کردے اور ان کافروں کی جڑ کاٹ دے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mclxviii{تاکہ حق کا حق ہونا اور باطل کا باطل ہونا ﺛابت کردے گو یہ مجرم لوگ ناپسند ہی کریں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mclxix{اس وقت کو یاد کرو جب کہ تم اپنے رب سے فریاد کررہے تھے، پھر اللہ تعالیٰ نے تمہاری سن لی کہ میں تم کو ایک ہزار فرشتوں سے مدد دوں گا جو لگاتار چلے آئیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mclxx{اور اللہ تعالیٰ نے یہ امداد محض اس لیے کی کہ بشارت ہو اور تاکہ تمہارے دلوں کو قرار ہو جائے اور مدد صرف اللہ ہی کی طرف سے ہے جو کہ زبردست حکمت واﻻ ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mclxxi{اس وقت کو یاد کرو جب کہ اللہ تم پر اونگھ طاری کر رہا تھا اپنی طرف سے چین دینے کے لیے اور تم پر آسمان سے پانی برسا رہا تھا کہ اس پانی کے ذریعہ سے تم کو پاک کر دے اور تم سے شیطانی وسوسہ کو دفع کر دے اور تمہارے دلوں کو مضبوط کر دے اور تمہارے پاؤں جما دے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mclxxii{اس وقت کو یاد کرو جب کہ آپ کا رب فرشتوں کو حکم دیتا تھا کہ میں تمہارا ساتھی ہوں سو تم ایمان والوں کی ہمت بڑھاؤ میں ابھی کفار کے قلوب میں رعب ڈالے دیتا ہوں، سو تم گردنوں پر مارو اور ان کے پور پور کو مارو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mclxxiii{یہ اس بات کی سزا ہے کہ انہوں نے اللہ کی اور اس کے رسول کی مخالفت کی۔ اور جو اللہ کی اور اس کے رسول کی مخالفت کرتا ہے سو بےشک اللہ تعالیٰ سخت سزا دینے واﻻ ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mclxxiv{سو یہ سزا چکھو اور جان رکھو کہ کافروں کے لیے جہنم کا عذاب مقرر ہی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mclxxv{اے ایمان والو! جب تم کافروں سے دو بدو مقابل ہو جاؤ تو ان سے پشت مت پھیرنا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mclxxvi{اور جو شخص ان سے اس موقع پر پشت پھیرے گا مگر ہاں جو لڑائی کے لیے پینترا بدلتا ہو یا جو (اپنی) جماعت کی طرف پناه لینے آتا ہو وه مستثنیٰ ہے۔ باقی اور جو ایسا کرے گا وه اللہ کے غضب میں آجائے گا اور اس کا ٹھکانہ دوزخ ہوگا وه بہت ہی بری جگہ ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mclxxvii{سو تم نے انہیں قتل نہیں کیا لیکن اللہ تعالیٰ نے ان کو قتل کیا۔ اور آپ نے خاک کی مٹھی نہیں پھینکی بلکہ اللہ تعالیٰ نے وه پھینکی اور تاکہ مسلمانوں کو اپنی طرف سے ان کی محنت کا خوب عوض دے بلاشبہ اللہ تعالیٰ خوب سننے واﻻ خوب جاننے واﻻ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mclxxviii{(ایک بات تو) یہ ہوئی اور (دوسری بات یہ ہے) اللہ تعالیٰ کو کافروں کی تدبیر کو کمزور کرنا تھا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mclxxix{اگر تم لوگ فیصلہ چاہتے ہو تو وه فیصلہ تمہارے سامنے آموجود ہوا اور اگر باز آجاؤ تو یہ تمہارے لیے نہایت خوب ہے اور اگر تم پھر وہی کام کرو گے تو ہم بھی پھر وہی کام کریں گے اور تمہاری جمعیت تمہارے ذرا بھی کام نہ آئے گی گو کتنی زیاده ہو اور واقعی بات یہ ہے کہ اللہ تعالیٰ ایمان والوں کے ساتھ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mclxxx{اے ایمان والو! اللہ کا اور اس کے رسول کا کہنا مانو اور اس (کا کہنا ماننے) سے روگردانی مت کرو سنتے جانتے ہوئے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mclxxxi{اور تم ان لوگوں کی طرح مت ہونا جو دعویٰ تو کرتے ہیں کہ ہم نے سن لیا حاﻻنکہ وه سنتے (سناتے کچھ) نہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mclxxxii{بےشک بدترین خلائق اللہ تعالیٰ کے نزدیک وه لوگ ہیں جو بہرے ہیں گونگے ہیں جو کہ (ذرا) نہیں سمجھتے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mclxxxiii{اور اگر اللہ تعالیٰ ان میں کوئی خوبی دیکھتا تو ان کو سننے کی توفیق دے دیتا اور اگر ان کو اب سنا دے تو ضرور روگردانی کریں گے بے رخی کرتے ہوئے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mclxxxiv{اے ایمان والو! تم اللہ اور رسول کے کہنے کو بجا لاؤ، جب کہ رسول تم کو تمہاری زندگی بخش چیز کی طرف بلاتے ہوں اور جان رکھو کہ اللہ تعالیٰ آدمی کے اور اس کے قلب کے درمیان آڑ بن جایا کرتا ہے اور بلاشبہ تم سب کو اللہ ہی کے پاس جمع ہونا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mclxxxv{اور تم ایسے وبال سے بچو! کہ جو خاص کر صرف ان ہی لوگوں پر واقع نہ ہو گا جو تم میں سے ان گناہوں کے مرتکب ہوئے ہیں اور یہ جان رکھو کہ اللہ سخت سزا دینے واﻻ ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mclxxxvi{اور اس حالت کو یاد کرو! جب کہ تم زمین میں قلیل تھے، کمزور شمار کئے جاتے تھے۔ اس اندیشہ میں رہتے تھے کہ تم کو لوگ نوچ کھسوٹ نہ لیں، سو اللہ نے تم کو رہنے کی جگہ دی اور تم کو اپنی نصرت سے قوت دی اور تم کو نفیس نفیس چیزیں عطا فرمائیں تاکہ تم شکر کرو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mclxxxvii{اے ایمان والو! تم اللہ اور رسول (کے حقوق) میں جانتے ہوئے خیانت مت کرو اور اپنی قابل حفاﻇت چیزوں میں خیانت مت کرو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mclxxxviii{اور تم اس بات کو جان رکھو کہ تمہارے اموال اور تمہاری اوﻻد ایک امتحان کی چیز ہے۔ اور اس بات کو بھی جان رکھو کہ اللہ تعالیٰ کے پاس بڑا بھاری اجر ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mclxxxix{اے ایمان والو! اگر تم اللہ سے ڈرتے رہو گے تو اللہ تعالیٰ تم کو ایک فیصلہ کی چیز دے گا اور تم سے تمہارے گناه دور کر دے گا اور تم کو بخش دے گا اور اللہ تعالیٰ بڑے فضل واﻻ ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcxc{اور اس واقعہ کا بھی ذکر کیجئے! جب کہ کافر لوگ آپ کی نسبت تدبیر سوچ رہے تھے کہ آپ کو قید کر لیں، یا آپ کو قتل کر ڈالیں یا آپ کو خارج وطن کر دیں اور وه تو اپنی تدبیریں کر رہے تھے اور اللہ اپنی تدبیر کر رہا تھا اور سب سے زیاده مستحکم تدبیر واﻻ اللہ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcxci{اور جب ان کے سامنے ہماری آیتیں پڑھی جاتی ہیں تو کہتے ہیں کہ ہم نے سن لیا، اگر ہم چاہیں تو اس کے برابر ہم بھی کہہ دیں، یہ تو کچھ بھی نہیں صرف بے سند باتیں ہیں جو پہلوں سے منقول چلی آرہی ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcxcii{اور جب کہ ان لوگوں نے کہا کہ اے اللہ! اگر یہ قرآن آپ کی طرف سے واقعی ہے تو ہم پر آسمان سے پتھر برسا یا ہم پر کوئی دردناک عذاب واقع کر دے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcxciii{اور اللہ تعالیٰ ایسا نہ کرے گا کہ ان میں آپ کے ہوتے ہوئے ان کو عذاب دے اور اللہ ان کو عذاب نہ دے گا اس حالت میں کہ وه استغفار بھی کرتے ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcxciv{اور ان میں کیا بات ہے کہ ان کو اللہ تعالیٰ سزا نہ دے حاﻻنکہ وه لوگ مسجد حرام سے روکتے ہیں، جب کہ وه لوگ اس مسجد کے متولی نہیں۔ اس کے متولی تو سوا متقیوں کے اور اشخاص نہیں، لیکن ان میں اکثر لوگ علم نہیں رکھتے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcxcv{اور ان کی نماز کعبہ کے پاس صرف یہ تھی سیٹیاں بجانا اور تالیاں بجانا۔ سو اپنے کفر کے سبب اس عذاب کا مزه چکھو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcxcvi{بلاشک یہ کافر لوگ اپنے مالوں کو اس لئے خرچ کر رہے ہیں کہ اللہ کی راه سے روکیں سو یہ لوگ تو اپنے مالوں کو خرچ کرتے ہی رہیں گے، پھر وه مال ان کے حق میں باعﺚ حسرت ہو جائیں گے۔ پھر مغلوب ہو جائیں گے اور کافر لوگوں کو دوزخ کی طرف جمع کیا جائے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcxcvii{تاکہ اللہ تعالیٰ ناپاک کو پاک سے الگ کر دے اور ناپاکوں کو ایک دوسرے سے ملا دے، پس ان سب کو اکھٹا ڈھیر کر دے پھر ان سب کو جہنم میں ڈال دے۔ ایسے لوگ پورے خسارے میں ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcxcviii{آپ ان کافروں سے کہہ دیجئے! کہ اگر یہ لوگ باز آجائیں تو ان کے سارے گناہ جو پہلے ہو چکے ہیں سب معاف کر دیئے جائیں گے اور اگر اپنی وہی عادت رکھیں گے تو (کفار) سابقین کے حق میں قانون نافذ ہو چکا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcxcix{اور تم ان سے اس حد تک لڑو کہ ان میں فساد عقیده نہ رہے۔ اور دین اللہ ہی کا ہو جائے پھر اگر یہ باز آجائیں تو اللہ تعالیٰ ان اعمال کو خوب دیکھتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcc{اور اگر روگردانی کریں تو یقین رکھیں کہ اللہ تعالیٰ تمہارا کار ساز ہے وه بہت اچھا کار ساز ہے اور بہت اچھا مدد گار ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcci{جان لو کہ تم جس قسم کی جو کچھ غنیمت حاصل کرو اس میں سے پانچواں حصہ تو اللہ کا ہے اور رسول کا اور قرابت داروں کا اور یتیموں اور مسکینوں کا اور مسافروں کا، اگر تم اللہ پر ایمان ﻻئے ہو اور اس چیز پر جو ہم نے اپنے بندے پر اس دن اتارا ہے، جو دن حق وباطل کی جدائی کا تھا جس دن دو فوجیں بھڑ گئی تھیں۔ اللہ ہر چیز پر قادر ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mccii{جب کہ تم پاس والے کنارے پر تھے اور وه دور والے کنارے پر تھے اور قافلہ تم سے نیچے تھا۔ اگر تم آپس میں وعدے کرتے تو یقیناً تم وقت معین پر پہنچنے میں مختلف ہو جاتے۔ لیکن اللہ کو تو ایک کام کر ہی ڈالنا تھا جو مقرر ہو چکا تھا تاکہ جو ہلاک ہو، دلیل پر (یعنی یقین جان کر) ہلاک ہو اور جو زنده رہے، وه بھی دلیل پر (حق پہچان کر) زنده رہے۔ بیشک اللہ بہت سننے واﻻ خوب جاننے واﻻ ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcciii{جب کہ اللہ تعالیٰ نے تجھے تیرے خواب میں ان کی تعداد کم دکھائی، اگر ان کی زیادتی دکھاتا تو تم بزدل ہو جاتے اور اس کام کے بارے میں آپس میں اختلاف کرتے لیکن اللہ تعالیٰ نے بچا لیا، وه دلوں کے بھیدوں سے خوب آگاه ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcciv{جبکہ اس نے بوقت ملاقات انہیں تمہاری نگاہوں میں بہت کم دکھائے اور تمہیں ان کی نگاہوں میں کم دکھائے تاکہ اللہ تعالیٰ اس کام کو انجام تک پہنچا دے جو کرنا ہی تھا اور سب کام اللہ ہی کی طرف پھیرے جاتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mccv{اے ایمان والو! جب تم کسی مخالف فوج سے بھڑ جاؤ تو ﺛابت قدم رہو اور بکثرت اللہ کو یاد کرو تاکہ تمہیں کامیابی حاصل ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mccvi{اور اللہ کی اور اس کے رسول کی فرماں برداری کرتے رہو، آپس میں اختلاف نہ کرو ورنہ بزدل ہو جاؤ گے اور تمہاری ہوا اکھڑ جائے گی اور صبر و سہارا رکھو، یقیناً اللہ تعالیٰ صبر کرنے والوں کے ساتھ ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mccvii{ان لوگوں جیسے نہ بنو جو اتراتے ہوئے اور لوگوں میں خود نمائی کرتے ہوئے اپنے گھروں سے چلے اور اللہ کی راه سے روکتے تھے، جو کچھ وه کر رہے ہیں اللہ اسے گھیر لینے واﻻ ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mccviii{جبکہ ان کے اعمال کو شیطان انہیں زینت دار دکھا رہا تھا اور کہہ رہا تھا کہ لوگوں میں سے کوئی بھی آج تم پر غالب نہیں آسکتا، میں خود بھی تمہارا حمایتی ہوں لیکن جب دونوں جماعتیں نمودار ہوئیں تو اپنی ایڑیوں کے بل پیچھے ہٹ گیا اور کہنے لگا میں تم سے بری ہوں۔ میں وه دیکھ رہا ہوں جو تم نہیں دیکھ رہے۔ میں اللہ سے ڈرتا ہوں، اور اللہ تعالیٰ سخت عذاب واﻻ ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mccix{جبکہ منافق کہہ رہے تھے اور وه بھی جن کے دلوں میں روگ تھا کہ انہیں تو ان کے دین نے دھوکے میں ڈال دیا ہے جو بھی اللہ پر بھروسہ کرے اللہ تعالیٰ بلا شک وشبہ غلبے واﻻ اور حکمت واﻻ ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mccx{کاش کہ تو دیکھتا جب کہ فرشتے کافروں کی روح قبض کرتے ہیں ان کے منھ پر اور سرینوں پر مار مارتے ہیں (اور کہتے ہیں) تم جلنے کا عذاب چکھو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mccxi{یہ بسبب ان کاموں کے جو تمہارے ہاتھوں نے پہلے ہی بھیج رکھا ہے بیشک اللہ اپنے بندوں پر ﻇلم کرنے واﻻ نہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mccxii{مثل فرعونیوں کے حال کے اور ان سے اگلوں کے، کہ انہوں نے اللہ کی آیتوں سے کفر کیا پس اللہ نے ان کے گناہوں کے باعﺚ انہیں پکڑ لیا۔ اللہ تعالیٰ یقیناً قوت واﻻ اور سخت عذاب واﻻ ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mccxiii{یہ اس لئے کہ اللہ تعالیٰ ایسا نہیں کہ کسی قوم پر کوئی نعمت انعام فرما کر پھر بدل دے جب تک کہ وه خود اپنی اس حالت کو نہ بدل دیں جو کہ ان کی اپنی تھی اور یہ کہ اللہ سننے واﻻ جاننے واﻻ ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mccxiv{مثل حالت فرعونیوں کے اور ان سے پہلے کے لوگوں کے کہ انہوں نے اپنے رب کی باتیں جھٹلائیں۔ پس ان کے گناہوں کے باعﺚ ہم نے انہیں برباد کیا اور فرعونیوں کو ڈبو دیا۔ یہ سارے ﻇالم تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxv{تمام جانداروں سے بدتر، اللہ کے نزدیک وه ہیں جو کفر کریں، پھر وه ایمان نہ ﻻئیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxvi{جن سے آپ نے عہد وپیمان کر لیا پھر بھی وه اپنے عہد وپیمان کو ہر مرتبہ توڑ دیتے ہیں اور بالکل پرہیز نہیں کرتے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxvii{پس جب کبھی تو لڑائی میں ان پر غالب آجائے انہیں ایسی مار مار کہ ان کے پچھلے بھی بھاگ کھڑے ہوں، ہو سکتا ہے کہ وه عبرت حاصل کریں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxviii{اور اگر تجھے کسی قوم کی خیانت کا ڈر ہو تو برابری کی حالت میں ان کا عہدنامہ توڑ دے، اللہ تعالیٰ خیانت کرنے والوں کو پسند نہیں فرماتا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxix{کافر یہ خیال نہ کریں کہ وه بھاگ نکلے۔ یقیناً وه عاجز نہیں کر سکتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxx{تم ان کے مقابلے کے لئے اپنی طاقت بھر قوت کی تیاری کرو اور گھوڑوں کے تیار رکھنے کی کہ اس سے تم اللہ کے دشمنوں کو خوف زده رکھ سکو اور ان کے سوا اوروں کو بھی، جنہیں تم نہیں جانتے، اللہ انہیں خوب جان رہا ہے جو کچھ بھی اللہ کی راه میں صرف کرو گے وه تمہیں پورا پورا دیا جائے گا اور تمہارا حق نہ مارا جائے گا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxxi{اگر وه صلح کی طرف جھکیں تو تو بھی صلح کی طرف جھک جا اور اللہ پر بھروسہ رکھ، یقیناً وه بہت سننے جاننے واﻻ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxxii{اگر وه تجھ سے دغا بازی کرنا چاہیں گے تو اللہ تجھے کافی ہے، اسی نے اپنی مدد سے اور مومنوں سے تیری تائید کی ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxxiii{ان کے دلوں میں باہمی الفت بھی اسی نے ڈالی ہے۔ زمین میں جو کچھ ہے تو اگر سارا کا سارا بھی خرچ کر ڈالتا ہے تو بھی ان کے دل آپس میں نہ ملا سکتا۔ یہ تو اللہ ہی نے ان میں الفت ڈال دی ہے وه غالب حکمتوں واﻻ ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxxiv{اے نبی! تجھے اللہ کافی ہے اور ان مومنوں کو جو تیری پیروی کر رہے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccxxv{اے نبی! ایمان والوں کو جہاد کا شوق دلاؤ اگر تم میں بیس بھی صبر کرنے والے ہوں گے، تو دو سو پر غالب رہیں گے۔ اور اگر تم میں ایک سو ہوں گے تو ایک ہزار کافروں پر غالب رہیں گے اس واسطے کہ وه بے سمجھ لوگ ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccxxvi{اچھا اب اللہ تمہارا بوجھ ہلکا کرتاہے، وه خوب جانتا ہے کہ تم میں ناتوانی ہے، پس اگر تم میں سے ایک سو صبر کرنے والے ہوں گے تو وه دو سو پر غالب رہیں گے اور اگر تم میں سے ایک ہزار ہوں گے تو وه اللہ کے حکم سے دو ہزار پرغالب رہیں گے، اللہ صبر کرنے والوں کے ساتھ ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mccxxvii{نبی کے ہاتھ میں قیدی نہیں چاہییں جب تک کہ ملک میں اچھی خونریزی کی جنگ نہ ہو جائے۔ تم تو دنیا کے مال چاہتے ہو اور اللہ کا اراده آخرت کا ہے اور اللہ زور آور باحکمت ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccxxviii{اگر پہلے ہی سے اللہ کی طرف سے بات لکھی ہوئی نہ ہوتی تو جو کچھ تم نے لیا ہے اس کے بارے میں تمہیں کوئی بڑی سزا ہوتی\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccxxix{پس جو کچھ حلال اور پاکیزه غنیمت تم نے حاصل کی ہے، خوب کھاؤ پیو اور اللہ سے ڈرتے رہو، یقیناً اللہ غفور ورحیم ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mccxxx{اے نبی! اپنے ہاتھ تلے کے قیدیوں سے کہہ دو کہ اگر اللہ تعالیٰ تمہارے دلوں میں نیک نیتی دیکھے گا تو جو کچھ تم سے لیا گیا ہے اس سے بہتر تمہیں دے گا اور پھر گناه بھی معاف فرمائے گا اور اللہ بخشنے واﻻ مہربان ہے ہی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mccxxxi{اور اگر وه تجھ سے خیانت کا خیال کریں گے تو یہ تو اس سے پہلے خود اللہ کی خیانت کر چکے ہیں آخر اس نے انہیں گرفتار کرا دیا، اور اللہ علم وحکمت واﻻ ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mccxxxii{جو لوگ ایمان ﻻئے اور ہجرت کی اور اپنے مالوں اور جانوں سے اللہ کی راه میں جہاد کیا اور جن لوگوں نے ان کو پناه دی اور مدد کی، یہ سب آپس میں ایک دوسرے کے رفیق ہیں، اور جو ایمان تو ﻻئے ہیں لیکن ہجرت نہیں کی تمہارے لئے ان کی کچھ بھی رفاقت نہیں جب تک کہ وه ہجرت نہ کریں۔ ہاں اگر وه تم سے دین کے بارے میں مدد طلب کریں تو تم پر مدد کرنا ضروری ہے، سوائے ان لوگوں کے کہ تم میں اور ان میں عہد وپیمان ہے، تم جو کچھ کر رہے ہو اللہ خوب دیکھتا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mccxxxiii{کافر آپس میں ایک دوسرے کے رفیق ہیں، اگر تم نے ایسا نہ کیا تو ملک میں فتنہ ہوگا اور زبردست فساد ہو جائے گا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mccxxxiv{جو لوگ ایمان ﻻئے اور ہجرت کی اور اللہ کی راه میں جہاد کیا اور جنہوں نے پناه دی اور مدد پہنچائی، یہی لوگ سچے مومن ہیں، ان کے لئے بخشش ہے اور عزت کی روزی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mccxxxv{اور جو لوگ اس کے بعد ایمان ﻻئے اور ہجرت کی اور تمہارے ساتھ ہو کر جہاد کیا۔ پس یہ لوگ بھی تم میں سے ہی ہیں اور رشتے ناتے والے ان میں سے بعض بعض سے زیاده نزدیک ہیں اللہ کے حکم میں، بیشک اللہ تعالیٰ ہر چیز کا جاننے واﻻ ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mccxxxvi{\basmalahur اللہ اوراس کے رسول کی جانب سے بیزاری کا اعلان ہے۔ ان مشرکوں کے بارے میں جن سے تم نے عہد وپیمان کیا تھا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccxxxvii{پس (اے مشرکو!) تم ملک میں چار مہینے تک تو چل پھر لو، جان لو کہ تم اللہ کو عاجز کرنے والے نہیں ہو، اور یہ (بھی یاد رہے) کہ اللہ کافروں کو رسوا کرنے واﻻ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccxxxviii{اللہ اور اس کے رسول کی طرف سے لوگوں کو بڑے حج کے دن صاف اطلاع ہے کہ اللہ مشرکوں سے بیزار ہے، اور اس کا رسول بھی، اگر اب بھی تم توبہ کر لو تو تمہارے حق میں بہتر ہے، اور اگر تم روگردانی کرو تو جان لو کہ تم اللہ کو ہرا نہیں سکتے۔ اور کافروں کو دکھ اور مار کی خبر پہنچا دیجئے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccxxxix{بجز ان مشرکوں کے جن سے تمہارا معاہده ہو چکا ہے اور انہوں نے تمہیں ذرا سا بھی نقصان نہیں پہنچایا نہ کسی کی تمہارے خلاف مدد کی ہے تو تم بھی ان کے معاہدے کی مدت ان کے ساتھ پوری کرو، اللہ تعالیٰ پرہیزگاروں کو دوست رکھتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccxl{پھر حرمت والے مہینوں کے گزرتے ہی مشرکوں کو جہاں پاؤ قتل کرو انہیں گرفتار کرو، ان کا محاصره کرلو اور ان کی تاک میں ہر گھاٹی میں جا بیٹھو، ہاں اگر وه توبہ کرلیں اور نماز کے پابند ہو جائیں اور زکوٰة ادا کرنے لگیں توتم ان کی راہیں چھوڑ دو۔ یقیناً اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccxli{اگر مشرکوں میں سے کوئی تجھ سے پناه طلب کرے تو تو اسے پناه دے دے یہاں تک کہ وه کلام اللہ سن لے پھر اسے اپنی جائے امن تک پہنچا دے۔ یہ اس لئے کہ یہ لوگ بے علم ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccxlii{مشرکوں کے لئے عہد اللہ اور اس کے رسول کے نزدیک کیسے ره سکتا ہے سوائے ان کے جن سے تم نے عہد وپیمان مسجد حرام کے پاس کیا ہے، جب تک وه لوگ تم سے معاہده نبھائیں تم بھی ان سے وفاداری کرو، اللہ تعالیٰ متقیوں سے محبت رکھتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccxliii{ان کے وعدوں کا کیا اعتبار ان کا اگر تم پر غلبہ ہو جائے تو نہ یہ قرابت داری کا خیال کریں نہ عہدوپیمان کا، اپنی زبانوں سے تو تمہیں پرچا رہے ہیں لیکن ان کے دل نہیں مانتے ان میں سے اکثر تو فاسق ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccxliv{انہوں نے اللہ کی آیتوں کو بہت کم قیمت پر بیچ دیا اور اس کی راه سے روکا۔ بہت برا ہے جو یہ کر رہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccxlv{یہ تو کسی مسلمان کے حق میں کسی رشتہداری کا یا عہد کا مطلق لحاظ نہیں کرتے، یہ ہیں ہی حد سے گزرنے والے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccxlvi{اب بھی اگر یہ توبہ کر لیں اور نماز کے پابند ہو جائیں اور زکوٰة دیتے رہیں تو تمہارے دینی بھائی ہیں۔ ہم تو جاننے والوں کے لئے اپنی آیتیں کھول کھول کر بیان کر رہے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccxlvii{اگر یہ لوگ عہدوپیمان کے بعد بھی اپنی قسموں کو توڑ دیں اور تمہارے دین میں طعنہ زنی کریں تو تم بھی ان سرداران کفر سے بھڑ جاؤ۔ ان کی قسمیں کوئی چیز نہیں، ممکن ہے کہ اس طرح وه بھی باز آجائیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccxlviii{تم ان لوگوں کی سرکوبی کے لئے کیوں تیار نہیں ہوتے جنہوں نے اپنی قسموں کو توڑ دیا اور پیغمبر کو جلا وطن کرنے کی فکر میں ہیں اور خود ہی اول بار انہوں نے تم سے چھیڑ کی ہے، کیا تم ان سے ڈرتے ہو؟ اللہ ہی زیاده مستحق ہے کہ تم اس کا ڈر رکھو بشرطیکہ تم ایمان والے ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccxlix{ان سے تم جنگ کرو اللہ تعالیٰ انہیں تمہارے ہاتھوں عذاب دے گا، انہیں ذلیل ورسوا کرے گا، تمہیں ان پر مدد دے گا اور مسلمانوں کے کلیجے ٹھنڈے کرے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccl{اور ان کے دل کا غم وغصہ دور کرے گا، اور وه جس کی طرف چاہتا ہے رحمت سے توجہ فرماتا ہے۔ اللہ جانتا بوجھتا حکمت واﻻ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccli{کیا تم یہ سمجھے بیٹھے ہو کہ تم چھوڑ دیئے جاؤ گے حاﻻنکہ اب تک اللہ نے تم میں سے انہیں ممتاز نہیں کیا جو مجاہد ہیں اور جنہوں نے اللہ کے اور اس کے رسول کے اور مومنوں کے سوا کسی کو دلی دوست نہیں بنایا۔ اللہ خوب خبردار ہے جو تم کر رہے ہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcclii{ﻻئق نہیں کہ مشرک اللہ تعالیٰ کی مسجدوں کو آباد کریں۔ درآں حالیکہ وه خود اپنے کفر کے آپ ہی گواه ہیں، ان کے اعمال غارت واکارت ہیں، اور وه دائمی طور پر جہنمی ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccliii{اللہ کی مسجدوں کی رونق وآبادی تو ان کے حصے میں ہے جو اللہ پر اور قیامت کے دن پر ایمان رکھتے ہوں، نمازوں کے پابند ہوں، زکوٰة دیتے ہوں، اللہ کے سوا کسی سے نہ ڈرتے ہوں، توقع ہے کہ یہی لوگ یقیناً ہدایت یافتہ ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccliv{کیا تم نے حاجیوں کو پانی پلا دینا اور مسجد حرام کی خدمت کرنا اس کے برابر کر دیا ہے جو اللہ پر اور آخرت کے دن پر ایمان ﻻئے اور اللہ کی راه میں جہاد کیا، یہ اللہ کے نزدیک برابر کے نہیں اور اللہ تعالیٰ ﻇالموں کو ہدایت نہیں دیتا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcclv{جو لوگ ایمان ﻻئے، ہجرت کی، اللہ کی راه میں اپنے مال اور اپنی جان سے جہاد کیا وه اللہ کے ہاں بہت بڑے مرتبہ والے ہیں، اور یہی لوگ مراد پانے والے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcclvi{انہیں ان کا رب خوشخبری دیتا ہے اپنی رحمت کی اور رضامندی کی اور جنتوں کی، ان کے لئے وہاں دوامی نعمت ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcclvii{وہاں یہ ہمیشہ رہنے والے ہیں اللہ کے پاس یقیناً بہت بڑے ﺛواب ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcclviii{اے ایمان والو! اپنے باپوں کو اور اپنے بھائیوں کو دوست نہ بناؤ اگر وه کفر کو ایمان سے زیاده عزیز رکھیں۔ تم میں سے جو بھی ان سے محبت رکھے گا وه پورا گنہگار ﻇالم ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcclix{آپ کہہ دیجئے کہ اگر تمہارے باپ اور تمہارے لڑکےاور تمہارے بھائی اور تمہاری بیویاں اور تمہارے کنبے قبیلے اور تمہارے کمائے ہوئے مال اور وه تجارت جس کی کمی سے تم ڈرتے ہو اور وه حویلیاں جنہیں تم پسند کرتے ہو اگر یہ تمہیں اللہ سے اور اس کے رسول سے اور اس کی راه میں جہاد سے بھی زیاده عزیز ہیں، تو تم انتظار کرو کہ اللہ تعالیٰ اپنا عذاب لے آئے۔ اللہ تعالیٰ فاسقوں کو ہدایت نہیں دیتا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcclx{یقیناً اللہ تعالیٰ نے بہت سے میدانوں میں تمہیں فتح دی ہے اور حنین کی لڑائی والے دن بھی جب کہ تمہیں اپنی کثرت پر ناز ہوگیا تھا، لیکن اس نے تمہیں کوئی فائده نہ دیا بلکہ زمین باوجود اپنی کشادگی کے تم پر تنگ ہوگئی پھر تم پیٹھ پھیر کر مڑ گئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcclxi{پھر اللہ نے اپنی طرف کی تسکین اپنے نبی پر اور مومنوں پر اتاری اور اپنے وه لشکر بھیجے جنہیں تم دیکھ نہیں رہے تھے اور کافروں کو پوری سزا دی۔ ان کفار کا یہی بدلہ تھا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcclxii{پھر اس کے بعد بھی جس پر چاہے اللہ تعالیٰ اپنی رحمت کی توجہ فرمائے گا اللہ ہی بخشش ومہربانی کرنے واﻻ ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcclxiii{اے ایمان والو! بے شک مشرک بالکل ہی ناپاک ہیں وه اس سال کے بعد مسجد حرام کے پاس بھی نہ پھٹکنے پائیں اگر تمہیں مفلسی کا خوف ہے تو اللہ تمہیں دولت مند کر دے گا اپنے فضل سے اگر چاہے اللہ علم وحکمت واﻻ ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcclxiv{ان لوگوں سے لڑو، جو اللہ پر اور قیامت کے دن پر ایمان نہیں ﻻتے جو اللہ اور اس کے رسول کی حرام کرده شے کو حرام نہیں جانتے، نہ دین حق کو قبول کرتے ہیں ان لوگوں میں جنہیں کتاب دی گئی ہے، یہاں تک کہ وه ذلیل وخوار ہو کر اپنے ہاتھ سے جزیہ ادا کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcclxv{یہود کہتے ہیں عزیر اللہ کا بیٹا ہے اور نصرانی کہتے ہیں مسیح اللہ کا بیٹا ہے یہ قول صرف ان کے منھ کی بات ہے۔ اگلے منکروں کی بات کی یہ بھی نقل کرنے لگے اللہ انہیں غارت کرے وه کیسے پلٹائے جاتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcclxvi{ان لوگوں نے اللہ کو چھوڑ کر اپنے عالموں اور درویشوں کو رب بنایا ہے اور مریم کے بیٹے مسیح کو حاﻻنکہ انہیں صرف ایک اکیلے اللہ ہی کی عبادت کا حکم دیا گیا تھا جس کے سوا کوئی معبود نہیں وه پاک ہے ان کے شریک مقرر کرنے سے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcclxvii{وه چاہتے ہیں کہ اللہ کے نور کو اپنے منھ سے بجھا دیں اور اللہ تعالیٰ انکاری ہے مگر اسی بات کا کہ اپنا نور پورا کرے گو کافر نا خوش رہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcclxviii{اسی نے اپنے رسول کو ہدایت اور سچے دین کے ساتھ بھیجا ہے کہ اسے اور تمام مذہبوں پر غالب کر دے اگر چہ مشرک برا مانیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcclxix{اے ایمان والو! اکثر علما اور عابد، لوگوں کا مال ناحق کھا جاتے ہیں اور اللہ کی راه سے روک دیتے ہیں اور جو لوگ سونے چاندی کا خزانہ رکھتے ہیں اور اللہ کی راه میں خرچ نہیں کرتے، انہیں دردناک عذاب کی خبر پہنچا دیجئے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcclxx{جس دن اس خزانے کو آتش دوزخ میں تپایا جائے گا پھر اس سے ان کی پیشانیاں اور پہلو اور پیٹھیں داغی جائیں گی (ان سے کہا جائے گا) یہ ہے جسے تم نے اپنے لئے خزانہ بنا کر رکھا تھا۔ پس اپنے خزانوں کا مزه چکھو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcclxxi{مہینوں کی گنتی اللہ کے نزدیک کتاب اللہ میں باره کی ہے، اسی دن سے جب سے آسمان وزمین کو اس نے پیدا کیا ہے اس میں سے چار حرمت وادب کے ہیں۔ یہی درست دین ہے، تم ان مہینوں میں اپنی جانوں پر ﻇلم نہ کرو اور تم تمام مشرکوں سے جہاد کرو جیسے کہ وه تم سب سے لڑتے ہیں اور جان رکھو کہ اللہ تعالی متقیوں کے ساتھ ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcclxxii{مہینوں کا آگے پیچھے کر دینا کفر کی زیادتی ہے اس سے وه لوگ گمراہی میں ڈالے جاتے ہیں جو کافر ہیں۔ ایک سال تو اسے حلال کر لیتے ہیں اور ایک سال اسی کو حرمت واﻻ کر لیتے ہیں، کہ اللہ نے جو حرمت رکھی ہے اس کے شمار میں تو موافقت کر لیں پھر اسے حلال بنا لیں جسے اللہ نے حرام کیا ہے انہیں ان کے برے کام بھلے دکھادیئے گئے ہیں اور قوم کفار کی اللہ رہنمائی نہیں فرماتا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcclxxiii{اے ایمان والو! تمہیں کیا ہو گیا ہے کہ جب تم سے کہا جاتا ہے کہ چلو اللہ کے راستے میں کوچ کرو تو تم زمین سے لگے جاتے ہو۔ کیا تم آخرت کے عوض دنیا کی زندگانی پر ہی ریجھ گئے ہو۔ سنو! دنیا کی زندگی تو آخرت کے مقابلے میں کچھ یونہی سی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcclxxiv{اگر تم نے کوچ نہ کیا تو تمہیں اللہ تعالیٰ دردناک سزا دے گا اور تمہارے سوا اور لوگوں کو بدل ﻻئے گا، تم اللہ تعالی کو کوئی نقصان نہیں پہنچا سکتے اور اللہ ہر چیز پر قادر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcclxxv{اگر تم ان (نبی صلی اللہ علیہ وسلم) کی مدد نہ کرو تو اللہ ہی نے ان کی مدد کی اس وقت جبکہ انہیں کافروں نے (دیس سے) نکال دیا تھا، دو میں سے دوسرا جبکہ وه دونوں غار میں تھے جب یہ اپنے ساتھی سے کہہ رہے تھے کہ غم نہ کر اللہ ہمارے ساتھ ہے، پس جناب باری نے اپنی طرف سے تسکین اس پر نازل فرما کر ان لشکروں سے اس کی مدد کی جنہیں تم نے دیکھا ہی نہیں، اس نے کافروں کی بات پست کر دی اور بلند وعزیز تو اللہ کا کلمہ ہی ہے، اللہ غالب ہے حکمت واﻻ ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcclxxvi{نکل کھڑے ہو جاؤ ہلکے پھلکے ہو تو بھی اور بھاری بھر کم ہو تو بھی، اور راه رب میں اپنی مال وجان سے جہاد کرو، یہی تمہارے لئے بہتر ہے اگر تم میں علم ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcclxxvii{اگر جلد وصول ہونے واﻻ مال واسباب ہوتا اور ہلکا سفر ہوتا تو یہ ضرور آپ کے پیچھے ہو لیتے لیکن ان پر تو دوری اور دراز کی مشکل پڑ گئی۔ اب تو یہ اللہ کی قسمیں کھائیں گے کہ اگر ہم میں قوت وطاقت ہوتی تو ہم یقیناً آپ کے ساتھ نکلتے، یہ اپنی جانوں کو خود ہی ہلاکت میں ڈال رہے ہیں ان کے جھوٹا ہونے کا سچا علم اللہ کو ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcclxxviii{اللہ تجھے معاف فرما دے، تو نے انہیں کیوں اجازت دے دی؟ بغیر اس کے کہ تیرے سامنے سچے لوگ کھل جائیں اور تو جھوٹے لوگوں کو بھی جان لے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcclxxix{اللہ پر اور قیامت کے دن پر ایمان ویقین رکھنے والے تو مالی اور جانی جہاد سے رک رہنے کی کبھی بھی تجھ سے اجازت طلب نہیں کریں گے، اور اللہ تعالیٰ پرہیزگاروں کو خوب جانتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcclxxx{یہ اجازت تو تجھ سے وہی طلب کرتے ہیں جنہیں نہ اللہ پر ایمان ہے نہ آخرت کے دن کا یقین ہے جن کے دل شک میں پڑے ہوئے ہیں اور وه اپنے شک میں ہی سرگرداں ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcclxxxi{اگر ان کا اراده جہاد کے لئے نکلنے کا ہوتا تو وه اس سفر کے لئے سامان کی تیاری کر رکھتے لیکن اللہ کو ان کا اٹھنا پسند ہی نہ تھا اس لئے انہیں حرکت سے ہی روک دیا اور کہہ دیا گیا کہ تم بیٹھنے والوں کے ساتھ بیٹھے ہی رہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcclxxxii{اگر یہ تم میں مل کر نکلتے بھی تو تمہارے لئے سوائے فساد کے اور کوئی چیز نہ بڑھاتے بلکہ تمہارے درمیان خوب گھوڑے دوڑا دیتے اور تم میں فتنے ڈالنے کی تلاش میں رہتے ان کے ماننے والے خود تم میں موجود ہیں، اور اللہ ان ﻇالموں کو خوب جانتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiii{یہ تو اس سے پہلے بھی فتنے کی تلاش کرتے رہے ہیں اور تیرے لئے کاموں کو الٹ پلٹ کرتے رہے ہیں، یہاں تک کہ حق آپہنچا اور اللہ کا حکم غالب آگیا باوجودیکہ وه ناخوشی میں ہی رہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiv{ان میں سے کوئی تو کہتا ہے مجھے اجازت دیجئے مجھے فتنے میں نہ ڈالیئے، آگاه رہو وه تو فتنے میں پڑ چکے ہیں اور یقیناً دوزخ کافروں کو گھیر لینے والی ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcclxxxv{آپ کو اگر کوئی بھلائی مل جائے تو انہیں برا لگتا ہے اور کوئی برائی پہنچ جائے تو یہ کہتے ہیں ہم نے تو اپنا معاملہ پہلے سے ہی درست کر لیا تھا، پھر تو بڑے ہی اتراتے ہوئے لوٹتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvi{آپ کہہ دیجئے کہ ہمیں سوائے اللہ کے ہمارے حق میں لکھے ہوئے کہ کوئی چیز پہنچ ہی نہیں سکتی وه ہمارا کار ساز اور مولیٰ ہے۔ مومنوں کو تو اللہ کی ذات پاک پر ہی بھروسہ کرنا چاہئے۔\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvii{کہہ دیجئے کہ تم ہمارے بارے میں جس چیز کا انتظار کر رہے ہو وه دو بھلائیوں میں سے ایک ہے اور ہم تمہارے حق میں اس کا انتظار کرتے ہیں کہ یا تو اللہ تعالیٰ اپنے پاس سے کوئی سزا تمہیں دے یا ہمارے ہاتھوں سے، پس ایک طرف تم منتظر رہو دوسری جانب تمہارے ساتھ ہم بھی منتظر ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcclxxxviii{کہہ دیجئے کہ تم خوشی یاناخوشی کسی طرح بھی خرچ کرو قبول تو ہرگز نہ کیا جائے گا، یقیناً تم فاسق لوگ ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcclxxxix{کوئی سبب ان کے خرچ کی قبولیت کے نہ ہونے کا اس کے سوا نہیں کہ یہ اللہ اور اس کے رسول کے منکر ہیں اور بڑی کاہلی سے ہی نماز کو آتے ہیں اور برے دل سے ہی خرچ کرتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxc{پس آپ کو ان کے مال واوﻻد تعجب میں نہ ڈال دیں۔ اللہ کی چاہت یہی ہے کہ اس سے انہیں دنیا کی زندگی میں ہی سزا دے اور ان کے کفر ہی کی حالت میں ان کی جانیں نکل جائیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxci{یہ اللہ کی قسم کھا کھا کر کہتے ہیں کہ یہ تمہاری جماعت کے لوگ ہیں، حاﻻنکہ وه دراصل تمہارے نہیں بات صرف اتنی ہے کہ یہ ڈرپوک لوگ ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxcii{اگر یہ کوئی بچاؤ کی جگہ یا کوئی غار یا کوئی بھی سر گھسانے کی جگہ پالیں تو ابھی اس طرح لگام توڑ کر الٹے بھاگ چھوٹیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxciii{ان میں وه بھی ہیں جو خیراتی مال کی تقسیم کے بارے میں آپ پر عیب رکھتے ہیں، اگر انہیں اس میں سے مل جائے تو خوش ہیں اور اگر اس میں سے نہ ملا تو فوراً بگڑ کھڑے ہوئے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxciv{اگر یہ لوگ اللہ اور رسول کے دیئے ہوئے پر خوش رہتے اور کہہ دیتے کہ اللہ ہمیں کافی ہے اللہ ہمیں اپنے فضل سے دے گا اور اس کا رسول بھی، ہم تو اللہ کی ذات سے ہی توقع رکھنے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxcv{صدقے صرف فقیروں کے لئے ہیں اور مسکینوں کے لئے اور ان کے وصول کرنے والوں کے لئے اور ان کے لئے جن کے دل پرچائے جاتے ہوں اور گردن چھڑانے میں اور قرض داروں کے لئے اور اللہ کی راه میں اور راہرو مسافروں کے لئے، فرض ہے اللہ کی طرف سے، اور اللہ علم وحکمت واﻻ ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxcvi{ان میں سے وه بھی ہیں جو پیغمبر کو ایذا دیتے ہیں اور کہتے ہیں کان کا کچا ہے، آپ کہہ دیجئے کہ وه کان تمہارے بھلے کے لئے ہے وه اللہ پر ایمان رکھتا ہے اور مسلمانوں کی بات کا یقین کرتا ہے اور تم میں سے جو اہل ایمان ہیں یہ ان کے لئے رحمت ہے، رسول اللہ ﴿صلی اللہ علیہ وسلم﴾ کو جو لوگ ایذا دیتے ہیں ان کے لئے دکھ کی مار ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxcvii{محض تمہیں خوش کرنے کے لئے تمہارے سامنے اللہ کی قسمیں کھا جاتے ہیں حاﻻنکہ اگر یہ ایمان دار ہوتے تو اللہ اور اس کا رسول رضامند کرنے کے زیاده مستحق تھے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxcviii{کیا یہ نہیں جانتے کہ جو بھی اللہ کی اور اس کے رسول کی مخالفت کرے گااس کے لئے یقیناً دوزخ کی آگ ہے جس میں وه ہمیشہ رہنے واﻻ ہے، یہ زبردست رسوائی ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxcix{منافقوں کو ہر وقت اس بات کا کھٹکا لگارہتا ہے کہ کہیں مسلمانوں پر کوئی سورت نہ اترے جو ان کے دلوں کی باتیں انہیں بتلا دے۔ کہہ دیجئے کہ تم مذاق اڑاتے رہو۔ یقیناً اللہ تعالیٰ اسے ﻇاہر کرنے واﻻ ہے جس سے تم ڈر دبک رہے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccc{اگر آپ ان سے پوچھیں تو صاف کہہ دیں گے کہ ہم تو یونہی آپس میں ہنس بول رہے تھے۔ کہہ دیجئے کہ اللہ، اس کی آیتیں اور اس کا رسول ہی تمہارے ہنسی مذاق کے لئے ره گئے ہیں؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccci{تم بہانے نہ بناؤ یقیناً تم اپنے ایمان کے بعد بے ایمان ہوگئے، اگر ہم تم میں سے کچھ لوگوں سے درگزر بھی کر لیں تو کچھ لوگوں کو ان کے جرم کی سنگین سزا بھی دیں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcccii{تمام منافق مرد وعورت آپس میں ایک ہی ہیں، یہ بری باتوں کا حکم دیتے ہیں اور بھلی باتوں سے روکتے ہیں اور اپنی مٹھی بند رکھتے ہیں، یہ اللہ کو بھول گئے اللہ نے انہیں بھلا دیا۔ بیشک منافق ہی فاسق وبدکردار ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccciii{اللہ تعالیٰ ان منافق مردوں، عورتوں اورکافروں سے جہنم کی آگ کا وعده کر چکا ہے جہاں یہ ہمیشہ رہنے والے ہیں، وہی انہیں کافی ہے ان پر اللہ کی پھٹکار ہے، اور ان ہی کے لئے دائمی عذاب ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccciv{مثل ان لوگوں کے جو تم سے پہلے تھے، تم میں سے وه زیاده قوت والے تھے اور زیاده مال واوﻻد والے تھے پس وه اپنا دینی حصہ برت گئے پھر تم نے بھی اپنا حصہ برت لیا جیسے تم سے پہلے کے لوگ اپنے حصے سے فائده مند ہوئے تھے اور تم نے بھی اسی طرح مذاقانہ بحﺚ کی جیسے کہ انہوں نے کی تھی۔ ان کے اعمال دنیا اور آخرت میں غارت ہوگئے۔ یہی لوگ نقصان پانے والے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcccv{کیا انہیں اپنے سے پہلے لوگوں کی خبریں نہیں پہنچیں، قوم نوح اور عاد اور ﺛمود اور قوم ابراہیم اور اہل مدین اور اہل مؤتفکات (الٹی ہوئی بستیوں کے رہنے والے) کی، ان کے پاس ان کے پیغمبر دلیلیں لے کر پہنچے، اللہ ایسا نہ تھا کہ ان پر ﻇلم کرے بلکہ انہوں نے خود ہی اپنے اوپر ﻇلم کیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcccvi{مومن مرد وعورت آپس میں ایک دوسرے کے (مددگار ومعاون اور) دوست ہیں، وه بھلائیوں کا حکم دیتے ہیں اور برائیوں سے روکتے ہیں، نمازوں کو پابندی سے بجا ﻻتے ہیں زکوٰة ادا کرتے ہیں، اللہ کی اور اس کے رسول کی بات مانتے ہیں، یہی لوگ ہیں جن پر اللہ تعالیٰ بہت جلد رحم فرمائے گا بیشک اللہ غلبے واﻻ حکمت واﻻ ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcccvii{ان ایمان دار مردوں اور عورتوں سے اللہ نے ان جنتوں کا وعده فرمایا ہے جن کے نیچے نہریں لہریں لے رہی ہیں جہاں وه ہمیشہ ہمیشہ رہنے والے ہیں اور ان صاف ستھرے پاکیزه محلات کا جو ان ہمیشگی والی جنتوں میں ہیں، اور اللہ کی رضامندی سب سے بڑی چیز ہے، یہی زبردست کامیابی ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcccviii{اے نبی! کافروں اور منافقوں سے جہاد جاری رکھو، اور ان پر سخت ہو جاؤ ان کی اصلی جگہ دوزخ ہے، جو نہایت بدترین جگہ ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcccix{یہ اللہ کی قسمیں کھا کر کہتے ہیں کہ انہوں نے نہیں کہا، حاﻻنکہ یقیناً کفر کا کلمہ ان کی زبان سے نکل چکا ہے اور یہ اپنے اسلام کے بعد کافر ہوگئے ہیں اور انہوں نے اس کام کا قصد بھی کیا جو پورا نہ کر سکے۔ یہ صرف اسی بات کا انتقام لے رہے ہیں کہ انہیں اللہ نے اپنے فضل سے اور اس کے رسول ﴿صلی اللہ علیہ وسلم﴾ نے دولت مند کردیا، اگر یہ اب بھی توبہ کر لیں تو یہ ان کے حق میں بہتر ہے، اور اگر منھ موڑے رہیں تو اللہ تعالیٰ انہیں دنیا وآخرت میں دردناک عذاب دے گا اور زمین بھر میں ان کا کوئی حمایتی اور مددگار نہ کھڑا ہوگا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcccx{ان میں وه بھی ہیں جنہوں نے اللہ سے عہد کیا تھا کہ اگر وه ہمیں اپنے فضل سے مال دے گا تو ہم ضرور صدقہ وخیرات کریں گے اور پکی طرح نیکو کاروں میں ہو جائیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcccxi{لیکن جب اللہ نے اپنے فضل سے انہیں دیا تو یہ اس میں بخیلی کرنے لگے اور ٹال مٹول کرکے منھ موڑ لیا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcccxii{پس اس کی سزا میں اللہ نے ان کے دلوں میں نفاق ڈال دیا اللہ سے ملنے کے دنوں تک، کیونکہ انہوں نے اللہ سے کئے ہوئے وعدے کا خلاف کیا اور کیوں کہ جھوٹ بولتے رہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcccxiii{کیا وه نہیں جانتے کہ اللہ تعالیٰ کو ان کے دل کا بھید اور ان کی سرگوشی سب معلوم ہے اور اللہ تعالیٰ غیب کی تمام باتوں سے خبردار ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcccxiv{جولوگ ان مسلمانوں پر طعنہ زنی کرتے ہیں جو دل کھول کر خیرات کرتے ہیں اور ان لوگوں پر جنہیں سوائے اپنی محنت مزدوری کے اور کچھ میسر ہی نہیں، پس یہ ان کا مذاق اڑاتے ہیں، اللہ بھی ان سے تمسخر کرتا ہے انہی کے لئے دردناک عذاب ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcccxv{ان کے لئے تو استغفار کر یا نہ کر۔ اگر تو ستر مرتبہ بھی ان کے لئے استغفار کرے تو بھی اللہ انہیں ہرگز نہ بخشے گا یہ اس لئے کہ انہوں نے اللہ سے اور اس کے رسول سے کفر کیا ایسے فاسق لوگوں کو رب کریم ہدایت نہیں دیتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcccxvi{پیچھے ره جانے والے لوگ رسول اللہ ﴿صلی اللہ علیہ وسلم﴾ کے جانے کے بعد اپنے بیٹھے رہنے پر خوش ہیں انہوں نے اللہ کی راه میں اپنے مال اور اپنی جانوں سے جہاد کرنا ناپسند رکھا اور انہوں نے کہہ دیا کہ اس گرمی میں مت نکلو۔ کہہ دیجئے کہ دوزخ کی آگ بہت ہی سخت گرم ہے، کاش کہ وه سمجھتے ہوتے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcccxvii{پس انہیں چاہئے کہ بہت کم ہنسیں اور بہت زیاده روئیں بدلے میں اس کے جو یہ کرتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcccxviii{پس اگر اللہ تعالیٰ آپ کو ان کی کسی جماعت کی طرف لوٹا کر واپس لے آئے پھر یہ آپ سے میدان جنگ میں نکلنے کی اجازت طلب کریں تو آپ کہہ دیجئے کہ تم میرے ساتھ ہرگز چل نہیں سکتے اور نہ میرے ساتھ تم دشمنوں سے لڑائی کر سکتے ہو۔ تم نے پہلی مرتبہ ہی بیٹھ رہنے کو پسند کیا تھا پس تم پیچھے ره جانے والوں میں ہی بیٹھے رہو\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcccxix{ان میں سے کوئی مر جائے تو آپ اس کے جنازے کی ہرگز نماز نہ پڑھیں اور نہ اس کی قبر پر کھڑے ہوں۔ یہ اللہ اور اس کے رسول کے منکر ہیں اور مرتے دم تک بدکار بے اطاعت رہے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcccxx{آپ کو ان کے مال واوﻻد کچھ بھی بھلے نہ لگیں! اللہ کی چاہت یہی ہے کہ انہیں ان چیزوں سے دنیوی سزا دے اور یہ اپنی جانیں نکلنے تک کافر ہی رہیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcccxxi{جب کوئی سورت اتاری جاتی ہے تو اللہ پر ایمان لاؤ اور اس کے رسول کے ساتھ مل کر جہاد کرو تو ان میں سے دولت مندوں کا ایک طبقہ آپ کے پاس آکر یہ کہہ کر رخصت لے لیتاہے کہ ہمیں تو بیٹھے رہنے والوں میں ہی چھوڑ دیجئے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcccxxii{یہ تو خانہ نشین عورتوں کاساتھ دینے پر ریجھ گئے اور ان کے دلوں پر مہر لگا دی گئی اب وه کچھ سمجھ عقل نہیں رکھتے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcccxxiii{لیکن خود رسول اللہ اور اس کے ساتھ کے ایمان والے اپنے مالوں اور جانوں سے جہاد کرتے ہیں، یہی لوگ بھلائیوں والے ہیں اور یہی لوگ کامیابی حاصل کرنے والے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcccxxiv{انہی کے لئے اللہ نے وه جنتیں تیار کی ہیں جن کے نیچے نہریں جاری ہیں جن میں یہ ہمیشہ رہنے والے ہیں۔ یہی بہت بڑی کامیابی ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcccxxv{بادیہ نشینوں میں سے عذر والے لوگ حاضر ہوئے کہ انہیں رخصت دے دی جائے اور وه بیٹھ رہے جنہوں نے اللہ سے اور اس کے رسول سے جھوٹی باتیں بنائی تھیں۔ اب تو ان میں جتنے کفار ہیں انہیں دکھ دینے والی مار پہنچ کر رہے گی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcccxxvi{ضعیفوں پر اور بیماروں پر اور ان پر جن کے پاس خرچ کرنے کو کچھ بھی نہیں کوئی حرج نہیں بشرطیکہ وه اللہ اور اس کے رسول کی خیر خواہی کرتے رہیں۔ ایسے نیک کاروں پر الزام کی کوئی راه نہیں، اللہ تعالیٰ بڑی مغفرت ورحمت واﻻ ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcccxxvii{ہاں ان پر بھی کوئی حرج نہیں جو آپ کے پاس آتے ہیں کہ آپ انہیں سواری مہیا کر دیں تو آپ جواب دیتے ہیں کہ میں تو تمہاری سواری کے لئے کچھ بھی نہیں پاتا، تو وه رنج وغم سے اپنی آنکھوں سے آنسو بہاتے ہوئے لوٹ جاتے ہیں کہ انہیں خرچ کرنے کے لئے کچھ بھی میسر نہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcccxxviii{بیشک انہیں لوگوں پر راه الزام ہے جو باوجود دولتمند ہونے کے آپ سے اجازت طلب کرتے ہیں۔ یہ خانہ نشین عورتوں کا ساتھ دینے پر خوش ہیں اور ان کے دلوں پر مہر خداوندی لگ چکی ہے جس سے وه محض بے علم ہو گئے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcccxxix{یہ لوگ تمہارے سامنے عذر پیش کریں گے جب تم ان کے پاس واپس جاؤ گے۔ آپ کہہ دیجئے کہ یہ عذر پیش مت کرو ہم کبھی تم کو سچا نہ سمجھیں گے، اللہ تعالیٰ ہم کو تمہاری خبر دے چکا ہے اور آئنده بھی اللہ اور اس کا رسول تمہاری کارگزاری دیکھ لیں گے پھر ایسے کے پاس لوٹائے جاؤ گے جو پوشیده اور ﻇاہر سب کا جاننے واﻻ ہے پھر وه تم کو بتادے گا جو کچھ تم کرتے تھے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcccxxx{ہاں وه اب تمہارے سامنے اللہ کی قسمیں کھا جائیں گے جب تم ان کے پاس واپس جاؤ گے تاکہ تم ان کو ان کی حالت پر چھوڑ دو۔ سو تم ان کو ان کی حالت پر چھوڑ دو۔ وه لوگ بالکل گندے ہیں اور ان کا ٹھکانہ دوزخ ہے ان کاموں کے بدلے جنہیں وه کیا کرتے تھے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcccxxxi{یہ اس لیے قسمیں کھائیں گے کہ تم ان سے راضی ہوجاؤ۔ سو اگر تم ان سے راضی بھی ہوجاؤ تو اللہ تعالیٰ تو ایسے فاسق لوگوں سے راضی نہیں ہوتا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcccxxxii{دیہاتی لوگ کفر اور نفاق میں بہت ہی سخت ہیں اور ان کو ایسا ہونا ہی چاہئے کہ ان کو ان احکام کا علم نہ ہو جو اللہ تعالیٰ نے اپنے رسول پر نازل فرمائے ہیں اور اللہ بڑا علم واﻻ بڑی حکمت واﻻ ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiii{اور ان دیہاتیوں میں سے بعض ایسے ہیں کہ جو کچھ خرچ کرتے ہیں اس کو جرمانہ سمجھتے ہیں اور تم مسلمانوں کے واسطے برے وقت کے منتظر رہتے ہیں، برا وقت ان ہی پر پڑنے واﻻ ہے اور اللہ سننے واﻻ جاننے واﻻ ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiv{اور بعض اہل دیہات میں ایسے بھی ہیں جو اللہ تعالیٰ پر اور قیامت کے دن پر ایمان رکھتے ہیں اور جو کچھ خرچ کرتے ہیں اس کو عنداللہ قرب حاصل ہونے کا ذریعہ اور رسول کی دعا کا ذریعہ بناتے ہیں، یاد رکھو کہ ان کا یہ خرچ کرنا بیشک ان کے لیے موجب قربت ہے، ان کو اللہ تعالیٰ ضرور اپنی رحمت میں داخل کرے گا۔ اللہ تعالیٰ بڑی مغفرت واﻻ بڑی رحمت واﻻ ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcccxxxv{اور جو مہاجرین اور انصار سابق اور مقدم ہیں اور جتنے لوگ اخلاص کے ساتھ ان کے پیرو ہیں اللہ ان سب سے راضی ہوا اور وه سب اس سے راضی ہوئے اور اللہ نے ان کے لیے ایسے باغ مہیا کر رکھے ہیں جن کے نیچے نہریں جاری ہوں گی جن میں ہمیشہ رہیں گے یہ بڑی کامیابی ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvi{اور کچھ تمہارے گردوپیش والوں میں اور کچھ مدینے والوں میں ایسے منافق ہیں کہ نفاق پر اڑے ہوئے ہیں، آپ ان کو نہیں جانتے، ان کو ہم جانتے ہیں ہم ان کو دہری سزا دیں گے، پھر وه بڑے بھاری عذاب کی طرف بھیجے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvii{اور کچھ اور لوگ ہیں جو اپنی خطا کے اقراری ہیں جنہوں نے ملے جلے عمل کیے تھے، کچھ بھلے اور کچھ برے۔ اللہ سے امید ہے کہ ان کی توبہ قبول فرمائے۔ بلاشبہ اللہ تعالیٰ بڑی مغفرت واﻻ بڑی رحمت واﻻ ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcccxxxviii{آپ ان کے مالوں میں سے صدقہ لے لیجئے، جس کے ذریعہ سے آپ ان کو پاک صاف کردیں اور ان کے لیے دعا کیجئے، بلاشبہ آپ کی دعا ان کے لیے موجب اطمینان ہے اور اللہ تعالیٰ خوب سنتا ہے خوب جانتا ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcccxxxix{کیا ان کو یہ خبر نہیں کہ اللہ ہی اپنے بندوں کی توبہ قبول کرتا ہے اور وہی صدقات کو قبول فرماتا ہے اور یہ کہ اللہ ہی توبہ قبول کرنے میں اور رحمت کرنے میں کامل ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcccxl{کہہ دیجئے کہ تم عمل کیے جاؤ تمہارے عمل اللہ خود دیکھ لے گا اور اس کا رسول اور ایمان والے (بھی دیکھ لیں گے) اور ضرور تم کو ایسے کے پاس جانا ہے جو تمام چھپی اور کھلی چیزوں کا جاننے واﻻ ہے۔ سو وه تم کو تمہارا سب کیا ہوا بتلا دے گا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcccxli{اور کچھ اور لوگ ہیں جن کا معاملہ اللہ کے حکم آنے تک ملتوی ہے ان کو سزا دے گا یا ان کی توبہ قبول کرلے گا، اور اللہ خوب جاننے واﻻ ہے بڑا حکمت واﻻ ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcccxlii{اور بعض ایسے ہیں جنہوں نے ان اغراض کے لیے مسجد بنائی ہے کہ ضرر پہنچائیں اور کفر کی باتیں کریں اور ایمانداروں میں تفریق ڈالیں اور اس شخص کے قیام کا سامان کریں جو اس سے پہلے سے اللہ اور رسول کا مخالف ہے، اور قسمیں کھا جائیں گے کہ بجز بھلائی کے اور ہماری کچھ نیت نہیں، اور اللہ گواه ہے کہ وه بالکل جھوٹے ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcccxliii{آپ اس میں کبھی کھڑے نہ ہوں۔ البتہ جس مسجد کی بنیاد اول دن سے تقویٰ پر رکھی گئی ہے وه اس ﻻئق ہے کہ آپ اس میں کھڑے ہوں، اس میں ایسے آدمی ہیں کہ وه خوب پاک ہونے کو پسند کرتے ہیں، اور اللہ تعالیٰ خوب پاک ہونے والوں کو پسند کرتا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcccxliv{پھر آیا ایسا شخص بہتر ہے جس نے اپنی عمارت کی بنیاد اللہ سے ڈرنے پر اور اللہ کی خوشنودی پر رکھی ہو، یا وه شخص، کہ جس نے اپنی عمارت کی بنیاد کسی گھاٹی کے کنارے پر جو کہ گرنے ہی کو ہو، رکھی ہو، پھر وه اس کو لے کر آتش دوزخ میں گر پڑے، اور اللہ تعالیٰ ایسے ﻇالموں کو سمجھ ہی نہیں دیتا\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcccxlv{ان کی یہ عمارت جو انہوں نے بنائی ہے ہمیشہ ان کے دلوں میں شک کی بنیاد پر (کانٹا بن کر) کھٹکتی رہے گی، ہاں مگر ان کے دل ہی اگر پاش پاش ہوجائیں تو خیر، اور اللہ تعالیٰ بڑا علم واﻻ بڑی حکمت واﻻ ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mcccxlvi{بلاشبہ اللہ تعالیٰ نے مسلمانوں سے ان کی جانوں کو اور ان کے مالوں کو اس بات کے عوض میں خرید لیا ہے کہ ان کو جنت ملے گی۔ وه لوگ اللہ کی راه میں لڑتے ہیں جس میں قتل کرتے ہیں اور قتل کیے جاتے ہیں، اس پر سچا وعده کیا گیا ہے تورات میں اور انجیل میں اور قرآن میں اور اللہ سے زیاده اپنے عہد کو کون پورا کرنے واﻻ ہے، تو تم لوگ اپنی اس بیع پر جس کا تم نے معاملہ ٹھہرایا ہے خوشی مناؤ، اور یہ بڑی کامیابی ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mcccxlvii{وه ایسے ہیں جو توبہ کرنے والے، عبادت کرنے والے، حمد کرنے والے، روزه رکھنے والے، (یا راه حق میں سفر کرنے والے) رکوع اور سجده کرنے والے، نیک باتوں کی تعلیم کرنے والے اور بری باتوں سے باز رکھنے والے اور اللہ کی حدوں کا خیال رکھنے والے ہیں اور ایسے مومنین کو آپ خوشخبری سنا دیجئے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mcccxlviii{پیغمبر کو اور دوسرے مسلمانوں کو جائز نہیں کہ مشرکین کے لیے مغفرت کی دعا مانگیں اگرچہ وه رشتہدار ہی ہوں اس امر کے ﻇاہر ہوجانے کے بعد کہ یہ لوگ دوزخی ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mcccxlix{اور ابراہیم (علیہ السلام) کا اپنے باپ کے لیے دعائے مغفرت مانگنا وه صرف وعده کے سبب سے تھا جو انہوں نے اس سے وعده کرلیا تھا۔ پھر جب ان پر یہ بات ﻇاہر ہوگئی کہ وه اللہ کا دشمن ہے تو وه اس سے محض بے تعلق ہوگئے، واقعی ابراہیم (علیہ السلام) بڑے نرم دل اور برد بار تھے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mcccl{اور اللہ ایسا نہیں کرتا کہ کسی قوم کو ہدایت کر کے بعد میں گمراه کر دے جب تک کہ ان چیزوں کو صاف صاف نہ بتلادے جن سے وه بچیں بیشک اللہ تعالیٰ ہر چیز کو خوب جانتا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mcccli{بلاشبہ اللہ ہی کی سلطنت ہے آسمانوں اور زمین میں۔ وہی جلاتا اور مارتا ہے، اور تمہارا اللہ کے سوا نہ کوئی یار ہے اور نہ کوئی مدد گار ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mccclii{اللہ تعالیٰ نے پیغمبر کے حال پر توجہ فرمائی اور مہاجرین اور انصار کے حال پر بھی جنہوں نے ایسی تنگی کے وقت پیغمبر کا ساتھ دیا، اس کے بعد کہ ان میں سے ایک گروه کے دلوں میں کچھ تزلزل ہو چلا تھا۔ پھر اللہ نے ان کے حال پر توجہ فرمائی۔ بلاشبہ اللہ تعالیٰ ان سب پر بہت ہی شفیق مہربان ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mcccliii{اور تین شخصوں کے حال پر بھی جن کا معاملہ ملتوی چھوڑ دیا گیا تھا۔ یہاں تک کہ جب زمین باوجود اپنی فراخی کے ان پر تنگ ہونے لگی اور وه خود اپنی جان سے تنگ آگئے اور انہوں نے سمجھ لیا کہ اللہ سے کہیں پناه نہیں مل سکتی بجز اس کے کہ اسی کی طرف رجوع کیا جائے پھر ان کے حال پر توجہ فرمائی تاکہ وه آئنده بھی توبہ کرسکیں۔ بیشک اللہ تعالیٰ بہت توبہ قبول کرنے واﻻ بڑا رحم واﻻ ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mcccliv{اے ایمان والو! اللہ تعالیٰ سے ڈرو اور سچوں کے ساتھ رہو\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mccclv{مدینہ کے رہنے والوں کو اور جو دیہاتی ان کے گردوپیش ہیں ان کو یہ زیبا نہ تھا کہ رسول اللہ کو چھوڑ کر پیچھے ره جائیں اور نہ یہ کہ اپنی جان کو ان کی جان سے عزیز سمجھیں، یہ اس سبب سے کہ ان کو اللہ کی راه میں جو پیاس لگی اور جو تکان پہنچی اور جو بھوک لگی اور جو کسی ایسی جگہ چلے جو کفار کے لیے موجب غیﻆ ہوا ہو اور دشمنوں کی جو کچھ خبر لی، ان سب پر ان کے نام (ایک ایک) نیک کام لکھا گیا۔ یقیناً اللہ تعالیٰ مخلصین کا اجر ضائع نہیں کرتا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mccclvi{اور جو کچھ چھوٹا بڑا انہوں نے خرچ کیا اور جتنے میدان ان کو طے کرنے پڑے، یہ سب بھی ان کے نام لکھا گیا تاکہ اللہ تعالیٰ ان کے کاموں کا اچھے سے اچھا بدلہ دے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mccclvii{اور مسلمانوں کو یہ نہ چاہئے کہ سب کے سب نکل کھڑے ہوں سو ایسا کیوں نہ کیا جائے کہ ان کی ہر بڑی جماعت میں سے ایک چھوٹی جماعت جایا کرے تاکہ وه دین کی سمجھ بوجھ حاصل کریں اور تاکہ یہ لوگ اپنی قوم کو جب کہ وه ان کے پاس آئیں، ڈرائیں تاکہ وه ڈر جائیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mccclviii{اے ایمان والو! ان کفار سے لڑو جو تمہارے آس پاس ہیں اور ان کو تمہارے اندر سختی پانا چاہئے۔ اور یقین رکھو کہ اللہ تعالیٰ متقی لوگوں کے ساتھ ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mccclix{اور جب کوئی سورت نازل کی جاتی ہے تو بعض منافقین کہتے ہیں کہ اس سورت نے تم میں سے کس کے ایمان کو زیاده کیا ہے، سو جو لوگ ایمان والے ہیں اس سورت نے ان کے ایمان کو زیاده کیا ہے اور وه خوش ہورہے ہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mccclx{اور جن کے دلوں میں روگ ہے اس سورت نے ان میں ان کی گندگی کے ساتھ اور گندگی بڑھا دی اور وه حالت کفر ہی میں مر گئے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mccclxi{اور کیا ان کو نہیں دکھلائی دیتا کہ یہ لوگ ہر سال ایک بار یا دو بار کسی نہ کسی آفت میں پھنستے رہتے ہیں پھر بھی نہ توبہ کرتے اور نہ نصیحت قبول کرتے ہیں\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mccclxii{اور جب کوئی سورت نازل کی جاتی ہے تو ایک دوسرے کو دیکھنے لگتے ہیں کہ تم کو کوئی دیکھتا تو نہیں پھر چل دیتے ہیں اللہ تعالیٰ نے ان کا دل پھیر دیا ہے اس وجہ سے کہ وه بے سمجھ لوگ ہیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mccclxiii{تمہارے پاس ایک ایسے پیغمبر تشریف ﻻئے ہیں جو تمہاری جنس سے ہیں جن کو تمہاری مضرت کی بات نہایت گراں گزرتی ہے جو تمہاری منفعت کے بڑے خواہش مند رہتے ہیں ایمان والوں کے ساتھ بڑے ہی شفیق اور مہربان ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mccclxiv{پھر اگر رو گردانی کریں تو آپ کہہ دیجیئے کہ میرے لیے اللہ کافی ہے، اس کے سوا کوئی معبود نہیں۔ میں نے اسی پر بھروسہ کیا اور وه بڑے عرش کا مالک ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mccclxv{\basmalahur الرٰ۔ یہ پرحکمت کتاب کی آیتیں ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccclxvi{کیا ان لوگوں کو اس بات سے تعجب ہوا کہ ہم نے ان میں سے ایک شخص کے پاس وحی بھیج دی کہ سب آدمیوں کو ڈرائیے اور جو ایمان لے آئے ان کو یہ خوشخبری سنائیے کہ ان کے رب کے پاس ان کو پورا اجر ومرتبہ ملے گا۔ کافروں نے کہا کہ یہ شخص تو بلاشبہ صریح جادوگر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccclxvii{بلاشبہ تمہارا رب اللہ ہی ہے جس نے آسمانوں اور زمین کو چھ روز میں پیدا کردیا پھر عرش پر قائم ہوا وه ہر کام کی تدبیر کرتا ہے۔ اس کی اجازت کے بغیر کوئی اس کے پاس سفارش کرنے واﻻ نہیں ایسا اللہ تمہارا رب ہے سو تم اس کی عبادت کرو، کیا تم پھر بھی نصیحت نہیں پکڑتے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccclxviii{تم سب کو اللہ ہی کے پاس جانا ہے، اللہ نے سچا وعده کر رکھا ہے۔ بیشک وہی پہلی بار بھی پیدا کرتا ہے پھر وہی دوباره بھی پیدا کرے گا تاکہ ایسے لوگوں کو جو کہ ایمان ﻻئے اور انہوں نے نیک کام کیے انصاف کے ساتھ جزا دے اور جن لوگوں نے کفر کیا ان کے واسطے کھولتا ہوا پانی پینے کو ملے گا اور دردناک عذاب ہوگا ان کے کفر کی وجہ سے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccclxix{وه اللہ تعالیٰ ایسا ہے جس نے آفتاب کو چمکتا ہوا بنایا اور چاند کو نورانی بنایا اور اس کے لیے منزلیں مقرر کیں تاکہ تم برسوں کی گنتی اور حساب معلوم کرلیا کرو۔ اللہ تعالیٰ نے یہ چیزیں بے فائده نہیں پیدا کیں۔ وه یہ دﻻئل ان کو صاف صاف بتلا رہا ہے جو دانش رکھتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccclxx{بلاشبہ رات اور دن کے یکے بعد دیگرے آنے میں اور اللہ تعالیٰ نے جو کچھ آسمانوں اور زمین میں پیدا کیا ہے ان سب میں ان لوگوں کے واسطے دﻻئل ہیں جو اللہ کا ڈر رکھتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccclxxi{جن لوگوں کو ہمارے پاس آنے کا یقین نہیں ہے اور وه دنیوی زندگی پر راضی ہوگئے ہیں اور اس میں جی لگا بیٹھے ہیں اور جو لوگ ہماری آیتوں سے غافل ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccclxxii{ایسے لوگوں کا ٹھکانا ان کے اعمال کی وجہ سے دوزخ ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccclxxiii{یقیناً جو لوگ ایمان ﻻئے اور انہوں نے نیک کام کیے ان کا رب ان کو ان کے ایمان کے سبب ان کے مقصد تک پہنچا دے گا نعمت کے باغوں میں جن کے نیچے نہریں جاری ہوں گی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccclxxiv{ان کے منھ سے یہ بات نکلے گی سبحان اللہ اور ان کا باہمی سلام یہ ہوگا السلام علیکم اور ان کی اخیر بات یہ ہوگی تمام تعریفیں اللہ کے لیے ہیں جو سارے جہان کا رب ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccclxxv{اور اگر اللہ لوگوں پر جلدی سے نقصان واقع کردیا کرتا جس طرح وه فائده کے لیے جلدی مچاتے ہیں تو ان کا وعده کبھی کا پورا ہوچکا ہوتا۔ سو ہم ان لوگوں کو جن کو ہمارے پاس آنے کا یقین نہیں ہے ان کے حال پر چھوڑے رکھتے ہیں کہ اپنی سرکشی میں بھٹکتے رہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccclxxvi{اور جب انسان کو کوئی تکلیف پہنچتی ہے تو ہم کو پکارتا ہے لیٹے بھی، بیٹھے بھی، کھڑے بھی۔ پھر جب ہم اس کی تکلیف اس سے ہٹا دیتے ہیں تو وه ایسا ہوجاتا ہے کہ گویا اس نے اپنی تکلیف کے لیے جو اسے پہنچی تھی کبھی ہمیں پکارا ہی نہ تھا، ان حد سے گزرنے والوں کے اعمال کو ان کے لیے اسی طرح خوشنما بنادیا گیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccclxxvii{اور ہم نے تم سے پہلے بہت سے گروہوں کو ہلاک کردیا جب کہ انہوں نے ﻇلم کیا حاﻻنکہ ان کے پاس ان کے پیغمبر بھی دﻻئل لے کر آئے، اور وه ایسے کب تھے کہ ایمان لے آتے؟ ہم مجرم لوگوں کو ایسی ہی سزا دیا کرتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccclxxviii{پھر ان کے بعد ہم نے دنیا میں بجائے ان کے تم کو جانشین کیا تاکہ ہم دیکھ لیں کہ تم کس طرح کام کرتے ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccclxxix{اور جب ان کے سامنے ہماری آیتیں پڑھی جاتی ہیں جو بالکل صاف صاف ہیں تو یہ لوگ جن کو ہمارے پاس آنے کی امید نہیں ہے یوں کہتے ہیں کہ اس کے سوا کوئی دوسرا قرآن ﻻئیے یا اس میں کچھ ترمیم کردیجئے۔ آپ (صلی اللہ علیہ وسلم) یوں کہہ دیجئے کہ مجھے یہ حق نہیں کہ میں اپنی طرف سے اس میں ترمیم کردوں بس میں تو اسی کا اتباع کروں گا جو میرے پاس وحی کے ذریعہ سے پہنچا ہے، اگر میں اپنے رب کی نافرمانی کروں تو میں ایک بڑے دن کے عذاب کا اندیشہ رکھتا ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccclxxx{آپ یوں کہہ دیجئے کہ اگر اللہ کو منظور ہوتا تو نہ تو میں تم کو وه پڑھ کر سناتا اور نہ اللہ تعالیٰ تم کو اس کی اطلاع دیتا کیونکہ میں اس سے پہلے تو ایک بڑے حصہ عمر تک تم میں ره چکا ہوں۔ پھر کیا تم عقل نہیں رکھتے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mccclxxxi{سو اس شخص سے زیاده کون ﻇالم ہوگا جو اللہ پرجھوٹ باندھے یا اس کی آیتوں کو جھوٹا بتلائے، یقیناً ایسے مجرموں کو اصلاً فلاح نہ ہوگی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccclxxxii{اور یہ لوگ اللہ کے سوا ایسی چیزوں کی عبادت کرتے ہیں جو نہ ان کو ضرر پہنچا سکیں اور نہ ان کو نفع پہنچا سکیں اور کہتے ہیں کہ یہ اللہ کے پاس ہمارے سفارشی ہیں۔ آپ کہہ دیجئے کہ کیا تم اللہ کو ایسی چیز کی خبر دیتے ہو جو اللہ تعالیٰ کو معلوم نہیں، نہ آسمانوں میں اور نہ زمین میں، وه پاک اور برتر ہے ان لوگوں کے شرک سے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiii{اور تمام لوگ ایک ہی امت کے تھے پھر انہوں نے اختلاف پیداکرلیا اور اگر ایک بات نہ ہوتی جو آپ کے رب کی طرف سے پہلے ٹھہر چکی ہے تو جس چیز میں یہ لوگ اختلاف کررہے ہیں ان کا قطعی فیصلہ ہوچکا ہوتا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiv{اور یہ لوگ یوں کہتے ہیں کہ ان پر ان کے رب کی جانب سے کوئی نشانی کیوں نہیں نازل ہوتی؟ سو آپ فرما دیجئے کہ غیب کی خبر صرف اللہ کو ہے سو تم بھی منتظر رہو میں بھی تمہارے ساتھ منتظر ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mccclxxxv{اور جب ہم لوگوں کو اس امر کے بعد کہ ان پر کوئی مصیبت پڑ چکی ہو کسی نعمت کامزه چکھا دیتے ہیں تو وه فوراً ہی ہماری آیتوں کے بارے میں چالیں چلنے لگتے ہیں، آپ کہہ دیجئے کہ اللہ چال چلنے میں تم سے زیاده تیز ہے، بالیقین ہمارے فرشتے تمہاری سب چالوں کو لکھ رہے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvi{وه اللہ ایسا ہے کہ تم کو خشکی اور دریا میں چلاتا ہے، یہاں تک کہ جب تم کشتی میں ہوتے ہو اور وه کشتیاں لوگوں کو موافق ہوا کے ذریعہ سے لے کر چلتی ہیں اور وه لوگ ان سے خوش ہوتے ہیں ان پر ایک جھونکا سخت ہوا کا آتا ہے اور ہر طرف سے ان پر موجیں اٹھتی چلی آتی ہیں اور وه سمجھتے ہیں کہ (برے) آ گھرے، (اس وقت) سب خالص اعتقاد کرکے اللہ ہی کو پکارتے ہیں کہ اگر تو ہم کو اس سے بچالے تو ہم ضرور شکر گزار بن جائیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvii{پھر جب اللہ تعالیٰ ان کو بچالیتا ہے تو فوراً ہی وه زمین میں ناحق سرکشی کرنے لگتے ہیں اے لوگو! یہ تمہاری سرکشی تمہارے لیے وبال ہونے والی ہے دنیاوی زندگی کے (چند) فائدے ہیں، پھر ہمارے پاس تم کو آنا ہے پھر ہم سب تمہارا کیا ہوا تم کو بتلادیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mccclxxxviii{پس دنیاوی زندگی کی حالت تو ایسی ہے جیسے ہم نے آسمان سے پانی برسایا پھر اس سے زمین کی نباتات، جن کو آدمی اور چوپائے کھاتے ہیں، خوب گنجان ہوکر نکلی۔ یہاں تک کہ جب وه زمین اپنی رونق کا پورا حصہ لے چکی اور اس کی خوب زیبائش ہوگئی اور اس کے مالکوں نے سمجھ لیا کہ اب ہم اس پر بالکل قابض ہوچکے تو دن میں یا رات میں اس پر ہماری طرف سے کوئی حکم (عذاب) آپڑا سو ہم نے اس کو ایسا صاف کردیا کہ گویا کل وه موجود ہی نہ تھی۔ ہم اسی طرح آیات کو صاف صاف بیان کرتے ہیں ایسے لوگوں کے لیے جو سوچتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mccclxxxix{اور اللہ تعالیٰ سلامتی کے گھر کی طرف تم کو بلاتا ہے اور جس کو چاہتا ہے راه راست پر چلنے کی توفیق دیتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcccxc{جن لوگوں نے نیکی کی ہے ان کے واسطے خوبی ہے اور مزید برآں بھی اور ان کے چہروں پر نہ سیاہی چھائے گی اور نہ ذلت، یہ لوگ جنت میں رہنے والے ہیں وه اس میں ہمیشہ رہیں گے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcccxci{اور جن لوگوں نے بدکام کیے ان کی بدی کی سزا اس کے برابر ملے گی اور ان کو ذلت چھائے گی، ان کو اللہ تعالیٰ سے کوئی نہ بچا سکے گا۔ گویا ان کے چہروں پر اندھیری رات کے پرت کے پرت لپیٹ دیے گئے ہیں۔ یہ لوگ دوزخ میں رہنے والے ہیں، وه اس میں ہمیشہ رہیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcccxcii{اور وه دن بھی قابل ذکر ہے جس روز ہم ان سب کو جمع کریں گے پھر مشرکین سے کہیں گے کہ تم اور تمہارے شریک اپنی جگہ ٹھہرو پھر ہم ان کے آپس میں پھوٹ ڈال دیں گے اور ان کے وه شرکا کہیں گے کہ تم ہماری عبادت نہیں کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcccxciii{سو ہمارے تمہارے درمیان اللہ کافی ہے گواه کے طور پر، کہ ہم کو تمہاری عبادت کی خبر بھی نہ تھی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcccxciv{اس مقام پر ہر شخص اپنے اگلے کیے ہوئے کاموں کی جانچ کرلے گا اور یہ لوگ اللہ کی طرف جو ان کا مالک حقیقی ہے لوٹائے جائیں گے اور جو کچھ جھوٹ باندھا کرتے تھے سب ان سے غائب ہوجائیں گے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcccxcv{آپ کہیے کہ وه کون ہے جو تم کو آسمان اور زمین سے رزق پہنچاتا ہے یا وه کون ہے جو کانوں اور آنکھوں پر پورا اختیار رکھتا ہے اور وه کون ہے جو زنده کو مرده سے نکالتا ہے اور مرده کو زنده سے نکالتا ہے اور وه کون ہے جو تمام کاموں کی تدبیر کرتا ہے؟ ضرور وه یہی کہیں گے کہ اللہ تو ان سے کہیے کہ پھر کیوں نہیں ڈرتے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcccxcvi{سو یہ ہے اللہ تعالیٰ جو تمہارا رب حقیقی ہے۔ پھر حق کے بعد اور کیا ره گیا بجز گمراہی کے، پھر کہاں پھرے جاتے ہو؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcccxcvii{اسی طرح آپ کے رب کی یہ بات کہ یہ ایمان نہ ﻻئیں گے، تمام فاسق لوگوں کے حق میں ﺛابت ہوچکی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcccxcviii{آپ یوں کہیے کہ کیا تمہارے شرکا میں کوئی ایسا ہے جو پہلی بار بھی پیدا کرے، پھر دوباره بھی پیدا کرے؟ آپ کہہ دیجئے کہ اللہ ہی پہلی بار پیدا کرتا ہے پھر وہی دوباره بھی پیدا کرے گا۔ پھر تم کہاں پھرے جاتے ہو؟\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcccxcix{آپ کہیے کہ تمہارے شرکا میں کوئی ایسا ہے کہ حق کا راستہ بتاتا ہو؟ آپ کہہ دیجئے کہ اللہ ہی حق کا راستہ بتاتا ہے۔ تو پھر آیا جو شخص حق کا راستہ بتاتا ہو وه زیاده اتباع کے ﻻئق ہے یا وه شخص جس کو بغیر بتائے خود ہی راستہ نہ سوجھے؟ پس تم کو کیا ہوگیا ہے تم کیسے فیصلے کرتے ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcd{اور ان میں سے اکثر لوگ صرف گمان پر چل رہے ہیں۔ یقیناً گمان، حق (کی معرفت) میں کچھ بھی کام نہیں دے سکتا یہ جو کچھ کررہے ہیں یقیناً اللہ کو سب خبر ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcdi{اور یہ قرآن ایسا نہیں ہے کہ اللہ (کی وحی) کے بغیر (اپنے ہی سے) گھڑ لیا گیا ہو۔ بلکہ یہ تو (ان کتابوں کی) تصدیق کرنے واﻻ ہے جو اس کے قبل (نازل) ہوچکی ہیں اور کتاب (احکام ضروریہ) کی تفصیل بیان کرنے واﻻ ہے اس میں کوئی بات شک کی نہیں کہ رب العالمین کی طرف سے ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcdii{کیا یہ لوگ یوں کہتے ہیں کہ آپ نے اس کو گھڑ لیا ہے؟ آپ کہہ دیجئے کہ تو پھر تم اس کے مثل ایک ہی سورت لاؤ اور جن جن غیراللہ کو بلا سکو، بلالو اگر تم سچے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcdiii{بلکہ ایسی چیز کی تکذیب کرنے لگے جس کو اپنے احاطہٴ علمی میں نہیں ﻻئے اور ہنوز ان کو اس کا اخیر نتیجہ نہیں ملا۔ جو لوگ ان سے پہلے ہوئے ہیں اسی طرح انہوں نے بھی جھٹلایا تھا، سو دیکھ لیجئے ان ﻇالموں کا انجام کیسا ہوا؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcdiv{اور ان میں سے بعض ایسے ہیں جو اس پر ایمان لے آئیں گے اور بعض ایسے ہیں کہ اس پر ایمان نہ ﻻئیں گے۔ اور آپ کا رب مفسدوں کو خوب جانتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcdv{اور اگر آپ کو جھٹلاتے رہیں تو یہ کہہ دیجئے کہ میرے لیے میرا عمل اور تمہارے لیے تمہارا عمل، تم میرے عمل سے بری ہو اور میں تمہارے عمل سے بری ہوں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcdvi{اور ان میں بعض ایسے ہیں جو آپ کی طرف کان لگائے بیٹھے ہیں۔ کیا آپ بہروں کو سناتے ہیں گو ان کو سمجھ بھی نہ ہو؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcdvii{اور ان میں بعض ایسے ہیں کہ آپ کو تک رہے ہیں۔ پھر کیا آپ اندھوں کو راستہ دکھلانا چاہتے ہیں گو ان کو بصیرت بھی نہ ہو؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcdviii{یہ یقینی بات ہے کہ اللہ لوگوں پر کچھ ﻇلم نہیں کرتا لیکن لوگ خود ہی اپنی جانوں پر ﻇلم کرتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcdix{اور ان کو وه دن یاد دﻻئیے جس میں اللہ ان کو (اپنے حضور) جمع کرے گا (تو ان کو ایسا محسوس ہوگا) کہ گویا وه (دنیا میں) سارے دن کی ایک آدھ گھڑی رہے ہوں گے اور آپس میں ایک دوسرے کو پہچاننے کو ٹھہرے ہوں گے۔ واقعی خسارے میں پڑے وه لوگ جنہوں نے اللہ کے پاس جانے کو جھٹلایا اور وه ہدایت پانے والے نہ تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcdx{اور جس کا ان سے ہم وعده کر رہے ہیں اس میں سے کچھ تھوڑا سا اگر ہم آپ کو دکھلا دیں یا (ان کے ﻇہور سے پہلے) ہم آپ کو وفات دے دیں، سو ہمارے پاس تو ان کو آنا ہی ہے۔ پھر اللہ ان کے سب افعال پر گواه ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcdxi{اور ہر امت کے لیے ایک رسول ہے، سو جب ان کا وه رسول آچکتا ہے ان کا فیصلہ انصاف کے ساتھ کیا جاتا ہے، اور ان پر ﻇلم نہیں کیا جاتا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcdxii{اور یہ لوگ کہتے ہیں کہ یہ وعده کب ہوگا؟ اگر تم سچے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcdxiii{آپ فرما دیجئے کہ میں اپنی ذات کے لیے تو کسی نفع کا اور کسی ضرر کا اختیار رکھتا ہی نہیں مگر جتنا اللہ کو منظور ہو۔ ہر امت کے لیے ایک معین وقت ہے جب ان کا وه معین وقت آپہنچتا ہے تو ایک گھڑی نہ پیچھے ہٹ سکتے ہیں اور نہ آگے سرک سکتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcdxiv{آپ فرما دیجئے کہ یہ تو بتلاؤ کہ اگر تم پر اللہ کا عذاب رات کو آپڑے یا دن کو تو عذاب میں کون سی چیز ایسی ہے کہ مجرم لوگ اس کو جلدی مانگ رہے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcdxv{کیا پھر جب وه آہی پڑے گا اس پر ایمان لاؤ گے۔ ہاں اب مانا! حاﻻنکہ تم اس کی جلدی مچایا کرتے تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcdxvi{پھر ﻇالموں سے کہا جائے گا کہ ہمیشہ کا عذاب چکھو۔ تم کو تو تمہارے کیے کا ہی بدلہ ملا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcdxvii{اور وه آپ سے دریافت کرتے ہیں کہ کیا عذاب واقعی سچ ہے؟ آپ فرما دیجئے کہ ہاں قسم ہے میرے رب کی وه واقعی سچ ہے اور تم کسی طرح اللہ کو عاجز نہیں کرسکتے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcdxviii{اور اگر ہر جان، جس نے ﻇلم (شرک) کیا ہے، کے پاس اتنا ہو کہ ساری زمین بھر جائے تب بھی اس کو دے کر اپنی جان بچانے لگے اور جب عذاب کو دیکھیں گے تو پشیمانی کو پوشیده رکھیں گے۔ اور ان کا فیصلہ انصاف کے ساتھ ہوگا۔ اور ان پر ﻇلم نہ ہوگا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcdxix{یاد رکھو کہ جتنی چیزیں آسمانوں میں اور زمین میں ہیں سب اللہ ہی کی ملک ہیں۔ یاد رکھو کہ اللہ تعالیٰ کا وعده سچا ہے لیکن بہت سے آدمی علم ہی نہیں رکھتے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcdxx{وہی جان ڈالتا ہے وہی جان نکالتا ہے اور تم سب اسی کے پاس ﻻئے جاؤ گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcdxxi{اے لوگو! تمہارے پاس تمہارے رب کی طرف سے ایک ایسی چیز آئی ہے جو نصیحت ہے اور دلوں میں جو روگ ہیں ان کے لیے شفا ہے اور رہنمائی کرنے والی ہے اور رحمت ہے ایمان والوں کے لیے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcdxxii{آپ کہہ دیجئے کہ بس لوگوں کو اللہ کے اس انعام اور رحمت پر خوش ہونا چاہئے۔ وه اس سے بدرجہا بہتر ہے جس کو وه جمع کر رہے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcdxxiii{آپ کہیے کہ یہ تو بتاؤ کہ اللہ نے تمہارے لیے جو کچھ رزق بھیجا تھا پھر تم نے اس کا کچھ حصہ حرام اور کچھ حلال قرار دے لیا۔ آپ پوچھیے کہ کیا تم کو اللہ نے حکم دیا تھا یا اللہ پر افترا ہی کرتے ہو؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcdxxiv{اور جو لوگ اللہ پر جھوٹ افترا باندھتے ہیں ان کا قیامت کی نسبت کیا گمان ہے؟ واقعی لوگوں پر اللہ تعالیٰ کا بڑا ہی فضل ہے لیکن اکثر آدمی شکر نہیں کرتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcdxxv{اور آپ کسی حال میں ہوں اور منجملہ ان احوال کے آپ کہیں سے قرآن پڑھتے ہوں اور جو کام بھی کرتے ہوں ہم کو سب کی خبر رہتی ہے جب تم اس کام میں مشغول ہوتے ہو۔ اور آپ کے رب سے کوئی چیز ذره برابر بھی غائب نہیں نہ زمین میں اور نہ آسمان میں اورنہ کوئی چیز اس سے چھوٹی اور نہ کوئی چیز بڑی مگر یہ سب کتاب مبین میں ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcdxxvi{یاد رکھو اللہ کے دوستوں پر نہ کوئی اندیشہ ہے اور نہ وه غمگین ہوتے ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcdxxvii{یہ وه لوگ ہیں جو ایمان ﻻئے اور (برائیوں سے) پرہیز رکھتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcdxxviii{ان کے لیے دنیاوی زندگی میں بھی اور آخرت میں بھی خوش خبری ہے اللہ تعالیٰ کی باتوں میں کچھ فرق ہوا نہیں کرتا۔ یہ بڑی کامیابی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcdxxix{اور آپ کو ان کی باتیں غم میں نہ ڈالیں۔ تمام تر غلبہ اللہ ہی کے لیے ہے وه سنتا جانتا ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcdxxx{یاد رکھو کہ جتنے کچھ آسمانوں میں ہیں اور جتنے زمین میں ہیں یہ سب اللہ ہی کے ہیں اور جو لوگ اللہ کو چھوڑ کر دوسرے شرکا کی عبادت کررہے ہیں کس چیز کی اتباع کر رہے ہیں۔ محض بے سند خیال کی اتباع کر رہے ہیں اور محض اٹکلیں لگا رہے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcdxxxi{وه ایسا ہے جس نے تمہارے لیے رات بنائی تاکہ تم اس میں آرام کرو اور دن بھی اس طور پر بنایا کہ دیکھنے بھالنے کا ذریعہ ہے، تحقیق اس میں دﻻئل ہیں ان لوگوں کے لیے جو سنتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcdxxxii{وه کہتے ہیں کہ اللہ اوﻻد رکھتا ہے۔ سبحان اللہ! وه تو کسی کا محتاج نہیں اسی کی ملکیت ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے۔ تمہارے پاس اس پر کوئی دلیل نہیں۔ کیا اللہ کے ذمہ ایسی بات لگاتے ہو جس کا تم علم نہیں رکھتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiii{آپ کہہ دیجئے کہ جو لوگ اللہ پر جھوٹ افترا کرتے ہیں، وه کامیاب نہ ہوں گے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiv{یہ دنیا میں تھوڑا سا عیش ہے پھر ہمارے پاس ان کو آنا ہے پھر ہم ان کو ان کے کفر کے بدلے سخت عذاب چکھائیں گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcdxxxv{اور آپ ان کو نوح﴿علیہ السلام﴾ کا قصہ پڑھ کر سنائیے جب کہ انہوں نے اپنی قوم سے فرمایا کہ اے میری قوم! اگر تم کو میرا رہنا اور احکام الٰہی کی نصیحت کرنا بھاری معلوم ہوتا ہے تو میرا تو اللہ ہی پر بھروسہ ہے۔ تم اپنی تدبیر مع اپنے شرکا کے پختہ کرلو پھر تمہاری تدبیر تمہاری گھٹن کا باعﺚ نہ ہونی چاہئے۔ پھر میرے ساتھ کر گزرو اور مجھ کو مہلت نہ دو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvi{پھر بھی اگر تم اعراض ہی کیے جاؤ تو میں نے تم سے کوئی معاوضہ تو نہیں مانگا، میرا معاوضہ تو صرف اللہ ہی کے ذمہ ہے اور مجھ کو حکم کیا گیا ہے کہ میں مسلمانوں میں سے رہوں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvii{سو وه لوگ ان کو جھٹلاتے رہے پس ہم نے ان کو اور جو ان کے ساتھ کشتی میں تھے ان کو نجات دی اور ان کو جانشین بنایا اور جنہوں نے ہماری آیتوں کو جھٹلایا تھا ان کو غرق کردیا۔ سو دیکھنا چاہئے کیسا انجام ہوا ان لوگوں کا جو ڈرائے جاچکے تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcdxxxviii{پھر نوح (علیہ السلام) کے بعد ہم نے اور رسولوں کو ان کی قوموں کی طرف بھیجا سو وه ان کے پاس روشن دلیلیں لے کر آئے پس جس چیز کو انہوں نے اول میں جھوٹا کہہ دیا یہ نہ ہوا کہ پھر اس کو مان لیتے۔ اللہ تعالیٰ اسی طرح حد سے بڑھنے والوں کے دلوں پر بند لگا دیتا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcdxxxix{پھر ان پیغمبروں کے بعد ہم نے موسیٰ اور ہارون (علیہما السلام) کو، فرعون اور اس کے سرداروں کے پاس اپنی نشانیاں دے کر بھیجا۔ سو انہوں نے تکبر کیا اور وه لوگ مجرم قوم تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcdxl{پھر جب ان کو ہمارے پاس سے صحیح دلیل پہنچی تو وه لوگ کہنے لگے کہ یقیناً یہ صریح جادو ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcdxli{موسیٰ (علیہ السلام) نے فرمایا کہ کیا تم اس صحیح دلیل کی نسبت جب کہ وه تمہارے پاس پہنچی ایسی بات کہتے ہو کیا یہ جادو ہے، حاﻻنکہ جادوگر کامیاب نہیں ہوا کرتے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcdxlii{وه لوگ کہنے لگے کیا تم ہمارے پاس اس لیے آئے ہو کہ ہم کو اس طریقہ سے ہٹادو جس پر ہم نے اپنے باپ دادوں کو پایا ہے اور تم دونوں کو دنیا میں بڑائی مل جائے اور ہم تم دونوں کو کبھی نہ مانیں گے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcdxliii{اور فرعون نے کہا کہ میرے پاس تمام ماہر جادوگروں کو حاضر کرو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcdxliv{پھر جب جادوگر آئے تو موسیٰ (علیہ السلام) نے ان سے فرمایا کہ ڈالو جو کچھ تم ڈالنے والے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcdxlv{سو جب انہوں نے ڈاﻻ تو موسی﴿علیہ السلام﴾ نے فرمایا کہ یہ جو کچھ تم ﻻئے ہو جادو ہے۔ یقینی بات ہے کہ اللہ اس کو ابھی درہم برہم کیے دیتا ہے، اللہ ایسے فسادیوں کا کام بننے نہیں دیتا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcdxlvi{اور اللہ تعالیٰ حق کو اپنے فرمان سے ﺛابت کردیتا ہے گو مجرم کیسا ہی ناگوار سمجھیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcdxlvii{پس موسیٰ (علیہ السلام) پر ان کی قوم میں سے صرف قدرے قلیل آدمی ایمان ﻻئے وه بھی فرعون سے اور اپنے حکام سے ڈرتے ڈرتے کہ کہیں ان کو تکلیف پہنچائے اور واقع میں فرعون اس ملک میں زور رکھتا تھا، اور یہ بھی بات تھی کہ وه حد سے باہر ہو جاتا تھا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcdxlviii{اور موسیٰ (علیہ السلام) نے فرمایا کہ اے میری قوم! اگر تم اللہ پر ایمان رکھتے ہو تو اسی پر توکل کرو اگر تم مسلمان ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcdxlix{انہوں نے عرض کیا کہ ہم نے اللہ ہی پر توکل کیا۔ اے ہمارے پروردگار! ہم کو ان ﻇالموں کے لئے فتنہ نہ بنا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcdl{اور ہم کو اپنی رحمت سے ان کافر لوگوں سے نجات دے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcdli{اور ہم نے موسیٰ (علیہ السلام) اور ان کے بھائی کے پاس وحی بھیجی کہ تم دونوں اپنے ان لوگوں کے لیے مصر میں گھر برقرار رکھو اور تم سب اپنے انہی گھروں کو نماز پڑھنے کی جگہ قرار دے لو اور نماز کے پابند رہو اور آپ مسلمانوں کو بشارت دے دیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcdlii{اور موسیٰ (علیہ السلام) نے عرض کیا اے ہمارے رب! تو نے فرعون کو اور اس کے سرداروں کو سامان زینت اور طرح طرح کے مال دنیاوی زندگی میں دیئے۔ اے ہمارے رب! (اسی واسطے دیئے ہیں کہ) وه تیری راه سے گمراه کریں۔ اے ہمارے رب! ان کے مالوں کو نیست ونابود کر دے اور ان کے دلوں کو سخت کردے سو یہ ایمان نہ ﻻنے پائیں یہاں تک کہ دردناک عذاب کو دیکھ لیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcdliii{حق تعالیٰ نے فرمایا کہ تم دونوں کی دعا قبول کرلی گئی، سو تم ﺛابت قدم رہو اور ان لوگوں کی راه نہ چلنا جن کو علم نہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcdliv{اور ہم نے بنی اسرائیل کو دریا سے پار کردیا پھر ان کے پیچھے پیچھے فرعون اپنے لشکر کے ساتھ ﻇلم اور زیادتی کے اراده سے چلا یہاں تک کہ جب ڈوبنے لگا تو کہنے لگا کہ میں ایمان ﻻتا ہوں کہ جس پر بنی اسرائیل ایمان ﻻئے ہیں، اس کے سوا کوئی معبود نہیں اور میں مسلمانوں میں سے ہوں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcdlv{(جواب دیا گیا کہ) اب ایمان ﻻتا ہے؟ اور پہلے سرکشی کرتا رہا اور مفسدوں میں داخل رہا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcdlvi{سو آج ہم صرف تیری ﻻش کو نجات دیں گے تاکہ تو ان کے لیے نشان عبرت ہو جو تیرے بعد ہیں اور حقیقت یہ ہے کہ بہت سے آدمی ہماری نشانیوں سے غافل ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcdlvii{اور ہم نے بنی اسرائیل کو بہت اچھا ٹھکانا رہنے کو دیا اور ہم نے انہیں پاکیزه چیزیں کھانے کو دیں۔ سو انہوں نے اختلاف نہیں کیا یہاں تک کہ ان کے پاس علم پہنچ گیا۔ یقینی بات ہے کہ آپ کا رب ان کے درمیان قیامت کے دن ان امور میں فیصلہ کرے گا جن میں وه اختلاف کرتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcdlviii{پھر اگر آپ اس کی طرف سے شک میں ہوں جس کو ہم نے آپ کے پاس بھیجا ہے تو آپ ان لوگوں سے پوچھ دیکھیے جو آپ سے پہلی کتابوں کو پڑھتے ہیں۔ بیشک آپ کے پاس آپ کے رب کی طرف سے سچی کتاب آئی ہے۔ آپ ہرگز شک کرنے والوں میں سے نہ ہوں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcdlix{اور نہ ان لوگوں میں سے ہوں جنہوں نے اللہ تعالیٰ کی آیتوں کو جھٹلایا، کہیں آپ خساره پانے والوں میں سے نہ ہوجائیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcdlx{یقیناً جن لوگوں کے حق میں آپ کے رب کی بات ﺛابت ہوچکی ہے وه ایمان نہ ﻻئیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcdlxi{گو ان کے پاس تمام نشانیاں پہنچ جائیں جب تک کہ وه دردناک عذاب کو نہ دیکھ لیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcdlxii{چنانچہ کوئی بستی ایمان نہ ﻻئی کہ ایمان ﻻنا اس کو نافع ہوتا سوائے یونس ﴿علیہ السلام﴾ کی قوم کے۔ جب وه ایمان لے آئے تو ہم نے رسوائی کے عذاب کو دنیوی زندگی میں ان پر سے ٹال دیا اور ان کو ایک وقت (خاص) تک کے لیے زندگی سے فائده اٹھانے (کا موقع) دیا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcdlxiii{اور اگر آپ کا رب چاہتا تو تمام روئے زمین کے لوگ سب کے سب ایمان لے آتے، تو کیا آپ لوگوں پر زبردستی کرسکتے ہیں یہاں تک کہ وه مومن ہی ہوجائیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcdlxiv{حاﻻنکہ کسی شخص کا ایمان ﻻنا اللہ کے حکم کے بغیر ممکن نہیں۔ اور اللہ تعالیٰ بے عقل لوگوں پر گندگی ڈال دیتا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcdlxv{آپ کہہ دیجئے کہ تم غور کرو کہ کیا کیا چیزیں آسمانوں میں اور زمین میں ہیں اور جو لوگ ایمان نہیں ﻻتے ان کو نشانیاں اور دھمکیاں کچھ فائده نہیں پہنچاتیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcdlxvi{سو وه لوگ صرف ان لوگوں کے سے واقعات کا انتظار کر رہے ہیں جو ان سے پہلے گزر چکے ہیں۔ آپ فرما دیجئے کہ اچھا تو تم انتظار میں رہو میں بھی تمہارے ساتھ انتظار کرنے والوں میں ہوں\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcdlxvii{پھر ہم اپنے پیغمبروں کو اور ایمان والوں کو بچالیتے تھے، اسی طرح ہمارے ذمہ ہے کہ ہم ایمان والوں کو نجات دیا کرتے ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcdlxviii{آپ کہہ دیجئے کہ اے لوگو! اگر تم مرے دین کی طرف سے شک میں ہو تو میں ان معبودوں کی عبادت نہیں کرتا جن کی تم اللہ کو چھوڑ کر عبادت کرتے ہو، لیکن ہاں اس اللہ کی عبادت کرتا ہوں جو تمہاری جان قبض کرتا ہے۔ اور مجھ کو یہ حکم ہوا ہے کہ میں ایمان ﻻنے والوں میں سے ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcdlxix{اور یہ کہ اپنا رخ یکسو ہو کر (اس) دین کی طرف کرلینا، اور کبھی مشرکوں میں سے نہ ہونا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcdlxx{اور اللہ کو چھوڑ کر ایسی چیز کی عبادت مت کرنا جو تجھ کو نہ کوئی نفع پہنچا سکے اور نہ کوئی ضرر پہنچا سکے۔ پھر اگر ایسا کیا تو تم اس حالت میں ﻇالموں میں سے ہو جاؤ گے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcdlxxi{اور اگر تم کو اللہ کوئی تکلیف پہنچائے تو بجز اس کے اور کوئی اس کو دور کرنے واﻻ نہیں ہے اور اگر وه تم کو کوئی خیر پہنچانا چاہے تو اس کے فضل کا کوئی ہٹانے واﻻ نہیں، وه اپنا فضل اپنے بندوں میں سے جس پر چاہے نچھاور کردے اور وه بڑی مغفرت بڑی رحمت واﻻ ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcdlxxii{آپ کہہ دیجئے کہ اے لوگو! تمہارے پاس حق تمہارے رب کی طرف سے پہنچ چکا ہے، اس لیے جو شخص راه راست پر آجائے سو وه اپنے واسطے راه راست پر آئے گا اور جو شخص بے راه رہے گا تو اس کا بے راه ہونا اسی پر پڑے گا اور میں تم پر مسلط نہیں کیا گیا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiii{اور آپ اس کی اتباع کرتے رہیے جو کچھ آپ کے پاس وحی بھیجی جاتی ہے اور صبر کیجئے یہاں تک کہ اللہ فیصلہ کردے اور وه سب فیصلہ کرنے والوں میں اچھا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiv{\basmalahur الرٰ، یہ ایک ایسی کتاب ہے کہ اس کی آیتیں محکم کی گئی ہیں، پھر صاف صاف بیان کی گئی ہیں ایک حکیم باخبر کی طرف سے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcdlxxv{یہ کہ اللہ کے سوا کسی کی عبادت مت کرو میں تم کو اللہ کی طرف سے ڈرانے واﻻ اور بشارت دینے واﻻ ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvi{اور یہ کہ تم لوگ اپنے گناه اپنے رب سے معاف کراؤ پھر اسی کی طرف متوجہ رہو، وه تم کو وقت مقرر تک اچھا سامان (زندگی) دے گا اور ہر زیاده عمل کرنے والے کو زیاده ﺛواب دے گا۔ اور اگر تم لوگ اعراض کرتے رہے تو مجھ کو تمہارے لیے ایک بڑے دن کے عذاب کا اندیشہ ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvii{تم کو اللہ ہی کے پاس جانا ہے اور وه ہر شے پر پوری قدرت رکھتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcdlxxviii{یاد رکھو وه لوگ اپنے سینوں کو دہرا کیے دیتے ہیں تاکہ اپنی باتیں (اللہ) سے چھپا سکیں۔ یاد رکھو کہ وه لوگ جس وقت اپنے کپڑے لپیٹتے ہیں وه اس وقت بھی سب جانتا ہے جو کچھ چھپاتے ہیں اور جو کچھ وه ﻇاہر کرتے ہیں۔ بالیقین وه دلوں کے اندر کی باتیں جانتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcdlxxix{زمین پر چلنے پھرنے والے جتنے جاندار ہیں سب کی روزیاں اللہ تعالیٰ پر ہیں وہی ان کے رہنے سہنے کی جگہ کو جانتا ہےاور ان کے سونپے جانے کی جگہ کو بھی، سب کچھ واضح کتاب میں موجود ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcdlxxx{اللہ ہی وه ہے جس نے چھ دن میں آسمان وزمین کو پیدا کیا اور اس کا عرش پانی پر تھا تاکہ وه تمہیں آزمائے کہ تم میں سے اچھے عمل واﻻ کون ہے، اگر آپ ان سے کہیں کہ تم لوگ مرنے کے بعد اٹھا کھڑے کئے جاؤ گے تو کافر لوگ پلٹ کر جواب دیں گے کہ یہ تو نرا صاف صاف جادو ہی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxi{اور اگر ہم ان سے عذاب کو گنی چنی مدت تک کے لئے پیچھے ڈال دیں تو یہ ضرور پکار اٹھیں گے کہ عذاب کو کون سی چیز روکے ہوئے ہے، سنو! جس دن وه ان کے پاس آئے گا پھر ان سے ٹلنے واﻻ نہیں پھر تو جس چیز کی ہنسی اڑا رہے تھے وه انہیں گھیر لے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxii{اور اگر ہم انسان کو اپنی کسی نعمت کا ذائقہ چکھا کر پھر اسے اس سے لے لیں تو وه بہت ہی ناامید اور بڑا ہی ناشکرا بن جاتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiii{اور اگر ہم اسے کوئی نعمت چکھائیں اس سختی کے بعد جو اسے پہنچ چکی تھی تو وه کہنے لگتا ہے کہ بس برائیاں مجھ سے جاتی رہیں، یقیناً وه بڑا ہی اترانے واﻻ شیخی خور ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiv{سوائے ان کے جو صبر کرتے ہیں اور نیک کاموں میں لگے رہتے ہیں۔ انہی لوگوں کے لئے بخشش بھی ہے اور بہت بڑا نیک بدلہ بھی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxv{پس شاید کہ آپ اس وحی کے کسی حصے کو چھوڑ دینے والے ہیں جو آپ کی طرف نازل کی جاتی ہے اور اس سے آپ کا دل تنگ ہے، صرف ان کی اس بات پر کہ اس پر کوئی خزانہ کیوں نہیں اترا؟ یا اس کے ساتھ کوئی فرشتہ ہی آتا، سن لیجئے! آپ تو صرف ڈرانے والے ہی ہیں اور ہر چیز کا ذمہ دار اللہ تعالیٰ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvi{کیا یہ کہتے ہیں کہ اس قرآن کو اسی نے گھڑا ہے۔ جواب دیجئے کہ پھر تم بھی اسی کی مثل دس سورتیں گھڑی ہوئی لے آؤ اور اللہ کے سوا جسے چاہو اپنے ساتھ بلا بھی لو اگر تم سچے ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvii{پھر اگر وه تمہاری اس بات کو قبول نہ کریں تو تم یقین سے جان لو کہ یہ قرآن اللہ کے علم کے ساتھ اتارا گیا ہے اور یہ کہ اللہ کے سوا کوئی معبود نہیں، پس کیا تم مسلمان ہوتے ہو؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxviii{جو شخص دنیا کی زندگی اور اس کی زینت پر فریفتہ ہوا چاہتا ہو ہم ایسوں کو ان کے کل اعمال (کا بدلہ) یہی بھرپور پہنچا دیتے ہیں اور یہاں انہیں کوئی کمی نہیں کی جاتی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxix{ہاں یہی وه لوگ ہیں جن کے لئے آخرت میں سوائے آگ کے اور کچھ نہیں اور جو کچھ انہوں نے یہاں کیا ہوگا وہاں سب اکارت ہے اور جو کچھ ان کےاعمال تھے سب برباد ہونے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcdxc{کیا وه شخص جو اپنے رب کے پاس کی دلیل پر ہو اور اس کے ساتھ اللہ کی طرف کا گواه ہو اور اس سے پہلے موسیٰ کی کتاب (گواه ہو) جو پیشوا اور رحمت ہے (اوروں کے برابر ہو سکتا ہے؟) یہی لوگ ہیں جو اس پر ایمان رکھتے ہیں، اور تمام فرقوں میں سے جو بھی اس کا منکر ہو اس کے آخری وعدے کی جگہ جہنم ہے، پس تو اس میں کسی قسم کے شبہ میں نہ ره، یقیناً یہ تیرے رب کی جانب سے سراسر برحق ہے، لیکن اکثر لوگ ایمان ﻻنے والے نہیں ہوتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcdxci{اس سے بڑھ کر ﻇالم کون ہوگا جو اللہ پرجھوٹ باندھے یہ لوگ اپنے پروردگار کے سامنے پیش کئے جائیں گے اور سارے گواه کہیں گے کہ یہ وه لوگ ہیں جنہوں نے اپنے پروردگار پر جھوٹ باندھا، خبردار ہو کہ اللہ کی لعنت ہے ﻇالموں پر\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcdxcii{جو اللہ کی راه سے روکتے ہیں اور اس میں کجی تلاش کر لیتے ہیں۔ یہی آخرت کے منکر ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcdxciii{نہ یہ لوگ دنیا میں اللہ کو ہرا سکے اور نہ ان کا کوئی حمایتی اللہ کے سوا ہوا، ان کے لئے عذاب دگنا کیا جائے گا نہ یہ سننے کی طاقت رکھتے تھے اور نہ یہ دیکھتے ہی تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcdxciv{یہی ہیں جنہوں نے اپنا نقصان آپ کر لیا اور وه سب کچھ ان سے کھو گیا، جو انہوں نے گھڑ رکھا تھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcdxcv{بیشک یہی لوگ آخرت میں زیاں کار ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcdxcvi{یقیناً جو لوگ ایمان ﻻئے اور انہوں نے کام بھی نیک کئے اور اپنے پالنے والے کی طرف جھکتے رہے، وہی جنت میں جانے والے ہیں، جہاں وه ہمیشہ ہی رہنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcdxcvii{ان دونوں فرقوں کی مثال اندھے، بہرے اور دیکھنے، سننے والے جیسی ہے۔ کیا یہ دونوں مثال میں برابر ہیں؟ کیا پھر بھی تم نصیحت حاصل نہیں کرتے؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcdxcviii{یقیناً ہم نے نوح (علیہ السلام) کو اس کی قوم کی طرف رسول بنا کر بھیجا کہ میں تمہیں صاف صاف ہوشیار کر دینے واﻻ ہوں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcdxcix{کہ تم صرف اللہ ہی کی عبادت کرو، مجھے تو تم پر دردناک دن کے عذاب کا خوف ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@md{اس کی قوم کے کافروں کے سرداروں نے جواب دیا کہ ہم تو تجھے اپنے جیسا انسان ہی دیکھتے ہیں اور تیرے تابعداروں کو بھی ہم دیکھتے ہیں کہ یہ لوگ واضح طور پر سوائے نیچ لوگوں کے اور کوئی نہیں جو بے سوچے سمجھے (تمہاری پیروی کر رہے ہیں)، ہم تو تمہاری کسی قسم کی برتری اپنے اوپر نہیں دیکھ رہے، بلکہ ہم تو تمہیں جھوٹا سمجھ رہے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdi{نوح نے کہا، میری قوم والو! مجھے بتاؤ تو اگر میں اپنے رب کی طرف سے کسی دلیل پر ہوا اور مجھے اس نے اپنے پاس کی کوئی رحمت عطا کی ہو، پھر وه تمہاری نگاہوں میں نہ آئی تو کیا زبردستی میں اسے تمہارے گلے منڈھ دوں، حاﻻنکہ تم اس سے بیزار ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdii{میری قوم والو! میں تم سے اس پر کوئی مال نہیں مانگتا۔ میرا ﺛواب تو صرف اللہ تعالیٰ کے ہاں ہے نہ میں ایمان والوں کو اپنے پاس سے نکال سکتا ہوں، انہیں اپنے رب سے ملنا ہے لیکن میں دیکھتا ہوں کہ تم لوگ جہالت کر رہے ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdiii{میری قوم کے لوگو! اگر میں ان مومنوں کو اپنے پاس سے نکال دوں تو اللہ کے مقابلہ میں میری مدد کون کر سکتا ہے؟ کیا تم کچھ بھی نصیحت نہیں پکڑتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdiv{میں تم سے نہیں کہتا کہ میرے پاس اللہ کے خزانے ہیں، (سنو!) میں غیب کا علم بھی نہیں رکھتا، نہ میں یہ کہتا ہوں کہ میں کوئی فرشتہ ہوں، نہ میرا یہ قول ہے کہ جن پر تمہاری نگاہیں ذلت سے پڑ رہی ہیں انہیں اللہ تعالیٰ کوئی نعمت دے گا ہی نہیں، ان کے دل میں جو ہے اسے اللہ ہی خوب جانتا ہے، اگر میں ایسی بات کہوں تو یقیناً میرا شمار ﻇالموں میں ہو جائے گا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdv{(قوم کے لوگوں نے) کہا اے نوح! تو نے ہم سے بحﺚ کر لی اور خوب بحﺚ کر لی۔ اب تو جس چیز سے ہمیں دھمکا رہا ہے وہی ہمارے پاس لے آ، اگر تو سچوں میں ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdvi{جواب دیا کہ اسے بھی اللہ تعالیٰ ہی ﻻئے گا اگر وه چاہے اور ہاں تم اسے ہرانے والے نہیں ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdvii{تمہیں میری خیر خواہی کچھ بھی نفع نہیں دے سکتی، گو میں کتنی ہی تمہاری خیر خواہی کیوں نہ چاہوں، بشرطیکہ اللہ کا اراده تمہیں گمراه کرنے کا ہو، وہی تم سب کا پروردگار ہے اور اسی کی طرف لوٹائے جاؤ گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdviii{کیا یہ کہتے ہیں کہ اسے خود اسی نے گھڑ لیا ہے؟ تو جواب دے کہ اگر میں نے اسے گھڑ لیا ہو تو میرا گناه مجھ پر ہے اور میں ان گناہوں سے بری ہوں جو تم کر رہے ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdix{نوح کی طرف وحی بھیجی گئی کہ تیری قوم میں سے جو ایمان ﻻ چکے ان کے سوا اور کوئی اب ایمان ﻻئے گا ہی نہیں، پس تو ان کے کاموں پر غمگین نہ ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdx{اورایک کشتی ہماری آنکھوں کے سامنے اور ہماری وحی سے تیار کر اور ﻇالموں کے بارے میں ہم سے کوئی بات چیت نہ کر وه پانی میں ڈبو دیئے جانے والے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdxi{وه (نوح) کشتی بنانے لگے ان کی قوم کے جو سردار ان کے پاس سے گزرتے وه ان کا مذاق اڑاتے، وه کہتے اگر تم ہمارا مذاق اڑاتے ہو تو ہم بھی تم پر ایک دن ہنسیں گے جیسے تم ہم پر ہنستے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdxii{تمیں بہت جلد معلوم ہو جائے گا کہ کس پر عذاب آتا ہے جو اسے رسوا کرے اور اس پر ہمیشگی کی سزا اتر آئے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdxiii{یہاں تک کہ جب ہمارا حکم آپہنچا اور تنور ابلنے لگا ہم نے کہا کہ اس کشتی میں ہر قسم کے (جانداروں میں سے) جوڑے (یعنی) دو (جانور، ایک نر اور ایک ماده) سوار کرا لے اور اپنے گھر کے لوگوں کو بھی، سوائے ان کے جن پر پہلے سے بات پڑ چکی ہے اور سب ایمان والوں کو بھی، اس کے ساتھ ایمان ﻻنے والے بہت ہی کم تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdxiv{نوح ﴿علیہ السلام﴾ نے کہا، اس کشتی میں بیٹھ جاؤ اللہ ہی کے نام سے اس کا چلنا اور ٹھہرنا ہے، یقیناً میرا رب بڑی بخشش اور بڑے رحم واﻻ ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdxv{وه کشتی انہیں پہاڑوں جیسی موجوں میں لے کر جا رہی تھی اور نوح (علیہ السلام) نے اپنے لڑکے کو جو ایک کنارے پر تھا، پکار کر کہا کہ اے میرے پیارے بچے ہمارے ساتھ سوار ہو جا اور کافروں میں شامل نہ ره\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdxvi{اس نے جواب دیا کہ میں تو کسی بڑے پہاڑ کی طرف پناه میں آجاؤں گا جو مجھے پانی سے بچا لے گا، نوح ﴿علیہ السلام﴾ نے کہا آج اللہ کے امر سے بچانے واﻻ کوئی نہیں، صرف وہی بچیں گے جن پر اللہ کا رحم ہوا۔ اسی وقت ان دونوں کے درمیان موج حائل ہوگئی اور وه ڈوبنے والوں میں سے ہوگیا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdxvii{فرما دیا گیا کہ اے زمین اپنے پانی کو نگل جا اور اے آسمان بس کر تھم جا، اسی وقت پانی سکھا دیا گیا اور کام پورا کر دیا گیا اور کشتی جودی نامی پہاڑ پر جا لگی اور فرما دیا گیا کہ ﻇالم لوگوں پر لعنت نازل ہو\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdxviii{نوح ﴿علیہ السلام﴾ نے اپنے پروردگار کو پکارا اور کہا کہ میرے رب میرا بیٹا تو میرے گھر والوں میں سے ہے، یقیناً تیرا وعده بالکل سچا ہے اور تو تمام حاکموں سے بہتر حاکم ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdxix{اللہ تعالیٰ نے فرمایا اے نوح یقیناً وه تیرے گھرانے سے نہیں ہے، اس کے کام بالکل ہی ناشائستہ ہیں تجھے ہرگز وه چیز نہ مانگنی چاہئے جس کا تجھے مطلقاً علم نہ ہو میں تجھے نصیحت کرتا ہوں کہ تو جاہلوں میں سے اپنا شمار کرانے سے باز رہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdxx{نوح نے کہا میرے پالنہار میں تیری ہی پناه چاہتا ہوں اس بات سے کہ تجھ سے وه مانگوں جس کا مجھے علم ہی نہ ہو اگر تو مجھے نہ بخشے گا اور تو مجھ پر رحم نہ فرمائے گا، تو میں خساره پانے والوں میں ہو جاؤں گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdxxi{فرما دیا گیا کہ اے نوح! ہماری جانب سے سلامتی اور ان برکتوں کے ساتھ اتر، جو تجھ پر ہیں اور تیرے ساتھ کی بہت سی جماعتوں پر اور بہت سی وه امتیں ہوں گی جنہیں ہم فائده تو ضرور پہنچائیں گے لیکن پھر انہیں ہماری طرف سے دردناک عذاب پہنچے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdxxii{یہ خبریں غیب کی خبروں میں سے ہیں جن کی وحی ہم آپ کی طرف کرتے ہیں انہیں اس سے پہلے آپ جانتے تھے اور نہ آپ کی قوم، اس لئے آپ صبر کرتے رہیئے (یقین مانیئے) کہ انجام کار پرہیزگاروں کے لئے ہی ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdxxiii{اور قوم عاد کی طرف ان کے بھائی ہود کو ہم نے بھیجا، اس نے کہا میری قوم والو! اللہ ہی کی عبادت کرو، اس کے سوا تمہارا کوئی معبود نہیں، تم تو صرف بہتان باندھ رہے ہو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdxxiv{اے میری قوم! میں تم سے اس کی کوئی اجرت نہیں مانگتا، میرا اجر اس کے ذمے ہے جس نے مجھے پیدا کیا ہے تو کیا پھر بھی تم عقل سے کام نہیں لیتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdxxv{اے میری قوم کے لوگو! تم اپنے پالنے والے سے اپنی تقصیروں کی معافی طلب کرو اور اس کی جناب میں توبہ کرو، تاکہ وه برسنے والے بادل تم پر بھیج دے اور تمہاری طاقت پر اور طاقت قوت بڑھا دے اور تم جرم کرتے ہوئے روگردانی نہ کرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdxxvi{انہوں نے کہا اے ہود! تو ہمارے پاس کوئی دلیل تو ﻻیا نہیں اور ہم صرف تیرے کہنے سے اپنے معبودوں کو چھوڑنے والے نہیں اور نہ ہم تجھ پر ایمان ﻻنے والے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdxxvii{بلکہ ہم تو یہی کہتے ہیں کہ تو ہمارے کسی معبود کے برے جھپٹے میں آگیا ہے۔ اس نے جواب دیا کہ میں اللہ کو گواه کرتا ہوں اور تم بھی گواه رہو کہ میں تو اللہ کے سوا ان سب سے بیزار ہوں، جنہیں تم شریک بنا رہے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdxxviii{اچھا تم سب مل کر میرے خلاف چالیں چل لو اور مجھے بالکل مہلت بھی نہ دو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdxxix{میرا بھروسہ صرف اللہ تعالیٰ پر ہی ہے، جو میرا اور تم سب کا پروردگار ہے جتنے بھی پاؤں دھرنے والے ہیں سب کی پیشانی وہی تھامے ہوئے ہے۔ یقیناً میرا رب بالکل صحیح راه پر ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdxxx{پس اگر تم روگردانی کرو تو کرو میں تو تمہیں وه پیغام پہنچا چکا جو دے کر مجھے تمہاری طرف بھیجا گیا تھا۔ میرا رب تمہارے قائم مقام اور لوگوں کو کر دے گا اور تم اس کا کچھ بھی بگاڑ نہ سکو گے، یقیناً میرا پروردگار ہر چیز پر نگہبان ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdxxxi{اور جب ہمارا حکم آپہنچا تو ہم نے ہود کو اور اس کے مسلمان ساتھیوں کو اپنی خاص رحمت سے نجات عطا فرمائی اور ہم نے ان سب کو سخت عذاب سے بچا لیا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdxxxii{یہ تھی قوم عاد، جنہوں نے اپنے رب کی آیتوں کا انکار کیا اور اس کے رسولوں کی نافرمانی کی اور ہر ایک سرکش نافرمان کے حکم کی تابعداری کی\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdxxxiii{دنیا میں بھی ان کے پیچھے لعنت لگا دی گئی اور قیامت کے دن بھی، دیکھ لو قوم عاد نے اپنے رب سے کفر کیا، ہود کی قوم عاد پر دوری ہو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdxxxiv{اور قوم ﺛمود کی طرف ان کے بھائی صالح کو بھیجا، اس نے کہا کہ اے میری قوم تم اللہ کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں، اسی نے تمہیں زمین سے پیدا کیا ہے اور اسی نے اس زمین میں تمہیں بسایا ہے، پس تم اس سے معافی طلب کرو اور اس کی طرف رجوع کرو۔ بیشک میرا رب قریب اور دعاؤں کا قبول کرنے واﻻ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdxxxv{انہوں نے کہا اے صالح! اس سے پہلے تو ہم تجھ سے بہت کچھ امیدیں لگائے ہوئے تھے، کیا تو ہمیں ان کی عبادتوں سے روک رہا ہے جن کی عبادت ہمارے باپ دادا کرتے چلے آئے، ہمیں تو اس دین میں حیران کن شک ہے جس کی طرف تو ہمیں بلا رہا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdxxxvi{اس نے جواب دیا کہ اے میری قوم کے لوگو! ذرا بتاؤ تو اگر میں اپنے رب کی طرف سے کسی مضبوط دلیل پر ہوا اور اس نے مجھے اپنے پاس کی رحمت عطا کی ہو، پھر اگر میں نے اس کی نافرمانی کر لی تو کون ہے جو اس کے مقابلے میں میری مدد کرے؟ تم تو میرا نقصان ہی بڑھا رہے ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdxxxvii{اور اے میری قوم والو! یہ اللہ کی بھیجی ہوئی اونٹنی ہے جو تمہارے لئے ایک معجزه ہے اب تم اسے اللہ کی زمین میں کھاتی ہوئی چھوڑ دو اور اسے کسی طرح کی ایذا نہ پہنچاؤ ورنہ فوری عذاب تمہیں پکڑ لے گا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdxxxviii{پھر بھی ان لوگوں نے اس اونٹنی کے پاؤں کاٹ ڈالے، اس پر صالح نے کہا کہ اچھا تم اپنے گھروں میں تین تین دن تک تو ره سہ لو، یہ وعده جھوٹا نہیں ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdxxxix{پھر جب ہمارا فرمان آپہنچا، ہم نے صالح کو اور ان پر ایمان ﻻنے والوں کو اپنی رحمت سے اس سے بھی بچا لیا اور اس دن کی رسوائی سے بھی۔ یقیناً تیرا رب نہایت توانا اور غالب ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdxl{اور ﻇالموں کو بڑے زور کی چنگھاڑ نے آدبوچا، پھر تو وه اپنے گھروں میں اوندھے پڑے ہوئے ره گئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdxli{ایسے کہ گویا وه وہاں کبھی آباد ہی نہ تھے، آگاه رہو کہ قوم ﺛمود نے اپنے رب سے کفر کیا۔ سن لو! ان ﺛمودیوں پر پھٹکار ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdxlii{اور ہمارے بھیجے ہوئے پیغامبر ابراہیم کے پاس خوشخبری لے کر پہنچے اور سلام کہا، انہوں نے بھی جواب سلام دیا اور بغیر کسی تاخیر کے گائے کا بھنا ہوا بچھڑا لے آئے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdxliii{اب جو دیکھا کہ ان کے تو ہاتھ بھی اس کی طرف نہیں پہنچ رہے تو ان سے اجنبیت محسوس کرکے دل ہی دل میں ان سے خوف کرنے لگے، انہوں نے کہا ڈرو نہیں ہم تو قوم لوط کی طرف بھیجے ہوئے آئے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdxliv{اس کی بیوی جو کھڑی ہوئی تھی وه ہنس پڑی، تو ہم نے اسے اسحاق کی اور اسحاق کے پیچھے یعقوب کی خوشخبری دی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdxlv{وه کہنے لگی ہائے میری کم بختی! میرے ہاں اوﻻد کیسے ہو سکتی ہے میں خود بڑھیا اور یہ میرے خاوند بھی بہت بڑی عمر کے ہیں یہ تو یقیناً بڑی عجیب بات ہے!\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdxlvi{فرشتوں نے کہا کیا تو اللہ کی قدرت سے تعجب کر رہی ہے؟ تم پر اے اس گھر کے لوگو اللہ کی رحمت اور اس کی برکتیں نازل ہوں، بیشک اللہ حمد وﺛنا کا سزاوار اور بڑی شان واﻻ ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdxlvii{جب ابراہیم کا ڈر خوف جاتا رہا اور اسے بشارت بھی پہنچ چکی تو ہم سے قوم لوط کے بارے میں کہنے سننے لگے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdxlviii{یقیناً ابراہیم بہت تحمل والے نرم دل اور اللہ کی جانب جھکنے والے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdxlix{اے ابراہیم! اس خیال کو چھوڑ دیجئے، آپ کے رب کا حکم آپہنچا ہے، اور ان پر نہ ٹالے جانے واﻻ عذاب ضرور آنے واﻻ ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdl{جب ہمارے بھیجے ہوئے فرشتے لوط کے پاس پہنچے تو وه ان کی وجہ سے بہت غمگین ہوگئے اور دل ہی دل میں کڑھنے لگے اور کہنے لگے کہ آج کا دن بڑی مصیبت کا دن ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdli{اور اس کی قوم دوڑتی ہوئی اس کے پاس آپہنچی، وه تو پہلے ہی سے بدکاریوں میں مبتلا تھی، لوط ﴿علیہ السلام﴾ نے کہا اے قوم کے لوگو! یہ ہیں میری بیٹیاں جو تمہارے لئے بہت ہی پاکیزه ہیں، اللہ سے ڈرو اور مجھے میرے مہمانوں کے بارے میں رسوا نہ کرو، کیا تم میں ایک بھی بھلا آدمی نہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdlii{انہوں نے جواب دیا کہ تو بخوبی جانتا ہے کہ ہمیں تو تیری بیٹیوں پر کوئی حق نہیں ہے اور تو ہماری اصلی چاہت سے بخوبی واقف ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdliii{لوط ﴿علیہ السلام﴾ نے کہا کاش کہ مجھ میں تم سے مقابلہ کرنے کی قوت ہوتی یا میں کسی زبردست کا آسرا پکڑ پاتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdliv{اب فرشتوں نے کہا اے لوط! ہم تیرے پروردگار کے بھیجے ہوئے ہیں ناممکن ہے کہ یہ تجھ تک پہنچ جائیں پس تو اپنے گھر والوں کو لے کر کچھ رات رہے نکل کھڑا ہو۔ تم میں سے کسی کو مڑ کر بھی نہ دیکھنا چاہئے، بجز تیری بیوی کے، اس لئے کہ اسے بھی وہی پہنچنے واﻻ ہے جو ان سب کو پہنچے گا، یقیناً ان کے وعدے کا وقت صبح کا ہے، کیا صبح بالکل قریب نہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdlv{پھر جب ہمارا حکم آپہنچا، ہم نے اس بستی کو زیر وزبر کر دیا اوپر کا حصہ نیچے کر دیا اور ان پر کنکریلے پتھر برسائے جو تہ بہ تہ تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdlvi{تیرے رب کی طرف سے نشان دار تھے اور وه ان ﻇالموں سے کچھ بھی دور نہ تھے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdlvii{اور ہم نے مدین والوں کی طرف ان کے بھائی شعیب کو بھیجا، اس نے کہا اے میری قوم! اللہ کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں اور تم ناپ تول میں بھی کمی نہ کرو میں تو تمہیں آسوده حال دیکھ رہا ہوں اور مجھے تم پر گھیرنے والے دن کے عذاب کا خوف (بھی) ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdlviii{اے میری قوم! ناپ تول انصاف کے ساتھ پوری پوری کرو لوگوں کو ان کی چیزیں کم نہ دو اور زمین میں فساد اور خرابی نہ مچاؤ\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdlix{اللہ تعالی کا حلال کیا ہوا جو بچ رہے تمہارے لئے بہت ہی بہتر ہے اگر تم ایمان والے ہو، میں تم پر کچھ نگہبان (اور داروغہ) نہیں ہوں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdlx{انہوں نے جواب دیا کہ اے شعیب! کیا تیری صلاة تجھے یہی حکم دیتی ہے کہ ہم اپنے باپ دادوں کے معبودوں کو چھوڑ دیں اور ہم اپنے مالوں میں جو کچھ چاہیں اس کا کرنا بھی چھوڑ دیں تو تو بڑا ہی باوقار اور نیک چلن آدمی ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdlxi{کہا اے میری قوم! دیکھو تو اگر میں اپنے رب کی طرف سے روشن دلیل لئے ہوئے ہوں اور اس نے مجھے اپنے پاس سے بہترین روزی دے رکھی ہے، میرا یہ اراده بالکل نہیں کہ تمہارا خلاف کر کے خود اس چیز کی طرف جھک جاؤں جس سے تمہیں روک رہا ہوں، میرا اراده تو اپنی طاقت بھر اصلاح کرنے کا ہی ہے۔ میری توفیق اللہ ہی کی مدد سے ہے، اسی پر میرا بھروسہ ہے اور اسی کی طرف میں رجوع کرتا ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdlxii{اور اے میری قوم (کے لوگو!) کہیں ایسا نہ ہو کہ تم کو میری مخالفت ان عذابوں کا مستحق بنا دے جو قوم نوح اور قوم ہود اور قوم صالح کو پہنچے ہیں۔ اور قوم لوط تو تم سے کچھ دور نہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdlxiii{تم اپنے رب سے استغفار کرو اور اس کی طرف توبہ کرو، یقین مانو کہ میرا رب بڑی مہربانی واﻻ اور بہت محبت کرنے واﻻ ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdlxiv{انہوں نے کہا اے شعیب! تیری اکثر باتیں تو ہماری سمجھ میں ہی نہیں آتیں اور ہم تو تجھے اپنے اندر بہت کمزور پاتے ہیں، اگر تیرے قبیلے کا خیال نہ ہوتا تو ہم تو تجھے سنگسار کر دیتے، اور ہم تجھے کوئی حیثیت والی ہستی نہیں گنتے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdlxv{انہوں نے جواب دیا کہ اے میری قوم کے لوگو! کیا تمہارے نزدیک میرے قبیلے کے لوگ اللہ سے بھی زیاده ذی عزت ہیں کہ تم نے اسے پس پشت ڈال دیا ہے یقیناً میرا رب جو کچھ تم کر رہے ہو سب کو گھیرے ہوئے ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdlxvi{اے میری قوم کے لوگو! اب تم اپنی جگہ عمل کئے جاؤ میں بھی عمل کر رہا ہوں، تمہیں عنقریب معلوم ہو جائے گا کہ کس کے پاس وه عذاب آتا ہے جو اسے رسوا کر دے اور کون ہے جو جھوٹا ہے۔ تم انتظار کرو میں بھی تمہارے ساتھ منتظر ہوں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdlxvii{جب ہمارا حکم (عذاب) آپہنچا ہم نے شعیب کو اور ان کے ساتھ (تمام) مومنوں کو اپنی خاص رحمت سے نجات بخشی اور ﻇالموں کو سخت چنگھاڑ کے عذاب نے دھر دبوچا جس سے وه اپنے گھروں میں اوندھے پڑے ہوئے ہوگئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdlxviii{گویا کہ وه ان گھروں میں کبھی بسے ہی نہ تھے، آگاه رہو مدین کے لئے بھی ویسی ہی دوری ہو جیسی دوری ﺛمود کو ہوئی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdlxix{اور یقیناً ہم نے ہی موسیٰ کو اپنی آیات اور روشن دلیلوں کے ساتھ بھیجا تھا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdlxx{فرعون اور اس کے سرداروں کی طرف، پھر بھی ان لوگوں نے فرعون کے احکام کی پیروی کی اور فرعون کا کوئی حکم درست تھا ہی نہیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdlxxi{وه تو قیامت کے دن اپنی قوم کا پیش رو ہو کر ان سب کو دوزخ میں جا کھڑا کرے گا، وه بہت ہی برا گھاٹ ہے جس پر ﻻ کھڑے کئے جائیں گے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdlxxii{ان پر تو اس دنیا میں بھی لعنت چپکا دی گئی اور قیامت کے دن بھی برا انعام ہے جو دیا گیا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdlxxiii{بستیوں کی یہ بعض خبریں جنہیں ہم تیرے سامنے بیان فرما رہے ہیں ان میں سے بعض تو موجود ہیں اور بعض (کی فصلیں) کٹ گئی ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdlxxiv{ہم نے ان پر کوئی ﻇلم نہیں کیا، بلکہ خود انہوں نے ہی اپنے اوپر ﻇلم کیا، اور انہیں ان کے معبودوں نے کوئی فائده نہ پہنچایا جنہیں وه اللہ کے سوا پکارا کرتے تھے، جب کہ تیرے پروردگار کا حکم آپہنچا، بلکہ اور ان کا نقصان ہی انہوں نے بڑھا دیا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdlxxv{تیرے پروردگار کی پکڑ کا یہی طریقہ ہے جب کہ وه بستیوں کے رہنے والے ﻇالموں کو پکڑتا ہے بیشک اس کی پکڑ دکھ دینے والی اور نہایت سخت ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdlxxvi{یقیناً اس میں ان لوگوں کے لئے نشان عبرت ہے جو قیامت کے عذاب سے ڈرتے ہیں۔ وه دن جس میں سب لوگ جمع کئے جائیں گے اور وه، وه دن ہے جس میں سب حاضر کئے جائیں گے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdlxxvii{اسے ہم جو ملتوی کرتے ہیں وه صرف ایک مدت معین تک ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdlxxviii{جس دن وه آجائے گی مجال نہ ہوگی کہ اللہ کی اجازت کے بغیر کوئی بات بھی کر لے، سو ان میں کوئی بدبخت ہوگا اور کوئی نیک بخت\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdlxxix{لیکن جو بدبخت ہوئے وه دوزخ میں ہوں گے وہاں چیخیں گے چلائیں گے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdlxxx{وه وہیں ہمیشہ رہنے والے ہیں جب تک آسمان وزمین برقرار رہیں۔ سوائے اس وقت کے جو تمہارا رب چاہے۔ یقیناً تیرا رب جو کچھ چاہے کر گزرتا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdlxxxi{لیکن جو نیک بخت کئے گئے وه جنت میں ہوں گے جہاں ہمیشہ رہیں گے جب تک آسمان وزمین باقی رہے مگر جو تیرا پروردگار چاہے۔ یہ بے انتہا بخشش ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdlxxxii{اس لئے آپ ان چیزوں سے شک وشبہ میں نہ رہیں جنہیں یہ لوگ پوج رہے ہیں، ان کی پوجا تو اس طرح ہے جس طرح ان کے باپ دادوں کی اس سے پہلے تھی۔ ہم ان سب کو ان کا پورا پورا حصہ بغیر کسی کمی کے دینے والے ہی ہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiii{یقیناً ہم نے موسیٰ (علیہ السلام) کو کتاب دی۔ پھر اس میں اختلاف کیا گیا، اگر پہلے ہی آپ کے رب کی بات صادر نہ ہوگئی ہوتی تو یقیناً ان کا فیصلہ کر دیا جاتا، انہیں تو اس میں سخت شبہ ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiv{یقیناًان میں سے ہر ایک جب ان کے روبرو جائے گا تو آپ کا رب اسے اس کے اعمال کا پورا پورا بدلہ دے گا۔ بیشک وه جو کر رہے ہیں ان سے وه باخبر ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdlxxxv{پس آپ جمے رہیئے جیسا کہ آپ کو حکم دیا گیا ہے اور وه لوگ بھی جو آپ کے ساتھ توبہ کر چکے ہیں، خبردار تم حد سے نہ بڑھنا، اللہ تمہارے تمام اعمال کا دیکھنے واﻻ ہے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvi{دیکھو ﻇالموں کی طرف ہرگز نہ جھکنا ورنہ تمہیں بھی (دوزخ کی) آگ لگ جائے گی اور اللہ کے سوا اور تمہارا مددگار نہ کھڑا ہو سکے گا اور نہ تم مدد دیئے جاؤ گے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvii{دن کے دونوں سروں میں نماز برپا رکھ اور رات کی کئی ساعتوں میں بھی، یقیناً نیکیاں برائیوں کو دور کر دیتی ہیں۔ یہ نصیحت ہے نصیحت پکڑنے والوں کے لئے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mdlxxxviii{آپ صبر کرتے رہئے یقیناً اللہ تعالیٰ نیکی کرنے والوں کا اجر ضائع نہیں کرتا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mdlxxxix{پس کیوں نہ تم سے پہلے زمانے کے لوگوں میں سے ایسے اہل خیر لوگ ہوئے جو زمین میں فساد پھیلانے سے روکتے، سوائے ان چند کے جنہیں ہم نے ان میں سے نجات دی تھی، ﻇالم لوگ تو اس چیز کے پیچھے پڑ گئے جس میں انہیں آسودگی دی گئی تھی اور وه گنہگار تھے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mdxc{آپ کا رب ایسا نہیں کہ کسی بستی کو ﻇلم سے ہلاک کر دے اور وہاں کے لوگ نیکو کار ہوں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mdxci{اگر آپ کا پروردگار چاہتا تو سب لوگوں کو ایک ہی راه پر ایک گروه کر دیتا۔ وه تو برابر اختلاف کرنے والے ہی رہیں گے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mdxcii{بجز ان کے جن پر آپ کا رب رحم فرمائے، انہیں تو اسی لئے پیدا کیا ہے، اور آپ کے رب کی یہ بات پوری ہے کہ میں جہنم کو جنوں اور انسانوں سب سے پر کروں گا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mdxciii{رسولوں کے سب احوال ہم آپ کے سامنے آپ کے دل کی تسکین کے لئے بیان فرما رہے ہیں۔ آپ کے پاس اس سورت میں بھی حق پہنچ چکا جو نصیحت ووعﻆ ہے مومنوں کے لئے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mdxciv{ایمان نہ ﻻنے والوں سے کہہ دیجئے کہ تم اپنے طور پر عمل کئے جاؤ ہم بھی عمل میں مشغول ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mdxcv{اور تم بھی انتظار کرو ہم بھی منتظر ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mdxcvi{زمینوں اور آسمانوں کا علم غیب اللہ تعالیٰ ہی کو ہے، تمام معاملات کا رجوع بھی اسی کی جانب ہے، پس تجھے اسی کی عبادت کرنی چاہئے اور اسی پر بھروسہ رکھنا چاہئے اور تم جو کچھ کرتے ہو اس سے اللہ تعالیٰ بے خبر نہیں\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mdxcvii{\basmalahur الرٰ، یہ روشن کتاب کی آیتیں ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdxcviii{یقیناً ہم نے اس کو قرآن عربی نازل فرمایا ہے کہ تم سمجھ سکو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdxcix{ہم آپ کے سامنے بہترین بیان پیش کرتے ہیں اس وجہ سے کہ ہم نے آپ کی جانب یہ قرآن وحی کے ذریعے نازل کیا اور یقیناً آپ اس سے پہلے بے خبروں میں سے تھے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdc{جب کہ یوسف نے اپنے باپ سے ذکر کیا کہ ابا جان میں نے گیاره ستاروں کو اور سورج چاند کو دیکھا کہ وه سب مجھے سجده کر رہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdci{یعقوب علیہ السلام نے کہا پیارے بچے! اپنے اس خواب کا ذکر اپنے بھائیوں سے نہ کرنا۔ ایسا نہ ہو کہ وه تیرے ساتھ کوئی فریب کاری کریں، شیطان تو انسان کا کھلا دشمن ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcii{اور اسی طرح تجھے تیرا پروردگار برگزیده کرے گا اور تجھے معاملہ فہمی (یا خوابوں کی تعبیر) بھی سکھائے گا اور اپنی نعمت تجھے بھرپور عطا فرمائے گا اور یعقوب کے گھر والوں کو بھی، جیسے کہ اس نے اس سے پہلے تیرے دادا اور پردادا یعنی ابراہیم واسحاق کو بھی بھرپور اپنی نعمت دی، یقیناً تیرا رب بہت بڑے علم واﻻ اور زبردست حکمت واﻻ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdciii{یقیناً یوسف اور اس کے بھائیوں میں دریافت کرنے والوں کے لئے (بڑی) نشانیاں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdciv{جب کہ انہوں نے کہا کہ یوسف اور اس کا بھائی بہ نسبت ہمارے، باپ کو بہت زیاده پیارے ہیں حاﻻنکہ ہم (طاقتور) جماعت ہیں کوئی شک نہیں کہ ہمارے ابا صریح غلطی میں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcv{یوسف کو تو مار ہی ڈالو یا اسے کسی (نامعلوم) جگہ پھینک دو کہ تمہارے والد کا رخ صرف تمہاری طرف ہی ہو جائے۔ اس کے بعد تم نیک ہو جانا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcvi{ان میں سے ایک نے کہا یوسف کو قتل تو نہ کرو بلکہ اسے کسی اندھے کنوئیں (کی تہ) میں ڈال آؤ کہ اسے کوئی (آتا جاتا) قافلہ اٹھا لے جائے اگر تمہیں کرنا ہی ہے تو یوں کرو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcvii{انہوں نے کہا ابا! آخر آپ یوسف (علیہ السلام) کے بارے میں ہم پر اعتبار کیوں نہیں کرتے ہم تو اس کے خیر خواه ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcviii{کل آپ اسے ضرور ہمارے ساتھ بھیج دیجئے کہ خوب کھائے پئے اور کھیلے، اس کی حفاﻇت کے ہم ذمہ دار ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcix{(یعقوب علیہ السلام نے) کہا اسے تمہارا لے جانا مجھے تو سخت صدمہ دے گا اور مجھے یہ بھی کھٹکا لگا رہے گا کہ تمہاری غفلت میں اسے بھیڑیا کھا جائے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcx{انہوں نے جواب دیا کہ ہم جیسی (زور آور) جماعت کی موجودگی میں بھی اگر اسے بھیڑیا کھا جائے تو ہم بالکل نکمے ہی ہوئے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcxi{پھر جب اسے لے چلے اور سب نے مل کر ٹھان لیا کہ اسے غیر آباد گہرے کنوئیں کی تہ میں پھینک دیں، ہم نے یوسف (علیہ السلام) کی طرف وحی کی کہ یقیناً (وقت آرہا ہے کہ) تو انہیں اس ماجرا کی خبر اس حال میں دے گا کہ وه جانتے ہی نہ ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcxii{اور عشا کے وقت (وه سب) اپنے باپ کے پاس روتے ہوئے پہنچے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcxiii{اور کہنے لگے کہ ابا جان ہم تو آپس میں دوڑ میں لگ گئے اور یوسف (علیہ السلام) کو ہم نے اسباب کے پاس چھوڑا پس اسے بھیڑیا کھا گیا، آپ تو ہماری بات نہیں مانیں گے، گو ہم بالکل سچے ہی ہوں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcxiv{اور یوسف کے کرتے کو جھوٹ موٹ کے خون سے خون آلود بھی کر ﻻئے تھے، باپ نے کہا یوں نہیں، بلکہ تم نے اپنے دل ہی سے ایک بات بنا لی ہے۔ پس صبر ہی بہتر ہے، اور تمہاری بنائی ہوئی باتوں پر اللہ ہی سے مدد کی طلب ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcxv{اور ایک قافلہ آیا اور انہوں نے اپنے پانی ﻻنے والے کو بھیجا اس نے اپنا ڈول لٹکا دیا، کہنے لگا واه واه خوشی کی بات ہے یہ تو ایک لڑکا ہے، انہوں نے اسے مال تجارت قرار دے کر چھپا دیا اور اللہ تعالیٰ اس سے باخبر تھا جو وه کر رہے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcxvi{اور انہوں نے اسے بہت ہی ہلکی قیمت پر گنتی کے چند درہموں پر ہی بیچ ڈاﻻ، وه تو یوسف کے بارے میں بہت ہی بے رغبت تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcxvii{مصر والوں میں سے جس نے اسے خریدا تھا اس نے اپنی بیوی سے کہا کہ اسے بہت عزت واحترام کے ساتھ رکھو، بہت ممکن ہے کہ یہ ہمیں فائده پہنچائے یا اسے ہم اپنا بیٹا ہی بنا لیں، یوں ہم نے مصر کی سرزمین میں یوسف کا قدم جما دیا کہ ہم اسے خواب کی تعبیر کا کچھ علم سکھا دیں۔ اللہ اپنے ارادے پر غالب ہے لیکن اکثر لوگ بے علم ہوتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcxviii{اور جب (یوسف) پختگی کی عمر کو پہنچ گئے ہم نے اسے قوت فیصلہ اور علم دیا، ہم نیک کاروں کو اسی طرح بدلہ دیتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcxix{اس عورت نے جس کے گھر میں یوسف تھے، یوسف کو بہلانا پھسلانا شروع کیا کہ وه اپنے نفس کی نگرانی چھوڑ دے اور دروازے بند کرکے کہنے لگی لو آجاؤ یوسف نے کہا اللہ کی پناه! وه میرا رب ہے، مجھے اس نے بہت اچھی طرح رکھا ہے۔ بے انصافی کرنے والوں کا بھلا نہیں ہوتا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcxx{اس عورت نے یوسف کی طرف قصد کیا اور یوسف اس کا قصد کرتے اگر وه اپنے پروردگار کی دلیل نہ دیکھتے، یونہی ہوا اس واسطے کہ ہم اس سے برائی اور بے حیائی دور کر دیں۔ بے شک وه ہمارے چنے ہوئے بندوں میں سے تھا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcxxi{دونوں دروازے کی طرف دوڑے اور اس عورت نے یوسف کا کرتا پیچھے کی طرف سے کھینچ کر پھاڑ ڈاﻻ اور دروازے کے پاس ہی عورت کا شوہر دونوں کو مل گیا، تو کہنے لگی جو شخص تیری بیوی کے ساتھ برا اراده کرے بس اس کی سزا یہی ہے کہ اسے قید کر دیا جائے یا اور کوئی دردناک سزا دی جائے۔\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcxxii{یوسف نے کہا یہ عورت ہی مجھے پھسلا رہی تھی، اور عورت کے قبیلے ہی کے ایک شخص نے گواہی دی کہ اگر اس کا کرتا آگے سے پھٹا ہوا ہو تو عورت سچی ہے اور یوسف جھوٹ بولنے والوں میں سے ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcxxiii{اور اگر اس کا کرتا پیچھے کی جانب سے پھاڑا گیاہے تو عورت جھوٹی ہے اور یوسف سچوں میں سے ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcxxiv{خاوند نے جو دیکھا کہ یوسف کا کرتا پیٹھ کی جانب سے پھاڑا گیا ہے تو صاف کہہ دیا کہ یہ تو تم عورتوں کی چال بازی ہے، بیشک تمہاری چال بازی بہت بڑی ہے۔\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcxxv{یوسف اب اس بات کو آتی جاتی کرو اور (اے عورت) تو اپنے گناه سے توبہ کر، بیشک تو گنہگاروں میں سے ہے۔\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcxxvi{اور شہر کی عورتوں میں چرچا ہونے لگا کہ عزیز کی بیوی اپنے (جوان) غلام کو اپنا مطلب نکالنے کے لئے بہلانے پھسلانے میں لگی رہتی ہے، ان کے دل میں یوسف کی محبت بیٹھ گئی ہے، ہمارے خیال میں تو وه صریح گمراہی میں ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcxxvii{اس نے جب ان کی اس پر فریب غیبت کا حال سنا تو انہیں بلوا بھیجا اور ان کے لئے ایک مجلس مرتب کی اور ان میں سے ہر ایک کو چھری دی۔ اور کہا اے یوسف! ان کے سامنے چلے آؤ، ان عورتوں نے جب اسے دیکھا تو بہت بڑا جانا اور اپنے ہاتھ کاٹ لئے، اور زبان سے نکل گیا کہ حاشاللہ! یہ انسان تو ہرگز نہیں، یہ تو یقیناً کوئی بہت ہی بزرگ فرشتہ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcxxviii{اس وقت عزیز مصر کی بیوی نے کہا، یہی ہے جن کے بارے میں تم مجھے طعنے دے رہی تھیں، میں نے ہر چند اس سے اپنا مطلب حاصل کرنا چاہا لیکن یہ بال بال بچا رہا، اور جو کچھ میں اس سے کہہ رہی ہوں اگر یہ نہ کرے گا تو یقیناً یہ قید کر دیا جائے گا اور بیشک یہ بہت ہی بے عزت ہوگا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcxxix{یوسف نے دعا کی کہ اے میرے پروردگار! جس بات کی طرف یہ عورتیں مجھے بلا رہی ہیں اس سے تو مجھے جیل خانہ بہت پسند ہے، اگر تو نے ان کا فن فریب مجھ سے دور نہ کیا تو میں تو ان کی طرف مائل ہو جاؤں گا اور بالکل نادانوں میں جا ملوں گا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcxxx{اس کے رب نے اس کی دعا قبول کر لی اور ان عورتوں کے داؤ پیچ اس سے پھیر دیے، یقیناً وه سننے واﻻ جاننے واﻻ ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcxxxi{پھر ان تمام نشانیوں کے دیکھ لینے کے بعد بھی انہیں یہی مصلحت معلوم ہوئی کہ یوسف کو کچھ مدت کے لئے قید خانہ میں رکھیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcxxxii{اس کے ساتھ ہی دو اور جوان بھی جیل خانے میں داخل ہوئے، ان میں سے ایک نے کہا کہ میں نے خواب میں اپنے آپ کو شراب نچوڑتے دیکھا ہے، اور دوسرے نے کہا میں نے اپنے آپ کو دیکھا ہے کہ میں اپنے سر پر روٹی اٹھائے ہوئے ہوں جسے پرندے کھا رہے ہیں، ہمیں آپ اس کی تعبیر بتایئے، ہمیں تو آپ خوبیوں والے شخص دکھائی دیتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiii{یوسف ﴿علیہ السلام﴾ نے کہا تمہیں جو کھانا دیا جاتا ہے اس کے تمہارے پاس پہنچنے سے پہلے ہی میں تمہیں اس کی تعبیر بتلا دوں گا۔ یہ سب اس علم کی بدولت ہے جو مجھے میرے رب نے سکھایا ہے، میں نے ان لوگوں کا مذہب چھوڑ دیا ہے جو اللہ پر ایمان نہیں رکھتے اور آخرت کے بھی منکر ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiv{میں اپنے باپ دادوں کے دین کا پابند ہوں، یعنی ابراہیم واسحاق اور یعقوب کے دین کا، ہمیں ہرگز یہ سزاوار نہیں کہ ہم اللہ تعالیٰ کے ساتھ کسی کو بھی شریک کریں، ہم پر اور تمام اور لوگوں پر اللہ تعالیٰ کا یہ خاص فضل ہے، لیکن اکثر لوگ ناشکری کرتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcxxxv{اے میرے قید خانے کے ساتھیو! کیا متفرق کئی ایک پروردگار بہتر ہیں؟ یا ایک اللہ زبردست طاقتور؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvi{اس کے سوا تم جن کی پوجا پاٹ کر رہے ہو وه سب نام ہی نام ہیں جو تم نے اور تمہارے باپ دادوں نے خود ہی گھڑ لئے ہیں۔ اللہ تعالیٰ نے ان کی کوئی دلیل نازل نہیں فرمائی، فرمانروائی صرف اللہ تعالیٰ ہی کی ہے، اس کا فرمان ہے کہ تم سب سوائے اس کے کسی اور کی عبادت نہ کرو، یہی دین درست ہے لیکن اکثر لوگ نہیں جانتے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvii{اے میرے قیدخانے کے رفیقو! تم دونوں میں سے ایک تو اپنے بادشاه کو شراب پلانے پر مقرر ہو جائے گا، لیکن دوسرا سولی پر چڑھایا جائے گا اور پرندے اس کا سرنوچ نوچ کھائیں گے، تم دونوں جس کے بارے میں تحقیق کر رہے تھے اس کام کا فیصلہ کردیا گیا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcxxxviii{اور جس کی نسبت یوسف کا گمان تھا کہ ان دونوں میں سے یہ چھوٹ جائے گا اس سے کہا کہ اپنے بادشاه سے میرا ذکر بھی کر دینا، پھر اسے شیطان نے اپنے بادشاه سے ذکر کرنا بھلا دیا اور یوسف نے کئی سال قیدخانے میں ہی کاٹے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcxxxix{بادشاه نے کہا، میں نے خواب میں دیکھا ہے کہ سات موٹی تازی فربہ گائیں ہیں جن کو سات ﻻغر دبلی پتلی گائیں کھا رہی ہیں اور سات بالیاں ہیں ہری ہری اور دوسری سات بالکل خشک۔ اے درباریو! میرے اس خواب کی تعبیر بتلاؤ اگر تم خواب کی تعبیر دے سکتے ہو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcxl{انہوں نے جواب دیا کہ یہ تو اڑتے اڑاتے پریشان خواب ہیں اور ایسے شوریده پریشان خوابوں کی تعبیر جاننے والے ہم نہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcxli{ان دو قیدیوں میں سے جو رہا ہوا تھا اسے مدت کے بعد یاد آگیا اور کہنے لگامیں تمہیں اس کی تعبیر بتلا دوں گا مجھے جانے کی اجازت دیجئے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcxlii{اے یوسف! اے بہت بڑے سچے یوسف! آپ ہمیں اس خواب کی تعبیر بتلایئے کہ سات موٹی تازی گائیں ہیں جنہیں سات دبلی پتلی گائیں کھا رہی ہیں اور سات بالکل سبز خوشے ہیں اور سات ہی دوسرے بالکل خشک ہیں، تاکہ میں واپس جاکر ان لوگوں سے کہوں کہ وه سب جان لیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcxliii{یوسف نے جواب دیا کہ تم سات سال تک پے درپے لگاتار حسب عادت غلہ بویا کرنا، اور فصل کاٹ کر اسے بالیوں سمیت ہی رہنے دینا سوائے اپنے کھانے کی تھوڑی سی مقدار کے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcxliv{اس کے بعد سات سال نہایت سخت قحط آئیں گے وه اس غلے کو کھا جائیں گے، جو تم نے ان کے لئے ذخیره رکھ چھوڑا تھا، سوائے اس تھوڑے سے کے جو تم روک رکھتے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcxlv{اس کے بعد جو سال آئے گا اس میں لوگوں پر خوب بارش برسائی جائے گی اور اس میں (شیرہٴ انگور بھی) خوب نچوڑیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdcxlvi{اور بادشاه نے کہا یوسف کو میرے پاس لاؤ، جب قاصد یوسف کے پاس پہنچا تو انہوں نے کہا، اپنے بادشاه کے پاس واپس جا اور اس سے پوچھ کہ ان عورتوں کا حقیقی واقعہ کیا ہے جنہوں نے اپنے ہاتھ کاٹ لئے، تھے؟ ان کے حیلے کو (صحیح طور پر) جاننے واﻻ میرا پروردگار ہی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcxlvii{بادشاه نے پوچھا اے عورتو! اس وقت کا صحیح واقعہ کیا ہے جب تم داؤ فریب کر کے یوسف کو اس کی دلی منشا سے بہکانا چاہتی تھیں، انہوں نے صاف جواب دیا کہ معاذ اللہ ہم نے یوسف میں کوئی برائی نہیں پائی، پھر تو عزیز کی بیوی بھی بول اٹھی کہ اب تو سچی بات نتھر آئی۔ میں نے ہی اسے ورغلایا تھا، اس کے جی سے، اور یقیناً وه سچوں میں سے ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcxlviii{(یوسف علیہ السلام نے کہا) یہ اس واسطے کہ (عزیز) جان لے کہ میں نے اس کی پیٹھ پیچھے اس کی خیانت نہیں کی اور یہ بھی کہ اللہ دغابازوں کے ہتھکنڈے چلنے نہیں دیتا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdcxlix{میں اپنے نفس کی پاکیزگی بیان نہیں کرتا۔ بیشک نفس تو برائی پر ابھارنے واﻻ ہی ہے، مگر یہ کہ میرا پروردگار ہی اپنا رحم کرے، یقیناً میرا پالنے واﻻ بڑی بخشش کرنے واﻻ اور بہت مہربانی فرمانے واﻻ ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdcl{بادشاه نے کہا اسے میرے پاس لاؤ کہ میں اسے اپنے خاص کاموں کے لئے مقرر کر لوں، پھر جب اس سے بات چیت کی تو کہنے لگا کہ آپ ہمارے ہاں آج سے ذی عزت اور امانت دار ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdcli{(یوسف نے) کہا آپ مجھے ملک کے خزانوں پر مقرر کر دیجئے، میں حفاﻇت کرنے واﻻ اور باخبر ہوں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdclii{اسی طرح ہم نے یوسف (علیہ السلام) کو ملک کا قبضہ دے دیا۔ کہ وه جہاں کہیں چاہے رہے سہے، ہم جسے چاہیں اپنی رحمت پہنچا دیتے ہیں۔ ہم نیکو کاروں کا ﺛواب ضائع نہیں کرتے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdcliii{یقیناً ایمان داروں اور پرہیز گاروں کا اخروی اجر بہت ہی بہتر ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdcliv{یوسف کے بھائی آئے اور یوسف کے پاس گئے تو اس نے انہیں پہچان لیا اور انہوں نے اسے نہ پہچانا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdclv{جب انہیں ان کا اسباب مہیا کر دیا تو کہا کہ تم میرے پاس اپنے اس بھائی کو بھی ﻻنا جو تمہارے باپ سے ہے، کیا تم نے نہیں دیکھا کہ میں پورا ناپ کر دیتا ہوں اور میں ہوں بھی بہترین میزبانی کرنے والوں میں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdclvi{پس اگر تم اسے لے کر پاس نہ آئے تو میری طرف سے تمہیں کوئی ناپ بھی نہ ملے گا بلکہ تم میرے قریب بھی نہ پھٹکنا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdclvii{انہوں نے کہا اچھا ہم اس کے باپ کو اس کی بابت پھسلائیں گے اور پوری کوشش کریں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdclviii{اپنے خدمت گاروں سے کہا کہ ان کی پونجی انہی کی بوریوں میں رکھ دو کہ جب لوٹ کر اپنے اہل وعیال میں جائیں اور پونجیوں کو پہچان لیں تو بہت ممکن ہے کہ یہ پھر لوٹ کر آئیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdclix{جب یہ لوگ لوٹ کر اپنے والد کے پاس گئے تو کہنے لگے کہ ہم سے تو غلہ کا ناپ روک لیا گیا۔ اب آپ ہمارے ساتھ ہمارے بھائی کو بھیجئے کہ ہم پیمانہ بھر کر ﻻئیں ہم اس کی نگہبانی کے ذمہ دار ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdclx{(یعقوب علیہ السلام نے) کہا کہ مجھے تو اس کی بابت تمہارا بس ویسا ہی اعتبار ہے جیسا اس سے پہلے اس کے بھائی کے بارے میں تھا، بس اللہ ہی بہترین حافﻆ ہے اور وه سب مہربانوں سے بڑا مہربان ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdclxi{جب انہوں نے اپنا اسباب کھوﻻ تو اپنا سرمایہ موجود پایا جو ان کی جانب لوٹا دیا گیا تھا۔ کہنے لگے اے ہمارے باپ ہمیں اور کیا چاہیئے۔ دیکھئے تو یہ ہمارا سرمایہ بھی ہمیں واپس لوٹا دیا گیا ہے۔ ہم اپنے خاندان کو رسد ﻻدیں گے اور اپنے بھائی کی نگرانی رکھیں گے اور ایک اونٹ کے بوجھ کا غلہ زیاده ﻻئیں گے۔ یہ ناپ تو بہت آسان ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdclxii{یعقوب (علیہ السلام) نے کہا! میں تو اسے ہرگز ہرگز تمہارے ساتھ نہ بھیجوں گا جب تک کہ تم اللہ کو بیچ میں رکھ کر مجھے قول وقرار نہ دو کہ تم اسے میرے پاس پہنچا دو گے، سوائے اس ایک صورت کے کہ تم سب گرفتار کر لئے جاؤ۔ جب انہوں نے پکا قول قرار دے دیا تو انہوں نے کہا کہ ہم جو کچھ کہتے ہیں اللہ اس پر نگہبان ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdclxiii{اور (یعقوب علیہ السلام) نے کہا اے میرے بچو! تم سب ایک دروازے سے نہ جانا بلکہ کئی جدا جدا دروازوں میں سے داخل ہونا۔ میں اللہ کی طرف سے آنے والی کسی چیز کو تم سے ٹال نہیں سکتا۔ حکم صرف اللہ ہی کا چلتا ہے۔ میرا کامل بھروسہ اسی پر ہے اور ہر ایک بھروسہ کرنے والے کو اسی پر بھروسہ کرنا چاہئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdclxiv{جب وه انہی راستوں سے جن کا حکم ان کے والد نے انہیں دیا تھا، گئے۔ کچھ نہ تھا کہ اللہ نے جو بات مقرر کر دی ہے وه اس سے انہیں ذرا بھی بچا لے۔ مگر یعقوب (علیہ السلام) کے دل میں ایک خیال (پیدا ہوا) جسے اس نے پورا کر لیا، بلاشبہ وه ہمارے سکھلائے ہوئے علم کا عالم تھا لیکن اکثر لوگ نہیں جانتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdclxv{یہ سب جب یوسف کے پاس پہنچ گئے تو اس نے اپنے بھائی کو اپنے پاس بٹھا لیا اور کہا میں تیرا بھائی (یوسف) ہوں، پس یہ جو کچھ کرتے رہے اس کا کچھ رنج نہ کر\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdclxvi{پھر جب انہیں ان کا سامان اسباب ٹھیک ٹھاک کرکے دیا تو اپنے بھائی کے اسباب میں پانی پینے کا پیالہ رکھ دیا۔ پھر ایک آواز دینے والے نے پکار کر کہا کہ اے قافلے والو! تم لوگ تو چور ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdclxvii{انہوں نے ان کی طرف منھ پھیر کر کہا کہ تمہاری کیا چیز کھوئی گئی ہے؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdclxviii{جواب دیا کہ شاہی پیمانہ گم ہے جو اسے لے آئےاسے ایک اونٹ کے بوجھ کا غلہ ملے گا۔ اس وعدے کا میں ضامن ہوں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdclxix{انہوں نے کہا اللہ کی قسم! تم کو خوب علم ہے کہ ہم ملک میں فساد پھیلانے کے لئے نہیں آئے اور نہ ہم چور ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdclxx{انہوں نے کہا اچھا چور کی کیا سزا ہے اگر تم جھوٹے ہو؟\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdclxxi{جواب دیا کہ اس کی سزا یہی ہے کہ جس کے اسباب میں سے پایا جائے وہی اس کا بدلہ ہے۔ ہم تو ایسے ﻇالموں کو یہی سزا دیا کرتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdclxxii{پس یوسف نے ان کے سامان کی تلاشی شروع کی، اپنے بھائی کے سامان کی تلاشی سے پہلے، پھر اس پیمانہ کو اپنے بھائی کے سامان (زنبیل) سے نکالا۔ ہم نے یوسف کے لئے اسی طرح یہ تدبیر کی۔ اس بادشاه کے قانون کی رو سے یہ اپنے بھائی کو نہ لے سکتا تھا مگر یہ کہ اللہ کو منظور ہو۔ ہم جس کے چاہیں درجے بلند کر دیں، ہر ذی علم پر فوقیت رکھنے واﻻ دوسرا ذی علم موجود ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdclxxiii{انہوں نے کہا کہ اگر اس نے چوری کی (تو کوئی تعجب کی بات نہیں) اس کابھائی بھی پہلے چوری کر چکا ہے۔ یوسف (علیہ السلام) نے اس بات کو اپنے دل میں رکھ لیا اور ان کے سامنے بالکل ﻇاہر نہ کیا۔ کہا کہ تم بدتر جگہ میں ہو، اور جو تم بیان کرتے ہو اسے اللہ ہی خوب جانتا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdclxxiv{انہوں نے کہا کہ اے عزیز مصر! اس کے والد بہت بڑی عمر کے بالکل بوڑھے شخص ہیں۔ آپ اس کے بدلے ہم میں سے کسی کو لے لیجئے۔ ہم دیکھتے ہیں کہ آپ بڑے نیک نفس ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdclxxv{یوسف (علیہ السلام) نے کہا ہم نے جس کے پاس اپنی چیز پائی ہے اس کے سوا دوسرے کی گرفتاری کرنے سے اللہ کی پناه چاہتے ہیں، ایسا کرنے سے تو ہم یقیناً ناانصافی کرنے والے ہو جائیں گے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdclxxvi{جب یہ اس سے مایوس ہو گئے تو تنہائی میں بیٹھ کر مشوره کرنے لگے۔ ان میں جو سب سے بڑا تھا اس نے کہا تمہیں معلوم نہیں کہ تمہارے والد نے تم سے اللہ کی قسم لے کر پختہ قول قرار لیا ہے اور اس سے پہلے یوسف کے بارے میں تم کوتاہی کر چکے ہو۔ پس میں تو اس سرزمین سے نہ ٹلوں گا جب تک کہ والد صاحب خود مجھے اجازت نہ دیں یا اللہ تعالیٰ میرے معاملے کا فیصلہ کر دے، وہی بہترین فیصلہ کرنے واﻻ ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdclxxvii{تم سب والد صاحب کی خدمت میں واپس جاؤ اور کہو کہ اباجی! آپ کے صاحبزادے نے چوری کی اور ہم نے وہی گواہی دی تھی جو ہم جانتے تھے۔ ہم کچھ غیب کی حفاﻇت کرنے والے نہ تھے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdclxxviii{آپ اس شہر کے لوگوں سے دریافت فرما لیں جہاں ہم تھے اور اس قافلہ سے بھی پوچھ لیں جس کے ساتھ ہم آئے ہیں، اور یقیناً ہم بالکل سچے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdclxxix{(یعقوب علیہ السلام نے) کہا یہ تو نہیں، بلکہ تم نے اپنی طرف سے بات بنالی، پس اب صبر ہی بہتر ہے۔ قریب ہے کہ اللہ تعالیٰ ان سب کو میرے پاس ہی پہنچا دے۔ وه ہی علم وحکمت واﻻ ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdclxxx{پھر ان سے منھ پھیر لیا اور کہا ہائے یوسف! ان کی آنکھیں بوجہ رنج وغم کے سفید ہو چکی تھیں اور وه غم کو دبائے ہوئے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdclxxxi{بیٹوں نے کہا واللہ! آپ ہمیشہ یوسف کی یاد ہی میں لگے رہیں گے یہاں تک کہ گھل جائیں یا ختم ہی ہو جائیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdclxxxii{انہوں نے کہا کہ میں تو اپنی پریشانیوں اور رنج کی فریاد اللہ ہی سے کر رہا ہوں، مجھے اللہ کی طرف سے وه باتیں معلوم ہیں جو تم نہیں جانتے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiii{میرے پیارے بچو! تم جاؤ اور یوسف (علیہ السلام) کی اور اس کے بھائی کی پوری طرح تلاش کرو اور اللہ کی رحمت سے ناامید نہ ہو۔ یقیناً رب کی رحمت سے ناامید وہی ہوتے ہیں جو کافر ہوتے ہیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiv{پھر جب یہ لوگ یوسف (علیہ السلام) کے پاس پہنچے تو کہنے لگے کہ اے عزیز! ہم کو اور ہمارے خانداں کو دکھ پہنچا ہے۔ ہم حقیر پونجی ﻻئے ہیں پس آپ ہمیں پورے غلہ کا ناپ دیجئے اور ہم پر خیرات کیجئے، اللہ تعالیٰ خیرات کرنے والوں کو بدلہ دیتا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdclxxxv{یوسف نے کہا جانتے بھی ہو کہ تم نے یوسف اوراس کے بھائی کے ساتھ اپنی نادانی کی حالت میں کیا کیا؟\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvi{انہوں نے کہا کیا (واقعی) تو ہی یوسف (علیہ السلام) ہے۔ جواب دیا کہ ہاں میں یوسف (علیہ السلام) ہوں اور یہ میرا بھائی ہے۔ اللہ نے ہم پر فضل وکرم کیا، بات یہ ہے کہ جو بھی پرہیز گاری اور صبر کرے تو اللہ تعالیٰ کسی نیکوکار کا اجر ضائع نہیں کرتا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvii{انہوں نے کہا اللہ کی قسم! اللہ تعالیٰ نے تجھے ہم پر برتری دی ہے اور یہ بھی بالکل سچ ہے کہ ہم خطا کار تھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdclxxxviii{جواب دیا آج تم پر کوئی ملامت نہیں ہے۔ اللہ تمہیں بخشے، وه سب مہربانوں سے بڑا مہربان ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdclxxxix{میرا یہ کرتا تم لے جاؤ اور اسے میرے والد کے منھ پر ڈال دو کہ وه دیکھنے لگیں، اور آجائیں اور اپنے تمام خاندان کو میرے پاس لےآؤ\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcxc{جب یہ قافلہ جدا ہوا تو ان کے والد نے کہا کہ مجھے تو یوسف کی خوشبو آرہی ہے اگر تم مجھے سٹھیایا ہوا قرار نہ دو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcxci{وه کہنے لگے کہ واللہ آپ اپنے اسی پرانے خبط میں مبتلا ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcxcii{جب خوشخبری دینے والے نے پہنچ کر ان کے منھ پر وه کرتا ڈاﻻ اسی وقت وه پھر سے بینا ہوگئے۔ کہا! کیا میں تم سے نہ کہا کرتا تھا کہ میں اللہ کی طرف سے وه باتیں جانتا ہوں جو تم نہیں جانتے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcxciii{انہوں نے کہا ابا جی! آپ ہمارے لئے گناہوں کی بخشش طلب کیجئے بیشک ہم قصور وار ہیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdcxciv{کہا اچھا میں جلد ہی تمہارے لئے اپنے پروردگار سے بخشش مانگوں گا، وه بہت بڑا بخشنے واﻻ اور نہایت مہربانی کرنے وﻻ ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdcxcv{جب یہ سارا گھرانہ یوسف کے پاس پہنچ گیا تو یوسف نے اپنے ماں باپ کو اپنے پاس جگہ دی اور کہا کہ اللہ کو منظور ہے تو آپ سب امن وامان کے ساتھ مصر میں آؤ\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdcxcvi{اور اپنے تخت پر اپنے ماں باپ کو اونچا بٹھایا اور سب اس کے سامنے سجدے میں گر گئے۔ تب کہا کہ اباجی! یہ میرے پہلے کے خواب کی تعبیر ہے میرے رب نے اسے سچا کر دکھایا، اس نے میرے ساتھ بڑا احسان کیا جب کہ مجھے جیل خانے سے نکالا اور آپ لوگوں کو صحرا سے لے آیا اس اختلاف کے بعد جو شیطان نے مجھ میں اور میرے بھائیوں میں ڈال دیا تھا۔ میرا رب جو چاہے اس کے لئے بہترین تدبیر کرنے واﻻ ہے۔ اور وه بہت علم وحکمت واﻻ ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdcxcvii{اے میرے پروردگار! تو نے مجھے ملک عطا فرمایا اور تو نے مجھے خواب کی تعبیر سکھلائی۔ اے آسمان وزمین کے پیدا کرنے والے! تو ہی دنیا وآخرت میں میرا ولی (دوست) اور کارساز ہے، تو مجھے اسلام کی حالت میں فوت کر اور نیکوں میں ملا دے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdcxcviii{یہ غیب کی خبروں میں سے ہے جس کی ہم آپ کی طرف وحی کر رہے ہیں۔ آپ ان کے پاس نہ تھے جب کہ انہوں نے اپنی بات ٹھان لی تھی اور وه فریب کرنے لگے تھے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdcxcix{گو آپ لاکھ چاہیں لیکن اکثر لوگ ایمان دار نہ ہوں گے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdcc{آپ ان سے اس پر کوئی اجرت طلب نہیں کر رہے ہیں۔ یہ تو تمام دنیا کے لئے نری نصیحت ہی نصیحت ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdcci{آسمانوں اور زمین میں بہت سی نشانیاں ہیں۔ جن سے یہ منھ موڑے گزر جاتے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdccii{ان میں سے اکثر لوگ باوجود اللہ پر ایمان رکھنے کے بھی مشرک ہی ہیں\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdcciii{کیا وه اس بات سے بے خوف ہوگئے ہیں کہ ان کے پاس اللہ کے عذابوں میں سے کوئی عام عذاب آجائے یا ان پر اچانک قیامت ٹوٹ پڑے اور وه بے خبر ہی ہوں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdcciv{آپ کہہ دیجئے میری راه یہی ہے۔ میں اور میرے متبعین اللہ کی طرف بلا رہے ہیں، پورے یقین اور اعتماد کے ساتھ۔ اور اللہ پاک ہے اور میں مشرکوں میں نہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdccv{آپ سے پہلے ہم نے بستی والوں میں جتنے رسول بھیجے ہیں سب مرد ہی تھے جن کی طرف ہم وحی نازل فرماتے گئے۔ کیا زمین میں چل پھر کر انہوں نے دیکھا نہیں کہ ان سے پہلے کے لوگوں کا کیسا کچھ انجام ہوا؟ یقیناً آخرت کا گھر پرہیزگاروں کے لئے بہت ہی بہتر ہے، کیا پھر بھی تم نہیں سمجھتے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdccvi{یہاں تک کہ جب رسول ناامید ہونے لگے اور وه (قوم کے لوگ) خیال کرنے لگے کہ انہیں جھوٹ کہا گیا۔ فوراً ہی ہماری مدد ان کے پاس آپہنچی جسے ہم نے چاہا اسے نجات دی گئی۔ بات یہ ہے کہ ہمارا عذاب گناهگاروں سے واپس نہیں کیا جاتا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdccvii{ان کے بیان میں عقل والوں کے لئے یقیناً نصیحت اور عبرت ہے، یہ قرآن جھوٹ بنائی ہوئی بات نہیں بلکہ یہ تصدیق ہے ان کتابوں کی جو اس سے پہلے کی ہیں، کھول کھول کر بیان کرنے واﻻ ہے ہر چیز کو اور ہدایت اور رحمت ہے ایمان دار لوگوں کے لئے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdccviii{\basmalahur ا ل م رٰ۔ یہ قرآن کی آیتیں ہیں، اور جو کچھ آپ کی طرف آپ کے رب کی جانب سے اتارا جاتا ہے، سب حق ہے لیکن اکثر لوگ ایمان نہیں ﻻتے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccix{اللہ وه ہے جس نے آسمانوں کو بغیر ستونوں کے بلند کر رکھا ہے کہ تم اسے دیکھ رہے ہو۔ پھر وه عرش پر قرار پکڑے ہوئے ہے، اسی نے سورج اور چاند کو ماتحتی میں لگا رکھا ہے۔ ہر ایک میعاد معین پر گشت کر رہا ہے، وہی کام کی تدبیر کرتا ہے وه اپنے نشانات کھول کھول کر بیان کر رہا ہے کہ تم اپنے رب کی ملاقات کا یقین کر لو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccx{اسی نے زمین پھیلا کر بچھا دی ہے اور اس میں پہاڑ اور نہریں پیدا کردی ہیں۔ اور اس میں ہر قسم کے پھلوں کے جوڑے دوہرے دوہرے پیدا کردیئے ہیں، وه رات کو دن سے چھپا دیتا ہے۔ یقیناً غور وفکر کرنے والوں کے لئے اس میں بہت سی نشانیاں ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccxi{اور زمین میں مختلف ٹکڑے ایک دوسرے سے لگتے لگاتے ہیں اور انگوروں کے باغات ہیں اور کھیت ہیں اور کھجوروں کے درخت ہیں، شاخ دار اور بعض ایسے ہیں جو بے شاخ ہیں سب ایک ہی پانی پلائے جاتے ہیں۔ پھر بھی ہم ایک کو ایک پر پھلوں میں برتری دیتے ہیں اس میں عقل مندوں کے لئے بہت سی نشانیاں ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdccxii{اگر تجھے تعجب ہو تو واقعی ان کا یہ کہنا عجیب ہے کہ کیا جب ہم مٹی ہو جائیں گے۔ تو کیا ہم نئی پیدائش میں ہوں گے؟ یہی وه لوگ ہیں جنہوں نے اپنے پروردگار سے کفر کیا۔ یہی ہیں جن کی گردنوں میں طوق ہوں گے اور یہی ہیں جو جہنم کے رہنے والے ہیں جو اس میں ہمیشہ ہمیشہ رہیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdccxiii{اور جو تجھ سے (سزا کی طلبی میں) جلد کر رہے ہیں راحت سے پہلے ہی، یقیناً ان سے پہلے سزائیں (بطور مثال) گزر چکی ہیں، اور بیشک تیرا رب البتہ بخشنے واﻻ ہے لوگوں کے بے جا ﻇلم پر بھی۔ اور یہ بھی یقینی بات ہے کہ تیرا رب بڑی سخت سزا دینے واﻻ بھی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdccxiv{اور کافر کہتے ہیں کہ اس پر اس کے رب کی طرف سے کوئی نشانی (معجزه) کیوں نہیں اتاری گئی۔ بات یہ ہے کہ آپ تو صرف آگاه کرنے والے ہیں۔ اور ہر قوم کے لئے ہادی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdccxv{ماده اپنے شکم میں جو کچھ رکھتی ہے اسے اللہ بخوبی جانتا ہے اور پیٹ کا گھٹنا بڑھنا بھی، ہر چیز اس کے پاس اندازے سے ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdccxvi{ﻇاہر وپوشیده کا وه عالم ہے (سب سے) بڑا اور (سب سے) بلند وباﻻ\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdccxvii{تم میں سے کسی کا اپنی بات کو چھپا کر کہنا اور بﺂواز بلند اسے کہنا اور جو رات کو چھپا ہوا ہو اور جو دن میں چل رہا ہو، سب اللہ پر برابر ویکساں ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdccxviii{اس کے پہرے دار انسان کے آگے پیچھے مقرر ہیں، جو اللہ کے حکم سے اس کی نگہبانی کرتے ہیں۔ کسی قوم کی حالت اللہ تعالیٰ نہیں بدلتا جب تک کہ وه خود اسے نہ بدلیں جو ان کے دلوں میں ہے۔ اللہ تعالیٰ جب کسی قوم کی سزا کا اراده کر لیتا ہے تو وه بدﻻ نہیں کرتا اور سوائے اس کے کوئی بھی ان کا کارساز نہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdccxix{وه اللہ ہی ہے جو تمہیں بجلی کی چمک ڈرانے اور امید دﻻنے کے لئے دکھاتا ہے اور بھاری بادلوں کو پیدا کرتا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdccxx{گرج اس کی تسبیح وتعریف کرتی ہے اور فرشتے بھی، اس کے خوف سے۔ وہی آسمان سے بجلیاں گراتا ہے اور جس پر چاہتا ہے اس پر ڈالتا ہے کفار اللہ کی بابت لڑ جھگڑ رہے ہیں اور اللہ سخت قوت والا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdccxxi{اسی کو پکارنا حق ہے۔ جو لوگ اوروں کو اس کے سوا پکارتے ہیں وه ان (کی پکار) کا کچھ بھی جواب نہیں دیتے مگر جیسے کوئی شخص اپنے دونوں ہاتھ پانی کی طرف پھیلائے ہوئے ہو کہ اس کے منھ میں پڑ جائے حاﻻنکہ وه پانی اس کے منھ میں پہنچنے واﻻ نہیں، ان منکروں کی جتنی پکار ہے سب گمراہی میں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdccxxii{اللہ ہی کے لئے زمین اور آسمانوں کی سب مخلوق خوشی اور ناخوشی سے سجده کرتی ہے اور ان کے سائے بھی صبح وشام\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdccxxiii{آپ پوچھئے کہ آسمانوں اور زمین کا پروردگار کون ہے؟ کہہ دیجئے! اللہ۔ کہہ دیجئے! کیا تم پھر بھی اس کے سوا اوروں کو حمایتی بنا رہے ہو جو خود اپنی جان کے بھی بھلے برے کا اختیار نہیں رکھتے۔ کہہ دیجئے کہ کیا اندھا اور بینا برابر ہو سکتا ہے؟ یا کیا اندھیریاں اور روشنی برابر ہو سکتی ہے۔ کیا جنہیں یہ اللہ کے شریک ٹھہرا رہے ہیں انہوں نے بھی اللہ کی طرح مخلوق پیدا کی ہے کہ ان کی نظر میں پیدائش مشتبہ ہوگئی ہو، کہہ دیجئے کہ صرف اللہ ہی تمام چیزوں کا خالق ہے وه اکیلا ہے اور زبردست غالب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdccxxiv{اسی نے آسمان سے پانی برسایا پھر اپنی اپنی وسعت کے مطابق نالے بہہ نکلے۔ پھر پانی کے ریلے نے اوپر چڑھے جھاگ کو اٹھا لیا، اور اس چیز میں بھی جس کو آگ میں ڈال کر تپاتے ہیں زیور یا ساز وسامان کے لئے اسی طرح کے جھاگ ہیں، اسی طرح اللہ تعالیٰ حق وباطل کی مثال بیان فرماتا ہے، اب جھاگ تو ناکاره ہو کر چلا جاتا ہے لیکن جو لوگوں کو نفع دینے والی چیز ہے وه زمین میں ٹھہری رہتی ہے، اللہ تعالیٰ اسی طرح مثالیں بیان فرماتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdccxxv{جن لوگوں نے اپنے رب کے حکم کی بجا آوری کی ان کے لئے بھلائی ہے اور جن لوگوں نے اس کی حکم برداری نہ کی اگر ان کے لئے زمین میں جو کچھ ہے سب کچھ ہو اور اسی کے ساتھ ویسا ہی اور بھی ہو تو وه سب کچھ اپنے بدلے میں دے دیں۔ یہی ہیں جن کے لئے برا حساب ہے اور جن کا ٹھکانہ جہنم ہے جو بہت بری جگہ ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdccxxvi{کیا وه ایک شخص جو یہ علم رکھتا ہو کہ آپ کی طرف آپ کے رب کی جانب سے جو اتارا گیا ہے وه حق ہے، اس شخص جیسا ہو سکتا ہے جو اندھا ہو نصیحت تو وہی قبول کرتے ہیں جو عقلمند ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdccxxvii{جو اللہ کے عہد (وپیمان) کو پورا کرتے ہیں اور قول وقرار کو توڑتے نہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdccxxviii{اور اللہ نے جن چیزوں کے جوڑنے کا حکم دیا ہے وه اسے جوڑتے ہیں اور وه اپنے پروردگار سے ڈرتے ہیں اور حساب کی سختی کا اندیشہ رکھتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdccxxix{اور وه اپنے رب کی رضا مندی کی طلب کے لئے صبر کرتے ہیں، اور نمازوں کو برابر قائم رکھتے ہیں اور جو کچھ ہم نے انہیں دے رکھا ہے اسے چھپے کھلے خرچ کرتے ہیں اور برائی کو بھی بھلائی سے ٹالتے ہیں، ان ہی کے لئے عاقبت کا گھر ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdccxxx{ہمیشہ رہنے کے باغات جہاں یہ خود جائیں گے اور ان کے باپ دادوں اور بیویوں اور اوﻻدوں میں سے بھی جو نیکو کار ہوں گے، ان کے پاس فرشتے ہر ہر دروازے سے آئیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdccxxxi{کہیں گے کہ تم پر سلامتی ہو، صبر کے بدلے، کیا ہی اچھا (بدلہ) ہے اس دار آخرت کا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdccxxxii{اور جو اللہ کے عہد کو اس کی مضبوطی کے بعد توڑ دیتے ہیں اور جن چیزوں کےجوڑنے کا اللہ نے حکم دیا ہے انہیں توڑتے ہیں اور زمین میں فساد پھیلاتے ہیں، ان کے لئے لعنتیں ہیں اور ان کے لئے برا گھر ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiii{اللہ تعالیٰ جس کی روزی چاہتا ہے بڑھاتا ہے اور گھٹاتا ہے یہ تو دنیا کی زندگی میں مست ہو گئے۔ حاﻻنکہ دنیا آخرت کے مقابلے میں نہایت (حقیر) پونجی ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiv{کافر کہتے ہیں کہ اس پر کوئی نشانی (معجزه) کیوں نازل نہیں کیا گیا؟ جواب دے دیجئے کہ جسے اللہ گمراه کرنا چاہے کر دیتا ہے اور جو اس کی طرف جھکے اسے راستہ دکھا دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdccxxxv{جو لوگ ایمان ﻻئے ان کے دل اللہ کے ذکر سے اطمینان حاصل کرتے ہیں۔ یاد رکھو اللہ کے ذکر سے ہی دلوں کو تسلی حاصل ہوتی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvi{جو لوگ ایمان ﻻئے اور جنہوں نے نیک کام بھی کئے ان کے لئے خوشحالی ہے اور بہترین ٹھکانا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvii{اسی طرح ہم نے آپ کو اس امت میں بھیجا ہے جس سے پہلے بہت سی امتیں گزر چکی ہیں کہ آپ انہیں ہماری طرف سے جو وحی آپ پر اتری ہے پڑھ کر سنایئے یہ اللہ رحمٰن کے منکر ہیں، آپ کہہ دیجئے کہ میرا پالنے واﻻ تو وہی ہے اس کے سوا درحقیقت کوئی بھی ﻻئق عبادت نہیں، اسی کے اوپر میرا بھروسہ ہے اور اسی کی جانب میرا رجوع ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdccxxxviii{اگر (بالفرض) کسی قرآن (آسمانی کتاب) کے ذریعے پہاڑ چلا دیئے جاتے یا زمین ٹکڑے ٹکڑے کر دی جاتی یا مردوں سے باتیں کرا دی جاتیں (پھر بھی وه ایمان نہ ﻻتے)، بات یہ ہے کہ سب کام اللہ کے ہاتھ میں ہے، تو کیا ایمان والوں کو اس بات پر دل جمعی نہیں کہ اگر اللہ تعالیٰ چاہے تو تمام لوگوں کو ہدایت دے دے۔ کفار کو تو ان کے کفر کے بدلے ہمیشہ ہی کوئی نہ کوئی سخت سزا پہنچتی رہے گی یا ان کے مکانوں کے قریب نازل ہوتی رہے گی تاوقتیکہ وعدہٴ الٰہی آپہنچے۔ یقیناً اللہ تعالیٰ وعده خلافی نہیں کرتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdccxxxix{یقیناً آپ سے پہلے کے پیغمبروں کا مذاق اڑایا گیا تھا اور میں نے بھی کافروں کو ڈھیل دی تھی پھر انہیں پکڑ لیا تھا، پس میرا عذاب کیسا رہا؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdccxl{آیا وه اللہ جو نگہبانی کرنے واﻻ ہے ہر شخص کی، اس کے کئے ہوئے اعمال پر، ان لوگوں نے اللہ کے شریک ٹھہرائے ہیں کہہ دیجئے ذرا ان کے نام تو لو، کیا تم اللہ کو وه باتیں بتاتے ہو جو وه زمین میں جانتا ہی نہیں، یا صرف اوپری اوپری باتیں بتا رہے ہو، بات اصل یہ ہے کہ کفر کرنے والوں کے لئے ان کے مکر سجا دیئے گئے ہیں، اور وه صحیح راه سے روک دیئے گئے ہیں، اور جس کو اللہ گمراه کر دے اس کو راه دکھانے واﻻ کوئی نہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdccxli{ان کے لئے دنیا کی زندگی میں بھی عذاب ہے، اور آخرت کا عذاب تو بہت ہی زیاده سخت ہے، انہیں اللہ کے غضب سے بچانے واﻻ کوئی بھی نہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdccxlii{اس جنت کی صفت، جس کا وعده پرہیزگاروں کو دیا گیا ہے یہ ہے کہ اس کے نیچے سے نہریں بہہ رہی ہیں۔ اس کا میوه ہمیشگی واﻻ ہے اور اس کا سایہ بھی۔ یہ ہے انجام پرہیزگاروں کا، اور کافروں کا انجام کار دوزخ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdccxliii{جنہیں ہم نے کتاب دی ہے وه تو جو کچھ آپ پر اتارا جاتا ہے اس سے خوش ہوتے ہیں اور دوسرے فرقے اس کی بعض باتوں کے منکر ہیں۔ آپ اعلان کر دیجئے کہ مجھے تو صرف یہی حکم دیا گیا ہے کہ میں اللہ کی عبادت کروں اور اس کے ساتھ شریک نہ کروں، میں اسی کی طرف بلا رہا ہوں اور اسی کی جانب میرا لوٹنا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdccxliv{اسی طرح ہم نے اس قرآن کو عربی زبان کا فرمان اتارا ہے۔ اگر آپ نے ان کی خواہشوں کی پیروی کر لی اس کے بعد کہ آپ کے پاس علم آچکا ہے تو اللہ (کے عذابوں) سے آپ کو کوئی حمایتی ملے گا اور نہ بچانے واﻻ\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdccxlv{ہم آپ سے پہلے بھی بہت سے رسول بھیج چکے ہیں اور ہم نے ان سب کو بیوی بچوں واﻻ بنایا تھا، کسی رسول سے نہیں ہو سکتا کہ کوئی نشانی بغیر اللہ کی اجازت کے لے آئے۔ ہر مقرره وعدے کی ایک لکھت ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdccxlvi{اللہ جو چاہے مٹا دے اور جو چاہے ﺛابت رکھے، لوح محفوظ اسی کے پاس ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxlvii{ان سے کیے ہوئے وعدوں میں سے کوئی اگر ہم آپ کو دکھا دیں یا آپ کو ہم فوت کر لیں تو آپ پر تو صرف پہنچا دینا ہی ہے۔ حساب تو ہمارے ذمہ ہی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxlviii{کیا وه نہیں دیکھتے؟ کہ ہم زمین کو اس کے کناروں سے گھٹاتے چلے آرہے ہیں، اللہ حکم کرتا ہے کوئی اس کے احکام پیچھے ڈالنے واﻻ نہیں، وه جلد حساب لینے واﻻ ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxlix{ان سے پہلے لوگوں نے بھی اپنی مکاری میں کمی نہ کی تھی، لیکن تمام تدبیریں اللہ ہی کی ہیں، جو شخص جو کچھ کر رہا ہے اللہ کے علم میں ہے۔ کافروں کو ابھی معلوم ہو جائے گا کہ (اس) جہان کی جزا کس کے لئے ہے؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccl{یہ کافر کہتے ہیں کہ آپ اللہ کے رسول نہیں۔ آپ جواب دیجئے کہ مجھ میں اور تم میں اللہ گواہی دینے واﻻ کافی ہے اور وه جس کے پاس کتاب کا علم ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccli{\basmalahur الرٰ! یہ عالی شان کتاب ہم نے آپ کی طرف اتاری ہے کہ آپ لوگوں کو اندھیروں سے اجالے کی طرف ﻻئیں، ان کے پروردگار کے حکم سے، زبردست اور تعریفوں والے اللہ کی طرف\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdcclii{جس اللہ کا ہے جو کچھ آسمانوں اور زمین میں ہے۔ اور کافروں کے لئے تو سخت عذاب کی خرابی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccliii{جو آخرت کے مقابلے میں دنیوی زندگی کو پسند رکھتے ہیں اور اللہ کی راه سے روکتے ہیں اور اس میں ٹیڑھ پن پیدا کرنا چاہتے ہیں۔ یہی لوگ پرلے درجے کی گمراہی میں ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccliv{ہم نے ہر ہر نبی کو اس کی قومی زبان میں ہی بھیجا ہے تاکہ ان کے سامنے وضاحت سے بیان کر دے۔ اب اللہ جسے چاہے گمراه کر دے، اور جسے چاہے راه دکھا دے، وه غلبہ اور حکمت واﻻ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcclv{(یاد رکھو جب کہ) ہم نے موسیٰ کو اپنی نشانیاں دے کر بھیجا کہ تو اپنی قوم کو اندھیروں سے روشنی میں نکال اور انہیں اللہ کے احسانات یاد دﻻ۔ اس میں نشانیاں ہیں ہر ایک صبر شکر کرنے والے کے لئے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcclvi{جس وقت موسیٰ نے اپنی قوم سے کہا کہ اللہ کے وه احسانات یاد کرو جو اس نے تم پر کیے ہیں، جبکہ اس نے تمہیں فرعونیوں سے نجات دی جو تمہیں بڑے دکھ پہنچاتے تھے۔ تمہارے لڑکوں کو قتل کرتے تھے اور تمہاری لڑکیوں کو زنده چھوڑتے تھے، اس میں تمہارے رب کی طرف سے تم پر بہت بڑی آزمائش تھی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcclvii{اور جب تمہارے پروردگار نے تمہیں آگاه کر دیا کہ اگر تم شکر گزاری کرو گے تو بیشک میں تمہیں زیاده دوں گا اور اگر تم ناشکری کرو گے تو یقیناً میرا عذاب بہت سخت ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcclviii{موسیٰ (علیہ السلام) نے کہا کہ اگر تم سب اور روئے زمین کے تمام انسان اللہ کی ناشکری کریں تو بھی اللہ بے نیاز اور تعریفوں واﻻ ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcclix{کیا تمہارے پاس تم سے پہلے کے لوگوں کی خبریں نہیں آئیں؟ یعنی قوم نوح کی اور عاد وﺛمود کی اور ان کے بعد والوں کی جنہیں سوائے اللہ تعالیٰ کے اور کوئی نہیں جانتا، ان کے پاس ان کے رسول معجزے ﻻئے، لیکن انہوں نے اپنے ہاتھ اپنے منھ میں دبالیے اور صاف کہہ دیا کہ جو کچھ تمہیں دے کر بھیجا گیا ہے ہم اس کے منکر ہیں اور جس چیز کی طرف تم ہمیں بلا رہے ہو ہمیں تو اس میں بڑا بھاری شبہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcclx{ان کے رسولوں نے انہیں کہا کہ کیا حق تعالیٰ کے بارے میں تمہیں شک ہے جو آسمانوں اور زمین کا بنانے واﻻ ہے وه تو تمہیں اس لئے بلا رہا ہے کہ تمہارے گناه معاف فرما دے، اور ایک مقرر وقت تک تمہیں مہلت عطا فرمائے، انہوں نے کہا کہ تم تو ہم جیسے ہی انسان ہو تم چاہتے ہو کہ ہمیں ان خداؤں کی عبادت سے روک دو جن کی عبادت ہمارے باپ دادا کرتے رہے۔ اچھا تو ہمارے سامنے کوئی کھلی دلیل پیش کرو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcclxi{ان کے پیغمبروں نے ان سے کہا کہ یہ تو سچ ہے کہ ہم تم جیسے ہی انسان ہیں لیکن اللہ تعالیٰ اپنے بندوں میں سے جس پر چاہتا ہے اپنا فضل کرتا ہے۔ اللہ کے حکم کے بغیر ہماری مجال نہیں کہ ہم کوئی معجزه تمہیں ﻻ دکھائیں اور ایمان والوں کو صرف اللہ تعالیٰ ہی پر بھروسہ رکھنا چاہئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcclxii{آخر کیا وجہ ہے کہ ہم اللہ تعالیٰ پر بھروسہ نہ رکھیں جبکہ اسی نے ہمیں ہماری راہیں سمجھائی ہیں۔ واللہ جو ایذائیں تم ہمیں دو گے ہم ان پر صبر ہی کریں گے۔ توکل کرنے والوں کو یہی ﻻئق ہے کہ اللہ ہی پر توکل کریں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcclxiii{کافروں نے اپنے رسولوں سے کہا کہ ہم تمہیں ملک بدر کر دیں گے یا تم پھر سے ہمارے مذہب میں لوٹ آؤ۔ تو ان کے پروردگار نے ان کی طرف وحی بھیجی کہ ہم ان ﻇالموں کو ہی غارت کر دیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcclxiv{اور ان کے بعد ہم خود تمہیں اس زمین میں بسائیں گے۔ یہ ہے ان کے لئے جو میرے سامنے کھڑے ہونے کا ڈر رکھیں اور میری وعید سے خوفزده رہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcclxv{اور انہوں نے فیصلہ طلب کیا اور تمام سرکش ضدی لوگ نامراد ہوگئے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcclxvi{اس کے سامنے دوزخ ہے جہاں وه پیﭗ کا پانی پلایا جائے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcclxvii{جسے بمشکل گھونٹ گھونٹ پئے گا۔ پھر بھی اسے گلے سے اتار نہ سکے گا اور اسے ہر جگہ سے موت آتی دکھائی دے گی لیکن وه مرنے واﻻ نہیں۔ پھر اس کے پیچھے بھی سخت عذاب ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcclxviii{ان لوگوں کی مثال جنہوں نے اپنے پالنے والے سے کفر کیا، ان کے اعمال مثل اس راکھ کے ہیں جس پر تیز ہوا آندھی والے دن چلے۔ جو بھی انہوں نے کیا اس میں سے کسی چیز پر قادر نہ ہوں گے، یہی دور کی گمراہی ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcclxix{کیا تو نے نہیں دیکھا کہ اللہ تعالیٰ نے آسمانوں کو اور زمین کو بہترین تدبیر کے ساتھ پیدا کیا ہے۔ اگر وه چاہے تو تم سب کو فنا کردے اور نئی مخلوق ﻻئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcclxx{اللہ پر یہ کام کچھ بھی مشکل نہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcclxxi{سب کے سب اللہ کے سامنے روبرو کھڑے ہوں گے۔ اس وقت کمزور لوگ بڑائی والوں سے کہیں گے کہ ہم تو تمہارے تابعدار تھے، تو کیا تم اللہ کے عذابوں میں سے کچھ عذاب ہم سے دور کرسکنے والے ہو؟ وه جواب دیں گے کہ اگر اللہ ہمیں ہدایت دیتا تو ہم بھی ضرور تمہاری رہنمائی کرتے، اب تو ہم پر بے قراری کرنا اور صبر کرنا دونوں ہی برابر ہے ہمارے لیے کوئی چھٹکارا نہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcclxxii{جب اور کام کا فیصلہ کردیا جائے گا تو شیطان کہے گا کہ اللہ نے تو تمہیں سچا وعده دیا تھا اور میں نے تم سے جو وعدے کیے تھے ان کے خلاف کیا، میرا تم پر کوئی دباؤ تو تھا ہی نہیں، ہاں میں نے تمہیں پکارا اور تم نے میری مان لی، پس تم مجھے الزام نہ لگاؤ بلکہ خود اپنے آپ کو ملامت کرو، نہ میں تمہارا فریاد رس اور نہ تم میری فریاد کو پہنچنے والے، میں تو سرے سے مانتا ہی نہیں کہ تم مجھے اس سے پہلے اللہ کا شریک مانتے رہے، یقیناً ﻇالموں کے لیے دردناک عذاب ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiii{جو لوگ ایمان ﻻئے اور نیک عمل کیے وه ان جنتوں میں داخل کیے جائیں گے جن کے نیچے چشمے جاری ہیں جہاں انہیں ہمیشگی ہوگی اپنے رب کے حکم سے۔ جہاں ان کا خیر مقدم سلام سے ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiv{کیا آپ نے نہیں دیکھا کہ اللہ تعالیٰ نے پاکیزه بات کی مثال کس طرح بیان فرمائی، مثل ایک پاکیزه درخت کے جس کی جڑ مضبوط ہے اور جس کی ٹہنیاں آسمان میں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcclxxv{جو اپنے پروردگار کے حکم سے ہر وقت اپنے پھل ﻻتا ہے، اور اللہ تعالیٰ لوگوں کے سامنے مثالیں بیان فرماتا ہے تاکہ وه نصیحت حاصل کریں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvi{اور ناپاک بات کی مثال گندے درخت جیسی ہے جو زمین کے کچھ ہی اوپر سے اکھاڑ لیا گیا۔ اسے کچھ ﺛبات تو ہے نہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvii{ایمان والوں کو اللہ تعالیٰ پکی بات کے ساتھ مضبوط رکھتا ہے، دنیا کی زندگی میں بھی اور آخرت میں بھی، ہاں ناانصاف لوگوں کو اللہ بہکا دیتا ہے اور اللہ جو چاہے کر گزرے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcclxxviii{کیا آپ نے ان کی طرف نظر نہیں ڈالی جنہوں نے اللہ کی نعمت کے بدلے ناشکری کی اور اپنی قوم کو ہلاکت کے گھر میں ﻻ اتارا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcclxxix{یعنی دوزخ میں جس میں یہ سب جائیں گے، جو بدترین ٹھکانا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcclxxx{انہوں نے اللہ کے ہمسر بنالیے کہ لوگوں کو اللہ کی راه سے بہکائیں۔ آپ کہہ دیجئے کہ خیر مزے کرلو تمہاری بازگشت تو آخر جہنم ہی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxi{میرے ایمان والے بندوں سے کہہ دیجئے کہ نمازوں کو قائم رکھیں اور جو کچھ ہم نے انہیں دے رکھا ہے اس میں سے کچھ نہ کچھ پوشیده اور ﻇاہر خرچ کرتے رہیں اس سے پہلے کہ وه دن آجائے جس میں نہ خرید وفروخت ہوگی نہ دوستی اور محبت\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxii{اللہ وه ہے جس نے آسمانوں اور زمین کو پیدا کیا ہے اور آسمانوں سے بارش برسا کر اس کے ذریعے سے تمہاری روزی کے لیے پھل نکالے ہیں اور کشتیوں کو تمہارے بس میں کردیا ہے کہ دریاؤں میں اس کے حکم سے چلیں پھریں۔ اسی نے ندیاں اور نہریں تمہارے اختیار میں کردی ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiii{اسی نے تمہارے لیے سورج چاند کو مسخر کردیا ہے کہ برابر ہی چل رہے ہیں اور رات دن کو بھی تمہارے کام میں لگا رکھا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiv{اسی نے تمہیں تمہاری منہ مانگی کل چیزوں میں سے دے رکھا ہے۔ اگر تم اللہ کے احسان گننا چاہو تو انہیں پورے گن بھی نہیں سکتے۔ یقیناً انسان بڑا ہی بے انصاف اور ناشکرا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxv{(ابراہیم کی یہ دعا بھی یاد کرو) جب انہوں نے کہا کہ اے میرے پروردگار! اس شہر کو امن واﻻ بنادے، اور مجھے اور میری اوﻻد کو بت پرستی سے پناه دے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvi{اے میرے پالنے والے معبود! انہوں نے بہت سے لوگوں کو راه سے بھٹکا دیا ہے۔ پس میری تابعداری کرنے واﻻ میرا ہے اور جو میری نافرمانی کرے تو تو بہت ہی معاف اور کرم کرنے واﻻ ہے۔\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvii{اے ہمارے پروردگار! میں نے اپنی کچھ اوﻻد اس بے کھیتی کی وادی میں تیرے حرمت والے گھر کے پاس بسائی ہے۔ اے ہمارے پروردگار! یہ اس لیے کہ وه نماز قائم رکھیں، پس تو کچھ لوگوں کے دلوں کو ان کی طرف مائل کردے۔ اور انہیں پھلوں کی روزیاں عنایت فرما تاکہ یہ شکر گزاری کریں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxviii{اے ہمارے پروردگار! تو خوب جانتا ہے جو ہم چھپائیں اور جو ﻇاہر کریں۔ زمین و آسمان کی کوئی چیز اللہ پر پوشیده نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxix{اللہ کا شکر ہے جس نے مجھے اس بڑھاپے میں اسماعیل واسحاق (علیہما السلام) عطا فرمائے۔ کچھ شک نہیں کہ میرا پالنہار اللہ دعاؤں کا سننے واﻻ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxc{اے میرے پالنے والے! مجھے نماز کا پابند رکھ اور میری اوﻻد سے بھی، اے ہمارے رب میری دعا قبول فرما\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxci{اے ہمارے پروردگار! مجھے بخش دے اور میرے ماں باپ کو بھی بخش اور دیگر مومنوں کو بھی بخش جس دن حساب ہونے لگے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxcii{ناانصافوں کے اعمال سے اللہ کو غافل نہ سمجھ وه تو انہیں اس دن تک مہلت دیے ہوئے ہے جس دن آنکھیں پھٹی کی پھٹی ره جائیں گی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccxciii{وه اپنے سر اوپر اٹھائے دوڑ بھاگ کر رہے ہوں گے، خود اپنی طرف بھی ان کی نگاہیں نہ لوٹیں گی اور ان کے دل خالی اور اڑے ہوئے ہوں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccxciv{لوگوں کو اس دن سے ہوشیار کردے جب کہ ان کے پاس عذاب آجائے گا، اور ﻇالم کہیں گے کہ اے ہمارے رب ہمیں بہت تھوڑے قریب کے وقت تک کی ہی مہلت دے کہ ہم تیری تبلیﻎ مان لیں اور تیرے پیغمبروں کی تابعداری میں لگ جائیں۔ کیا تم اس سے پہلے بھی قسمیں نہیں کھا رہے تھے؟ کہ تمہارے لیے دنیا سے ٹلنا ہی نہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdccxcv{اور کیا تم ان لوگوں کے گھروں میں رہتے سہتے نہ تھے جنہوں نے اپنی جانوں پر ﻇلم کیا اور کیا تم پر وه معاملہ کھلا نہیں کہ ہم نے ان کے ساتھ کیسا کچھ کیا۔ ہم نے تو (تمہارے سمجھانے کو) بہت سی مثالیں بیان کردی تھیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdccxcvi{یہ اپنی اپنی چالیں چل رہے ہیں اور اللہ کو ان کی تمام چالوں کا علم ہے اور ان کی چالیں ایسی نہ تھیں کہ ان سے پہاڑ اپنی جگہ سے ٹل جائیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdccxcvii{آپ ہرگز یہ خیال نہ کریں کہ اللہ اپنے نبیوں سے وعده خلافی کرے گا، اللہ بڑا ہی غالب اور بدلہ لینے واﻻ ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdccxcviii{جس دن زمین اس زمین کے سوا اور ہی بدل دی جائے گی اور آسمان بھی، اور سب کے سب اللہ واحد غلبے والے کے روبرو ہوں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdccxcix{آپ اس دن گناه گاروں کو دیکھیں گے کہ زنجیروں میں ملے جلے ایک جگہ جکڑے ہوئے ہوں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccc{ان کے لباس گندھک کے ہوں گے اور آگ ان کے چہروں پر بھی چڑھی ہوئی ہوگی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdccci{یہ اس لیے کہ اللہ تعالیٰ ہر شخص کو اس کے کیے ہوئے اعمال کا بدلہ دے، بیشک اللہ تعالیٰ کو حساب لیتے کچھ دیر نہیں لگنے کی\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccii{یہ قرآن تمام لوگوں کے لیے اطلاع نامہ ہے کہ اس کے ذریعہ سے وه ہوشیار کر دیے جائیں اور بخوبی معلوم کرلیں کہ اللہ ایک ہی معبود ہے اور تاکہ عقلمند لوگ سوچ سمجھ لیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccciii{\basmalahur الرٰ، یہ کتاب الٰہی کی آیتیں ہیں اور کھلے اور روشن قرآن کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccciv{وه بھی وقت ہوگا کہ کافر اپنے مسلمان ہونے کی آرزو کریں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdcccv{آپ انہیں کھاتا، نفع اٹھاتا اور (جھوٹی) امیدوں میں مشغول ہوتا چھوڑ دیجئے یہ خود ابھی جان لیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdcccvi{کسی بستی کو ہم نے ہلاک نہیں کیا مگر یہ کہ اس کے لیے مقرره نوشتہ تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcccvii{کوئی گروه اپنی موت سے نہ آگے بڑھتا ہے نہ پیچھے رہتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcccviii{انہوں نے کہا کہ اے وه شخص جس پر قرآن اتارا گیا ہے یقیناً تو تو کوئی دیوانہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcccix{اگر تو سچا ہی ہے تو ہمارے پاس فرشتوں کو کیوں نہیں ﻻتا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcccx{ہم فرشتوں کو حق کے ساتھ ہی اتارتے ہیں اور اس وقت وه مہلت دیئے گئے نہیں ہوتے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcccxi{ہم نے ہی اس قرآن کو نازل فرمایا ہے اور ہم ہی اس کے محافﻆ ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcccxii{ہم نے آپ سے پہلے اگلی امتوں میں بھی اپنے رسول (برابر) بھیجے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcccxiii{اور (لیکن) جو بھی رسول آتا وه اس کا مذاق اڑاتے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcccxiv{گناه گاروں کے دلوں میں ہم اسی طرح یہی رچا دیا کرتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcccxv{وه اس پر ایمان نہیں ﻻتے اور یقیناً اگلوں کا طریقہ گزرا ہوا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcccxvi{اور اگر ہم ان پر آسمان کا دروازه کھول بھی دیں اور یہ وہاں چڑھنے بھی لگ جائیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcccxvii{تب بھی یہی کہیں گے کہ ہماری نظر بندی کر دی گئی ہے بلکہ ہم لوگوں پر جادو کر دیا گیا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcccxviii{یقیناً ہم نے آسمان میں برج بنائے ہیں اور دیکھنے والوں کے لیے اسے سجا دیا گیا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcccxix{اور اسے ہر مردود شیطان سے محفوظ رکھا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcccxx{ہاں مگر جو چوری چھپے سننے کی کوشش کرے اس کے پیچھے دہکتا ہوا (کھلا شعلہ) لگتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcccxxi{اور زمین کو ہم نے پھیلا دیا ہے اور اس پر (اٹل) پہاڑ ڈال دیئے ہیں، اور اس میں ہم نے ہر چیز ایک معین مقدار سے اگا دی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcccxxii{اور اسی میں ہم نے تمہاری روزیاں بنا دی ہیں اور جنہیں تم روزی دینے والے نہیں ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiii{اور جتنی بھی چیزیں ہیں ان سب کے خزانے ہمارے پاس ہیں، اور ہم ہر چیز کو اس کے مقرره انداز سے اتارتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiv{اور ہم بھیجتے ہیں بوجھل ہوائیں، پھر آسمان سے پانی برسا کر وه تمہیں پلاتے ہیں اور تم اس کا ذخیره کرنے والے نہیں ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcccxxv{ہم ہی جلاتے اور مارتے ہیں اور ہم ہی (بالﺂخر) وارث ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvi{اور تم میں سے آگے بڑھنے والے اور پیچھے ہٹنے والے بھی ہمارے علم میں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvii{آپ کا رب سب لوگوں کو جمع کرے گا یقیناً وه بڑی حکمتوں واﻻ بڑے علم واﻻ ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcccxxviii{یقیناً ہم نے انسان کو کالی اور سڑی ہوئی کھنکھناتی مٹی سے، پیدا فرمایا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcccxxix{اور اس سے پہلے جنات کو ہم نے لو والی آگ سے پیدا کیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcccxxx{اور جب تیرے پروردگار نے فرشتوں سے فرمایا کہ میں ایک انسان کو کالی اور سڑی ہوئی کھنکھناتی مٹی سے پیدا کرنے واﻻ ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxi{تو جب میں اسے پورا بنا چکوں اور اس میں اپنی روح پھونک دوں تو تم سب اس کے لیے سجدے میں گر پڑنا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxii{چنانچہ تمام فرشتوں نے سب کے سب نے سجده کر لیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiii{مگر ابلیس کے۔ کہ اس نے سجده کرنے والوں میں شمولیت کرنے سے (صاف) انکار کر دیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiv{(اللہ تعالیٰ نے) فرمایا اے ابلیس تجھے کیا ہوا کہ تو سجده کرنے والوں میں شامل نہ ہوا؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxv{وه بوﻻ کہ میں ایسا نہیں کہ اس انسان کو سجده کروں جسے تو نے کالی اور سڑی ہوئی کھنکھناتی مٹی سے پیدا کیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvi{فرمایا اب تو بہشت سے نکل جا کیوں کہ تو رانده درگاه ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvii{اور تجھ پر میری پھٹکار ہے قیامت کے دن تک\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxviii{کہنے لگا کہ اے میرے رب! مجھے اس دن تک کی ڈھیل دے کہ لوگ دوباره اٹھا کھڑے کیے جائیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxix{فرمایا کہ اچھا تو ان میں سے ہے جنہیں مہلت ملی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcccxl{روز مقرر کے وقت تک کی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcccxli{(شیطان نے) کہا کہ اے میرے رب! چونکہ تو نے مجھے گمراه کیا ہے مجھے بھی قسم ہے کہ میں بھی زمین میں ان کے لئے معاصی کو مزین کروں گا اور ان سب کو بہکاؤں گا بھی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcccxlii{سوائے تیرے ان بندوں کے جو منتخب کر لیے گئے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcccxliii{ارشاد ہوا کہ ہاں یہی مجھ تک پہنچنے کی سیدھی راه ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcccxliv{میرے بندوں پر تجھے کوئی غلبہ نہیں، لیکن ہاں جو گمراه لوگ تیری پیروی کریں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcccxlv{یقیناً ان سب کے وعدے کی جگہ جہنم ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvi{جس کے سات دروازے ہیں۔ ہر دروازے کے لیے ان کا ایک حصہ بٹا ہوا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvii{پرہیزگار جنتی لوگ باغوں اور چشموں میں ہوں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcccxlviii{(ان سے کہا جائے گا) سلامتی اور امن کے ساتھ اس میں داخل ہو جاؤ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcccxlix{ان کے دلوں میں جو کچھ رنجش وکینہ تھا، ہم سب کچھ نکال دیں گے، وه بھائی بھائی بنے ہوئے ایک دوسرے کے آمنے سامنے تختوں پر بیٹھے ہوں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcccl{نہ تو وہاں انہیں کوئی تکلیف چھو سکتی ہے اور نہ وه وہاں سے کبھی نکالے جائیں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcccli{میرے بندوں کو خبر دے دو کہ میں بہت ہی بخشنے واﻻ اور بڑا ہی مہربان ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccclii{اور ساتھ ہی میرے عذاب بھی نہایت دردناک ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcccliii{انہیں ابراہیم کے مہمانوں کا (بھی) حال سنا دو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccliv{کہ جب انہوں نے ان کے پاس آکر سلام کہا تو انہوں نے کہا کہ ہم کو تو تم سے ڈر لگتا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccclv{انہوں نے کہا ڈرو نہیں، ہم تجھے ایک صاحب علم فرزند کی بشارت دیتے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdccclvi{کہا، کیا اس بڑھاپے کے آجانے کے بعد تم مجھے خوشخبری دیتے ہو! یہ خوشخبری تم کیسے دے رہے ہو؟\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdccclvii{انہوں نے کہا ہم آپ کو بالکل سچی خوشخبری سناتے ہیں آپ مایوس لوگوں میں شامل نہ ہوں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdccclviii{کہا اپنے رب تعالیٰ کی رحمت سے ناامید تو صرف گمراه اور بہکے ہوئے لوگ ہی ہوتے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdccclix{پوچھا کہ اللہ کے بھیجے ہوئے (فرشتو!) تمہارا ایسا کیا اہم کام ہے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdccclx{انہوں نے جواب دیا کہ ہم مجرم قوم کی طرف بھیجے گئے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdccclxi{مگر خاندان لوط کہ ہم ان سب کو تو ضرور بچا لیں گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdccclxii{سوائے اس (لوط) کی بیوی کے کہ ہم نے اسے رکنے اور باقی ره جانے والوں میں مقرر کر دیا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdccclxiii{جب بھیجے ہوئے فرشتے آل لوط کے پاس پہنچے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdccclxiv{تو انہوں (لوط علیہ السلام) نے کہا تم لوگ تو کچھ انجان سے معلوم ہو رہے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdccclxv{انہوں نے کہا نہیں بلکہ ہم تیرے پاس وه چیز ﻻئے ہیں جس میں یہ لوگ شک شبہ کر رہے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdccclxvi{ہم تو تیرے پاس (صریح) حق ﻻئے ہیں اور ہیں بھی بالکل سچے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdccclxvii{اب تو اپنے خاندان سمیت اس رات کے کسی حصہ میں چل دے اور آپ ان کے پیچھے رہنا، اور (خبردار) تم میں سے کوئی (پیچھے) مڑکر بھی نہ دیکھے اور جہاں کا تمہیں حکم کیا جارہا ہے وہاں چلے جانا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdccclxviii{اور ہم نے اس کی طرف اس بات کا فیصلہ کر دیا کہ صبح ہوتے ہوتے ان لوگوں کی جڑیں کاٹ دی جائیں گی\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdccclxix{اور شہر والے خوشیاں مناتے ہوئے آئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdccclxx{(لوط علیہ السلام نے) کہا یہ لوگ میرے مہمان ہیں تم مجھے رسوا نہ کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdccclxxi{اللہ تعالیٰ سے ڈرو اور مجھے رسوا نہ کرو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdccclxxii{وه بولے کیا ہم نے تجھے دنیا بھر (کی ٹھیکیداری) سے منع نہیں کر رکھا؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiii{(لوط علیہ السلام نے) کہا اگر تمہیں کرنا ہی ہے تو یہ میری بچیاں موجود ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiv{تیری عمر کی قسم! وه تو اپنی بدمستی میں سرگرداں تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdccclxxv{پس سورج نکلتے نکلتے انہیں ایک بڑے زور کی آواز نے پکڑ لیا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvi{بالﺂخر ہم نے اس شہر کو اوپر تلے کر دیا اور ان لوگوں پر کنکر والے پتھر برسائے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvii{بلاشبہ بصیرت والوں کے لیے اس میں بہت سی نشانیاں ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdccclxxviii{یہ بستی ایسی راه پر ہے جو برابر چلتی رہتی (عام گذرگاه) ہے۔\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdccclxxix{اور اس میں ایمان والوں کے لیے بڑی نشانی ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdccclxxx{اَیکَہ بستی کے رہنے والے بھی بڑے ﻇالم تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxi{جن سے (آخر) ہم نے انتقام لے ہی لیا۔ یہ دونوں شہر کھلے (عام) راستے پر ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxii{اور حِجر والوں نے بھی رسولوں کو جھٹلایا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiii{اور ہم نے ان کو اپنی نشانیاں بھی عطا فرمائیں (لیکن) تاہم وه ان سے روگردانی ہی کرتے رہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiv{یہ لوگ پہاڑوں کو تراش تراش کر گھر بناتے تھے، بے خوف ہوکر\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxv{آخر انہیں بھی صبح ہوتے ہوتے چنگھاڑنے آدبوچا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvi{پس ان کی کسی تدبیروعمل نے انہیں کوئی فائده نہ دیا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvii{ہم نے آسمانوں اور زمین کو اور ان کے درمیان کی سب چیزوں کو حق کے ساتھ ہی پیدا فرمایا ہے، اور قیامت ضرور ضرور آنے والی ہے۔ پس تو حسن وخوبی (اور اچھائی) سے درگزر کر لے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxviii{یقیناً تیرا پروردگار ہی پیدا کرنے واﻻ اور جاننے واﻻ ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxix{یقیناً ہم نے آپ کو سات آیتیں دے رکھی ہیں کہ دہرائی جاتی ہیں اور عظیم قرآن بھی دے رکھا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdcccxc{آپ ہر گز اپنی نظریں اس چیز کی طرف نہ دوڑائیں، جس سے ہم نے ان میں سے کئی قسم کے لوگوں کو بہره مند کر رکھا ہے، نہ ان پر آپ افسوس کریں اور مومنوں کے لیے اپنے بازو جھکائے رہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdcccxci{اور کہہ دیجئے کہ میں تو کھلم کھلا ڈرانے واﻻ ہوں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdcccxcii{جیسے کہ ہم نے ان تقسیم کرنے والوں پر اتارا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdcccxciii{جنہوں نے اس کتاب الٰہی کے ٹکڑے ٹکڑے کر دیئے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdcccxciv{قسم ہے تیرے پالنے والے کی! ہم ان سب سے ضرور باز پرس کریں گے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdcccxcv{ہر اس چیز کی جو وه کرتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvi{پس آپ اس حکم کو جو آپ کو کیا جارہا ہے کھول کر سنا دیجئے! اور مشرکوں سے منھ پھیر لیجئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvii{آپ سے جو لوگ مسخراپن کرتے ہیں ان کی سزا کے لیے ہم کافی ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcccxcviii{جو اللہ کے ساتھ دوسرے معبود مقرر کرتے ہیں انہیں عنقریب معلوم ہو جائے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcccxcix{ہمیں خوب علم ہے کہ ان کی باتوں سے آپ کا دل تنگ ہوتا ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcm{آپ اپنے پروردگار کی تسبیح اور حمد بیان کرتے رہیں اور سجده کرنے والوں میں شامل ہو جائیں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcmi{اور اپنے رب کی عبادت کرتے رہیں یہاں تک کہ آپ کو موت آجائے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcmii{\basmalahur اللہ تعالیٰ کا حکم آپہنچا، اب اس کی جلدی نہ مچاؤ۔ تمام پاکی اس کے لیے ہے وه برتر ہے ان سب سے جنہیں یہ اللہ کے نزدیک شریک بتلاتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcmiii{وہی فرشتوں کو اپنی وحی دے کر اپنے حکم سے اپنے بندوں میں سے جس پر چاہتا ہے اتارتا ہے کہ تم لوگوں کو آگاه کر دو کہ میرے سوا اور کوئی معبود نہیں، پس تم مجھ سے ڈرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcmiv{اسی نے آسمانوں اور زمین کو حق کے ساتھ پیدا کیا وه اس سے بری ہے جو مشرک کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcmv{اس نے انسان کو نطفے سے پیدا کیا پھر وه صریح جھگڑالو بن بیٹھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcmvi{اسی نے چوپائے پیدا کیے جن میں تمہارے لیے گرمی کے لباس ہیں اور بھی بہت سے نفع ہیں اور بعض تمہارے کھانے کے کام آتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcmvii{اور ان میں تمہاری رونق بھی ہے جب چرا کر ﻻؤ تب بھی اور جب چرانے لے جاؤ تب بھی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcmviii{اور وه تمہارے بوجھ ان شہروں تک اٹھالے جاتے ہیں جہاں تم بغیر آدھی جان کیے پہنچ ہی نہیں سکتے تھے۔ یقیناً تمہارا رب بڑا ہی شفیق اور نہایت مہربان ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcmix{گھوڑوں کو، خچروں کو، گدھوں کو اس نے پیدا کیا کہ تم ان کی سواری لو اور وه باعﺚ زینت بھی ہیں۔ اور بھی وه ایسی بہت چیزیں پیدا کرتا ہے جن کا تمہیں علم بھی نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcmx{اور اللہ پر سیدھی راه کا بتا دینا ہے اور بعض ٹیڑھی راہیں ہیں، اور اگر وه چاہتا تو تم سب کو راه راست پر لگا دیتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcmxi{وہی تمہارے فائدے کے لیے آسمان سے پانی برساتا ہے جسے تم پیتے بھی ہو اور اسی سے اگے ہوئے درختوں کو تم اپنے جانوروں کو چراتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcmxii{اسی سے وه تمہارے لیے کھیتی اور زیتون اور کھجور اور انگور اور ہر قسم کے پھل اگاتا ہے بےشک ان لوگوں کے لیے تو اس میں بڑی نشانی ہے جو غوروفکر کرتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcmxiii{اسی نے رات دن اور سورج چاند کو تمہارے لیے تابع کر دیا ہے اور ستارے بھی اسی کے حکم کے ماتحت ہیں۔ یقیناًاس میں عقلمند لوگوں کے لیے کئی ایک نشانیاں موجود ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcmxiv{اور بھی بہت سی چیزیں طرح طرح کے رنگ روپ کی اس نے تمہارے لیے زمین پر پھیلا رکھی ہیں۔ بیشک نصیحت قبول کرنے والوں کے لیے اس میں بڑی بھاری نشانی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcmxv{اور دریا بھی اسی نے تمہارے بس میں کر دیے ہیں کہ تم اس میں سے (نکلا ہوا) تازه گوشت کھاؤ اور اس میں سے اپنے پہننے کے زیورات نکال سکو اور تم دیکھتے ہو کہ کشتیاں اس میں پانی چیرتی ہوئی (چلتی) ہیں اور اس لیے بھی کہ تم اس کا فضل تلاش کرو اور ہوسکتا ہے کہ تم شکر گزاری بھی کرو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcmxvi{اور اس نے زمین میں پہاڑ گاڑ دیے ہیں تاکہ تمہیں لے کر ہلے نہ، اور نہریں اور راہیں بنا دیں تاکہ تم منزل مقصود کو پہنچو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcmxvii{اور بھی بہت سی نشانیاں مقرر فرمائیں۔ اور ستاروں سے بھی لوگ راه حاصل کرتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcmxviii{تو کیا وه جو پیدا کرتا ہے اس جیسا ہے جو پیدا نہیں کرسکتا؟ کیا تم بالکل نہیں سوچتے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcmxix{اور اگر تم اللہ کی نعمتوں کا شمار کرنا چاہو تو تم اسے نہیں کر سکتے۔ بیشک اللہ بڑا بخشنے واﻻ مہربان ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcmxx{اور جو کچھ تم چھپاؤ اور ﻇاہر کرو اللہ تعالیٰ سب کچھ جانتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcmxxi{اور جن جن کو یہ لوگ اللہ تعالیٰ کے سوا پکارتے ہیں وه کسی چیز کو پیدا نہیں کرسکتے، بلکہ وه خود پیدا کیے ہوئے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcmxxii{مردے ہیں زنده نہیں، انہیں تو یہ بھی شعور نہیں کہ کب اٹھائے جائیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcmxxiii{تم سب کا معبود صرف اللہ تعالیٰ اکیلا ہے اور آخرت پر ایمان نہ رکھنے والوں کے دل منکر ہیں اور وه خود تکبر سے بھرے ہوئے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcmxxiv{بےشک وشبہ اللہ تعالیٰ ہر اس چیز کو، جسے وه لوگ چھپاتے ہیں اور جسے ﻇاہر کرتے ہیں، بخوبی جانتا ہے۔ وه غرور کرنے والوں کو پسند نہیں فرماتا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcmxxv{ان سے جب دریافت کیا جاتا ہے کہ تمہارے پروردگار نے کیا نازل فرمایا ہے؟ تو جواب دیتے ہیں کہ اگلوں کی کہانیاں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcmxxvi{اسی کا نتیجہ ہوگا کہ قیامت کے دن یہ لوگ اپنے پورے بوجھ کے ساتھ ہی ان کے بوجھ کے بھی حصے دار ہوں گے جنہیں بے علمی سے گمراه کرتے رہے۔ دیکھو تو کیسا برا بوجھ اٹھا رہے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcmxxvii{ان سے پہلے کے لوگوں نے بھی مکر کیا تھا، (آخر) اللہ نے (ان کے منصوبوں) کی عمارتوں کو جڑوں سے اکھیڑ دیا اور ان (کے سروں) پر (ان کی) چھتیں اوپر سے گر پڑیں، اور ان کے پاس عذاب وہاں سے آگیا جہاں کا انہیں وہم وگمان بھی نہ تھا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcmxxviii{پھر قیامت والے دن بھی اللہ تعالیٰ انہیں رسوا کرے گا اور فرمائے گا کہ میرے وه شریک کہاں ہیں جن کے بارے میں تم لڑتے جھگڑتے تھے، جنہیں علم دیا گیا تھا وه پکار اٹھیں گے کہ آج تو کافروں کو رسوائی اور برائی چمٹ گئی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcmxxix{وه جو اپنی جانوں پر ﻇلم کرتے ہیں، فرشتے جب ان کی جان قبض کرنے لگتے ہیں اس وقت وه جھک جاتے ہیں کہ ہم برائی نہیں کرتے تھے۔ کیوں نہیں؟ اللہ تعالیٰ خوب جاننے واﻻ ہے جو کچھ تم کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcmxxx{پس اب تو ہمیشگی کے طور پر تم جہنم کے دروازوں میں داخل ہو جاؤ، پس کیا ہی برا ٹھکانا ہے غرور کرنے والوں کا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcmxxxi{اور پرہیز گاروں سے پوچھا جاتا ہے کہ تمہارے پروردگار نے کیا نازل فرمایا ہے؟ تو وه جواب دیتے ہیں کہ اچھے سے اچھا۔ جن لوگوں نے بھلائی کی ان کے لیے اس دنیا میں بھلائی ہے، اور یقیناً آخرت کا گھر تو بہت ہی بہتر ہے، اور کیا ہی خوب پرہیز گاروں کا گھر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcmxxxii{ہمیشگی والے باغات جہاں وه جائیں گے جن کے نیچے نہریں بہہ رہی ہیں، جو کچھ یہ طلب کریں گے وہاں ان کے لیے موجود ہوگا۔ پرہیز گاروں کو اللہ تعالیٰ اسی طرح بدلے عطا فرماتا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiii{وه جن کی جانیں فرشتے اس حال میں قبض کرتے ہیں کہ وه پاک صاف ہوں کہتے ہیں کہ تمہارے لیے سلامتی ہی سلامتی ہے، جاؤ جنت میں اپنے ان اعمال کے بدلے جو تم کرتے تھے۔\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiv{کیا یہ اسی بات کا انتظار کر رہے ہیں کہ ان کے پاس فرشتے آجائیں یا تیرے رب کا حکم آجائے؟ ایسا ہی ان لوگوں نے بھی کیا تھا جو ان سے پہلے تھے۔ ان پر اللہ تعالیٰ نے کوئی ﻇلم نہیں کیا بلکہ وه خود اپنی جانوں پر ﻇلم کرتے رہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcmxxxv{پس ان کے برے اعمال کے نتیجے انہیں مل گئے اور جس کی ہنسی اڑاتے تھے اس نے ان کو گھیر لیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvi{مشرک لوگوں نے کہا کہ اگر اللہ تعالیٰ چاہتا تو ہم اور ہمارے باپ دادے اس کے سوا کسی اور کی عبادت ہی نہ کرتے، نہ اس کے فرمان کے بغیر کسی چیز کو حرام کرتے۔ یہی فعل ان سے پہلے کے لوگوں کا رہا۔ تو رسولوں پر تو صرف کھلم کھلا پیغام کا پہنچا دینا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvii{ہم نے ہر امت میں رسول بھیجا کہ (لوگو!) صرف اللہ کی عبادت کرو اور اس کے سوا تمام معبودوں سے بچو۔ پس بعض لوگوں کو تو اللہ تعالیٰ نے ہدایت دی اور بعض پر گمراہی ﺛابت ہوگئی، پس تم خود زمین میں چل پھر کر دیکھ لو کہ جھٹلانے والوں کا انجام کیسا کچھ ہوا؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcmxxxviii{گو آپ ان کی ہدایت کے خواہش مند رہے ہیں لیکن اللہ تعالیٰ اسے ہدایت نہیں دیتا جسے گمراه کر دے اور نہ ان کا کوئی مددگار ہوتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcmxxxix{وه لوگ بڑی سخت سخت قسمیں کھا کھا کر کہتے ہیں کہ مردوں کو اللہ تعالیٰ زنده نہیں کرے گا۔ کیوں نہیں ضرور زنده کرے گا یہ تو اس کا برحق ﻻزمی وعده ہے، لیکن اکثر لوگ جانتے نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcmxl{اس لیے بھی کہ یہ لوگ جس چیز میں اختلاف کرتے تھے اسے اللہ تعالیٰ صاف بیان کر دے اور اس لیے بھی کہ خود کافر اپنا جھوٹا ہونا جان لیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcmxli{ہم جب کسی چیز کا اراده کرتے ہیں تو صرف ہمارا یہ کہہ دینا ہوتا ہے کہ ہوجا، پس وه ہوجاتی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcmxlii{جن لوگوں نے ﻇلم برداشت کرنے کے بعد اللہ کی راه میں ترک وطن کیا ہے ہم انہیں بہتر سے بہتر ٹھکانا دنیا میں عطا فرمائیں گے اور آخرت کا ﺛواب تو بہت ہی بڑا ہے، کاش کہ لوگ اس سے واقف ہوتے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcmxliii{وه جنہوں نے دامن صبر نہ چھوڑا اور اپنے پالنے والے ہی پر بھروسہ کرتے رہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcmxliv{آپ سے پہلے بھی ہم مَردوں کو ہی بھیجتے رہے، جن کی جانب وحی اتارا کرتے تھے پس اگر تم نہیں جانتے تو اہل علم سے دریافت کر لو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcmxlv{دلیلوں اور کتابوں کے ساتھ، یہ ذکر (کتاب) ہم نے آپ کی طرف اتارا ہے کہ لوگوں کی جانب جو نازل فرمایا گیا ہے آپ اسے کھول کھول کر بیان کر دیں، شاید کہ وه غور وفکر کریں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcmxlvi{بدترین داؤ پیچ کرنے والے کیا اس بات سے بے خوف ہوگئے ہیں کہ اللہ تعالیٰ انہیں زمین میں دھنسا دے یا ان کے پاس ایسی جگہ سے عذاب آجائے جہاں کا انہیں وہم وگمان بھی نہ ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcmxlvii{یا انہیں چلتے پھرتے پکڑ لے۔ یہ کسی صورت میں اللہ تعالیٰ کو عاجز نہیں کر سکتے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcmxlviii{یا انہیں ڈرا دھمکا کر پکڑ لے، پس یقیناً تمہارا پروردگار اعلیٰ شفقت اور انتہائی رحم واﻻ ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcmxlix{کیا انہوں نے اللہ کی مخلوق میں سے کسی کو بھی نہیں دیکھا؟ کہ اس کے سائے دائیں بائیں جھک جھک کر اللہ تعالیٰ کے سامنے سر بسجود ہوتے اور عاجزی کا اﻇہار کرتے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcml{یقیناً آسمان وزمین کے کل جاندار اور تمام فرشتے اللہ تعالیٰ کے سامنے سجدے کرتے ہیں اور ذرا بھی تکبر نہیں کرتے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcmli{اور اپنے رب سے جو ان کے اوپر ہے، کپکپاتے رہتے ہیں اور جو حکم مل جائے اس کی تعمیل کرتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcmlii{اللہ تعالیٰ ارشاد فرما چکا ہے کہ دو معبود نہ بناؤ۔ معبود تو صرف وہی اکیلا ہے، پس تم سب صرف میرا ہی ڈر خوف رکھو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcmliii{آسمانوں میں اور زمین میں جو کچھ ہے سب اسی کا ہے اور اسی کی عبادت ﻻزم ہے، کیا پھر تم اس کے سوا اوروں سے ڈرتے ہو؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcmliv{تمہارے پاس جتنی بھی نعمتیں ہیں سب اسی کی دی ہوئی ہیں، اب بھی جب تمہیں کوئی مصیبت پیش آجائے تو اسی کی طرف نالہ وفریاد کرتے ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcmlv{اور جہاں اس نے وه مصیبت تم سے دفع کر دی تم میں سے کچھ لوگ اپنے رب کے ساتھ شرک کرنے لگ جاتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcmlvi{کہ ہماری دی ہوئی نعمتوں کی ناشکری کریں۔ اچھا کچھ فائده اٹھالو آخر کار تمہیں معلوم ہو ہی جائے گا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcmlvii{اور جسے جانتے بوجھتے بھی نہیں اس کا حصہ ہماری دی ہوئی روزی میں سے مقرر کرتے ہیں، واللہ تمہارے اس بہتان کا سوال تم سے ضرور ہی کیا جائے گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcmlviii{اور وه اللہ سبحانہ وتعالیٰ کے لیے لڑکیاں مقرر کرتے ہیں اور اپنے لیے وه جو اپنی خواہش کے مطابق ہو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcmlix{ان میں سے جب کسی کو لڑکی ہونے کی خبر دی جائے تو اس کا چہره سیاه ہو جاتا ہے اور دل ہی دل میں گھٹنے لگتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcmlx{اس بری خبر کی وجہ سے لوگوں سے چھپا چھپا پھرتا ہے۔ سوچتا ہے کہ کیا اس کو ذلت کے ساتھ لئے ہوئے ہی رہے یا اسے مٹی میں دبا دے، آه! کیا ہی برے فیصلے کرتے ہیں؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcmlxi{آخرت پر ایمان نہ رکھنے والوں کی ہی بری مثال ہے، اللہ کے لیے تو بہت ہی بلند صفت ہے، وه بڑا ہی غالب اور باحکمت ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcmlxii{اگر لوگوں کے گناه پر اللہ تعالیٰ ان کی گرفت کرتا تو روئے زمین پر ایک بھی جاندار باقی نہ رہتا، لیکن وه تو انہیں ایک وقت مقرر تک ڈھیل دیتا ہے، جب ان کا وه وقت آجاتا ہے تو وه ایک ساعت نہ پیچھے ره سکتے ہیں اور نہ آگے بڑھ سکتے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcmlxiii{اور وه اپنے لیے جو ناپسند رکھتے ہیں اللہ کے لیے ﺛابت کرتے ہیں اور ان کی زبانیں جھوٹی باتیں بیان کرتی ہیں کہ ان کے لیے خوبی ہے۔ نہیں نہیں، دراصل ان کے لیے آگ ہے اور یہ دوزخیوں کے پیش رو ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcmlxiv{واللہ! ہم نے تجھ سے پہلے کی امتوں کی طرف بھی اپنے رسول بھیجے لیکن شیطان نے ان کے اعمال بد ان کی نگاہوں میں آراستہ کر دیئے، وه شیطان آج بھی ان کا رفیق بنا ہوا ہے اور ان کے لیے درد ناک عذاب ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcmlxv{اس کتاب کو ہم نے آپ پر اس لیے اتارا ہے کہ آپ ان کے لیے ہر اس چیز کو واضح کر دیں جس میں وه اختلاف کر رہے ہیں اور یہ ایمان والوں کے لیے رہنمائی اور رحمت ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcmlxvi{اور اللہ آسمان سے پانی برسا کر اس سے زمین کو اس کی موت کے بعد زنده کر دیتا ہے۔ یقیناً اس میں ان لوگوں کے لیے نشانی ہے جو سنیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcmlxvii{تمہارے لیے تو چوپایوں میں بھی بڑی عبرت ہے کہ ہم تمہیں اس کے پیٹ میں جو کچھ ہے اسی میں سے گوبر اور لہو کے درمیان سے خالص دودھ پلاتے ہیں جو پینے والوں کے لیے سہتا پچتا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcmlxviii{اور کھجور اور انگور کے درختوں کے پھلوں سے تم شراب بنا لیتے ہو اور عمده روزی بھی۔ جو لوگ عقل رکھتے ہیں ان کے لیے تو اس میں بہت بڑی نشانی ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcmlxix{آپ کے رب نے شہد کی مکھی کے دل میں یہ بات ڈال دی کہ پہاڑوں میں درختوں اور لوگوں کی بنائی ہوئی اونچی اونچی ٹٹیوں میں اپنے گھر (چھتے) بنا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcmlxx{اور ہر طرح کے میوے کھا اور اپنے رب کی آسان راہوں میں چلتی پھرتی ره، ان کے پیٹ سے رنگ برنگ کا مشروب نکلتا ہے، جس کے رنگ مختلف ہیں اور جس میں لوگوں کے لیے شفا ہے غوروفکر کرنے والوں کے لیے اس میں بھی بہت بڑی نشانی ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcmlxxi{اللہ تعالیٰ نے ہی تم سب کو پیدا کیا ہے وہی پھر تمہیں فوت کرے گا، تم میں ایسے بھی ہیں جو بدترین عمر کی طرف لوٹائے جاتے ہیں کہ بہت کچھ جاننے بوجھنے کے بعد بھی نہ جانیں۔ بیشک اللہ دانا اور توانا ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcmlxxii{اللہ تعالیٰ ہی نے تم میں سے ایک کو دوسرے پر روزی میں زیادتی دے رکھی ہے، پس جنہیں زیادتی دی گئی ہے وه اپنی روزی اپنے ماتحت غلاموں کو نہیں دیتے کہ وه اور یہ اس میں برابر ہو جائیں، تو کیا یہ لوگ اللہ کی نعمتوں کے منکر ہو رہے ہیں؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiii{اللہ تعالیٰ نے تمہارے لیے تم میں سے ہی تمہاری بیویاں پیدا کیں اور تمہاری بیویوں سے تمہارے لیے تمہارے بیٹے اور پوتے پیدا کیے اور تمہیں اچھی اچھی چیزیں کھانے کو دیں۔ کیا پھر بھی لوگ باطل پر ایمان ﻻئیں گے؟ اور اللہ تعالیٰ کی نعمتوں کی ناشکری کریں گے؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiv{اور وه اللہ تعالیٰ کے سوا ان کی عبادت کرتے ہیں جو آسمانوں اور زمین سے انہیں کچھ بھی تو روزی نہیں دے سکتے اور نہ کچھ قدرت رکھتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcmlxxv{پس اللہ تعالیٰ کے لیے مثالیں مت بناؤ اللہ تعالیٰ خوب جانتا ہے اور تم نہیں جانتے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvi{اللہ تعالیٰ ایک مثال بیان فرماتا ہے کہ ایک غلام ہے دوسرے کی ملکیت کا، جو کسی بات کا اختیار نہیں رکھتا اور ایک اور شخص ہے جسے ہم نے اپنے پاس سے معقول روزی دے رکھی ہے، جس میں سے وه چھپے کھلے خرچ کرتا ہے۔ کیا یہ سب برابر ہوسکتے ہیں؟ اللہ تعالیٰ ہی کے لیے سب تعریف ہے، بلکہ ان میں سے اکثر نہیں جانتے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvii{اللہ تعالیٰ ایک اور مثال بیان فرماتا ہے، دو شخصوں کی، جن میں سے ایک تو گونگا ہے اور کسی چیز پر اختیار نہیں رکھتا بلکہ وه اپنے مالک پر بوجھ ہے کہیں بھی اسے بھیجے وه کوئی بھلائی نہیں ﻻتا، کیا یہ اور وه جو عدل کا حکم دیتا ہے اور ہے بھی سیدھی راه پر، برابر ہوسکتے ہیں؟\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcmlxxviii{آسمانوں اور زمین کا غیب صرف اللہ تعالیٰ ہی کو معلوم ہے۔ اور قیامت کا امر تو ایسا ہی ہے جیسے آنکھ کا جھپکنا، بلکہ اس سے بھی زیاده قریب۔ بیشک اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcmlxxix{اللہ تعالیٰ نے تمہیں تمہاری ماؤں کے پیٹوں سے نکالا ہے کہ اس وقت تم کچھ بھی نہیں جانتے تھے، اسی نے تمہارے کان اور آنکھیں اور دل بنائے کہ تم شکر گزاری کرو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcmlxxx{کیا ان لوگوں نے پرندوں کو نہیں دیکھا جو تابع فرمان ہو کر فضا میں ہیں، جنہیں بجز اللہ تعالیٰ کے کوئی اور تھامے ہوئے نہیں، بیشک اس میں ایمان ﻻنے والے لوگوں کے لیے بڑی نشانیاں ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxi{اور اللہ تعالیٰ نے تمہارے لیے تمہارے گھروں میں سکونت کی جگہ بنا دی ہے اور اسی نے تمہارے لیے چوپایوں کی کھالوں کے گھر بنا دیے ہیں، جنہیں تم ہلکا پھلکا پاتے ہو اپنے کوچ کے دن اور اپنے ٹھہرنے کے دن بھی، اور ان کی اون اور روؤں اور بالوں سے بھی اس نے بہت سے سامان اور ایک وقت مقرره تک کے لیے فائده کی چیزیں بنائیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxii{اللہ ہی نے تمہارے لیے اپنی پیدا کرده چیزوں میں سے سائے بنائے ہیں اور اسی نے تمہارے لیے پہاڑوں میں غار بنائے ہیں اور اسی نے تمہارے لیے کرتے بنائے ہیں جو تمہیں گرمی سے بچائیں اور ایسے کرتے بھی جو تمہیں لڑائی کے وقت کام آئیں۔ وه اسی طرح اپنی پوری پوری نعمتیں دے رہا ہے کہ تم حکم بردار بن جاؤ\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiii{پھر بھی اگر یہ منھ موڑے رہیں تو آپ پر صرف کھول کر تبلیﻎ کر دینا ہی ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiv{یہ اللہ کی نعمتیں جانتے پہچانتے ہوئے بھی ان کے منکر ہو رہے ہیں، بلکہ ان میں سے اکثر ناشکرے ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxv{اور جس دن ہم ہر امت میں سے گواه کھڑا کریں گے پھر کافروں کو نہ اجازت دی جائے گی اور نہ ان سے توبہ کرنے کو کہا جائے گا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvi{اور جب یہ ﻇالم عذاب دیکھ لیں گے پھر نہ تو ان سے ہلکا کیا جائے گا اور نہ وه ڈھیل دیے جائیں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvii{اور جب مشرکین اپنے شریکوں کو دیکھ لیں گے تو کہیں گے اے ہمارے پروردگار! یہی ہمارے وه شریک ہیں جنہیں ہم تجھے چھوڑ کر پکارا کرتے تھے، پس وه انہیں جواب دیں گے کہ تم بالکل ہی جھوٹے ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxviii{اس دن وه سب (عاجز ہوکر) اللہ کے سامنے اطاعت کا اقرار پیش کریں گے اور جو بہتان بازی کیا کرتے تھے وه سب ان سے گم ہو جائے گی\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxix{جنہوں نے کفر کیا اور اللہ کی راه سے روکا ہم انہیں عذاب پر عذاب بڑھاتے جائیں گے، یہ بدلہ ہوگا ان کی فتنہ پردازیوں کا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcmxc{اور جس دن ہم ہر امت میں انہی میں سے ان کے مقابلے پر گواه کھڑا کریں گے اور تجھے ان سب پر گواه بنا کر ﻻئیں گے اور ہم نے تجھ پر یہ کتاب نازل فرمائی ہے جس میں ہر چیز کا شافی بیان ہے، اور ہدایت اور رحمت اور خوشخبری ہے مسلمانوں کے لیے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcmxci{اللہ تعالیٰ عدل کا، بھلائی کا اور قرابت داروں کے ساتھ سلوک کرنے کا حکم دیتا ہے اور بےحیائی کے کاموں، ناشائستہ حرکتوں اور ﻇلم وزیادتی سے روکتا ہے، وه خود تمہیں نصیحتیں کر رہا ہے کہ تم نصیحت حاصل کرو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcmxcii{اور اللہ کے عہد کو پورا کرو جب کہ تم آپس میں قول وقرار کرو اور قسموں کو ان کی پختگی کے بعد مت توڑو، حاﻻنکہ تم اللہ تعالیٰ کو اپنا ضامن ٹھہرا چکے ہو، تم جو کچھ کرتے ہو اللہ اس کو بخوبی جان رہا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcmxciii{اور اس عورت کی طرح نہ ہو جاؤ جس نے اپنا سوت مضبوط کاتنے کے بعد ٹکڑے ٹکڑے کرکے توڑ ڈاﻻ، کہ تم اپنی قسموں کو آپس کے مکر کا باعﺚ ٹھراؤ، اس لیے کہ ایک گروه دوسرے گروه سے بڑھا چڑھا ہوجائے۔ بات صرف یہی ہے کہ اس عہد سے اللہ تمہیں آزما رہا ہے۔ یقیناً اللہ تعالیٰ تمہارے لیے قیامت کے دن ہر اس چیز کو کھول کر بیان کر دے گا جس میں تم اختلاف کر رہے تھے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcmxciv{اگر اللہ چاہتا تم سب کو ایک ہی گروه بنا دیتا لیکن وه جسے چاہے گمراه کرتا ہے اور جسے چاہے ہدایت دیتا ہے، یقیناً تم جو کچھ کر رہے ہو اس کے بارے میں باز پرس کی جانے والی ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcmxcv{اور تم اپنی قسموں کو آپس کی دغابازی کا بہانہ نہ بناؤ۔ پھر تو تمہارے قدم اپنی مضبوطی کے بعد ڈگمگا جائیں گے اور تمہیں سخت سزا برداشت کرنا پڑے گی کیونکہ تم نے اللہ کی راه سے روک دیا اور تمہیں بڑا سخت عذاب ہوگا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcmxcvi{تم اللہ کے عہد کو تھوڑے مول کے بدلے نہ بیچ دیا کرو۔ یاد رکھو اللہ کے پاس کی چیز ہی تمہارے لیے بہتر ہے بشرطیکہ تم میں علم ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcmxcvii{تمہارے پاس جو کچھ ہے سب فانی ہے اور اللہ تعالیٰ کے پاس جو کچھ ہے باقی ہے۔ اور صبر کرنے والوں کو ہم بھلے اعمال کا بہترین بدلہ ضرور عطا فرمائیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcmxcviii{جو شخص نیک عمل کرے مرد ہو یا عورت، لیکن باایمان ہو تو ہم اسے یقیناً نہایت بہتر زندگی عطا فرمائیں گے۔ اور ان کے نیک اعمال کا بہتر بدلہ بھی انہیں ضرور ضرور دیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcmxcix{قرآن پڑھنے کے وقت راندے ہوئے شیطان سے اللہ کی پناه طلب کرو\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mm{ایمان والوں اور اپنے پروردگار پر بھروسہ رکھنے والوں پر اس کا زور مطلقاً نہیں چلتا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmi{ہاں اس کا غلبہ ان پر تو یقیناً ہے جو اسی سے رفاقت کریں اور اسے اللہ کا شریک ٹھہرائیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmii{اور جب ہم کسی آیت کی جگہ دوسری آیت بدل دیتے ہیں اور جو کچھ اللہ تعالیٰ نازل فرماتا ہے اسے وه خوب جانتا ہے تو یہ کہتے ہیں کہ تو تو بہتان باز ہے۔ بات یہ ہے کہ ان میں سے اکثر جانتے ہی نہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmiii{کہہ دیجئے کہ اسے آپ کے رب کی طرف سے جبرائیل حق کے ساتھ لے کر آئے ہیں تاکہ ایمان والوں کو اللہ تعالیٰ استقامت عطا فرمائے اور مسلمانوں کی رہنمائی اور بشارت ہو جائے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmiv{ہمیں بخوبی علم ہے کہ یہ کافر کہتے ہیں کہ اسے تو ایک آدمی سکھاتا ہے اس کی زبان جس کی طرف یہ نسبت کر رہے ہیں عجمی ہے اور یہ قرآن تو صاف عربی زبان میں ہے۔\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmv{جو لوگ اللہ تعالیٰ کی آیتوں پر ایمان نہیں رکھتے انہیں اللہ کی طرف سے بھی رہنمائی نہیں ہوتی اور ان کے لیے المناک عذاب ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmvi{جھوٹ افترا تو وہی باندھتے ہیں جنہیں اللہ تعالیٰ کی آیتوں پر ایمان نہیں ہوتا۔ یہی لوگ جھوٹے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmvii{جو شخص اپنے ایمان کے بعد اللہ سے کفر کرے بجز اس کے جس پر جبر کیا جائے اور اس کا دل ایمان پر برقرار ہو، مگر جو لوگ کھلے دل سے کفر کریں تو ان پر اللہ کا غضب ہے اور انہی کے لیے بہت بڑا عذاب ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmviii{یہ اس لیے کہ انہوں نے دنیا کی زندگی کو آخرت سے زیاده محبوب رکھا۔ یقیناً اللہ تعالیٰ کافر لوگوں کو راه راست نہیں دکھاتا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmix{یہ وه لوگ ہیں جن کے دلوں پر اور جن کے کانوں پر اور جن کی آنکھوں پر اللہ نے مہر لگا دی ہے اور یہی لوگ غافل ہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmx{کچھ شک نہیں کہ یہی لوگ آخرت میں سخت نقصان اٹھانے والے ہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmxi{جن لوگوں نے فتنوں میں ڈالے جانے کے بعد ہجرت کی پھر جہاد کیا اور صبر کا ﺛبوت دیا بیشک تیرا پروردگار ان باتوں کے بعد انہیں بخشنے واﻻ اور مہربانیاں کرنے واﻻ ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmxii{جس دن ہر شخص اپنی ذات کے لیے لڑتا جھگڑتا آئے اور ہر شخص کو اس کے کیے ہوئے اعمال کا پورا بدلہ دیا جائے گا اور لوگوں پر (مطلقاً) ﻇلم نہ کیا جائے گا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmxiii{اللہ تعالیٰ اس بستی کی مثال بیان فرماتا ہے جو پورے امن واطمینان سے تھی اس کی روزی اس کے پاس بافراغت ہر جگہ سے چلی آرہی تھی۔ پھر اس نے اللہ تعالیٰ کی نعمتوں کا کفر کیا تو اللہ تعالیٰ نے اسے بھوک اور ڈر کا مزه چکھایا جو بدلہ تھا ان کے کرتوتوں کا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmxiv{ان کے پاس انہی میں سے رسول پہنچا پھر بھی انہوں نے اسے جھٹلایا پس انہیں عذاب نے آدبوچا اور وه تھے ہی ﻇالم\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmxv{جو کچھ حلال اور پاکیزه روزی اللہ نے تمہیں دے رکھی ہے اسے کھاؤ اور اللہ کی نعمت کا شکر کرو اگر تم اسی کی عبادت کرتے ہو\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmxvi{تم پر صرف مردار اور خون اور سور کا گوشت اور جس چیز پر اللہ کے سوا دوسرے کا نام پکارا جائے حرام ہیں، پھر اگر کوئی شخص بے بس کر دیا جائے نہ وه خواہشمند ہو اور نہ حد سے گزرنے واﻻ ہو تو یقیناً اللہ بخشنے واﻻ رحم کرنے واﻻ ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmxvii{کسی چیز کو اپنی زبان سے جھوٹ موٹ نہ کہہ دیا کرو کہ یہ حلال ہے اور یہ حرام ہے کہ اللہ پر جھوٹ بہتان باندھ لو، سمجھ لو کہ اللہ تعالیٰ پر بہتان بازی کرنے والے کامیابی سے محروم ہی رہتے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmxviii{انہیں بہت معمولی فائده ملتا ہے اور ان کے لئے ہی دردناک عذاب ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmxix{اور یہودیوں پر جو کچھ ہم نے حرام کیا تھا اسے ہم پہلے ہی سے آپ کو سنا چکے ہیں، ہم نے ان پر ﻇلم نہیں کیا بلکہ وه خود اپنی جانوں پر ﻇلم کرتے رہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmxx{جو کوئی جہالت سے برے عمل کرلے پھر توبہ کرلے اور اصلاح بھی کرلے تو پھر آپ کا رب بلا شک وشبہ بڑی بخشش کرنے واﻻ اور نہایت ہی مہربان ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmxxi{بےشک ابراہیم پیشوا اور اللہ تعالیٰ کے فرمانبردار اور یک طرفہ مخلص تھے۔ وه مشرکوں میں سے نہ تھے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmxxii{اللہ تعالیٰ کی نعمتوں کے شکر گزار تھے، اللہ نے انہیں اپنا برگزیده کر لیا تھا اور انہیں راه راست سجھا دی تھی\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmxxiii{ہم نے اسے دنیا میں بھی بہتری دی تھی اور بےشک وه آخرت میں بھی نیکوکاروں میں ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmxxiv{پھر ہم نے آپ کی جانب وحی بھیجی کہ آپ ملت ابراہیم حنیف کی پیروی کریں، جو مشرکوں میں سے نہ تھے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmxxv{ہفتے کے دن کی عظمت تو صرف ان لوگوں کے ذمے ہی ضروری کی گئی تھی جنہوں نے اس میں اختلاف کیا تھا، بات یہ ہے کہ آپ کا پروردگار خود ہی ان میں ان کے اختلاف کا فیصلہ قیامت کے دن کرے گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmxxvi{اپنے رب کی راه کی طرف لوگوں کو حکمت اور بہترین نصیحت کے ساتھ بلایئے اور ان سے بہترین طریقے سے گفتگو کیجئے، یقیناً آپ کا رب اپنی راه سے بہکنے والوں کو بھی بخوبی جانتا ہے اور وه راه یافتہ لوگوں سے بھی پورا واقف ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmxxvii{اور اگر بدلہ لو بھی تو بالکل اتنا ہی جتنا صدمہ تمہیں پہنچایا گیا ہو اور اگر صبر کرلو تو بےشک صابروں کے لئے یہی بہتر ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmxxviii{آپ صبر کریں بغیر توفیق الٰہی کے آپ صبر کر ہی نہیں سکتے اور ان کے حال پر رنجیده نہ ہوں اور جو مکر وفریب یہ کرتے رہتے ہیں ان سے تنگ دل نہ ہوں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmxxix{یقین مانو کہ اللہ تعالیٰ پرہیزگاروں اور نیک کاروں کے ساتھ ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmxxx{\basmalahur پاک ہے وه اللہ تعالیٰ جو اپنے بندے کو رات ہی رات میں مسجد حرام سے مسجد اقصیٰ تک لے گیا جس کے آس پاس ہم نے برکت دے رکھی ہے، اس لئے کہ ہم اسے اپنی قدرت کے بعض نمونے دکھائیں، یقیناً اللہ تعالیٰ ہی خوب سننے دیکھنے واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmxxxi{ہم نے موسیٰ کو کتاب دی اور اسے بنی اسرائیل کے لئے ہدایت بنا دیا کہ تم میرے سوا کسی کو اپنا کارساز نہ بنانا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmxxxii{اے ان لوگوں کی اوﻻد! جنہیں ہم نے نوح کے ساتھ سوار کردیا تھا، وه ہمارا بڑا ہی شکرگزار بنده تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmxxxiii{ہم نے بنی اسرائیل کے لئے ان کی کتاب میں صاف فیصلہ کردیا تھا کہ تم زمین میں دوبار فساد برپا کرو گے اور تم بڑی زبردست زیادتیاں کرو گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmxxxiv{ان دونوں وعدوں میں سے پہلے کے آتے ہی ہم نے تمہارے مقابلہ پر اپنے بندے بھیج دیئے جو بڑے ہی لڑاکے تھے۔ پس وه تمہارے گھروں کے اندر تک پھیل گئے اور اللہ کا یہ وعده پورا ہونا ہی تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmxxxv{پھر ہم نے ان پر تمہارا غلبہ دے کر تمہارے دن پھیرے اور مال اور اوﻻد سے تمہاری مدد کی اور تمہیں بڑے جتھے واﻻ بنا دیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmxxxvi{اگر تم نے اچھے کام کئے تو خود اپنے ہی فائده کے لئے، اور اگر تم نے برائیاں کیں تو بھی اپنے ہی لئے، پھر جب دوسرے وعدے کا وقت آیا (تو ہم نے دوسرے بندوں کو بھیج دیا تاکہ) وه تمہارے چہرے بگاڑ دیں اور پہلی دفعہ کی طرح پھر اسی مسجد میں گھس جائیں۔ اور جس جس چیز پر قابو پائیں توڑ پھوڑ کر جڑ سے اکھاڑ دیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmxxxvii{امید ہے کہ تمہارا رب تم پر رحم کرے۔ ہاں اگر تم پھر بھی وہی کرنے لگے تو ہم بھی دوباره ایسا ہی کریں گے اور ہم نے منکروں کا قید خانہ جہنم کو بنا رکھا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmxxxviii{یقیناً یہ قرآن وه راستہ دکھاتا ہے جو بہت ہی سیدھا ہے اور ایمان والوں کو جو نیک اعمال کرتے ہیں اس بات کی خوشخبری دیتا ہے کہ ان کے لئے بہت بڑا اجر ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmxxxix{اور یہ کہ جو لوگ آخرت پر یقین نہیں رکھتے ان کے لئے ہم نے دردناک عذاب تیار کر رکھا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmxl{اور انسان برائی کی دعائیں مانگنے لگتا ہے بالکل اس کی اپنی بھلائی کی دعا کی طرح، انسان ہے ہی بڑا جلد باز\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmxli{ہم نے رات اور دن کو اپنی قدرت کی نشانیاں بنائی ہیں، رات کی نشانی کو تو ہم نے بےنور کردیا ہے اور دن کی نشانی کو روشن بنایا ہے تاکہ تم اپنے رب کا فضل تلاش کر سکو اور اس لئے بھی کہ برسوں کا شمار اور حساب معلوم کرسکو اور ہر ہر چیز کو ہم نے خوب تفصیل سے بیان فرما دیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmxlii{ہم نے ہر انسان کی برائی بھلائی کو اس کے گلے لگا دیا ہے اور بروز قیامت ہم اس کے سامنے اس کا نامہٴ اعمال نکالیں گے جسے وه اپنے اوپر کھلا ہوا پالے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmxliii{لے! خود ہی اپنی کتاب آپ پڑھ لے۔ آج تو تو آپ ہی اپنا خود حساب لینے کو کافی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmxliv{جو راه راست حاصل کرلے وه خود اپنے ہی بھلے کے لئے راه یافتہ ہوتا ہے اور جو بھٹک جائے اس کا بوجھ اسی کے اوپر ہے، کوئی بوجھ واﻻ کسی اور کا بوجھ اپنے اوپر نہ ﻻدے گا اور ہماری سنت نہیں کہ رسول بھیجنے سے پہلے ہی عذاب کرنے لگیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmxlv{اور جب ہم کسی بستی کی ہلاکت کا اراده کرلیتے ہیں تو وہاں کے خوشحال لوگوں کو (کچھ) حکم دیتے ہیں اور وه اس بستی میں کھلی نافرمانی کرنے لگتے ہیں تو ان پر (عذاب کی) بات ﺛابت ہوجاتی ہے پھر ہم اسے تباه وبرباد کردیتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmxlvi{ہم نے نوح کے بعد بھی بہت سی قومیں ہلاک کیں اور تیرا رب اپنے بندوں کے گناہوں سے کافی خبردار اور خوب دیکھنے بھالنے واﻻ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmxlvii{جس کا اراده صرف اس جلدی والی دنیا (فوری فائده) کا ہی ہو اسے ہم یہاں جس قدر جس کے لئے چاہیں سردست دیتے ہیں بالﺂخر اس کے لئے ہم جہنم مقرر کردیتے ہیں جہاں وه برے حالوں دھتکارا ہوا داخل ہوگا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmxlviii{اور جس کا اراده آخرت کا ہو اور جیسی کوشش اس کے لئے ہونی چاہیئے، وه کرتا بھی ہو اور وه باایمان بھی ہو، پس یہی لوگ ہیں جن کی کوشش کی اللہ کے ہاں پوری قدردانی کی جائے گی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmxlix{ہر ایک کو ہم بہم پہنچائے جاتے ہیں انہیں بھی اور ا نہیں بھی تیرے پروردگار کے انعامات میں سے۔ تیرے پروردگار کی بخشش رکی ہوئی نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mml{دیکھ لے کہ ان میں ایک کو ایک پر ہم نے کس طرح فضیلت دے رکھی ہے اور آخرت تو درجوں میں اور بھی بڑھ کر ہے اور فضیلت کے اعتبار سے بھی بہت بڑی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmli{اللہ کے ساتھ کسی اور کو معبود نہ ٹھہرا کہ آخرش تو برے حالوں بےکس ہو کر بیٹھ رہے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmlii{اور تیرا پروردگار صاف صاف حکم دے چکا ہے کہ تم اس کے سوا کسی اور کی عبادت نہ کرنا اور ماں باپ کے ساتھ احسان کرنا۔ اگر تیری موجودگی میں ان میں سے ایک یا یہ دونوں بڑھاپے کو پہنچ جائیں تو ان کے آگے اف تک نہ کہنا، نہ انہیں ڈانٹ ڈپٹ کرنا بلکہ ان کے ساتھ ادب و احترام سے بات چیت کرنا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmliii{اور عاجزی اور محبت کے ساتھ ان کے سامنے تواضع کا بازو پست رکھے رکھنا اور دعا کرتے رہنا کہ اے میرے پروردگار! ان پر ویسا ہی رحم کر جیسا انہوں نے میرے بچپن میں میری پرورش کی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmliv{جو کچھ تمہارے دلوں میں ہے اسے تمہارا رب بخوبی جانتا ہے اگر تم نیک ہو تو وه تو رجوع کرنے والوں کو بخشنے واﻻ ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmlv{اور رشتے داروں کا اور مسکینوں اور مسافروں کا حق ادا کرتے رہو اور اسراف اور بیجا خرچ سے بچو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmlvi{بیجا خرچ کرنے والے شیطانوں کے بھائی ہیں۔ اور شیطان اپنے پروردگار کا بڑا ہی ناشکرا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmlvii{اور اگر تجھے ان سے منھ پھیر لینا پڑے اپنے رب کی اس رحمت کی جستجو میں، جس کی تو امید رکھتا ہے تو بھی تجھے چاہیئے کہ عمدگی اور نرمی سے انہیں سمجھا دے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmlviii{اپنا ہاتھ اپنی گردن سے بندھا ہوا نہ رکھ اور نہ اسے بالکل ہی کھول دے کہ پھر ملامت کیا ہوا درمانده بیٹھ جائے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmlix{یقیناً تیرا رب جس کے لئے چاہے روزی کشاده کردیتا ہے اور جس کے لئے چاہے تنگ۔ یقیناً وه اپنے بندوں سے باخبر اور خوب دیکھنے واﻻ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmlx{اور مفلسی کے خوف سے اپنی اوﻻد کو نہ مار ڈالو، ان کو اور تم کو ہم ہی روزی دیتے ہیں۔ یقیناً ان کا قتل کرنا کبیره گناه ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmlxi{خبردار زنا کے قریب بھی نہ پھٹکنا کیوں کہ وه بڑی بےحیائی ہے اور بہت ہی بری راه ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmlxii{اور کسی جان کو جس کا مارنا اللہ نے حرام کردیا ہے ہرگز ناحق قتل نہ کرنا اور جو شخص مظلوم ہونے کی صورت میں مار ڈاﻻ جائے ہم نے اس کے وارث کو طاقت دے رکھی ہے پس اسے چاہیئے کہ مار ڈالنے میں زیادتی نہ کرے بےشک وه مدد کیا گیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmlxiii{اور یتیم کے مال کے قریب بھی نہ جاؤ بجز اس طریقہ کے جو بہت ہی بہتر ہو، یہاں تک کہ وه اپنی بلوغت کو پہنچ جائے اور وعدے پورے کرو کیونکہ قول وقرار کی باز پرس ہونے والی ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmlxiv{اور جب ناپنے لگو تو بھر پور پیمانے سے ناپو اور سیدھی ترازو سے توﻻ کرو۔ یہی بہتر ہے اور انجام کے لحاظ سے بھی بہت اچھا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmlxv{جس بات کی تجھے خبر ہی نہ ہو اس کے پیچھے مت پڑ۔ کیونکہ کان اور آنکھ اور دل ان میں سے ہر ایک سے پوچھ گچھ کی جانے والی ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmlxvi{اور زمین میں اکڑ کر نہ چل کہ نہ تو زمین کو پھاڑ سکتا ہے اور نہ لمبائی میں پہاڑوں کو پہنچ سکتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmlxvii{ان سب کاموں کی برائی تیرے رب کے نزدیک (سخت) ناپسند ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmlxviii{یہ بھی منجملہ اس وحی کے ہے جو تیری جانب تیرے رب نے حکمت سے اتاری ہے تو اللہ کے ساتھ کسی اور کو معبود نہ بنانا کہ ملامت خورده اور راندہٴ درگاه ہو کر دوزخ میں ڈال دیا جائے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmlxix{کیا بیٹوں کے لئے تو اللہ نے تمہیں چھانٹ لیا اور خود اپنے لئے فرشتوں کو لڑکیاں بنالیں؟ بےشک تم بہت بڑا بول بول رہے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmlxx{ہم نے تو اس قرآن میں ہر ہر طرح بیان فرما دیا کہ لوگ سمجھ جائیں لیکن اس سے انہیں تو نفرت ہی بڑھتی ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmlxxi{کہہ دیجیئے! کہ اگر اللہ کے ساتھ اور معبود بھی ہوتے جیسے کہ یہ لوگ کہتے ہیں تو ضرور وه اب تک مالک عرش کی جانب راه ڈھونڈ نکالتے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmlxxii{جو کچھ یہ کہتے ہیں اس سے وه پاک اور باﻻتر، بہت دور اور بہت بلند ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmlxxiii{ساتوں آسمان اور زمین اور جو بھی ان میں ہے اسی کی تسبیح کر رہے ہیں۔ ایسی کوئی چیز نہیں جو اسے پاکیزگی اور تعریف کے ساتھ یاد نہ کرتی ہو۔ ہاں یہ صحیح ہے کہ تم اس کی تسبیح سمجھ نہیں سکتے۔ وه بڑا بردبار اور بخشنے واﻻ ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmlxxiv{تو جب قرآن پڑھتا ہے ہم تیرے اور ان لوگوں کے درمیان جو آخرت پر یقین نہیں رکھتے ایک پوشیده حجاب ڈال دیتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmlxxv{اور ان کے دلوں پر ہم نے پردے ڈال دیئے ہیں کہ وه اسے سمجھیں اور ان کے کانوں میں بوجھ اور جب تو صرف اللہ ہی کا ذکر اس کی توحید کے ساتھ، اس قرآن میں کرتا ہے تو وه روگردانی کرتے پیٹھ پھیر کر بھاگ کھڑے ہوتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmlxxvi{جس غرض سے وه لوگ اسے سنتے ہیں ان (کی نیتوں) سے ہم خوب آگاه ہیں، جب یہ آپ کی طرف کان لگائے ہوئے ہوتے ہیں تب بھی اور جب یہ مشوره کرتے ہیں تب بھی جب کہ یہ ﻇالم کہتے ہیں کہ تم اس کی تابعداری میں لگے ہوئے ہو جن پر جادو کردیا گیا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmlxxvii{دیکھیں تو سہی، آپ کے لئے کیا کیا مثالیں بیان کرتے ہیں، پس وه بہک رہے ہیں۔ اب تو راه پانا ان کے بس میں نہیں رہا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmlxxviii{انہوں نے کہا کیا جب ہم ہڈیاں اور (مٹی ہو کر) ریزه ریزه ہوجائیں گے تو کیا ہم ازسرنو پیدا کر کے پھر دوباره اٹھا کر کھڑے کر دیئے جائیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmlxxix{جواب دیجیئے کہ تم پتھر بن جاؤ یا لوہا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmlxxx{یا کوئی اور ایسی خلقت جو تمہارے دلوں میں بہت ہی سخت معلوم ہو، پھر وه پوچھیں کہ کون ہے جو دوباره ہماری زندگی لوٹائے؟ آپ جواب دے دیں کہ وہی اللہ جس نے تمہیں اول بار پیدا کیا، اس پر وه اپنے سر ہلا ہلا کر آپ سے دریافت کریں گے کہ اچھا یہ ہے کب؟ تو آپ جواب دے دیں کہ کیا عجب کہ وه (ساعت) قریب ہی آن لگی ہو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmlxxxi{جس دن وه تمہیں بلائے گا تم اس کی تعریف کرتے ہوئے تعمیل ارشاد کرو گے اور گمان کرو گے کہ تمہارا رہنا بہت ہی تھوڑا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmlxxxii{اور میرے بندوں سے کہہ دیجیئے کہ وه بہت ہی اچھی بات منھ سے نکالا کریں کیونکہ شیطان آپس میں فساد ڈلواتا ہے۔ بےشک شیطان انسان کا کھلا دشمن ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiii{تمہارا رب تم سے بہ نسبت تمہارے بہت زیاده جاننے واﻻ ہے، وه اگر چاہے تو تم پر رحم کردے یا اگر وه چاہے تمہیں عذاب دے۔ ہم نے آپ کو ان کا ذمہ دار ٹھہرا کر نہیں بھیجا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiv{آسمانوں وزمین میں جو بھی ہے آپ کا رب سب کو بخوبی جانتا ہے۔ ہم نے بعض پیغمبروں کو بعض پر بہتری اور برتری دی ہے اور داؤد کو زبور ہم نے عطا فرمائی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmlxxxv{کہہ دیجیئے کہ اللہ کے سوا جنہیں تم معبود سمجھ رہے ہو انہیں پکارو لیکن نہ تو وه تم سے کسی تکلیف کو دور کرسکتے ہیں اور نہ بدل سکتے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvi{جنہیں یہ لوگ پکارتے ہیں خود وه اپنے رب کے تقرب کی جستجو میں رہتے ہیں کہ ان میں سے کون زیاده نزدیک ہوجائے وه خود اس کی رحمت کی امید رکھتے اور اس کے عذاب سے خوفزده رہتے ہیں، (بات بھی یہی ہے) کہ تیرے رب کا عذاب ڈرنے کی چیز ہی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvii{جتنی بھی بستیاں ہیں ہم قیامت کے دن سے پہلے پہلے یا تو انہیں ہلاک کردینے والے ہیں یا سخت تر سزا دینے والے ہیں۔ یہ تو کتاب میں لکھا جاچکا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmlxxxviii{ہمیں نشانات (معجزات) کے نازل کرنے سے روک صرف اسی کی ہے کہ اگلے لوگ انہیں جھٹلا چکے ہیں۔ ہم نے ﺛمودیوں کو بطور بصیرت کے اونٹنی دی لیکن انہوں نے اس پر ﻇلم کیا ہم تو لوگوں کو دھمکانے کے لئے ہی نشانیاں بھیجتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmlxxxix{اور یاد کرو جب کہ ہم نے آپ سے فرما دیا کہ آپ کے رب نے لوگوں کو گھیر لیا ہے۔ جو رویا (عینی رؤیت) ہم نے آپ کو دکھائی تھی وه لوگوں کے لئے صاف آزمائش ہی تھی اور اسی طرح وه درخت بھی جس سے قرآن میں اﻇہار نفرت کیا گیا ہے۔ ہم انہیں ڈرا رہے ہیں لیکن یہ انہیں اور بڑی سرکشی میں بڑھا رہا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmxc{جب ہم نے فرشتوں کو حکم دیا کہ آدم کو سجده کرو تو ابلیس کے سوا سب نے کیا، اس نے کہا کہ کیا میں اسے سجده کروں جسے تو نے مٹی سے پیدا کیا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmxci{اچھا دیکھ لے اسے تو نے مجھ پر بزرگی تو دی ہے، لیکن اگر مجھے بھی قیامت تک تو نے ڈھیل دی تو میں اس کی اوﻻد کو بجز بہت تھوڑے لوگوں کے، اپنے بس میں کرلوں گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmxcii{ارشاد ہوا کہ جا ان میں سے جو بھی تیرا تابعدار ہوجائے گا تو تم سب کی سزا جہنم ہے جو پورا پورا بدلہ ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmxciii{ان میں سے تو جسے بھی اپنی آواز سے بہکا سکے بہکا لے اور ان پر اپنے سوار اور پیادے چڑھا ﻻ اور ان کے مال اور اوﻻد میں سے اپنا بھی ساجھا لگا اور انہیں (جھوٹے) وعدے دے لے۔ ان سے جتنے بھی وعدے شیطان کے ہوتے ہیں سب کے سب سراسر فریب ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmxciv{میرے سچے بندوں پر تیرا کوئی قابو اور بس نہیں۔ تیرا رب کارسازی کرنے واﻻ کافی ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmxcv{تمہارا پروردگار وه ہے جو تمہارے لئے دریا میں کشتیاں چلاتا ہے تاکہ تم اس کا فضل تلاش کرو۔ وه تمہارے اوپر بہت ہی مہربان ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmxcvi{اور سمندروں میں مصیبت پہنچتے ہی جنہیں تم پکارتے تھے سب گم ہوجاتے ہیں صرف وہی اللہ باقی ره جاتا ہے۔ پھر جب وه تمہیں خشکی کی طرف بچا ﻻتا ہے تو تم منھ پھیر لیتے ہو اور انسان بڑا ہی ناشکرا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmxcvii{تو کیا تم اس سے بےخوف ہوگئے ہو کہ تمہیں خشکی کی طرف (لے جاکر زمین) میں دھنسا دے یا تم پر پتھروں کی آندھی بھیج دے۔ پھر تم اپنے لئے کسی نگہبان کو نہ پاسکو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmxcviii{کیا تم اس بات سے بےخوف ہوگئے ہو کہ اللہ تعالیٰ پھر تمہیں دوباره دریا کے سفر میں لے آئے اور تم پر تیز وتند ہواؤں کے جھونکے بھیج دے اور تمہارے کفر کے باعﺚ تمہیں ڈبو دے۔ پھر تم اپنے لئے ہم پر اس کا دعویٰ (پیچھا) کرنے واﻻ کسی کو نہ پاؤ گے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmxcix{یقیناً ہم نے اوﻻد آدم کو بڑی عزت دی اور انہیں خشکی اور تری کی سواریاں دیں اور انہیں پاکیزه چیزوں کی روزیاں دیں اور اپنی بہت سی مخلوق پر انہیں فضیلت عطا فرمائی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmc{جس دن ہم ہر جماعت کو اس کے پیشوا سمیت بلائیں گے۔ پھر جن کا بھی اعمال نامہ دائیں ہاتھ میں دے دیا گیا وه تو شوق سے اپنا نامہٴ اعمال پڑھنے لگیں گے اور دھاگے کے برابر (ذره برابر) بھی ﻇلم نہ کئے جائیں گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmci{اور جو کوئی اس جہان میں اندھا رہا، وه آخرت میں بھی اندھا اور راستے سے بہت ہی بھٹکا ہوا رہے گا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcii{یہ لوگ آپ کو اس وحی سے جو ہم نے آپ پر اتاری ہے بہکانا چاہتے کہ آپ اس کے سوا کچھ اور ہی ہمارے نام سے گھڑ گھڑالیں، تب تو آپ کو یہ لوگ اپنا ولی دوست بنا لیتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmciii{اگر ہم آپ کو ﺛابت قدم نہ رکھتے تو بہت ممکن تھا کہ ان کی طرف قدرے قلیل مائل ہو ہی جاتے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmciv{پھر تو ہم بھی آپ کو دوہرا عذاب دنیا کا کرتے اور دوہرا ہی موت کا، پھر آپ تو اپنے لئے ہمارے مقابلے میں کسی کو مددگار بھی نہ پاتے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcv{یہ تو آپ کے قدم اس سرزمین سے اکھاڑنے ہی لگے تھے کہ آپ کو اس سے نکال دیں۔ پھر یہ بھی آپ کے بعد بہت ہی کم ٹھہر پاتے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcvi{ایسا ہی دستور ان کا تھا جو آپ سے پہلے رسول ہم نے بھیجے اور آپ ہمارے دستور میں کبھی ردوبدل نہ پائیں گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcvii{نماز کو قائم کریں آفتاب کے ڈھلنے سے لے کر رات کی تاریکی تک اور فجر کا قرآن پڑھنا بھی یقیناً فجر کے وقت کا قرآن پڑھنا حاضر کیا گیا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcviii{رات کے کچھ حصے میں تہجد کی نماز میں قرآن کی تلاوت کریں یہ زیادتی آپ کے لئے ہے عنقریب آپ کا رب آپ کو مقام محمود میں کھڑا کرے گا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcix{اور دعا کیا کریں کہ اے میرے پروردگار مجھے جہاں لے جا اچھی طرح لے جا اور جہاں سے نکال اچھی طرح نکال اور میرے لئے اپنے پاس سے غلبہ اور امداد مقرر فرما دے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcx{اور اعلان کردے کہ حق آچکا اور ناحق نابود ہوگیا۔ یقیناً باطل تھا بھی نابود ہونے واﻻ\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcxi{یہ قرآن جو ہم نازل کر رہے ہیں مومنوں کے لئے تو سراسر شفا اور رحمت ہے۔ ہاں ﻇالموں کو بجز نقصان کے اور کوئی زیادتی نہیں ہوتی\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcxii{اور انسان پر جب ہم اپنا انعام کرتے ہیں تو وه منھ موڑ لیتا ہے اور کروٹ بدل لیتا ہے اور جب اسے کوئی تکلیف پہنچتی ہے تو وه مایوس ہوجاتا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcxiii{کہہ دیجئیے! کہ ہر شخص اپنے طریقہ پر عامل ہے جو پوری ہدایت کے راستے پر ہیں انہیں تمہارا رب ہی بخوبی جاننے واﻻ ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcxiv{اور یہ لوگ آپ سے روح کی بابت سوال کرتے ہیں، آپ جواب دے دیجئیے کہ روح میرے رب کے حکم سے ہے اور تمہیں بہت ہی کم علم دیا گیا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcxv{اور اگر ہم چاہیں تو جو وحی آپ کی طرف ہم نے اتاری ہے سب سلب کرلیں، پھر آپ کو اس کے لئے ہمارے مقابلے میں کوئی حمایتی میسر نہ آسکے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcxvi{سوائے آپ کے رب کی رحمت کے، یقیناً آپ پر اس کا بڑا ہی فضل ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcxvii{کہہ دیجیئے کہ اگر تمام انسان اور کل جنات مل کر اس قرآن کے مثل ﻻنا چاہیں تو ان سب سے اس کے مثل ﻻنا ناممکن ہے گو وه (آپس میں) ایک دوسرے کے مددگار بھی بن جائیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcxviii{ہم نے تو اس قرآن میں لوگوں کے سمجھنے کے لئے ہر طرح سے تمام مثالیں بیان کردی ہیں، مگر اکثر لوگ انکار سے باز نہیں آتے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcxix{انہوں نے کہا کہ ہم آپ پر ہرگز ایمان ﻻنے کے نہیں تاوقتیکہ آپ ہمارے لئے زمین سے کوئی چشمہ جاری نہ کردیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcxx{یا خود آپ کے لئے ہی کوئی باغ ہو کھجوروں اور انگوروں کا اور اس کے درمیان آپ بہت سی نہریں جاری کر دکھائیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcxxi{یا آپ آسمان کو ہم پر ٹکڑے ٹکڑے کرکے گرا دیں جیسا کہ آپ کا گمان ہے یا آپ خود اللہ تعالیٰ کو اور فرشتوں کو ہمارے سامنے ﻻکھڑا کریں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcxxii{یا آپ کے اپنے لئے کوئی سونے کا گھر ہوجائے یا آپ آسمان پر چڑھ جائیں اور ہم تو آپ کے چڑھ جانے کا بھی اس وقت تک ہرگز یقین نہیں کریں گے جب تک کہ آپ ہم پر کوئی کتاب نہ اتار ﻻئیں جسے ہم خود پڑھ لیں، آپ جواب دے دیں کہ میرا پروردگار پاک ہے میں تو صرف ایک انسان ہی ہوں جو رسول بنایا گیا ہوں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcxxiii{لوگوں کے پاس ہدایت پہنچ چکنے کے بعد ایمان سے روکنے والی صرف یہی چیز رہی کہ انہوں نے کہا کیا اللہ نے ایک انسان کو ہی رسول بنا کر بھیجا؟\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcxxiv{آپ کہہ دیں کہ اگر زمین میں فرشتے چلتے پھرتے اور رہتے بستے ہوتے تو ہم بھی ان کے پاس کسی آسمانی فرشتے ہی کو رسول بنا کر بھیجتے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcxxv{کہہ دیجئیے کہ میرے اور تمہارے درمیان اللہ تعالیٰ کا گواه ہونا کافی ہے۔ وه اپنے بندوں سے خوب آگاه اور بخوبی دیکھنے واﻻ ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcxxvi{اللہ جس کی رہنمائی کرے تو وه ہدایت یافتہ ہے اور جسے وه راه سے بھٹکا دے ناممکن ہے کہ تو اس کا مددگار اس کے سوا کسی اور کو پائے، ایسے لوگوں کا ہم بروز قیامت اوندھے منھ حشر کریں گے، دراں حالیکہ وه اندھے، گونگے اور بہرے ہوں گے، ان کا ٹھکانہ جہنم ہوگا۔ جب کبھی وه بجھنے لگے گی ہم ان پر اسے اور بھڑکا دیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcxxvii{یہ سب ہماری آیتوں سے کفر کرنے اور اس کہنے کا بدلہ ہے کہ کیا جب ہم ہڈیاں اور ریزے ریزے ہوجائیں گے پھر ہم نئی پیدائش میں اٹھا کھڑے کئے جائیں گے؟\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcxxviii{کیا انہوں نے اس بات پر نظر نہیں کی کہ جس اللہ نے آسمان وزمین کو پیدا کیا ہے وه ان جیسوں کی پیدائش پر پورا قادر ہے، اسی نے ان کے لئے ایک ایسا وقت مقرر کر رکھا ہے جو شک شبہ سے یکسر خالی ہے، لیکن ﻇالم لوگ انکار کئے بغیر رہتے ہی نہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcxxix{کہہ دیجیئے کہ اگر بالفرض تم میرے رب کی رحمتوں کے خزانوں کے مالک بن جاتے تو تم اس وقت بھی اس کے خرچ ہوجانے کے خوف سے اس کو روکے رکھتے اور انسان ہے ہی تنگ دل\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcxxx{ہم نے موسیٰ کو نو معجزے بالکل صاف صاف عطا فرمائے، تو خود ہی بنی اسرائیل سے پوچھ لے کہ جب وه ان کے پاس پہنچے تو فرعون بوﻻ کہ اے موسیٰ میرے خیال میں تو تجھ پر جادو کردیا گیا ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcxxxi{موسیٰ نے جواب دیا کہ یہ تو تجھے علم ہوچکا ہے کہ آسمان وزمین کے پروردگار ہی نے یہ معجزے دکھانے، سمجھانے کو نازل فرمائے ہیں، اے فرعون! میں تو سمجھ رہا ہوں کہ تو یقیناً برباد وہلاک کیا گیا ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcxxxii{آخر فرعون نے پختہ اراده کر لیا کہ انہیں زمین سے ہی اکھیڑ دے تو ہم نے خود اسے اور اس کے تمام ساتھیوں کو غرق کر دیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiii{اس کے بعد ہم نے بنی اسرائیل سے فرما دیا کہ اس سرزمین پر تم رہو سہو۔ ہاں جب آخرت کا وعده آئے گا ہم تم سب کو سمیٹ اور لپیٹ کر لے آئیں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiv{اور ہم نے اس قرآن کو حق کے ساتھ اتارا اور یہ بھی حق کے ساتھ اترا۔ ہم نے آپ کو صرف خوشخبری سنانے واﻻ اور ڈرانے واﻻ بنا کر بھیجا ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcxxxv{قرآن کو ہم نے تھوڑا تھوڑا کرکے اس لئے اتارا ہے کہ آپ اسے بہ مہلت لوگوں کو سنائیں اور ہم نے خود بھی اسے بتدریج نازل فرمایا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvi{کہہ دیجئیے! تم اس پر ایمان ﻻؤ یا نہ ﻻؤ جنہیں اس سے پہلے علم دیا گیا ہے ان کے پاس تو جب بھی اس کی تلاوت کی جاتی ہے تو وه ٹھوڑیوں کے بل سجده میں گر پڑتے ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvii{اور کہتے ہیں کہ ہمارا رب پاک ہے، ہمارے رب کا وعده بلاشک وشبہ پورا ہو کر رہنے واﻻ ہی ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcxxxviii{وه اپنی ٹھوڑیوں کے بل روتے ہوئے سجده میں گر پڑ تے ہیں اور یہ قرآن ان کی عاجزی اور خشوع اور خضوع بڑھا دیتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcxxxix{کہہ دیجئیے کہ اللہ کو اللہ کہہ کر پکارو یا رحمٰن کہہ کر، جس نام سے بھی پکارو تمام اچھے نام اسی کے ہیں۔ نہ تو تو اپنی نماز بہت بلند آواز سے پڑھ اور نہ بالکل پوشیده بلکہ اس کے درمیان کا راستہ تلاش کرلے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcxl{اور یہ کہہ دیجیئے کہ تمام تعریفیں اللہ ہی کے لئے ہیں جو نہ اوﻻد رکھتا ہے نہ اپنی بادشاہت میں کسی کو شریک وساجھی رکھتا ہے اور نہ وه کمزور ہے کہ اسے کسی حمایتی کی ضرورت ہو اور تو اس کی پوری پوری بڑائی بیان کرتا ره\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcxli{\basmalahur تمام تعریفیں اسی اللہ کے لئے سزاوار ہیں جس نے اپنے بندے پر یہ قرآن اتارا اور اس میں کوئی کسر باقی نہ چھوڑی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcxlii{بلکہ ہر طرح سے ٹھیک ٹھاک رکھا تاکہ اپنے پاس کی سخت سزا سے ہوشیار کردے اور ایمان ﻻنے اور نیک عمل کرنے والوں کو خوشخبریاں سنا دے کہ ان کے لئے بہترین بدلہ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcxliii{جس میں وه ہمیشہ ہمیشہ رہیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcxliv{اور ان لوگوں کو بھی ڈرا دے جو کہتے ہیں کہ اللہ تعالیٰ اوﻻد رکھتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcxlv{در حقیقت نہ تو خود انہیں اس کا علم ہے نہ ان کے باپ دادوں کو۔ یہ تہمت بڑی بری ہے جو ان کے منھ سے نکل رہی ہے وه نرا جھوٹ بک رہے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcxlvi{پس اگر یہ لوگ اس بات پر ایمان نہ ﻻئیں تو کیا آپ ان کے پیچھے اسی رنج میں اپنی جان ہلاک کر ڈالیں گے؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcxlvii{روئے زمین پر جو کچھ ہے ہم نے اسے زمین کی رونق کا باعﺚ بنایا ہے کہ ہم انہیں آزمالیں کہ ان میں سے کون نیک اعمال واﻻ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcxlviii{اس پر جو کچھ ہے ہم اسے ایک ہموار صاف میدان کر ڈالنے والے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcxlix{کیا تو اپنے خیال میں غار اور کتبے والوں کو ہماری نشانیوں میں سے کوئی بہت عجیب نشانی سمجھ رہا ہے؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcl{ان چند نوجوانوں نے جب غار میں پناه لی تو دعا کی کہ اے ہمارے پروردگار! ہمیں اپنے پاس سے رحمت عطا فرما اور ہمارے کام میں ہمارے لئے راه یابی کو آسان کردے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcli{پس ہم نے ان کے کانوں پر گنتی کے کئی سال تک اسی غار میں پردے ڈال دیئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmclii{پھر ہم نے انہیں اٹھا کھڑا کیا کہ ہم یہ معلوم کرلیں کہ دونوں گروه میں سے اس انتہائی مدت کو جو انہوں نے گزاری کس نے زیاده یاد رکھی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcliii{ہم ان کا صحیح واقعہ تیرے سامنے بیان فرما رہے ہیں۔ یہ چند نوجوان اپنے رب پر ایمان ﻻئے تھے اور ہم نے ان کی ہدایت میں ترقی دی تھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcliv{ہم نے ان کے دل مضبوط کردیئے تھے جب کہ یہ اٹھ کھڑے ہوئے اور کہنے لگے کہ ہمارا پروردگار تو وہی ہے جو آسمان وزمین کا پروردگار ہے، ناممکن ہے کہ ہم اس کے سوا کسی اور معبود کو پکاریں اگر ایسا کیا تو ہم نے نہایت ہی غلط بات کہی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmclv{یہ ہے ہماری قوم جس نے اس کے سوا اور معبود بنا رکھے ہیں۔ ان کی خدائی کی یہ کوئی صاف دلیل کیوں پیش نہیں کرتے اللہ پر جھوٹ افترا باندھنے والے سے زیاده ﻇالم کون ہے؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmclvi{جب کہ تم ان سے اور اللہ کے سوا ان کے اور معبودوں سے کناره کش ہوگئے تو اب تم کسی غار میں جا بیٹھو، تمہارا رب تم پر اپنی رحمت پھیلا دے گا اور تمہارے لئے تمہارے کام میں سہولت مہیا کردے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmclvii{آپ دیکھیں گے کہ آفتاب بوقت طلوع ان کے غار سے دائیں جانب کو جھک جاتا ہے اور بوقت غروب ان کے بائیں جانب کترا جاتا ہے اور وه اس غار کی کشاده جگہ میں ہیں۔ یہ اللہ کی نشانیوں میں سے ہے۔ اللہ تعالیٰ جس کی رہبری فرمائے وه راه راست پر ہے اور جسے وه گمراه کردے ناممکن ہے کہ آپ اس کا کوئی کارساز اور رہنما پاسکیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmclviii{آپ خیال کرتے کہ وه بیدار ہیں، حاﻻنکہ وه سوئے ہوئے تھے، خود ہم ہی انہیں دائیں بائیں کروٹیں دﻻیا کرتے تھے، ان کا کتا بھی چوکھٹ پر اپنے ہاتھ پھیلائے ہوئے تھا۔ اگر آپ جھانک کر انہیں دیکھنا چاہتے تو ضرور الٹے پاؤں بھاگ کھڑے ہوتے اور ان کے رعب سے آپ پر دہشت چھا جاتی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmclix{اسی طرح ہم نے انہیں جگا کر اٹھا دیا کہ آپس میں پوچھ گچھ کرلیں۔ ایک کہنے والے نے کہا کہ کیوں بھئی تم کتنی دیر ٹھہرے رہے؟ انہوں نے جواب دیا کہ ایک دن یا ایک دن سے بھی کم۔ کہنے لگے کہ تمہارے ٹھہرے رہنے کا بخوبی علم اللہ تعالیٰ ہی کو ہے۔ اب تو تم اپنے میں سے کسی کو اپنی یہ چاندی دے کر شہر بھیجو وه خوب دیکھ بھال لے کہ شہر کا کون سا کھانا پاکیزه تر ہے، پھر اسی میں سے تمہارے کھانے کے لئے لے آئے، اور وه بہت احتیاط اور نرمی برتے اور کسی کو تمہاری خبر نہ ہونے دے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmclx{اگر یہ کافر تم پر غلبہ پالیں تو تمہیں سنگسار کر دیں گے یا تمہیں پھر اپنے دین میں لوٹا لیں گے اور پھر تم کبھی بھی کامیاب نہ ہو سکو گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmclxi{ہم نے اس طرح لوگوں کو ان کے حال سے آگاه کر دیا کہ وه جان لیں کہ اللہ کا وعده بالکل سچا ہے اور قیامت میں کوئی شک وشبہ نہیں۔ جب کہ وه اپنے امر میں آپس میں اختلاف کر رہے تھے کہنے لگے کہ ان کے غار پر ایک عمارت بنا لو۔ ان کا رب ہی ان کے حال کا زیاده عالم ہے۔ جن لوگوں نے ان کے بارے میں غلبہ پایا وه کہنے لگے کہ ہم تو ان کے آس پاس مسجد بنالیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmclxii{کچھ لوگ تو کہیں گے کہ اصحاب کہف تین تھے اور چوتھا ان کا کتا تھا۔ کچھ کہیں گے کہ پانچ تھے اور چھٹا ان کا کتا تھا، غیب کی باتوں میں اٹکل (کے تیر تکے) چلاتے ہیں، کچھ کہیں گے کہ وه سات ہیں اور آٹھواں ان کا کتا ہے۔ آپ کہہ دیجیئے کہ میرا پروردگار ان کی تعداد کو بخوبی جاننے واﻻ ہے، انہیں بہت ہی کم لوگ جانتے ہیں۔ پس آپ ان کے مقدمے میں صرف سرسری گفتگو کریں اور ان میں سے کسی سے ان کے بارے میں پوچھ گچھ بھی نہ کریں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmclxiii{اور ہرگز ہرگز کسی کام پر یوں نہ کہنا کہ میں اسے کل کروں گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmclxiv{مگر ساتھ ہی انشاءاللہ کہہ لینا۔ اور جب بھی بھولے، اپنے پروردگار کی یاد کر لیا کرنا اور کہتے رہنا کہ مجھے پوری امید ہے کہ میرا رب مجھے اس سے بھی زیاده ہدایت کے قریب کی بات کی رہبری کرے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmclxv{وه لوگ اپنے غار میں تین سو سال تک رہے اور نو سال اور زیاده گزارے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmclxvi{آپ کہہ دیں اللہ ہی کو ان کے ٹھہرے رہنے کی مدت کا بخوبی علم ہے، آسمانوں اور زمینوں کا غیب صرف اسی کو حاصل ہے وه کیا ہی اچھا دیکھنے سننے واﻻ ہے۔ سوائے اللہ کے ان کا کوئی مددگار نہیں، اللہ تعالیٰ اپنے حکم میں کسی کو شریک نہیں کرتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmclxvii{تیری جانب جو تیرے رب کی کتاب وحی کی گئی ہے اسے پڑھتا ره، اس کی باتوں کو کوئی بدلنے واﻻ نہیں تو اس کے سوا ہرگز ہرگز کوئی پناه کی جگہ نہ پائے گا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmclxviii{اور اپنے آپ کو انہیں کے ساتھ رکھا کر جو اپنے پروردگار کو صبح شام پکارتے ہیں اور اسی کے چہرے کے ارادے رکھتے ہیں (رضامندی چاہتے ہیں)، خبردار! تیری نگاہیں ان سے نہ ہٹنے پائیں کہ دنیوی زندگی کے ٹھاٹھ کے ارادے میں لگ جا۔ دیکھ اس کا کہنا نہ ماننا جس کے دل کو ہم نے اپنے ذکر سے غافل کردیا ہے اور جو اپنی خواہش کے پیچھے پڑا ہوا ہے اور جس کا کام حد سے گزر چکا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmclxix{اور اعلان کردے کہ یہ سراسر برحق قرآن تمہارے رب کی طرف سے ہے۔ اب جو چاہے ایمان ﻻئے اور جو چاہے کفر کرے۔ ﻇالموں کے لئے ہم نے وه آگ تیار کر رکھی ہے جس کی قناتیں انہیں گھیر لیں گی۔ اگر وه فریاد رسی چاہیں گے تو ان کی فریاد رسی اس پانی سے کی جائے گی جو تیل کی تلچھٹ جیسا ہوگا جو چہرے بھون دے گا، بڑا ہی برا پانی ہے اور بڑی بری آرام گاه (دوزخ) ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmclxx{یقیناً جو لوگ ایمان ﻻئیں اور نیک اعمال کریں تو ہم کسی نیک عمل کرنے والے کا ﺛواب ضائع نہیں کرتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmclxxi{ان کے لئے ہمیشگی والی جنتیں ہیں، ان کے نیچے نہریں جاری ہوں گی، وہاں یہ سونے کے کنگن پہنائے جائیں گے اور سبز رنگ کے نرم وباریک اور موٹے ریشم کے لباس پہنیں گے، وہاں تختوں کے اوپر تکیے لگائے ہوئے ہوں گے۔ کیا خوب بدلہ ہے، اور کس قدر عمده آرام گاه ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmclxxii{اور انہیں ان دو شخصوں کی مثال بھی سنا دے جن میں سے ایک کو ہم نے دو باغ انگوروں کے دے رکھے تھے اور جنہیں کھجوروں کے درختوں سے ہم نے گھیر رکھا تھا اور دونوں کے درمیان کھیتی لگا رکھی تھی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmclxxiii{دونوں باغ اپنا پھل خوب ﻻئے اور اس میں کسی طرح کی کمی نہ کی اور ہم نے ان باغوں کے درمیان نہر جاری کر رکھی تھی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmclxxiv{الغرض اس کے پاس میوے تھے، ایک دن اس نے باتوں ہی باتوں میں اپنے ساتھی سے کہا کہ میں تجھ سے زیاده مالدار اور جتھے کے اعتبار سے بھی زیاده مضبوط ہوں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmclxxv{اور یہ اپنے باغ میں گیا اور تھا اپنی جان پر ﻇلم کرنے واﻻ۔ کہنے لگا کہ میں خیال نہیں کرسکتا کہ کسی وقت بھی یہ برباد ہوجائے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmclxxvi{اور نہ میں قیامت کو قائم ہونے والی خیال کرتا ہوں اور اگر (بالفرض) میں اپنے رب کی طرف لوٹایا بھی گیا تو یقیناً میں (اس لوٹنے کی جگہ) اس سے بھی زیاده بہتر پاؤں گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmclxxvii{اس کے ساتھی نے اس سے باتیں کرتے ہوئے کہا کہ کیا تو اس (معبود) سے کفر کرتا ہے جس نے تجھے مٹی سے پیدا کیا۔ پھر نطفے سے پھر تجھے پورا آدمی بنا دیا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmclxxviii{لیکن میں تو عقیده رکھتا ہوں کہ وہی اللہ میرا پروردگار ہے میں اپنے رب کے ساتھ کسی کو شریک نہ کروں گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmclxxix{تو نے اپنے باغ میں جاتے وقت کیوں نہ کہا کہ اللہ کا چاہا ہونے واﻻ ہے، کوئی طاقت نہیں مگر اللہ کی مدد سے، اگر تو مجھے مال واوﻻد میں اپنے سے کم دیکھ رہا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmclxxx{بہت ممکن ہے کہ میرا رب مجھے تیرے اس باغ سے بھی بہتر دے اور اس پر آسمانی عذاب بھیج دے تو یہ چٹیل اور چکنا میدان بن جائے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmclxxxi{یا اس کا پانی نیچے اتر جائے اور تیرے بس میں نہ رہے کہ تو اسے ڈھونڈ ﻻئے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmclxxxii{اور اس کے (سارے) پھل گھیر لئے گئے، پس وه اپنے اس خرچ پر جو اس نے اس میں کیا تھا اپنے ہاتھ ملنے لگا اور وه باغ تو اوندھا الٹا پڑا تھا اور (وه شخص) یہ کہہ رہا تھا کہ کاش! میں اپنے رب کے ساتھ کسی کو بھی شریک نہ کرتا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiii{اس کی حمایت میں کوئی جماعت نہ اٹھی کہ اللہ سے اس کا کوئی بچاؤ کرتی اور نہ وه خود ہی بدلہ لینے واﻻ بن سکا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiv{یہیں سے (ﺛابت ہے) کہ اختیارات اللہ برحق کے لئے ہیں وه ﺛواب دینے اور انجام کے اعتبار سے بہت ہی بہتر ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmclxxxv{ان کے سامنے دنیا کی زندگی کی مثال (بھی) بیان کرو جیسے پانی جسے ہم آسمان سے اتارتے ہیں اس سے زمین کا سبزه ملا جلا (نکلا) ہے، پھر آخر کار وه چورا چورا ہوجاتا ہے جسے ہوائیں اڑائے لئے پھرتی ہیں۔ اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvi{مال واوﻻد تو دنیا کی ہی زینت ہے، اور (ہاں) البتہ باقی رہنے والی نیکیاں تیرے رب کے نزدیک از روئے ﺛواب اور (آئنده کی) اچھی توقع کے بہت بہتر ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvii{اور جس دن ہم پہاڑوں کو چلائیں گے اور زمین کو تو صاف کھلی ہوئی دیکھے گا اور تمام لوگوں کو ہم اکٹھا کریں گے ان میں سے ایک کو بھی باقی نہ چھوڑیں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmclxxxviii{اور سب کے سب تیرے رب کے سامنے صف بستہ حاضر کئے جائیں گے۔ یقیناً تم ہمارے پاس اسی طرح آئے جس طرح ہم نے تمہیں پہلی مرتبہ پیدا کیا تھا لیکن تم تو اسی خیال میں رہے کہ ہم ہرگز تمہارے لئے کوئی وعدے کا وقت مقرر کریں گے بھی نہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmclxxxix{اور نامہٴ اعمال سامنے رکھ دیئے جائیں گے۔ پس تو دیکھے گا کہ گنہگار اس کی تحریر سے خوفزده ہو رہے ہوں گے اور کہہ رہے ہوں گے ہائے ہماری خرابی یہ کیسی کتاب ہے جس نے کوئی چھوٹا بڑا بغیر گھیرے کے باقی ہی نہیں چھوڑا، اور جو کچھ انہوں نے کیا تھا سب موجود پائیں گے اور تیرا رب کسی پر ﻇلم وستم نہ کرے گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcxc{اور جب ہم نے فرشتوں کو حکم دیا کہ تم آدم کو سجده کرو تو ابلیس کے سوا سب نے سجده کیا، یہ جنوں میں سے تھا، اس نے اپنے پروردگار کی نافرمانی کی، کیا پھر بھی تم اسے اور اس کی اوﻻد کو مجھے چھوڑ کر اپنا دوست بنا رہے ہو؟ حاﻻنکہ وه تم سب کا دشمن ہے۔ ایسے ﻇالموں کا کیا ہی برا بدل ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcxci{میں نے انہیں آسمانوں وزمین کی پیدائش کے وقت موجود نہیں رکھا تھا اور نہ خود ان کی اپنی پیدائش میں، اور میں گمراه کرنے والوں کو اپنا مددگار بنانے واﻻ بھی نہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcxcii{اور جس دن وه فرمائے گا کہ تمہارے خیال میں جو میرے شریک تھے انہیں پکارو! یہ پکاریں گے لیکن ان میں سے کوئی بھی جواب نہ دے گا ہم ان کے درمیان ہلاکت کا سامان کردیں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcxciii{اور گنہگار جہنم کو دیکھ کرسمجھ لیں گے کہ وه اسی میں جھونکے جانے والے ہیں لیکن اس سے بچنے کی جگہ نہ پائیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcxciv{ہم نے اس قرآن میں ہر ہر طریقے سے تمام کی تمام مثالیں لوگوں کے لئے بیان کردی ہیں لیکن انسان سب سے زیاده جھگڑالو ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcxcv{لوگوں کے پاس ہدایت آچکنے کے بعد انہیں ایمان ﻻنے اور اپنے رب سے استغفار کرنے سے صرف اسی چیز نے روکا کہ اگلے لوگوں کا سا معاملہ انہیں بھی پیش آئے یا ان کے سامنے کھلم کھلا عذاب آموجود ہوجائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcxcvi{ہم تو اپنے رسولوں کو صرف اس لئے بھیجتے ہیں کہ وه خوشخبریاں سنا دیں اور ڈرا دیں۔ کافر لوگ باطل کے سہارے جھگڑتے ہیں اور (چاہتے ہیں کہ) اس سے حق کو لڑکھڑادیں، انہوں نے میری آیتوں کو اور جس چیز سے ڈرایا جائے اسے مذاق بنا ڈاﻻ ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcxcvii{اس سے بڑھ کر ﻇالم کون ہے؟ جسے اس کے رب کی آیتوں سے نصیحت کی جائے وه پھر منھ موڑے رہے اور جو کچھ اس کے ہاتھوں نے آگے بھیج رکھا ہے اسے بھول جائے، بےشک ہم نے ان کے دلوں پر پردے ڈال دیئے ہیں کہ وه اسے (نہ) سمجھیں اور ان کے کانوں میں گرانی ہے، گو تو انہیں ہدایت کی طرف بلاتا رہے، لیکن یہ کبھی بھی ہدایت نہیں پانے کے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcxcviii{تیرا پروردگار بہت ہی بخشش واﻻ اور مہربانی واﻻ ہے وه اگر ان کے اعمال کی سزا میں پکڑے تو بےشک انہیں جلد ہی عذاب کردے، بلکہ ان کے لئے ایک وعده کی گھڑی مقرر ہے جس سے وه سرکنے کی ہرگز جگہ نہیں پائیں گے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcxcix{یہ ہیں وه بستیاں جنہیں ہم نے ان کے مظالم کی بنا پر غارت کردیا اور ان کی تباہی کی بھی ہم نے ایک میعاد مقرر کر رکھی تھی\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcc{جب کہ موسیٰ نے اپنے نوجوان سے کہا کہ میں تو چلتا ہی رہوں گا یہاں تک کہ دو دریاؤں کے سنگم پر پہنچوں، خواه مجھے سالہا سال چلنا پڑے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcci{جب وه دونوں دریا کے سنگم پر پہنچے، وہاں اپنی مچھلی بھول گئے جس نے دریا میں سرنگ جیسا اپنا راستہ بنالیا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmccii{جب یہ دونوں وہاں آگے بڑھے تو موسیٰ نے اپنے نوجوان سے کہا کہ ﻻ ہمارا کھانا دے ہمیں تو اپنے اس سفر سے سخت تکلیف اٹھانی پڑی\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcciii{اس نے جواب دیا کہ کیا آپ نے دیکھا بھی؟ جب کہ ہم پتھر سے ٹیک لگا کر آرام کر رہے تھے وہیں میں مچھلی بھول گیا تھا، دراصل شیطان نے ہی مجھے بھلا دیا کہ میں آپ سے اس کا ذکر کروں۔ اس مچھلی نے ایک انوکھے طور پر دریا میں اپنا راستہ بنالیا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcciv{موسیٰ نے کہا یہی تھا جس کی تلاش میں ہم تھے چنانچہ وہیں سے اپنے قدموں کے نشان ڈھونڈتے ہوئے واپس لوٹے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmccv{پس ہمارے بندوں میں سے ایک بندے کو پایا، جسے ہم نے اپنے پاس کی خاص رحمت عطا فرما رکھی تھی اور اسے اپنے پاس سے خاص علم سکھا رکھا تھا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmccvi{اس سے موسیٰ نے کہا کہ میں آپ کی تابعداری کروں؟ کہ آپ مجھے اس نیک علم کو سکھا دیں جو آپ کو سکھایا گیا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmccvii{اس نے کہا آپ میرے ساتھ ہرگز صبر نہیں کرسکتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmccviii{اور جس چیز کو آپ نے اپنے علم میں نہ لیا ہو اس پر صبر بھی کیسے کر سکتے ہیں؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmccix{موسیٰ نے جواب دیا کہ انشاءاللہ آپ مجھے صبر کرنے واﻻ پائیں گے اور کسی بات میں، میں آپ کی نافرمانی نہ کروں گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmccx{اس نے کہا اچھا اگر آپ میرے ساتھ ہی چلنے پر اصرار کرتے ہیں تو یاد رہے کسی چیز کی نسبت مجھ سے کچھ نہ پوچھنا جب تک کہ میں خود اس کی نسبت کوئی تذکره نہ کروں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmccxi{پھر وه دونوں چلے، یہاں تک کہ ایک کشتی میں سوار ہوئے، تو اس نے کشتی کے تختے توڑ دیئے، موسیٰ نے کہا کیا آپ اسے توڑ رہے ہیں تاکہ کشتی والوں کو ڈبو دیں، یہ تو آپ نے بڑی (خطرناک) بات کردی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmccxii{اس نے جواب دیا کہ میں نے تو پہلے ہی تجھ سے کہہ دیا تھا کہ تو میرے ساتھ ہرگز صبر نہ کرسکے گا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmccxiii{موسیٰ نے جواب دیا کہ میری بھول پر مجھے نہ پکڑیئے اور مجھے اپنے کام میں تنگی میں نہ ڈالیے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmccxiv{پھر دونوں چلے، یہاں تک کہ ایک لڑکے کو پایا، اس نے اسے مار ڈاﻻ، موسیٰ نے کہا کہ کیا آپ نے ایک پاک جان کو بغیر کسی جان کے عوض مار ڈاﻻ؟ بےشک آپ نے تو بڑی ناپسندیده حرکت کی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmccxv{وه کہنے لگے کہ میں نے تم سے نہیں کہا تھا کہ تم میرے ہمراه ره کر ہرگز صبر نہیں کر سکتے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmccxvi{موسیٰ (علیہ السلام) نے جواب دیا اگر اب اس کے بعد میں آپ سے کسی چیز کے بارے میں سوال کروں تو بیشک آپ مجھے اپنے ساتھ نہ رکھنا، یقیناً آپ میری طرف سے (حد) عذر کو پہنچ چکے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmccxvii{پھر دونوں چلے ایک گاؤں والوں کے پاس آکر ان سے کھانا طلب کیا تو انہوں نے ان کی مہمانداری سے صاف انکار کر دیا، دونوں نے وہاں ایک دیوار پائی جو گراہی چاہتی تھی، اس نے اسے ٹھیک اور درست کر دیا، موسیٰ (علیہ السلام) کہنے لگے اگر آپ چاہتے تو اس پر اجرت لے لیتے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmccxviii{اس نے کہا بس یہ جدائی ہے میرے اور تیرے درمیان، اب میں تجھے ان باتوں کی اصلیت بھی بتا دوں گا جس پر تجھ سے صبر نہ ہو سکا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmccxix{کشتی تو چند مسکینوں کی تھی جو دریا میں کام کاج کرتے تھے۔ میں نے اس میں کچھ توڑ پھوڑ کرنے کا اراده کر لیا کیونکہ ان کے آگے ایک بادشاه تھا جو ہر ایک (صحیح سالم) کشتی کو جبراً ضبط کر لیتا تھا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmccxx{اور اس لڑکے کے ماں باپ ایمان والے تھے۔ ہمیں خوف ہوا کہ کہیں یہ انہیں اپنی سرکشی اور کفر سے عاجز وپریشان نہ کر دے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmccxxi{اس لئے ہم نے چاہا کہ انہیں ان کا پروردگار اس کے بدلے اس سے بہتر پاکیزگی واﻻ اور اس سے زیاده محبت اور پیار واﻻ بچہ عنایت فرمائے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmccxxii{دیوار کا قصہ یہ ہے کہ اس شہر میں دو یتیم بچے ہیں جن کا خزانہ ان کی اس دیوار کے نیچے دفن ہے، ان کا باپ بڑا نیک شخص تھا تو تیرے رب کی چاہت تھی کہ یہ دونوں یتیم اپنی جوانی کی عمر میں آکر اپنا یہ خزانہ تیرے رب کی مہربانی اور رحمت سے نکال لیں، میں نے اپنی رائے سے کوئی کام نہیں کیا، یہ تھی اصل حقیقت ان واقعات کی جن پر آپ سے صبر نہ ہو سکا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmccxxiii{آپ سے ذوالقرنین کا واقعہ یہ لوگ دریافت کر رہے ہیں، آپ کہہ دیجئے کہ میں ان کا تھوڑا سا حال تمہیں پڑھ کر سناتا ہوں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmccxxiv{ہم نے اسے زمین میں قوت عطا فرمائی تھی اور اسے ہر چیز کے سامان بھی عنایت کردیے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmccxxv{وه ایک راه کے پیچھے لگا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmccxxvi{یہاں تک کہ سورج ڈوبنے کی جگہ پہنچ گیا اور اسے ایک دلدل کےچشمے میں غروب ہوتا ہوا پایا اور اس چشمے کے پاس ایک قوم کو بھی پایا، ہم نے فرما دیا کہ اے ذوالقرنین! یا تو تو انہیں تکلیف پہنچائے یا ان کے بارے میں تو کوئی بہترین روش اختیار کرے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmccxxvii{اس نے کہا کہ جو ﻇلم کرے گا اسے تو ہم بھی اب سزا دیں گے، پھر وه اپنے پروردگار کی طرف لوٹایا جائے گا اور وه اسے سخت تر عذاب دے گا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmccxxviii{ہاں جو ایمان ﻻئے اور نیک اعمال کرے اس کے لئے تو بدلے میں بھلائی ہے اور ہم اسے اپنے کام میں بھی آسانی ہی کا حکم دیں گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmccxxix{پھر وه اور راه کے پیچھے لگا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmccxxx{یہاں تک کہ جب سورج نکلنے کی جگہ تک پہنچا تو اسے ایک ایسی قوم پر نکلتا پایا کہ ان کے لئے ہم نے اس سے اور کوئی اوٹ نہیں بنائی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmccxxxi{واقعہ ایسا ہی ہے اور ہم نے اس کے پاس کی کل خبروں کا احاطہ کر رکھا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmccxxxii{وه پھر ایک سفر کے سامان میں لگا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiii{یہاں تک کہ جب دو دیواروں کے درمیان پہنچا ان دونوں کے پرے اس نے ایک ایسی قوم پائی جو بات سمجھنے کے قریب بھی نہ تھی\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiv{انہوں نے کہا اے ذوالقرنین! یاجوج ماجوج اس ملک میں (بڑے بھاری) فسادی ہیں، تو کیا ہم آپ کے لئے کچھ خرچ کا انتظام کر دیں؟ (اس شرط پر کہ) آپ ہمارے اور ان کے درمیان ایک دیوار بنادیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmccxxxv{اس نے جواب دیا کہ میرے اختیار میں میرے پروردگار نے جو دے رکھا ہے وہی بہتر ہے، تم صرف قوت طاقت سے میری مدد کرو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvi{میں تم میں اور ان میں مضبوط حجاب بنا دیتا ہوں۔ مجھے لوہے کی چادریں ﻻ دو۔ یہاں تک کہ جب ان دونوں پہاڑوں کے درمیان دیوار برابر کر دی تو حکم دیا کہ آگ تیز جلاؤ تاوقتیکہ لوہے کی ان چادروں کو بالکل آگ کر دیا، تو فرمایا میرے پاس ﻻؤ اس پر پگھلا ہوا تانبا ڈال دوں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvii{پس تو ان میں اس دیوار کے اوپر چڑھنے کی طاقت تھی اور نہ ان میں کوئی سوراخ کر سکتے تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmccxxxviii{کہا یہ صرف میرے رب کی مہربانی ہے ہاں جب میرے رب کا وعده آئے گا تو اسے زمین بوس کر دے گا، بیشک میرے رب کا وعده سچا اور حق ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmccxxxix{اس دن ہم انہیں آپس میں ایک دوسرے میں گڈ مڈ ہوتے ہوئے چھوڑ دیں گے اور صور پھونک دیا جائے گا پس سب کو اکٹھا کرکے ہم جمع کر لیں گے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmccxl{اس دن ہم جہنم کو (بھی) کافروں کے سامنے ﻻکھڑا کر دیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmccxli{جن کی آنکھیں میری یاد سے پردے میں تھی اور (امر حق) سن بھی نہیں سکتے تھے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmccxlii{کیا کافر یہ خیال کیے بیٹھے ہیں؟ کہ میرے سوا وه میرے بندوں کو اپنا حمایتی بنا لیں گے؟ (سنو) ہم نے تو ان کفار کی مہمانی کے لئے جہنم کو تیار کر رکھا ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmccxliii{کہہ دیجئے کہ اگر (تم کہو تو) میں تمہیں بتا دوں کہ باعتبار اعمال سب سے زیاده خسارے میں کون ہیں؟\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmccxliv{وه ہیں کہ جن کی دنیوی زندگی کی تمام تر کوششیں بیکار ہوگئیں اور وه اسی گمان میں رہے کہ وه بہت اچھے کام کر رہے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmccxlv{یہی وه لوگ ہیں جنہوں نے اپنے پروردگار کی آیتوں اور اس کی ملاقات سے کفر کیا، اس لئے ان کے اعمال غارت ہوگئے پس قیامت کے دن ہم ان کا کوئی وزن قائم نہ کریں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmccxlvi{حال یہ ہے کہ ان کا بدلہ جہنم ہے کیونکہ انہوں نے کفر کیا اور میری آیتوں اور میرے رسولوں کو مذاق میں اڑایا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmccxlvii{جو لوگ ایمان ﻻئے اور انہوں نے کام بھی اچھے کیے یقیناً ان کے لئے الفردوس کے باغات کی مہمانی ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmccxlviii{جہاں وه ہمیشہ رہا کریں گے جس جگہ کو بدلنے کا کبھی بھی ان کا اراده ہی نہ ہوگا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmccxlix{کہہ دیجئے کہ اگر میرے پروردگار کی باتوں کے لکھنے کے لئے سمندر سیاہی بن جائے تو وه بھی میرے رب کی باتوں کے ختم ہونے سے پہلے ہی ختم ہو جائے گا، گو ہم اسی جیسا اور بھی اس کی مدد میں لے آئیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmccl{آپ کہہ دیجئے کہ میں تو تم جیسا ہی ایک انسان ہوں۔ (ہاں) میری جانب وحی کی جاتی ہے کہ سب کا معبود صرف ایک ہی معبود ہے، تو جسے بھی اپنے پروردگار سے ملنے کی آرزو ہو اسے چاہئے کہ نیک اعمال کرے اور اپنے پروردگار کی عبادت میں کسی کو بھی شریک نہ کرے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmccli{\basmalahur کہیعص\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcclii{یہ ہے تیرے پروردگار کی اس مہربانی کا ذکر جو اس نے اپنے بندے زکریا پر کی تھی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmccliii{جبکہ اس نے اپنے رب سے چپکے چپکے دعا کی تھی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccliv{کہ اے میرے پروردگار! میری ہڈیاں کمزور ہوگئی ہیں اور سر بڑھاپے کی وجہ سے بھڑک اٹھا ہے، لیکن میں کبھی بھی تجھ سے دعا کر کے محروم نہیں رہا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcclv{مجھے اپنے مرنے کے بعد اپنے قرابت والوں کا ڈر ہے، میری بیوی بھی بانجھ ہے پس تو مجھے اپنے پاس سے وارث عطا فرما\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcclvi{جو میرا بھی وارث ہو اور یعقوب (علیہ السلام) کے خاندان کا بھی جانشین اور میرے رب! تو اسے مقبول بنده بنا لے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcclvii{اے زکریا! ہم تجھے ایک بچے کی خوشخبری دیتے ہیں جس کا نام یحيٰ ہے، ہم نے اس سے پہلے اس کا ہم نام بھی کسی کو نہیں کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcclviii{زکریا (علیہ السلام) کہنے لگے میرے رب! میرے ہاں لڑکا کیسے ہوگا، جبکہ میری بیوی بانجھ اور میں خود بڑھاپے کے انتہائی ضعف کو پہنچ چکا ہوں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcclix{ارشاد ہوا کہ وعده اسی طرح ہو چکا، تیرے رب نے فرما دیا ہے کہ مجھ پر تو یہ بالکل آسان ہے اور تو خود جبکہ کچھ نہ تھا میں تجھے پیدا کر چکا ہوں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcclx{کہنے لگے میرے پروردگار میرے لئے کوئی علامت مقرر فرما دے، ارشاد ہوا کہ تیرے لئے علامت یہ ہے کہ باوجود بھلا چنگا ہونے کے تو تین راتوں تک کسی شخص سے بول نہ سکے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcclxi{اب زکریا (علیہ السلام) اپنے حجرے سے نکل کر اپنی قوم کے پاس آکر انہیں اشاره کرتے ہیں کہ تم صبح وشام اللہ تعالیٰ کی تسبیح بیان کرو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcclxii{اے یحيٰ! میری کتاب کو مضبوطی سے تھام لے اور ہم نے اسے لڑکپن ہی سے دانائی عطا فرما دی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcclxiii{اور اپنے پاس سے شفقت اور پاکیزگی بھی، وه پرہیزگار شخص تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcclxiv{اور اپنے ماں باپ سے نیک سلوک کرنے واﻻ تھا وه سرکش اور گناه گار نہ تھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcclxv{اس پر سلام ہے جس دن وه پیدا ہوا اور جس دن وه مرے اور جس دن وه زنده کرکے اٹھایا جائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcclxvi{اس کتاب میں مریم کا بھی واقعہ بیان کر۔ جبکہ وه اپنے گھر کے لوگوں سے علیحده ہو کر مشرقی جانب آئیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcclxvii{اور ان لوگوں کی طرف سے پرده کر لیا، پھر ہم نے اس کے پاس اپنی روح (جبرائیل علیہ السلام) کو بھیجا پس وه اس کے سامنے پورا آدمی بن کر ﻇاہر ہوا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcclxviii{یہ کہنے لگیں میں تجھ سے رحمٰن کی پناه مانگتی ہوں اگر تو کچھ بھی اللہ سے ڈرنے واﻻ ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcclxix{اس نے جواب دیا کہ میں تو اللہ کا بھیجا ہوا قاصد ہوں، تجھے ایک پاکیزه لڑکا دینے آیا ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcclxx{کہنے لگیں بھلا میرے ہاں بچہ کیسے ہو سکتا ہے؟ مجھے تو کسی انسان کا ہاتھ تک نہیں لگا اور نہ میں بدکار ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcclxxi{اس نے کہا بات تو یہی ہے۔ لیکن تیرے پروردگار کا ارشاد ہے کہ وه مجھ پر بہت ہی آسان ہے ہم تو اسے لوگوں کے لئے ایک نشانی بنا دیں گے اور اپنی خاص رحمت، یہ تو ایک طے شده بات ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcclxxii{پس وه حمل سے ہو گئیں اوراسی وجہ سے وه یکسو ہو کر ایک دور کی جگہ چلی گئیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiii{پھر درِد زه ایک کھجور کے تنے کے نیچے لے آیا، بولی کاش! میں اس سے پہلے ہی مر گئی ہوتی اور لوگوں کی یاد سے بھی بھولی بسری ہو جاتی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiv{اتنے میں اسے نیچے سے ہی آواز دی کہ آزرده خاطر نہ ہو، تیرے رب نے تیرے پاؤں تلے ایک چشمہ جاری کر دیا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcclxxv{اور اس کھجور کے تنے کو اپنی طرف ہلا، یہ تیرے سامنے تروتازه پکی کھجوریں گرا دے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvi{اب چین سے کھا پی اور آنکھیں ٹھنڈی رکھ، اگر تجھے کوئی انسان نظر پڑ جائے تو کہہ دینا کہ میں نے اللہ رحمنٰ کے نام کا روزه مان رکھا ہے۔ میں آج کسی شخص سے بات نہ کروں گی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvii{اب حضرت عیسیٰ (علیہ السلام) کو لئے ہوئے وه اپنی قوم کے پاس آئیں۔ سب کہنے لگے مریم تو نے بڑی بری حرکت کی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcclxxviii{اے ہارون کی بہن! نہ تو تیرا باپ برا آدمی تھا اور نہ تیری ماں بدکار تھی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcclxxix{مریم نے اپنے بچے کی طرف اشاره کیا۔ سب کہنے لگے کہ لو بھلا ہم گود کے بچے سے باتیں کیسے کریں؟\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcclxxx{بچہ بول اٹھا کہ میں اللہ تعالیٰ کا بنده ہوں۔ اس نے مجھے کتاب عطا فرمائی اور مجھے اپنا پیغمبر بنایا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxi{اور اس نے مجھے بابرکت کیا ہے جہاں بھی میں ہوں، اور اس نے مجھے نماز اور زکوٰة کا حکم دیا ہے جب تک بھی میں زنده رہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxii{اور اس نے مجھے اپنی والده کا خدمت گزار بنایا ہے اور مجھے سرکش اور بدبخت نہیں کیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiii{اور مجھ پر میری پیدائش کے دن اور میری موت کے دن اور جس دن کہ میں دوباره زنده کھڑا کیا جاؤں گا، سلام ہی سلام ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiv{یہ ہے صحیح واقعہ عیسیٰ بن مریم (علیہ السلام) کا، یہی ہے وه حق بات جس میں لوگ شک وشبہ میں مبتلا ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxv{اللہ تعالیٰ کے لئے اوﻻد کا ہونا ﻻئق نہیں، وه تو بالکل پاک ذات ہے، وه تو جب کسی کام کے سر انجام دینے کا اراده کرتا ہے تو اسے کہہ دیتا ہے کہ ہو جا، وه اسی وقت ہو جاتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvi{میرا اور تم سب کا پروردگار صرف اللہ تعالیٰ ہی ہے۔ تم سب اسی کی عبادت کرو، یہی سیدھی راه ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvii{پھر یہ فرقے آپس میں اختلاف کرنے لگے، پس کافروں کے لئے ویل ہے ایک بڑے (سخت) دن کی حاضری سے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxviii{کیا خوب دیکھنے سننے والے ہوں گے اس دن جبکہ ہمارے سامنے حاضر ہوں گے، لیکن آج تو یہ ﻇالم لوگ صریح گمراہی میں پڑے ہوئے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxix{تو انہیں اس رنج وافسوس کے دن کا ڈر سنا دے جبکہ کام انجام کو پہنچا دیا جائے گا، اور یہ لوگ غفلت اور بے ایمانی میں ہی ره جائیں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccxc{خود زمین کے اور تمام زمین والوں کے وارث ہم ہی ہوں گے اور سب لوگ ہماری ہی طرف لوٹا کر ﻻئے جائیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccxci{اس کتاب میں ابراہیم (علیہ السلام) کا قصہ بیان کر، بیشک وه بڑی سچائی والے پیغمبر تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmccxcii{جبکہ انہوں نے اپنے باپ سے کہا کہ ابّا جان! آپ ان کی پوجا پاٹ کیوں کر رہے ہیں جو نہ سنیں نہ دیکھیں؟ نہ آپ کو کچھ بھی فائده پہنچا سکیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmccxciii{میرے مہربان باپ! آپ دیکھیئے میرے پاس وه علم آیا ہے جو آپ کے پاس آیا ہی نہیں، تو آپ میری ہی مانیں میں بالکل سیدھی راه کی طرف آپ کی رہبری کروں گا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmccxciv{میرے ابّا جان آپ شیطان کی پرستش سے باز آجائیں شیطان تو رحم وکرم والے اللہ تعالیٰ کا بڑا ہی نافرمان ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmccxcv{ابّا جان! مجھے خوف لگا ہوا کہ کہیں آپ پر کوئی عذاب الٰہی نہ آپڑے کہ آپ شیطان کے ساتھی بن جائیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmccxcvi{اس نے جواب دیا کہ اے ابراہیم! کیا تو ہمارے معبودوں سے روگردانی کر رہا ہے۔ سن اگر تو باز نہ آیا تو میں تجھے پتھروں سے مار ڈالوں گا، جا ایک مدت دراز تک مجھ سے الگ ره\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmccxcvii{کہا اچھا تم پر سلام ہو، میں تو اپنے پروردگار سے تمہاری بخشش کی دعا کرتا رہوں گا، وه مجھ پر حد درجہ مہربان ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmccxcviii{میں تو تمہیں بھی اور جن جن کو تم اللہ تعالیٰ کے سوا پکارتے ہو انہیں بھی سب کو چھوڑ رہا ہوں۔ صرف اپنے پروردگار کو پکارتا رہوں گا، مجھے یقین ہے کہ میں اپنے پروردگار سے دعا مانگ کر محروم نہ رہوں گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmccxcix{جب ابراہیم (علیہ السلام) ان سب کو اور اللہ کے سوا ان کے سب معبودوں کو چھوڑ چکے تو ہم نے انہیں اسحاق ویعقوب (علیہما السلام) عطا فرمائے، اور دونوں کو نبی بنا دیا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmccc{اور ان سب کو ہم نے اپنی بہت سی رحمتیں عطا فرمائیں اور ہم نے ان کے ذکر جمیل کو بلند درجے کا کر دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmccci{اس قرآن میں موسیٰ (علیہ السلام) کا ذکر بھی کر، جو چنا ہوا اور رسول اور نبی تھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcccii{ہم نے اسے طور کی دائیں جانب سے ندا کی اور راز گوئی کرتے ہوئے اسے قریب کر لیا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmccciii{اور اپنی خاص مہربانی سے اس کے بھائی کو نبی بنا کر عطا فرمایا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmccciv{اس کتاب میں اسماعیل (علیہ السلام) کا واقعہ بھی بیان کر، وه بڑا ہی وعدے کا سچا تھا اور تھا بھی رسول اور نبی\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcccv{وه اپنے گھر والوں کو برابر نماز اور زکوٰة کاحکم دیتا تھا، اور تھا بھی اپنے پروردگار کی بارگاه میں پسندیده اور مقبول\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcccvi{اور اس کتاب میں ادریس (علیہ السلام) کا بھی ذکر کر، وه بھی نیک کردار پیغمبر تھا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcccvii{ہم نےاسے بلند مقام پر اٹھا لیا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcccviii{یہی وه انبیا ہیں جن پر اللہ تعالیٰ نے فضل وکرم کیا جو اوﻻد آدم میں سے ہیں اور ان لوگوں کی نسل سے ہیں جنہیں ہم نے نوح (علیہ السلام) کے ساتھ کشتی میں چڑھا لیا تھا، اور اوﻻد ابراہیم ویعقوب سے اور ہماری طرف سے راه یافتہ اور ہمارے پسندیده لوگوں میں سے۔ ان کے سامنے جب اللہ رحمان کی آیتوں کی تلاوت کی جاتی تھی یہ سجده کرتے اور روتے گڑگڑاتے گر پڑتے تھے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcccix{پھر ان کے بعد ایسے ناخلف پیدا ہوئے کہ انہوں نے نماز ضائع کردی اور نفسانی خواہشوں کے پیچھے پڑ گئے، سو ان کا نقصان ان کے آگے آئے گا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcccx{بجز ان کے جو توبہ کر لیں اور ایمان ﻻئیں اور نیک عمل کریں۔ ایسے لوگ جنت میں جائیں گے اور ان کی ذرا سی بھی حق تلفی نہ کی جائے گی\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcccxi{ہمیشگی والی جنتوں میں جن کا غائبانہ وعده اللہ مہربان نے اپنے بندوں سے کیا ہے۔ بیشک اس کا وعده پورا ہونے واﻻ ہی ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcccxii{وه لوگ وہاں کوئی لغو بات نہ سنیں گے صرف سلام ہی سلام سنیں گے، ان کے لئے وہاں صبح شام ان کا رزق ہوگا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcccxiii{یہ ہے وه جنت جس کا وارث ہم اپنے بندوں میں سے انہیں بناتے ہیں جو متقی ہوں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcccxiv{ہم بغیر تیرے رب کے حکم کے اتر نہیں سکتے، ہمارے آگے پیچھے اور ان کے درمیان کی کل چیزیں اسی کی ملکیت میں ہیں، تیرا پروردگار بھولنے واﻻ نہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcccxv{آسمانوں کا، زمین کا اور جو کچھ ان کے درمیان ہے سب کا رب وہی ہے تو اسی کی بندگی کر اور اس کی عبادت پر جم جا۔ کیا تیرے علم میں اس کا ہمنام ہم پلہ کوئی اور بھی ہے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcccxvi{انسان کہتا ہے کہ جب میں مرجاؤں گا تو کیا پھر زنده کر کے نکالا جاؤں گا؟\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcccxvii{کیا یہ انسان اتنا بھی یاد نہیں رکھتا کہ ہم نے اسے اس سے پہلے پیدا کیا حاﻻنکہ وه کچھ بھی نہ تھا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcccxviii{تیرے پروردگار کی قسم! ہم انہیں اور شیطانوں کو جمع کر کے ضرور ضرور جہنم کے اردگرد گھٹنوں کے بل گرے ہوئے حاضر کر دیں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcccxix{ہم پھر ہر ہر گروه سے انہیں الگ نکال کھڑا کریں گے جو اللہ رحمنٰ سے بہت اکڑے اکڑے پھرتے تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcccxx{پھر ہم انہیں بھی خوب جانتے ہیں جو جہنم کے داخلے کے زیاده سزاوار ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcccxxi{تم میں سے ہر ایک وہاں ضرور وارد ہونے واﻻ ہے، یہ تیرے پروردگار کے ذمے قطعی، فیصل شده امر ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcccxxii{پھر ہم پرہیزگاروں کو تو بچالیں گے اور نافرمانوں کو اسی میں گھٹنوں کے بل گرا ہوا چھوڑ دیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiii{جب ان کے سامنے ہماری روشن آیتیں تلاوت کی جاتی ہیں تو کافر مسلمانوں سے کہتے ہیں بتاؤ ہم تم دونوں جماعتوں میں سے کس کا مرتبہ زیاده ہے؟ اور کس کی مجلس شاندار ہے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiv{ہم تو ان سے پہلے بہت سی جماعتوں کو غارت کر چکے ہیں جو ساز وسامان اور نام ونمود میں ان سے بڑھ چڑھ کر تھیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcccxxv{کہہ دیجئے! جو گمراہی میں ہوتا اللہ رحمنٰ اس کو خوب لمبی مہلت دیتا ہے، یہاں تک کہ وه ان چیزوں کو دیکھ لیں جنکا وعده کیے جاتے ہیں یعنی عذاب یا قیامت کو، اس وقت ان کو صحیح طور پر معلوم ہو جائے گا کہ کون برے مرتبے واﻻ اور کس کا جتھا کمزور ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvi{اور ہدایت یافتہ لوگوں کو اللہ تعالیٰ ہدایت میں بڑھاتا ہے، اور باقی رہنے والی نیکیاں تیرے رب کے نزدیک ﺛواب کے لحاظ سے اور انجام کے لحاظ سے بہت ہی بہتر ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvii{کیا تو نے اسے بھی دیکھا جس نے ہماری آیتوں سے کفر کیا اور کہا کہ مجھے تو مال واوﻻد ضرور ہی دی جائے گی\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcccxxviii{کیا وه غیب پر مطلع ہے یا اللہ کا کوئی وعده لے چکا ہے؟\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcccxxix{ہرگز نہیں، یہ جو بھی کہہ رہا ہے ہم اسے ضرور لکھ لیں گے، اور اس کے لئے عذاب بڑھائے چلے جائیں گے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcccxxx{یہ جن چیزوں کو کہہ رہا ہے اسے ہم اس کے بعد لے لیں گے۔ اور یہ تو بالکل اکیلا ہی ہمارے سامنے حاضر ہوگا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxi{انہوں نے اللہ کے سوا دوسرے معبود بنا رکھے ہیں کہ وه ان کے لئے باعﺚ عزت ہوں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxii{لیکن ایسا ہرگز ہونا نہیں۔ وه تو ان کی پوجا سے منکر ہو جائیں گے، اور الٹے ان کے دشمن بن جائیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiii{کیا تو نے نہیں دیکھا کہ ہم کافروں کے پاس شیطانوں کو بھیجتے ہیں جو انہیں خوب اکساتے ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiv{تو ان کے بارے میں جلدی نہ کر، ہم تو خود ہی ان کے لئے مدت شماری کر رہے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxv{جس دن ہم پرہیزگاروں کو اللہ رحمان کی طرف بطور مہمان جمع کریں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvi{اور گناه گاروں کوسخت پیاس کی حالت میں جہنم کی طرف ہانک لے جائیں گے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvii{کسی کو شفاعت کا اختیار نہ ہوگا سوائے ان کے جنہوں نے اللہ تعالیٰ کی طرف سے کوئی قول قرار لے لیا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxviii{ان کا قول تو یہ ہے کہ اللہ رحمٰن نے بھی اوﻻد اختیار کی ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxix{یقیناً تم بہت بری اور بھاری چیز ﻻئے ہو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcccxl{قریب ہے کہ اس قول کی وجہ سے آسمان پھٹ جائیں اور زمین شق ہوجائے اور پہاڑ ریزے ریزے ہو جائیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcccxli{کہ وه رحمان کی اوﻻد ﺛابت کرنے بیٹھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcccxlii{شان رحمٰن کے ﻻئق نہیں کہ وه اوﻻد رکھے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcccxliii{آسمان وزمین میں جو بھی ہیں سب کے سب اللہ کے غلام بن کر ہی آنے والے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcccxliv{ان سب کو اس نے گھیر رکھا ہے اور سب کو پوری طرح گن بھی رکھا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcccxlv{یہ سارے کے سارے قیامت کے دن اکیلے اس کے پاس حاضر ہونے والے ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvi{بیشک جو ایمان لائے ہیں اور جنہوں نے شائستہ اعمال کیے ہیں ان کے لیے اللہ رحمٰن محبت پیدا کردے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvii{ہم نے اس قرآن کو تیری زبان میں بہت ہی آسان کر دیا ہے کہ تو اس کے ذریعہ سے پرہیزگاروں کو خوشخبری دے اور جھگڑالو لوگوں کو ڈرا دے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcccxlviii{ہم نے ان سے پہلے بہت سی جماعتیں تباہ کر دی ہیں، کیا ان میں سے ایک کی بھی آہٹ تو پاتا ہے یا ان کی آواز کی بھنک بھی تیرے کان میں پڑتی ہے؟\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcccxlix{\basmalahur طٰہٰ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcccl{ہم نے یہ قرآن تجھ پر اس لئے نہیں اتارا کہ تو مشقت میں پڑ جائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcccli{بلکہ اس کی نصیحت کے لئے جو اللہ سے ڈرتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccclii{اس کا اتارنا اس کی طرف سے ہے جس نے زمین کو اور بلند آسمانوں کو پیدا کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcccliii{جو رحمٰن ہے، عرش پر قائم ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcccliv{جس کی ملکیت آسمانوں اور زمین اور ان دونوں کے درمیان اور (کرہٴ خاک) کے نیچے کی ہر ایک چیز پر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmccclv{اگر تو اونچی بات کہے تو وه تو ہر ایک پوشیده، بلکہ پوشیده سے پوشیده تر چیز کو بھی بخوبی جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmccclvi{وہی اللہ ہے جس کے سوا کوئی معبود نہیں، بہترین نام اسی کے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmccclvii{تجھے موسیٰ (علیہ السلام) کا قصہ بھی معلوم ہے؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmccclviii{جبکہ اس نے آگ دیکھ کر اپنے گھر والوں سے کہا کہ تم ذرا سی دیر ٹھہر جاؤ مجھے آگ دکھائی دی ہے۔ بہت ممکن ہے کہ میں اس کا کوئی انگارا تمہارے پاس ﻻؤں یا آگ کے پاس سے راستے کی اطلاع پاؤں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmccclix{جب وه وہاں پہنچے تو آواز دی گئی اے موسیٰ!\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmccclx{یقیناً میں ہی تیرا پروردگار ہوں تو اپنی جوتیاں اتار دے، کیونکہ تو پاک میدان طویٰ میں ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmccclxi{اور میں نے تجھے منتخب کر لیا اب جو وحی کی جائے اسے کان لگا کر سن\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmccclxii{بیشک میں ہی اللہ ہوں، میرے سوا عبادت کے ﻻئق اور کوئی نہیں پس تو میری ہی عبادت کر، اور میری یاد کے لئے نماز قائم رکھ\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmccclxiii{قیامت یقیناً آنے والی ہے جسے میں پوشیده رکھنا چاہتا ہوں تاکہ ہر شخص کو وه بدلہ دیا جائے جو اس نے کوشش کی ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmccclxiv{پس اب اس کے یقین سے تجھے کوئی ایسا شخص روک نہ دے جو اس پر ایمان نہ رکھتا ہو اور اپنی خواہش کے پیچھے پڑا ہو، ورنہ تو ہلاک ہوجائے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmccclxv{اے موسیٰ! تیرے اس دائیں ہاتھ میں کیا ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmccclxvi{جواب دیا کہ یہ میری ﻻٹھی ہے، جس پر میں ٹیک لگاتا ہوں اور جس سے میں اپنی بکریوں کے لئے پتے جھاڑ لیا کرتا ہوں اور بھی اس میں مجھے بہت سے فائدے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmccclxvii{فرمایا اے موسیٰ! اسے ہاتھ سے نیچے ڈال دے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmccclxviii{ڈالتے ہی وه سانﭗ بن کر دوڑنے لگی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmccclxix{فرمایا بے خوف ہو کر اسے پکڑ لے، ہم اسے اسی پہلی سی صورت میں دوباره ﻻ دیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmccclxx{اور اپنا ہاتھ اپنی بغل میں ڈال لے تو وه سفید چمکتا ہوا ہو کر نکلے گا، لیکن بغیر کسی عیب (اور روگ) کے یہ دوسرا معجزه ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmccclxxi{یہ اس لئے کہ ہم تجھے اپنی بڑی بڑی نشانیاں دکھانا چاہتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmccclxxii{اب تو فرعون کی طرف جا اس نے بڑی سرکشی مچا رکھی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiii{موسیٰ (علیہ السلام) نے کہا اے میرے پروردگار! میرا سینہ میرے لئے کھول دے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiv{اور میرے کام کو مجھ پر آسان کر دے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmccclxxv{اور میری زبان کی گره بھی کھول دے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvi{تاکہ لوگ میری بات اچھی طرح سمجھ سکیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvii{اور میرا وزیر میرے کنبے میں سے کر دے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmccclxxviii{یعنی میرے بھائی ہارون (علیہ السلام) کو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmccclxxix{تو اس سے میری کمر کس دے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmccclxxx{اور اسے میرا شریک کار کر دے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxi{تاکہ ہم دونوں بکثرت تیری تسبیح بیان کریں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxii{اور بکثرت تیری یاد کریں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiii{بیشک تو ہمیں خوب دیکھنے بھالنے واﻻ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiv{جناب باری تعالیٰ نے فرمایا موسیٰ تیرے تمام سواﻻت پورے کر دیئے گئے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxv{ہم نے تو تجھ پرایک بار اور بھی بڑا احسان کیا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvi{جبکہ ہم نے تیری ماں کو وه الہام کیا جس کا ذکر اب کیا جا رہا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvii{کہ تو اسے صندوق میں بند کرکے دریا میں چھوڑ دے، پس دریا اسے کنارے ﻻ ڈالے گا اور میرا اور خود اس کا دشمن اسے لے لے گا، اور میں نے اپنی طرف کی خاص محبت ومقبولیت تجھ پر ڈال دی۔ تاکہ تیری پرورش میری آنکھوں کے سامنے کی جائے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxviii{(یاد کر) جبکہ تیری بہن چل رہی تھی اور کہہ رہی تھی کہ اگر تم کہو تو میں اسے بتا دوں جو اس کی نگہبانی کرے، اس تدبیر سے ہم نے تجھے پھر تیری ماں کے پاس پہنچایا کہ اس کی آنکھیں ٹھنڈی رہیں اور وه غمگین نہ ہو۔ اور تو نے ایک شخص کو مار ڈاﻻ تھا اس پر بھی ہم نے تجھے غم سے بچا لیا، غرض ہم نے تجھے اچھی طرح آزما لیا۔ پھر تو کئی سال تک مدین کے لوگوں میں ٹھہرا رہا، پھر تقدیر الٰہی کے مطابق اے موسیٰ! تو آیا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxix{اور میں نے تجھے خاص اپنی ذات کے لئے پسند فرما لیا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcccxc{اب تو اپنے بھائی سمیت میری نشانیاں ہمراه لئے ہوئے جا، اور خبردار میرے ذکر میں سستی نہ کرنا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcccxci{تم دونوں فرعون کے پاس جاؤ اس نے بڑی سرکشی کی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcccxcii{اسے نرمی سے سمجھاؤ کہ شاید وه سمجھ لے یا ڈر جائے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcccxciii{دونوں نے کہا اے ہمارے رب! ہمیں خوف ہے کہ کہیں فرعون ہم پر کوئی زیادتی نہ کرے یا اپنی سرکشی میں بڑھ نہ جائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcccxciv{جواب ملا کہ تم مطلقاً خوف نہ کرو میں تمہارے ساتھ ہوں اور سنتا دیکھتا رہوں گا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcccxcv{تم اس کے پاس جا کر کہو کہ ہم تیرے پروردگار کے پیغمبر ہیں تو ہمارے ساتھ بنی اسرائیل کو بھیج دے، ان کی سزائیں موقوف کر۔ ہم تو تیرے پاس تیرے رب کی طرف سے نشانی لے کر آئے ہیں اور سلامتی اسی کے لئے ہے جو ہدایت کا پابند ہو جائے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvi{ہماری طرف وحی کی گئی ہے کہ جو جھٹلائے اور روگردانی کرے اس کے لئے عذاب ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvii{فرعون نے پوچھا کہ اے موسیٰ تم دونوں کا رب کون ہے؟\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcccxcviii{جواب دیا کہ ہمارا رب وه ہے جس نے ہر ایک کو اس کی خاص صورت، شکل عنایت فرمائی پھر راه سجھا دی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcccxcix{اس نے کہا اچھا یہ تو بتاؤ اگلے زمانے والوں کا حال کیا ہونا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcd{جواب دیا کہ ان کا علم میرے رب کے ہاں کتاب میں موجود ہے، نہ تو میرا رب غلطی کرتا ہے نہ بھولتا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcdi{اسی نے تمہارے لئے زمین کو فرش بنایا ہے اور اس میں تمہارے چلنے کے لئے راستے بنائے ہیں اور آسمان سے پانی بھی وہی برساتا ہے، پھر اس برسات کی وجہ سے مختلف قسم کی پیداوار بھی ہم ہی پیدا کرتے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcdii{تم خود کھاؤ اور اپنے چوپایوں کو بھی چراؤ۔ کچھ شک نہیں کہ اس میں عقلمندوں کے لئے بہت سی نشانیاں ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcdiii{اسی زمین میں سے ہم نے تمہیں پیدا کیا اور اسی میں پھر واپس لوٹائیں گے اور اسی سے پھر دوباره تم سب کو نکال کھڑا کریں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcdiv{ہم نے اسےاپنی سب نشانیاں دکھا دیں لیکن پھر بھی اس نے جھٹلایا اور انکار کر دیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcdv{کہنے لگا اے موسیٰ! کیا تو اسی لئے آیا ہے کہ ہمیں اپنے جادو کے زور سے ہمارے ملک سے باہر نکال دے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcdvi{اچھا ہم بھی تیرے مقابلے میں اسی جیسا جادو ضرور ﻻئیں گے پس تو ہمارے اور اپنے درمیان ایک وعدے کا وقت مقرر کر لے، کہ نہ ہم اس کا خلاف کریں اور نہ تو، صاف میدان میں مقابلہ ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcdvii{موسیٰ (علیہ السلام) نے جواب دیا کہ زینت اور جشن کے دن کا وعده ہے اور یہ کہ لوگ دن چڑھے ہی جمع ہو جائیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcdviii{پس فرعون لوٹ گیا اور اس نے اپنے ہتھکنڈے جمع کیے پھر آگیا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcdix{موسی (علیہ السلام) نے ان سے کہا تمہاری شامت آچکی، اللہ تعالیٰ پر جھوٹ اور افترا نہ باندھو کہ وه تمہیں عذابوں سے ملیا میٹ کر دے، یاد رکھو وه کبھی کامیاب نہ ہوگا جس نے جھوٹی بات گھڑی\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcdx{پس یہ لوگ آپس کے مشوروں میں مختلف رائے ہوگئے اور چھﭗ کر چپکے چپکے مشوره کرنے لگے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcdxi{کہنے لگے یہ دونوں محض جادوگر ہیں اور ان کا پختہ اراده ہے کہ اپنے جادو کے زور سے تمہیں تمہارے ملک سے نکال باہر کر دیں اور تمہارے بہترین مذہب کو برباد کر دیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcdxii{تو تم بھی اپنا کوئی داؤ اٹھا نہ رکھو، پھر صف بندی کرکے آؤ۔ جو غالب آگیا وہی بازی لے گیا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcdxiii{کہنے لگے کہ اے موسیٰ! یا تو تو پہلے ڈال یا ہم پہلے ڈالنے والے بن جائیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcdxiv{جواب دیا کہ نہیں تم ہی پہلے ڈالو۔ اب تو موسیٰ (علیہ السلام) کو یہ خیال گزرنے لگا کہ ان کی رسیاں اور لکڑیاں ان کے جادو کے زور سے دوڑ بھاگ رہی ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcdxv{پس موسیٰ (علیہ السلام) نے اپنے دل ہی دل میں ڈر محسوس کیا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcdxvi{ہم نے فرمایا کچھ خوف نہ کر یقیناً تو ہی غالب اور برتر رہے گا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcdxvii{اور تیرے دائیں ہاتھ میں جو ہے اسے ڈالدے کہ ان کی تمام کاریگری کووه نگل جائے، انہوں نے جو کچھ بنایا ہے یہ صرف جادوگروں کے کرتب ہیں اور جادوگر کہیں سے بھی آئے کامیاب نہیں ہوتا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcdxviii{اب تو تمام جادوگر سجدے میں گر پڑے اور پکار اٹھے کہ ہم تو ہارون اور موسیٰ (علیہما السلام) کے رب پر ایمان ﻻئے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcdxix{فرعون کہنے لگا کہ کیا میری اجازت سے پہلے ہی تم اس پرایمان لے آئے؟ یقیناً یہی تمہارا وه بڑا بزرگ ہے جس نے تم سب کو جادو سکھایا ہے، (سن لو) میں تمہارے پاؤں الٹے سیدھے کٹوا کر تم سب کو کھجور کے تنوں میں سولی پر لٹکوا دوں گا، اور تمہیں پوری طرح معلوم ہوجائے گا کہ ہم میں سے کس کی مار زیاده سخت اور دیرپا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcdxx{انہوں نے جواب دیا کہ ناممکن ہے کہ ہم تجھے ترجیح دیں ان دلیلوں پر جو ہمارے سامنے آچکیں اور اس اللہ پر جس نے ہمیں پیدا کیا ہے اب تو تو جو کچھ کرنے وﻻ ہے کر گزر، تو جو کچھ بھی حکم چلا سکتا ہے وه اسی دنیوی زندگی میں ہی ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcdxxi{ہم (اس امید سے) اپنے پروردگار پرایمان ﻻئے کہ وه ہماری خطائیں معاف فرما دے اور (خاص کر) جادوگری (کا گناه،) جس پر تم نے ہمیں مجبور کیا ہے، اللہ ہی بہتر اور ہمیشہ باقی رہنے واﻻ ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcdxxii{بات یہی ہے کہ جو بھی گنہگار بن کر اللہ تعالیٰ کے ہاں حاضر ہوگا اس کے لئے دوزخ ہے، جہاں نہ موت ہوگی اور نہ زندگی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiii{اور جو بھی اس کے پاس ایمان کی حالت میں حاضر ہوگا اور اس نے اعمال بھی نیک کیے ہوں گے اس کے لئے بلند وباﻻ درجے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiv{ہمیشگی والی جنتیں جن کے نیچے نہریں لہریں لے رہی ہیں جہاں وه ہمیشہ (ہمیشہ) رہیں گے۔ یہی انعام ہے ہر اس شخص کا جو پاک ہوا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcdxxv{ہم نے موسیٰ (علیہ السلام) کی طرف وحی نازل فرمائی کہ تو راتوں رات میرے بندوں کو لے چل، اور ان کے لئے دریا میں خشک راستہ بنا لے، پھر نہ تجھے کسی کے آپکڑنے کا خطره ہوگا نہ ڈر\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvi{فرعون نے اپنے لشکروں سمیت ان کا تعاقب کیا پھر تو دریا ان سب پر چھا گیا جیسا کچھ چھا جانے واﻻ تھا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvii{فرعون نے اپنی قوم کو گمراہی میں ڈال دیا اور سیدھا راستہ نہ دکھایا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcdxxviii{اے بنی اسرائیل! دیکھو ہم نے تمہیں تمہارے دشمن سے نجات دی اور تم سے کوه طور کی دائیں طرف کا وعده کیا اور تم پر من وسلویٰ اتارا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcdxxix{تم ہماری دی ہوئی پاکیزه روزی کھاؤ، اور اس میں حد سے آگے نہ بڑھو، ورنہ تم پر میرا غضب نازل ہوگا، اور جس پر میرا غضب نازل ہو جائے وه یقیناً تباه ہوا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcdxxx{ہاں بیشک میں انہیں بخش دینے واﻻ ہوں جو توبہ کریں ایمان ﻻئیں نیک عمل کریں اور راه راست پر بھی رہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxi{اے موسیٰ! تجھے اپنی قوم سے (غافل کرکے) کون سی چیز جلدی لے آئی؟\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxii{کہا کہ وه لوگ بھی میرے پیچھے ہی پیچھے ہیں، اور میں نے اے رب! تیری طرف جلدی اس لئے کی کہ تو خوش ہو جائے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiii{فرمایا! ہم نے تیری قوم کو تیرے پیچھے آزمائش میں ڈال دیا اور انہیں سامری نے بہکا دیا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiv{پس موسیٰ (علیہ السلام) سخت غضبناک ہو کر رنج کے ساتھ واپس لوٹے، اور کہنے لگے کہ اے میری قوم والو! کیا تم سے تمہارے پروردگار نے نیک وعده نہیں کیا تھا؟ کیا اس کی مدت تمہیں لمبی معلوم ہوئی؟ بلکہ تمہارا اراده ہی یہ ہے کہ تم پر تمہارے پروردگار کا غضب نازل ہو؟ کہ تم نے میرے وعدے کا خلاف کیا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxv{انہوں نے جواب دیا کہ ہم نے اپنےاختیار سے آپ کے ساتھ وعدے کا خلاف نہیں کیا۔ بلکہ ہم پر زیورات قوم کے جو بوجھ ﻻد دیے گئے تھے انہیں ہم نے ڈال دیا، اور اسی طرح سامری نے بھی ڈال دیئے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvi{پھر اس نے لوگوں کے لئے ایک بچھڑا نکال کھڑا کیا یعنی بچھڑے کا بت، جس کی گائے کی سی آواز بھی تھی پھر کہنے لگے کہ یہی تمہارا معبود ہے اور موسیٰ کا بھی، لیکن موسیٰ بھول گیا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvii{کیا یہ گمراه لوگ یہ بھی نہیں دیکھتے کہ وه تو ان کی بات کا جواب بھی نہیں دے سکتا اور نہ ان کے کسی برے بھلے کا اختیار رکھتا ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxviii{اور ہارون (علیہ السلام) نےاس سے پہلے ہی ان سے کہہ دیا تھا اے میری قوم والو! اس بچھڑے سے تو صرف تمہاری آزمائش کی گئی ہے، تمہارا حقیقی پروردگار تو اللہ رحمنٰ ہی ہے، پس تم سب میری تابعداری کرو۔ اور میری بات مانتے چلے جاؤ\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxix{انہوں نے جواب دیا کہ موسیٰ (علیہ السلام) کی واپسی تک تو ہم اسی کے مجاور بنے بیٹھے رہیں گے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcdxl{موسیٰ (علیہ السلام) کہنے لگے اے ہارون! انہیں گمراه ہوتا ہوا دیکھتے ہوئے تجھے کس چیز نے روکا تھا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcdxli{کہ تو میرے پیچھے نہ آیا۔ کیا تو بھی میرے فرمان کا نافرمان بن بیٹھا\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcdxlii{ہارون (علیہ السلام) نے کہا اے میرے ماں جائے بھائی! میری داڑھی نہ پکڑ اور سر کے بال نہ کھینچ، مجھے تو صرف یہ خیال دامن گیر ہوا کہ کہیں آپ یہ (نہ) فرمائیں کہ تو نے بنی اسرائیل میں تفرقہ ڈال دیا اور میری بات کا انتظار نہ کیا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcdxliii{موسیٰ (علیہ السلام) نے پوچھا سامری تیرا کیا معاملہ ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcdxliv{اس نے جواب دیا کہ مجھے وه چیز دکھائی دی جو انہیں دکھائی نہیں دی، تو میں نے فرستادہٴ الٰہی کے نقش قدم سے ایک مٹھی بھر لی اسے اس میں ڈال دیا اسی طرح میرے دل نے یہ بات میرے لئے بھلی بنا دی\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcdxlv{کہا اچھا جا دنیا کی زندگی میں تیری سزا یہی ہے کہ تو کہتا رہے کہ مجھے نہ چھونا، اور ایک اور بھی وعده تیرے ساتھ ہے جو تجھ سے ہر گز نہ ٹلے گا، اور اب تو اپنے اس معبود کو بھی دیکھ لینا جس کا اعتکاف کیے ہوئے تھا کہ ہم اسے جلا کر دریا میں ریزه ریزه اڑا دیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvi{اصل بات یہی ہے کہ تم سب کا معبود برحق صرف اللہ ہی ہے اس کے سوا کوئی پرستش کے قابل نہیں۔ اس کا علم تمام چیزوں پر حاوی ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvii{اسی طرح ہم تیرے سامنے پہلے کی گزری ہوئی وارداتیں بیان فرما رہے ہیں اور یقیناً ہم تجھے اپنے پاس سے نصیحت عطا فرما چکے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcdxlviii{اس سے جو منھ پھیر لے گا وه یقیناً قیامت کے دن اپنا بھاری بوجھ ﻻدے ہوئے ہوگا\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcdxlix{جس میں ہمیشہ ہی رہے گا، اور ان کے لئے قیامت کے دن (بڑا) برا بوجھ ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcdl{جس دن صور پھونکا جائے گا اور گناه گاروں کو ہم اس دن (دہشت کی وجہ سے) نیلی پیلی آنکھوں کے ساتھ گھیر ﻻئیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcdli{وه آپس میں چپکے چپکے کہہ رہے ہوں گے کہ ہم تو (دنیا میں) صرف دس دن ہی رہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcdlii{جوکچھ وه کہہ رہے ہیں اس کی حقیقت سے ہم باخبر ہیں ان میں سب سے زیاده اچھی راه واﻻ کہہ رہا ہو گا کہ تم تو صرف ایک ہی دن رہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcdliii{وه آپ سے پہاڑوں کی نسبت سوال کرتے ہیں، تو آپ کہہ دیں کہ انہیں میرا رب ریزه ریزه کر کے اڑا دے گا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcdliv{اور زمین کو بالکل ہموار صاف میدان کر کے چھوڑے گا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcdlv{جس میں تو نہ کہیں موڑ دیکھے گا نہ اونچ نیچ\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcdlvi{جس دن لوگ پکارنے والے کے پیچھے چلیں گے جس میں کوئی کجی نہ ہوگی اور اللہ رحمنٰ کے سامنے تمام آوازیں پست ہو جائیں گی سوائے کھسر پھسر کے تجھے کچھ بھی سنائی نہ دے گا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcdlvii{اس دن سفارش کچھ کام نہیں آئے گی مگر جسے رحمنٰ حکم دے اور اس کی بات کو پسند فرمائے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcdlviii{جو کچھ ان کے آگے پیچھے ہے اسے اللہ ہی جانتا ہے مخلوق کا علم اس پر حاوی نہیں ہو سکتا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcdlix{تمام چہرے اس زنده اور قائم دائم مدبر، اللہ کے سامنے کمال عاجزی سے جھکے ہوئے ہونگے، یقیناً وه برباد ہوا جس نے ﻇلم ﻻد لیا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcdlx{اور جو نیک اعمال کرے اور ایمان واﻻ بھی ہو تو نہ اسے بے انصافی کا کھٹکا ہوگا نہ حق تلفی کا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmcdlxi{اسی طرح ہم نے تجھ پر عربی قرآن نازل فرمایا ہے اور طرح طرح سے اس میں ڈر کا بیان سنایا ہے تاکہ لوگ پرہیز گار بن جائیں یا ان کے دل میں سوچ سمجھ تو پیدا کرے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmcdlxii{پس اللہ عالی شان واﻻ سچا اور حقیقی بادشاه ہے۔ تو قرآن پڑھنے میں جلدی نہ کر اس سے پہلے کہ تیری طرف جو وحی کی جاتی ہے وه پوری کی جائے، ہاں یہ دعا کر کہ پروردگار! میرا علم بڑھا\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiii{ہم نے آدم کو پہلے ہی تاکیدی حکم دیا تھا لیکن وه بھول گیا اور ہم نے اس میں کوئی عزم نہیں پایا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiv{اور جب ہم نے فرشتوں سے کہا کہ آدم (علیہ السلام) کو سجده کرو تو ابلیس کے سوا سب نے کیا، اس نے صاف انکار کر دیا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmcdlxv{تو ہم نے کہا اے آدم! یہ تیرا اور تیری بیوی کا دشمن ہے (خیال رکھنا) ایسا نہ ہو کہ وه تم دونوں کو جنت سے نکلوا دے کہ تو مصیبت میں پڑ جائے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvi{یہاں تو تجھے یہ آرام ہے کہ نہ تو بھوکا ہوتا ہے نہ ننگا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvii{اور نہ تو یہاں پیاسا ہوتا ہے نہ دھوپ سے تکلیف اٹھاتا ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmcdlxviii{لیکن شیطان نے اسے وسوسہ ڈاﻻ، کہنے لگا کہ میں تجھے دائمی زندگی کا درخت اور بادشاہت بتلاؤں کہ جو کبھی پرانی نہ ہو\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmcdlxix{چنانچہ ان دونوں نے اس درخت سے کچھ کھا لیا پس ان کے ستر کھل گئے اور بہشت کے پتے اپنے اوپر ٹانکنے لگے۔ آدم (علیہ السلام) نے اپنے رب کی نافرمانی کی، پس بہک گیا\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmcdlxx{پھر اس کے رب نے نوازا، اس کی توبہ قبول کی اور اس کی رہنمائی کی\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxi{فرمایا، تم دونوں یہاں سےاتر جاؤ تم آپس میں ایک دوسرے کے دشمن ہو، اب تمہارے پاس کبھی میری طرف سے ہدایت پہنچے تو جو میری ہدایت کی پیروی کرے نہ تو وه بہکے گا نہ تکلیف میں پڑے گا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxii{اور (ہاں) جو میری یاد سے روگردانی کرے گا اس کی زندگی تنگی میں رہے گی، اور ہم اسے بروز قیامت اندھا کر کے اٹھائیں گے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiii{وه کہے گا کہ الٰہی! مجھے تو نے اندھا بنا کر کیوں اٹھایا؟ حاﻻنکہ میں تو دیکھتا بھالتا تھا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiv{(جواب ملے گا کہ) اسی طرح ہونا چاہئے تھا تو میری آئی ہوئی آیتوں کو بھول گیا تو آج تو بھی بھلا دیا جاتا ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxv{ہم ایسا ہی بدلہ ہر اس شخص کو دیا کرتے ہیں جو حد سے گزر جائے اور اپنے رب کی آیتوں پر ایمان نہ ﻻئے، اور بیشک آخرت کا عذاب نہایت ہی سخت اور باقی رہنے واﻻ ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvi{کیا ان کی رہبری اس بات نے بھی نہیں کی کہ ہم نے ان سے پہلے بہت سی بستیاں ہلاک کر دی ہیں جن کے رہنے سہنے کی جگہ یہ چل پھر رہے ہیں۔ یقیناً اس میں عقلمندوں کے لئے بہت سی نشانیاں ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvii{اگر تیرے رب کی بات پہلے ہی سے مقرر شده اور وقت معین کرده نہ ہوتا تو اسی وقت عذاب آچمٹتا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxviii{پس ان کی باتوں پر صبر کر اور اپنے پروردگار کی تسبیح اور تعریف بیان کرتا ره، سورج نکلنے سے پہلے اور اس کے ڈوبنے سے پہلے، رات کے مختلف وقتوں میں بھی اور دن کے حصوں میں بھی تسبیح کرتا ره، بہت ممکن ہے کہ تو راضی ہو جائے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxix{اور اپنی نگاہیں ہرگز ان چیزوں کی طرف نہ دوڑانا جو ہم نے ان میں سے مختلف لوگوں کو آرائش دنیا کی دے رکھی ہیں تاکہ انہیں اس میں آزما لیں تیرے رب کا دیا ہوا ہی (بہت) بہتر اور باقی رہنے واﻻ ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxx{اپنے گھرانے کے لوگوں پرنماز کی تاکید رکھ اور خود بھی اس پر جما ره، ہم تجھ سے روزی نہیں مانگتے، بلکہ ہم خود تجھے روزی دیتے ہیں، آخر میں بول باﻻ پرہیزگاری ہی کا ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxi{انہوں نے کہا کہ یہ نبی ہمارے پاس اپنے پروردگار کی طرف سے کوئی نشانی کیوں نہیں ﻻیا؟ کیا ان کے پاس اگلی کتابوں کی واضح دلیل نہیں پہنچی؟\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxii{اور اگر ہم اس سے پہلے ہی انہیں عذاب سے ہلاک کر دیتے تو یقیناً یہ کہہ اٹھتے کہ اے ہمارے پروردگار تو نے ہمارے پاس اپنا رسول کیوں نہ بھیجا؟ کہ ہم تیری آیتوں کی تابعداری کرتے اس سے پہلے کہ ہم ذلیل ورسوا ہوتے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiii{کہہ دیجئے! ہر ایک انجام کا منتظر ہے پس تم بھی انتظار میں رہو۔ ابھی ابھی قطعاً جان لو گے کہ راه راست والے کون ہیں اور کون راه یافتہ ہیں\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiv{\basmalahur لوگوں کے حساب کا وقت قریب آگیا پھر بھی وه بے خبری میں منھ پھیرے ہوئے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxv{ان کے پاس ان کے رب کی طرف سے جو بھی نئی نئی نصیحت آتی ہے اسے وه کھیل کود میں ہی سنتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvi{ان کے دل بالکل غافل ہیں اور ان ﻇالموں نے چپکے چپکے سرگوشیاں کیں کہ وه تم ہی جیسا انسان ہے، پھر کیا وجہ ہے جو تم آنکھوں دیکھتے جادو میں آجاتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvii{پیغمبر نے کہا میرا پروردگار ہر اس بات کو جو زمین وآسمان میں ہے بخوبی جانتا ہے، وه بہت ہی سننے واﻻ اور جاننے واﻻ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxviii{اتنا ہی نہیں بلکہ یہ تو کہتے ہیں کہ یہ قرآن پراگنده خوابوں کا مجموعہ ہے بلکہ اس نے از خود اسے گھڑ لیا ہے بلکہ یہ شاعر ہے، ورنہ ہمارے سامنے یہ کوئی ایسی نشانی ﻻتے جیسے کہ اگلے پیغمبر بھیجے گئے تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxix{ان سے پہلے جتنی بستیاں ہم نے اجاڑیں سب ایمان سے خالی تھیں۔ تو کیا اب یہ ایمان ﻻئیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcdxc{تجھ سے پہلے جتنے پیغمبر ہم نے بھیجے سبھی مرد تھے جن کی طرف ہم وحی اتارتے تھے پس تم اہل کتاب سے پوچھ لو اگر خود تمہیں علم نہ ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcdxci{ہم نے ان کے ایسے جسم نہیں بنائے تھے کہ وه کھانا نہ کھائیں اور نہ وه ہمیشہ رہنے والے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcdxcii{پھر ہم نے ان سے کیے ہوئے سب وعدے سچے کیے انہیں اور جن جن کو ہم نے چاہا نجات عطا فرمائی اور حد سے نکل جانے والوں کو غارت کر دیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcdxciii{یقیناً ہم نے تمہاری جانب کتاب نازل فرمائی ہے جس میں تمہارے لئے ذکر ہے، کیا پھر بھی تم عقل نہیں رکھتے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcdxciv{اور بہت سی بستیاں ہم نے تباه کر دیں جو ﻇالم تھیں اور ان کے بعد ہم نے دوسری قوم کو پیدا کر دیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcdxcv{جب انہوں نے ہمارے عذاب کا احساس کر لیا، تو لگے اس سے بھاگنے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvi{بھاگ دوڑ نہ کرو اور جہاں تمہیں آسودگی دی گئی تھی وہیں واپس لوٹو اور اپنے مکانات کی طرف جاؤ تاکہ تم سے سوال تو کر لیا جائے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvii{کہنے لگے ہائے ہماری خرابی! بیشک ہم ﻇالم تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcdxcviii{پھر تو ان کا یہی قول تھا یہاں تک کہ ہم نے انہیں جڑ سے کٹی ہوئی کھیتی اور بجھی پڑی آگ (کی طرح) کر دیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcdxcix{ہم نے آسمان وزمین اور ان کے درمیان کی چیزوں کو کھیلتے ہوئے نہیں بنایا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmd{اگر ہم یوں ہی کھیل تماشے کا اراده کرتے تو اسے اپنے پاس سے ہی بنا لیتے، اگر ہم کرنے والے ہی ہوتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdi{بلکہ ہم سچ کو جھوٹ پر پھینک مارتے ہیں پس سچ جھوٹ کا سر توڑ دیتا ہے اور وه اسی وقت نابود ہو جاتا ہے، تم جو باتیں بناتے ہو وه تمہاری لئے باعﺚ خرابی ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdii{آسمانوں اور زمین میں جو ہے اسی اللہ کا ہے اور جو اس کے پاس ہیں وه اس کی عبادت سے نہ سرکشی کرتے ہیں اور نہ تھکتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdiii{وه دن رات تسبیح بیان کرتے ہیں اور ذرا سی بھی سستی نہیں کرتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdiv{کیا ان لوگوں نے زمین (کی مخلوقات میں) سے جنہیں معبود بنا رکھا ہے وه زنده کردیتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdv{اگر آسمان وزمین میں سوائے اللہ تعالیٰ کے اور بھی معبود ہوتے تو یہ دونوں درہم برہم ہوجاتے پس اللہ تعالیٰ عرش کا رب ہر اس وصف سے پاک ہے جو یہ مشرک بیان کرتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdvi{وه اپنے کاموں کے لئے (کسی کےآگے) جواب ده نہیں اور سب (اس کےآگے) جواب ده ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdvii{کیا ان لوگوں نے اللہ کے سوا اور معبود بنا رکھے ہیں، ان سے کہہ دو ﻻؤ اپنی دلیل پیش کرو۔ یہ ہے میرے ساتھ والوں کی کتاب اور مجھ سے اگلوں کی دلیل۔ بات یہ ہے کہ ان میں کے اکثر لوگ حق کو نہیں جانتے اسی وجہ سے منھ موڑے ہوئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdviii{تجھ سے پہلے بھی جو رسول ہم نے بھیجا اس کی طرف یہی وحی نازل فرمائی کہ میرے سوا کوئی معبود برحق نہیں پس تم سب میری ہی عبادت کرو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdix{(مشرک لوگ) کہتے ہیں کہ رحمٰن اوﻻد واﻻ ہے (غلط ہے) اس کی ذات پاک ہے، بلکہ وه سب اس کے باعزت بندے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdx{کسی بات میں اللہ پر پیش دستی نہیں کرتے بلکہ اس کے فرمان پر کاربند ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdxi{وه ان کے آگے پیچھے تمام امور سے واقف ہے وه کسی کی بھی سفارش نہیں کرتے بجز ان کے جن سے اللہ خوش ہو وه تو خود ہیبت الٰہی سے لرزاں وترساں ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdxii{ان میں سے اگر کوئی بھی کہہ دے کہ اللہ کے سوا میں ﻻئق عبادت ہوں تو ہم اسے دوزخ کی سزا دیں ہم ﻇالموں کو اسی طرح سزا دیتے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdxiii{کیا کافر لوگوں نے یہ نہیں دیکھا کہ آسمان وزمین باہم ملے جلے تھے پھر ہم نے انہیں جدا کیا اور ہر زنده چیز کو ہم نے پانی سے پیدا کیا، کیا یہ لوگ پھر بھی ایمان نہیں ﻻتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdxiv{اور ہم نے زمین میں پہاڑ بنا دیئے تاکہ وه مخلوق کو ہلا نہ سکے، اور ہم نے اس میں کشاده راہیں بنا دیں تاکہ وه راستہ حاصل کریں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdxv{آسمان کو محفوظ چھت بھی ہم نے ہی بنایا ہے۔ لیکن لوگ اس کی قدرت کے نمونوں پر دھیان نہیں دھرتے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdxvi{وہی اللہ ہے جس نے رات اور دن اور سورج اور چاند کو پیدا کیا ہے۔ ان میں سے ہر ایک اپنے اپنے مدار میں تیرتے پھرتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdxvii{آپ سے پہلے کسی انسان کو بھی ہم نے ہمیشگی نہیں دی، کیا اگر آپ مرگئے تو وه ہمیشہ کے لئے ره جائیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdxviii{ہر جان دار موت کا مزه چکھنے واﻻ ہے۔ ہم بطریق امتحان تم میں سے ہر ایک کو برائی بھلائی میں مبتلا کرتے ہیں اور تم سب ہماری ہی طرف لوٹائے جاؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdxix{یہ منکرین تجھے جب بھی دیکھتے ہیں تو تمہارا مذاق ہی اڑاتے ہیں کہ کیا یہی وه ہے جو تمہارے معبودوں کا ذکر برائی سے کرتا ہے، اور وه خود ہی رحمٰن کی یاد کے بالکل ہی منکر ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdxx{انسان جلد باز مخلوق ہے۔ میں تمہیں اپنی نشانیاں ابھی ابھی دکھاؤں گا تم مجھ سے جلد بازی نہ کرو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdxxi{کہتے ہیں کہ اگر سچے ہو تو بتا دو کہ یہ وعده کب ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdxxii{کاش! یہ کافر جانتے کہ اس وقت نہ تو یہ کافر آگ کو اپنے چہروں سے ہٹا سکیں گے اور نہ اپنی پیٹھوں سے اور نہ ان کی مدد کی جائے گی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdxxiii{(ہاں ہاں!) وعدے کی گھڑی ان کے پاس اچانک آجائے گی اور انہیں ہکا بکا کر دے گی، پھر نہ تو یہ لوگ اسے ٹال سکیں گے اور نہ ذرا سی بھی مہلت دیئے جائیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdxxiv{اور تجھ سے پہلے رسولوں کے ساتھ بھی ہنسی مذاق کیا گیا پس ہنسی کرنے والوں کو ہی اس چیز نے گھیر لیا جس کی وه ہنسی اڑاتے تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdxxv{ان سے پوچھئے کہ رحمٰن سے، دن اور رات تمہاری حفاﻇت کون کر سکتا ہے؟ بات یہ ہے کہ یہ لوگ اپنے رب کے ذکر سے پھرے ہوئے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdxxvi{کیا ہمارے سوا ان کے اور معبود ہیں جو انہیں مصیبتوں سے بچا لیں۔ کوئی بھی خود اپنی مدد کی طاقت نہیں رکھتا اور نہ کوئی ہماری طرف سے رفاقت دیا جاتا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdxxvii{بلکہ ہم نے انہیں اور ان کے باپ دادوں کو زندگی کے سروسامان دیے یہاں تک کہ ان کی مدت عمر گزر گئی۔ کیا وه نہیں دیکھتے کہ ہم زمین کو اس کے کناروں سے گھٹاتے چلے آرہے ہیں، اب کیا وہی غالب ہیں؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdxxviii{کہہ دیجئے! میں تو تمہیں اللہ کی وحی کے ذریعہ آگاه کر رہا ہوں مگر بہرے لوگ بات نہیں سنتے جبکہ انہیں آگاه کیا جائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdxxix{اگر انہیں تیرے رب کے کسی عذاب کا جھونکا بھی لگ جائے تو پکار اٹھیں کہ ہائے ہماری بدبختی! یقیناً ہم گنہگار تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdxxx{قیامت کے دن ہم درمیان میں ﻻ رکھیں گے ٹھیک ٹھیک تولنے والی ترازو کو۔ پھر کسی پر کچھ بھی ﻇلم نہ کیا جائے گا۔ اور اگر ایک رائی کے دانے کے برابر بھی عمل ہوگا ہم اسے ﻻ حاضر کریں گے، اور ہم کافی ہیں حساب کرنے والے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdxxxi{یہ بالکل سچ ہے کہ ہم نے موسیٰ وہارون کو فیصلے کرنے والی نورانی اور پرہیزگاروں کے لئے وعﻆ ونصیحت والی کتاب عطا فرمائی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdxxxii{وه لوگ جو اپنے رب سے بن دیکھے خوف کھاتے ہیں اور قیامت (کے تصور) سے کانپتے رہتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiii{اور یہ نصیحت وبرکت واﻻ قرآن بھی ہم ہی نے نازل فرمایا ہے کیا پھر بھی تم اس کے منکر ہو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiv{یقیناً ہم نے اس سے پہلے ابراہیم کو اس کی سمجھ بوجھ بخشی تھی اور ہم اس کے احوال سے بخوبی واقف تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdxxxv{جبکہ اس نے اپنے باپ سے اور اپنی قوم سے کہا کہ یہ مورتیاں جن کے تم مجاور بنے بیٹھے ہو کیا ہیں؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvi{سب نے جواب دیا کہ ہم نے اپنے باپ دادا کو انہی کی عبادت کرتے ہوئے پایا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvii{آپ نے فرمایا! پھر تو تم اور تمہارے باپ دادا سبھی یقیناً کھلی گمراہی میں مبتلا رہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdxxxviii{کہنے لگے کیا آپ ہمارے پاس سچ مچ حق ﻻئے ہیں یا یوں ہی مذاق کر رہے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdxxxix{آپ نے فرمایا نہیں درحقیقت تم سب کا پروردگار تو وه ہے جو آسمانوں اور زمین کا مالک ہے جس نے انہیں پیدا کیا ہے، میں تو اسی بات کا گواه اور قائل ہوں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdxl{اور اللہ کی قسم! میں تمہارے ان معبودوں کے ساتھ جب تم علیحده پیٹھ پھیر کر چل دو گے ایک چال چلوں گا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdxli{پس اس نے ان سب کے ٹکڑے ٹکڑے کر دیئے ہاں صرف بڑے بت کو چھوڑ دیا یہ بھی اس لئے کہ وه سب اس کی طرف ہی لوٹیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdxlii{کہنے لگے کہ ہمارے خداؤں کے ساتھ یہ کس نے کیا؟ ایسا شخص تو یقیناً ﻇالموں میں سے ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdxliii{بولے ہم نے ایک نوجوان کو ان کا تذکره کرتے ہوئے سنا تھا جسے ابراہیم (علیہ السلام) کہا جاتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdxliv{سب نے کہا اچھا اسے مجمع میں لوگوں کی نگاہوں کے سامنے ﻻؤ تاکہ سب دیکھیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdxlv{کہنے لگے! اے ابراہیم (علیہ السلام) کیا تو نے ہی ہمارے خداؤں کے ساتھ یہ حرکت کی ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdxlvi{آپ نے جواب دیا بلکہ اس کام کو ان کے بڑے نے کیا ہے تم اپنے خداؤں سے ہی پوچھ لو اگر یہ بولتے چالتے ہوں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdxlvii{پس یہ لوگ اپنے دلوں میں قائل ہوگئے اور کہنے لگے واقعی ﻇالم تو تم ہی ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdxlviii{پھر اپنے سروں کے بل اوندھے ہوگئے (اور کہنے لگے کہ) یہ تو تجھے بھی معلوم ہے کہ یہ بولنے چالنے والے نہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdxlix{اللہ کے خلیل نے اسی وقت فرمایا افسوس! کیا تم اللہ کے علاوه ان کی عبادت کرتے ہو جو نہ تمہیں کچھ بھی نفع پہنچا سکیں نہ نقصان\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdl{تف ہے تم پر اور ان پر جن کی تم اللہ کے سوا عبادت کرتے ہو۔ کیا تمہیں اتنی سی عقل بھی نہیں؟\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdli{کہنے لگے کہ اسے جلا دو اور اپنے خداؤں کی مدد کرو اگر تمہیں کچھ کرنا ہی ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdlii{ہم نے فرما دیا اے آگ! تو ٹھنڈی پڑ جا اور ابراہیم (علیہ السلام) کے لئے سلامتی (اور آرام کی چیز) بن جا!\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdliii{گو انہوں نے ابراہیم (علیہ السلام) کا برا چاہا، لیکن ہم نے انہیں ناکام بنا دیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdliv{اور ہم ابراہیم اور لوط کو بچاکر اس زمین کی طرف لے چلے جس میں ہم نے تمام جہان والوں کے لئے برکت رکھی تھی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdlv{اور ہم نے اسےاسحاق عطا فرمایااور یعقوب اس پر مزید۔ اور ہرایک کو ہم نے صالح بنایا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdlvi{اور ہم نے انہیں پیشوا بنا دیا کہ ہمارے حکم سے لوگوں کی رہبری کریں اور ہم نے ان کی طرف نیک کاموں کے کرنے اور نمازوں کے قائم رکھنے اور زکوٰة دینے کی وحی (تلقین) کی، اور وه سب کے سب ہمارے عبادت گزار بندے تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdlvii{ہم نے لوط (علیہ السلام) کو بھی حکم اور علم دیا اور اسے اسی بستی سے نجات دی جہاں کے لوگ گندے کاموں میں مبتلا تھے۔ اور تھے بھی بدترین گنہگار\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdlviii{اور ہم نے لوط (علیہ السلام) کو اپنی رحمت میں داخل کر لیا بے شک وه نیکو کار لوگوں میں سے تھا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdlix{نوح کے اس وقت کو یاد کیجئے جبکہ اس نے اس سے پہلے دعا کی ہم نے اس کی دعا قبول فرمائی اور اسے اور اس کے گھر والوں کو بڑے کرب سے نجات دی\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdlx{اور جو لوگ ہماری آیتوں کو جھٹلا رہے تھے ان کے مقابلے میں ہم نے اس کی مدد کی، یقیناً وه برے لوگ تھے پس ہم نےان سب کو ڈبو دیا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdlxi{اور داؤد اور سلیمان (علیہما السلام) کو یاد کیجئے جبکہ وه کھیت کے معاملہ میں فیصلہ کر رہے تھے کہ کچھ لوگوں کی بکریاں رات کو اس میں چر چگ گئی تھیں، اور ان کے فیصلے میں ہم موجود تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdlxii{ہم نے اس کا صحیح فیصلہ سلیمان کو سمجھا دیا۔ ہاں ہر ایک کو ہم نے حکم وعلم دے رکھا تھا اور داؤد کے تابع ہم نے پہاڑ کر دیئے تھے جو تسبیح کرتے تھے اور پرند بھی۔ ہم کرنے والے ہی تھے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdlxiii{اور ہم نے اسے تمہارے لئے لباس بنانے کی کاریگری سکھائی تاکہ لڑائی کے ضرر سے تمہارا بچاؤ ہو۔ کیا تم شکر گزار بنو گے؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdlxiv{ہم نے تند وتیز ہوا کو سلیمان (علیہ السلام) کے تابع کر دیا جو اس کے فرمان کے مطابق اس زمین کی طرف چلتی تھی جہاں ہم نے برکت دے رکھی تھی، اور ہم ہر چیز سے باخبر اور دانا ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdlxv{اسی طرح سے بہت سے شیاطین بھی ہم نے اس کے تابع کیے تھے جو اس کے فرمان سے غوطے لگاتے تھے اور اس کے سوا بھی بہت سے کام کرتے تھے، ان کے نگہبان ہم ہی تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdlxvi{ایوب (علیہ السلام) کی اس حالت کو یاد کرو جبکہ اس نے اپنے پروردگار کو پکارا کہ مجھے یہ بیماری لگ گئی ہے اور تو رحم کرنے والوں سے زیاده رحم کرنے واﻻ ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdlxvii{تو ہم نے اس کی سن لی اور جو دکھ انہیں تھا اسے دور کر دیا اور اس کو اہل وعیال عطا فرمائے بلکہ ان کے ساتھ ویسے ہی اور اپنی خاص مہربانی سے تاکہ سچے بندوں کے لئے سبب نصیحت ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdlxviii{اور اسماعیل اور ادریس اور ذوالکفل، (علیہم السلام) یہ سب صابر لوگ تھے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdlxix{ہم نے انہیں اپنی رحمت میں داخل کر لیا۔ یہ سب لوگ نیک تھے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdlxx{مچھلی والے (حضرت یونس علیہ السلام) کو یاد کرو! جبکہ وه غصہ سے چل دیا اور خیال کیا کہ ہم اسے نہ پکڑ سکیں گے۔ بالﺂخر وه اندھیروں کے اندر سے پکار اٹھا کہ الٰہی تیرے سوا کوئی معبود نہیں تو پاک ہے، بیشک میں ﻇالموں میں ہو گیا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdlxxi{تو ہم نے اس کی پکار سن لی اور اسے غم سے نجات دے دی اور ہم ایمان والوں کو اسی طرح بچا لیا کرتے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdlxxii{اور زکریا (علیہ السلام) کو یاد کرو جب اس نے اپنے رب سے دعا کی کہ اے میرے پروردگار! مجھے تنہا نہ چھوڑ، تو سب سے بہتر وارث ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiii{ہم نے اس کی دعا کو قبول فرما کر اسے یحيٰ (علیہ السلام) عطا فرمایا اور ان کی بیوی کو ان کے لئے درست کر دیا۔ یہ بزرگ لوگ نیک کاموں کی طرف جلدی کرتے تھے اور ہمیں ﻻلچ طمع اور ڈر خوف سے پکارتے تھے۔ اور ہمارے سامنے عاجزی کرنے والے تھے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiv{اور وه پاک دامن بی بی جس نے اپنی عصمت کی حفاﻇت کی ہم نے اس کے اندر روح سے پھونک دی اور خود انہیں اور ان کے لڑکے کو تمام جہان کے لئے نشانی بنا دیا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdlxxv{یہ تمہاری امت ہے جو حقیقت میں ایک ہی امت ہے، اور میں تم سب کا پروردگار ہوں پس تم میری ہی عبادت کرو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvi{مگر لوگوں نےآپس میں اپنے دین میں فرقہ بندیاں کر لیں، سب کے سب ہماری ہی طرف لوٹنے والے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvii{پھر جو بھی نیک عمل کرے اور وه مومن (بھی) ہو تو اس کی کوشش کی بے قدری نہیں کی جائے گی۔ ہم تو اس کے لکھنے والے ہیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdlxxviii{اور جس بستی کو ہم نے ہلاک کر دیا اس پر ﻻزم ہے کہ وہاں کے لوگ پلٹ کر نہیں آئیں گے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdlxxix{یہاں تک کہ یاجوج اور ماجوج کھول دیئے جائیں گے اور وه ہر بلندی سے دوڑتے ہوئے آئیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdlxxx{اور سچا وعده قریب آلگے گا اس وقت کافروں کی نگاہیں پھٹی کی پھٹی ره جائیں گی، کہ ہائے افسوس! ہم اس حال سے غافل تھے بلکہ فی الواقع ہم قصور وار تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxi{تم اور اللہ کے سوا جن جن کی تم عبادت کرتے ہو، سب دوزخ کا ایندھن بنو گے، تم سب دوزخ میں جانے والے ہو\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxii{اگر یہ (سچے) معبود ہوتے تو جہنم میں داخل نہ ہوتے، اور سب کے سب اسی میں ہمیشہ رہنے والے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiii{وه وہاں چلا رہے ہوں گے اور وہاں کچھ بھی نہ سن سکیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiv{البتہ بے شک جن کے لئے ہماری طرف سے نیکی پہلے ہی ٹھہر چکی ہے۔ وه سب جہنم سے دور ہی رکھے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxv{وه تو دوزخ کی آہٹ تک نہ سنیں گے اور اپنی من بھاتی چیزوں میں ہمیشہ رہنے والے ہوں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvi{وه بڑی گھبراہٹ (بھی) انہیں غمگین نہ کر سکے گی اور فرشتے انہیں ہاتھوں ہاتھ لیں گے، کہ یہی تمہارا وه دن ہے جس کا تم وعده دیئے جاتے رہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvii{جس دن ہم آسمان کو یوں لپیٹ لیں گے جیسے طومار میں اوراق لپیٹ دیئے جاتے ہیں، جیسے کہ ہم نے اول دفعہ پیدائش کی تھی اسی طرح دوباره کریں گے۔ یہ ہمارے ذمے وعده ہے اور ہم اسے ضرور کر کے (ہی) رہیں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxviii{ہم زبور میں پند ونصیحت کے بعد یہ لکھ چکے ہیں کہ زمین کے وارث میرے نیک بندے (ہی) ہوں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxix{عبادت گزار بندوں کے لئے تو اس میں ایک بڑا پیغام ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdxc{اور ہم نے آپ کو تمام جہان والوں کے لئے رحمت بنا کر ہی بھیجا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdxci{کہہ دیجئے! میرے پاس تو پس وحی کی جاتی ہے کہ تم سب کا معبود ایک ہی ہے، تو کیا تم بھی اس کی فرمانبرداری کرنے والے ہو؟\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdxcii{پھر اگر یہ منھ موڑ لیں تو کہہ دیجئے کہ میں نے تمہیں یکساں طور پر خبردار کر دیا ہے۔ مجھے علم نہیں کہ جس کا وعده تم سے کیا جا رہا ہے وه قریب ہے یا دور\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdxciii{البتہ اللہ تعالیٰ تو کھلی اور ﻇاہر بات کو بھی جانتا ہے اور جو تم چھپاتے ہو اسے بھی جانتا ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdxciv{مجھے اس کا بھی علم نہیں، ممکن ہے یہ تمہاری آزمائش ہو اور ایک مقرره وقت تک کا فائده (پہنچانا) ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdxcv{خود نبی نے کہا اے رب! انصاف کے ساتھ فیصلہ فرما اور ہمارا رب بڑا مہربان ہے جس سے مدد طلب کی جاتی ہے ان باتوں پر جو تم بیان کرتے ہو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdxcvi{\basmalahur لوگو! اپنے پروردگار سے ڈرو! بلاشبہ قیامت کا زلزلہ بہت ہی بڑی چیز ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdxcvii{جس دن تم اسے دیکھ لو گے ہر دودھ پلانے والی اپنے دودھ پیتے بچے کو بھول جائے گی اور تمام حمل والیوں کے حمل گر جائیں گے اور تو دیکھے گا کہ لوگ مدہوش دکھائی دیں گے، حاﻻنکہ درحقیقت وه متوالے نہ ہوں گے لیکن اللہ کا عذاب بڑا ہی سخت ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdxcviii{بعض لوگ اللہ کے بارے میں باتیں بناتے ہیں اور وه بھی بے علمی کے ساتھ اور ہر سرکش شیطان کی پیروی کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdxcix{جس پر (قضائے الٰہی) لکھ دی گئی ہے کہ جو کوئی اس کی رفاقت کرے گا وه اسے گمراه کر دے گا اور اسے آگ کے عذاب کی طرف لے جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdc{لوگو! اگر تمہیں مرنے کے بعد جی اٹھنے میں شک ہے تو سوچو ہم نے تمہیں مٹی سے پیدا کیا پھر نطفہ سے پھر خون بستہ سے پھر گوشت کے لوتھڑے سے جو صورت دیا گیا تھا اور بے نقشہ تھا۔ یہ ہم تم پر ﻇاہر کر دیتے ہیں، اور ہم جسے چاہیں ایک ٹھہرائے ہوئے وقت تک رحم مادر میں رکھتے ہیں پھر تمہیں بچپن کی حالت میں دنیا میں ﻻتے ہیں پھر تاکہ تم اپنی پوری جوانی کو پہنچو، تم میں سے بعض تو وه ہیں جو فوت کر لئے جاتے ہیں اور بعض بے غرض عمر کی طرف پھر سے لوٹا دیئے جاتے ہیں کہ وه ایک چیز سے باخبر ہونے کے بعد پھر بے خبر ہو جائے۔ تو دیکھتا ہے کہ زمین (بنجر اور) خشک ہے پھر ہم اس پر بارشیں برساتے ہیں تو وه ابھرتی ہے اور پھولتی ہے اور ہر قسم کی رونق دار نباتات اگاتی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdci{یہ اس لئے کہ اللہ ہی حق ہے اور وہی مردوں کو جِلاتا ہے اور وه ہر ہر چیز پر قدرت رکھنے واﻻ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdcii{اور یہ کہ قیامت قطعاً آنے والی ہے جس میں کوئی شک وشبہ نہیں اور یقیناً اللہ تعالیٰ قبروں والوں کو دوباره زنده فرمائے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdciii{بعض لوگ اللہ کے بارے میں بغیر علم کے اور بغیر ہدایت کے اور بغیر روشن کتاب کے جھگڑتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdciv{جو اپنی پہلو موڑنے واﻻ بن کر اس لئے کہ اللہ کی راه سے بہکادے، اسے دنیا میں بھی رسوائی ہوگی اور قیامت کے دن بھی ہم اسے جہنم میں جلنے کا عذاب چکھائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdcv{یہ ان اعمال کی وجہ سے جو تیرے ہاتھوں نے آگے بھیج رکھے تھے۔ یقین مانو کہ اللہ تعالیٰ اپنے بندوں پر ﻇلم کرنے واﻻ نہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcvi{بعض لوگ ایسے بھی ہیں کہ ایک کنارے پر (کھڑے) ہو کر اللہ کی عبادت کرتے ہیں۔ اگر کوئی نفع مل گیا تو دلچسپی لینے لگتے ہیں اور اگر کوئی آفت آگئی تو اسی وقت منھ پھیر لیتے ہیں، انہوں نے دونوں جہان کانقصان اٹھا لیا۔ واقعی یہ کھلا نقصان ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdcvii{اللہ کے سوا انہیں پکارتے ہیں جو نہ انہیں نقصان پہنچا سکیں نہ نفع۔ یہی تو دور دراز کی گمراہی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdcviii{اسے پکارتے ہیں جس کا نقصان اس کے نفع سے زیاده قریب ہے، یقیناً برے والی ہیں اور برے ساتھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcix{ایمان اور نیک اعمال والوں کو اللہ تعالیٰ لہریں لیتی ہوئی نہروں والی جنتوں میں لے جائے گا۔ اللہ جو اراده کرے اسے کر کے رہتا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcx{جس کا یہ خیال ہو کہ اللہ تعالیٰ اپنے رسول کی مدد دونوں جہان میں نہ کرے گا وه اونچائی پر ایک رسہ باندھ کر (اپنے حلق میں پھنده ڈال کر اپنا گلا گھونٹ لے) پھر دیکھ لے کہ اس کی چاﻻکیوں سے وه بات ہٹ جاتی ہے جو اسے تڑپا رہی ہے؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcxi{ہم نے اسی طرح اس قرآن کو واضح آیتوں میں اتارا ہے جسے اللہ چاہے ہدایت نصیب فرماتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxii{بیشک اہل ایمان اور یہودی اور صابی اور نصرانی اور مجوسی اور مشرکین ان سب کے درمیان قیامت کے دن خود اللہ تعالیٰ فیصلے کر دے گا، اللہ تعالیٰ ہر ہر چیز پر گواه ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxiii{کیا تو نہیں دیکھ رہا کہ اللہ کے سامنے سجده میں ہیں سب آسمانوں والے اور سب زمینوں والے اور سورج اور چاند اور ستارے اور پہاڑ اور درخت اور جانور اور بہت سے انسان بھی۔ ہاں بہت سے وه بھی ہیں جن پر عذاب کا مقولہ ﺛابت ہو چکا ہے، جسے رب ذلیل کردے اسے کوئی عزت دینے واﻻ نہیں، اللہ جو چاہتا ہے کرتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxiv{یہ دونوں اپنے رب کے بارے میں اختلاف کرنے والے ہیں، پس کافروں کے لئے تو آگ کے کپڑے بیونت کر کاٹے جائیں گے، اور ان کے سروں کے اوپر سے سخت کھولتا ہوا پانی بہایا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxv{جس سے ان کے پیٹ کی سب چیزیں اور کھالیں گلا دی جائیں گی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxvi{اور ان کی سزا کے لئے لوہے کے ہتھوڑے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxvii{یہ جب بھی وہاں کے غم سے نکل بھاگنے کا اراده کریں گے وہیں لوٹا دیئے جائیں گے اور (کہا جائے گا) جلنے کا عذاب چکھو!\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxviii{ایمان والوں اور نیک کام والوں کو اللہ تعالیٰ ان جنتوں میں لے جائے گا جن کے درختوں تلے سے نہریں لہریں لے رہی ہیں، جہاں وه سونے کے کنگن پہنائے جائیں گے اور سچے موتی بھی۔ وہاں ان کا لباس خالص ریشم ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxix{ان کو پاکیزه بات کی رہنمائی کر دی گئی اور قابل صد تعریف راه کی ہدایت کر دی گئی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxx{جن لوگوں نے کفر کیا اور اللہ کی راه سے روکنے لگے اور اس حرمت والی مسجد سے بھی جسے ہم نے تمام لوگوں کے لئے مساوی کر دیا ہے وہیں کے رہنے والے ہوں یا باہر کے ہوں، جو بھی ﻇلم کے ساتھ وہاں الحاد کا اراده کرے ہم اسے درد ناک عذاب چکھائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxxi{اور جبکہ ہم نے ابراہیم (علیہ السلام) کو کعبہ کے مکان کی جگہ مقرر کر دی اس شرط پر کہ میرے ساتھ کسی کو شریک نہ کرنا اور میرے گھر کو طواف قیام رکوع سجده کرنے والوں کے لئے پاک صاف رکھنا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcxxii{اور لوگوں میں حج کی منادی کر دے لوگ تیرے پاس پا پیاده بھی آئیں گے اور دبلے پتلے اونٹوں پر بھی اور دور دراز کی تمام راہوں سے آئیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiii{اپنے فائدے حاصل کرنے کو آجائیں اور ان مقرره دنوں میں اللہ کا نام یاد کریں اور چوپایوں پر جو پالتو ہیں۔ پس تم آپ بھی کھاؤ اور بھوکے فقیروں کو بھی کھلاؤ\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiv{پھر وه اپنا میل کچیل دور کریں اور اپنی نذریں پوری کریں اور اللہ کے قدیم گھر کا طواف کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcxxv{یہ ہے اور جو کوئی اللہ کی حرمتوں کی تعظیم کرے اس کے اپنے لئے اس کے رب کے پاس بہتری ہے۔ اور تمہارے لئے چوپائے جانور حلال کر دیئے گئے بجز ان کے جو تمہارے سامنے بیان کیے گئے ہیں پس تمہیں بتوں کی گندگی سے بچتے رہنا چاہئے اور جھوٹی بات سے بھی پرہیز کرنا چاہئے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvi{اللہ کی توحید کو مانتے ہوئے اس کے ساتھ کسی کو شریک نہ کرتے ہوئے۔ سنو! اللہ کے ساتھ شریک کرنے واﻻ گویا آسمان سے گر پڑا، اب یا تو اسے پرندے اچک لے جائیں گے یا ہوا کسی دور دراز کی جگہ پھینک دے گی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvii{یہ سن لیا اب اور سنو! اللہ کی نشانیوں کی جو عزت وحرمت کرے اس کے دل کی پرہیز گاری کی وجہ سے یہ ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcxxviii{ان میں تمہارے لئے ایک مقرر وقت تک فائده ہے پھر ان کے حلال ہونے کی جگہ خانہ کعبہ ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcxxix{اور ہر امت کے لئے ہم نے قربانی کے طریقے مقرر فرمائے ہیں تاکہ وه ان چوپائے جانوروں پر اللہ کا نام لیں جو اللہ نے انہیں دے رکھے ہیں۔ سمجھ لو کہ تم سب کا معبود برحق صرف ایک ہی ہے تم اسی کے تابع فرمان ہو جاؤ عاجزی کرنے والوں کو خوشخبری سنا دیجئے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcxxx{انہیں کہ جب اللہ کا ذکر کیا جائے ان کے دل تھرا جاتے ہیں۔ انہیں جو برائی پہنچے اس پر صبر کرتے ہیں، نماز قائم کرنے والے ہیں اور جو کچھ ہم نے انہیں دے رکھا ہے وه اس میں سے بھی دیتے رہتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxi{قربانی کے اونٹ ہم نے تمہارے لئے اللہ تعالیٰ کی نشانیاں مقرر کر دی ہیں ان میں تمہیں نفع ہے۔ پس انہیں کھڑا کر کے ان پر اللہ کا نام لو، پھر جب ان کے پہلو زمین سے لگ جائیں اسے (خود بھی) کھاؤ اور مسکین سوال سے رکنے والوں اور سوال کرنے والوں کو بھی کھلاؤ، اسی طرح ہم نے چوپایوں کو تمہارے ماتحت کردیا ہے کہ تم شکر گزاری کرو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxii{اللہ تعالیٰ کو قربانیوں کے گوشت نہیں پہنچتے نہ اس کے خون بلکہ اسے تو تمہارے دل کی پرہیزگاری پہنچتی ہے۔ اسی طرح اللہ نے ان جانوروں کو تمہارے مطیع کر دیا ہے کہ تم اس کی رہنمائی کے شکریئے میں اس کی بڑائیاں بیان کرو، اور نیک لوگوں کو خوشخبری سنا دیجئے!\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiii{سن رکھو! یقیناً سچے مومنوں کے دشمنوں کو خود اللہ تعالیٰ ہٹا دیتا ہے۔ کوئی خیانت کرنے واﻻ ناشکرا اللہ تعالیٰ کو ہرگز پسند نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiv{جن (مسلمانوں) سے (کافر) جنگ کر رہے ہیں انہیں بھی مقابلے کی اجازت دی جاتی ہے کیونکہ وه مظلوم ہیں۔ بیشک ان کی مدد پر اللہ قادر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxv{یہ وه ہیں جنہیں ناحق اپنے گھروں سے نکالا گیا، صرف ان کےاس قول پر کہ ہمارا پروردگار فقط اللہ ہے۔ اگر اللہ تعالیٰ لوگوں کو آپس میں ایک دوسرے سے نہ ہٹاتا رہتا تو عبادت خانے اور گرجے اور مسجدیں اور یہودیوں کے معبد اور وه مسجدیں بھی ڈھا دی جاتیں جہاں اللہ کا نام بہ کثرت لیا جاتا ہے۔ جو اللہ کی مدد کرے گا اللہ بھی ضرور اس کی مدد کرے گا۔ بیشک اللہ تعالیٰ بڑی قوتوں واﻻ بڑے غلبے واﻻ ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvi{یہ وه لوگ ہیں کہ اگر ہم زمین میں ان کے پاؤں جما دیں تو یہ پوری پابندی سے نمازیں قائم کریں اور زکوٰتیں دیں اور اچھے کاموں کا حکم کریں اور برے کاموں سے منع کریں۔ تمام کاموں کا انجام اللہ کے اختیار میں ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvii{اگر یہ لوگ آپ کو جھٹلائیں (تو کوئی تعجب کی بات نہیں) تو ان سے پہلے نوح کی قوم اور عاد اور ﺛمود\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxviii{اور قوم ابراہیم اور قوم لوط\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxix{اور مدین والے بھی اپنے اپنے نبیوں کو جھٹلا چکے ہیں۔ موسیٰ (علیہ السلام) بھی جھٹلائے جا چکے ہیں پس میں نے کافروں کو یوں ہی سی مہلت دی پھر دھر دبایا، پھر میرا عذاب کیسا ہوا؟\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcxl{بہت سی بستیاں ہیں جنہیں ہم نے تہ وباﻻ کر دیا اس لئے کہ وه ﻇالم تھے پس وه اپنی چھتوں کے بل اوندھی ہوئی پڑی ہیں اور بہت سے آباد کنوئیں بیکار پڑے ہیں اور بہت سے پکے اور بلند محل ویران پڑے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcxli{کیا انہوں نے زمین میں سیر وسیاحت نہیں کی جو ان کے دل ان باتوں کے سمجھنے والے ہوتے یا کانوں سے ہی ان (واقعات) کو سن لیتے، بات یہ ہے کہ صرف آنکھیں ہی اندھی نہیں ہوتیں بلکہ وه دل اندھے ہو جاتے ہیں جو سینوں میں ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcxlii{اللہ ہرگز اپنا وعده نہیں ٹالے گا۔ ہاں البتہ آپ کے رب کے نزدیک ایک دن تمہاری گنتی کے اعتبار سے ایک ہزار سال کا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcxliii{بہت سی ﻇلم کرنے والی بستیوں کو میں نے ڈھیل دی پھر آخر انہیں پکڑ لیا، اور میری ہی طرف لوٹ کر آنا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcxliv{اعلان کر دو کہ لوگو! میں تمہیں کھلم کھلا چوکنا کرنے واﻻ ہی ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcxlv{پس جو ایمان ﻻئے ہیں اور جنہوں نے نیک عمل کیے ہیں ان ہی کے لئے بخشش ہے اور عزت والی روزی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvi{اور جو لوگ ہماری نشانیوں کو پست کرنے کے درپے رہتے ہیں وہی دوزخی ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvii{ہم نے آپ سے پہلے جس رسول اور نبی کو بھیجا اس کے ساتھ یہ ہوا کہ جب وه اپنے دل میں کوئی آرزو کرنے لگا شیطان نے اس کی آرزو میں کچھ ملا دیا، پس شیطان کی ملاوٹ کو اللہ تعالیٰ دور کر دیتا ہے پھر اپنی باتیں پکی کر دیتا ہے۔ اللہ تعالیٰ دانا اور باحکمت ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcxlviii{یہ اس لئے کہ شیطانی ملاوٹ کو اللہ تعالیٰ ان لوگوں کی آزمائش کا ذریعہ بنا دے جن کے دلوں میں بیماری ہے اور جن کے دل سخت ہیں۔ بیشک ﻇالم لوگ گہری مخالفت میں ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcxlix{اور اس لئے بھی کہ جنہیں علم عطا فرمایا گیا ہے وه یقین کر لیں کہ یہ آپ کے رب ہی کی طرف سے سراسر حق ہی ہے پھر وه اس پر ایمان ﻻئیں اور ان کے دل اس کی طرف جھک جائیں۔ یقیناً اللہ تعالیٰ ایمان داروں کو راه راست کی طرف رہبری کرنے واﻻ ہی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcl{کافر اس وحی الٰہی میں ہمیشہ شک شبہ ہی کرتے رہیں گے حتیٰ کہ اچانک ان کے سروں پر قیامت آجائے یا ان کے پاس اس دن کا عذاب آجائے جو منحوس ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcli{اس دن صرف اللہ ہی کی بادشاہت ہوگی وہی ان میں فیصلے فرمائے گا۔ ایمان اور نیک عمل والے تو نعمتوں سے بھری جنتوں میں ہوں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdclii{اور جن لوگوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا ان کے لئے ذلیل کرنے والے عذاب ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcliii{اور جن لوگوں نے راه خدا میں ترک وطن کیا پھر وه شہید کر دیئے گئے یا اپنی موت مر گئے اللہ تعالیٰ انہیں بہترین رزق عطا فرمائے گا۔ اور بیشک اللہ تعالیٰ روزی دینے والوں میں سب سے بہتر ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcliv{انہیں اللہ تعالیٰ ایسی جگہ پہنچائے گا کہ وه اس سے راضی ہو جائیں گے، بیشک اللہ تعالیٰ علم اور بردباری واﻻ ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdclv{بات یہی ہے، اور جس نے بدلہ لیا اسی کے برابر جو اس کے ساتھ کیا گیا تھا پھر اگر اس سے زیادتی کی جائے تو یقیناً اللہ تعالیٰ خود اس کی مدد فرمائے گا۔ بیشک اللہ درگزر کرنے واﻻ بخشنے واﻻ ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdclvi{یہ اس لئے کہ اللہ رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے، اور بیشک اللہ سننے واﻻ دیکھنے واﻻ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdclvii{یہ سب اس لئے کہ اللہ ہی حق ہے اور اس کے سوا جسے بھی یہ پکارتے ہیں وه باطل ہے اور بیشک اللہ ہی بلندی واﻻ کبریائی واﻻ ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdclviii{کیا آپ نے نہیں دیکھا کہ اللہ تعالیٰ آسمان سے پانی برساتا ہے، پس زمین سرسبز ہو جاتی ہے۔ بے شک اللہ تعالیٰ مہربان اور باخبر ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdclix{آسمانوں اور زمین میں جو کچھ ہے اسی کا ہے اور یقیناً اللہ وہی ہے بے نیاز تعریفوں واﻻ\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdclx{کیا آپ نے نہیں دیکھا کہ اللہ ہی نے زمین کی تمام چیزیں تمہارے لئے مسخر کر دی ہیں اور اس کے فرمان سے پانی میں چلتی ہوئی کشتیاں بھی۔ وہی آسمان کو تھامے ہوئے ہے کہ زمین پر اس کی اجازت کے بغیر نہ گر پڑے، بیشک اللہ تعالیٰ لوگوں پر شفقت ونرمی کرنے واﻻ اور مہربان ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdclxi{اسی نے تمہیں زندگی بخشی، پھر وہی تمہیں مار ڈالے گا پھر وہی تمہیں زنده کرے گا، بے شک انسان البتہ ناشکرا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdclxii{ہر امت کے لئے ہم نے عبادت کا ایک طریقہ مقرر کر دیا ہے، جسے وه بجا ﻻنے والے ہیں پس انہیں اس امر میں آپ سے جھگڑا نہ کرنا چاہئے آپ اپنے پروردگار کی طرف لوگوں کو بلائیے۔ یقیناً آپ ٹھیک ہدایت پر ہی ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdclxiii{پھر بھی اگر یہ لوگ آپ سے الجھنے لگیں تو آپ کہہ دیں کہ تمہارے اعمال سے اللہ بخوبی واقف ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdclxiv{بیشک تمہارے سب کے اختلاف کا فیصلہ قیامت والے دن اللہ تعالیٰ آپ کرے گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdclxv{کیا آپ نے نہیں جانا کہ آسمان وزمین کی ہر چیز اللہ کے علم میں ہے۔ یہ سب لکھی ہوئی کتاب میں محفوظ ہے۔ اللہ تعالیٰ پر تو یہ امر بالکل آسان ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdclxvi{اور یہ اللہ کے سوا ان کی عبادت کر رہے ہیں جس کی کوئی خدائی دلیل نازل نہیں ہوئی نہ وه خود ہی اس کا کوئی علم رکھتے ہیں۔ ﻇالموں کا کوئی مددگار نہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdclxvii{جب ان کے سامنے ہمارے کلام کی کھلی ہوئی آیتوں کی تلاوت کی جاتی ہے تو آپ کافروں کے چہروں پر ناخوشی کے صاف آﺛار پہچان لیتے ہیں۔ وه تو قریب ہوتے ہیں کہ ہماری آیتیں سنانے والوں پر حملہ کر بیٹھیں، کہہ دیجئے کہ کیا میں تمہیں اس سے بھی زیاده بدتر خبر دوں۔ وه آگ ہے، جس کا وعده اللہ نے کافروں سے کر رکھا ہے، اور وه بہت ہی بری جگہ ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdclxviii{لوگو! ایک مثال بیان کی جا رہی ہے، ذرا کان لگا کر سن لو! اللہ کے سوا جن جن کو تم پکارتے رہے ہو وه ایک مکھی بھی تو پیدا نہیں کر سکتے، گو سارے کے سارے ہی جمع ہو جائیں، بلکہ اگر مکھی ان سے کوئی چیز لے بھاگے تو یہ تو اسے بھی اس سے چھین نہیں سکتے، بڑا بودا ہے طلب کرنے واﻻ اور بڑا بودا ہے وه جس سے طلب کیا جا رہا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdclxix{انہوں نے اللہ کے مرتبہ کے مطابق اس کی قدر جانی ہی نہیں، اللہ تعالیٰ بڑا ہی زور وقوت واﻻ اور غالب وزبردست ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdclxx{فرشتوں میں سے اور انسانوں میں سے پیغام پہونچانے والوں کو اللہ ہی چھانٹ لیتا ہے، بیشک اللہ تعالیٰ سننے واﻻ دیکھنے واﻻ ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdclxxi{وه بخوبی جانتا ہے جو کچھ ان کے آگے ہے اور جو کچھ ان کے پیچھے ہے، اور اللہ ہی کی طرف سب کام لوٹائے جاتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdclxxii{اے ایمان والو! رکوع سجده کرتے رہو اور اپنے پروردگار کی عبادت میں لگے رہو اور نیک کام کرتے رہو تاکہ تم کامیاب ہو جاؤ\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiii{اور اللہ کی راه میں ویسا ہی جہاد کرو جیسا جہاد کا حق ہے۔ اسی نے تمہیں برگزیده بنایا ہے اور تم پر دین کے بارے میں کوئی تنگی نہیں ڈالی، دین اپنے باپ ابراہیم (علیہ السلام) کا قائم رکھو، اسی اللہ نے تمہارا نام مسلمان رکھا ہے۔ اس قرآن سے پہلے اور اس میں بھی تاکہ پیغمبر تم پر گواه ہو جائے اور تم تمام لوگوں کے گواه بن جاؤ۔ پس تمہیں چاہئے کہ نمازیں قائم رکھو اور زکوٰة ادا کرتے رہو اور اللہ کو مضبوط تھام لو، وہی تمہارا ولی اور مالک ہے۔ پس کیا ہی اچھا مالک ہے اور کتنا ہی بہتر مددگار ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiv{\basmalahur یقیناً ایمان والوں نے فلاح حاصل کرلی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdclxxv{جو اپنی نماز میں خشوع کرتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvi{جو لغویات سے منھ موڑ لیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvii{جو زکوٰة ادا کرنے والے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdclxxviii{جو اپنی شرمگاہوں کی حفاﻇت کرنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdclxxix{بجز اپنی بیویوں اور ملکیت کی لونڈیوں کے یقیناً یہ ملامتیوں میں سے نہیں ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdclxxx{جو اس کے سوا کچھ اور چاہیں وہی حد سے تجاوز کرجانے والے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxi{جو اپنی امانتوں اور وعدے کی حفاﻇت کرنے والے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxii{جو اپنی نمازوں کی نگہبانی کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiii{یہی وارث ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiv{جو فردوس کے وارث ہوں گے جہاں وه ہمیشہ رہیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxv{یقیناً ہم نے انسان کو مٹی کے جوہر سے پیدا کیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvi{پھر اسے نطفہ بنا کر محفوظ جگہ میں قرار دے دیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvii{پھر نطفہ کو ہم نے جما ہوا خون بنا دیا، پھر اس خون کے لوتھڑے کو گوشت کا ٹکڑا کردیا۔ پھر گوشت کے ٹکڑے کو ہڈیاں بنا دیں، پھر ہڈیوں کو ہم نے گوشت پہنا دیا، پھر دوسری بناوٹ میں اس کو پیدا کردیا۔ برکتوں واﻻ ہے وه اللہ جو سب سے بہترین پیدا کرنے واﻻ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxviii{اس کے بعد پھر تم سب یقیناً مر جانے والے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxix{پھر قیامت کے دن بلا شبہ تم سب اٹھائے جاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxc{ہم نے تمہارے اوپر سات آسمان بنائے ہیں اور ہم مخلوقات سے غافل نہیں ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxci{ہم ایک صحیح انداز سے آسمان سے پانی برساتے ہیں، پھر اسے زمین میں ٹھہرا دیتے ہیں، اور ہم اس کے لے جانے پر یقیناً قادر ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxcii{اسی پانی کے ذریعہ سے ہم تمہارے لئے کھجوروں اور انگوروں کے باغات پیدا کردیتے ہیں، کہ تمہارے لئے ان میں بہت سے میوے ہوتے ہیں ان ہی میں سے تم کھاتے بھی ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxciii{اور وه درخت جو طور سینا پہاڑ سے نکلتا ہے جو تیل نکالتا ہے اور کھانے والے کے لئے سالن ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxciv{تمہارے لئے چوپایوں میں بھی بڑی بھاری عبرت ہے۔ ان کے پیٹوں میں سے ہم تمہیں دودھ پلاتے ہیں اور بھی بہت سے نفع تمہارے لئے ان میں ہیں ان میں سے بعض بعض کو تم کھاتے بھی ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxcv{اور ان پر اور کشتیوں پر تم سوار کرائے جاتے ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvi{یقیناً ہم نے نوح (علیہ السلام) کو اس کی قوم کی طرف رسول بنا کر بھیجا، اس نے کہا کہ اے میری قوم کے لوگو! اللہ کی عبادت کرو اور اس کے سوا تمہارا کوئی معبود نہیں، کیا تم (اس سے) نہیں ڈرتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvii{اس کی قوم کے کافر سرداروں نے صاف کہہ دیا کہ یہ تو تم جیسا ہی انسان ہے، یہ تم پر فضیلت اور بڑائی حاصل کرنا چاہتا ہے۔ اگر اللہ ہی کو منظور ہوتا تو کسی فرشتے کو اتارتا، ہم نے تو اسے اپنے اگلے باپ دادوں کے زمانے میں سنا ہی نہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxcviii{یقیناً اس شخص کو جنون ہے، پس تم اسے ایک وقت مقرر تک ڈھیل دو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxcix{نوح (علیہ السلام) نے دعا کی اے میرے رب! ان کے جھٹلانے پر تو میری مدد کر\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcc{تو ہم نے ان کی طرف وحی بھیجی کہ تو ہماری آنکھوں کے سامنے ہماری وحی کے مطابق ایک کشتی بنا۔ جب ہمارا حکم آجائے اور تنور ابل پڑے تو، تو ہر قسم کا ایک ایک جوڑا اس میں رکھ لے اور اپنے اہل کو بھی، مگر ان میں سے جن کی بابت ہماری بات پہلے گزر چکی ہے۔ خبردار جن لوگوں نے ﻇلم کیا ہے ان کے بارے میں مجھ سے کچھ کلام نہ کرنا وه تو سب ڈبوئے جائیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcci{جب تو اور تیرے ساتھی کشتی پر باطمینان بیٹھ جاؤ تو کہنا کہ سب تعریف اللہ کے لئے ہی ہے جس نے ہمیں ﻇالم لوگوں سے نجات عطا فرمائی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccii{اور کہنا کہ اے میرے رب! مجھے بابرکت اتارنا اتار اور تو ہی بہتر ہے اتارنے والوں میں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcciii{یقیناً اس میں بڑی بڑی نشانیاں ہیں اور ہم بےشک آزمائش کرنے والے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcciv{ان کے بعد ہم نے اور بھی امت پیدا کی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccv{پھر ان میں خود ان میں سے (ہی) رسول بھی بھیجا کہ تم سب اللہ کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں، تم کیوں نہیں ڈرتے؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccvi{اور سرداران قوم نے جواب دیا، جو کفر کرتے تھے اور آخرت کی ملاقات کو جھٹلاتے تھے اور ہم نے انہیں دنیوی زندگی میں خوشحال کر رکھا تھا، کہ یہ تو تم جیسا ہی انسان ہے، تمہاری ہی خوراک یہ بھی کھاتا ہے اور تمہارے پینے کا پانی ہی یہ پیتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccvii{اگر تم نے اپنے جیسے ہی انسان کی تابعداری کر لی ہے تو بےشک تم سخت خسارے والے ہو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdccviii{کیا یہ تمہیں اس بات کا وعده کرتا ہے کہ جب تم مرکر صرف خاک اور ہڈی ره جاؤ گے تو تم پھر زنده کئے جاؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdccix{نہیں نہیں دور اور بہت دور ہے وه جس کا تم وعده دیئے جاتے ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdccx{(زندگی) تو صرف دنیا کی زندگی ہے ہم مرتے جیتے رہتے ہیں اور یہ نہیں کہ ہم پھر اٹھائے جائیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdccxi{یہ تو بس ایسا شخص ہے جس نے اللہ پر جھوٹ (بہتان) باندھ لیا ہے، ہم تو اس پر ایمان ﻻنے والے نہیں ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdccxii{نبی نے دعا کی کہ پروردگار! ان کے جھٹلانے پر تو میری مدد کر\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdccxiii{جواب ملا کہ یہ تو بہت ہی جلد اپنے کئے پر پچھتانے لگیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdccxiv{بالﺂخر عدل کے تقاضے کے مطابق چیﺦ نے پکڑ لیا اور ہم نے انہیں کوڑا کرکٹ کر ڈاﻻ، پس ﻇالموں کے لئے دوری ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdccxv{ان کے بعد ہم نے اور بھی بہت سی امتیں پیدا کیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdccxvi{نہ تو کوئی امت اپنے وقت مقرره سے آگے بڑھی اور نہ پیچھے رہی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdccxvii{پھر ہم نے لگاتار رسول بھیجے، جب جب اس امت کے پاس اس کا رسول آیا اس نے جھٹلایا، پس ہم نے ایک دوسرے کے پیچھے لگا دیا اور انہیں افسانہ بنا دیا۔ ان لوگوں کو دوری ہے جو ایمان قبول نہیں کرتے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdccxviii{پھر ہم نے موسیٰ (علیہ السلام) کو اور ان کے بھائی ہارون (علیہ السلام) کو اپنی آیتوں اور کھلی دلیل کے ساتھ بھیجا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdccxix{فرعون اور اس کے لشکروں کی طرف، پس انہوں نے تکبر کیا اور تھے ہی وه سرکش لوگ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdccxx{کہنے لگے کہ کیا ہم اپنے جیسے دو شخصوں پر ایمان ﻻئیں؟ حاﻻنکہ خود ان کی قوم (بھی) ہمارے ماتحت ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdccxxi{پس انہوں نے ان دونوں کو جھٹلایا آخر وه بھی ہلاک شده لوگوں میں مل گئے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdccxxii{ہم نے تو موسیٰ (علیہ السلام) کو کتاب (بھی) دی کہ لوگ راه راست پر آجائیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiii{ہم نے ابن مریم اور اس کی والده کو ایک نشانی بنایا اور ان دونوں کو بلند صاف قرار والی اور جاری پانی والی جگہ میں پناه دی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiv{اے پیغمبرو! حلال چیزیں کھاؤ اور نیک عمل کرو تم جو کچھ کر رہے ہو اس سے میں بخوبی واقف ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdccxxv{یقیناً تمہارا یہ دین ایک ہی دین ہے اور میں ہی تم سب کا رب ہوں، پس تم مجھ سے ڈرتے رہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvi{پھر انہوں نے خود (ہی) اپنے امر (دین) کے آپس میں ٹکڑے ٹکڑے کر لیئے، ہر گروه جو کچھ اس کے پاس ہے اسی پر اترا رہا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvii{پس آپ (بھی) انہیں ان کی غفلت میں ہی کچھ مدت پڑا رہنے دیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdccxxviii{کیا یہ (یوں) سمجھ بیٹھے ہیں؟ کہ ہم جو بھی ان کے مال و اوﻻد بڑھا رہے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdccxxix{وه ان کے لئے بھلائیوں میں جلدی کر رہے ہیں (نہیں نہیں) بلکہ یہ سمجھتے ہی نہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdccxxx{یقیناً جو لوگ اپنے رب کی ہیبت سے ڈرتے ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxi{اور جو اپنے رب کی آیتوں پر ایمان رکھتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxii{اور جو اپنے رب کے ساتھ کسی کو شریک نہیں کرتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiii{اور جو لوگ دیتے ہیں جو کچھ دیتے ہیں اور ان کے دل کپکپاتے ہیں کہ وه اپنے رب کی طرف لوٹنے والے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiv{یہی ہیں جو جلدی جلدی بھلائیاں حاصل کر رہے ہیں اور یہی ہیں جو ان کی طرف دوڑ جانے والے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxv{ہم کسی نفس کو اس کی طاقت سے زیاده تکلیف نہیں دیتے، اور ہمارے پاس ایسی کتاب ہے جو حق کے ساتھ بولتی ہے، ان کے اوپر کچھ ﻇلم نہ کیا جائے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvi{بلکہ ان کے دل اس طرف سے غفلت میں ہیں اور ان کے لئے اس کے سوا بھی بہت سے اعمال ہیں جنہیں وه کرنے والے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvii{یہاں تک کہ جب ہم نے ان کے آسوده حال لوگوں کو عذاب میں پکڑ لیا تو وه بلبلانے لگے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxviii{آج مت بلبلاؤ یقیناً تم ہمارے مقابلہ پر مدد نہ کئے جاؤ گے۔\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxix{میری آیتیں تو تمہارے سامنے پڑھی جاتی تھیں پھر بھی تم اپنی ایڑیوں کے بل الٹے بھاگتے تھے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdccxl{اکڑتے اینٹھتے افسانہ گوئی کرتے اسے چھوڑ دیتے تھے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdccxli{کیا انہوں نے اس بات میں غور وفکر ہی نہیں کیا؟ بلکہ ان کے پاس وه آیا جو ان کے اگلے باپ دادوں کے پاس نہیں آیا تھا؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdccxlii{یا انہوں نے اپنے پیغمبر کو پہچانا نہیں کہ اس کے منکر ہو رہے ہیں؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdccxliii{یا یہ کہتے ہیں کہ اسے جنون ہے؟ بلکہ وه تو ان کے پاس حق ﻻیا ہے۔ ہاں ان میں اکثر حق سے چڑنے والے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdccxliv{اگر حق ہی ان کی خواہشوں کا پیرو ہوجائے تو زمین وآسمان اور ان کے درمیان کی ہر چیز درہم برہم ہو جائے۔ حق تو یہ ہے کہ ہم نے انہیں ان کی نصیحت پہنچا دی ہے لیکن وه اپنی نصیحت سے منھ موڑنے والے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdccxlv{کیا آپ ان سے کوئی اجرت چاہتے ہیں؟ یاد رکھیئے کہ آپ کے رب کی اجرت بہت ہی بہتر ہے اور وه سب سے بہتر روزی رساں ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvi{یقیناً آپ تو انہیں راه راست کی طرف بلا رہے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvii{بےشک جو لوگ آخرت پر یقین نہیں رکھتے وه سیدھے راستے سے مڑ جانے والے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdccxlviii{اور اگر ہم ان پر رحم فرمائیں اور ان کی تکلیفیں دور کردیں تو یہ تو اپنی اپنی سرکشی میں جم کر اور بہکنے لگیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdccxlix{اور ہم نے انہیں عذاب میں بھی پکڑا تاہم یہ لوگ نہ تو اپنے پروردگار کے سامنے جھکے اور نہ ہی عاجزی اختیار کی\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdccl{یہاں تک کہ جب ہم نے ان پر سخت عذاب کا دروازه کھول دیا تو اسی وقت فوراً مایوس ہوگئے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdccli{وه اللہ ہے جس نے تمہارے لئے کان اور آنکھیں اور دل پیدا کئے، مگر تم بہت (ہی) کم شکر کرتے ہو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdcclii{اور وہی ہے جس نے تمہیں پیدا کرکے زمین میں پھیلا دیا اور اسی کی طرف تم جمع کئے جاؤ گے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdccliii{اور یہ وہی ہے جو جلاتا اور مارتا ہے اور رات دن کے ردوبدل کا مختار بھی وہی ہے۔ کیا تم کو سمجھ بوجھ نہیں؟\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdccliv{بلکہ ان لوگوں نے بھی ویسی ہی بات کہی جو اگلے کہتے چلے آئے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdcclv{کہ کیا جب ہم مر کر مٹی اور ہڈی ہوجائیں گے کیا پھر بھی ہم ضرور اٹھائے جائیں گے؟\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdcclvi{ہم سے اور ہمارے باپ دادوں سے پہلے ہی یہ وعده ہوتا چلا آیا ہے کچھ نہیں یہ تو صرف اگلے لوگوں کے افسانے ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdcclvii{پوچھیئے تو سہی کہ زمین اور اس کی کل چیزیں کس کی ہیں؟ بتلاؤ اگر جانتے ہو؟\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdcclviii{فوراً جواب دیں گے کہ اللہ کی، کہہ دیجیئے کہ پھر تم نصیحت کیوں نہیں حاصل کرتے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdcclix{دریافت کیجیئے کہ ساتوں آسمان کا اور بہت باعظمت عرش کا رب کون ہے؟\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdcclx{وه لوگ جواب دیں گے کہ اللہ ہی ہے۔ کہہ دیجیئے کہ پھر تم کیوں نہیں ڈرتے؟\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdcclxi{پوچھیئے کہ تمام چیزوں کا اختیار کس کے ہاتھ میں ہے؟ جو پناه دیتا ہے اور جس کے مقابلے میں کوئی پناه نہیں دیا جاتا، اگر تم جانتے ہو تو بتلا دو؟\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdcclxii{یہی جواب دیں گے کہ اللہ ہی ہے، کہہ دیجیئے پھر تم کدھر سے جادو کر دیئے جاتے ہو؟\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiii{حق یہ ہے کہ ہم نے انہیں حق پہنچا دیا ہے اور یہ بےشک جھوٹے ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiv{نہ تو اللہ نے کسی کو بیٹا بنایا اور نہ اس کے ساتھ اور کوئی معبود ہے، ورنہ ہر معبود اپنی مخلوق کو لئے لئے پھرتا اور ہر ایک دوسرے پر چڑھ دوڑتا۔ جو اوصاف یہ بتلاتے ہیں ان سے اللہ پاک (اور بےنیاز) ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdcclxv{وه غائب حاضر کا جاننے واﻻ ہے اور جو شرک یہ کرتے ہیں اس سے باﻻتر ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvi{آپ دعا کریں کہ اے میرے پروردگار! اگر تو مجھے وه دکھائے جس کا وعده انہیں دیا جا رہا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvii{تو اے رب! تو مجھے ان ﻇالموں کے گروه میں نہ کرنا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdcclxviii{ہم جو کچھ وعدے انہیں دے رہے ہیں سب آپ کو دکھا دینے پر یقیناً قادر ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdcclxix{برائی کو اس طریقے سے دور کریں جو سراسر بھلائی واﻻ ہو، جو کچھ یہ بیان کرتے ہیں ہم بخوبی واقف ہیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdcclxx{اور دعا کریں کہ اے میرے پروردگار! میں شیطانوں کے وسوسوں سے تیری پناه چاہتا ہوں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxi{اور اے رب! میں تیری پناه چاہتا ہوں کہ وه میرے پاس آجائیں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxii{یہاں تک کہ جب ان میں کسی کو موت آنے لگتی ہے تو کہتا ہے اے میرے پروردگار! مجھے واپس لوٹا دے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiii{کہ اپنی چھوڑی ہوئی دنیا میں جا کر نیک اعمال کر لوں، ہرگز ایسا نہیں ہوگا، یہ تو صرف ایک قول ہے جس کا یہ قائل ہے، ان کے پس پشت تو ایک حجاب ہے، ان کے دوباره جی اٹھنے کے دن تک\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiv{پس جب کہ صور پھونک دیا جائے گا اس دن نہ تو آپس کے رشتے دار ہی رہیں گے، نہ آپس کی پوچھ گچھ\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxv{جن کی ترازو کا پلہ بھاری ہوگیا وه تو نجات والے ہوگئے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvi{اور جن کے ترازو کا پلہ ہلکا ہوگیا یہ ہیں وه جنہوں نے اپنا نقصان آپ کر لیا جو ہمیشہ کے لئے جہنم واصل ہوئے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvii{ان کے چہروں کو آگ جھلستی رہے گی اور وه وہاں بدشکل بنے ہوئے ہوں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxviii{کیا میری آیتیں تمہارے سامنے تلاوت نہیں کی جاتی تھیں؟ پھر بھی تم انہیں جھٹلاتے تھے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxix{کہیں گے کہ اے پروردگار! ہماری بدبختی ہم پر غالب آگئی (واقعی) ہم تھے ہی گمراه\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxx{اے ہمارے پروردگار! ہمیں یہاں سے نجات دے اگر اب بھی ہم ایسا ہی کریں تو بےشک ہم ﻇالم ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxi{اللہ تعالیٰ فرمائے گا پھٹکارے ہوئے یہیں پڑے رہو اور مجھ سے کلام نہ کرو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxii{میرے بندوں کی ایک جماعت تھی جو برابر یہی کہتی رہی کہ اے ہمارے پروردگار! ہم ایمان ﻻچکے ہیں تو ہمیں بخش اور ہم پر رحم فرما تو سب مہربانوں سے زیاده مہربان ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiii{(لیکن) تم انہیں مذاق میں ہی اڑاتے رہے یہاں تک کہ (اس مشغلے نے) تم کو میری یاد (بھی) بھلا دی اور تم ان سے مذاق ہی کرتے رہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiv{میں نے آج انہیں ان کے اس صبر کا بدلہ دے دیا ہے کہ وه خاطر خواه اپنی مراد کو پہنچ چکے ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxv{اللہ تعالیٰ دریافت فرمائے گا کہ تم زمین میں باعتبار برسوں کی گنتی کے کس قدر رہے؟\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvi{وه کہیں گے ایک دن یا ایک دن سے بھی کم، گنتی گننے والوں سے بھی پوچھ لیجیئے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvii{اللہ تعالیٰ فرمائے گا فی الواقع تم وہاں بہت ہی کم رہے ہو اے کاش! تم اسے پہلے ہی سے جان لیتے؟\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxviii{کیا تم یہ گمان کئے ہوئے ہو کہ ہم نے تمہیں یوں ہی بیکار پیدا کیا ہے اور یہ کہ تم ہماری طرف لوٹائے ہی نہ جاؤ گے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxix{اللہ تعالیٰ سچا بادشاه ہے وه بڑی بلندی واﻻ ہے۔ اس کے سوا کوئی معبود نہیں، وہی بزرگ عرش کا مالک ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmdccxc{جو شخص اللہ کے ساتھ کسی دوسرے معبود کو پکارے جس کی کوئی دلیل اس کے پاس نہیں، پس اس کا حساب تو اس کے رب کے اوپر ہی ہے۔ بےشک کافر لوگ نجات سے محروم ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmdccxci{اور کہو کہ اے میرے رب! تو بخش اور رحم کر اور تو سب مہربانوں سے بہتر مہربانی کرنے واﻻ ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmdccxcii{\basmalahur یہ ہے وه سورت جو ہم نے نازل فرمائی ہے اور مقرر کردی ہے اور جس میں ہم نے کھلی آیتیں (احکام) اتارے ہیں تاکہ تم یاد رکھو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccxciii{زناکار عورت و مرد میں سے ہر ایک کو سو کوڑے لگاؤ۔ ان پر اللہ کی شریعت کی حد جاری کرتے ہوئے تمہیں ہرگز ترس نہ کھانا چاہیئے، اگر تمہیں اللہ پر اور قیامت کے دن پر ایمان ہو۔ ان کی سزا کے وقت مسلمانوں کی ایک جماعت موجود ہونی چاہیئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccxciv{زانی مرد بجز زانیہ یا مشرکہ عورت کے اور سے نکاح نہیں کرتا اور زناکار عورت بھی بجز زانی یا مشرک مرد کے اور سے نکاح نہیں کرتی اور ایمان والوں پر یہ حرام کردیا گیا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccxcv{جو لوگ پاک دامن عورتوں پر زنا کی تہمت لگائیں پھر چار گواه نہ پیش کرسکیں تو انہیں اسی کوڑے لگاؤ اور کبھی بھی ان کی گواہی قبول نہ کرو۔ یہ فاسق لوگ ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvi{ہاں جو لوگ اس کے بعد توبہ اور اصلاح کرلیں تو اللہ تعالیٰ بخشنے واﻻ اور مہربانی کرنے واﻻ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvii{جو لوگ اپنی بیویوں پر بدکاری کی تہمت لائیں اور ان کا کوئی گواه بجز خود ان کی ذات کے نہ ہو تو ایسے لوگوں میں سے ہر ایک کا ﺛبوت یہ ہے کہ چار مرتبہ اللہ کی قسم کھا کر کہیں کہ وه سچوں میں سے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccxcviii{اور پانچویں مرتبہ کہے کہ اس پر اللہ تعالیٰ کی لعنت ہو اگر وه جھوٹوں میں سے ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccxcix{اور اس عورت سے سزا اس طرح دور ہوسکتی ہے کہ وه چار مرتبہ اللہ کی قسم کھا کر کہے کہ یقیناً اس کا مرد جھوٹ بولنے والوں میں سے ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccc{اور پانچویں دفعہ کہے کہ اس پر اللہ تعالیٰ کا غضب ہو اگر اس کا خاوند سچوں میں سے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccci{اگر اللہ تعالیٰ کا فضل وکرم تم پر نہ ہوتا (تو تم پر مشقت اترتی) اور اللہ تعالیٰ توبہ قبول کرنے واﻻ باحکمت ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcccii{جو لوگ یہ بہت بڑا بہتان باندھ ﻻئے ہیں یہ بھی تم میں سے ہی ایک گروه ہے۔ تم اسے اپنے لئے برا نہ سمجھو، بلکہ یہ تو تمہارے حق میں بہتر ہے۔ ہاں ان میں سے ہر ایک شخص پر اتنا گناه ہے جتنا اس نے کمایا ہے اور ان میں سے جس نے اس کے بہت بڑے حصے کو سرانجام دیا ہے اس کے لئے عذاب بھی بہت ہی بڑا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccciii{اسے سنتے ہی مومن مردوں عورتوں نے اپنے حق میں نیک گمانی کیوں نہ کی اور کیوں نہ کہہ دیا کہ یہ تو کھلم کھلا صریح بہتان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccciv{وه اس پر چار گواه کیوں نہ ﻻئے؟ اور جب گواه نہیں ﻻئے تو یہ بہتان باز لوگ یقیناً اللہ کے نزدیک محض جھوٹے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcccv{اگر اللہ تعالیٰ کا فضل وکرم تم پر دنیا اور آخرت میں نہ ہوتا تو یقیناً تم نے جس بات کے چرچے شروع کر رکھے تھے اس بارے میں تمہیں بہت بڑا عذاب پہنچتا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcccvi{جب کہ تم اسے اپنی زبانوں سے نقل در نقل کرنے لگے اور اپنے منھ سے وه بات نکالنے لگے جس کی تمہیں مطلق خبر نہ تھی، گو تم اسے ہلکی بات سمجھتے رہے لیکن اللہ تعالیٰ کے نزدیک وه بہت بڑی بات تھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcccvii{تم نے ایسی بات کو سنتے ہی کیوں نہ کہہ دیا کہ ہمیں ایسی بات منھ سے نکالنی بھی ﻻئق نہیں۔ یا اللہ! تو پاک ہے، یہ تو بہت بڑا بہتان ہے اور تہمت ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcccviii{اللہ تعالیٰ تمہیں نصیحت کرتا ہے کہ پھر کبھی بھی ایسا کام نہ کرنا اگر تم سچے مومن ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcccix{اللہ تعالیٰ تمہارے سامنے اپنی آیتیں بیان فرما رہا ہے، اور اللہ تعالیٰ علم و حکمت واﻻ ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcccx{جو لوگ مسلمانوں میں بےحیائی پھیلانے کے آرزومند رہتے ہیں ان کے لئے دنیا اور آخرت میں دردناک عذاب ہیں، اللہ سب کچھ جانتا ہے اور تم کچھ بھی نہیں جانتے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcccxi{اگر تم پر اللہ کا فضل اور اس کی رحمت نہ ہوتی اور یہ بھی کہ اللہ تعالیٰ بڑی شفقت رکھنے واﻻ مہربان ہے۔ (تو تم پر عذاب اتر جاتا)\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcccxii{ایمان والو! شیطان کے قدم بقدم نہ چلو۔ جو شخص شیطانی قدموں کی پیروی کرے تو وه تو بےحیائی اور برے کاموں کا ہی حکم کرے گا۔ اور اگر اللہ تعالیٰ کا فضل وکرم تم پر نہ ہوتا تو تم میں سے کوئی کبھی بھی پاک صاف نہ ہوتا۔ لیکن اللہ تعالی جسے پاک کرنا چاہے، کر دیتا ہے۔ اور اللہ سب سننے واﻻ سب جاننے واﻻ ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiii{تم میں سے جو بزرگی اور کشادگی والے ہیں انہیں اپنے قرابت داروں اور مسکینوں اور مہاجروں کو فی سبیل اللہ دینے سے قسم نہ کھا لینی چاہیئے، بلکہ معاف کردینا اور درگزر کرلینا چاہیئے۔ کیا تم نہیں چاہتے کہ اللہ تعالیٰ تمہارے قصور معاف فرما دے؟ اللہ قصوروں کو معاف فرمانے واﻻ مہربان ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiv{جو لوگ پاک دامن بھولی بھالی باایمان عورتوں پر تہمت لگاتے ہیں وه دنیا وآخرت میں ملعون ہیں اور ان کے لئے بڑا بھاری عذاب ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcccxv{جب کہ ان کے مقابلے میں ان کی زبانیں اور ان کے ہاتھ پاؤں ان کے اعمال کی گواہی دیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvi{اس دن اللہ تعالیٰ انہیں پورا پورا بدلہ حق و انصاف کے ساتھ دے گا اور وه جان لیں گے کہ اللہ تعالیٰ ہی حق ہے (اور وہی) ﻇاہر کرنے واﻻ ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvii{خبیﺚ عورتیں خبیﺚ مردوں کے ﻻئق ہیں اور خبیﺚ مرد خبیﺚ عورتوں کے ﻻئق ہیں اور پاک عورتیں پاک مردوں کے ﻻئق ہیں اور پاک مرد پاک عورتوں کے ﻻئق ہیں۔ ایسے پاک لوگوں کے متعلق جو کچھ بکواس (بہتان باز) کر رہے ہیں وه ان سے بالکل بری ہیں، ان کے لئے بخشش ہے اور عزت والی روزی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcccxviii{اے ایمان والو! اپنے گھروں کے سوا اور گھروں میں نہ جاؤ جب تک کہ اجازت نہ لے لو اور وہاں کے رہنے والوں کو سلام نہ کرلو، یہی تمہارے لئے سراسر بہتر ہے تاکہ تم نصیحت حاصل کرو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcccxix{اگر وہاں تمہیں کوئی بھی نہ مل سکے تو پھر اجازت ملے بغیر اندر نہ جاؤ۔ اگر تم سے لوٹ جانے کو کہا جائے تو تم لوٹ ہی جاؤ، یہی بات تمہارے لئے پاکیزه ہے، جو کچھ تم کر رہے ہو اللہ تعالیٰ خوب جانتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcccxx{ہاں غیر آباد گھروں میں جہاں تمہارا کوئی فائده یا اسباب ہو، جانے میں تم پر کوئی گناه نہیں۔ تم جو کچھ بھی ﻇاہر کرتے ہو اور جو چھپاتے ہو اللہ تعالیٰ سب کچھ جانتا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxi{مسلمان مردوں سے کہو کہ اپنی نگاہیں نیچی رکھیں، اور اپنی شرمگاہوں کی حفاﻇت رکھیں۔ یہی ان کے لئے پاکیزگی ہے، لوگ جو کچھ کریں اللہ تعالیٰ سب سے خبردار ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxii{مسلمان عورتوں سے کہو کہ وه بھی اپنی نگاہیں نیچی رکھیں اور اپنی عصمت میں فرق نہ آنے دیں اور اپنی زینت کو ﻇاہر نہ کریں، سوائے اس کے جو ﻇاہر ہے اور اپنے گریبانوں پر اپنی اوڑھنیاں ڈالے رہیں، اور اپنی آرائش کو کسی کے سامنے ﻇاہر نہ کریں، سوائے اپنے خاوندوں کے یا اپنے والد کے یا اپنے خسر کے یا اپنے لڑکوں کے یا اپنے خاوند کے لڑکوں کے یا اپنے بھائیوں کے یا اپنے بھتیجوں کے یا اپنے بھانجوں کے یا اپنے میل جول کی عورتوں کے یا غلاموں کے یا ایسے نوکر چاکر مردوں کے جو شہوت والے نہ ہوں یا ایسے بچوں کے جو عورتوں کے پردے کی باتوں سے مطلع نہیں۔ اور اس طرح زور زور سے پاؤں مار کر نہ چلیں کہ ان کی پوشیده زینت معلوم ہوجائے، اے مسلمانو! تم سب کے سب اللہ کی جناب میں توبہ کرو تاکہ تم نجات پاؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiii{تم میں سے جو مرد عورت بےنکاح کے ہوں ان کا نکاح کر دو اور اپنے نیک بخت غلام اور لونڈیوں کا بھی۔ اگر وه مفلس بھی ہوں گے تو اللہ تعالیٰ انہیں اپنے فضل سے غنی بنا دے گا۔ اللہ تعالیٰ کشادگی واﻻ اور علم واﻻ ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiv{اور ان لوگوں کو پاک دامن رہنا چاہیئے جو اپنا نکاح کرنے کا مقدور نہیں رکھتے یہاں تک کہ اللہ تعالیٰ انہیں اپنے فضل سے مالدار بنا دے، تمہارے غلاموں میں جو کوئی کچھ تمہیں دے کر آزادی کی تحریر کرانی چاہے تو تم ایسی تحریر انہیں کردیا کرو اگر تم کو ان میں کوئی بھلائی نظر آتی ہو۔ اور اللہ نے جو مال تمہیں دے رکھا ہے اس میں سے انہیں بھی دو، تمہاری جو لونڈیاں پاک دامن رہنا چاہتی ہیں انہیں دنیا کی زندگی کے فائدے کی غرض سے بدکاری پر مجبور نہ کرو اور جو انہیں مجبور کردے تو اللہ تعالیٰ ان پر جبر کے بعد بخشش دینے واﻻ اور مہربانی کرنے واﻻ ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxv{ہم نے تمہاری طرف کھلی اور روشن آیتیں اتار دی ہیں اور ان لوگوں کی کہاوتیں جو تم سے پہلے گزرچکے ہیں اور پرہیزگاروں کے لئے نصیحت\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvi{اللہ نور ہے آسمانوں اور زمین کا، اس کے نور کی مثال مثل ایک طاق کے ہے جس میں چراغ ہو اور چراغ شیشہ کی قندیل میں ہو اور شیشہ مثل چمکتے ہوئے روشن ستارے کے ہو وه چراغ ایک بابرکت درخت زیتون کے تیل سے جلایا جاتا ہو جو درخت نہ مشرقی ہے نہ مغربی خود وه تیل قریب ہے کہ آپ ہی روشنی دینے لگے اگرچہ اسے آگ نہ بھی چھوئے، نور پر نور ہے، اللہ تعالیٰ اپنے نور کی طرف رہنمائی کرتا ہے جسے چاہے، لوگوں (کے سمجھانے) کو یہ مثالیں اللہ تعالیٰ بیان فرما رہا ہے، اور اللہ تعالیٰ ہر چیز کے حال سے بخوبی واقف ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvii{ان گھروں میں جن کے بلند کرنے، اور جن میں اپنے نام کی یاد کا اللہ تعالیٰ نے حکم دیا ہے وہاں صبح وشام اللہ تعالیٰ کی تسبیح بیان کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxviii{ایسے لوگ جنہیں تجارت اور خرید وفروخت اللہ کے ذکر سے اور نماز کے قائم کرنے اور زکوٰة ادا کرنے سے غافل نہیں کرتی اس دن سے ڈرتے ہیں جس دن بہت سے دل اور بہت سی آنکھیں الٹ پلٹ ہوجائیں گی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxix{اس ارادے سے کہ اللہ انہیں ان کے اعمال کا بہترین بدلے دے بلکہ اپنے فضل سے اور کچھ زیادتی عطا فرمائے۔ اللہ تعالیٰ جسے چاہے بےشمار روزیاں دیتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxx{اور کافروں کے اعمال مثل اس چمکتی ہوئی ریت کے ہیں جو چٹیل میدان میں ہو جسے پیاسا شخص دور سے پانی سمجھتا ہے لیکن جب اس کے پاس پہنچتا ہے تو اسے کچھ بھی نہیں پاتا، ہاں اللہ کو اپنے پاس پاتا ہے جو اس کا حساب پورا پورا چکا دیتا ہے۔ اللہ بہت جلد حساب کردینے واﻻ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxi{یا مثل ان اندھیروں کے ہے جو نہایت گہرے سمندر کی تہہ میں ہوں جسے اوپر تلے کی موجوں نے ڈھانﭗ رکھا ہو، پھر اوپر سے بادل چھائے ہوئے ہوں۔ الغرض اندھیریاں ہیں جو اوپر تلے پےدرپے ہیں۔ جب اپنا ہاتھ نکالے تو اسے بھی قریب ہے کہ نہ دیکھ سکے، اور (بات یہ ہے کہ) جسے اللہ تعالیٰ ہی نور نہ دے اس کے پاس کوئی روشنی نہیں ہوتی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxii{کیا آپ نے نہیں دیکھا کہ آسمانوں اور زمین کی کل مخلوق اور پر پھیلائے اڑنے والے کل پرند اللہ کی تسبیح میں مشغول ہیں۔ ہر ایک کی نماز اور تسبیح اسے معلوم ہے، لوگ جو کچھ کریں اس سے اللہ بخوبی واقف ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiii{زمین و آسمان کی بادشاہت اللہ ہی کی ہے اور اللہ تعالیٰ ہی کی طرف لوٹنا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiv{کیا آپ نے نہیں دیکھا کہ اللہ تعالیٰ بادلوں کو چلاتا ہے، پھر انہیں ملاتا ہے پھر انہیں تہہ بہ تہہ کر دیتا ہے، پھر آپ دیکھتے ہیں کہ ان کے درمیان میں سے مینہ برستا ہے۔ وہی آسمان کی جانب سے اولوں کے پہاڑ میں سے اولے برساتا ہے، پھر جنہیں چاہے ان کے پاس انہیں برسائے اور جن سے چاہے ان سے انہیں ہٹا دے۔ بادل ہی سے نکلنے والی بجلی کی چمک ایسی ہوتی ہے کہ گویا اب آنکھوں کی روشنی لے چلی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxv{اللہ تعالیٰ ہی دن اور رات کو ردوبدل کرتا رہتا ہے آنکھوں والوں کے لیے تو اس میں یقیناً بڑی بڑی عبرتیں ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvi{تمام کے تمام چلنے پھرنے والے جانداروں کو اللہ تعالیٰ ہی نے پانی سے پیدا کیا ہےان میں سے بعض تو اپنے پیٹ کے بل چلتے ہیں، بعض دو پاؤں پر چلتے ہیں۔ بعض چار پاؤں پر چلتے ہیں، اللہ تعالیٰ جو چاہتا ہے پیدا کرتا ہے۔ بےشک اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvii{بلاشک و شبہ ہم نے روشن اور واضح آیتیں اتار دی ہیں اللہ تعالیٰ جسے چاہے سیدھی راه دکھا دیتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxviii{اور کہتے ہیں کہ ہم اللہ تعالیٰ اور رسول پر ایمان ﻻئے اور فرماں بردار ہوئے، پھر ان میں سے ایک فرقہ اس کے بعد بھی پھر جاتا ہے۔ یہ ایمان والے ہیں (ہی) نہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxix{جب یہ اس بات کی طرف بلائے جاتے ہیں کہ اللہ اور اس کا رسول ان کے جھگڑے چکا دے تو بھی ان کی ایک جماعت منھ موڑنے والی بن جاتی ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcccxl{ہاں اگر ان ہی کو حق پہنچتا ہو تو مطیع وفرماں بردار ہو کر اس کی طرف چلے آتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcccxli{کیا ان کے دلوں میں بیماری ہے؟ یا یہ شک وشبہ میں پڑے ہوئے ہیں؟ یا انہیں اس بات کا ڈر ہے کہ اللہ تعالیٰ اور اس کا رسول ان کی حق تلفی نہ کریں؟ بات یہ ہے کہ یہ لوگ خود ہی بڑے ﻇالم ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlii{ایمان والوں کا قول تو یہ ہے کہ جب انہیں اس لئے بلایا جاتا ہے کہ اللہ اور اس کا رسول ان میں فیصلہ کردے تو وه کہتے ہیں کہ ہم نے سنا اور مان لیا۔ یہی لوگ کامیاب ہونے والے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliii{جو بھی اللہ تعالیٰ کی، اس کے رسول کی فرماں برداری کریں، خوف الٰہی رکھیں اور اس کے عذابوں سے ڈرتے رہیں، وہی نجات پانے والے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliv{بڑی پختگی کے ساتھ اللہ تعالیٰ کی قسمیں کھا کھا کر کہتے ہیں کہ آپ کا حکم ہوتے ہی نکل کھڑے ہوں گے۔ کہہ دیجیئے کہ بس قسمیں نہ کھاؤ (تمہاری) اطاعت (کی حقیقت) معلوم ہے۔ جو کچھ تم کر رہے ہو اللہ تعالیٰ اس سے باخبر ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlv{کہہ دیجیئے کہ اللہ تعالیٰ کا حکم مانو، رسول اللہ کی اطاعت کرو، پھر بھی اگر تم نے روگردانی کی تو رسول کے ذمے تو صرف وہی ہے جو اس پر ﻻزم کردیا گیا ہے اور تم پر اس کی جوابدہی ہے جو تم پر رکھا گیا ہے ہدایت تو تمہیں اسی وقت ملے گی جب رسول کی ماتحتی کرو۔ سنو رسول کے ذمے تو صرف صاف طور پر پہنچا دینا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvi{تم میں سے ان لوگوں سے جو ایمان ﻻئے ہیں اور نیک اعمال کئے ہیں اللہ تعالیٰ وعده فرما چکا ہے کہ انہیں ضرور زمین میں خلیفہ بنائے گا جیسے کہ ان لوگوں کو خلیفہ بنایا تھا جو ان سے پہلے تھے اور یقیناً ان کے لئے ان کے اس دین کو مضبوطی کے ساتھ محکم کرکے جما دے گا جسے ان کے لئے وه پسند فرما چکا ہے اور ان کے اس خوف وخطر کو وه امن وامان سے بدل دے گا، وه میری عبادت کریں گے میرے ساتھ کسی کو بھی شریک نہ ٹھہرائیں گے۔ اس کے بعد بھی جو لوگ ناشکری اور کفر کریں وه یقیناً فاسق ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvii{نماز کی پابندی کرو، زکوٰة ادا کرو اور اللہ تعالیٰ کے رسول کی فرمانبرداری میں لگے رہو تاکہ تم پر رحم کیا جائے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlviii{یہ خیال آپ کبھی بھی نہ کرنا کہ منکر لوگ زمین میں (ادھر ادھر بھاگ کر) ہمیں ہرا دینے والے ہیں، ان کا اصلی ٹھکانا تو جہنم ہے جو یقیناً بہت ہی برا ٹھکانا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlix{ایمان والو! تم سے تمہاری ملکیت کے غلاموں کو اور انہیں بھی جو تم میں سے بلوغت کو نہ پہنچے ہوں (اپنے آنے کی) تین وقتوں میں اجازت حاصل کرنی ضروری ہے۔ نماز فجر سے پہلے اور ﻇہر کے وقت جب کہ تم اپنے کپڑے اتار رکھتے ہو اور عشا کی نماز کے بعد، یہ تینوں وقت تمہاری (خلوت) اور پرده کے ہیں۔ ان وقتوں کے ماسوا نہ تو تم پر کوئی گناه ہے نہ ان پر۔ تم سب آپس میں ایک دوسرے کے پاس بکثرت آنے جانے والے ہو (ہی)، اللہ اسی طرح کھول کھول کر اپنے احکام تم سے بیان فرما رہا ہے۔ اللہ تعالیٰ پورے علم اور کامل حکمت واﻻ ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcccl{اور تمہارے بچے (بھی) جب بلوغت کو پہنچ جائیں تو جس طرح ان کے اگلے لوگ اجازت مانگتے ہیں انہیں بھی اجازت مانگ کر آنا چاہیئے، اللہ تعالیٰ تم سے اسی طرح اپنی آیتیں بیان فرماتا ہے۔ اللہ تعالیٰ ہی علم وحکمت واﻻ ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdcccli{بڑی بوڑھی عورتیں جنہیں نکاح کی امید (اور خواہش ہی) نہ رہی ہو وه اگر اپنے کپڑے اتار رکھیں تو ان پر کوئی گناه نہیں بشرطیکہ وه اپنا بناؤ سنگھار ﻇاہر کرنے والیاں نہ ہوں، تاہم اگر ان سے بھی احتیاط رکھیں تو ان کے لئے بہت افضل ہے، اور اللہ تعالیٰ سنتا جانتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccclii{اندھے پر، لنگڑے پر، بیمار پر اور خود تم پر (مطلقاً) کوئی حرج نہیں کہ تم اپنے گھروں سے کھالو یا اپنے باپوں کے گھروں سے یا اپنی ماؤں کے گھروں سے یا اپنے بھائیوں کے گھروں سے یا اپنی بہنوں کے گھروں سے یا اپنے چچاؤں کے گھروں سے یا اپنی پھوپھیوں کے گھروں سے یا اپنے ماموؤں کے گھروں سے یا اپنی خاﻻؤں کے گھروں سے یا ان گھروں سے جن کی کنجیوں کے تم مالک ہو یا اپنے دوستوں کے گھروں سے۔ تم پر اس میں بھی کوئی گناه نہیں کہ تم سب ساتھ بیٹھ کر کھانا کھاؤ یا الگ الگ پس جب تم گھروں میں جانے لگو تو اپنے گھر والوں کو سلام کرلیا کرو دعائے خیر ہے جو بابرکت اور پاکیزه ہے اللہ تعالیٰ کی طرف سے نازل شده، یوں ہی اللہ تعالیٰ کھول کھول کر تم سے اپنے احکام بیان فرما رہا ہے تاکہ تم سمجھ لو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdcccliii{باایمان لوگ تو وہی ہیں جو اللہ تعالیٰ پر اور اس کے رسول پر یقین رکھتے ہیں اور جب ایسے معاملہ میں جس میں لوگوں کے جمع ہونے کی ضرورت ہوتی ہے نبی کے ساتھ ہوتے ہیں تو جب تک آپ سے اجازت نہ لیں کہیں نہیں جاتے۔ جو لوگ ایسے موقع پر آپ سے اجازت لے لیتے ہیں حقیقت میں یہی ہیں وه جو اللہ تعالیٰ پر اور اس کے رسول پر ایمان ﻻچکے ہیں۔ پس جب ایسے لوگ آپ سے اپنے کسی کام کے لئے اجازت طلب کریں تو آپ ان میں سے جسے چاہیں اجازت دے دیں اور ان کے لئے اللہ تعالیٰ سے بخشش کی دعا مانگیں، بےشک اللہ بخشنے واﻻ مہربان ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdcccliv{تم اللہ تعالیٰ کے نبی کے بلانے کو ایسا بلاوا نہ کرلو جیسا کہ آپس میں ایک دوسرے کو ہوتا ہے۔ تم میں سے انہیں اللہ خوب جانتا ہے جو نظر بچا کر چپکے سے سرک جاتے ہیں۔ سنو جو لوگ حکم رسول کی مخالفت کرتے ہیں انہیں ڈرتے رہنا چاہیئے کہ کہیں ان پر کوئی زبردست آفت نہ آ پڑے یا انہیں درد ناک عذاب نہ پہنچے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccclv{آگاه ہو جاؤ کہ آسمان وزمین میں جو کچھ ہے سب اللہ تعالیٰ ہی کا ہے۔ جس روش پر تم ہو وه اسے بخوبی جانتا ہے، اور جس دن یہ سب اس کی طرف لوٹائے جائیں گے اس دن ان کو ان کے کئے سے وه خبردار کر دے گا۔ اللہ تعالیٰ سب کچھ جاننے واﻻ ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccclvi{\basmalahur بہت بابرکت ہے وه اللہ تعالیٰ جس نے اپنے بندے پر فرقان اتارا تاکہ وه تمام لوگوں کے لئے آگاه کرنے واﻻ بن جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccclvii{اسی اللہ کی سلطنت ہے آسمانوں اور زمین کی اور وه کوئی اوﻻد نہیں رکھتا، نہ اس کی سلطنت میں کوئی اس کا ساجھی ہے اور ہر چیز کو اس نے پیدا کرکے ایک مناسب اندازه ٹھہرا دیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccclviii{ان لوگوں نے اللہ کے سوا جنہیں اپنے معبود ٹھہرا رکھے ہیں وه کسی چیز کو پیدا نہیں کرسکتے بلکہ وه خود پیدا کئے جاتے ہیں، یہ تو اپنی جان کے نقصان نفع کا بھی اختیارنہیں رکھتے اور نہ موت وحیات کے اور نہ دوباره جی اٹھنے کے وه مالک ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccclix{اور کافروں نے کہا یہ تو بس خود اسی کا گھڑا گھڑایا جھوٹ ہے جس پر اور لوگوں نے بھی اس کی مدد کی ہے، دراصل یہ کافر بڑے ہی ﻇلم اور سرتاسر جھوٹ کے مرتکب ہوئے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccclx{اور یہ بھی کہا کہ یہ تو اگلوں کے افسانے ہیں جو اس نے لکھا رکھے ہیں بس وہی صبح وشام اس کے سامنے پڑھے جاتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccclxi{کہہ دیجیئے کہ اسے تو اس اللہ نے اتارا ہے جو آسمان وزمین کی تمام پوشیده باتوں کو جانتا ہے۔ بےشک وه بڑا ہی بخشنے واﻻ مہربان ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccclxii{اور انہوں نے کہا کہ یہ کیسا رسول ہے؟ کہ کھانا کھاتا ہے اور بازاروں میں چلتا پھرتا ہے، اس کے پاس کوئی فرشتہ کیوں نہیں بھیجا جاتا؟ کہ وه بھی اس کے ساتھ ہو کر ڈرانے واﻻ بن جاتا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiii{یا اس کے پاس کوئی خزانہ ہی ڈال دیا جاتا یا اس کا کوئی باغ ہی ہوتا جس میں سے یہ کھاتا۔ اور ان ﻇالموں نے کہا کہ تم ایسے آدمی کے پیچھے ہو لئے ہو جس پر جادو کر دیا گیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiv{خیال تو کیجیئے! کہ یہ لوگ آپ کی نسبت کیسی کیسی باتیں بناتے ہیں۔ پس جس سے وه خود ہی بہک رہے ہیں اور کسی طرح راه پر نہیں آسکتے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccclxv{اللہ تعالیٰ تو ایسا بابرکت ہے کہ اگر چاہے تو آپ کو بہت سے ایسے باغات عنایت فرما دے جو ان کے کہے ہوئے باغ سے بہت ہی بہتر ہوں جن کے نیچے نہریں لہریں لے رہی ہوں اور آپ کو بہت سے (پختہ) محل بھی دے دے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvi{بات یہ ہے کہ یہ لوگ قیامت کو جھوٹ سمجھتے ہیں اور قیامت کے جھٹلانے والوں کے لئے ہم نے بھڑکتی ہوئی آگ تیار کر رکھی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvii{جب وه انہیں دور سے دیکھے گی تو یہ اس کا غصے سے بپھرنا اور دھاڑنا سنیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccclxviii{اور جب یہ جہنم کی کسی تنگ جگہ میں مشکیں کس کر پھینک دیئے جائیں گے تو وہاں اپنے لئے موت ہی موت پکاریں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdccclxix{(ان سے کہا جائے گا) آج ایک ہی موت کو نہ پکارو بلکہ بہت سی اموات کو پکارو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdccclxx{آپ کہہ دیجیئے کہ کیا یہ بہتر ہے یا وه ہمیشگی والی جنت جس کا وعده پرہیزگاروں سے کیا گیا ہے، جو ان کا بدلہ ہے اور ان کے لوٹنے کی اصلی جگہ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxi{وه جو چاہیں گے ان کے لئے وہاں موجود ہوگا، ہمیشہ رہنے والے۔ یہ تو آپ کے رب کے ذمے وعده ہے جو قابل طلب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxii{اور جس دن اللہ تعالیٰ انہیں اور سوائے اللہ کے جنہیں یہ پوجتے رہے، انہیں جمع کرکے پوچھے گا کہ کیا میرے ان بندوں کو تم نے گمراه کیا یا یہ خود ہی راه سے گم ہوگئے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiii{وه جواب دیں گے کہ تو پاک ذات ہے خود ہمیں ہی یہ زیبا نہ تھا کہ تیرے سوا اوروں کو اپنا کارساز بناتے بات یہ ہے کہ تو نے انہیں اور ان کے باپ دادوں کو آسودگیاں عطا فرمائیں یہاں تک کہ وه نصیحت بھلا بیٹھے، یہ لوگ تھے ہی ہلاک ہونے والے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiv{تو انہوں نے تو تمہیں تمہاری تمام باتوں میں جھٹلایا، اب نہ تو تم میں عذابوں کے پھیرنے کی طاقت ہے، نہ مدد کرنے کی، تم میں سے جس جس نے ﻇلم کیا ہے ہم اسے بڑا عذاب چکھائیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxv{ہم نے آپ سے پہلے جتنے رسول بھیجے سب کے سب کھانا بھی کھاتے تھے اور بازاروں میں بھی چلتے پھرتے تھے اور ہم نے تم میں سے ہر ایک کو دوسرے کی آزمائش کا ذریعہ بنا دیا۔ کیا تم صبر کرو گے؟ تیرا رب سب کچھ دیکھنے واﻻ ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvi{اور جنہیں ہماری ملاقات کی توقع نہیں انہوں نے کہا کہ ہم پر فرشتے کیوں نہیں اتارے جاتے؟ یا ہم اپنی آنکھوں سے اپنے رب کو دیکھ لیتے؟ ان لوگوں نے اپنے آپ کو ہی بہت بڑا سمجھ رکھا ہے اور سخت سرکشی کرلی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvii{جس دن یہ فرشتوں کو دیکھ لیں گے اس دن ان گناه گاروں کو کوئی خوشی نہ ہوگی اور کہیں گے یہ محروم ہی محروم کیے گئے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxviii{اور انہوں نے جو جو اعمال کیے تھے ہم نےان کی طرف بڑھ کر انہیں پراگنده ذروں کی طرح کردیا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxix{البتہ اس دن جنتیوں کا ٹھکانا بہتر ہوگا اور خواب گاه بھی عمده ہوگی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxx{اور جس دن آسمان بادل سمیت پھٹ جائے گا اور فرشتے لگاتار اتارے جائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxi{اس دن صحیح طور پر ملک صرف رحمٰن کا ہی ہوگا اور یہ دن کافروں پر بڑا بھاری ہوگا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxii{اور اس دن ﻇالم شخص اپنے ہاتھوں کو چبا چبا کر کہے گا ہائے کاش کہ میں نے رسول (صلی اللہ علیہ وسلم) کی راه اختیار کی ہوتی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiii{ہائے افسوس کاش کہ میں نے فلاں کو دوست نہ بنایا ہوتا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiv{اس نے تو مجھے اس کے بعد گمراه کردیا کہ نصیحت میرے پاس آپہنچی تھی اور شیطان تو انسان کو (وقت پر) دغا دینے واﻻ ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxv{اور رسول کہے گا کہ اے میرے پروردگار! بےشک میری امت نے اس قرآن کو چھوڑ رکھا تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvi{اور اسی طرح ہم نے ہر نبی کے دشمن بعض گناه گاروں کو بنادیا ہے اور تیرا رب ہی ہدایت کرنے واﻻ اور مدد کرنے واﻻ کافی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvii{اور کافروں نے کہا کہ اس پر قرآن سارا کا سارا ایک ساتھ ہی کیوں نہ اتارا گیا اسی طرح ہم نے (تھوڑا تھوڑا کرکے) اتارا تاکہ اس سے ہم آپ کا دل قوی رکھیں، ہم نے اسے ٹھہر ٹھہر کر ہی پڑھ سنایا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxviii{یہ آپ کے پاس جو کوئی مثال ﻻئیں گے ہم اس کا سچا جواب اور عمده توجیہ آپ کو بتادیں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxix{جو لوگ اپنے منھ کے بل جہنم کی طرف جمع کیے جائیں گے۔ وہی بدتر مکان والے اور گمراه تر راستے والے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxc{اور بلاشبہ ہم نے موسیٰ کو کتاب دی اور ان کے ہمراه ان کے بھائی ہارون کو ان کا وزیر بنادیا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxci{اور کہہ دیا کہ تم دونوں ان لوگوں کی طرف جاؤ جو ہماری آیتوں کو جھٹلا رہے ہیں۔ پھر ہم نے انہیں بالکل ہی پامال کردیا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcii{اور قوم نوح نے بھی جب رسولوں کو جھوٹا کہا تو ہم نے انہیں غرق کردیا اور لوگوں کے لیے انہیں نشان عبرت بنا دیا۔ اور ہم نے ﻇالموں کے لیے دردناک عذاب مہیا کر رکھا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciii{اور عادیوں اور ﺛمودیوں اور کنوئیں والوں کو اور ان کے درمیان کی بہت سی امتوں کو (ہلاک کردیا)\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciv{اور ہم نے ان کے سامنے مثالیں بیان کیں پھر ہر ایک کو بالکل ہی تباه و برباد کردیا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcv{یہ لوگ اس بستی کے پاس سے بھی آتے جاتے ہیں جن پر بری طرح کی بارش برسائی گئی۔ کیا یہ پھر بھی اسے دیکھتے نہیں؟ حقیقت یہ ہے کہ انہیں مرکر جی اٹھنے کی امید ہی نہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvi{اور تمہیں جب کبھی دیکھتے ہیں تو تم سے مسخرا پن کرنے لگتے ہیں۔ کہ کیا یہی وه شخص ہیں جنہیں اللہ تعالیٰ نے رسول بنا کر بھیجا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvii{(وه تو کہیئے) کہ ہم اس پر جمے رہے ورنہ انہوں نے تو ہمیں ہمارے معبودوں سے بہکادینے میں کوئی کسر نہیں چھوڑی تھی۔ اور یہ جب عذابوں کو دیکھیں گے تو انہیں صاف معلوم ہوجائے گا کہ پوری طرح راه سے بھٹکا ہوا کون تھا؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcviii{کیا آپ نے اسے بھی دیکھا جو اپنی خواہش نفس کو اپنا معبود بنائے ہوئے ہے کیا آپ اس کے ذمہدار ہوسکتے ہیں؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcix{کیا آپ اسی خیال میں ہیں کہ ان میں سے اکثر سنتے یا سمجھتے ہیں۔ وه تو نرے چوپایوں جیسے ہیں بلکہ ان سے بھی زیاده بھٹکے ہوئے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcm{کیا آپ نے نہیں دیکھا کہ آپ کے رب نے سائے کو کس طرح پھیلا دیا ہے؟ اگر چاہتا تو اسے ٹھہرا ہوا ہی کر دیتا۔ پھر ہم نے آفتاب کو اس پر دلیل بنایا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmi{پھر ہم نے اسے آہستہ آہستہ اپنی طرف کھینچ لیا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmii{اور وہی ہے جس نے رات کو تمہارے لیے پرده بنایا۔ اور نیند کو راحت بنائی۔ اور دن کو اٹھ کھڑے ہونے کا وقت\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmiii{اور وہی ہے جو باران رحمت سے پہلے خوش خبری دینے والی ہواؤں کو بھیجتا ہے اور ہم آسمان سے پاک پانی برساتے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmiv{تاکہ اس کے ذریعے سے مرده شہر کو زنده کردیں اوراسے ہم اپنی مخلوقات میں سے بہت سے چوپایوں اور انسانوں کو پلاتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmv{اور بے شک ہم نے اسےان کے درمیان طرح طرح سے بیان کیا تاکہ وه نصیحت حاصل کریں، مگر پھر بھی اکثر لوگوں نے سوائے ناشکری کے مانا نہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmvi{اگر ہم چاہتے تو ہر ہر بستی میں ایک ایک ڈرانے واﻻ بھیج دیتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmvii{پس آپ کافروں کا کہنا نہ مانیں اور قرآن کے ذریعے ان سے پوری طاقت سے بڑا جہاد کریں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmviii{اور وہی ہے جس نے دو سمندر آپس میں ملا رکھے ہیں، یہ ہے میٹھا اور مزیدار اور یہ ہے کھاری کڑوا، اور ان دونوں کے درمیان ایک حجاب اور مضبوط اوٹ کردی\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmix{وه ہے جس نے پانی سے انسان کو پیدا کیا، پھر اسے نسب واﻻ اور سسرالی رشتوں واﻻ کردیا۔ بلاشبہ آپ کا پروردگار (ہر چیز پر) قادر ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmx{یہ اللہ کو چھوڑ کر ان کی عبادت کرتے ہیں جو نہ تو انہیں کوئی نفع دے سکیں نہ کوئی نقصان پہنچاسکیں، اور کافر تو ہے ہی اپنے رب کے خلاف (شیطان کی) مدد کرنے واﻻ\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmxi{ہم نے تو آپ کو خوشخبری اور ڈر سنانے واﻻ (نبی) بنا کر بھیجا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmxii{کہہ دیجئے کہ میں قرآن کے پہنچانے پر تم سے کوئی بدلہ نہیں چاہتا مگر جو شخص اپنے رب کی طرف راه پکڑنا چاہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxiii{اس ہمیشہ زنده رہنے والے اللہ تعالیٰ پر توکل کریں جسے کبھی موت نہیں اور اس کی تعریف کے ساتھ پاکیزگی بیان کرتے رہیں، وه اپنے بندوں کے گناہوں سے کافی خبردار ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxiv{وہی ہے جس نے آسمانوں اور زمین اوران کے درمیان کی سب چیزوں کو چھ دن میں پیدا کردیا ہے، پھر عرش پر مستوی ہوا، وه رحمٰن ہے، آپ اس کے بارے میں کسی خبردار سے پوچھ لیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxv{ان سے جب بھی کہا جاتا ہے کہ رحمٰن کو سجده کرو تو جواب دیتے ہیں رحمٰن ہے کیا؟ کیا ہم اسے سجده کریں جس کا تو ہمیں حکم دے رہا ہے اور اس (تبلیﻎ) نےان کی نفرت میں مزید اضافہ کردیا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxvi{بابرکت ہے وه جس نے آسمان میں برج بنائے اور اس میں آفتاب بنایا اور منور مہتاب بھی\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxvii{اور اسی نے رات اور دن کو ایک دوسرے کے پیچھے آنے جانے واﻻ بنایا۔ اس شخص کی نصیحت کے لیے جو نصیحت حاصل کرنے یا شکر گزاری کرنے کا اراده رکھتا ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxviii{رحمٰن کے (سچے) بندے وه ہیں جو زمین پر فروتنی کے ساتھ چلتے ہیں اور جب بے علم لوگ ان سے باتیں کرنے لگتے ہیں تو وه کہہ دیتے ہیں کہ سلام ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxix{اور جو اپنے رب کے سامنے سجدے اور قیام کرتے ہوئے راتیں گزار دیتے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxx{اور جو یہ دعا کرتے ہیں کہ اے ہمارے پروردگار! ہم سے دوزخ کا عذاب پرے ہی پرے رکھ، کیونکہ اس کا عذاب چمٹ جانے واﻻ ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxxi{بے شک وه ٹھہرنے اور رہنے کے لحاظ سے بدترین جگہ ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxxii{اور جو خرچ کرتے وقت بھی نہ تو اسراف کرتے ہیں نہ بخیلی، بلکہ ان دونوں کے درمیان معتدل طریقے پر خرچ کرتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiii{اور اللہ کے ساتھ کسی دوسرے معبود کو نہیں پکارتے اور کسی ایسے شخص کو جسے قتل کرنا اللہ تعالیٰ نے منع کردیا ہو وه بجز حق کے قتل نہیں کرتے، نہ وه زنا کے مرتکب ہوتے ہیں اور جو کوئی یہ کام کرے وه اپنے اوپر سخت وبال ﻻئے گا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiv{اسے قیامت کے دن دوہرا عذاب کیا جائے گا اور وه ذلت و خواری کے ساتھ ہمیشہ اسی میں رہے گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcmxxv{سوائے ان لوگوں کے جو توبہ کریں اور ایمان ﻻئیں اور نیک کام کریں، ایسے لوگوں کے گناہوں کو اللہ تعالیٰ نیکیوں سے بدل دیتا ہے، اللہ بخشنے واﻻ مہربانی کرنے واﻻ ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvi{اور جو شخص توبہ کرے اور نیک عمل کرے وه تو (حقیقتاً) اللہ تعالیٰ کی طرف سچا رجوع کرتا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvii{اور جو لوگ جھوٹی گواہی نہیں دیتے اور جب کسی لغو چیز پر ان کا گزر ہوتا ہے تو شرافت سے گزر جاتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcmxxviii{اور جب انہیں ان کے رب کے کلام کی آیتیں سنائی جاتی ہیں تو وه اندھے بہرے ہو کر ان پر نہیں گرتے۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcmxxix{اور یہ دعا کرتے ہیں کہ اے ہمارے پروردگار! تو ہمیں ہماری بیویوں اور اوﻻد سے آنکھوں کی ٹھنڈک عطا فرما اور ہمیں پرہیزگاروں کا پیشوا بنا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcmxxx{یہی وه لوگ ہیں جنہیں ان کے صبر کے بدلے جنت کے بلند و باﻻخانے دیئے جائیں گے جہاں انہیں دعا سلام پہنچایا جائے گا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxi{اس میں یہ ہمیشہ رہیں گے، وه بہت ہی اچھی جگہ اور عمده مقام ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxii{کہہ دیجئے! اگر تمہاری دعا التجا (پکارنا) نہ ہوتی تو میرا رب تمہاری مطلق پروا نہ کرتا، تم تو جھٹلا چکے اب عنقریب اس کی سزا تمہیں چمٹ جانے والی ہوگی\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiii{\basmalahur طٰسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiv{یہ آیتیں روشن کتاب کی ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxv{ان کے ایمان نہ ﻻنے پر شاید آپ تو اپنی جان کھودیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvi{اگر ہم چاہتے تو ان پر آسمان سے کوئی ایسی نشانی اتارتے کہ جس کے سامنے ان کی گردنیں خم ہو جاتیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvii{اور ان کے پاس رحمٰن کی طرف سے جو بھی نئی نصیحت آئی یہ اس سے روگردانی کرنے والے بن گئے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxviii{ان لوگوں نے جھٹلایا ہے اب ان کے پاس جلدی سے اس کی خبریں آجائیں گی جس کے ساتھ وه مسخرا پن کر رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxix{کیا انہوں نے زمین پر نظریں نہیں ڈالیں؟ کہ ہم نے اس میں ہر طرح کے نفیس جوڑے کس قدر اگائے ہیں؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcmxl{بے شک اس میں یقیناً نشانی ہے اور ان میں کے اکثر لوگ مومن نہیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcmxli{اور تیرا رب یقیناً وہی غالب اور مہربان ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcmxlii{اور جب آپ کے رب نے موسیٰ (علیہ السلام) کو آواز دی کہ تو ﻇالم قوم کے پاس جا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcmxliii{قوم فرعون کے پاس، کیا وه پرہیزگاری نہ کریں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcmxliv{موسیٰ (علیہ السلام) نے کہا میرے پروردگار! مجھے تو خوف ہے کہ کہیں وه مجھے جھٹلا (نہ) دیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcmxlv{اور میرا سینہ تنگ ہو رہا ہے میری زبان چل نہیں رہی پس تو ہارون کی طرف بھی وحی بھیج\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvi{اور ان کا مجھ پر میرے ایک قصور کا (دعویٰ) بھی ہے مجھے ڈر ہے کہ کہیں وه مجھے مار نہ ڈالیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvii{جناب باری نے فرمایا! ہرگز ایسا نہ ہوگا، تم دونوں ہماری نشانیاں لے کر جاؤ ہم خود سننے والے تمہارے ساتھ ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcmxlviii{تم دونوں فرعون کے پاس جاکر کہو کہ بلاشبہ ہم رب العالمین کے بھیجے ہوئے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcmxlix{کہ تو ہمارے ساتھ بنی اسرائیل کو روانہ کردے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcml{فرعون نے کہا کہ کیا ہم نے تجھے تیرے بچپن کے زمانہ میں اپنے ہاں نہیں پاﻻ تھا؟ اور تو نے اپنی عمر کے بہت سے سال ہم میں نہیں گزارے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcmli{پھر تو اپنا وه کام کر گیا جو کر گیا اور تو ناشکروں میں ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcmlii{(حضرت) موسیٰ (علیہ السلام) نے جواب دیا کہ میں نے اس کام کو اس وقت کیا تھا جبکہ میں راه بھولے ہوئے لوگوں میں سے تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcmliii{پھر تم سے خوف کھا کر میں تم میں سے بھاگ گیا، پھر مجھے میرے رب نے حکم و علم عطا فرمایا اور مجھے اپنے پیغمبروں میں سے کر دیا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcmliv{مجھ پر تیرا کیا یہی وه احسان ہے؟ جسے تو جتا رہا ہے جبکہ تو نے بنی اسرائیل کو غلام بنا رکھا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcmlv{فرعون نے کہا رب العالمین کیا (چیز) ہے؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcmlvi{(حضرت) موسیٰ (علیہ السلام) نے فرمایا وه آسمانوں اور زمین اور ان کے درمیان کی تمام چیزوں کا رب ہے، اگر تم یقین رکھنے والے ہو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcmlvii{فرعون نے اپنے اردگرد والوں سے کہا کہ کیا تم سن نہیں رہے؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcmlviii{(حضرت) موسیٰ (علیہ السلام) نے فرمایا وه تمہارا اور تمہارے اگلے باپ دادوں کا پروردگار ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcmlix{فرعون نے کہا (لوگو!) تمہارا یہ رسول جو تمہاری طرف بھیجا گیا ہے یہ تو یقیناً دیوانہ ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcmlx{حضرت موسیٰ علیہ السلام نے فرمایا! وہی مشرق ومغرب کا اور ان کے درمیان کی تمام چیزوں کا رب ہے، اگر تم عقل رکھتے ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcmlxi{فرعون کہنے لگا سن لے! اگر تو نے میرے سوا کسی اور کو معبود بنایا تو میں تجھے قیدیوں میں ڈال دوں گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcmlxii{موسیٰ (علیہ السلام) نے کہا اگرچہ میں تیرے پاس کوئی کھلی چیز لے آؤں؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiii{فرعون نے کہا اگر تو سچوں میں سے ہے تو اسے پیش کر\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiv{آپ نے (اسی وقت) اپنی ﻻٹھی ڈال دی جو اچانک کھلم کھلا (زبردست) اﮊدہا بن گئی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcmlxv{اور اپنا ہاتھ کھینچ نکالا تو وه بھی اسی وقت ہر دیکھنے والے کو سفید چمکیلا نظر آنے لگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvi{فرعون اپنے آس پاس کے سرداروں سے کہنے لگا بھئی یہ تو کوئی بڑا دانا جادوگر ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvii{یہ تو چاہتا ہے کہ اپنے جادو کے زور سے تمہیں تمہاری سر زمین سے ہی نکال دے، بتاؤ اب تم کیا حکم دیتے ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcmlxviii{ان سب نے کہا آپ اسے اور اس کے بھائی کو مہلت دیجئے اور تمام شہروں میں ہرکارے بھیج دیجئے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcmlxix{جو آپ کے پاس ذی علم جادو گروں کو لے آئیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcmlxx{پھر ایک مقرر دن کے وعدے پر تمام جادوگر جمع کیے گئے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxi{اور عام لوگوں سے بھی کہہ دیا گیا کہ تم بھی مجمع میں حاضر ہوجاؤ گے؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxii{تاکہ اگر جادوگر غالب آجائیں تو ہم ان ہی کی پیروی کریں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiii{جادوگر آکر فرعون سے کہنے لگے کہ اگر ہم جیت گئے تو ہمیں کچھ انعام بھی ملے گا؟\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiv{فرعون نے کہا ہاں! (بڑی خوشی سے) بلکہ ایسی صورت میں تم میرے خاص درباری بن جاؤ گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxv{(حضرت) موسیٰ (علیہ السلام) نے جادوگروں سے فرمایا جو کچھ تمہیں ڈالنا ہے ڈال دو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvi{انہوں نے اپنی رسیاں اور ﻻٹھیاں ڈال دیں اور کہنے لگے عزت فرعون کی قسم! ہم یقیناً غالب ہی رہیں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvii{اب (حضرت) موسیٰ (علیہ السلام) نے بھی اپنی ﻻٹھی میدان میں ڈال دی جس نے اسی وقت ان کے جھوٹ موٹ کے کرتب کو نگلنا شروع کردیا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxviii{یہ دیکھتے ہی دیکھتے جادوگر بے اختیار سجدے میں گر گئے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxix{اورانہوں نے صاف کہہ دیا کہ ہم تو اللہ رب العالمین پر ایمان ﻻئے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxx{یعنی موسیٰ (علیہ السلام) اور ہارون کے رب پر\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxi{فرعون نے کہا کہ میری اجازت سے پہلے تم اس پر ایمان لے آئے؟ یقیناً یہی تمہارا وه بڑا (سردار) ہے جس نے تم سب کو جادو سکھایا ہے، سو تمہیں ابھی ابھی معلوم ہوجائے گا، قسم ہے میں ابھی تمہارے ہاتھ پاؤں الٹے طور پر کاٹ دوں گا اور تم سب کو سولی پر لٹکا دوں گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxii{انہوں نے کہا کوئی حرج نہیں، ہم تو اپنے رب کی طرف لوٹنے والے ہیں ہی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiii{اس بنا پر کہ ہم سب سے پہلےایمان والے بنے ہیں ہمیں امید پڑتی ہے کہ ہمارا رب ہماری سب خطائیں معاف فرما دے گا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiv{اور ہم نے موسیٰ کو وحی کی کہ راتوں رات میرے بندوں کو نکال لے چل تم سب پیچھا کیے جاؤ گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxv{فرعون نے شہروں میں ہرکاروں کو بھیج دیا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvi{کہ یقیناً یہ گروه بہت ہی کم تعداد میں ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvii{اور اس پر یہ ہمیں سخت غضب ناک کر رہے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxviii{اور یقیناً ہم بڑی جماعت ہیں ان سے چوکنا رہنے والے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxix{بالﺂخر ہم نےانہیں باغات سے اور چشموں سے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxc{اور خزانوں سے۔ اور اچھے اچھے مقامات سے نکال باہر کیا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxci{اسی طرح ہوا اور ہم نےان (تمام) چیزوں کا وارث بنی اسرائیل کو بنا دیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxcii{پس فرعونی سورج نکلتے ہی ان کے تعاقب میں نکلے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxciii{پس جب دونوں نے ایک دوسرے کو دیکھ لیا، تو موسیٰ کے ساتھیوں نے کہا، ہم تو یقیناً پکڑ لیے گئے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxciv{موسیٰ نے کہا، ہرگز نہیں۔ یقین مانو، میرا رب میرے ساتھ ہے جو ضرور مجھے راه دکھائے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxcv{ہم نے موسیٰ کی طرف وحی بھیجی کہ دریا پر اپنی ﻻٹھی مار، پس اسی وقت دریا پھٹ گیا اور ہر ایک حصہ پانی کا مثل بڑے پہاڑ کے ہوگیا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvi{اور ہم نے اسی جگہ دوسروں کو نزدیک ﻻ کھڑا کر دیا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvii{اور موسیٰ (علیہ السلام) کو اور اس کے تمام ساتھیوں کو نجات دے دی\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxcviii{پھر اور سب دوسروں کو ڈبو دیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxcix{یقیناً اس میں بڑی عبرت ہے اور ان میں کےاکثر لوگ ایمان والے نہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmm{اور بیشک آپ کا رب بڑا ہی غالب اور مہربان ہے؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmi{انہیں ابراہیم (علیہ السلام) کا واقعہ بھی سنادو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmii{جبکہ انہوں نے اپنے باپ اور اپنی قوم سے فرمایا کہ تم کس کی عبادت کرتے ہو؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmiii{انہوں نے جواب دیا کہ عبادت کرتے ہیں بتوں کی، ہم تو برابر ان کے مجاور بنے بیٹھے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmiv{آپ نے فرمایا کہ جب تم انہیں پکارتے ہو تو کیا وه سنتے بھی ہیں؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmv{یا تمہیں نفع نقصان بھی پہنچا سکتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmvi{انہوں نے کہا یہ (ہم کچھ نہیں جانتے) ہم تو اپنے باپ دادوں کو اسی طرح کرتے پایا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmvii{آپ نے فرمایا کچھ خبر بھی ہے جنہیں تم پوج رہے ہو\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmviii{تم اور تمہارے اگلے باپ دادا، وه سب میرے دشمن ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmix{بجز سچے اللہ تعالیٰ کے جو تمام جہان کا پالنہار ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmx{جس نے مجھے پیدا کیا ہے اور وہی میری رہبری فرماتا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmxi{وہی ہے جو مجھے کھلاتا پلاتا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmxii{اور جب میں بیمار پڑ جاؤں تو مجھے شفا عطا فرماتا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmxiii{اور وہی مجھے مار ڈالے گا پھر زنده کردے گا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmxiv{اور جس سے امید بندھی ہوئی ہے کہ وه روز جزا میں میرے گناہوں کو بخش دے گا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmxv{اے میرے رب! مجھے قوت فیصلہ عطا فرما اور مجھے نیک لوگوں میں ملا دے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmxvi{اور میرا ذکر خیر پچھلے لوگوں میں بھی باقی رکھ\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmxvii{مجھے نعمتوں والی جنت کے وارﺛوں میں سے بنادے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmxviii{اور میرے باپ کو بخش دے یقیناً وه گمراہوں میں سے تھا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmxix{اور جس دن کے لوگ دوباره جلائے جائیں مجھے رسوا نہ کر\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmxx{جس دن کہ مال اور اوﻻد کچھ کام نہ آئے گی\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmxxi{لیکن فائده واﻻ وہی ہوگا جو اللہ تعالیٰ کے سامنے بے عیب دل لے کر جائے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmxxii{اور پرہیزگاروں کے لیے جنت بالکل نزدیک ﻻدی جائے گی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmxxiii{اور گمراه لوگوں کے لیے جہنم ﻇاہر کردی جائے گی\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmxxiv{اور ان سے پوچھا جائے گا کہ جن کی تم پوجا کرتے رہے وه کہاں ہیں؟\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmxxv{جو اللہ تعالیٰ کے سوا تھے، کیاوه تمہاری مدد کرتے ہیں؟ یا کوئی بدلہ لے سکتے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmxxvi{پس وه سب اور کل گمراه لوگ جہنم میں اوندھے منھ ڈال دیے جائیں گے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmxxvii{اور ابلیس کے تمام کے تمام لشکر بھی، وہاں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmxxviii{آپس میں لڑتے جھگڑتے ہوئے کہیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmxxix{کہ قسم اللہ کی! یقیناً ہم تو کھلی غلطی پر تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmxxx{جبکہ تمہیں رب العالمین کے برابر سمجھ بیٹھے تھے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmxxxi{اور ہمیں تو سوا ان بدکاروں کے کسی اور نے گمراه نہیں کیا تھا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmxxxii{اب تو ہمارا کوئی سفارشی بھی نہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiii{اور نہ کوئی (سچا) غم خوار دوست\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiv{اگر کاش کہ ہمیں ایک مرتبہ پھر جانا ملتا تو ہم پکے سچے مومن بن جاتے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmxxxv{یہ ماجرا یقیناً ایک زبردست نشانی ہے ان میں سے اکثر لوگ ایمان ﻻنے والے نہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvi{یقیناً آپ کا پروردگار ہی غالب مہربان ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvii{قوم نوح نے بھی نبیوں کو جھٹلایا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmxxxviii{جبکہ ان کے بھائی نوح (علیہ السلام) نے کہا کہ کیا تمہیں اللہ کا خوف نہیں!\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmxxxix{سنو! میں تمہاری طرف اللہ کا امانتدار رسول ہوں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmxl{پس تمہیں اللہ سے ڈرنا چاہئے اور میری بات ماننی چاہئے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmxli{میں تم سے اس پر کوئی اجر نہیں چاہتا، میرا بدلہ تو صرف رب العالمین کے ہاں ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmxlii{پس تم اللہ کا خوف رکھو اور میری فرمانبرداری کرو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmxliii{قوم نے جواب دیا کہ ہم تجھ پر ایمان ﻻئیں! تیری تابعداری تو رذیل لوگوں نے کی ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmxliv{آپ نے فرمایا! مجھے کیا خبر کہ وه پہلے کیا کرتے رہے؟\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmxlv{ان کا حساب تو میرے رب کے ذمہ ہے اگر تمہیں شعور ہو تو\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmxlvi{میں ایمان والوں کو دھکے دینے واﻻ نہیں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmxlvii{میں تو صاف طور پر ڈرا دینے واﻻ ہوں\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmxlviii{انہوں نے کہاکہ اے نوح! اگر تو باز نہ آیا تو یقیناً تجھے سنگسار کردیا جائے گا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmxlix{آپ نے کہا اے میرے پروردگار! میری قوم نے مجھے جھٹلا دیا\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmml{پس تو مجھ میں اور ان میں کوئی قطعی فیصلہ کردے اور مجھے اور میرے با ایمان ساتھیوں کو نجات دے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmli{چنانچہ ہم نے اسے اور اس کے ساتھیوں کو بھری ہوئی کشتی میں (سوار کراکر) نجات دے دی\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmlii{بعد ازاں باقی کے تمام لوگوں کو ہم نے ڈبو دیا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmliii{یقیناً اس میں بہت بڑی عبرت ہے۔ ان میں سے اکثر لوگ ایمان ﻻنے والے تھے بھی نہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmliv{اور بیشک آپ کا پروردگار البتہ وہی ہے زبردست رحم کرنے واﻻ\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmlv{عادیوں نے بھی رسولوں کو جھٹلایا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmlvi{جبکہ ان سے ان کے بھائی ہود نے کہا کہ کیا تم ڈرتے نہیں؟\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmlvii{میں تمہارا امانتدار پیغمبر ہوں\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmlviii{پس اللہ سے ڈرو اور میرا کہا مانو!\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmlix{میں اس پر تم سے کوئی اجرت طلب نہیں کرتا، میرا ﺛواب تو تمام جہان کے پروردگار کے پاس ہی ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmlx{کیا تم ایک ایک ٹیلے پر بطور کھیل تماشا یادگار (عمارت) بنا رہے ہو\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmlxi{اور بڑی صنعت والے (مضبوط محل تعمیر) کر رہے ہو، گویا کہ تم ہمیشہ یہیں رہو گے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmlxii{اور جب کسی پر ہاتھ، ڈالتے ہو تو سختی اور ﻇلم سے پکڑتے ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmlxiii{اللہ سے ڈرو اور میری پیروی کرو\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmlxiv{اس سے ڈرو جس نے ان چیزوں سے تمہاری امداد کی جنہیں تم جانتے ہو\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmlxv{اس نے تمہاری مدد کی مال سے اور اوﻻد سے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmlxvi{باغات سے اور چشموں سے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmlxvii{مجھے تو تمہاری نسبت بڑے دن کےعذاب کا اندیشہ ہے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmlxviii{انہوں نے کہا کہ آپ وعﻆ کہیں یا وعﻆ کہنے والوں میں نہ ہوں ہم پر یکساں ہے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmlxix{یہ تو بس پرانے لوگوں کی عادت ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmlxx{اور ہم ہرگز عذاب نہیں دیے جائیں گے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmlxxi{چونکہ عادیوں نے حضرت ہود کو جھٹلایا، اس لیے ہم نے انہیں تباه کردیا یقیناً اس میں نشانی ہے اور ان میں سے اکثر بے ایمان تھے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmlxxii{بیشک آپ کا رب وہی غالب مہربان\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiii{ﺛمودیوں نے بھی پیغمبروں کو جھٹلایا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiv{ان کے بھائی صالح نے ان سے فرمایا کہ کیا تم اللہ سے نہیں ڈرتے؟\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmlxxv{میں تمہاری طرف اللہ کا امانت دار پیغمبر ہوں\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvi{تو تم اللہ سے ڈرو اور میرا کہا کرو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvii{میں اس پر تم سے کوئی اجرت نہیں مانگتا، میری اجرت تو بس پرودگار عالم پر ہی ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmlxxviii{کیا ان چیزوں میں جو یہاں ہیں تم امن کے ساتھ چھوڑ دیے جاؤ گے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmlxxix{یعنی ان باغوں اور ان چشموں\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmlxxx{اور ان کھیتوں اور ان کھجوروں کے باغوں میں جن کے شگوفے نرم و نازک ہیں\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxi{اور تم پہاڑوں کو تراش تراش کر پر تکلف مکانات بنا رہے ہو\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxii{پس اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiii{بے باک حد سے گزر جانے والوں کی اطاعت سے باز آجاؤ\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiv{جو ملک میں فساد پھیلا رہے ہیں اور اصلاح نہیں کرتے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxv{وه بولے کہ بس تو ان میں سے ہے جن پر جادو کردیا گیا ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvi{تو تو ہم جیسا ہی انسان ہے۔ اگر تو سچوں سے ہے تو کوئی معجزه لے آ\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvii{آپ نے فرمایا یہ ہے اونٹنی، پانی پینے کی ایک باری اس کی اور ایک مقرره دن کی باری پانی پینے کی تمہاری\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxviii{(خبردار!) اسے برائی سے ہاتھ نہ لگانا ورنہ ایک بڑے بھاری دن کا عذاب تمہاری گرفت کر لے گا\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxix{پھر بھی انہوں نے اس کی کوچیں کاٹ ڈالیں، بس وه پشیمان ہوگئے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmxc{اور عذاب نے انہیں آ دبوچا۔ بیشک اس میں عبرت ہے۔ اور ان میں سے اکثر لوگ مومن نہ تھے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmxci{اور بیشک آپ کا رب بڑا زبردست اور مہربان ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmxcii{قوم لوط نے بھی نبیوں کو جھٹلایا\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmxciii{ان سے ان کے بھائی لوط (علیہ السلام) نے کہا کیا تم اللہ کا خوف نہیں رکھتے؟\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmxciv{میں تمہاری طرف امانت دار رسول ہوں\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmxcv{پس تم اللہ تعالیٰ سے ڈرو اور میری اطاعت کرو\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmxcvi{میں تم سے اس پر کوئی بدلہ نہیں مانگتا میرا اجر تو صرف اللہ تعالیٰ پر ہے جو تمام جہان کا رب ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmxcvii{کیا تم جہان والوں میں سے مردوں کے ساتھ شہوت رانی کرتے ہو\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmxcviii{اور تمہاری جن عورتوں کو اللہ تعالیٰ نے تمہارا جوڑا بنایا ہے ان کو چھوڑ دیتے ہو، بلکہ تم ہو ہی حد سے گزر جانے والے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmxcix{انہوں نے جواب دیاکہ اے لوط! اگر تو باز نہ آیا تو یقیناً نکال دیا جائے گا\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmc{آپ نے فرمایا، میں تمہارے کام سے سخت ناخوش ہوں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmci{میرے پروردگار! مجھے اور میرے گھرانے کو اس (وبال) سے بچالے جو یہ کرتے ہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcii{پس ہم نے اسے اور اس کے متعلقین کو سب کو بچالیا\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmciii{بجز ایک بڑھیا کے کہ وه پیچھے ره جانے والوں میں ہوگئی\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmciv{پھر ہم نے باقی اور سب کو ہلاک کر دیا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcv{اور ہم نے ان پر ایک خاص قسم کا مینہ برسایا، پس بہت ہی برا مینہ تھا جو ڈرائے گئے ہوئے لوگوں پر برسا\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcvi{یہ ماجرا بھی سراسر عبرت ہے۔ ان میں سے بھی اکثر مسلمان نہ تھے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcvii{بیشک تیرا پروردگار وہی ہے غلبے واﻻ مہربانی واﻻ\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcviii{اَیکہ والوں نے بھی رسولوں کو جھٹلایا\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcix{جبکہ ان سے شعیب (علیہ السلام) نے کہاکہ کیا تمہیں ڈر خوف نہیں؟\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcx{میں تمہاری طرف امانت دار رسول ہوں\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcxi{اللہ کا خوف کھاؤ اور میری فرمانبرداری کرو\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcxii{میں اس پر تم سے کوئی اجرت نہیں چاہتا، میرا اجر تمام جہانوں کے پالنے والے کے پاس ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcxiii{ناپ پورا بھرا کرو کم دینے والوں میں شمولیت نہ کرو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcxiv{اور سیدھی صحیح ترازو سے توﻻ کرو\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcxv{لوگوں کو ان کی چیزیں کمی سے نہ دو بے باکی کے ساتھ زمین میں فساد مچاتے نہ پھرو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mmmcxvi{اس اللہ کا خوف رکھو جس نے خود تمہیں اور اگلی مخلوق کو پیدا کیا ہے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mmmcxvii{انہوں نے کہا تو تو ان میں سے ہے جن پر جادو کردیا جاتا ہے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mmmcxviii{اور تو تو ہم ہی جیسا ایک انسان ہے اور ہم تو تجھے جھوٹ بولنے والوں میں سے ہی سمجھتے ہیں\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mmmcxix{اگر تو سچے لوگوں میں سے ہے تو ہم پر آسمان کے ٹکڑے گرادے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mmmcxx{کہاکہ میرا رب خوب جاننے واﻻ ہے جو کچھ تم کر رہے ہو\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mmmcxxi{چونکہ انہوں نے اسے جھٹلایا تو انہیں سائبان والے دن کے عذاب نے پکڑ لیا۔ وه بڑے بھاری دن کا عذاب تھا\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mmmcxxii{یقیناً اس میں بڑی نشانی ہے اور ان میں کےاکثر مسلمان نہ تھے\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiii{اور یقیناً تیرا پروردگار البتہ وہی ہے غلبے واﻻ مہربانی واﻻ\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiv{اور بیشک و شبہ یہ (قرآن) رب العالمین کا نازل فرمایا ہوا ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mmmcxxv{اسے امانت دار فرشتہ لے کر آیا ہے\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvi{آپ کے دل پر اترا ہے کہ آپ آگاه کر دینے والوں میں سے ہو جائیں\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvii{صاف عربی زبان میں ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mmmcxxviii{اگلے نبیوں کی کتابوں میں بھی اس قرآن کا تذکره ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mmmcxxix{کیا انہیں یہ نشانی کافی نہیں کہ حقانیت قرآن کو تو بنی اسرائیل کے علماء بھی جانتے ہیں\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mmmcxxx{اور اگر ہم اسے کسی عجمی شخص پر نازل فرماتے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxi{پس وه ان کے سامنے اس کی تلاوت کرتا تو یہ اسے باور کرنے والے نہ ہوتے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxii{اسی طرح ہم نے گناہگاروں کے دلوں میں اس انکار کو داخل کر دیا ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiii{وه جب تک دردناک عذابوں کو ملاحظہ نہ کرلیں ایمان نہ ﻻئیں گے\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiv{پس وه عذاب ان کو ناگہاں آجائے گا انہیں اس کا شعور بھی نہ ہو گا\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxv{اس وقت کہیں گے کہ کیا ہمیں کچھ مہلت دی جائے گی؟\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvi{پس کیا یہ ہمارے عذاب کی جلدی مچا رہے ہیں؟\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvii{اچھا یہ بھی بتاؤ کہ اگر ہم نے انہیں کئی سال بھی فائده اٹھانے دیا\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxviii{پھر انہیں وه عذاب آ لگا جن سے یہ دھمکائے جاتے تھے\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxix{تو جو کچھ بھی یہ برتتے رہے اس میں سے کچھ بھی فائده نہ پہنچا سکے گا\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@mmmcxl{ہم نے کسی بستی کو ہلاک نہیں کیا ہے مگر اسی حال میں کہ اس کے لیے ڈرانے والے تھے\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@mmmcxli{نصیحت کے طور پر اور ہم ﻇلم کرنے والے نہیں ہیں\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@mmmcxlii{اس قرآن کو شیطان نہیں ﻻئے\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@mmmcxliii{نہ وه اس کے قابل ہیں، نہ انہیں اس کی طاقت ہے\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@mmmcxliv{بلکہ وه تو سننے سے بھی محروم کردیے گئے ہیں\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@mmmcxlv{پس تو اللہ کے ساتھ کسی اور معبود کو نہ پکار کہ تو بھی سزا پانے والوں میں سے ہوجائے\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvi{اپنے قریبی رشتہ والوں کو ڈرا دے\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvii{اس کے ساتھ فروتنی سے پیش آ، جو بھی ایمان ﻻنے واﻻ ہو کر تیری تابعداری کرے\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@mmmcxlviii{اگر یہ لوگ تیری نافرمانی کریں تو تو اعلان کردے کہ میں ان کاموں سے بیزار ہوں جو تم کر رہے ہو\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@mmmcxlix{اپنا پورا بھروسہ غالب مہربان اللہ پر رکھ\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@mmmcl{جو تجھے دیکھتا رہتا ہے جبکہ تو کھڑا ہوتا ہے\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@mmmcli{اور سجده کرنے والوں کے درمیان تیرا گھومنا پھرنا بھی\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@mmmclii{وه بڑا ہی سننے واﻻ اور خوب ہی جاننے واﻻ ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@mmmcliii{کیا میں تمہیں بتاؤں کہ شیطان کس پر اترتے ہیں\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@mmmcliv{وه ہر ایک جھوٹے گنہگار پر اترتے ہیں\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@mmmclv{(اچٹتی) ہوئی سنی سنائی پہنچا دیتے ہیں اور ان میں سے اکثر جھوٹے ہیں\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@mmmclvi{شاعروں کی پیروی وه کرتے ہیں جو بہکے ہوئے ہوں\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@mmmclvii{کیا آپ نے نہیں دیکھا کہ شاعر ایک ایک بیابان میں سر ٹکراتے پھرتے ہیں\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@mmmclviii{اور وه کہتے ہیں جو کرتے نہیں\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@mmmclix{سوائے ان کے جو ایمان ﻻئے اور نیک عمل کیے اور بکثرت اللہ تعالیٰ کا ذکر کیا اور اپنی مظلومی کے بعد انتقام لیا، جنہوں نے ﻇلم کیا ہے وه بھی ابھی جان لیں گے کہ کس کروٹ الٹتے ہیں\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@mmmclx{\basmalahur طٰس، یہ آیتیں ہیں قرآن کی (یعنی واضح) اور روشن کتاب کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmclxi{ہدایت اور خوشخبری ایمان والوں کے لیے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmclxii{جو نماز قائم کرتے ہیں اور زکوٰة ادا کرتے ہیں اور آخرت پر یقین رکھتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmclxiii{جو لوگ قیامت پر ایمان نہیں ﻻتے ہم نے انہیں ان کے کرتوت زینت دار کر دکھائے ہیں، پس وه بھٹکتے پھرتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmclxiv{یہی لوگ ہیں جن کے لیے برا عذاب ہے اور آخرت میں بھی وه سخت نقصان یافتہ ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmclxv{بیشک آپ کو اللہ حکیم وعلیم کی طرف سے قرآن سکھایا جارہا ہے۔\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmclxvi{(یاد ہوگا) جبکہ موسیٰ (علیہ السلام) نے اپنے گھر والوں سے کہا کہ میں نے آگ دیکھی ہے، میں وہاں سے یا تو کوئی خبر لے کر یا آگ کا کوئی سلگتا ہوا انگارا لے کر ابھی تمہارے پاس آ جاؤں گا تاکہ تم سینک تاپ کر لو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmclxvii{جب وہاں پہنچے تو آواز دی گئی کہ بابرکت ہے وه جو اس آگ میں ہے اور برکت دیاگیا ہے وه جس کے آس پاس ہے اور پاک ہے اللہ جو تمام جہانوں کا پالنے واﻻ ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmclxviii{موسیٰ! سن بات یہ ہے کہ میں ہی اللہ ہوں غالب با حکمت\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmclxix{تو اپنی ﻻٹھی ڈال دے، موسیٰ نے جب اسے ہلتا جلتا دیکھا اس طرح کہ گویا وه ایک سانﭗ ہے تو منھ موڑے ہوئے پیٹھ پھیر کر بھاگے اور پلٹ کر بھی نہ دیکھا، اے موسیٰ! خوف نہ کھا، میرے حضور میں پیغمبر ڈرا نہیں کرتے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmclxx{لیکن جو لوگ ﻇلم کریں پھر اس کے عوض نیکی کریں اس برائی کے پیچھے تو میں بھی بخشنے واﻻ مہربان ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmclxxi{اور اپنا ہاتھ اپنے گریبان میں ڈال، وه سفید چمکیلا ہو کر نکلے گا بغیر کسی عیب کے، تو نو نشانیاں لے کر فرعون اور اس کی قوم کی طرف جا، یقیناً وه بدکاروں کا گروه ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmclxxii{پس جب ان کے پاس آنکھیں کھول دینے والے ہمارے معجزے پہنچے تو وه کہنے لگے یہ تو صریح جادو ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiii{انہوں نے انکار کردیا حاﻻنکہ ان کے دل یقین کر چکے تھے صرف ﻇلم اور تکبر کی بنا پر۔ پس دیکھ لیجئے کہ ان فتنہ پرداز لوگوں کا انجام کیسا کچھ ہوا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiv{اور ہم نے یقیناً داؤد اور سلیمان کو علم دے رکھا تھا۔ اور دونوں نے کہا، تعریف اس اللہ کے لیے ہے جس نے ہمیں اپنے بہت سے ایماندار بندوں پر فضیلت عطا فرمائی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmclxxv{اور داؤد کے وارث سلیمان ہوئے اور کہنے لگے لوگو! ہمیں پرندوں کی بولی سکھائی گئی ہے اور ہم سب کچھ میں سے دیئے گئے ہیں۔ بیشک یہ بالکل کھلا ہوا فضل الٰہی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvi{سلیمان کے سامنے ان کے تمام لشکر جنات اور انسان اور پرند میں سے جمع کیے گئے (ہر ہر قسم کی) الگ الگ درجہ بندی کردی گئی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvii{جب وه چینوٹیوں کے میدان میں پہنچے تو ایک چیونٹی نے کہا اے چیونٹیو! اپنے اپنے گھروں میں گھس جاؤ، ایسا نہ ہو کہ بیخبری میں سلیمان اور اس کا لشکر تمہیں روند ڈالے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmclxxviii{اس کی اس بات سے حضرت سلیمان مسکرا کر ہنس دیئے اور دعا کرنے لگے کہ اے پروردگار! تو مجھے توفیق دے کہ میں تیری ان نعمتوں کا شکر بجا ﻻؤں جو تو نے مجھ پر انعام کی ہیں اور میرے ماں باپ پر اور میں ایسے نیک اعمال کرتا رہوں جن سے تو خوش رہے مجھے اپنی رحمت سے نیک بندوں میں شامل کر لے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmclxxix{آپ نے پرندوں کی دیکھ بھال کی اور فرمانے لگے یہ کیا بات ہے کہ میں ہدہد کو نہیں دیکھتا؟ کیا واقعی وه غیر حاضر ہے؟\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmclxxx{یقیناً میں اسے سخت سزا دوں گا، یا اسے ذبح کر ڈالوں گا، یا میرے سامنے کوئی صریح دلیل بیان کرے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxi{کچھ زیاده دیر نہ گزری تھی کہ آ کر اس نے کہا میں ایک ایسی چیز کی خبر ﻻیا ہوں کہ تجھے اس کی خبر ہی نہیں، میں سبا کی ایک سچی خبر تیرے پاس ﻻیا ہوں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxii{میں نے دیکھا کہ ان کی بادشاہت ایک عورت کر رہی ہے جسے ہر قسم کی چیز سے کچھ نہ کچھ دیا گیا ہے اور اس کا تخت بھی بڑی عظمت واﻻ ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiii{میں نے اسے اور اس کی قوم کو، اللہ تعالیٰ کو چھوڑ کر سورج کو سجده کرتے ہوئے پایا، شیطان نے ان کے کام انہیں بھلے کرکے دکھلا کر صحیح راه سے روک دیا ہے۔ پس وه ہدایت پر نہیں آتے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiv{کہ اسی اللہ کے لیے سجدے کریں جو آسمانوں اور زمینوں کے پوشیده چیزوں کو باہر نکالتا ہے، اور جو کچھ تم چھپاتے ہو اور ﻇاہر کرتے ہو وه سب کچھ جانتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxv{اس کے سوا کوئی معبود برحق نہیں وہی عظمت والے عرش کا مالک ہے۔\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvi{سلیمان نے کہا، اب ہم دیکھیں گے کہ تو نے سچ کہا ہے یا تو جھوٹا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvii{میرے اس خط کو لے جاکر انہیں دے دے پھر ان کے پاس سے ہٹ آ اور دیکھ کہ وه کیا جواب دیتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxviii{وه کہنے لگی اے سردارو! میری طرف ایک باوقعت خط ڈاﻻ گیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxix{جو سلیمان کی طرف سے ہے اور جو بخشش کرنے والے مہربان اللہ کے نام سے شروع ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcxc{یہ کہ تم میرے سامنے سرکشی نہ کرو اور مسلمان بن کر میرے پاس آجاؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcxci{اس نے کہا اے میرے سردارو! تم میرے اس معاملہ میں مجھے مشوره دو۔ میں کسی امر کا قطعی فیصلہ جب تک تمہاری موجودگی اور رائے نہ ہو نہیں کیا کرتی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcxcii{ان سب نے جواب دیا کہ ہم طاقت اور قوت والے سخت لڑنے بھڑنے والے ہیں۔ آگے آپ کو اختیار ہے آپ خود ہی سوچ لیجئے کہ ہمیں آپ کیا کچھ حکم فرماتی ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcxciii{اس نے کہا کہ بادشاه جب کسی بستی میں گھستے ہیں تو اسے اجاڑ دیتے ہیں اور وہاں کے باعزت لوگوں کو ذلیل کر دیتے ہیں اور یہ لوگ بھی ایسا ہی کریں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcxciv{میں انہیں ایک ہدیہ بھیجنے والی ہوں، پھر دیکھ لوں گی کہ قاصد کیا جواب لے کر لوٹتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcxcv{پس جب قاصد حضرت سلیمان کے پاس پہنچا تو آپ نے فرمایا کیا تم مال سے مجھے مدد دینا چاہتے ہو؟ مجھے تو میرے رب نے اس سے بہت بہتر دے رکھا ہے جو اس نے تمہیں دیا ہے پس تم ہی اپنے تحفے سے خوش رہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvi{جا ان کی طرف واپس لوٹ جا، ہم ان (کے مقابلہ) پر وه لشکر ﻻئیں گے جن کے سامنے پڑنے کی ان میں طاقت نہیں اور ہم انہیں ذلیل و پست کر کے وہاں سے نکال باہر کریں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvii{آپ نے فرمایا اے سردارو! تم میں سے کوئی ہے جو ان کے مسلمان ہو کر پہنچنے سے پہلے ہی اس کا تخت مجھے ﻻدے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcxcviii{ایک قوی ہیکل جن کہنے لگا آپ اپنی اس مجلس سے اٹھیں اس سے پہلے ہی پہلے میں اسے آپ کے پاس ﻻدیتا ہوں، یقین مانیے کہ میں اس پر قادر ہوں اور ہوں بھی امانت دار\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcxcix{جس کے پاس کتاب کا علم تھا وه بول اٹھا کہ آپ پلک جھپکائیں اس سے بھی پہلے میں اسے آپ کے پاس پہنچا سکتا ہوں۔ جب آپ نے اسے اپنے پاس موجود پایا تو فرمانے لگے یہی میرے رب کا فضل ہے، تاکہ وه مجھے آزمائے کہ میں شکر گزاری کرتا ہوں یا ناشکری، شکر گزار اپنے ہی نفع کے لیے شکر گزاری کرتا ہے اور جو ناشکری کرے تو میرا پروردگار (بے پروا اور بزرگ) غنی اور کریم ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcc{حکم دیا کہ اس کے تخت میں کچھ پھیر بدل کر دو تاکہ معلوم ہو جائے کہ یہ راه پالیتی ہے یا ان میں سے ہوتی ہے جو راه نہیں پاتے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcci{پھر جب وه آگئی تو اس سے کہا (دریافت کیا) گیا کہ ایسا ہی تیرا (بھی) تخت ہے؟ اس نے جواب دیا کہ یہ گویا وہی ہے، ہمیں اس سے پہلے ہی علم دیا گیا تھا اور ہم مسلمان تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccii{اسے انہوں نے روک رکھا تھا جن کی وه اللہ کے سوا پرستش کرتی رہی تھی، یقیناً وه کافر لوگوں میں سے تھی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcciii{اس سے کہا گیا کہ محل میں چلی چلو، جسے دیکھ کر یہ سمجھ کر کہ یہ حوض ہے اس نے اپنی پنڈلیاں کھول دیں، فرمایا یہ توشیشے سے منڈھی ہوئی عمارت ہے، کہنے لگی میرے پروردگار! میں نے اپنے آپ پر ﻇلم کیا۔ اب میں سلیمان کے ساتھ اللہ رب العالمین کی مطیع اور فرمانبردار بنتی ہوں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcciv{یقیناً ہم نے ﺛمود کی طرف ان کے بھائی صالح کو بھیجا کہ تم سب اللہ کی عبادت کرو پھر بھی وه دو فریق بن کر آپس میں لڑنے جھگڑنے لگے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccv{آپ نے فرمایا اے میری قوم کے لوگو! تم نیکی سے پہلے برائی کی جلدی کیوں مچا رہے ہو؟ تم اللہ تعالیٰ سےاستغفار کیوں نہیں کرتے تاکہ تم پر رحم کیا جائے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccvi{وه کہنے لگے ہم تو تیری اور تیرے ساتھیوں کی بدشگونی لے رہے ہیں؟ آپ نے فرمایا تمہاری بدشگونی اللہ کے ہاں ہے، بلکہ تم فتنے میں پڑے ہوئے لوگ ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccvii{اس شہر میں نو سردار تھے جو زمین میں فساد پھیلاتے رہتے تھے اور اصلاح نہیں کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccviii{انہوں نے آپس میں بڑی قسمیں کھا کھا کر عہد کیا کہ رات ہی کو صالح اور اس کے گھر والوں پر ہم چھاپہ ماریں گے، اور اس کے وارﺛوں سے صاف کہہ دیں گے کہ ہم اس کے اہل کی ہلاکت کے وقت موجود نہ تھے اور ہم بالکل سچے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmccix{انہوں نے مکر (خفیہ تدبیر) کیا اور ہم نے بھی اور وه اسے سمجھتے ہی نہ تھے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccx{(اب) دیکھ لے ان کے مکر کا انجام کیسا کچھ ہوا؟ کہ ہم نے ان کو اور ان کی قوم کو سب کو غارت کردیا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccxi{یہ ہیں ان کے مکانات جو ان کے ﻇلم کی وجہ سے اجڑے پڑے ہیں، جو لوگ علم رکھتے ہیں ان کے لیےاس میں بڑی نشانی ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmccxii{ہم نے ان کو جو ایمان ﻻئے تھے اور پرہیزگار تھے بال بال بچالیا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmccxiii{اور لوط کا (ذکر کر) جبکہ اس نے اپنی قوم سے کہاکہ کیا باوجود دیکھنے بھالنے کے پھر بھی تم بدکاری کر رہے ہو؟\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmccxiv{یہ کیا بات ہے کہ تم عورتوں کو چھوڑ کر مردوں کے پاس شہوت سے آتے ہو حق یہ ہے کہ تم بڑی ہی نادانی کر رہے ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmccxv{قوم کا جواب بجز اس کہنے کے اور کچھ نہ تھا کہ آل لوط کو اپنے شہر سے شہر بدر کر دو، یہ تو بڑے پاک باز بن رہے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmccxvi{پس ہم نے اسے اور اس کے اہل کو بجز اس کی بیوی کے سب کو بچالیا، اس کا اندازه تو باقی ره جانے والوں میں ہم لگا ہی چکے تھے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmccxvii{اور ان پر ایک (خاص قسم) کی بارش برسادی، پس ان دھمکائے ہوئے لوگوں پر بری بارش ہوئی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmccxviii{تو کہہ دے کہ تمام تعریف اللہ ہی کے لیے ہے اور اس کے برگزیده بندوں پر سلام ہے۔ کیا اللہ تعالیٰ بہتر ہے یا وه جنہیں یہ لوگ شریک ٹھہرا رہے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmccxix{بھلا بتاؤ تو؟ کہ آسمانوں کو اور زمین کو کس نے پیدا کیا؟ کس نے آسمان سے بارش برسائی؟ پھر اس سے ہرے بھرے بارونق باغات اگا دیئے؟ ان باغوں کے درختوں کو تم ہر گز نہ اگا سکتے، کیا اللہ کے ساتھ اور کوئی معبود بھی ہے؟ بلکہ یہ لوگ ہٹ جاتے ہیں (سیدھی راه سے)\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmccxx{کیا وه جس نے زمین کو قرار گاه بنایا اور اس کے درمیان نہریں جاری کر دیں اور اس کے لیے پہاڑ بنائے اور دو سمندروں کے درمیان روک بنا دی کیا اللہ کے ساتھ اور کوئی معبود بھی ہے؟ بلکہ ان میں سے اکثر کچھ جانتے ہی نہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmccxxi{بے کس کی پکار کو جب کہ وه پکارے، کون قبول کرکے سختی کو دور کر دیتا ہے؟ اور تمہیں زمین کا خلیفہ بناتا ہے، کیا اللہ تعالیٰ کے ساتھ اور معبود ہے؟ تم بہت کم نصیحت وعبرت حاصل کرتے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmccxxii{کیا وه جو تمہیں خشکی اور تری کی تاریکیوں میں راه دکھاتا ہے اور جو اپنی رحمت سے پہلے ہی خوشخبریاں دینے والی ہوائیں چلاتا ہے، کیا اللہ کے ساتھ کوئی اور معبود بھی ہے جنہیں یہ شریک کرتے ہیں ان سب سے اللہ بلند وباﻻتر ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiii{کیا وه جو مخلوق کی اول دفعہ پیدائش کرتا ہے پھر اسے لوٹائے گا اور جو تمہیں آسمان اور زمین سے روزیاں دے رہا ہے، کیا اللہ کے ساتھ کوئی اور معبود ہے کہہ دیجئے کہ اگر سچے ہو تو اپنی دلیل ﻻؤ\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiv{کہہ دیجئے کہ آسمانوں والوں میں سے زمین والوں میں سے سوائے اللہ کے کوئی غیب نہیں جانتا، انہیں تو یہ بھی نہیں معلوم کہ کب اٹھا کھڑے کیے جائیں گے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmccxxv{بلکہ آخرت کے بارے میں ان کا علم ختم ہوچکا ہے، بلکہ یہ اس کی طرف سے شک میں ہیں۔ بلکہ یہ اس سے اندھے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvi{کافروں نے کہا کہ کیا جب ہم مٹی ہو جائیں گے اور ہمارے باپ دادا بھی کیا ہم پھر نکالے جائیں گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvii{ہم اور ہمارے باپ دادوں کو بہت پہلے سے یہ وعدے دیے جاتے رہے۔ کچھ نہیں یہ تو صرف اگلوں کے افسانے ہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmccxxviii{کہہ دیجئے کہ زمین میں چل پھر کر ذرا دیکھو تو سہی کہ گنہگاروں کا کیسا انجام ہوا؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmccxxix{آپ ان کے بارے میں غم نہ کریں اور ان کے داؤں گھات سے تنگ دل نہ ہوں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmccxxx{کہتے ہیں کہ یہ وعده کب ہے اگر سچے ہو تو بتلا دو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxi{جواب دیجئے! کہ شاید بعض وه چیزیں جن کی تم جلدی مچا رہے ہو تم سے بہت ہی قریب ہوگئی ہوں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxii{یقیناً آپ کا پروردگار تمام لوگوں پر بڑے ہی فضل واﻻ ہے لیکن اکثر لوگ ناشکری کرتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiii{بیشک آپ کا رب ان چیزوں کو بھی جانتا ہے جنہیں ان کے سینے چھپا رہے ہیں اور جنہیں ﻇاہر کر رہے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiv{آسمان وزمین کی کوئی پوشیده چیز بھی ایسی نہیں جو روشن اور کھلی کتاب میں نہ ہو\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxv{یقیناً یہ قرآن بنی اسرائیل کے سامنے ان اکثر چیزوں کا بیان کر رہا ہے جن میں یہ اختلاف کرتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvi{اور یہ قرآن ایمان والوں کے لیے یقیناً ہدایت اور رحمت ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvii{آپ کا رب ان کے درمیان اپنے حکم سے سب فیصلے کر دے گا، وه بڑا ہی غالب اور دانا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxviii{پس آپ یقیناً اللہ ہی پر بھروسہ رکھیے، یقیناً آپ سچے اور کھلے دین پر ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxix{بیشک آپ نہ مُردوں کو سنا سکتے ہیں اور نہ بہروں کو اپنی پکار سنا سکتے ہیں، جبکہ وه پیٹھ پھیرے روگرداں جا رہے ہوں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmccxl{اور نہ آپ اندھوں کو ان کی گمراہی سے ہٹا کر رہنمائی کر سکتے ہیں آپ تو صرف انہیں سنا سکتے ہیں جو ہماری آیتوں پر ایمان ﻻئے ہیں پھر وه فرمانبردار ہوجاتے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmccxli{جب ان کے اوپر عذاب کا وعده ﺛابت ہو جائے گا، ہم زمین سے ان کے لیے ایک جانور نکالیں گے جو ان سے باتیں کرتا ہوگا کہ لوگ ہماری آیتوں پر یقین نہیں کرتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmccxlii{اور جس دن ہم ہر امت میں سے ان لوگوں کے گروه کو جو ہماری آیتوں کو جھٹلاتے تھے گھیر گھار کر ﻻئیں گے پھر وه سب کے سب الگ کر دیئے جائیں گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmccxliii{جب سب کے سب آپہنچیں گے تو اللہ تعالیٰ فرمائے گا کہ تم نے میری آیتوں کو باوجودیکہ تمہیں ان کا پورا علم نہ تھا کیوں جھٹلایا؟ اور یہ بھی بتلاؤ کہ تم کیا کچھ کرتے رہے؟\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmccxliv{بسبب اس کے کہ انہوں نے ﻇلم کیا تھا ان پر بات جم جائے گی اور وه کچھ بول نہ سکیں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmccxlv{کیا وه دیکھ نہیں رہے ہیں کہ ہم نے رات کو اس لیے بنایا ہے کہ وه اس میں آرام حاصل کرلیں اور دن کو ہم نے دکھلانے واﻻ بنایا ہے، یقیناً اس میں ان لوگوں کے لیے نشانیاں ہیں جو ایمان ویقین رکھتے ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvi{جس دن صور پھونکا جائے گا تو سب کے سب آسمانوں والے اور زمین والے گھبرا اٹھیں گے مگر جسے اللہ تعالیٰ چاہے، اور سارے کے سارے عاجز وپست ہو کر اس کے سامنے حاضر ہوں گے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvii{اور آپ پہاڑوں کو دیکھ کر اپنی جگہ جمے ہوئے خیال کرتے ہیں لیکن وه بھی بادل کی طرح اڑتے پھریں گے، یہ ہے صنعت اللہ کی جس نے ہر چیز کو مضبوط بنایا ہے، جو کچھ تم کرتے ہو اس سے وه باخبر ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmccxlviii{جو لوگ نیک عمل ﻻئیں گے انھیں اس سے بہتر بدلہ ملے گا اور وه اس دن کی گھبراہٹ سے بےخوف ہوں گے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmccxlix{اور جو برائی لے کر آئیں گے وه اوندھے منھ آگ میں جھونک دیئے جائیں گے۔ صرف وہی بدلہ دیئے جاؤ گے جو تم کرتے رہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmccl{مجھے تو بس یہی حکم دیا گیا ہے کہ میں اس شہر کے پروردگار کی عبادت کرتا رہوں جس نے اسے حرمت واﻻ بنایا ہے، جس کی ملکیت ہر چیز ہے اور مجھے یہ بھی فرمایا گیا ہے کہ میں فرماں برداروں میں ہو جاؤں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmccli{اور میں قرآن کی تلاوت کرتا رہوں، جو راه راست پر آجائے وه اپنے نفع کے لیے راه راست پر آئے گا۔ اور جو بہک جائے تو کہہ دیجئے! کہ میں تو صرف ہوشیار کرنے والوں میں سے ہوں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmcclii{کہہ دیجئے، کہ تمام تعریفیں اللہ ہی کو سزاوار ہیں وه عنقریب اپنی نشانیاں دکھائے گا جنہیں تم (خود) پہچان لو گے۔ اور جو کچھ تم کرتے ہو اس سے آپ کا رب غافل نہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmccliii{\basmalahur طٰسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmccliv{یہ آیتیں ہیں روشن کتاب کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcclv{ہم آپ کے سامنے موسیٰ اور فرعون کا صحیح واقعہ بیان کرتے ہیں ان لوگوں کے لیے جو ایمان رکھتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcclvi{یقیناً فرعون نے زمین میں سرکشی کر رکھی تھی اور وہاں کے لوگوں کو گروه گروه بنا رکھا تھا اور ان میں سے ایک فرقہ کو کمزور کر رکھا تھا اور ان کے لڑکوں کو تو ذبح کر ڈالتا تھا اور ان کی لڑکیوں کو زنده چھوڑ دیتا تھا۔ بیشک وشبہ وه تھا ہی مفسدوں میں سے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcclvii{پھر ہماری چاہت ہوئی کہ ہم ان پر کرم فرمائیں جنہیں زمین میں بےحد کمزور کر دیا گیا تھا، اور ہم انہیں کو پیشوا اور (زمین) کا وارث بنائیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcclviii{اور یہ بھی کہ ہم انہیں زمین میں قدرت واختیار دیں اور فرعون اور ہامان اور ان کے لشکروں کو وه دکھائیں جس سے وه ڈر رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcclix{ہم نے موسیٰ (علیہ السلام) کی ماں کو وحی کی کہ اسے دودھ پلاتی ره اور جب تجھے اس کی نسبت کوئی خوف معلوم ہو تو اسے دریا میں بہا دینا اور کوئی ڈر خوف یا رنج غم نہ کرنا، ہم یقیناً اسے تیری طرف لوٹانے والے ہیں اور اسے اپنے پیغمبروں میں بنانے والے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcclx{آخر فرعون کے لوگوں نے اس بچے کو اٹھا لیا کہ آخرکار یہی بچہ ان کا دشمن ہوا اور ان کے رنج کا باعﺚ بنا، کچھ شک نہیں کہ فرعون اور ہامان اور ان کے لشکر تھے ہی خطاکار\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcclxi{اور فرعون کی بیوی نے کہا یہ تو میری اور تیری آنکھوں کی ٹھنڈک ہے، اسے قتل نہ کرو، بہت ممکن ہے کہ یہ ہمیں کوئی فائده پہنچائے یا ہم اسے اپنا ہی بیٹا بنا لیں اور یہ لوگ شعور ہی نہ رکھتے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcclxii{موسیٰ (علیہ السلام) کی والده کا دل بے قرار ہوگیا، قریب تھیں کہ اس واقعہ کو بالکل ﻇاہر کر دیتیں اگر ہم ان کے دل کو ڈھارس نہ دے دیتے یہ اس لیے کہ وه یقین کرنے والوں میں رہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiii{موسیٰ (علیہ السلام) کی والده نے اس کی بہن سے کہا کہ تو اس کے پیچھے پیچھے جا، تو وه اسے دور ہی دور سے دیکھتی رہی اور فرعونیوں کو اس کا علم بھی نہ ہوا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiv{ان کے پہنچنے سے پہلے ہم نے موسیٰ (علیہ السلام) پر دائیوں کا دودھ حرام کر دیا تھا۔ یہ کہنے لگی کہ کیا میں تمہیں ایسا گھرانا بتاؤں جو اس بچہ کی تمہارے لیے پرورش کرے اور ہوں بھی وه اس بچے کے خیر خواه\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcclxv{پس ہم نے اسے اس کی ماں کی طرف واپس پہنچایا، تاکہ اس کی آنکھیں ٹھنڈی رہیں اور آزرده خاطر نہ ہو اور جان لے کہ اللہ تعالی کا وعده سچا ہے لیکن اکثر لوگ نہیں جانتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvi{اور جب موسیٰ (علیہ السلام) اپنی جوانی کو پہنچ گئے اور پورے توانا ہوگئے ہم نے انہیں حکمت وعلم عطا فرمایا، نیکی کرنے والوں کو ہم اسی طرح بدلہ دیا کرتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvii{اور موسیٰ (علیہ السلام) ایک ایسے وقت شہر میں آئے جبکہ شہر کے لوگ غفلت میں تھے۔ یہاں دو شخصوں کو لڑتے ہوئے پایا، یہ ایک تو اس کے رفیقوں میں سے تھا اور یہ دوسرا اس کے دشمنوں میں سے، اس کی قوم والے نے اس کے خلاف جو اس کے دشمنوں میں سے تھا اس سے فریاد کی، جس پر موسیٰ (علیہ السلام) نے اس کو مکا مارا جس سے وه مر گیا موسیٰ (علیہ السلام) کہنے لگے یہ تو شیطانی کام ہے، یقیناً شیطان دشمن اور کھلے طور پر بہکانے واﻻ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcclxviii{پھر دعا کرنے لگے کہ اے پروردگار! میں نے خود اپنے اوپر ﻇلم کیا، تو مجھے معاف فرما دے، اللہ تعالیٰ نے اسے بخش دیا، وه بخشش اور بہت مہربانی کرنے واﻻ ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcclxix{کہنے لگے اے میرے رب! جیسے تو نے مجھ پر یہ کرم فرمایا میں بھی اب ہرگز کسی گنہگار کا مددگار نہ بنوں گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcclxx{صبح ہی صبح ڈرتے اندیشہ کی حالت میں خبریں لینے کو شہر میں گئے، کہ اچانک وہی شخص جس نے کل ان سے مدد طلب کی تھی ان سے فریاد کر رہا ہے۔ موسیٰ (علیہ السلام) نے اس سے کہا کہ اس میں شک نہیں تو تو صریح بے راه ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxi{پھر جب اپنے اور اس کے دشمن کو پکڑنا چاہا وه فریادی کہنے لگا کہ موسیٰ (علیہ السلام) کیا جس طرح تو نے کل ایک شخص کو قتل کیا ہے مجھے بھی مار ڈالنا چاہتا ہے، تو تو ملک میں ﻇالم وسرکش ہونا ہی چاہتا ہے اور تیرا یہ اراده ہی نہیں کہ ملاپ کرنے والوں میں سے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxii{شہر کے پرلے کنارے سے ایک شخص دوڑتا ہوا آیا اور کہنے لگا اے موسیٰ! یہاں کے سردار تیرے قتل کا مشوره کر رہے ہیں، پس تو بہت جلد چلا جا مجھے اپنا خیر خواه مان\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiii{پس موسیٰ (علیہ السلام) وہاں سے خوفزده ہوکر دیکھتے بھالتے نکل کھڑے ہوئے، کہنے لگے اے پروردگار! مجھے ﻇالموں کے گروه سے بچا لے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiv{اور جب مدین کی طرف متوجہ ہوئے تو کہنے لگے مجھے امید ہے کہ میرا رب مجھے سیدھی راه لے چلے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxv{مدین کے پانی پر جب آپ پہنچے تو دیکھا کہ لوگوں کی ایک جماعت وہاں پانی پلا رہی ہے اور دو عورتیں الگ کھڑی اپنے (جانوروں کو) روکتی ہوئی دکھائی دیں، پوچھا کہ تمہارا کیا حال ہے، وه بولیں کہ جب تک یہ چرواہے واپس نہ لوٹ جائیں ہم پانی نہیں پلاتیں اور ہمارے والد بہت بڑی عمر کے بوڑھے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvi{پس آپ نے خود ان جانوروں کو پانی پلا دیا پھر سائے کی طرف ہٹ آئے اور کہنے لگے اے پروردگار! تو جو کچھ بھلائی میری طرف اتارے میں اس کا محتاج ہوں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvii{اتنے میں ان دونوں عورتوں میں سے ایک ان کی طرف شرم وحیا سے چلتی ہوئی آئی، کہنے لگی کہ میرے باپ آپ کو بلا رہے ہیں تاکہ آپ نے ہمارے (جانوروں) کو جو پانی پلایا ہے اس کی اجرت دیں، جب حضرت موسیٰ (علیہ السلام) ان کے پاس پہنچے اور ان سے اپنا سارا حال بیان کیا تو وه کہنے لگے اب نہ ڈر تو نے ﻇالم قوم سے نجات پائی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxviii{ان دونوں میں سے ایک نے کہا کہ ابا جی! آپ انہیں مزدوری پر رکھ لیجئے، کیونکہ جنہیں آپ اجرت پر رکھیں ان میں سے سب سے بہتر وه ہے جو مضبوط اور امانت دار ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxix{اس بزرگ نے کہا میں اپنی ان دونوں لڑکیوں میں سے ایک کو آپ کے نکاح میں دینا چاہتا ہوں اس (مہر پر) کہ آپ آٹھ سال تک میرا کام کاج کریں۔ ہاں اگر آپ دس سال پورے کریں تو یہ آپ کی طرف سے بطور احسان کے ہے میں یہ ہرگز نہیں چاہتا کہ آپ کو کسی مشقت میں ڈالوں، اللہ کو منظور ہے تو آگے چل کر آپ مجھے بھلا آدمی پائیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxx{موسیٰ (علیہ السلام) نے کہا، خیر تو یہ بات میرے اور آپ کے درمیان پختہ ہوگئی، میں ان دونوں مدتوں میں سے جسے پورا کروں مجھ پر کوئی زیادتی نہ ہو، ہم یہ جو کچھ کہہ رہے ہیں اس پر اللہ (گواه اور) کارساز ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxi{جب حضرت موسیٰ علیہ السلام نے مدت پوری کرلی اور اپنے گھر والوں کو لے کر چلے تو کوه طور کی طرف آگ دیکھی۔ اپنی بیوی سے کہنے لگے ٹھہرو! میں نے آگ دیکھی ہے بہت ممکن ہے کہ میں وہاں سے کوئی خبر ﻻؤں یا آگ کا کوئی انگاره ﻻؤں تاکہ تم سینک لو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxii{پس جب وہاں پہنچے تو اس بابرکت زمین کے میدان کے دائیں کنارے کے درخت میں سے آواز دیئے گئے کہ اے موسیٰ! یقیناً میں ہی اللہ ہوں سارے جہانوں کا پروردگار\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiii{اور یہ (بھی آواز آئی) کہ اپنی ﻻٹھی ڈال دے۔ پھر جب اسے دیکھا کہ وه سانﭗ کی طرح پھن پھنا رہی ہے تو پیٹھ پھیر کر واپس ہوگئے اور مڑ کر رخ بھی نہ کیا، ہم نے کہا اے موسیٰ! آگے آ ڈر مت، یقیناً تو ہر طرح امن واﻻ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiv{اپنے ہاتھ کو اپنے گریبان میں ڈال وه بغیر کسی قسم کے روگ کے چمکتا ہوا نکلے گا بالکل سفید اور خوف سے (بچنے کے لیے) اپنے بازو اپنی طرف ملا لے، پس یہ دونوں معجزے تیرے لیے تیرے رب کی طرف سے ہیں فرعون اور اس کی جماعت کی طرف، یقیناً وه سب کے سب بےحکم اور نافرمان لوگ ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxv{موسیٰ (علیہ السلام) نے کہا پروردگار! میں نے ان کا ایک آدمی قتل کر دیا تھا۔ اب مجھے اندیشہ ہے کہ وه مجھے بھی قتل کر ڈالیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvi{اور میرا بھائی ہارون (علیہ السلام) مجھ سے بہت زیاده فصیح زبان واﻻ ہے تو اسے بھی میرا مددگار بنا کر میرے ساتھ بھیج کہ وه مجھے سچا مانے، مجھے تو خوف ہے کہ وه سب مجھے جھٹلا دیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvii{اللہ تعالیٰ نے فرمایا کہ ہم تیرے بھائی کے ساتھ تیرا بازو مضبوط کردیں گے اور تم دونوں کو غلبہ دیں گے فرعونی تم تک پہنچ ہی نہ سکیں گے، بسبب ہماری نشانیوں کے، تم دونوں اور تمہاری تابعداری کرنے والے ہی غالب رہیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxviii{پس جب ان کے پاس موسیٰ (علیہ السلام) ہمارے دیے ہوئے کھلے معجزے لے کر پہنچے تو وه کہنے لگے یہ تو صرف گھڑا گھڑایا جادو ہے ہم نے اپنے اگلے باپ دادوں کے زمانہ میں کبھی یہ نہیں سنا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxix{حضرت موسیٰ (علیہ السلام) کہنے لگے میرا رب تعالیٰ اسے خوب جانتا ہے جو اس کے پاس کی ہدایت لے کر آتا ہے اور جس کے لیے آخرت کا (اچھا) انجام ہوتا ہے۔ یقیناً بے انصافوں کا بھلا نہ ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccxc{فرعون کہنے لگا اے درباریو! میں تو اپنے سوا کسی کو تمہارا معبود نہیں جانتا۔ سن اے ہامان! تو میرے لیے مٹی کو آگ سے پکوا پھر میرے لیے ایک محل تعمیر کر تو میں موسیٰ کے معبود کو جھانک لوں اسے میں تو جھوٹوں میں سے ہی گمان کر رہا ہوں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccxci{اس نے اور اس کے لشکروں نے ناحق طریقے پر ملک میں تکبر کیا اور سمجھ لیا کہ وه ہماری جانب لوٹائے ہی نہ جائیں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccxcii{بالﺂخر ہم نے اسے اور اس کے لشکروں کو پکڑ لیا اور دریا برد کر دیا، اب دیکھ لے کہ ان گنہگاروں کا انجام کیسا کچھ ہوا؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccxciii{اور ہم نے انہیں ایسے امام بنا دیئے کہ لوگوں کو جہنم کی طرف بلائیں اور روز قیامت مطلق مدد نہ کیے جائیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccxciv{اور ہم نے اس دنیا میں بھی ان کے پیچھے اپنی لعنت لگا دی اور قیامت کے دن بھی وه بدحال لوگوں میں سے ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccxcv{اور ان اگلے زمانہ والوں کو ہلاک کرنے کے بعد ہم نے موسیٰ (علیہ السلام) کو ایسی کتاب عنایت فرمائی جو لوگوں کے لیے دلیل اور ہدایت ورحمت ہوکر آئی تھی تاکہ وه نصیحت حاصل کرلیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvi{اور طور کے مغربی جانب جب کہ ہم نے موسیٰ (علیہ السلام) کو حکم احکام کی وحی پہنچائی تھی، نہ تو تو موجود تھا اور نہ تو دیکھنے والوں میں سے تھا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvii{لیکن ہم نے بہت سی نسلیں پیدا کیں جن پر لمبی مدتیں گزر گئیں، اور نہ تو مدین کے رہنے والوں میں سے تھا کہ ان کے سامنے ہماری آیتوں کی تلاوت کرتا بلکہ ہم ہی رسولوں کے بھیجنے والے رہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccxcviii{اور نہ تو طور کی طرف تھا جب کہ ہم نے آواز دی بلکہ یہ تیرے پروردگار کی طرف سے ایک رحمت ہے، اس لیے کہ تو ان لوگوں کو ہوشیار کر دے جن کے پاس تجھ سے پہلے کوئی ڈرانے واﻻ نہیں پہنچا، کیا عجب کہ وه نصیحت حاصل کرلیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccxcix{اگر یہ بات نہ ہوتی کہ انہیں ان کے اپنے ہاتھوں آگے بھیجے ہوئے اعمال کی وجہ سے کوئی مصیبت پہنچتی تو یہ کہہ اٹھتے کہ اے ہمارے رب! تو نے ہماری طرف کوئی رسول کیوں نہ بھیجا؟ کہ ہم تیری آیتوں کی تابعداری کرتے اور ایمان والوں میں سے ہو جاتے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccc{پھر جب ان کے پاس ہماری طرف سے حق آپہنچا تو کہتے ہیں کہ یہ وه کیوں نہیں دیا گیا جیسے دیئے گئے تھے موسیٰ (علیہ السلام) اچھا تو کیا موسیٰ (علیہ السلام) کو جو کچھ دیا گیا تھا اس کے ساتھ لوگوں نے کفر نہیں کیا تھا، صاف کہا تھا کہ یہ دونوں جادوگر ہیں جو ایک دوسرے کے مددگار ہیں اور ہم تو ان سب کے منکر ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccci{کہہ دے کہ اگر سچے ہو تو تم بھی اللہ کے پاس سے کوئی ایسی کتاب لے آؤ جو ان دونوں سے زیاده ہدایت والی ہو میں اسی کی پیروی کروں گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccii{پھر اگر یہ تیری نہ مانیں تو تو یقین کرلے کہ یہ صرف اپنی خواہش کی پیروی کر رہے ہیں۔ اور اس سے بڑھ کر بہکا ہوا کون ہے؟ جو اپنی خواہش کے پیچھے پڑا ہوا ہو بغیر اللہ کی رہنمائی کے، بیشک اللہ تعالیٰ ﻇالم لوگوں کو ہدایت نہیں دیتا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccciii{اور ہم برابر پے درپے لوگوں کے لیے اپنا کلام بھیجتے رہے تاکہ وه نصیحت حاصل کرلیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccciv{جس کو ہم نے اس سے پہلے کتاب عنایت فرمائی وه تو اس پر بھی ایمان رکھتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccv{اور جب اس کی آیتیں ان کے پاس پڑھی جاتی ہیں تو وه کہہ دیتے ہیں کہ اس کے ہمارے رب کی طرف سے حق ہونے پر ہمارا ایمان ہے ہم تو اس سے پہلے ہی مسلمان ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccvi{یہ اپنے کیے ہوئے صبر کے بدلے دوہرا دوہرا اجر دیئے جائیں گے۔ یہ نیکی سے بدی کو ٹال دیتے ہیں اور ہم نے جو انہیں دے رکھا ہے اس میں سے دیتے رہتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccvii{اور جب بیہوده بات کان میں پڑتی ہے تو اس سے کناره کر لیتے ہیں اور کہہ دیتے ہیں کہ ہمارے عمل ہمارے لیے اور تمہارے اعمال تمہارے لیے، تم پر سلام ہو، ہم جاہلوں سے (الجھنا) نہیں چاہتے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccviii{آپ جسے چاہیں ہدایت نہیں کر سکتے بلکہ اللہ تعالیٰ ہی جسے چاہے ہدایت کرتا ہے۔ ہدایت والوں سے وہی خوب آگاه ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccix{کہنے لگے اگر ہم آپ کے ساتھ ہوکر ہدایت کے تابع دار بن جائیں تو ہم تو اپنے ملک سے اچک لیے جائیں، کیا ہم نے انہیں امن وامان اور حرمت والے حرم میں جگہ نہیں دی؟ جہاں تمام چیزوں کے پھل کِھچے چلے آتے ہیں جو ہمارے پاس بطور رزق کے ہیں، لیکن ان میں سے اکثر کچھ نہیں جانتے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccx{اور ہم نے بہت سی وه بستیاں تباه کر دیں جو اپنی عیش و عشرت میں اترانے لگی تھیں، یہ ہیں ان کی رہائش کی جگہیں جو ان کے بعد بہت ہی کم آباد کی گئیں اور ہم ہی ہیں آخر سب کچھ کے وارث\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxi{تیرا رب کسی ایک بستی کو بھی اس وقت تک ہلاک نہیں کرتا جب تک کہ ان کی کسی بڑی بستی میں اپنا کوئی پیغمبر نہ بھیج دے جو انہیں ہماری آیتیں پڑھ کر سنا دے اور ہم بستیوں کو اسی وقت ہلاک کرتے ہیں جب کہ وہاں والے ﻇلم وستم پر کمر کس لیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcccxii{اور تمہیں جو کچھ دیا گیا ہے وه صرف زندگی دنیا کا سامان اور اسی کی رونق ہے، ہاں اللہ کے پاس جو ہے وه بہت ہی بہتر اور دیرپا ہے۔ کیا تم نہیں سمجھتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiii{کیا وه شخص جس سے ہم نے نیک وعده کیا ہے جسے وه قطعاً پانے واﻻ ہے مثل اس شخص کے ہوسکتا ہے؟ جسے ہم نے زندگانیٴ دنیا کی کچھ یونہی سی منفعت دے دی پھر بالﺂخر وه قیامت کے روز پکڑا باندھا حاضر کیا جائے گا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiv{اور جس دن اللہ تعالیٰ انہیں پکار کر فرمائے گا کہ تم جنہیں اپنے گمان میں میرا شریک ٹھہرا رہے تھے کہاں ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcccxv{جن پر بات آچکی وه جواب دیں گے کہ اے ہمارے پروردگار! یہی وه ہیں جنہیں ہم نے بہکا رکھا تھا، ہم نے انہیں اسی طرح بہکایا جس طرح ہم بہکے تھے، ہم تیری سرکار میں اپنی دست برداری کرتے ہیں، یہ ہماری عبادت نہیں کرتے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvi{کہا جائے گا کہ اپنے شریکوں کو بلاؤ، وه بلائیں گے لیکن انہیں وه جواب تک نہ دیں گے اور سب عذاب دیکھ لیں گے، کاش یہ لوگ ہدایت پا لیتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvii{اس دن انہیں بلا کر پوچھے گا کہ تم نے نبیوں کو کیا جواب دیا؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcccxviii{پھر تو اس دن ان کی تمام دلیلیں گم ہو جائیں گی اور ایک دوسرے سے سوال تک نہ کریں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcccxix{ہاں جو شخص توبہ کرلے ایمان لے آئے اور نیک کام کرے یقین ہے کہ وه نجات پانے والوں میں سے ہو جائے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcccxx{اور آپ کا رب جو چاہتا ہے پیدا کرتا ہے اور جسے چاہتا ہے چن لیتا ہے، ان میں سے کسی کو کوئی اختیار نہیں، اللہ ہی کے لیے پاکی ہے وه بلند تر ہے ہر اس چیز سے کہ لوگ شریک کرتے ہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxi{ان کے سینے جو کچھ چھپاتے اور جو کچھ ﻇاہر کرتے ہیں آپ کا رب سب کچھ جانتا ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxii{وہی اللہ ہے اس کے سوا کوئی ﻻئق عبادت نہیں، دنیا اور آخرت میں اسی کی تعریف ہے۔ اسی کے لیے فرمانروائی ہے اور اسی کی طرف تم سب پھیرے جاؤ گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiii{کہہ دیجئے! کہ دیکھو تو سہی اگر اللہ تعالیٰ تم پر رات ہی رات قیامت تک برابر کر دے تو سوائے اللہ کے کون معبود ہے جو تمہارے پاس دن کی روشنی ﻻئے؟ کیا تم سنتے نہیں ہو؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiv{پوچھئے! کہ یہ بھی بتا دو کہ اگر اللہ تعالیٰ تم پر ہمیشہ قیامت تک دن ہی دن رکھے تو بھی سوائے اللہ تعالیٰ کے کوئی معبود ہے جو تمہارے پاس رات لے آئے؟ جس میں تم آرام حاصل کرو، کیا تم دیکھ نہیں رہے ہو؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxv{اسی نے تو تمہارے لیے اپنے فضل وکرم سے دن رات مقرر کر دیے ہیں کہ تم رات میں آرام کرو اور دن میں اس کی بھیجی ہوئی روزی تلاش کرو، یہ اس لیے کہ تم شکر ادا کرو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvi{اور جس دن انہیں پکار کر اللہ تعالیٰ فرمائے گا کہ جنہیں تم میرے شریک خیال کرتے تھے وه کہاں ہیں؟\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvii{اور ہم ہر امت میں سے ایک گواه الگ کرلیں گے کہ اپنی دلیلیں پیش کرو پس اس وقت جان لیں گے کہ حق اللہ تعالیٰ کی طرف ہے، اور جو کچھ افترا وه جوڑتے تھے سب ان کے پاس سے کھو جائے گا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxviii{قارون تھا تو قوم موسیٰ سے، لیکن ان پر ﻇلم کرنے لگا تھا ہم نے اسے (اس قدر) خزانے دے رکھے تھے کہ کئی کئی طاقت ور لوگ بہ مشکل اس کی کنجیاں اٹھا سکتے تھے، ایک بار اس کی قوم نے اس سے کہا کہ اترا مت! اللہ تعالیٰ اترانے والوں سے محبت نہیں رکھتا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxix{اور جو کچھ اللہ تعالی نے تجھے دے رکھا ہے اس میں سے آخرت کے گھر کی تلاش بھی رکھ اور اپنے دنیوی حصے کو بھی نہ بھول اور جیسے کہ اللہ نے تیرے ساتھ احسان کیا ہے تو بھی اچھا سلوک کر اور ملک میں فساد کا خواہاں نہ ہو، یقین مان کہ اللہ مفسدوں کو ناپسند رکھتا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxx{قارون نے کہا یہ سب کچھ مجھے میری اپنی سمجھ کی بنا پر ہی دیا گیا ہے، کیا اسے اب تک یہ نہیں معلوم کہ اللہ تعالیٰ نے اس سے پہلے بہت سے بستی والوں کو غارت کر دیا جو اس سے بہت زیاده قوت والے اور بہت بڑی جمع پونجی والے تھے۔ اور گنہگاروں سے ان کے گناہوں کی باز پرس ایسے وقت نہیں کی جاتی\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxi{پس قارون پوری آرائش کے ساتھ اپنی قوم کے مجمع میں نکلا، تو دنیاوی زندگی کے متوالے کہنے لگے کاش کہ ہمیں بھی کسی طرح وه مل جاتا جو قارون کو دیا گیا ہے۔ یہ تو بڑا ہی قسمت کا دھنی ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxii{ذی علم لوگ انہیں سمجھانے لگے کہ افسوس! بہتر چیز تو وه ہے جو بطور ﺛواب انہیں ملے گی جو اللہ پر ایمان ﻻئیں اور نیک عمل کریں یہ بات انہی کے دل میں ڈالی جاتی ہے جو صبر وسہارا والے ہوں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiii{(آخرکار) ہم نے اسے اس کے محل سمیت زمین میں دھنسا دیا اور اللہ کے سوا کوئی جماعت اس کی مدد کے لیے تیار نہ ہوئی نہ وه خود اپنے بچانے والوں میں سے ہو سکا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiv{اور جو لوگ کل اس کے مرتبہ پر پہنچنے کی آرزو مندیاں کر رہے تھے وه آج کہنے لگے کہ کیا تم نہیں دیکھتے کہ اللہ تعالیٰ ہی اپنے بندوں میں سے جس کے لیے چاہے روزی کشاده کر دیتا ہے اور تنگ بھی؟ اگر اللہ تعالیٰ ہم پر فضل نہ کرتا تو ہمیں بھی دھنسا دیتا، کیا دیکھتے نہیں ہو کہ ناشکروں کو کبھی کامیابی نہیں ہوتی؟\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxv{آخرت کا یہ بھلا گھر ہم ان ہی کے لیے مقرر کر دیتے ہیں جو زمین میں اونچائی بڑائی اور فخر نہیں کرتے نہ فساد کی چاہت رکھتے ہیں۔ پرہیزگاروں کے لیے نہایت ہی عمده انجام ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvi{جو شخص نیکی ﻻئے گا اسے اس سے بہتر ملے گا اور جو برائی لے کر آئے گا تو ایسے بداعمالی کرنے والوں کو ان کے انہی اعمال کا بدلہ دیا جائے گا جو وه کرتے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvii{جس اللہ نے آپ پر قرآن نازل فرمایا ہے وه آپ کو دوباره پہلی جگہ ﻻنے واﻻ ہے، کہہ دیجئے! کہ میرا رب اسے بھی بخوبی جانتا ہے جو ہدایت ﻻیا ہے اور اسے بھی جو کھلی گمراہی میں ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxviii{آپ کو تو کبھی اس کا خیال بھی نہ گزرا تھا کہ آپ کی طرف کتاب نازل فرمائی جائے گی لیکن یہ آپ کے رب کی مہربانی سے اترا۔ اب آپ کو ہرگز کافروں کا مددگار نہ ہونا چاہیئے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxix{خیال رکھیئے کہ یہ کفار آپ کو اللہ تعالیٰ کی آیتوں کی تبلیﻎ سے روک نہ دیں اس کے بعد کہ یہ آپ کی جانب اتاری گئیں، تو اپنے رب کی طرف بلاتے رہیں اور شرک کرنے والوں میں سے نہ ہوں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmcccxl{اللہ تعالیٰ کے ساتھ کسی اور معبود کو نہ پکارنا بجز اللہ تعالیٰ کے کوئی اور معبود نہیں، ہر چیز فنا ہونے والی ہے مگر اسی کا منھ (اور ذات) ۔ اسی کے لیے فرمانروائی ہے اور تم اسی کی طرف لوٹائے جاؤ گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmcccxli{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlii{کیا لوگوں نے یہ گمان کر رکھا ہے کہ ان کے صرف اس دعوے پر کہ ہم ایمان ﻻئے ہیں ہم انہیں بغیر آزمائے ہوئے ہی چھوڑ دیں گے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliii{ان سے اگلوں کو بھی ہم نے خوب جانچا۔ یقیناً اللہ تعالیٰ انہیں بھی جان لے گا جو سچ کہتے ہیں اور انہیں بھی معلوم کرلے گا جو جھوٹے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliv{کیا جو لوگ برائیاں کر رہے ہیں انہوں نے یہ سمجھ رکھا ہے کہ وه ہمارے قابو سے باہر ہو جائیں گے، یہ لوگ کیسی بری تجویزیں کر رہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlv{جسے اللہ کی ملاقات کی امید ہو پس اللہ کا ٹھہرایا ہوا وقت یقیناً آنے واﻻ ہے، وه سب کچھ سننے واﻻ، سب کچھ جاننے واﻻ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvi{اور ہر ایک کوشش کرنے واﻻ اپنے ہی بھلے کی کوشش کرتا ہے۔ ویسے تو اللہ تعالیٰ تمام جہان والوں سے بےنیاز ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvii{اور جن لوگوں نے یقین کیا اور مطابق سنت کام کیے ہم ان کے تمام گناہوں کو ان سے دور کر دیں گے اور انہیں ان کے نیک اعمال کے بہترین بدلے دیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlviii{ہم نے ہر انسان کو اپنے ماں باپ کے ساتھ اچھا سلوک کرنے کی نصیحت کی ہے ہاں اگر وه یہ کوشش کریں کہ آپ میرے ساتھ اسے شریک کرلیں جس کا آپ کو علم نہیں تو ان کا کہنا نہ مانیئے، تم سب کا لوٹنا میری ہی طرف ہے پھر میں ہر اس چیز سے جو تم کرتے تھے تمہیں خبر دوں گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlix{اور جن لوگوں نے ایمان قبول کیا اور نیک کام کیے انہیں میں اپنے نیک بندوں میں شمار کر لوں گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcccl{اور بعض لوگ ایسے بھی ہیں جو زبانی کہتے ہیں کہ ہم ایمان ﻻئے ہیں لیکن جب اللہ کی راه میں کوئی مشکل آن پڑتی ہے تو لوگوں کی ایذا دہی کو اللہ تعالیٰ کے عذاب کی طرح بنا لیتے ہیں، ہاں اگر اللہ کی مدد آجائے تو پکار اٹھتے ہیں کہ ہم تو تمہارے ساتھی ہی ہیں کیا دنیا جہان کے سینوں میں جو کچھ ہے اس سے اللہ تعالیٰ دانا نہیں ہے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcccli{جو لوگ ایمان ﻻئے اللہ انہیں بھی ﻇاہر کرکے رہے گا اور منافقوں کو بھی ﻇاہر کرکے رہے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmccclii{کافروں نے ایماں والوں سے کہا کہ تم ہماری راه کی تابعداری کرو تمہارے گناه ہم اٹھا لیں گے، حاﻻنکہ وه ان کے گناہوں میں سے کچھ بھی نہیں اٹھانے والے، یہ تو محض جھوٹے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcccliii{البتہ یہ اپنے بوجھ ڈھولیں گے اور اپنے بوجھوں کے ساتھ ہی اور بوجھ بھی۔ اور جو کچھ افترا پردازیاں کر رہے ہیں ان سب کی بابت ان سے باز پرس کی جائے گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcccliv{اور ہم نے نوح (علیہ السلام) کو ان کی قوم کی طرف بھیجا وه ان میں ساڑھے نو سو سال تک رہے، پھر تو انہیں طوفان نے دھر پکڑا اور وه تھے بھی ﻇالم\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmccclv{پھر ہم نے انہیں اور کشتی والوں کو نجات دی اور اس واقعہ کو ہم نے تمام جہان کے لیے عبرت کا نشان بنا دیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmccclvi{اور ابراہیم (علیہ السلام) نے بھی اپنی قوم سے فرمایا کہ اللہ تعالیٰ کی عبادت کرو اوراس سے ڈرتے رہو، اگر تم میں دانائی ہے تو یہی تمہارے لیے بہتر ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmccclvii{تم تو اللہ تعالیٰ کے سوا بتوں کی پوجا پاٹ کر رہے ہو اور جھوٹی باتیں دل سے گھڑ لیتے ہو۔ سنو! جن جنکی تم اللہ تعالیٰ کے سوا پوجا پاٹ کر رہے ہو وه تو تمہاری روزی کے مالک نہیں پس تمہیں چاہئے کہ تم اللہ تعالیٰ ہی سے روزیاں طلب کرو اور اسی کی عبادت کرو اور اسی کی شکر گزاری کرو اور اسی کی طرف تم لوٹائے جاؤ گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmccclviii{اور اگر تم جھٹلاؤ تو تم سے پہلے کی امتوں نے بھی جھٹلایا ہے، رسول کے ذمہ تو صرف صاف طور پر پہنچا دینا ہی ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmccclix{کیا انہوں نے نہیں دیکھا کہ مخلوق کی ابتدا کس طرح اللہ نے کی پھر اللہ اس کا اعاده کرے گا، یہ تو اللہ تعالیٰ پر بہت ہی آسان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmccclx{کہہ دیجئے! کہ زمین میں چل پھر کر دیکھو تو سہی کہ کس طرح اللہ تعالیٰ نے ابتداءً پیدائش کی۔ پھر اللہ تعالیٰ ہی دوسری نئی پیدائش کرے گا، اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmccclxi{جسے چاہے عذاب کرے جس پر چاہے رحم کرے، سب اسی کی طرف لوٹائے جاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmccclxii{تم نہ تو زمین میں اللہ تعالیٰ کو عاجز کرسکتے ہو نہ آسمان میں، اللہ تعالیٰ کے سوا تمہارا کوئی والی ہے نہ مددگار\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiii{جو لوگ اللہ تعالیٰ کی آیتوں اور اس کی ملاقات کو بھلاتے ہیں وه میری رحمت سے ناامید ہو جائیں اور ان کے لیے دردناک عذاب ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiv{ان کی قوم کا جواب بجز اس کے کچھ نہ تھا کہ کہنے لگے کہ اسے مار ڈالو یا اسے جلا دو۔ آخر اللہ نے انہیں آگ سے بچا لیا، اس میں ایمان والے لوگوں کے لیے تو بہت سی نشانیاں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmccclxv{(حضرت ابراہیم علیہ السلام نے) کہا کہ تم نے جن بتوں کی پرستش اللہ کے سوا کی ہے انہیں تم نے اپنی آپس کی دنیوی دوستی کی بنا ٹھہرا لی ہے، تم سب قیامت کے دن ایک دوسرے سے کفر کرنے لگو گے اور ایک دوسرے پر لعنت کرنے لگو گے۔ اور تمہارا سب کا ٹھکانہ دوزخ ہوگا اور تمہارا کوئی مددگار نہ ہوگا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvi{پس حضرت ابراہیم (علیہ السلام) پر حضرت لوط (علیہ السلام) ایمان ﻻئے اور کہنے لگے کہ میں اپنے رب کی طرف ہجرت کرنے واﻻ ہوں۔ وه بڑا ہی غالب اور حکیم ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvii{اور ہم نے انھیں (ابراہیم کو) اسحاق ویعقوب (علیہما السلام) عطا کیے اور ہم نے نبوت اور کتاب ان کی اوﻻد میں ہی کر دی اور ہم نے دنیا میں بھی اسے ﺛواب دیا اور آخرت میں تو وه صالح لوگوں میں سے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmccclxviii{اور حضرت لوط (علیہ السلام) کا بھی ذکر کرو جب کہ انہوں نے اپنی قوم سے فرمایا کہ تم تو اس بدکاری پر اتر آئے ہو جسے تم سے پہلے دنیا بھر میں سے کسی نے نہیں کیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmccclxix{کیا تم مردوں کے پاس بدفعلی کے لیے آتے ہو اور راستے بند کرتے ہو اور اپنی عام مجلسوں میں بے حیائیوں کا کام کرتے ہو؟ اس کے جواب میں اس کی قوم نے بجز اس کے اور کچھ نہیں کہا کہ بس جا اگر سچا ہے تو ہمارے پاس اللہ تعالیٰ کا عذاب لے آ\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmccclxx{حضرت لوط (علیہ السلام) نے دعا کی کہ پروردگار! اس مفسد قوم پر میری مدد فرما\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxi{اور جب ہمارے بھیجے ہوئے فرشتے ابراہیم (علیہ السلام) کے پاس بشارت لے کر پہنچے کہنے لگے کہ اس بستی والوں کو ہم ہلاک کرنے والے ہیں، یقیناً یہاں کے رہنے والے گنہگار ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxii{(حضرت ابراہیم علیہ السلام نے) کہا اس میں تو لوط (علیہ السلام) ہیں، فرشتوں نے کہا یہاں جو ہیں ہم انہیں بخوبی جانتے ہیں۔ لوط (علیہ السلام) کو اور اس کے خاندان کو سوائے اس کی بیوی کے ہم بچالیں گے، البتہ وه عورت پیچھے ره جانے والوں میں سے ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiii{پھر جب ہمارے قاصد لوط (علیہ السلام) کے پاس پہنچے تو وه ان کی وجہ سے غمگین ہوئے اور دل ہی دل میں رنج کرنے لگے۔ قاصدوں نے کہا آپ نہ خوف کھایئے نہ آزرده ہوں، ہم آپ کو مع آپ کے متعلقین کے بچالیں گے مگر آپ کی بیوی کہ وه عذاب کے لیے باقی ره جانے والوں میں سے ہوگی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiv{ہم اس بستی والوں پر آسمانی عذاب نازل کرنے والے ہیں اس وجہ سے کہ یہ بےحکم ہو رہے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxv{البتہ ہم نے اس بستی کو صریح عبرت کی نشانی بنا دیا ان لوگوں کے لیے جو عقل رکھتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvi{اور مدین کی طرف ہم نے ان کے بھائی شعیب (علیہ السلام) کو بھیجا انہوں نے کہا اے میری قوم کے لوگو! اللہ کی عبادت کرو قیامت کے دن کی توقع رکھو اور زمین میں فساد نہ کرتے پھرو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvii{پھر بھی انہوں نے انہیں جھٹلایا آخر انہیں زلزلے نے پکڑ لیا اور وه اپنے گھروں میں بیٹھے کے بیٹھے مرده ہو کر ره گئے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxviii{اور ہم نے عادیوں اور ﺛمودیوں کو بھی غارت کیا جن کے بعض مکانات تمہارے سامنے ﻇاہر ہیں اور شیطان نے انہیں ان کی بداعمالیاں آراستہ کر دکھائی تھیں اور انہیں راه سے روک دیا تھا باوجودیکہ یہ آنکھوں والے اور ہوشیار تھے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxix{اور قارون اور فرعون اور ہامان کو بھی، ان کے پاس حضرت موسیٰ (علیہ السلام) کھلے کھلے معجزے لے کر آئے تھے پھر بھی انہوں نے زمین میں تکبر کیا لیکن ہم سے آگے بڑھنے والے نہ ہو سکے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxx{پھر تو ہر ایک کو ہم نے اس کے گناه کے وبال میں گرفتار کر لیا، ان میں سے بعض پر ہم نے پتھروں کا مینہ برسایا اور ان میں سے بعض کو زور دار سخت آواز نے دبوچ لیا اور ان میں سے بعض کو ہم نے زمین میں دھنسا دیا اور ان میں سے بعض کو ہم نے ڈبو دیا، اللہ تعالیٰ ایسا نہیں کہ ان پر ﻇلم کرے بلکہ یہی لوگ اپنی جانوں پر ﻇلم کرتے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxi{جن لوگوں نے اللہ تعالیٰ کے سوا اور کارساز مقرر کر رکھے ہیں ان کی مثال مکڑی کی سی ہے کہ وه بھی ایک گھر بنا لیتی ہے، حاﻻنکہ تمام گھروں سے زیاده بودا گھر مکڑی کا گھر ہی ہے، کاش! وه جان لیتے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxii{اللہ تعالیٰ ان تمام چیزوں کو جانتا ہے جنہیں وه اس کے سوا پکار رہے ہیں، وه زبردست اور ذی حکمت ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiii{ہم ان مثالوں کو لوگوں کے لیے بیان فرما رہے ہیں انہیں صرف علم والے ہی سمجھتے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiv{اللہ تعالیٰ نے آسمانوں اور زمین کو مصلحت اور حق کے ساتھ پیدا کیا ہے، ایمان والوں کے لیے تو اس میں بڑی بھاری دلیل ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxv{جو کتاب آپ کی طرف وحی کی گئی ہے اسے پڑھئے اور نماز قائم کریں، یقیناً نماز بے حیائی اور برائی سے روکتی ہے، بیشک اللہ کا ذکر بہت بڑی چیز ہے، تم جو کچھ کر رہے ہو اس سے اللہ خبردار ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvi{اور اہل کتاب کے ساتھ بحﺚ ومباحثہ نہ کرو مگر اس طریقہ پر جو عمده ہو مگر ان کے ساتھ جو ان میں ﻇالم ہیں اور صاف اعلان کر دو کہ ہمارا تو اس کتاب پر بھی ایمان ہے اور جو ہم پر اتاری گئی ہے اور اس پر بھی جو تم پر اتاری گئی، ہمارا تمہارا معبود ایک ہی ہے۔ ہم سب اسی کے حکم برادر ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvii{اور ہم نے اسی طرح آپ کی طرف اپنی کتاب نازل فرمائی ہے، پس جنہیں ہم نے کتاب دی ہے وه اس پر ایمان ﻻتے ہیں اور ان (مشرکین) میں سے بعض اس پر ایمان رکھتے ہیں اور ہماری آیتوں کا انکار صرف کافر ہی کرتے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxviii{اس سے پہلے تو آپ کوئی کتاب پڑھتے نہ تھے اور نہ کسی کتاب کو اپنے ہاتھ سے لکھتے تھے کہ یہ باطل پرست لوگ شک وشبہ میں پڑتے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxix{بلکہ یہ (قرآن) تو روشن آیتیں ہیں جو اہل علم کے سینوں میں محفوظ ہیں، ہماری آیتوں کا منکر بجز ﻇالموں کے اور کوئی نہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccxc{انہوں نے کہا کہ اس پر کچھ نشانیاں (معجزات) اس کے رب کی طرف سے کیوں نہیں اتارے گئے۔ آپ کہہ دیجئے کہ نشانیاں تو سب اللہ تعالیٰ کے پاس ہیں میں تو صرف کھلم کھلا آگاه کر دینے واﻻ ہوں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcccxci{کیا انہیں یہ کافی نہیں؟ کہ ہم نے آپ پر کتاب نازل فرما دی جو ان پر پڑھی جا رہی ہے، اس میں رحمت (بھی) ہے اور نصیحت (بھی) ہے ان لوگوں کے لئے جو ایمان والے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcii{کہہ دیجئے کہ مجھ میں اور تم میں اللہ تعالیٰ گواه ہونا کافی ہے وه آسمان وزمین کی ہر چیز کا عالم ہے، جو لوگ باطل کے ماننے والے اور اللہ تعالیٰ سے کفر کرنے والے ہیں وه زبردست نقصان اور گھاٹے میں ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciii{یہ لوگ آپ سے عذاب کی جلدی کر رہے ہیں۔ اگر میری طرف سے مقرر کیا ہوا وقت نہ ہوتا تو ابھی تک ان کے پاس عذاب آچکا ہوتا، یہ یقینی بات ہے کہ اچانک ان کی بے خبری میں ان کے پاس عذاب آپہنچے گا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciv{یہ عذاب کی جلدی مچا رہے ہیں اور (تسلی رکھیں) جہنم کافروں کو گھیر لینے والی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcv{اس دن ان کے اوپر تلے سے عذاب ڈھانﭗ رہا ہوگا اور اللہ تعالیٰ فرمائے گا کہ اب اپنے (بد) اعمال کا مزه چکھو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvi{اے میرے ایمان والے بندو! میری زمین بہت کشاده ہے سو تم میری ہی عبادت کرو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvii{ہر جاندار موت کا مزه چکھنے واﻻ ہےاور تم سب ہماری ہی طرف لوٹائے جاؤ گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcviii{اور جولوگ ایمان ﻻئے اور نیک کام کیے انہیں ہم یقیناً جنت کے ان باﻻ خانوں میں جگہ دینگے جن کے نیچے چشمے بہہ رہے ہیں جہاں وه ہمیشہ رہیں گے، کام کرنے والوں کا کیا ہی اچھا اجر ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcix{وه جنہوں نے صبر کیا، اور اپنے رب تعالیٰ پر بھروسہ رکھتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcd{اور بہت سے جانور ہیں جو اپنی روزی اٹھائے نہیں پھرتے، ان سب کو اور تمہیں بھی اللہ تعالیٰ ہی روزی دیتا ہے، وه بڑا ہی سننے جاننے واﻻ ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdi{اور اگر آپ ان سے دریافت کریں کہ زمین وآسمان کا خالق اور سورج چاند کو کام میں لگانے واﻻ کون ہے؟ تو ان کا جواب یہی ہوگا کہ اللہ تعالیٰ، پھر کدھر الٹے جا رہے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcdii{اللہ تعالیٰ اپنے بندوں میں سے جسے چاہے فراخ روزی دیتا ہے اور جسے چاہے تنگ۔ یقیناً اللہ تعالیٰ ہر چیز کا جاننے واﻻ ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcdiii{اور اگر آپ ان سے سوال کریں کہ آسمان سے پانی اتار کر زمین کو اس کی موت کے بعد زنده کس نے کیا؟ تو یقیناً ان کا جواب یہی ہوگا اللہ تعالیٰ نے۔ آپ کہہ دیں کہ ہر تعریف اللہ ہی کے لئے سزاوار ہے، بلکہ ان میں سے اکثر بے عقل ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcdiv{اور دنیا کی یہ زندگانی تو محض کھیل تماشا ہے البتہ آخرت کے گھر کی زندگی ہی حقیقی زندگی ہے، کاش! یہ جانتے ہوتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcdv{پس یہ لوگ جب کشتیوں میں سوار ہوتے ہیں تو اللہ تعالیٰ ہی کو پکارتے ہیں اس کے لئے عبادت کو خالص کر کے پھر جب وه انہیں خشکی کی طرف بچا ﻻتا ہے تو اسی وقت شرک کرنے لگتے ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcdvi{تاکہ ہماری دی ہوئی نعمتوں سے مکرتے رہیں اور برتتے رہیں۔ ابھی ابھی پتہ چل جائے گا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcdvii{کیا یہ نہیں دیکھتے کہ ہم نے حرم کو با امن بنا دیا ہے حاﻻنکہ ان کے اردگرد سے لوگ اچک لیے جاتے ہیں، کیا یہ باطل پر تو یقین رکھتے ہیں اور اللہ تعالیٰ کی نعمتوں پر ناشکری کرتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcdviii{اور اس سے بڑا ﻇالم کون ہوگا؟ جو اللہ تعالیٰ پر جھوٹ باندھے یا جب حق اس کے پاس آجائے وه اسے جھٹلائے، کیا ایسے کافروں کا ٹھکانا جہنم میں نہ ہوگا؟\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcdix{اور جو لوگ ہماری راه میں مشقتیں برداشت کرتے ہیں ہم انہیں اپنی راہیں ضرور دکھا دیں گے۔ یقیناً اللہ تعالیٰ نیکو کاروں کا ساتھی ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcdx{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdxi{رومی مغلوب ہوگئے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdxii{نزدیک کی زمین پر اور وه مغلوب ہونے کے بعد عنقریب غالب آجائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiii{چند سال میں ہی۔ اس سے پہلے اور اس کے بعد بھی اختیار اللہ تعالیٰ ہی کا ہے۔ اس روز مسلمان شادمان ہوں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiv{اللہ کی مدد سے، وه جس کی چاہتا ہے مدد کرتا ہے۔ اصل غالب اور مہربان وہی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdxv{اللہ کا وعده ہے، اللہ تعالیٰ اپنے وعدے کا خلاف نہیں کرتا لیکن اکثر لوگ نہیں جانتے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvi{وه تو (صرف) دنیوی زندگی کے ﻇاہر کو (ہی) جانتے ہیں اور آخرت سے تو بالکل ہی بےخبر ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvii{کیا ان لوگوں نے اپنے دل میں یہ غور نہیں کیا؟ کہ اللہ تعالیٰ نے آسمانوں کو اور زمین اور ان کے درمیان جو کچھ ہے سب کو بہترین قرینے سے مقرر وقت تک کے لئے (ہی) پیدا کیا ہے، ہاں اکثر لوگ یقیناً اپنے رب کی ملاقات کے منکر ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdxviii{کیا انہوں نے زمین پر چل پھر کر یہ نہیں دیکھا کہ ان سے پہلے لوگوں کا انجام کیسا (برا) ہوا؟ وه ان سے بہت زیاده توانا (اور طاقتور) تھے اور انہوں نے (بھی) زمین بوئی جوتی تھی اور ان سے زیاده آباد کی تھی اور ان کے پاس ان کے رسول روشن دﻻئل لے کر آئے تھے۔ یہ تو ناممکن تھا کہ اللہ تعالیٰ ان پر ﻇلم کرتا لیکن (دراصل) وه خود اپنی جانوں پر ﻇلم کرتے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdxix{پھر آخر برا کرنے والوں کا بہت ہی برا انجام ہوا، اس لئے کہ وه اللہ تعالیٰ کی آیتوں کو جھٹلاتے اور ان کی ہنسی اڑاتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdxx{اللہ تعالیٰ ہی مخلوق کی ابتدا کرتا ہے پھر وہی اسے دوباره پیدا کرے گا پھر تم سب اسی کی طرف لوٹائے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxi{اور جس دن قیامت قائم ہوگی تو گنہگار حیرت زده ره جائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxii{اور ان کے تمام تر شریکوں میں سے ایک بھی ان کا سفارشی نہ ہوگا اور (خود یہ بھی) اپنے شریکوں کے منکر ہو جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiii{اور جس دن قیامت قائم ہوگی اس دن (جماعتیں) الگ الگ ہو جائیں گی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiv{جو ایمان ﻻکر نیک اعمال کرتے رہے وه تو جنت میں خوش وخرم کر دیئے جائیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxv{اور جنہوں نے کفر کیا تھا اور ہماری آیتوں کو اور آخرت کی ملاقات کو جھوٹا ٹھہرایا تھا وه سب عذاب میں پکڑ کر حاضر رکھے جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvi{پس اللہ تعالیٰ کی تسبیح پڑھا کرو جب کہ تم شام کرو اور جب صبح کرو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvii{تمام تعریفوں کے ﻻئق آسمان وزمین میں صرف وہی ہے تیسرے پہر کو اور ﻇہر کے وقت بھی (اس کی پاکیزگی بیان کرو)\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxviii{(وہی) زنده کو مرده سے اور مرده کو زنده سے نکالتا ہے۔ اور وہی زمین کو اس کی موت کے بعد زنده کرتا ہے اسی طرح تم (بھی) نکالے جاؤ گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxix{اللہ کی نشانیوں میں سے ہے کہ اس نے تم کو مٹی سے پیدا کیا پھر اب انسان بن کر (چلتے پھرتے) پھیل رہے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxx{اور اس کی نشانیوں میں سے ہے کہ تمہاری ہی جنس سے بیویاں پیدا کیں تاکہ تم ان سے آرام پاؤ اس نے تمہارے درمیان محبت اور ہمدردی قائم کر دی، یقیناً غور وفکر کرنے والوں کے لئے اس میں بہت سی نشانیاں ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxi{اس (کی قدرت) کی نشانیوں میں سے آسمانوں اور زمین کی پیدائش اور تمہاری زبانوں اور رنگتوں کا اختلاف (بھی) ہے، دانش مندوں کے لئے اس میں یقیناً بڑی نشانیاں ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxii{اور (بھی) اس کی (قدرت کی) نشانی تمہاری راتوں اور دن کی نیند میں ہے اور اس کے فضل (یعنی روزی) کو تمہارا تلاش کرنا بھی ہے۔ جو لوگ (کان لگا کر) سننے کے عادی ہیں ان کے لئے اس میں بہت سی نشانیاں ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiii{اور اس کی نشانیوں میں سے ایک یہ (بھی) ہے کہ وه تمہیں ڈرانے اور امیدوار بنانے کے لئے بجلیاں دکھاتا ہے اور آسمان سے بارش برساتا ہے اور اس مرده زمین کو زنده کر دیتا ہے، اس میں (بھی) عقلمندوں کے لئے بہت سی نشانیاں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiv{اس کی ایک نشانی یہ بھی ہے کہ آسمان وزمین اسی کے حکم سے قائم ہیں، پھر جب وه تمہیں آواز دے گا صرف ایک بار کی آواز کے ساتھ ہی تم سب زمین سے نکل آؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxv{اور زمین وآسمان کی ہر ہر چیز اس کی ملکیت ہےاور ہر ایک اس کے فرمان کے ماتحت ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvi{وہی ہے جو اول بار مخلوق کو پیدا کرتا ہے پھر سے دوباره پیدا کرے گا اور یہ تو اس پر بہت ہی آسان ہے۔ اسی کی بہترین اور اعلیٰ صفت ہے، آسمانوں میں اور زمین میں بھی اور وہی غلبے واﻻ حکمت واﻻ ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvii{اللہ تعالیٰ نے تمہارے لئے ایک مثال خود تمہاری ہی بیان فرمائی، جو کچھ ہم نے تمہیں دے رکھا ہے کیا اس میں تمہارے غلاموں میں سے بھی کوئی تمہارا شریک ہے؟ کہ تم اور وه اس میں برابر درجے کے ہو؟ اور تم ان کا ایسا خطره رکھتے ہو جیسا خود اپنوں کا، ہم عقل رکھنے والوں کے لئے اسی طرح کھول کھول کر آیتیں بیان کر دیتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxviii{بلکہ بات یہ ہے کہ یہ ﻇالم تو بغیر علم کے خواہش پرستی کر رہے ہیں، اسے کون راه دکھائے جسے اللہ تعالیٰ راه سے ہٹا دے، ان کا ایک بھی مددگار نہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxix{پس آپ یک سو ہو کر اپنا منھ دین کی طرف متوجہ کر دیں۔ اللہ تعالیٰ کی وه فطرت جس پر اس نے لوگوں کو پیدا کیا ہے، اللہ تعالیٰ کے بنائے کو بدلنا نہیں، یہی سیدھا دین ہے لیکن اکثر لوگ نہیں سمجھتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcdxl{(لوگو!) اللہ تعالیٰ کی طرف رجوع ہو کر اس سے ڈرتے رہو اور نماز کو قائم رکھو اور مشرکین میں سے نہ ہو جاؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcdxli{ان لوگوں میں سے جنہوں نے اپنے دین کو ٹکڑے ٹکڑے کر دیا اور خود بھی گروه گروه ہوگئے ہر گروه اس چیز پر جو اس کے پاس ہے مگن ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlii{لوگوں کو جب کبھی کوئی مصیبت پہنچتی ہے تو اپنے رب کی طرف (پوری طرح) رجوع ہو کر دعائیں کرتے ہیں، پھر جب وه اپنی طرف سے رحمت کاذائقہ چکھاتا ہے تو ان میں سے ایک جماعت اپنے رب کے ساتھ شرک کرنے لگتی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliii{تاکہ وه اس چیز کی ناشکری کریں جو ہم نے انہیں دی ہے اچھا تم فائده اٹھا لو! ابھی ابھی تمہیں معلوم ہو جائے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliv{کیا ہم نے ان پر کوئی دلیل نازل کی ہے جو اسے بیان کرتی ہے جسے یہ اللہ کے ساتھ شریک کر رہے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlv{اور جب ہم لوگوں کو رحمت کا مزه چکھاتے ہیں تو وه خوب خوش ہو جاتے ہیں اور اگر انہیں ان کے ہاتھوں کے کرتوت کی وجہ سے کوئی برائی پہنچے تو ایک دم وه محض ناامید ہو جاتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvi{کیا انہوں نے نہیں دیکھا کہ اللہ تعالیٰ جسے چاہے کشاده روزی دیتا ہے اور جسے چاہے تنگ، اس میں بھی ان لوگوں کے لئے جو ایمان ﻻتے ہیں نشانیاں ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvii{پس قرابت دار کو مسکین کو مسافر کو ہر ایک کو اس کا حق دیجئے، یہ ان کے لئے بہتر ہے جو اللہ تعالیٰ کا منھ دیکھنا چاہتے ہوں، ایسے ہی لوگ نجات پانے والے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlviii{تم جو سود پر دیتے ہو کہ لوگوں کے مال میں بڑھتا رہے وه اللہ تعالیٰ کے ہاں نہیں بڑھتا۔ اور جو کچھ صدقہ زکوٰة تم اللہ تعالیٰ کا منھ دیکھنے (اورخوشنودی کے لئے) دو تو ایسے لوگ ہی اپنا دو چند کرنے والے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlix{اللہ تعالیٰ وه ہے جس نے تمہیں پیدا کیا پھر روزی دی پھر مار ڈالے گا پھر زنده کر دے گا بتاؤ تمہارے شریکوں میں سے کوئی بھی ایسا ہے جو ان میں سے کچھ بھی کر سکتا ہو۔ اللہ تعالیٰ کے لئے پاکی اور برتری ہے ہر اس شریک سے جو یہ لوگ مقرر کرتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcdl{خشکی اور تری میں لوگوں کی بداعمالیوں کے باعﺚ فساد پھیل گیا۔ اس لئے کہ انہیں ان کے بعض کرتوتوں کا پھل اللہ تعالیٰ چکھا دے (بہت) ممکن ہے کہ وه باز آجائیں۔\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcdli{زمین میں چل پھر کر دیکھو تو سہی کہ اگلوں کا انجام کیا ہوا۔ جن میں اکثر لوگ مشرک تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmcdlii{پس آپ اپنا رخ اس سچے اور سیدھے دین کی طرف ہی رکھیں قبل اس کے کہ وه دن آجائے جس کا ٹل جانا اللہ تعالیٰ کی طرف سے ہے ہی نہیں، اس دن سب متفرق ہو جائیں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcdliii{کفر کرنے والوں پر ان کے کفر کا وبال ہوگا اور نیک کام کرنے والے اپنی ہی آرام گاه سنوار رہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcdliv{تاکہ اللہ تعالیٰ انہیں اپنے فضل سے جزا دے جو ایمان ﻻئے اور نیک اعمال کیے وه کافروں کو دوست نہیں رکھتا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmcdlv{اس کی نشانیوں میں سے خوشخبریاں دینے والی ہواؤں کو چلانا بھی ہے اس لئے کہ تمہیں اپنی رحمت سے لطف اندوز کرے، اور اس لئے کہ اس کے حکم سے کشتیاں چلیں، اور اس لئے کہ اس کے فضل کو تم ڈھونڈو، اور اس لئے کہ تم شکر گزاری کرو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvi{اور ہم نے آپ سے پہلے بھی اپنے رسولوں کو ان کی قوم کی طرف بھیجا وه ان کے پاس دلیلیں ﻻئے۔ پھر ہم نے گناه گاروں سے انتقام لیا۔ ہم پر مومنوں کی مدد کرنا ﻻزم ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvii{اللہ تعالیٰ ہوائیں چلاتا ہے وه ابر کو اٹھاتی ہیں پھر اللہ تعالیٰ اپنی منشا کے مطابق اسے آسمان میں پھیلا دیتا ہے اور اس کے ٹکڑے ٹکڑے کر دیتا ہے پھر آپ دیکھتے ہیں کہ اس کےاندر سے قطرے نکلتے ہیں، اور جنہیں اللہ چاہتا ہے ان بندوں پر پانی برساتا ہے تو وه خوش خوش ہو جاتے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmcdlviii{یقین ماننا کہ بارش ان پر برسنے سے پہلے پہلے تو وه ناامید ہو رہے تھے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcdlix{پس آپ رحمت الٰہی کے آﺛار دیکھیں کہ زمین کی موت کے بعد کس طرح اللہ تعالیٰ اسے زنده کر دیتا ہے؟ کچھ شک نہیں کہ وہی مردوں کو زنده کرنے واﻻ ہے، اور وه ہر ہر چیز پر قادر ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcdlx{اور اگر ہم باد تند چلا دیں اور یہ لوگ انہی کھیتوں کو (مرجھائی ہوئی) زرد پڑی ہوئی دیکھ لیں تو پھر اس کے بعد ناشکری کرنے لگیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxi{بیشک آپ مردوں کو نہیں سنا سکتے اور نہ بہروں کو (اپنی) آواز سنا سکتے ہیں جب کہ وه پیٹھ پھیر کر مڑ گئے ہوں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxii{اور نہ آپ اندھوں کو ان کی گمراہی سے ہدایت کرنے والے ہیں آپ تو صرف ان ہی لوگوں کو سناتے ہیں جو ہماری آیتوں پر ایمان رکھتے ہیں پس وہی اطاعت کرنے والے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiii{اللہ تعالیٰ وه ہے جس نے تمہیں کمزوری کی حالت میں پیدا کیا پھر اس کمزوری کے بعد توانائی دی، پھر اس توانائی کے بعد کمزوری اور بڑھاپا دیا جو چاہتا ہے پیدا کرتا ہے، وه سب سے پورا واقف اور سب پر پورا قادر ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiv{اور جس دن قیامت برپا ہو جائے گی گناه گار لوگ قسمیں کھائیں گے کہ (دنیا میں) ایک گھڑی کے سوا نہیں ٹھہرے، اسی طرح یہ بہکے ہوئے ہی رہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxv{اور جن لوگوں کو علم اور ایمان دیا گیا وه جواب دیں گے کہ تم تو جیسا کہ کتاب اللہ میں ہے یوم قیامت تک ٹھہرے رہے۔ آج کا یہ دن قیامت ہی کا دن ہے لیکن تم تو یقین ہی نہیں مانتے تھے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvi{پس اس دن ﻇالموں کو ان کا عذر بہانہ کچھ کام نہ آئے گا اور نہ ان سے توبہ اور عمل طلب کیا جائے گا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvii{بیشک ہم نےاس قرآن میں لوگوں کے سامنے کل مثالیں بیان کر دی ہیں۔ آپ ان کے پاس کوئی بھی نشانی ﻻئیں، یہ کافر تو یہی کہیں گے کہ تم (بے ہوده گو) بالکل جھوٹے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxviii{اللہ تعالیٰ ان لوگوں کے دلوں پر جو سمجھ نہیں رکھتے یوں ہی مہر کر دیتا ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxix{پس آپ صبر کریں یقیناً اللہ کا وعده سچا ہے۔ آپ کو وه لوگ ہلکا (بے صبرا) نہ کریں جویقین نہیں رکھتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxx{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxi{یہ حکمت والی کتاب کی آیتیں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxii{جو نیکو کاروں کے لئے رہبر اور (سراسر) رحمت ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiii{جو لوگ نماز قائم کرتے ہیں اور زکوٰة ادا کرتے ہیں اور آخرت پر (کامل) یقین رکھتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiv{یہی لوگ ہیں جو اپنے رب کی طرف سے ہدایت پر ہیں اور یہی لوگ نجات پانے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxv{اور بعض لوگ ایسے بھی ہیں جو لغو باتوں کو مول لیتے ہیں کہ بےعلمی کے ساتھ لوگوں کو اللہ کی راه سے بہکائیں اور اسے ہنسی بنائیں، یہی وه لوگ ہیں جن کے لئے رسوا کرنے واﻻ عذاب ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvi{جب اس کے سامنے ہماری آیتیں تلاوت کی جاتی ہیں تو تکبر کرتا ہوا اس طرح منھ پھیر لیتا ہے گویا اس نے سنا ہی نہیں گویا کہ اس کے دونوں کانوں میں ڈاٹ لگے ہوئے ہیں، آپ اسے درد ناک عذاب کی خبر سنا دیجئے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvii{بیشک جن لوگوں نےایمان قبول کیا اور کام بھی نیک (مطابق سنت) کیے ان کے لئے نعمتوں والی جنتیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxviii{جہاں وه ہمیشہ رہیں گے۔ اللہ کا سچا وعده ہے، وه بہت بڑی عزت وغلبہ واﻻ اور کامل حکمت واﻻ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxix{اسی نے آسمانوں کو بغیر ستون کے پیدا کیا ہے تم انہیں دیکھ رہے ہو اور اس نے زمین میں پہاڑوں کو ڈال دیا تاکہ وه تمہیں جنبش نہ دے سکے اور ہر طرح کے جاندار زمین میں پھیلا دیئے۔ اور ہم نے آسمان سے پانی برسا کر زمین میں ہر قسم کے نفیس جوڑے اگا دیئے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxx{یہ ہے اللہ کی مخلوق اب تم مجھے اس کے سوا دوسرے کسی کی کوئی مخلوق تو دکھاؤ (کچھ نہیں)، بلکہ یہ ﻇالم کھلی گمراہی میں ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxi{اور ہم نے یقیناً لقمان کو حکمت دی تھی کہ تو اللہ تعالیٰ کا شکر کر ہر شکر کرنے واﻻ اپنے ہی نفع کے لئے شکر کرتا ہے جو بھی ناشکری کرے وه جان لے کہ اللہ تعالیٰ بے نیاز اور تعریفوں واﻻ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxii{اور جب کہ لقمان نے وعﻆ کہتے ہوئے اپنے لڑکے سے فرمایا کہ میرے پیارے بچے! اللہ کے ساتھ شریک نہ کرنا بیشک شرک بڑا بھاری ﻇلم ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiii{ہم نے انسان کو اس کے ماں باپ کے متعلق نصیحت کی ہے، اس کی ماں نے دکھ پر دکھ اٹھا کر اسے حمل میں رکھا اور اس کی دودھ چھڑائی دو برس میں ہے کہ تو میری اور اپنے ماں باپ کی شکر گزاری کر، (تم سب کو) میری ہی طرف لوٹ کر آنا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiv{اور اگر وه دونوں تجھ پر اس بات کا دباؤ ڈالیں کہ تو میرے ساتھ شریک کرے جس کا تجھے علم نہ ہو تو تو ان کا کہنا نہ ماننا، ہاں دنیا میں ان کے ساتھ اچھی طرح بسر کرنا اور اس کی راه چلنا جو میری طرف جھکا ہوا ہو تمہارا سب کا لوٹنا میری ہی طرف ہے تم جو کچھ کرتے ہو اس سے پھر میں تمہیں خبردار کروں گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxv{پیارے بیٹے! اگر کوئی چیز رائی کے دانے کے برابر ہو پھر وه (بھی) خواه کسی چٹان میں ہو یا آسمانوں میں ہو یا زمین میں ہو اسے اللہ تعالیٰ ضرور ﻻئے گا اللہ تعالیٰ بڑا باریک بین اور خبردار ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvi{اے میرے پیارے بیٹے! تو نماز قائم رکھنا، اچھے کاموں کی نصیحت کرتے رہنا، برے کاموں سے منع کیا کرنا اور جو مصیبت تم پر آجائے صبر کرنا (یقین مانو) کہ یہ بڑے تاکیدی کاموں میں سے ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvii{لوگوں کے سامنے اپنے گال نہ پھلا اور زمین پر اترا کر نہ چل کسی تکبر کرنے والے شیخی خورے کو اللہ تعالیٰ پسند نہیں فرماتا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxviii{اپنی رفتار میں میانہ روی اختیار کر، اور اپنی آواز پست کر یقیناً آوازوں میں سب سے بدتر آواز گدھوں کی آواز ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxix{کیا تم نہیں دیکھتے کہ اللہ تعالیٰ نے زمین وآسمان کی ہر چیز کو ہمارے کام میں لگا رکھا ہے اور تمہیں اپنی ﻇاہری وباطنی نعمتیں بھرپور دے رکھی ہیں، بعض لوگ اللہ کے بارے میں بغیر علم کے اور بغیر ہدایت کے اور بغیر روشن کتاب کے جھگڑا کرتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxc{اور جب ان سے کہا جاتا ہے کہ اللہ تعالیٰ کی اتاری ہوئی وحی کی تابعداری کرو تو کہتے ہیں کہ ہم نے تو جس طریق پر اپنے باپ دادوں کو پایا ہے اسی کی تابعداری کریں گے، اگرچہ شیطان ان کے بڑوں کو دوزخ کےعذاب کی طرف بلاتا ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxci{اور جو (شخص) اپنے آپ کو اللہ کے تابع کردے اور ہو بھی وه نیکو کار یقیناً اس نے مضبوط کڑا تھام لیا، تمام کاموں کا انجام اللہ کی طرف ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcii{کافروں کے کفر سے آپ رنجیده نہ ہوں، آخر ان سب کو لوٹنا تو ہماری جانب ہی ہے پھر ہم ان کو بتائیں گے جو انہوں نے کیا ہے، بے شک اللہ سینوں کے بھیدوں تک سے واقف ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciii{ہم انہیں گو کچھ یونہی سا فائده دے دیں لیکن (بالﺂخر) ہم انہیں نہایت بیچارگی کی حالت میں سخت عذاب کی طرف ہنکا لے جائیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciv{اگر آپ ان سے دریافت کریں کہ آسمان وزمین کا خالق کون ہے؟ تو یہ ضرور جواب دیں گے کہ اللہ، تو کہہ دیجئے کہ سب تعریفوں کے ﻻئق اللہ ہی ہے، لیکن ان میں کے اکثر بے علم ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcv{آسمانوں میں اور زمین میں جو کچھ ہے وه سب اللہ ہی کا ہے یقیناً اللہ تعالیٰ بہت بڑا بے نیاز اور سزاوار حمد وﺛنا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvi{روئے زمین کے (تمام) درختوں کے اگر قلمیں ہو جائیں اور تمام سمندروں کی سیاہی ہو اور ان کے بعد سات سمندر اور ہوں تاہم اللہ کے کلمات ختم نہیں ہو سکتے، بیشک اللہ تعالیٰ غالب اور باحکمت ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvii{تم سب کی پیدائش اور مرنے کے بعد جلانا ایسا ہی ہے جیسے ایک جی کا، بیشک اللہ تعالیٰ سننے واﻻ دیکھنے واﻻ ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcviii{کیا آپ نہیں دیکھتے کہ اللہ تعالیٰ رات کو دن میں اور دن کو رات میں کھپا دیتا ہے، سورج چاند کو اسی نے فرماں بردار کر رکھا ہے ہر ایک مقرره وقت تک چلتا رہے، اللہ تعالیٰ ہر اس چیز سے جو تم کرتے ہو خبردار ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcix{یہ سب (انتظامات) اس وجہ سے ہیں کہ اللہ تعالیٰ حق ہے اور اس کے سوا جن جن کو لوگ پکارتے ہیں سب باطل ہیں اور یقیناً اللہ تعالیٰ بہت بلندیوں واﻻ اور بڑی شان واﻻ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmd{کیا تم اس پر غور نہیں کرتے کہ دریا میں کشتیاں اللہ کے فضل سے چل رہی ہیں اس لئے کہ وه تمہیں اپنی نشانیاں دکھاوے، یقیناً اس میں ہر ایک صبر وشکر کرنے والے کے لئے بہت سی نشانیاں ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdi{اور جب ان پر موجیں سائبانوں کی طرح چھا جاتی ہیں تو وه (نہایت) خلوص کے ساتھ اعتقاد کر کے اللہ تعالیٰ ہی کو پکارتے ہیں۔ پھر جب وه (باری تعالیٰ) انہیں نجات دے کر خشکی کی طرف پہنچاتا ہے تو کچھ ان میں سے اعتدال پر رہتے ہیں، اور ہماری آیتوں کا انکار صرف وہی کرتے ہیں جو بدعہد اور ناشکرے ہوں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdii{لوگو! اپنے رب سے ڈرو اور اس دن کا خوف کرو جس دن باپ اپنے بیٹے کو کوئی نفع نہ پہنچا سکے گا اور نہ بیٹا اپنے باپ کا ذرا سا بھی نفع کرنے واﻻ ہوگا (یاد رکھو) اللہ کا وعده سچا ہے (دیکھو) تمہیں دنیا کی زندگی دھوکے میں نہ ڈالے اور نہ دھوکے باز (شیطان) تمہیں دھوکے میں ڈال دے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdiii{بے شک اللہ تعالیٰ ہی کے پاس قیامت کا علم ہے وہی بارش نازل فرماتا ہے اور ماں کے پیٹ میں جو ہے اسے جانتا ہے۔ کوئی (بھی) نہیں جانتا کہ کل کیا (کچھ) کرے گا؟ نہ کسی کو یہ معلوم ہے کہ کس زمین میں مرے گا۔ (یاد رکھو) اللہ تعالیٰ ہی پورے علم واﻻ اور صحیح خبروں واﻻ ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdiv{\basmalahur الم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdv{بلاشبہ اس کتاب کا اتارنا تمام جہانوں کے پروردگار کی طرف سے ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdvi{کیا یہ کہتے ہیں کہ اس نے اسے گھڑ لیا ہے۔ (نہیں نہیں) بلکہ یہ تیرے رب تعالیٰ کی طرف سے حق ہے تاکہ آپ انہیں ڈرائیں جن کے پاس آپ سے پہلے کوئی ڈرانے واﻻ نہیں آیا۔ تاکہ وه راه راست پر آجائیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdvii{اللہ تعالیٰ وه ہے جس نے آسمان وزمین کو اور جو کچھ ان کے درمیان ہے سب کو چھ دن میں پیدا کر دیا پھر عرش پر قائم ہوا، تمہارے لئے اس کے سوا کوئی مددگار اور سفارشی نہیں۔ کیا پھر بھی تم نصیحت حاصل نہیں کرتے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdviii{وه آسمان سے لے کر زمین تک (ہر) کام کی تدبیر کرتا ہے۔ پھر (وه کام) ایک ایسے دن میں اس کی طرف چڑھ جاتا ہے جس کا اندازه تمہاری گنتی کے ایک ہزار سال کے برابر ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdix{یہی ہے چھپے کھلے کا جاننے واﻻ، زبردست غالب بہت ہی مہربان\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdx{جس نے نہایت خوب بنائی جو چیز بھی بنائی اور انسان کی بناوٹ مٹی سے شروع کی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxi{پھر اس کی نسل ایک بے وقعت پانی کے نچوڑ سے چلائی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxii{جسے ٹھیک ٹھاک کر کے اس میں اپنی روح پھونکی، اسی نے تمہارے کان آنکھیں اور دل بنائے (اس پر بھی) تم بہت ہی تھوڑا احسان مانتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxiii{انہوں نے کہا کیا جب ہم زمین میں مل جائیں گے کیا پھر نئی پیدائش میں آجائیں گے؟ بلکہ (بات یہ ہے) کہ وه لوگ اپنے پروردگار کی ملاقات کے منکر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxiv{کہہ دیجئے! کہ تمہیں موت کا فرشتہ فوت کرے گا جو تم پر مقرر کیا گیا ہے پھر تم سب اپنے پروردگار کی طرف لوٹائے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxv{کاش کہ آپ دیکھتے جب کہ گناه گار لوگ اپنے رب تعالیٰ کے سامنے سر جھکائے ہوئے ہوں گے، کہیں گے اے ہمارے رب! ہم نے دیکھ لیا اور سن لیا اب تو ہمیں واپس لوٹا دے ہم نیک اعمال کریں گے ہم یقین کرنے والے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxvi{اگر ہم چاہتے تو ہر شخص کو ہدایت نصیب فرما دیتے، لیکن میری یہ بات بالکل حق ہو چکی ہے کہ میں ضرور ضرور جہنم کو انسانوں اور جنوں سے پر کردوں گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxvii{اب تم اپنے اس دن کی ملاقات کے فراموش کر دینے کا مزه چکھو، ہم نے بھی تمہیں بھلا دیا اور اپنے کیے ہوئے اعمال (کی شامت) سے ابدی عذاب کا مزه چکھو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxviii{ہماری آیتوں پر وہی ایمان ﻻتے ہیں جنہیں جب کبھی ان سے نصیحت کی جاتی ہے تو وه سجدے میں گر پڑتے ہیں اور اپنے رب کی حمد کے ساتھ اس کی تسبیح پڑھتے ہیں اور تکبر نہیں کرتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxix{ان کی کروٹیں اپنے بستروں سے الگ رہتی ہیں اپنے رب کو خوف اور امید کے ساتھ پکارتے ہیں اور جو کچھ ہم نے انہیں دے رکھا ہے وه خرچ کرتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdxx{کوئی نفس نہیں جانتا جو کچھ ہم نے ان کی آنکھوں کی ٹھنڈک ان کے لئے پوشیده کر رکھی ہے، جو کچھ کرتے تھے یہ اس کا بدلہ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdxxi{کیا وه جو مومن ہو مثل اس کے ہے جو فاسق ہو؟ یہ برابر نہیں ہو سکتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdxxii{جن لوگوں نے ایمان قبول کیا اور نیک اعمال بھی کیے ان کے لئے ہمیشگی والی جنتیں ہیں، مہمانداری ہے ان کے اعمال کے بدلے جو وه کرتے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiii{لیکن جن لوگوں نے حکم عدولی کی ان کا ٹھکانا دوزخ ہے۔ جب کبھی اس سے باہر نکلنا چاہیں گے اسی میں لوٹا دیئے جائیں گے۔ اور کہہ دیا جائے گا کہ اپنے جھٹلانے کے بدلے آگ کا عذاب چکھو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiv{بالیقین ہم انہیں قریب کے چھوٹے سے بعض عذاب اس بڑے عذاب کے سوا چکھائیں گے تاکہ وه لوٹ آئیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdxxv{اس سے بڑھ کر ﻇالم کون ہے جسے اللہ تعالیٰ کی آیتوں سے وعﻆ کیا گیا پھر بھی اس نے ان سے منھ پھیر لیا، (یقین مانو) کہ ہم بھی گناه گاروں سے انتقام لینے والے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvi{بیشک ہم نے موسیٰ کو کتاب دی، پس آپ کو ہرگز اس کی ملاقات میں شک نہ کرنا چاہئے اور ہم نے اسے بنی اسرائیل کی ہدایت کا ذریعہ بنایا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvii{اور جب ان لوگوں نے صبر کیا تو ہم نے ان میں سے ایسے پیشوا بنائے جو ہمارے حکم سے لوگوں کو ہدایت کرتے تھے، اور وه ہماری آیتوں پر یقین رکھتے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdxxviii{آپ کا رب ان (سب) کے درمیان ان (تمام) باتوں کا فیصلہ قیامت کے دن کرے گا جن میں وه اختلاف کر رہے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdxxix{کیا اس بات نے بھی انہیں ہدایت نہیں دی کہ ہم نے ان سے پہلے بہت سی امتوں کو ہلاک کر دیا جن کے مکانوں میں یہ چل پھر رہے ہیں۔ اس میں تو (بڑی) بڑی نشانیاں ہیں۔ کیا پھر بھی یہ نہیں سنتے؟\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdxxx{کیا یہ نہیں دیکھتے کہ ہم پانی کو بنجر (غیر آباد) زمین کی طرف بہا کر لے جاتے ہیں پھر اس سے ہم کھیتیاں نکالتے ہیں جسے ان کے چوپائے اور یہ خود کھاتے ہیں، کیا پھر بھی یہ نہیں دیکھتے؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxi{اور کہتے ہیں کہ یہ فیصلہ کب ہوگا؟ اگر تم سچے ہو (تو بتلاؤ)\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxii{جواب دے دو کہ فیصلے والے دن ایمان ﻻنا بے ایمانوں کو کچھ کام نہ آئے گا اور نہ انہیں ڈھیل دی جائے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiii{اب آپ ان کا خیال چھوڑ دیں اور منتظر رہیں۔ یہ بھی منتظر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiv{\basmalahur اے نبی! اللہ تعالیٰ سے ڈرتے رہنا اور کافروں اور منافقوں کی باتوں میں نہ آجانا، اللہ تعالیٰ بڑے علم واﻻ اور بڑی حکمت واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxv{جو کچھ آپ کی جانب آپ کے رب کی طرف سے وحی کی جاتی ہے اس کی تابعداری کریں (یقین مانو) کہ اللہ تمہارے ہر ایک عمل سے باخبر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvi{آپ اللہ ہی پر توکل رکھیں، وه کار سازی کے لئے کافی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvii{کسی آدمی کے سینے میں اللہ تعالیٰ نے دو دل نہیں رکھے، اور اپنی جن بیویوں کو تم ماں کہہ بیٹھتے ہو انہیں اللہ نے تمہاری (سچ مچ کی) مائیں نہیں بنایا، اور نہ تمہارے لے پالک لڑکوں کو (واقعی) تمہارے بیٹے بنایا ہے، یہ تو تمہارے اپنے منھ کی باتیں ہیں، اللہ تعالیٰ حق بات فرماتا ہے اور وه (سیدھی) راه سجھاتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxviii{لے پالکوں کو ان کے (حقیقی) باپوں کی طرف نسبت کر کے بلاؤ اللہ کے نزدیک پورا انصاف یہی ہے۔ پھر اگر تمہیں ان کے (حقیقی) باپوں کا علم ہی نہ ہو تو وه تمہارے دینی بھائی اور دوست ہیں، تم سے بھول چوک میں جو کچھ ہو جائے اس میں تم پر کوئی گناه نہیں، البتہ گناه وه ہے جس کا تم اراده دل سے کرو۔ اللہ تعالیٰ بڑا ہی بخشنے واﻻ مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxix{پیغمبر مومنوں پر خود ان سے بھی زیاده حق رکھنے والے ہیں اور پیغمبر کی بیویاں مومنوں کی مائیں ہیں، اور رشتے دار کتاب اللہ کی رو سے بہ نسبت دوسرے مومنوں اور مہاجروں کے آپس میں زیاده حق دار ہیں (ہاں) مگر یہ کہ تم اپنے دوستوں کے ساتھ حسن سلوک کرنا چاہو۔ یہ حکم کتاب (الٰہی) میں لکھا ہوا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdxl{جب کہ ہم نے تمام نبیوں سے عہد لیا اور (بالخصوص) آپ سے اور نوح سے اور ابراہیم سے اور موسیٰ سے اور مریم کے بیٹے عیسیٰ سے، اور ہم نے ان سے (پکا اور) پختہ عہد لیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxli{تاکہ اللہ تعالیٰ سچوں سے ان کی سچائی کے بارے میں دریافت فرمائے، اور کافروں کے لئے ہم نے المناک عذاب تیار کر رکھے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxlii{اے ایمان والو! اللہ تعالیٰ نے جو احسان تم پر کیا اسے یاد کرو جبکہ تمہارے مقابلے کو فوجوں پر فوجیں آئیں پھر ہم نے ان پر تیز وتند آندھی اور ایسے لشکر بھیجے جنہیں تم نے دیکھا ہی نہیں، اور جو کچھ تم کرتے ہو اللہ تعالیٰ سب کچھ دیکھتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxliii{جب کہ (دشمن) تمہارے پاس اوپر سے اور نیچے سے چڑھ آئے اور جب کہ آنکھیں پتھرا گئیں اور کلیجے منھ کو آگئے اور تم اللہ تعالیٰ کی نسبت طرح طرح کے گمان کرنے لگے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxliv{یہیں مومن آزمائے گئے اور پوری طرح وه جھنجھوڑ دیئے گئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxlv{اور اس وقت منافق اور وه لوگ جن کے دلوں میں (شک کا) روگ تھا کہنے لگے اللہ تعالیٰ اور اس کے رسول نے ہم سے محض دھوکا فریب کا ہی وعده کیا تھا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvi{ان ہی کی ایک جماعت نے ہانک لگائی کہ اے مدینہ والو! تمہارے لئے ٹھکانہ نہیں چلو لوٹ چلو، اور ان کی ایک اور جماعت یہ کہہ کر نبی ﴿صلی اللہ علیہ وسلم﴾ سے اجازت مانگنے لگی کہ ہمارے گھر غیر محفوظ ہیں، حاﻻنکہ وه (کھلے ہوئے اور) غیر محفوظ نہ تھے (لیکن) ان کا پختہ اراده بھاگ کھڑے ہونے کا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvii{اور اگر مدینے کے اطراف سے ان پر (لشکر) داخل کیے جاتے پھر ان سے فتنہ طلب کیا جاتا تو یہ ضرور اسے برپا کر دیتے اور نہ لڑتے مگر تھوڑی مدت\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxlviii{اس سے پہلے تو انہوں نے اللہ سے عہد کیا تھا کہ پیٹھ نہ پھیریں گے، اور اللہ تعالیٰ سے کیے ہوئے وعده کی باز پرس ضرور ہوگی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxlix{کہہ دیجئے کہ گو تم موت سے یا خوف قتل سے بھاگو تو یہ بھاگنا تمہیں کچھ بھی کام نہ آئے گا اور اس وقت تم بہت ہی کم فائده اٹھاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdl{پوچھیئے! تو کہ اگر اللہ تعالیٰ تمہیں کوئی برائی پہنچانا چاہے یا تم پر کوئی فضل کرنا چاہے تو کون ہے جو تمہیں بچا سکے (یا تم سے روک سکے؟)، اپنے لیے بجز اللہ تعالیٰ کے نہ کوئی حمایتی پائیں گے نہ مددگار\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdli{اللہ تعالیٰ تم میں سے انہیں (بخوبی) جانتا ہے جو دوسروں کو روکتے ہیں اور اپنے بھائی بندوں سے کہتے ہیں کہ ہمارے پاس چلے آؤ۔ اور کبھی کبھی ہی لڑائی میں آجاتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdlii{تمہاری مدد میں (پورے) بخیل ہیں، پھر جب خوف ودہشت کا موقعہ آجائے تو آپ انہیں دیکھیں گے کہ آپ کی طرف نظریں جما دیتے ہیں اور ان کی انکھیں اس طرح گھومتی ہیں جیسے اس شخص کی جس پر موت کی غشی طاری ہو۔ پھر جب خوف جاتا رہتا ہے تو تم پر اپنی تیز زبانوں سے بڑی باتیں بناتے ہیں مال کے بڑے ہی حریص ہیں، یہ ایمان ﻻئے ہی نہیں ہیں اللہ تعالیٰ نے ان کے تمام اعمال نابود کر دیئے ہیں، اور اللہ تعالیٰ پر یہ بہت ہی آسان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdliii{سمجھتے ہیں کہ اب تک لشکر چلے نہیں گئے، اور اگر فوجیں آجائیں تو تمنائیں کرتے ہیں کہ کاش! وه صحرا میں بادیہ نشینوں کے ساتھ ہوتے کہ تمہاری خبریں دریافت کیا کرتے، اگر وه تم میں موجود ہوتے (تو بھی کیا؟) نہ لڑتے مگر برائے نام\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdliv{یقیناً تمہارے لئے رسول اللہ میں عمده نمونہ (موجود) ہے، ہر اس شخص کے لئے جو اللہ تعالیٰ کی اور قیامت کے دن کی توقع رکھتا ہے اور بکثرت اللہ تعالیٰ کی یاد کرتا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdlv{اور ایمان والوں نے جب (کفار کے) لشکروں کو دیکھا (بے ساختہ) کہہ اٹھے! کہ انہیں کا وعده ہمیں اللہ تعالیٰ نے اور اس کے رسول نے دیا تھا اور اللہ تعالیٰ اور اس کے رسول نے سچ فرمایا، اور اس (چیز) نے ان کے ایمان میں اور شیوہٴ فرماں برداری میں اور اضافہ کر دیا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdlvi{مومنوں میں (ایسے) لوگ بھی ہیں جنہوں نے جو عہد اللہ تعالیٰ سے کیا تھا انہیں سچا کر دکھایا، بعض نے تو اپنا عہد پورا کر دیا اور بعض (موقعہ کے) منتظر ہیں اور انہوں نے کوئی تبدیلی نہیں کی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdlvii{تاکہ اللہ تعالیٰ سچوں کو ان کی سچائی کا بدلہ دے اور اگر چاہے تو منافقوں کو سزا دے یا ان کی توبہ قبول فرمائے، اللہ تعالیٰ بڑا ہی بخشنے واﻻ بہت ہی مہربان ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdlviii{اور اللہ تعالیٰ نےکافروں کو غصے بھرے ہوئے ہی (نامراد) لوٹا دیا انہوں نے کوئی فائده نہیں پایا، اور اس جنگ میں اللہ تعالیٰ خود ہی مومنوں کو کافی ہوگیا اللہ تعالیٰ بڑی قوتوں واﻻ اور غالب ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdlix{اور جن اہل کتاب نے ان سے سازباز کر لی تھی انہیں (بھی) اللہ تعالیٰ نے ان کے قلعوں سے نکال دیا اور ان کے دلوں میں (بھی) رعب بھر دیا کہ تم ان کے ایک گروه کو قتل کر رہے ہو اور ایک گروه کو قیدی بنا رہے ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdlx{اور اس نے تمہیں ان کی زمینوں کا اور ان کے گھر بار کا اور ان کے مال کا وارث کر دیا اور اس زمین کا بھی جس کو تمہارے قدموں نے روندا نہیں، اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdlxi{اے نبی! اپنی بیویوں سے کہہ دو کہ اگر تم زندگانی دنیا اور زینت دنیا چاہتی ہو تو آؤ میں تمہیں کچھ دے دﻻ دوں اور تمہیں اچھائی کے ساتھ رخصت کر دوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdlxii{اور اگر تمہاری مراد اللہ اور اس کا رسول اور آخرت کا گھر ہے تو (یقین مانو کہ) تم میں سے نیک کام کرنے والیوں کے لئے اللہ تعالیٰ نے بہت زبردست اجر رکھ چھوڑے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiii{اے نبی کی بیویو! تم میں سے جو بھی کھلی بے حیائی (کا ارتکاب) کرے گی اسے دوہرا دوہرا عذاب دیا جائے گا، اور اللہ تعالیٰ کے نزدیک یہ بہت ہی سہل (سی بات) ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiv{اور تم میں سے جو کوئی اللہ کی اور اس کے رسول کی فرمانبرداری کرے گی اور نیک کام کرے گی ہم اسے اجر (بھی) دوہرا دیں گے اور اس کے لئے ہم نے بہترین روزی تیار کر رکھی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdlxv{اے نبی کی بیویو! تم عام عورتوں کی طرح نہیں ہو، اگر تم پرہیزگاری اختیار کرو تو نرم لہجے سے بات نہ کرو کہ جس کے دل میں روگ ہو وه کوئی برا خیال کرے اور ہاں قاعدے کے مطابق کلام کرو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvi{اور اپنے گھروں میں قرار سے رہو اور قدیم جاہلیت کے زمانے کی طرح اپنے بناؤ کا اﻇہار نہ کرو اور نماز ادا کرتی رہو اور زکوٰة دیتی رہو اور اللہ اور اس کے رسول کی اطاعت گزاری کرو۔ اللہ تعالیٰ یہی چاہتا ہے کہ اے نبی کی گھر والیو! تم سے وه (ہر قسم کی) گندگی کو دور کردے اور تمہیں خوب پاک کردے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvii{اور تمہارے گھروں میں اللہ کی جو آیتیں اور رسول کی احادیﺚ پڑھی جاتی ہیں ان کا ذکر کرتی رہو، یقیناً اللہ تعالیٰ لطف کرنے واﻻ خبردار ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdlxviii{بےشک مسلمان مرد اور مسلمان عورتیں مومن مرد اور مومن عورتیں فرماں برداری کرنے والے مرد اور فرمانبردار عورتیں راست باز مرد اور راست باز عورتیں صبر کرنے والے مرد اور صبر کرنے والی عورتیں، عاجزی کرنے والے مرد اور عاجزی کرنے والی عورتیں، خیرات کرنے والے مرد اور خیرات کرنے والی عورتیں، روزے رکھنے والے مرد اور روزے رکھنے والی عورتیں اپنی شرمگاه کی حفاﻇت کرنے والے مرد اور حفاﻇت کرنے والیاں بکثرت اللہ کا ذکر کرنے والے اور ذکر کرنے والیاں ان (سب کے) لئے اللہ تعالیٰ نے (وسیع) مغفرت اور بڑا ﺛواب تیار کر رکھا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdlxix{اور (دیکھو) کسی مومن مرد و عورت کو اللہ اور اس کے رسول کا فیصلہ کے بعد اپنے کسی امر کا کوئی اختیار باقی نہیں رہتا، (یاد رکھو) اللہ تعالیٰ اور اس کے رسول کی جو بھی نافرمانی کرے گا وه صریح گمراہی میں پڑے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdlxx{(یاد کرو) جب کہ تو اس شخص سے کہہ رہا تھا جس پر اللہ نے بھی انعام کیا اور تو نے بھی کہ تو اپنی بیوی کو اپنے پاس رکھ اور اللہ سے ڈر اور تو اپنے دل میں وه بات چھپائے ہوئے تھا جسے اللہ ﻇاہر کرنے واﻻ تھا اور تو لوگوں سے خوف کھاتا تھا، حاﻻنکہ اللہ تعالیٰ اس کا زیاده حق دار تھا کہ تو اس سے ڈرے، پس جب کہ زید نے اس عورت سے اپنی غرض پوری کرلی ہم نے اسے تیرے نکاح میں دے دیا تاکہ مسلمانوں پر اپنے لے پالکوں کی بیویوں کے بارے میں کسی طرح کی تنگی نہ رہے جب کہ وه اپنی غرض ان سے پوری کرلیں، اللہ کا (یہ) حکم تو ہو کر ہی رہنے واﻻ تھا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxi{جو چیزیں اللہ تعالیٰ نے اپنے نبی کے لئے مقرر کی ہیں ان میں نبی پر کوئی حرج نہیں، (یہی) اللہ کا دستور ان میں بھی رہا جو پہلے ہوئے اور اللہ تعالیٰ کے کام اندازے پر مقرر کئے ہوئے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxii{یہ سب ایسے تھے کہ اللہ تعالیٰ کے احکام پہنچایا کرتے تھے اور اللہ ہی سے ڈرتے تھے اور اللہ کے سوا کسی سے نہیں ڈرتے تھے، اور اللہ تعالیٰ حساب لینے کے لئے کافی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiii{(لوگو) تمہارے مردوں میں سے کسی کے باپ محمد ﴿صلی اللہ علیہ وسلم﴾ نہیں لیکن آپ اللہ تعالیٰ کے رسول ہیں اور تمام نبیوں کے ختم کرنے والے، اور اللہ تعالی ہر چیز کا (بخوبی) جاننے واﻻ ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiv{مسلمانو! اللہ تعالیٰ کا ذکر بہت زیاده کرو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxv{اور صبح وشام اس کی پاکیزگی بیان کرو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvi{وہی ہے جو تم پر اپنی رحمتیں بھیجتا ہے اور اس کے فرشتے (تمہارے لئے دعائے رحمت کرتے ہیں) تاکہ وه تمہیں اندھیروں سے اجالے کی طرف لے جائے اور اللہ تعالیٰ مومنوں پر بہت ہی مہربان ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvii{جس دن یہ (اللہ سے) ملاقات کریں گے ان کا تحفہ سلام ہوگا، ان کے لئے اللہ تعالیٰ نے باعزت اجر تیار کر رکھا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxviii{اے نبی! یقیناً ہم نے ہی آپ کو (رسول بنا کر) گواہیاں دینے واﻻ، خوشخبریاں سنانے واﻻ، آگاه کرنے واﻻ بھیجا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxix{اور اللہ کے حکم سے اس کی طرف بلانے واﻻ اور روشن چراغ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxx{آپ مومنوں کو خوشخبری سنا دیجئے! کہ ان کے لئے اللہ کی طرف سے بہت بڑا فضل ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxi{اور کافروں اور منافقوں کا کہنا نہ مانیئے! اور جو ایذا (ان کی طرف سے پہنچے) اس کا خیال بھی نہ کیجیئے اللہ پر بھروسہ کئے رہیں، اور کافی ہے اللہ تعالیٰ کام بنانے واﻻ\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxii{اے مومنو! جب تم مومن عورتوں سے نکاح کرو پھر ہاتھ لگانے سے پہلے (ہی) طلاق دے دو تو ان پر تمہارا کوئی حق عدت کا نہیں جسے تم شمار کرو، پس تم کچھ نہ کچھ انہیں دے دو اور بھلے طریق پر انہیں رخصت کر دو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiii{اے نبی! ہم نے تیرے لئے تیری وه بیویاں حلال کر دی ہیں جنہوں تو ان کا مہر دے چکا ہے اور وه لونڈیاں بھی جو اللہ تعالیٰ نے غنیمت میں تجھے دی ہیں اور تیرے چچا کی لڑکیاں اور پھوپھیوں کی بیٹیاں اور تیرے ماموں کی بیٹیاں اور تیری خاﻻؤں کی بیٹیاں بھی جنہوں نے تیرے ساتھ ہجرت کی ہے، اور وه باایمان عورت جو اپنا نفس نبی کو ہبہ کردے یہ اس صورت میں کہ خود نبی بھی اس سے نکاح کرنا چاہے، یہ خاص طور پر صرف تیرے لئے ہی ہے اور مومنوں کے لئے نہیں، ہم اسے بخوبی جانتے ہیں جو ہم نے ان پر ان کی بیویوں اور لونڈیوں کے بارے میں (احکام) مقرر کر رکھے ہیں، یہ اس لئے کہ تجھ پر حرج واقع نہ ہو، اللہ تعالیٰ بہت بخشنے اور بڑے رحم واﻻ ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiv{ان میں سے جسے تو چاہے دور رکھ دے اور جسے چاہے اپنے پاس رکھ لے، اور اگر تو نے ان میں سے بھی کسی کو اپنے پاس بلالے جنہیں تو نے الگ کر رکھا تھا تو تجھ پر کوئی گناه نہیں، اس میں اس بات کی زیاده توقع ہے کہ ان عورتوں کی آنکھیں ٹھنڈی رہیں اور وه رنجیده نہ ہوں اور جو کچھ بھی تو انہیں دے دے اس پر سب کی سب راضی رہیں۔ تمہارے دلوں میں جو کچھ ہے اسے اللہ (خوب) جانتا ہے۔ اللہ تعالیٰ بڑا ہی علم اور حلم واﻻ ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxv{اس کے بعد اور عورتیں آپ کے لئے حلال نہیں اور نہ یہ (درست ہے) کہ ان کے بدلے اور عورتوں سے (نکاح کرے) اگر چہ ان کی صورت اچھی بھی لگتی ہو مگر جو تیری مملوکہ ہوں۔ اور اللہ تعالیٰ ہر چیز کا (پورا) نگہبان ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvi{اے ایمان والو! جب تک تمہیں اجازت نہ دی جائے تم نبی کے گھروں میں نہ جایا کرو کھانے کے لئے ایسے وقت میں کہ اس کے پکنے کا انتظار کرتے رہو بلکہ جب بلایا جائے جاؤ اور جب کھا چکو نکل کھڑے ہو، وہیں باتوں میں مشغول نہ ہوجایا کرو۔ نبی کو تمہاری اس بات سے تکلیف ہوتی ہے۔ تو وه لحاظ کر جاتے ہیں اور اللہ تعالیٰ (بیان) حق میں کسی کا لحاظ نہیں کرتا، جب تم نبی کی بیویوں سے کوئی چیز طلب کرو تو پردے کے پیچھے سے طلب کرو۔ تمہارے اور ان کے دلوں کے لئے کامل پاکیزگی یہی ہے، نہ تمہیں یہ جائز ہے کہ تم رسول اللہ کو تکلیف دو اور نہ تمہیں یہ حلال ہے کہ آپ کے بعد کسی وقت بھی آپ کی بیویوں سے نکاح کرو۔ (یاد رکھو) اللہ کے نزدیک یہ بہت بڑا (گناه) ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvii{تم کسی چیز کو ﻇاہر کرو یا مخفی رکھو اللہ تو ہر ہر چیز کا بخوبی علم رکھنے واﻻ ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxviii{ان عورتوں پر کوئی گناه نہیں کہ وه اپنے باپوں اور اپنے بیٹوں اور بھائیوں اور بھتیجوں اور بھانجوں اور اپنی (میل جول کی) عورتوں اور ملکیت کے ماتحتوں (لونڈی، غلام) کے سامنے ہوں۔ (عورتو!) اللہ سے ڈرتی رہو۔ اللہ تعالیٰ یقیناً ہر چیز پر شاہد ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxix{اللہ تعالیٰ اور اس کے فرشتے اس نبی پر رحمت بھیجتے ہیں۔ اے ایمان والو! تم (بھی) ان پر درود بھیجو اور خوب سلام (بھی) بھیجتے رہا کرو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdxc{جو لوگ اللہ اور اس کے رسول کو ایذا دیتے ہیں ان پر دنیا اور آخرت میں اللہ کی پھٹکار ہے اور ان کے لئے نہایت رسوا کن عذاب ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdxci{اور جو لوگ مومن مردوں اور مومن عورتوں کو ایذا دیں بغیر کسی جرم کے جو ان سے سرزد ہوا ہو، وه (بڑے ہی) بہتان اور صریح گناه کا بوجھ اٹھاتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdxcii{اے نبی! اپنی بیویوں سے اور اپنی صاحبزادیوں سے اور مسلمانوں کی عورتیں سے کہہ دو کہ وه اپنے اوپر اپنی چادریں لٹکا لیا کریں، اس سے بہت جلد ان کی شناخت ہو جایا کرے گی پھر نہ ستائی جائیں گی، اور اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdxciii{اگر (اب بھی) یہ منافق اور وه جن کے دلوں میں بیماری ہے اور وه لوگ جو مدینہ میں غلط افواہیں اڑانے والے ہیں باز نہ آئے تو ہم آپ کو ان (کی تباہی) پر مسلط کردیں گے پھر تو وه چند دن ہی آپ کے ساتھ اس (شہر) میں ره سکیں گے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdxciv{ان پر پھٹکار برسائی گئی، جہاں بھی مل جائیں پکڑے جائیں اور خوب ٹکڑے ٹکڑے کردیئے جائیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdxcv{ان سے اگلوں میں بھی اللہ کا یہی دستور جاری رہا۔ اور تو اللہ کے دستور میں ہرگز ردوبدل نہ پائے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvi{لوگ آپ سے قیامت کے بارے میں سوال کرتے ہیں۔ آپ کہہ دیجیئے! کہ اس کا علم تو اللہ ہی کو ہے، آپ کو کیا خبر بہت ممکن ہے قیامت بالکل ہی قریب ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvii{اللہ تعالیٰ نے کافروں پر لعنت کی ہے اور ان کے لئے بھڑکتی ہوئی آگ تیار کر رکھی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdxcviii{جس میں وه ہمیشہ ہمیشہ رہیں گے۔ وه کوئی حامی ومددگار نہ پائیں گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdxcix{اس دن ان کے چہرے آگ میں الٹ پلٹ کئے جائیں گے۔ (حسرت وافسوس سے) کہیں گے کہ کاش ہم اللہ تعالیٰ اور رسول کی اطاعت کرتے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdc{اور کہیں گے اے ہمارے رب! ہم نے اپنے سرداروں اور اپنے بڑوں کی مانی جنہوں نے ہمیں راه راست سے بھٹکا دیا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdci{پروردگار تو انہیں دگنا عذاب دے اور ان پر بہت بڑی لعنت نازل فرما\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcii{اے ایمان والو! ان لوگوں جیسے نہ بن جاؤ جنہوں نے موسیٰ کو تکلیف دی پس جو بات انہوں نے کہی تھی اللہ نے انہیں اس سے بری فرما دیا، اور وه اللہ کے نزدیک باعزت تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdciii{اے ایمان والو! اللہ تعالیٰ سے ڈرو اور سیدھی سیدھی (سچی) باتیں کیا کرو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdciv{تاکہ اللہ تعالیٰ تمہارے کام سنوار دے اور تمہارے گناه معاف فرما دے، اور جو بھی اللہ اور اس کے رسول کی تابعداری کرے گا اس نے بڑی مراد پالی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcv{ہم نے اپنی امانت کو آسمانوں پر زمین پر اور پہاڑوں پر پیش کیا لیکن سب نے اس کے اٹھانے سے انکار کردیا اور اس سے ڈر گئے (مگر) انسان نے اسے اٹھا لیا، وه بڑا ہی ﻇالم جاہل ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcvi{(یہ اس لئے) کہ اللہ تعالیٰ منافق مردوں عورتوں اور مشرک مردوں عورتوں کو سزا دے اور مومن مردوں عورتوں کی توبہ قبول فرمائے، اور اللہ تعالیٰ بڑا ہی بخشنے واﻻ اور مہربان ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcvii{\basmalahur تمام تعریفیں اس اللہ کے لئے سزاوار ہیں جس کی ملکیت میں وه سب کچھ ہے جو آسمانوں اور زمین میں ہے آخرت میں بھی تعریف اسی کے لئے ہے، وه (بڑی) حکمتوں واﻻ اور (پورا) خبردار ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdcviii{جو زمین میں جائے اور جو اس سے نکلے جو آسمان سے اترے اور جو چڑھ کر اس میں جائے وه سب سے باخبر ہے۔ اور وه مہربان نہایت بخشش واﻻ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdcix{کفار کہتے ہیں کہ ہم پر قیامت نہیں آئے گی۔ آپ کہہ دیجیئے! کہ مجھے میرے رب کی قسم! جو عالم الغیب ہے کہ وه یقیناً تم پر آئے گی اللہ تعالیٰ سے ایک ذرے کے برابر کی چیز بھی پوشیده نہیں نہ آسمانوں میں اور نہ زمین میں بلکہ اس سے بھی چھوٹی اور بڑی چیز کھلی کتاب میں موجود ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdcx{تاکہ وه ایمان والوں اور نیکوکاروں کو بھلائی عطا فرمائے، یہی لوگ ہیں جن کے لئے مغفرت اور عزت کی روزی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdcxi{اور ہماری آیتوں کو نیچا دکھانے کی جنہوں نے کوشش کی ہے یہ وه لوگ ہیں جن کے لئے بدترین قسم کا دردناک عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdcxii{اور جنہیں علم ہے وه دیکھ لیں گے کہ جو کچھ آپ کی جانب آپ کے رب کی طرف سے نازل ہوا ہے وه (سراسر) حق ہے اور اللہ غالب خوبیوں والے کی راه کی رہبری کرتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiii{اور کافروں نے کہا (آؤ) ہم تمہیں ایک ایسا شخص بتلائیں جو تمہیں یہ خبر پہنچا رہا ہے کہ جب تم بالکل ہی ریزه ریزه ہوجاؤ گے تو تم پھر سے ایک نئی پیدائش میں آؤ گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiv{(ہم نہیں کہہ سکتے) کہ خود اس نے (ہی) اللہ پر جھوٹ باندھ لیا ہے یا اسے دیوانگی ہے بلکہ (حقیقت یہ ہے) کہ آخرت پر یقین نہ رکھنے والے ہی عذاب میں اور دور کی گمراہی میں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdcxv{کیا پس وه اپنے آگے پیچھے آسمان وزمین کو دیکھ نہیں رہے ہیں؟ اگر ہم چاہیں تو انہیں زمین میں دھنسا دیں یا ان پر آسمان کے ٹکڑے گرادیں، یقیناً اس میں پوری دلیل ہے ہر اس بندے کے لئے جو (دل سے) متوجہ ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvi{اور ہم نے داؤد پر اپنا فضل کیا، اے پہاڑو! اس کے ساتھ رغبت سے تسبیح پڑھا کرو اور پرندوں کو بھی (یہی حکم ہے) اور ہم نے اس کے لئے لوہا نرم کردیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvii{کہ تو پوری پوری زرہیں بنا اور جوڑوں میں اندازه رکھ تم سب نیک کام کیا کرو۔ (یقین مانو) کہ میں تمہارے اعمال دیکھ رہا ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdcxviii{اور ہم نے سلیمان کے لئے ہوا کو مسخر کردیا کہ صبح کی منزل اس کی مہینہ بھر کی ہوتی تھی اور شام کی منزل بھی اور ہم نے ان کے لئے تانبے کا چشمہ بہا دیا۔ اور اس کے رب کے حکم سے بعض جنات اس کی ماتحتی میں اس کے سامنے کام کرتے تھے اور ان میں سے جو بھی ہمارے حکم سے سرتابی کرے ہم اسے بھڑکتی ہوئی آگ کے عذاب کا مزه چکھائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdcxix{جو کچھ سلیمان چاہتے وه جنات تیار کردیتے مثلا قلعے اور مجسمے اور حوضوں کے برابر لگن اور چولہوں پر جمی ہوئی مضبوط دیگیں، اے آل داؤد اس کے شکریہ میں نیک عمل کرو، میرے بندوں میں سے شکرگزار بندے کم ہی ہوتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcxx{پھر جب ہم نے ان پر موت کا حکم بھیج دیا تو ان کی خبر جنات کو کسی نے نہ دی سوائے گھن کے کیڑے کے جو ان کی عصا کو کھا رہا تھا۔ پس جب (سلیمان) گر پڑے اس وقت جنوں نے جان لیا کہ اگر وه غیب دان ہوتے تو اس کے ذلت کے عذاب میں مبتلا نہ رہتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxi{قوم سبا کے لئے اپنی بستیوں میں (قدرت الٰہی کی) نشانی تھی ان کے دائیں بائیں دو باغ تھے (ہم نے ان کو حکم دیا تھا کہ) اپنے رب کی دی ہوئی روزی کھاؤ اور اس کا شکر ادا کرو، یہ عمده شہر اور وه بخشنے واﻻ رب ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxii{لیکن انہوں نے روگردانی کی تو ہم نے ان پر زور کے سیلاب (کا پانی) بھیج دیا اور ہم نے ان کے (ہرے بھرے) باغوں کے بدلے دو (ایسے) باغ دیئے جو بدمزه میوؤں والے اور (بکثرت) جھاؤ اور کچھ بیری کے درختوں والے تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiii{ہم نے ان کی ناشکری کا یہ بدلہ انہیں دیا۔ ہم (ایسی) سخت سزا بڑے بڑے ناشکروں ہی کو دیتے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiv{اور ہم نے ان کے اور ان بستیوں کے درمیان جن میں ہم نے برکت دے رکھی تھی چند بستیاں اور (آباد) رکھی تھیں جو برسرراه ﻇاہر تھیں، اور ان میں چلنے کی منزلیں مقرر کردی تھیں ان میں راتوں اور دنوں کو بہ امن وامان چلتے پھرتے رہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxv{لیکن انہوں نے پھر کہا کہ اے ہمارے پروردگار! ہمارے سفر دور دراز کردے چونکہ خود انہوں نے اپنے ہاتھوں اپنا برا کیا اس لئے ہم نے انہیں (گزشتہ) فسانوں کی صورت میں کردیا اور ان کے ٹکڑے ٹکڑے اڑا دیئے۔ بلاشبہ ہر ایک صبروشکر کرنے والے کے لئے اس (ماجرے) میں بہت سی عبرتیں ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvi{اور شیطان نے ان کے بارے میں اپنا گمان سچا کر دکھایا یہ لوگ سب کے سب اس کے تابعدار بن گئے سوائے مومنوں کی ایک جماعت کے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvii{شیطان کا ان پر کوئی زور (اور دباؤ) نہ تھا مگر اس لئے کہ ہم ان لوگوں کو جو آخرت پر ایمان رکھتے ہیں ﻇاہر کردیں ان لوگوں میں سے جو اس سے شک میں ہیں۔ اور آپ کا رب (ہر) ہر چیز پر نگہبان ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxviii{کہہ دیجیئے! کہ اللہ کے سوا جن جن کا تمہیں گمان ہے (سب) کو پکار لو، نہ ان میں سے کسی کو آسمانوں اور زمینوں میں سے ایک ذره کا اختیار ہے نہ ان کا ان میں کوئی حصہ ہے نہ ان میں سے کوئی اللہ کا مددگار ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxix{شفاعت (سفارش) بھی اس کے پاس کچھ نفع نہیں دیتی بجز ان کے جن کے لئے اجازت ہوجائے۔ یہاں تک کہ جب ان کے دلوں سے گھبراہٹ دور کردی جاتی ہے تو پوچھتے ہیں تمہارے پرودگار نے کیا فرمایا؟ جواب دیتے ہیں کہ حق فرمایا اور وه بلند وباﻻ اور بہت بڑا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxx{پوچھیئے کہ تمہیں آسمانوں اور زمین سے روزی کون پہنچاتا ہے؟ (خود) جواب دیجیئے! کہ اللہ تعالیٰ۔ (سنو) ہم یا تم۔ یا تو یقیناً ہدایت پر ہیں یا کھلی گمراہی میں ہیں؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxi{کہہ دیجیئے! کہ ہمارے کئے ہوئے گناہوں کی بابت تم سے کوئی سوال نہ کیا جائے گا نہ تمہارے اعمال کی بازپرس ہم سے کی جائے گی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxii{انہیں خبر دے دیجیئے کہ ہم سب کو ہمارا رب جمع کرکے پھر ہم میں سچے فیصلے کردے گا۔ وه فیصلے چکانے واﻻ ہے اور دانا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiii{کہہ دیجیئے! کہ اچھا مجھے بھی تو انہیں دکھا دو جنہیں تم اللہ کا شریک ٹھہرا کر اس کے ساتھ ملا رہے ہو، ایسا ہرگز نہیں، بلکہ وہی اللہ ہے غالب باحکمت\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiv{ہم نے آپ کو تمام لوگوں کے لئے خوشخبریاں سنانے واﻻ اور ڈرانے واﻻ بنا کر بھیجا ہے ہاں مگر (یہ صحیح ہے) کہ لوگوں کی اکثریت بےعلم ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxv{پوچھتے ہیں کہ وه وعده ہے کب؟ سچے ہو تو بتا دو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvi{جواب دیجیئے کہ وعدے کا دن ٹھیک معین ہے جس سے ایک ساعت نہ تم پیچھے ہٹ سکتے ہو نہ آگے بڑھ سکتے ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvii{اور کافروں نے کہا کہ ہم ہرگز نہ تو اس قرآن کو مانیں نہ اس سے پہلے کی کتابوں کو! اے دیکھنے والے کاش کہ تو ان ﻇالموں کو اس وقت دیکھتا جب کہ یہ اپنے رب کے سامنے کھڑے ہوئے ایک دوسرے کو الزام دے رہے ہوں گے کمزور لوگ بڑے لوگوں سے کہیں گے اگر تم نہ ہوتے تو ہم تو مومن ہوتے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxviii{یہ بڑے لوگ ان کمزوروں کو جواب دیں گے کہ کیا تمہارے پاس ہدایت آچکنے کے بعد ہم نے تمہیں اس سے روکا تھا؟ (نہیں) بلکہ تم (خود) ہی مجرم تھے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxix{(اس کے جواب میں) یہ کمزور لوگ ان متکبروں سے کہیں گے، (نہیں نہیں) بلکہ دن رات مکروفریب سے ہمیں اللہ کے ساتھ کفر کرنے اور اس کے شریک مقرر کرنے کا تمہارا حکم دینا ہماری بےایمانی کا باعﺚ ہوا، اور عذاب کو دیکھتے ہی سب کے سب دل میں پشیمان ہو رہے ہوں گے، اور کافروں کی گردنوں میں ہم طوق ڈال دیں گے انہیں صرف ان کے کئے کرائے اعمال کا بدلہ دیا جائے گا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxl{اور ہم تو جس بستی میں جو بھی آگاه کرنے واﻻ بھیجا وہاں کے خوشحال لوگوں نے یہی کہا کہ جس چیز کے ساتھ تم بھیجے گئے ہو ہم اس کے ساتھ کفر کرنے والے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxli{اور کہا ہم مال واوﻻد میں بہت بڑھے ہوئے ہیں یہ نہیں ہوسکتا کہ ہم عذاب دیئے جائیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlii{کہہ دیجیئے! کہ میرا رب جس کے لئے چاہے روزی کشاده کردیتا ہے اور تنگ بھی کردیتا ہے، لیکن اکثر لوگ نہیں جانتے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliii{اور تمہارے مال اور اوﻻد ایسے نہیں کہ تمہیں ہمارے پاس (مرتبوں سے) قریب کردیں ہاں جو ایمان ﻻئیں اور نیک عمل کریں ان کے لئے ان کے اعمال کا دوہرا اجر ہے اور وه نڈر و بےخوف ہو کر باﻻ خانوں میں رہیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliv{اور جو لوگ ہماری آیتوں کے مقابلے کی تگ ودو میں لگے رہتے ہیں یہی ہیں جو عذاب میں پکڑ کر حاضر رکھے جائیں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlv{کہہ دیجیئے! کہ میرا رب اپنے بندوں میں جس کے لئے چاہے روزی کشاده کرتا ہے اور جس کے لئے چاہے تنگ کردیتا ہے، تم جو کچھ بھی اللہ کی راه میں خرچ کرو گے اللہ اس کا (پورا پورا) بدلہ دے گا اور وه سب سے بہتر روزی دینے واﻻ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvi{اور ان سب کو اللہ اس دن جمع کرکے فرشتوں سے دریافت فرمائے گا کہ کیا یہ لوگ تمہاری عبادت کرتے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvii{وه کہیں گے تیری ذات پاک ہے اور ہمارا ولی تو تو ہے نہ کہ یہ بلکہ یہ لوگ جنوں کی عبادت کرتے تھے، ان میں کے اکثر کا ان ہی پر ایمان تھا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlviii{پس آج تم میں سے کوئی (بھی) کسی کے لئے (بھی کسی قسم کے) نفع نقصان کا مالک نہ ہوگا۔ اور ہم ﻇالموں سے کہہ دیں گے کہ اس آگ کا عذاب چکھو جسے تم جھٹلاتے رہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlix{اور جب ان کے سامنے ہماری صاف صاف آیتیں پڑھی جاتی ہیں تو کہتے ہیں کہ یہ ایسا شخص ہے جو تمہیں تمہارے باپ دادا کے معبودوں سے روک دینا چاہتا ہے۔ (اس کے سوا کوئی بات نہیں)، اور کہتے ہیں کہ یہ تو گھڑا ہوا جھوٹ ہے اور حق ان کے پاس آچکا پھر بھی کافر یہی کہتے رہے کہ یہ تو کھلا ہوا جادو ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcl{اور ان (مکہ والوں) کو نہ تو ہم نے کتابیں دے رکھی ہیں جنہیں یہ پڑھتے ہوں نہ ان کے پاس آپ سے پہلے کوئی آگاه کرنے واﻻ آیا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcli{اور ان سے پہلے کے لوگوں نے بھی ہماری باتوں کو جھٹلایا تھا اور انہیں ہم نے جو دے رکھا تھا یہ تو اس کے دسویں حصے کو بھی نہیں پہنچے، پس انہوں نے میرے رسولوں کو جھٹلایا، (پھر دیکھ کہ) میرا عذاب کیسا (سخت) تھا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdclii{کہہ دیجیئے! کہ میں تمہیں صرف ایک ہی بات کی نصیحت کرتا ہوں کہ تم اللہ کے واسطے (ضد چھوڑ کر) دو دو مل کر یا تنہا تنہا کھڑے ہو کر سوچو تو سہی، تمہارے اس رفیق کو کوئی جنون نہیں، وه تو تمہیں ایک بڑے (سخت) عذاب کے آنے سے پہلے ڈرانے واﻻ ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcliii{کہہ دیجیئے! کہ جو بدلہ میں تم سے مانگوں وه تمہارے لئے ہے میرا بدلہ تو اللہ تعالیٰ ہی کے ذمے ہے۔ وه ہر چیز سے باخبر (اور مطلع) ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcliv{کہہ دیجیئے! کہ میرا رب حق (سچی وحی) نازل فرماتا ہے وه ہر غیب کا جاننے واﻻ ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdclv{کہہ دیجیئے کہ حق آچکا باطل نہ تو پہلے کچھ کرسکا ہے اور نہ کرسکے گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdclvi{کہہ دیجیئے کہ اگر میں بہک جاؤں تو میرے بہکنے (کا وبال) مجھ پر ہی ہے اور اگر میں راه ہدایت پر ہوں تو بہ سبب اس وحی کے جو میرا پروردگار مجھے کرتا ہے وه بڑا ہی سننے واﻻ اور بہت ہی قریب ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdclvii{اور اگر آپ (وه وقت) ملاحظہ کریں جب کہ یہ کفار گھبرائے پھریں گے پھر نکل بھاگنے کی کوئی صورت نہ ہوگی اور قریب کی جگہ سے گرفتار کر لئے جائیں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdclviii{اس وقت کہیں گے کہ ہم اس قرآن پر ایمان ﻻئے لیکن اس قدر دور جگہ سے (مطلوبہ چیز) کیسے ہاتھ آسکتی ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdclix{اس سے پہلے تو انہوں نے اس سے کفر کیا تھا، اور دور دراز سے بن دیکھے ہی پھینکتے رہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdclx{ان کی چاہتوں اور ان کے درمیان پرده حائل کردیا گیا جیسے کہ اس سے پہلے بھی ان جیسوں کے ساتھ کیا گیا، وه بھی (ان ہی کی طرح) شک وتردد میں (پڑے ہوئے) تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdclxi{\basmalahur اس اللہ کے لئے تمام تعریفیں سزاوار ہیں جو (ابتداءً) آسمانوں اور زمین کا پیدا کرنے واﻻ اور دو دو تین تین چار چار پروں والے فرشتوں کو اپنا پیغمبر (قاصد) بنانے واﻻ ہے، مخلوق میں جو چاہے زیادتی کرتا ہے اللہ تعالیٰ یقیناً ہر چیز پر قادر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdclxii{اللہ تعالیٰ جو رحمت لوگوں کے لئے کھول دے سو اس کا کوئی بند کرنے واﻻ نہیں اور جس کو بند کردے سو اس کے بعد اس کا کوئی جاری کرنے واﻻ نہیں اور وہی غالب حکمت واﻻ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiii{لوگو! تم پر جو انعام اللہ تعالیٰ نے کئے ہیں انہیں یاد کرو۔ کیا اللہ کے سوا اور کوئی بھی خالق ہے جو تمہیں آسمان وزمین سے روزی پہنچائے؟ اس کے سوا کوئی معبود نہیں۔ پس تم کہاں الٹے جاتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiv{اور اگر یہ آپ کو جھٹلائیں تو آپ سے پہلے کے تمام رسول بھی جھٹلائے جاچکے ہیں۔ تمام کام اللہ ہی کی طرف لوٹائے جاتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdclxv{لوگو! اللہ تعالیٰ کا وعده سچا ہے تمہیں زندگانیٴ دنیا دھوکے میں نہ ڈالے، اور نہ دھوکے باز شیطان تمہیں غفلت میں ڈالے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvi{یاد رکھو! شیطان تمہارا دشمن ہے، تم اسے دشمن جانو وه تو اپنے گروه کو صرف اس لئے ہی بلاتا ہے کہ وه سب جہنم واصل ہو جائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvii{جو لوگ کافر ہوئے ان کے لئے سخت سزا ہے اور جو لوگ ایمان ﻻئے اور نیک اعمال کئے ان کے لئے بخشش ہے اور (بہت) بڑا اجر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdclxviii{کیا پس وه شخص جس کے لئے اس کے برے اعمال مزین کردیئے گئے ہیں پس وه انہیں اچھاسمجھتا ہے (کیا وه ہدایت یافتہ شخص جیسا ہے)، (یقین مانو) کہ اللہ جسے چاہے گمراه کرتا ہے اور جسے چاہے راه راست دکھاتا ہے۔ پس آپ کو ان پر غم کھا کھا کر اپنی جان ہلاکت میں نہ ڈالنی چاہیئے، یہ جو کچھ کر رہے ہیں اس سے یقیناً اللہ تعالیٰ بخوبی واقف ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdclxix{اور اللہ ہی ہوائیں چلاتا ہے جو بادلوں کو اٹھاتی ہیں پھر ہم بادلوں کو خشک زمین کی طرف لے جاتے ہیں اور اس سے اس زمین کو اس کی موت کے بعد زنده کردیتے ہیں۔ اسی طرح دوباره جی اٹھنا (بھی) ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdclxx{جو شخص عزت حاصل کرنا چاہتا ہو تو اللہ تعالیٰ ہی کی ساری عزت ہے، تمام تر ستھرے کلمات اسی کی طرف چڑھتے ہیں اور نیک عمل ان کو بلند کرتا ہے، جو لوگ برائیوں کے داؤں گھات میں لگے رہتے ہیں ان کے لئے سخت تر عذاب ہے، اور ان کا یہ مکر برباد ہوجائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxi{لوگو! اللہ تعالیٰ نے تمہیں مٹی سے پھر نطفہ سے پیدا کیا ہے، پھر تمہیں جوڑے جوڑے (مرد وعورت) بنا دیا ہے، عورتوں کو حاملہ ہونا اور بچوں کا تولد ہونا سب اس کے علم سے ہی ہے، اور جو بڑی عمر واﻻ عمر دیا جائے اور جس کی عمر گھٹے وه سب کتاب میں لکھا ہوا ہے۔ اللہ تعالیٰ پر یہ بات بالکل آسان ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxii{اور برابر نہیں دو دریا یہ میٹھا ہے پیاس بجھاتا پینے میں خوشگوار اور یہ دوسرا کھاری ہے کڑوا، تم ان دونوں میں سے تازه گوشت کھاتے ہو اور وه زیوارت نکالتے ہو جنہیں تم پہنتے ہو۔ اور آپ دیکھتے ہیں کہ بڑی بڑی کشتیاں پانی کو چیرنے پھاڑنے والی ان دریاؤں میں ہیں تاکہ تم اس کا فضل ڈھونڈو اور تاکہ تم اس کا شکر کرو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiii{وه رات کو دن اور دن کو رات میں داخل کرتا ہے اور آفتاب وماہتاب کو اسی نے کام میں لگا دیا ہے۔ ہر ایک میعاد معین پر چل رہا ہے۔ یہی ہے اللہ تم سب کا پالنے واﻻ اسی کی سلطنت ہے۔ جنہیں تم اس کے سوا پکار رہے ہو وه تو کھجور کی گٹھلی کے چھلکے کے بھی مالک نہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiv{اگر تم انہیں پکارو تو وه تمہاری پکار سنتے ہی نہیں اور اگر (بالفرض) سن بھی لیں تو فریاد رسی نہیں کریں گے، بلکہ قیامت کے دن تمہارے اس شرک کا صاف انکار کرجائیں گے۔ آپ کو کوئی حق تعالیٰ جیسا خبردار خبریں نہ دے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxv{اے لوگو! تم اللہ کے محتاج ہو اور اللہ بےنیاز خوبیوں واﻻ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvi{اگر وه چاہے تو تم کو فنا کردے اور ایک نئی مخلوق پیدا کردے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvii{اور یہ بات اللہ کو کچھ مشکل نہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxviii{کوئی بھی بوجھ اٹھانے واﻻ دوسرے کا بوجھ نہیں اٹھائے گا، اگر کوئی گراں بار دوسرے کو اپنا بوجھ اٹھانے کے لئے بلائے گا تو وه اس میں سے کچھ بھی نہ اٹھائے گا گو قرابت دار ہی ہو۔ تو صرف ان ہی کو آگاه کرسکتا ہے جو غائبانہ طور پر اپنے رب سے ڈرتے ہیں اور نمازوں کی پابندی کرتے ہیں اور جو بھی پاک ہوجائے وه اپنے ہی نفع کے لئے پاک ہوگا۔ لوٹنا اللہ ہی کی طرف ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxix{اور اندھا اور آنکھوں واﻻ برابر نہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxx{اور نہ تاریکی اور روشنی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxi{اور نہ چھاؤں اور نہ دھوپ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxii{اور زنده اور مردے برابر نہیں ہوسکتے، اللہ تعالیٰ جس کو چاہتا ہے سنا دیتا ہے، اور آپ ان لوگوں کو نہیں سنا سکتے جو قبروں میں ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiii{آپ تو صرف ڈرانے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiv{ہم نے ہی آپ کو حق دے کر خوشخبری سنانے واﻻ اور ڈر سنانے واﻻ بنا کر بھیجا ہے اور کوئی امت ایسی نہیں ہوئی جس میں کوئی ڈر سنانے واﻻ نہ گزرا ہو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxv{اور اگر یہ لوگ آپ کو جھٹلا دیں تو جو لوگ ان سے پہلے ہو گزرے ہیں انہوں نے بھی جھٹلایا تھا ان کے پاس بھی ان کے پیغمبر معجزے اور صحیفے اور روشن کتابیں لے کر آئے تھے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvi{پھر میں نےان کافروں کو پکڑ لیا سو میرا عذاب کیسا ہوا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvii{کیا آپ نے اس بات پر نظر نہیں کی کہ اللہ تعالیٰ نے آسمان سے پانی اتارا پھر ہم نے اس کے ذریعہ سے مختلف رنگتوں کے پھل نکالے اور پہاڑوں کے مختلف حصے ہیں سفید اور سرخ کہ ان کی بھی رنگتیں مختلف ہیں اور بہت گہرے سیاه\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxviii{اور اسی طرح آدمیوں اور جانوروں اور چوپایوں میں بھی بعض ایسے ہیں کہ ان کی رنگتیں مختلف ہیں، اللہ سے اس کے وہی بندے ڈرتے ہیں جو علم رکھتے ہیں واقعی اللہ تعالیٰ زبردست بڑا بخشنے واﻻ ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxix{جو لوگ کتاب اللہ کی تلاوت کرتے ہیں اور نماز کی پابندی رکھتے ہیں اور جو کچھ ہم نے ان کو عطا فرمایا ہے اس میں سے پوشیده اور علانیہ خرچ کرتے ہیں وه ایسی تجارت کے امیدوار ہیں جو کبھی خساره میں نہ ہوگی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxc{تاکہ ان کو ان کی اجرتیں پوری دے اور ان کو اپنے فضل سے اور زیاده دے بےشک وه بڑا بخشنے واﻻ قدردان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxci{اور یہ کتاب جو ہم نے آپ کے پاس وحی کے طور پر بھیجی ہے یہ بالکل ٹھیک ہے جو کہ اپنے سے پہلی کتابوں کی بھی تصدیق کرتی ہے۔ اللہ تعالیٰ اپنے بندوں کی پوری خبر رکھنے واﻻ خوب دیکھنے واﻻ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcii{پھر ہم نے ان لوگوں کو (اس) کتاب کا وارث بنایا جن کو ہم نے اپنے بندوں میں سے پسند فرمایا۔ پھر بعضے تو ان میں اپنی جانوں پر ﻇلم کرنے والے ہیں اور بعضے ان میں متوسط درجے کے ہیں اور بعضے ان میں اللہ کی توفیق سے نیکیوں میں ترقی کئے چلے جاتے ہیں۔ یہ بڑا فضل ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciii{وه باغات میں ہمیشہ رہنے کے جن میں یہ لوگ داخل ہوں گے سونے کے کنگن اور موتی پہنائے جاویں گے۔ اور پوشاک ان کی وہاں ریشم کی ہوگی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciv{اور کہیں گے کہ اللہ کا لاکھ لاکھ شکر ہے جس نے ہم سے غم دور کیا۔ بےشک ہمارا پروردگار بڑا بخشنے واﻻ بڑا قدردان ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcv{جس نے ہم کو اپنے فضل سے ہمیشہ رہنے کے مقام میں ﻻ اتارا جہاں نہ ہم کو کوئی تکلیف پہنچے گی اور نہ ہم کو کوئی خستگی پہنچے گی\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvi{اور جو لوگ کافر ہیں ان کے لئے دوزخ کی آگ ہے نہ تو ان کی قضا ہی آئے گی کہ مر ہی جائیں اور نہ دوزخ کا عذاب ہی ان سے ہلکا کیا جائے گا۔ ہم ہر کافر کو ایسی ہی سزا دیتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvii{اور وه لوگ اس میں چلائیں گے کہ اے ہمارے پروردگار! ہم کو نکال لے ہم اچھے کام کریں گے برخلاف ان کاموں کے جو کیا کرتے تھے، (اللہ کہے گا) کیا ہم نے تم کو اتنی عمر نہ دی تھی کہ جس کو سمجھنا ہوتا وه سمجھ سکتا اور تمہارے پاس ڈرانے واﻻ بھی پہنچا تھا، سو مزه چکھو کہ (ایسے) ﻇالموں کا کوئی مددگار نہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcviii{بےشک اللہ تعالیٰ جاننے واﻻ ہے آسمانوں اور زمین کی پوشیده چیزوں کا، بےشک وہی جاننے واﻻ ہے سینوں کی باتوں کا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcix{وہی ایسا ہے جس نے تم کو زمین میں آباد کیا، سو جو شخص کفر کرے گا اس کے کفر کا وبال اسی پر پڑے گا۔ اور کافروں کے لئے ان کا کفر ان کے پروردگار کے نزدیک ناراضی ہی بڑھنے کا باعﺚ ہوتا ہے، اور کافروں کے لئے ان کا کفر خساره ہی بڑھنے کا باعﺚ ہوتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcc{آپ کہیئے! کہ تم اپنے قرارداد شریکوں کا حال تو بتلاؤ جن کو تم اللہ کے سوا پوجا کرتے ہو۔ یعنی مجھ کو یہ بتلاؤ کہ انہوں نے زمین میں سے کون سا (جزو) بنایا ہے یا ان کا آسمانوں میں کچھ ساجھا ہے یا ہم نے ان کو کوئی کتاب دی ہے کہ یہ اس کی دلیل پر قائم ہوں، بلکہ یہ ﻇالم ایک دوسرے سے نرے دھوکے کی باتوں کا وعده کرتے آتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcci{یقینی بات ہے کہ اللہ تعالیٰ آسمانوں اور زمین کو تھامے ہوئے ہے کہ وه ٹل نہ جائیں اور اگر وه ٹل جائیں تو پھر اللہ کے سوا اور کوئی ان کو تھام بھی نہیں سکتا۔ وه حلیم غفور ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccii{اور ان کفار نے بڑی زوردار قسم کھائی تھی کہ اگر ان کے پاس کوئی ڈرانے واﻻ آئے تو وه ہر ایک امت سے زیاده ہدایت قبول کرنے والے ہوں۔ پھر جب ان کے پاس ایک پیغمبر آ پہنچے تو بس ان کی نفرت ہی میں اضافہ ہوا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcciii{دنیا میں اپنے کو بڑا سمجھنے کی وجہ سے، اور ان کی بری تدبیروں کی وجہ سے اور بری تدبیروں کا وبال ان تدبیر والوں ہی پر پڑتا ہے، سو کیا یہ اسی دستور کے منتظر ہیں جو اگلے لوگوں کے ساتھ ہوتا رہا ہے۔ سو آپ اللہ کے دستور کو کبھی بدلتا ہوا نہ پائیں گے، اور آپ اللہ کے دستور کو کبھی منتقل ہوتا ہوا نہ پائیں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcciv{اور کیا یہ لوگ زمین میں چلے پھرے نہیں جس میں دیکھتے بھالتے کہ جو لوگ ان سے پہلے ہو گزرے ہیں ان کا انجام کیا ہوا؟ حاﻻنکہ وه قوت میں ان سے بڑھے ہوئے تھے، اور اللہ ایسا نہیں ہے کہ کوئی چیز اس کو ہرا دے نہ آسمانوں میں اور نہ زمین میں۔ وه بڑے علم واﻻ، بڑی قدرت واﻻ ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccv{اور اگر اللہ تعالیٰ لوگوں پر ان کے اعمال کے سبب داروگیر فرمانے لگتا تو روئے زمین پر ایک جاندار کو نہ چھوڑتا، لیکن اللہ تعالیٰ ان کو ایک میعاد معین تک مہلت دے رہا ہے، سو جب ان کی وه میعاد آپہنچے گی اللہ تعالیٰ اپنے بندوں کو آپ دیکھ لے گا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccvi{\basmalahur یٰس\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccvii{قسم ہے قرآن باحکمت کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccviii{کہ بے شک آپ پیغمبروں میں سے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccix{سیدھے راستے پر ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccx{یہ قرآن اللہ زبردست مہربان کی طرف سے نازل کیا گیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxi{تاکہ آپ ایسے لوگوں کو ڈرائیں جن کے باپ دادے نہیں ڈرائے گئے تھے، سو (اسی وجہ سے) یہ غافل ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxii{ان میں سے اکثر لوگوں پر بات ﺛابت ہوچکی ہے سو یہ لوگ ایمان نہ ﻻئیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiii{ہم نے ان کی گردنوں میں طوق ڈال دیئے ہیں پھر وه ٹھوڑیوں تک ہیں، جس سے ان کے سر اوپر کو الٹ گئے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiv{اور ہم نے ایک آڑ ان کے سامنے کردی اورایک آڑ ان کے پیچھے کردی، جس سے ہم نے ان کو ڈھانک دیا سو وه نہیں دیکھ سکتے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxv{اور آپ ان کو ڈرائیں یا نہ ڈرائیں دونوں برابر ہیں، یہ ایمان نہیں ﻻئیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvi{بس آپ تو صرف ایسے شخص کو ڈرا سکتے ہیں جو نصیحت پر چلے اور رحمٰن سے بےدیکھے ڈرے، سو آپ اس کو مغفرت اور باوقار اجر کی خوش خبریاں سنا دیجیئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvii{بےشک ہم مُردوں کو زنده کریں گے، اور ہم لکھتے جاتے ہیں وه اعمال بھی جن کو لوگ آگے بھیجتے ہیں اور ان کے وه اعمال بھی جن کو پیچھے چھوڑ جاتے ہیں، اور ہم نے ہر چیز کو ایک واضح کتاب میں ضبط کر رکھا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccxviii{اور آپ ان کے سامنے ایک مثال (یعنی ایک) بستی والوں کی مثال (اس وقت کا) بیان کیجیئے جب کہ اس بستی میں (کئی) رسول آئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdccxix{جب ہم نے ان کے پاس دو کو بھیجا سو ان لوگوں نے (اول) دونوں کو جھٹلایا پھر ہم نے تیسرے سے تائید کی سو ان تینوں نے کہا کہ ہم تمہارے پاس بھیجے گئے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccxx{ان لوگوں نے کہا کہ تم تو ہماری طرح معمولی آدمی ہو اور رحمٰن نے کہا کوئی چیز نازل نہیں کی۔ تم نرا جھوٹ بولتے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxi{ان (رسولوں) نے کہا ہمارا پروردگار جانتا ہے کہ بےشک ہم تمہارے پاس بھیجے گئے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxii{اور ہمارے ذمہ تو صرف واضح طور پر پہنچا دینا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiii{انہوں نے کہا کہ ہم تو تم کو منحوس سمجھتے ہیں۔ اگر تم باز نہ آئے تو ہم پتھروں سے تمہارا کام تمام کردیں گے اور تم کو ہماری طرف سے سخت تکلیف پہنچے گی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiv{ان رسولوں نے کہا کہ تمہاری نحوست تمہارے ساتھ ہی لگی ہوئی ہے، کیا اس کو نحوست سمجھتے ہو کہ تم کو نصیحت کی جائے بلکہ تم حد سے نکل جانے والے لوگ ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxv{اور ایک شخص (اس) شہر کے آخری حصے سے دوڑتا ہوا آیا کہنے لگا کہ اے میری قوم! ان رسولوں کی راه پر چلو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvi{ایسے لوگوں کی راه پر چلو جو تم سے کوئی معاوضہ نہیں مانگتے اور وه راه راست پر ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvii{اور مجھے کیا ہو گیا ہے کہ میں اس کی عبادت نہ کروں جس نے مجھے پیدا کیا اور تم سب اسی کی طرف لوٹائے جاؤگے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxviii{کیا میں اسے چھوڑ کر ایسوں کو معبود بناؤں کہ اگر (اللہ) رحمٰن مجھے کوئی نقصان پہنچانا چاہے تو ان کی سفارش مجھے کچھ بھی نفع نہ پہنچا سکے اور نہ وه مجھے بچا سکیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxix{پھر تو میں یقیناً کھلی گمراہی میں ہوں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxx{میری سنو! میں تو (سچے دل سے) تم سب کے رب پر ایمان ﻻ چکا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxi{(اس سے) کہا گیا کہ جنت میں چلا جا، کہنے لگا کاش! میری قوم کو بھی علم ہو جاتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxii{کہ مجھے میرے رب نے بخش دیا اور مجھے باعزت لوگوں میں سے کر دیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiii{اس کے بعد ہم نے اس کی قوم پر آسمان سے کوئی لشکر نہ اتارا، اور نہ اس طرح ہم اتارا کرتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiv{وه تو صرف ایک زور کی چیﺦ تھی کہ یکایک وه سب کے سب بجھ بجھا گئے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxv{(ایسے) بندوں پر افسوس! کبھی بھی کوئی رسول ان کے پاس نہیں آیا جس کی ہنسی انہوں نے نہ اڑائی ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvi{کیا انہوں نے نہیں دیکھا کہ ان کے پہلے بہت سی قوموں کو ہم نے غارت کر دیا کہ وه ان کی طرف لوٹ کر نہیں آئیں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvii{اور نہیں ہے کوئی جماعت مگر یہ کہ وه جمع ہو کر ہمارے سامنے حاضر کی جائے گی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxviii{اور ان کے لئے ایک نشانی (خشک) زمین ہے جس کو ہم نے زنده کر دیا اور اس سے غلہ نکالا جس میں سے وه کھاتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxix{اور ہم نے اس میں کھجوروں کے اور انگور کے باغات پیدا کر دیئے، اور جن میں ہم نے چشمے بھی جاری کر دیئے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdccxl{تاکہ (لوگ) اس کے پھل کھائیں، اور اس کو ان کے ہاتھوں نے نہیں بنایا۔ پھر کیوں شکر گزاری نہیں کرتے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdccxli{وه پاک ذات ہے جس نے ہر چیز کے جوڑے پیدا کیے خواه وه زمین کی اگائی ہوئی چیزیں ہوں، خواه خود ان کے نفوس ہوں خواه وه (چیزیں) ہوں جنہیں یہ جانتے بھی نہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlii{اور ان کے لئے ایک نشانی رات ہے جس سے ہم دن کو کھینچ دیتے ہیں تو وه یکایک اندھیرے میں ره جاتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliii{اور سورج کے لئے جو مقرره راه ہے وه اسی پر چلتا رہتا ہے۔ یہ ہے مقرر کرده غالب، باعلم اللہ تعالیٰ کا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliv{اور چاند کی ہم نے منزلیں مقررکر رکھی ہیں، یہاں تک کہ وه لوٹ کر پرانی ٹہنی کی طرح ہو جاتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlv{نہ آفتاب کی یہ مجال ہے کہ چاند کو پکڑے اور نہ رات دن پرآگے بڑھ جانے والی ہے، اور سب کے سب آسمان میں تیرتے پھرتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvi{اور ان کے لئے ایک نشانی (یہ بھی) ہے کہ ہم نے ان کی نسل کو بھری ہوئی کشتی میں سوار کیا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvii{اور ان کے لئے اسی جیسی اور چیزیں پیدا کیں جن پر یہ سوار ہوتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlviii{اور اگر ہم چاہتے تو انہیں ڈبو دیتے۔ پھر نہ تو کوئی ان کا فریاد رس ہوتا نہ وه بچائے جائیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlix{لیکن ہم اپنی طرف سے رحمت کرتے ہیں اور ایک مدت تک کے لئے انہیں فائدے دے رہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccl{اور ان سے جب (کبھی) کہا جاتا ہے کہ اگلے پچھلے (گناہوں) سے بچو تاکہ تم پر رحم کیا جائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccli{اور ان کے پاس تو ان کے رب کی نشانیوں میں سے کوئی نشانی ایسی نہیں آئی جس سے یہ بے رخی نہ برتتے ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcclii{اور ان سے جب کہا جاتا ہے کہ اللہ تعالیٰ کے دیئے ہوئے میں سے کچھ خرچ کرو، تو یہ کفار ایمان والوں کو جواب دیتے ہیں کہ ہم انہیں کیوں کھلائیں؟ جنہیں اگر اللہ تعالیٰ چاہتا تو خود کھلا پلا دیتا، تم تو ہو ہی کھلی گمراہی میں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdccliii{وه کہتے ہیں کہ یہ وعده کب ہوگا، سچے ہو تو بتلاؤ\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdccliv{انہیں صرف ایک سخت چیﺦ کاانتظار ہے جو انہیں آپکڑے گی اور یہ باہم لڑائی جھگڑے میں ہی ہوں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcclv{اس وقت نہ تو یہ وصیت کر سکیں گے اور نہ اپنے اہل کی طرف لوٹ سکیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvi{تو صور کے پھونکے جاتے ہی سب کے سب اپنی قبروں سے اپنے پروردگار کی طرف (تیز تیز) چلنے لگیں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvii{کہیں گے ہائے ہائے! ہمیں ہماری خواب گاہوں سے کس نے اٹھا دیا۔ یہی ہے جس کا وعده رحمٰن نے دیا تھا اور رسولوں نے سچ سچ کہہ دیا تھا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcclviii{یہ نہیں ہے مگر ایک چیﺦ کہ یکایک سارے کے سارے ہمارے سامنے حاضر کر دیئے جائیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcclix{پس آج کسی شخص پر کچھ بھی ﻇلم نہ کیا جائے گا اور تمہیں نہیں بدلہ دیا جائے گا، مگر صرف ان ہی کاموں کا جو تم کیا کرتے تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcclx{جنتی لوگ آج کے دن اپنے (دلچسﭗ) مشغلوں میں ہشاش بشاش ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxi{وه اور ان کی بیویاں سایوں میں مسہریوں پر تکیہ لگائے بیٹھے ہوں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxii{ان کے لئے جنت میں ہر قسم کے میوے ہوں گے اور بھی جو کچھ وه طلب کریں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiii{مہربان پروردگار کی طرف سے انہیں سلام کہا جائے گا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiv{اے گناهگارو! آج تم الگ ہو جاؤ\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxv{اے اوﻻد آدم! کیا میں نے تم سے قول قرار نہیں لیا تھا کہ تم شیطان کی عبادت نہ کرنا، وه تو تمہارا کھلا دشمن ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvi{اور میری ہی عبادت کرنا۔ سیدھی راه یہی ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvii{شیطان نے تو تم میں سے بہت ساری مخلوق کو بہکا دیا۔ کیا تم عقل نہیں رکھتے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxviii{یہی وه دوزخ ہے جس کا تمہیں وعده دیا جاتا تھا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxix{اپنے کفر کا بدلہ پانے کے لئے آج اس میں داخل ہوجاؤ\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxx{ہم آج کے دن ان کے منھ پر مہریں لگا دیں گے اور ان کے ہاتھ ہم سے باتیں کریں گے اور ان کے پاؤں گواہیاں دیں گے، ان کاموں کی جو وه کرتے تھے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxi{اگر ہم چاہتے تو ان کی آنکھیں بے نور کر دیتے پھر یہ رستے کی طرف دوڑتے پھرتے لیکن انہیں کیسے دکھائی دیتا؟\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxii{اور اگر ہم چاہتے تو ان کی جگہ ہی پر ان کی صورتیں مسﺦ کر دیتے پھر نہ وه چل پھر سکتے اور نہ لوٹ سکتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiii{اور جسے ہم بوڑھا کرتے ہیں اسے پیدائشی حالت کی طرف پھر الٹ دیتے ہیں کیا پھر بھی وه نہیں سمجھتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiv{نہ تو ہم نے اس پیغمبر کو شعر سکھائے اور نہ یہ اس کے ﻻئق ہے۔ وه تو صرف نصیحت اور واضح قرآن ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxv{تاکہ وه ہر اس شخص کو آگاه کر دے جو زنده ہے، اور کافروں پر حجت ﺛابت ہو جائے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvi{کیا وه نہیں دیکھتے کہ ہم نے اپنے ہاتھوں سے بنائی ہوئی چیزوں میں سے ان کے لئے چوپائے (بھی) پیدا کر دیئے، جن کے یہ مالک ہوگئے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvii{اور ان مویشیوں کو ہم نے ان کا تابع فرمان بنا دیا ہے جن میں سے بعض تو ان کی سواریاں ہیں اور بعض کا گوشت کھاتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxviii{انہیں ان سے اور بھی بہت سے فائدے ہیں، اور پینے کی چیزیں۔ کیا پھر (بھی) یہ شکر ادا نہیں کریں گے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxix{اور وه اللہ کے سوا دوسروں کو معبود بناتے ہیں تاکہ وه مدد کئے جائیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxx{(حاﻻنکہ) ان میں ان کی مدد کی طاقت ہی نہیں، (لیکن) پھر بھی (مشرکین) ان کے لئے حاضر باش لشکری ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxi{پس آپ کو ان کی بات غمناک نہ کرے، ہم ان کی پوشیده اور علانیہ سب باتوں کو (بخوبی) جانتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxii{کیا انسان کو اتنا بھی معلوم نہیں کہ ہم نے اسے نطفے سے پیدا کیا ہے؟ پھر یکایک وہ صریح جھگڑالو بن بیٹھا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiii{اور اس نے ہمارے لئے مثال بیان کی اور اپنی (اصل) پیدائش کو بھول گیا، کہنے لگا ان گلی سڑی ہڈیوں کو کون زنده کر سکتا ہے؟\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiv{آپ جواب دیجئے! کہ انہیں وه زنده کرے گا جس نے انہیں اول مرتبہ پیدا کیا ہے، جو سب طرح کی پیدائش کا بخوبی جاننے واﻻ ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxv{وہی جس نے تمہارے لئے سبز درخت سے آگ پیدا کر دی جس سے تم یکایک آگ سلگاتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvi{جس نے آسمانوں اور زمین کو پیدا کیا ہے کیا وه ان جیسوں کے پیدا کرنے پرقادر نہیں، بےشک قادر ہے۔ اور وہی تو پیدا کرنے واﻻ دانا (بینا) ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvii{وه جب کبھی کسی چیز کا اراده کرتا ہے اسے اتنا فرما دینا (کافی ہے) کہ ہو جا، وه اسی وقت ہو جاتی ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxviii{پس پاک ہے وه اللہ جس کے ہاتھ میں ہر چیز کی بادشاہت ہے اور جس کی طرف تم سب لوٹائے جاؤ گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxix{\basmalahur قسم ہے صف باندھنے والے (فرشتوں) کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccxc{پھر پوری طرح ڈانٹنے والوں کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccxci{پھر ذکر اللہ کی تلاوت کرنے والوں کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcii{یقیناً تم سب کا معبود ایک ہی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciii{آسمانوں اور زمین اور ان کے درمیان کی تمام چیزوں اور مَشرقوں کا رب وہی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciv{ہم نے آسمان دنیا کو ستاروں کی زینت سے آراستہ کیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcv{اور حفاﻇت کی سرکش شیطان سے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvi{عالم باﻻ کے فرشتوں (کی باتوں) کو سننے کے لئے وه کان بھی نہیں لگا سکتے، بلکہ ہر طرف سے وه مارے جاتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvii{بھگانے کے لئے اور ان کے لئے دائمی عذاب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcviii{مگر جو کوئی ایک آدھ بات اچک لے بھاگے تو (فوراً ہی) اس کے پیچھے دہکتا ہوا شعلہ لگ جاتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcix{ان کافروں سے پوچھو تو کہ آیا ان کا پیدا کرنا زیاده دشوار ہے یا (ان کا) جنہیں ہم نے (ان کے علاوه) پیدا کیا؟ ہم نے (انسانوں) کو لیس دار مٹی سے پیدا کیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccc{بلکہ تو تعجب کر رہا ہے اور یہ مسخرا پن کر رہے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccci{اور جب انہیں نصیحت کی جاتی ہے یہ نہیں مانتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcccii{اور جب کسی معجزے کو دیکھتے ہیں تو مذاق اڑاتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccciii{اور کہتے ہیں کہ یہ تو بالکل کھلم کھلا جادو ہی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccciv{کیا جب ہم مر جائیں گے اور خاک اور ہڈی ہو جائیں گے پھر کیا (سچ مچ) ہم اٹھائے جائیں گے؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcccv{کیا ہم سے پہلے کے ہمارے باپ دادا بھی؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvi{آپ جواب دیجئے! کہ ہاں ہاں اور تم ذلیل (بھی) ہوں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvii{وه تو صرف ایک زور کی جھڑکی ہے کہ یکایک یہ دیکھنے لگیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcccviii{اور کہیں گے کہ ہائے ہماری خرابی یہی جزا (سزا) کا دن ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcccix{یہی فیصلہ کا دن ہے جسے تم جھٹلاتے رہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcccx{ﻇالموں کو اور ان کے ہمراہیوں کو اور (جن) جن کی وه اللہ کے علاوه پرستش کرتے تھے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxi{(ان سب کو) جمع کرکے انہیں دوزخ کی راه دکھا دو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxii{اور انہیں ٹھہرا لو، (اس لئے) کہ ان سے (ضروری) سوال کیے جانے والے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiii{تمہیں کیا ہو گیا ہے کہ (اس وقت) تم ایک دوسرے کی مدد نہیں کرتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiv{بلکہ وه (سب کے سب) آج فرمانبردار بن گئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxv{وه ایک دوسرے کی طرف متوجہ ہو کر سوال وجواب کرنے لگیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvi{کہیں گے کہ تم تو ہمارے پاس ہماری دائیں طرف سے آتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvii{وه جواب دیں گے کہ نہیں بلکہ تم ہی ایمان والے نہ تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxviii{اور کچھ ہمارا زور تو تم پر تھا (ہی) نہیں۔ بلکہ تم (خود) سرکش لوگ تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxix{اب تو ہم (سب) پر ہمارے رب کی یہ بات ﺛابت ہو چکی کہ ہم (عذاب) چکھنے والے ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxx{پس ہم نے تمہیں گمراه کیا ہم تو خود بھی گمراه ہی تھے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxi{سو اب آج کے دن تو (سب کے سب) عذاب میں شریک ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxii{ہم گناه گاروں کے ساتھ اسی طرح کیا کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiii{یہ وه (لوگ) ہیں کہ جب ان سے کہا جاتا ہے کہ اللہ کے سوا کوئی معبود نہیں تو یہ سرکشی کرتے تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiv{اور کہتے تھے کہ کیا ہم اپنے معبودوں کو ایک دیوانے شاعر کی بات پر چھوڑ دیں؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxv{(نہیں نہیں) بلکہ (نبی) تو حق (سچا دین) ﻻئے ہیں اور سب رسولوں کو سچا جانتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvi{یقیناً تم دردناک عذاب (کا مزه) چکھنے والے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvii{تمہیں اسی کا بدلہ دیا جائے گا جو تم کرتے تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxviii{مگر اللہ تعالیٰ کے خالص برگزیده بندے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxix{انہیں کے لئے مقرره روزی ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxx{(ہر طرح کے) میوے، اور وه باعزت واکرام ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxi{نعمتوں والی جنتوں میں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxii{تختوں پر ایک دوسرے کے سامنے (بیٹھے) ہوں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiii{جاری شراب کے جام کا ان پر دور چل رہا ہوگا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiv{جو صاف شفاف اور پینے میں لذیذ ہوگی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxv{نہ اس سے درد سر ہو اور نہ اس کے پینے سے بہکیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvi{اور ان کے پاس نیچی نظروں، بڑی بڑی آنکھوں والی (حوریں) ہوں گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvii{ایسی جیسے چھپائے ہوئے انڈے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxviii{(جنتی) ایک دوسرے کی طرف رخ کرکے پوچھیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxix{ان میں سے ایک کہنے واﻻ کہے گا کہ میرا ایک ساتھی تھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxl{جو (مجھ سے) کہا کرتا تھا کہ کیا تو (قیامت کے آنے کا) یقین کرنے والوں میں سے ہے؟\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxli{کیا جب کہ ہم مر کر مٹی اور ہڈی ہو جائیں گے کیا اس وقت ہم جزا دیئے جانے والے ہیں؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlii{کہے گا تم چاہتے ہو کہ جھانک کر دیکھ لو؟\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliii{جھانکتے ہی اسے بیچوں بیچ جہنم میں (جلتا ہوا) دیکھے گا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliv{کہے گا واللہ! قریب تھا کہ تو مجھے (بھی) برباد کر دے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlv{اگر میرے رب کا احسان نہ ہوتا تو میں بھی دوزخ میں حاضر کئے جانے والوں میں ہوتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvi{کیا (یہ صحیح ہے) کہ ہم مرنے والے ہی نہیں؟\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvii{بجز پہلی ایک موت کے، اور نہ ہم عذاب کیے جانے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlviii{پھر تو (ﻇاہر بات ہے کہ) یہ بڑی کامیابی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlix{ایسی (کامیابی) کے لئے عمل کرنے والوں کو عمل کرنا چاہئے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcccl{کیا یہ مہمانی اچھی ہے یا سینڈھ (زقوم) کا درخت؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcccli{جسے ہم نے ﻇالموں کے لئے سخت آزمائش بنا رکھا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdccclii{بے شک وه درخت جہنم کی جڑ میں سے نکلتا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliii{جس کے خوشے شیطانوں کے سروں جیسے ہوتے ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliv{(جہنمی) اسی درخت سے کھائیں گے اور اسی سے پیٹ بھریں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdccclv{پھر اس پر گرم جلتے جلتے پانی کی ملونی ہوگی\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvi{پھر ان سب کا لوٹنا جہنم کی (آگ کے ڈھیرکی) طرف ہوگا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvii{یقین مانو! کہ انہوں نے اپنے باپ دادا کو بہکا ہوا پایا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdccclviii{اور یہ انہی کے نشان قدم پر دوڑتے رہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdccclix{ان سے پہلے بھی بہت سے اگلے بہک چکے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdccclx{جن میں ہم نے ڈرانے والے (رسول) بھیجے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxi{اب تو دیکھ لے کہ جنہیں دھمکایا گیا تھا ان کا انجام کیسا کچھ ہوا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxii{سوائے اللہ کے برگزیده بندوں کے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiii{اور ہمیں نوح (علیہ السلام) نے پکارا تو (دیکھ لو) ہم کیسے اچھے دعا قبول کرنے والے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiv{ہم نے اسے اور اس کے گھر والوں کو اس زبردست مصیبت سے بچا لیا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxv{اور اس کی اوﻻد کو ہم نے باقی رہنے والی بنا دی\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvi{اور ہم نے اس کا (ذکر خیر) پچھلوں میں باقی رکھا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvii{نوح (علیہ السلام) پر تمام جہانوں میں سلام ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxviii{ہم نیکی کرنے والوں کو اسی طرح بدلہ دیتے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxix{وه ہمارے ایمان والے بندوں میں سے تھا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxx{پھر ہم نے دوسروں کو ڈبو دیا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxi{اور اس (نوح علیہ السلام کی) تابعداری کرنے والوں میں سے (ہی) ابراہیم (علیہ السلام بھی) تھے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxii{جبکہ اپنے رب کے پاس بے عیب دل ﻻئے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiii{انہوں نے اپنے باپ اور اپنی قوم سے کہا کہ تم کیا پوج رہے ہو؟\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiv{کیا تم اللہ کے سوا گھڑے ہوئے معبود چاہتے ہو؟\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxv{تو یہ (بتلاؤ کہ) تم نے رب العالمین کو کیا سمجھ رکھا ہے؟\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvi{اب ابراہیم (علیہ السلام) نے ایک نگاه ستاروں کی طرف اٹھائی\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvii{اور کہا میں تو بیمار ہوں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxviii{اس پر وه سب اس سے منھ موڑے ہوئے واپس چلے گئے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxix{آپ (چﭗ چپاتے) ان کے معبودوں کے پاس گئے اور فرمانے لگے تم کھاتے کیوں نہیں؟\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxx{تمہیں کیا ہو گیا کہ بات تک نہیں کرتے ہو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxi{پھر تو (پوری قوت کے ساتھ) دائیں ہاتھ سے انہیں مارنے پر پل پڑے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxii{وه (بت پرست) دوڑے بھاگے آپ کی طرف متوجہ ہوئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiii{تو آپ نے فرمایا تم انہیں پوجتے ہو جنہیں (خود) تم تراشتے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiv{حاﻻنکہ تمہیں اور تمہاری بنائی ہوئی چیزوں کو اللہ ہی نے پیدا کیا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxv{وه کہنے لگے اس کے لئے ایک مکان بناؤ اور اس (دہکتی ہوئی) آگ میں اسے ڈال دو\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvi{انہوں نے تو اس (ابراہیم علیہ السلام) کے ساتھ مکر کرنا چاہا لیکن ہم نے انہی کو نیچا کر دیا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvii{اور اس (ابراہیم علیہ السلام) نے کہا میں تو ہجرت کر کے اپنے پروردگار کی طرف جانے واﻻ ہوں۔ وه ضرور میری رہنمائی کرے گا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxviii{اے میرے رب! مجھے نیک بخت اوﻻد عطا فرما\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxix{تو ہم نے اسے ایک بردبار بچے کی بشارت دی\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxc{پھر جب وه (بچہ) اتنی عمر کو پہنچا کہ اس کے ساتھ چلے پھرے، تو اس (ابراہیم علیہ السلام) نے کہا میرے پیارے بچے! میں خواب میں اپنے آپ کو تجھے ذبح کرتے ہوئے دیکھ رہا ہوں۔ اب تو بتا کہ تیری کیا رائے ہے؟ بیٹے نے جواب دیا کہ ابا! جو حکم ہوا ہے اسے بجا ﻻئیے انشاءاللہ آپ مجھے صبر کرنے والوں میں سے پائیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxci{غرض جب دونوں مطیع ہوگئے اور اس نے (باپ نے) اس کو (بیٹے کو) پیشانی کے بل گرا دیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcii{تو ہم نے آواز دی کہ اے ابراہیم!\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciii{یقیناً تو نے اپنے خواب کو سچا کر دکھایا، بیشک ہم نیکی کرنے والوں کو اسی طرح جزا دیتے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciv{درحقیقت یہ کھلا امتحان تھا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcv{اور ہم نے ایک بڑا ذبیحہ اس کے فدیہ میں دے دیا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvi{اور ہم نے ان کا ذکر خیر پچھلوں میں باقی رکھا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvii{ابراہیم (علیہ السلام) پر سلام ہو\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcviii{ہم نیکو کاروں کو اسی طرح بدلہ دیتے ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcix{بیشک وه ہمارے ایمان دار بندوں میں سے تھا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmcm{اور ہم نے اس کو اسحاق (علیہ السلام) نبی کی بشارت دی جو صالح لوگوں میں سے ہوگا\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmcmi{اور ہم نے ابراہیم واسحاق (علیہ السلام) پر برکتیں نازل فرمائیں، اور ان دونوں کی اوﻻد میں بعضے تو نیک بخت ہیں اور بعض اپنے نفس پر صریح ﻇلم کرنے والے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmcmii{یقیناً ہم نے موسیٰ اور ہارون (علیہ السلام) پر بڑا احسان کیا\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmcmiii{اور انہیں اور ان کی قوم کو بہت بڑے دکھ درد سے نجات دے دی\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmcmiv{اور ان کی مدد کی تو وہی غالب رہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmcmv{اور ہم نے انہیں (واضح اور) روشن کتاب دی\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmmcmvi{اور انہیں سیدھے راستہ پرقائم رکھا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmcmvii{اور ہم نے ان دونوں کے لئے پیچھے آنے والوں میں یہ بات باقی رکھی\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmcmviii{کہ موسیٰ اور ہارون (علیہما السلام) پر سلام ہو\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmcmix{بے شک ہم نیک لوگوں کو اسی طرح بدلے دیا کرتے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmcmx{یقیناً یہ دونوں ہمارے مومن بندوں میں سے تھے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmcmxi{بے شک الیاس (علیہ السلام) بھی پیغمبروں میں سے تھے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmcmxii{جب کہ انہوں نے اپنی قوم سے فرمایا کہ تم اللہ سے ڈرتے نہیں ہو؟\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiii{کیا تم بعل (نامی بت) کو پکارتے ہو؟ اور سب سے بہتر خالق کو چھوڑ دیتے ہو؟\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiv{اللہ جو تمہارا اور تمہارے اگلے تمام باپ دادوں کا رب ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmcmxv{لیکن قوم نے انہیں جھٹلایا، پس وه ضرور (عذاب میں) حاضر رکھے جائیں گے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvi{سوائے اللہ تعالی کے مخلص بندوں کے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvii{ہم نے (الیاس علیہ السلام) کا ذکر خیر پچھلوں میں بھی باقی رکھا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmcmxviii{کہ الیاس پر سلام ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmcmxix{ہم نیکی کرنے والوں کو اسی طرح بدلہ دیتے ہیں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmcmxx{بیشک وه ہمارے ایمان دار بندوں میں سے تھے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxi{بیشک لوط (علیہ السلام بھی) پیغمبروں میں سے تھے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxii{ہم نے انہیں اور ان کے گھر والوں کو سب کو نجات دی\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiii{بجز اس بڑھیا کے جو پیچھے ره جانے والوں میں سے ره گئی\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiv{پھر ہم نے اوروں کو ہلاک کر دیا\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxv{اور تم تو صبح ہونے پر ان کی بستیوں کے پاس سے گزرتے ہو\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvi{اور رات کو بھی، کیا پھر بھی نہیں سمجھتے؟\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvii{اور بلاشبہ یونس (علیہ السلام) نبیوں میں سے تھے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxviii{جب بھاگ کر پہنچے بھری کشتی پر\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxix{پھر قرعہ اندازی ہوئی تو یہ مغلوب ہوگئے\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxx{تو پھر انہیں مچھلی نے نگل لیا اور وه خود اپنے آپ کو ملامت کرنے لگ گئے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxi{پس اگر یہ پاکی بیان کرنے والوں میں سے نہ ہوتے\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxii{تو لوگوں کے اٹھائے جانے کے دن تک اس کے پیٹ میں ہی رہتے\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiii{پس انہیں ہم نے چٹیل میدان میں ڈال دیا اور وه اس وقت بیمار تھے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiv{اور ان پر سایہ کرنے واﻻ ایک بیل دار درخت ہم نے اگا دیا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxv{اور ہم نے انہیں ایک لاکھ بلکہ اور زیاده آدمیوں کی طرف بھیجا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvi{پس وه ایمان ﻻئے، اور ہم نے انہیں ایک زمانہ تک عیش وعشرت دی\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvii{ان سے دریافت کیجئے! کہ کیا آپ کے رب کی تو بیٹیاں ہیں اور ان کے بیٹے ہیں؟\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxviii{یا یہ اس وقت موجود تھے جبکہ ہم نے فرشتوں کو مؤنﺚ پیدا کیا\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxix{آگاه رہو! کہ یہ لوگ صرف اپنی افترا پردازی سے کہہ رہے ہیں\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmcmxl{کہ اللہ تعالی کی اوﻻد ہے۔ یقیناً یہ محض جھوٹے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmcmxli{کیا اللہ تعالی نے اپنے لیے بیٹیوں کو بیٹوں پر ترجیح دی\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlii{تمہیں کیا ہو گیا ہے کیسے حکم لگاتے پھرتے ہو؟\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliii{کیا تم اس قدر بھی نہیں سمجھتے؟\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliv{یا تمہارے پاس اس کی کوئی صاف دلیل ہے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlv{تو جاؤ اگر سچے ہو تو اپنی ہی کتاب لے آؤ\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvi{اور ان لوگوں نے تو اللہ کے اور جنات کے درمیان بھی قرابت داری ٹھہرائی ہے، اور حاﻻنکہ خود جنات کو معلوم ہے کہ وه (اس عقیده کے لوگ عذاب کے سامنے) پیش کیے جائیں گے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvii{جو کچھ یہ (اللہ کے بارے میں) بیان کر رہے ہیں اس سے اللہ تعالیٰ بالکل پاک ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlviii{سوائے! اللہ کے مخلص بندوں کے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlix{یقین مانو کہ تم سب اور تمہارے معبودان (باطل)\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmcml{کسی ایک کو بھی بہکا نہیں سکتے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmcmli{بجز اس کے جو جہنمی ہی ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmcmlii{(فرشتوں کا قول ہے کہ) ہم میں سے تو ہر ایک کی جگہ مقرر ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmcmliii{اور ہم تو (بندگیٴ الٰہی میں) صف بستہ کھڑے ہیں\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmcmliv{اور اس کی تسبیح بیان کر رہے ہیں\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmcmlv{کفار تو کہا کرتے تھے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvi{کہ اگر ہمارے سامنے اگلے لوگوں کا ذکر ہوتا\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvii{تو ہم بھی اللہ کے چیده بندے بن جاتے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcmlviii{لیکن پھر اس قرآن کے ساتھ کفر کر گئے، پس اب عنقریب جان لیں گے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmcmlix{اور البتہ ہمارا وعده پہلے ہی اپنے رسولوں کے لئے صادر ہو چکا ہے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmcmlx{کہ یقیناً وه ہی مدد کیے جائیں گے\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxi{اور ہمارا ہی لشکر غالب (اور برتر) رہے گا\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxii{اب آپ کچھ دنوں تک ان سے منھ پھیر لیجئے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiii{اور انہیں دیکھتے رہیئے، اور یہ بھی آگے چل کر دیکھ لیں گے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiv{کیا یہ ہمارے عذاب کی جلدی مچا رہے ہیں؟\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxv{سنو! جب ہمارا عذاب ان کے میدان میں اتر آئے گا اس وقت ان کی جن کو متنبہ کر دیا گیا تھا بڑی بری صبح ہوگی\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvi{آپ کچھ وقت تک ان کا خیال چھوڑ دیجئے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvii{اور دیکھتے رہئیے یہ بھی ابھی ابھی دیکھ لیں گے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxviii{پاک ہے آپ کا رب جو بہت بڑی عزت واﻻ ہے ہر اس چیز سے (جو مشرک) بیان کرتے ہیں\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxix{پیغمبروں پر سلام ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxx{اور سب طرح کی تعریف اللہ کے لئے ہے جو سارے جہان کا رب ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxi{\basmalahur ص! اس نصیحت والے قرآن کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxii{بلکہ کفار غرور ومخالفت میں پڑے ہوئے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiii{ہم نے ان سے پہلے بھی بہت سی امتوں کو تباه کر ڈاﻻ انہوں نے ہر چند چیﺦ وپکار کی لیکن وه وقت چھٹکارے کا نہ تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiv{اور کافروں کو اس بات پر تعجب ہوا کہ ان ہی میں سے ایک انہیں ڈرانے واﻻ آگیا اور کہنے لگے کہ یہ تو جادوگر اور جھوٹا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxv{کیا اس نےاتنے سارے معبودوں کا ایک ہی معبود کر دیا واقعی یہ بہت ہی عجیب بات ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvi{ان کے سردار یہ کہتے ہوئے چلے کہ چلو جی اور اپنے معبودوں پر جمے رہو، یقیناً اس بات میں تو کوئی غرض ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvii{ہم نے تو یہ بات پچھلے دین میں بھی نہیں سنی، کچھ نہیں یہ تو صرف گھڑنت ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxviii{کیا ہم سب میں سے اسی پر کلام الٰہی نازل کیا گیا ہے؟ دراصل یہ لوگ میری وحی کی طرف سے شک میں ہیں، بلکہ (صحیح یہ ہے کہ) انہوں نے اب تک میرا عذاب چکھا ہی نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxix{یا کیا ان کے پاس تیرے زبردست فیاض رب کی رحمت کے خزانے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxx{یا کیا آسمان وزمین اور ان کے درمیان کی ہر چیز کی بادشاہت ان ہی کی ہے، تو پھر یہ رسیاں تان کر چڑھ جائیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxi{یہ بھی (بڑے بڑے) لشکروں میں سے شکست پایا ہوا (چھوٹا سا) لشکر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxii{ان سے پہلے بھی قوم نوح اور عاد اور میخوں والے فرعون نے جھٹلایا تھا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiii{اور ﺛمود نے اور قوم لوط نے اور ایکہ کے رہنے والوں نے بھی، یہی (بڑے) لشکر تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiv{ان میں سے ایک بھی ایسا نہ تھا جس نے رسولوں کی تکذیب نہ کی ہو پس میری سزا ان پر ﺛابت ہوگئی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxv{انہیں صرف ایک چیﺦ کا انتظار ہے جس میں کوئی توقف (اور ڈھیل) نہیں ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvi{اور انہوں نے کہا کہ اے ہمارے رب! ہماری سرنوشت تو ہمیں روز حساب سے پہلے ہی دے دے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvii{آپ ان کی باتوں پر صبر کریں اور ہمارے بندے داؤد (علیہ السلام) کو یاد کریں جو بڑی قوت واﻻ تھا، یقیناً وه بہت رجوع کرنے واﻻ تھا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxviii{ہم نے پہاڑوں کو اس کے تابع کر رکھا تھا کہ اس کے ساتھ شام کو اور صبح کو تسبیح خوانی کریں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxix{اور پرندوں کو بھی جمع ہو کر سب کے سب اس کے زیر فرمان رہتے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcmxc{اور ہم نے اس کی سلطنت کو مضبوط کر دیا تھا اور اسے حکمت دی تھی اور بات کا فیصلہ کرنا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcmxci{اور کیا تجھے جھگڑا کرنے والوں کی (بھی) خبر ملی؟ جبکہ وه دیوار پھاند کر محراب میں آگئے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcii{جب یہ (حضرت) داؤد (علیہ السلام) کے پاس پہنچے، پس یہ ان سے ڈر گئے، انہوں نے کہا خوف نہ کیجئے! ہم دو فریق مقدمہ ہیں، ہم میں سے ایک نے دوسرے پر زیادتی کی ہے، پس آپ ہمارے درمیان حق کے ساتھ فیصلہ کر دیجئے اور ناانصافی نہ کیجئے اور ہمیں سیدھی راه بتا دیجئے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciii{(سنیے) یہ میرا بھائی ہے اس کے پاس نناوے دنبیاں ہیں اور میرے پاس ایک ہی دنبی ہے لیکن یہ مجھ سے کہہ رہا ہے کہ اپنی یہ ایک بھی مجھ ہی کو دے دے اور مجھ پر بات میں بڑی سختی برتتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciv{آپ نے فرمایا! اس کا اپنی دنبیوں کے ساتھ تیری ایک دنبی ملا لینے کا سوال بیشک تیرے اوپر ایک ﻇلم ہے اور اکثر حصہ دار اور شریک (ایسے ہی ہوتے ہیں کہ) ایک دوسرے پر ﻇلم کرتے ہیں، سوائے ان کے جو ایمان ﻻئے اور جنہوں نے نیک عمل کیے اور ایسے لوگ بہت ہی کم ہیں اور (حضرت) داؤد (علیہ السلام) سمجھ گئے کہ ہم نے انہیں آزمایا ہے، پھر تو اپنے رب سے استغفار کرنے لگے اور عاجزی کرتے ہوئے گر پڑے اور (پوری طرح) رجوع کیا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcv{پس ہم نے بھی ان کا وه (قصور) معاف کر دیا، یقیناً وه ہمارے نزدیک بڑے مرتبہ والے اور بہت اچھے ٹھکانے والے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvi{اے داؤد! ہم نے تمہیں زمین میں خلیفہ بنا دیا تم لوگوں کے درمیان حق کے ساتھ فیصلے کرو اور اپنی نفسانی خواہش کی پیروی نہ کرو ورنہ وه تمہیں اللہ کی راه سے بھٹکا دے گی، یقیناً جو لوگ اللہ کی راه سے بھٹک جاتے ہیں ان کے لئے سخت عذاب ہے اس لئے کہ انہوں نے حساب کے دن کو بھلا دیا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvii{اور ہم نے آسمان وزمین اور ان کے درمیان کی چیزوں کو ناحق پیدا نہیں کیا، یہ گمان تو کافروں کا ہے سو کافروں کے لئے خرابی ہے آگ کی۔\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcviii{کیا ہم ان لوگوں کو جو ایمان ﻻئے اور نیک عمل کیے ان کے برابر کر دیں گے جو (ہمیشہ) زمین میں فساد مچاتے رہے، یا پرہیزگاروں کو بدکاروں جیسا کر دینگے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcix{یہ بابرکت کتاب ہے جسے ہم نے آپ کی طرف اس لئے نازل فرمایا ہے کہ لوگ اس کی آیتوں پر غور وفکر کریں اور عقلمند اس سے نصیحت حاصل کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmm{اور ہم نے داؤد کو سلیمان (نامی فرزند) عطا فرمایا، جو بڑا اچھا بنده تھا اور بے حد رجوع کرنے واﻻ تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmi{جب ان کے سامنے شام کے وقت تیز رو خاصے گھوڑے پیش کیے گئے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmii{تو کہنے لگے میں نے اپنے پروردگار کی یاد پر ان گھوڑوں کی محبت کو ترجیح دی، یہاں تک کہ (آفتاب) چھﭗ گیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmiii{ان (گھوڑوں) کو دوباره میرے سامنے ﻻؤ! پھر تو پنڈلیوں اور گردنوں پر ہاتھ پھیرنا شروع کر دیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmiv{اور ہم نے سلیمان (علیہ السلام) کی آزمائش کی اور ان کے تخت پر ایک جسم ڈال دیا پھر اس نے رجوع کیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmv{کہا کہ اے میرے رب! مجھے بخش دے اور مجھے ایسا ملک عطا فرما جو میرے سوا کسی (شخص) کے ﻻئق نہ ہو، تو بڑا ہی دینے واﻻ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmvi{پس ہم نے ہوا کو ان کے ماتحت کر دیا اور آپ کے حکم سے جہاں آپ چاہتے نرمی سے پہنچا دیا کرتی تھی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmvii{اور (طاقت ور) جنات کو بھی (ان کا ماتحت کر دیا) ہر عمارت بنانے والے کو اور غوطہ خور کو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmviii{اور دوسرے جنات کو بھی جو زنجیروں میں جکڑے رہتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmix{یہ ہے ہمارا عطیہ اب تو احسان کر یا روک رکھ، کچھ حساب نہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmx{ان کے لئے ہمارے پاس بڑا تقرب ہے اور بہت اچھا ٹھکانا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxi{اور ہمارے بندے ایوب (علیہ السلام) کا (بھی) ذکر کر، جبکہ اس نے اپنے رب کو پکارا کہ مجھے شیطان نے رنج اور دکھ پہنچایا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmxii{اپنا پاؤں مارو، یہ نہانے کا ٹھنڈا اور پینے کا پانی ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmxiii{اور ہم نے اسے اس کا پورا کنبہ عطا فرمایا بلکہ اتنا ہی اور بھی اسی کے ساتھ اپنی (خاص) رحمت سے، اور عقلمندوں کی نصیحت کے لئے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmxiv{اور اپنے ہاتھوں میں تنکوں کا ایک مٹھا (جھاڑو) لے کر مار دے اور قسم کے خلاف نہ کر، سچ تو یہ ہے کہ ہم نے اسے بڑا صابر بنده پایا، وه بڑا نیک بنده تھا اور بڑی ہی رغبت رکھنے واﻻ\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmxv{ہمارے بندوں ابراہیم، اسحاق اور یعقوب (علیہم السلام) کا بھی لوگوں سے ذکر کرو جو ہاتھوں اور آنکھوں والے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmxvi{ہم نے انہیں ایک خاص بات یعنی آخرت کی یاد کے ساتھ مخصوص کر دیا تھا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmxvii{یہ سب ہمارے نزدیک برگزیده اور بہترین لوگ تھے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmxviii{اسماعیل، یسع اور ذوالکفل (علیہم السلام) کا بھی ذکر کر دیجئے۔ یہ سب بہترین لوگ تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmxix{یہ نصیحت ہے اور یقین مانو کہ پرہیزگاروں کی بڑی اچھی جگہ ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmxx{(یعنی ہمیشگی والی) جنتیں جن کے دروازے ان کے لئے کھلے ہوئے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmxxi{جن میں بافراغت تکیے لگائے بیٹھے ہوئے طرح طرح کے میوے اور قسم قسم کی شرابوں کی فرمائشیں کر رہے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmxxii{اور ان کے پاس نیچی نظروں والی ہم عمر حوریں ہوں گی\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiii{یہ ہے جس کا وعده تم سے حساب کے دن کے لئے کیا جاتا تھا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiv{بیشک روزیاں (خاص) ہمارا عطیہ ہیں جن کا کبھی خاتمہ ہی نہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmxxv{یہ تو ہوئی جزا، (یاد رکھو کہ) سرکشوں کے لئے بڑی بری جگہ ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvi{دوزخ ہے جس میں وه جائیں گے (آه) کیا ہی برا بچھونا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvii{یہ ہے، پس اسے چکھیں، گرم پانی اور پیﭗ\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmxxviii{اس کے علاوه اور طرح طرح کے عذاب\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmxxix{یہ ایک قوم ہے جو تمہارے ساتھ (آگ میں) جانے والی ہے، کوئی خوش آمدید ان کے لئے نہیں ہے یہی تو جہنم میں جانے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmxxx{وه کہیں گے بلکہ تم ہی ہو جن کے لئے کوئی خوش آمدید نہیں ہے تم ہی نے تو اسے پہلے ہی سے ہمارے سامنے ﻻ رکھا تھا، پس رہنے کی بڑی بری جگہ ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxi{وه کہیں گے اے ہمارے رب! جس نے (کفر کی رسم) ہمارے لئے پہلے سے نکالی ہو اس کے حق میں جہنم کی دگنی سزا کر دے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxii{اور جہنمی کہیں گے کیا بات ہے کہ وه لوگ ہمیں دکھائی نہیں دیتے جنہیں ہم برے لوگوں میں شمار کرتے تھے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiii{کیا ہم نے ہی ان کا مذاق بنا رکھا تھا یا ہماری نگاہیں ان سے ہٹ گئی ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiv{یقین جانو کہ دوزخیوں کا یہ جھگڑا ضرور ہی ہوگا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxv{کہہ دیجئے! کہ میں تو صرف خبردار کرنے واﻻ ہوں اور بجز اللہ واحد غالب کے اور کوئی ﻻئق عبادت نہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvi{جو پروردگار ہے آسمانوں کا اور زمین کا اور جو کچھ ان کے درمیان ہے، وه زبردست اور بڑا بخشنے واﻻ ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvii{آپ کہہ دیجئے کہ یہ بہت بڑی خبر ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxviii{جس سے تم بے پرواه ہو رہے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxix{مجھے ان بلند قدر فرشتوں کی (بات چیت کا) کوئی علم ہی نہیں جبکہ وه تکرار کر رہے تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmxl{میری طرف فقط یہی وحی کی جاتی ہے کہ میں تو صاف صاف آگاه کر دینے واﻻ ہوں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmxli{جبکہ آپ کے رب نے فرشتوں سے ارشاد فرمایا کہ میں مٹی سے انسان کو پیدا کرنے واﻻ ہوں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmxlii{سو جب میں اسے ٹھیک ٹھاک کر لوں اور اس میں اپنی روح پھونک دوں، تو تم سب اس کے سامنے سجدے میں گر پڑنا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmxliii{چنانچہ تمام فرشتوں نے سجده کیا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmxliv{مگر ابلیس نے (نہ کیا)، اس نے تکبر کیا اور وه تھا کافروں میں سے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmxlv{(اللہ تعالیٰ نے) فرمایا اے ابلیس! تجھے اسے سجده کرنے سے کس چیز نے روکا جسے میں نے اپنے ہاتھوں سے پیدا کیا۔ کیا تو کچھ گھمنڈ میں آگیا ہے؟ یا تو بڑے درجے والوں میں سے ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvi{اس نے جواب دیا کہ میں اس سے بہتر ہوں، تو نے مجھے آگ سے بنایا، اور اسے مٹی سے بنایا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvii{ارشاد ہوا کہ تو یہاں سے نکل جا تو مردود ہوا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmxlviii{اور تجھ پر قیامت کے دن تک میری لعنت وپھٹکار ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmxlix{کہنے لگا میرے رب مجھے لوگوں کے اٹھ کھڑے ہونے کے دن تک مہلت دے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmml{(اللہ تعالیٰ نے) فرمایا تو مہلت والوں میں سے ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmli{متعین وقت کے دن تک\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmlii{کہنے لگا پھر تو تیری عزت کی قسم! میں ان سب کو یقیناً بہکا دوں گا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmliii{بجز تیرے ان بندوں کے جو چیده اور پسندیده ہوں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmliv{فرمایا سچ تو یہ ہے، اور میں سچ ہی کہا کرتا ہوں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmlv{کہ تجھ سے اور تیرے تمام ماننے والوں سے میں (بھی) جہنم کو بھر دوں گا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmlvi{کہہ دیجئے کہ میں تم سے اس پر کوئی بدلہ طلب نہیں کرتا اور نہ میں تکلف کرنے والوں میں سے ہوں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmlvii{یہ تو تمام جہان والوں کے لئے سراسر نصیحت (وعبرت) ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmlviii{یقیناً تم اس کی حقیقت کو کچھ ہی وقت کے بعد (صحیح طور پر) جان لو گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmlix{\basmalahur اس کتاب کا اتارنا اللہ تعالیٰ غالب باحکمت کی طرف سے ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmlx{یقیناً ہم نے اس کتاب کو آپ کی طرف حق کے ساتھ نازل فرمایا ہے پس آپ اللہ ہی کی عبادت کریں، اسی کے لئے دین کو خالص کرتے ہوئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmlxi{خبردار! اللہ تعالیٰ ہی کے لئے خالص عبادت کرنا ہے اور جن لوگوں نے اس کے سوا اولیا بنا رکھے ہیں (اور کہتے ہیں) کہ ہم ان کی عبادت صرف اس لئے کرتے ہیں کہ یہ (بزرگ) اللہ کی نزدیکی کے مرتبہ تک ہماری رسائی کرا دیں، یہ لوگ جس بارے میں اختلاف کر رہے ہیں اس کا (سچا) فیصلہ اللہ (خود) کرے گا۔ جھوٹے اور ناشکرے (لوگوں) کو اللہ تعالیٰ راه نہیں دکھاتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmlxii{اگر اللہ تعالیٰ کااراده اوﻻد ہی کا ہوتا تو اپنی مخلوق میں سے جسے چاہتا چن لیتا۔ (لیکن) وه تو پاک ہے، وه وہی اللہ تعالیٰ ہے یگانہ اور قوت واﻻ\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiii{نہایت اچھی تدبیر سے اس نے آسمانوں اور زمین کو بنایا وه رات کو دن اور دن کو رات پر لپیٹ دیتا ہے اور اس نے سورج اور چاند کو کام پر لگا رکھا ہے۔ ہر ایک مقرره مدت تک چل رہا ہے یقین مانو کہ وہی زبردست اور گناہوں کا بخشنے واﻻ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiv{اس نے تم سب کو ایک ہی جان سے پیدا کیا ہے، پھر اسی سے اس کا جوڑا پیدا کیا اور تمہارے لئے چوپایوں میں سے (آٹھ نر وماده) اتارے وه تمہیں تمہاری ماؤں کے پیٹوں میں ایک بناوٹ کے بعد دوسری بناوٹ پر بناتا ہے تین تین اندھیروں میں، یہی اللہ تعالیٰ تمہارا رب ہے اسی کے لئے بادشاہت ہے، اس کے سوا کوئی معبود نہیں، پھر تم کہاں بہک رہے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmlxv{اگر تم ناشکری کرو تو (یاد رکھو کہ) اللہ تعالیٰ تم (سب سے) بے نیاز ہے، اور وه اپنے بندوں کی ناشکری سے خوش نہیں اور اگر تم شکر کرو تو وه اسے تمہارے لئے پسند کرے گا۔ اور کوئی کسی کا بوجھ نہیں اٹھاتا پھر تم سب کا لوٹنا تمہارے رب ہی کی طرف ہے۔ تمہیں وه بتلا دے گا جو تم کرتے تھے۔ یقیناً وه دلوں تک کی باتوں کا واقف ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvi{اور انسان کو جب کبھی کوئی تکلیف پہنچتی ہے تو وه خوب رجوع ہو کر اپنے رب کو پکارتا ہے، پھر جب اللہ تعالیٰ اسے اپنے پاس سے نعمت عطا فرمادیتا ہے تو وه اس سے پہلے جو دعا کرتا تھا اسے (بالکل) بھول جاتا ہے اور اللہ تعالیٰ کے شریک مقرر کرنے لگتا ہے جس سے (اوروں کو بھی) اس کی راه سے بہکائے، آپ کہہ دیجئے! کہ اپنے کفر کا فائده کچھ دن اور اٹھالو، (آخر) تو دوزخیوں میں ہونے واﻻ ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvii{بھلا جو شخص راتوں کے اوقات سجدے اور قیام کی حالت میں (عبادت میں) گزارتا ہو، آخرت سے ڈرتا ہو اور اپنے رب کی رحمت کی امید رکھتا ہو، (اور جو اس کے برعکس ہو برابر ہو سکتے ہیں) بتاؤ تو علم والے اور بے علم کیا برابر کے ہیں؟ یقیناً نصیحت وہی حاصل کرتے ہیں جو عقلمند ہوں۔ (اپنے رب کی طرف سے)\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmlxviii{کہہ دو کہ اے میرے ایمان والے بندو! اپنے رب سے ڈرتے رہو، جو اس دنیا میں نیکی کرتے ہیں ان کے لئے نیک بدلہ ہے اور اللہ تعالیٰ کی زمین بہت کشاده ہے صبر کرنے والوں ہی کو ان کا پورا پورا بےشمار اجر دیا جاتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmlxix{آپ کہہ دیجئے! کہ مجھے حکم دیا گیا ہے کہ اللہ تعالیٰ کی اس طرح عبادت کروں کہ اسی کے لئے عبادت کو خالص کر لوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmlxx{اور مجھے حکم دیا گیا ہے کہ میں سب سے پہلا فرماں بردار بن جاؤں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxi{کہہ دیجئے! کہ مجھے تو اپنے رب کی نافرمانی کرتے ہوئے بڑے دن کے عذاب کا خوف لگتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxii{کہہ دیجئے! کہ میں تو خالص کر کے صرف اپنے رب ہی کی عبادت کرتا ہوں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiii{تم اس کے سوا جس کی چاہو عبادت کرتے رہو کہہ دیجئے! کہ حقیقی زیاں کار وه ہیں جو اپنے آپ کو اور اپنے اہل کو قیامت کے دن نقصان میں ڈال دیں گے، یاد رکھو کہ کھلم کھلا نقصان یہی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiv{انہیں نیچے اوپر سے آگ کے (شعلے مثل) سائبان (کے) ڈھانک رہے ہوں گے۔ یہی (عذاب) ہے جن سے اللہ تعالیٰ اپنے بندوں کو ڈرا رہا ہے، اے میرے بندو! پس مجھ سے ڈرتے رہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxv{اور جن لوگوں نے طاغوت کی عبادت سے پرہیز کیا اور (ہمہ تن) اللہ تعالیٰ کی طرف متوجہ رہے وه خوش خبری کے مستحق ہیں، میرے بندوں کو خوشخبری سنا دیجئے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvi{جو بات کو کان لگا کر سنتے ہیں۔ پھر جو بہترین بات ہو اس کی اتباع کرتے ہیں۔ یہی ہیں جنہیں اللہ تعالیٰ نے ہدایت کی ہے اور یہی عقلمند بھی ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvii{بھلا جس شخص پر عذاب کی بات ﺛابت ہو چکی ہے، تو کیا آپ اسے جو دوزخ میں ہے چھڑا سکتے ہیں؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxviii{ہاں وه لوگ جو اپنے رب سے ڈرتے رہے ان کے لئے باﻻ خانے ہیں جن کے اوپر بھی بنے بنائے باﻻ خانے ہیں (اور) ان کے نیچے نہریں بہہ رہی ہیں۔ رب کا وعده ہے اور وه وعده خلافی نہیں کرتا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxix{کیا آپ نے نہیں دیکھا کہ اللہ تعالیٰ آسمان سے پانی اتارتا ہے اور اسے زمین کی سوتوں میں پہنچاتا ہے، پھر اسی کے ذریعہ سے مختلف قسم کی کھیتیاں اگاتا ہے پھر وه خشک ہو جاتی ہیں اور آپ انہیں زرد رنگ دیکھتے ہیں پھر انہیں ریزه ریزه کر دیتا ہے، اس میں عقل مندوں کے لئے بہت زیاده نصیحت ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxx{کیا وه شخص جس کا سینہ اللہ تعالیٰ نےاسلام کے لئے کھول دیا ہے پس وه اپنے پروردگار کی طرف سے ایک نور پر ہے اور ہلاکی ہے ان پر جن کے دل یاد الٰہی سے (اﺛر نہیں لیتے بلکہ) سخت ہو گئے ہیں۔ یہ لوگ صریح گمراہی میں (مبتلا) ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxi{اللہ تعالیٰ نے بہترین کلام نازل فرمایا ہے جو ایسی کتاب ہے کہ آپس میں ملتی جلتی اور بار بار دہرائی ہوئی آیتوں کی ہے، جس سے ان لوگوں کے رونگٹے کھڑے ہو جاتے ہیں جو اپنے رب کا خوف رکھتے ہیں آخر میں ان کے جسم اور دل اللہ تعالیٰ کے ذکر کی طرف نرم ہو جاتے ہیں، یہ ہے اللہ تعالیٰ کی ہدایت جس کے ذریعہ جسے چاہے راه راست پر لگا دیتا ہے۔ اور جسے اللہ تعالیٰ ہی راه بھلا دے اس کا ہادی کوئی نہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxii{بھلا جو شخص قیامت کے دن کے بدترین عذاب کی سپر (ڈھال) اپنے منھ کو بنائے گا۔ (ایسے) ﻇالموں سے کہا جائے گا کہ اپنے کیے کا (وبال) چکھو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiii{ان سے پہلے والوں نے بھی جھٹلایا، پھر ان پر وہاں سے عذاب آپڑا جہاں سے ان کو خیال بھی نہ تھا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiv{اور اللہ تعالیٰ نے انہیں زندگانی دنیا میں رسوائی کا مزه چکھایا اور ابھی آخرت کا تو بڑا بھاری عذاب ہے کاش کہ یہ لوگ سمجھ لیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxv{اور یقیناً ہم نے اس قرآن میں لوگوں کے لئے ہر قسم کی مثالیں بیان کر دیں ہیں کیا عجب کہ وه نصیحت حاصل کر لیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvi{قرآن ہے عربی میں جس میں کوئی کجی نہیں، ہو سکتا ہے کہ وه پرہیزگاری اختیار کر لیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvii{اللہ تعالیٰ مثال بیان فرما رہا ہے ایک وه شخص جس میں بہت سے باہم ضد رکھنے والے ساجھی ہیں، اور دوسرا وه شخص جو صرف ایک ہی کا (غلام) ہے، کیا یہ دونوں صفت میں یکساں ہیں، اللہ تعالیٰ ہی کے لئے سب تعریف ہے۔ بات یہ ہے کہ ان میں کے اکثر لوگ سمجھتے نہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxviii{یقیناً خود آپ کو بھی موت آئے گی اور یہ سب بھی مرنے والے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxix{پھر تم سب کے سب قیامت والے دن اپنے رب کے سامنے جھگڑو گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmxc{اس سے بڑھ کر ظالم کون ہے جو اللہ تعالیٰ پر جھوٹ بولے؟ اور سچا دین جب اس کے پاس آئے تو اسے جھوٹا بتائے؟ کیا ایسے کفار کے لیے جہنم ٹھکانا نہیں ہے؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmxci{اور جو سچے دین کو ﻻئے اور جس نے اس کی تصدیق کی یہی لوگ پارسا ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmxcii{ان کے لیے ان کے رب کے پاس (ہر) وه چیز ہے جو یہ چاہیں، نیک لوگوں کا یہی بدلہ ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmxciii{تاکہ اللہ تعالیٰ ان سے ان کے برے عملوں کو دور کردے اور جو نیک کام انہوں نے کیے ہیں ان کا اچھا بدلہ عطا فرمائے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmxciv{کیا اللہ تعالیٰ اپنے بندے کے لیے کافی نہیں؟ یہ لوگ آپ کو اللہ کے سوا اوروں سے ڈرا رہے ہیں اور جسے اللہ گمراه کر دےاس کی رہنمائی کرنے واﻻ کوئی نہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmxcv{اور جسے وه ہدایت دے اسے کوئی گمراه کرنے واﻻ نہیں کیا اللہ تعالیٰ غالب اور بدلہ لینے واﻻ نہیں ہے؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvi{اگر آپ ان سے پوچھیں کہ آسمان و زمین کو کس نے پیدا کیا ہے؟ تو یقیناً وه یہی جواب دیں گے کہ اللہ نے۔ آپ ان سے کہئیے کہ اچھا یہ تو بتاؤ جنہیں تم اللہ کے سوا پکارتے ہو اگر اللہ تعالی مجھے نقصان پہنچانا چاہے توکیا یہ اس کے نقصان کو ہٹا سکتے ہیں؟ یا اللہ تعالیٰ مجھ پر مہربانی کا اراده کرے تو کیا یہ اس کی مہربانی کو روک سکتے ہیں؟ آپ کہہ دیں کہ اللہ مجھے کافی ہے، توکل کرنے والے اسی پر توکل کرتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvii{کہہ دیجیئے کہ اے میری قوم! تم اپنی جگہ پر عمل کیے جاؤ میں بھی عمل کر رہا ہوں، ابھی ابھی تم جان لوگے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmxcviii{کہ کس پر رسوا کرنے واﻻ عذاب آتا ہے اور کس پر دائمی مار اور ہمیشگی کی سزا ہوتی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxcix{آپ پر ہم نے حق کے ساتھ یہ کتاب لوگوں کے لیے نازل فرمائی ہے، پس جو شخص راه راست پر آجائے اس کے اپنے لیے نفع ہے اور جو گمراه ہوجائے اس کی گمراہی کا (وبال) اسی پر ہے، آپ ان کے ذمہ دار نہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmc{اللہ ہی روحوں کو ان کی موت کے وقت اور جن کی موت نہیں آئی انہیں ان کی نیند کے وقت قبض کر لیتا ہے، پھر جن پر موت کا حکم لگ چکا ہے انہیں تو روک لیتا ہے اور دوسری (روحوں) کو ایک مقرر وقت تک کے لیے چھوڑ دیتا ہے۔ غور کرنے والوں کے لیے اس میں یقیناً بہت سی نشانیاں ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmci{کیا ان لوگوں نے اللہ تعالی کے سوا (اوروں) کو سفارشی مقرر کر رکھا ہے؟ آپ کہہ دیجیئے! کہ گو وه کچھ بھی اختیار نہ رکھتے ہوں اور نہ عقل رکھتے ہوں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcii{کہہ دیجئے! کہ تمام سفارش کا مختار اللہ ہی ہے۔ تمام آسمانوں اور زمین کا راج اسی کے لیے ہے تم سب اسی کی طرف پھیرے جاؤ گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmciii{جب اللہ اکیلے کا ذکر کیا جائے تو ان لوگوں کے دل نفرت کرنے لگتے ہیں جو آخرت کایقین نہیں رکھتے اور جب اس کے سوا (اور کا) ذکر کیا جائے تو ان کے دل کھل کر خوش ہو جاتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmciv{آپ کہہ دیجئے! کہ اے اللہ! آسمانوں اور زمین کے پیدا کرنے والے، چھپے کھلے کے جاننے والے تو ہی اپنے بندوں میں ان امور کا فیصلہ فرمائے گا جن میں وه الجھ رہے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcv{اگر ﻇلم کرنے والوں کے پاس وه سب کچھ ہو جو روئے زمین پر ہے اور اس کے ساتھ اتنا ہی اور ہو، تو بھی بدترین سزا کے بدلے میں قیامت کے دن یہ سب کچھ دے دیں، اور ان کے سامنے اللہ کی طرف سے وه ﻇاہر ہوگا جس کا گمان بھی انہیں نہ تھا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcvi{جو کچھ انہوں نے کیا تھا اس کی برائیاں ان پر کھل پڑیں گی اور جس کا وه مذاق کرتے تھے اور وه انہیں آ گھیرے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcvii{انسان کو جب کوئی تکلیف پہنچتی ہے تو ہمیں پکارنے لگتا ہے، پھر جب ہم اسے اپنی طرف سے کوئی نعمت عطا فرمادیں تو کہنے لگتا ہے کہ اسے تو میں محض اپنے علم کی وجہ سے دیا گیا ہوں، بلکہ یہ آزمائش ہے لیکن ان میں سے اکثر لوگ بے علم ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcviii{ان سے اگلے بھی یہی بات کہہ چکے ہیں پس ان کی کارروائی ان کے کچھ کام نہ آئی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcix{پھر ان کی تمام برائیاں ان پر آ پڑیں، اوران میں سے بھی جو گناه گار ہیں ان کی کی ہوئی برائیاں بھی اب ان پر آ پڑیں گی، یہ (ہمیں) ہرا دینے والے نہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcx{کیا انہیں یہ معلوم نہیں کہ اللہ تعالیٰ جس کے لیے چاہے روزی کشاده کر دیتا ہے اور تنگ (بھی)، ایمان ﻻنے والوں کے لیے اس میں (بڑی بڑی) نشانیاں ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcxi{(میری جانب سے) کہہ دو کہ اے میرے بندو! جنہوں نے اپنی جانوں پر زیادتی کی ہے تم اللہ کی رحمت سے ناامید نہ ہو جاؤ، بالیقین اللہ تعالیٰ سارے گناہوں کو بخش دیتا ہے، واقعی وه بڑی بخشش بڑی رحمت واﻻ ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcxii{تم (سب) اپنے پروردگار کی طرف جھک پڑو اور اس کی حکم برداری کیے جاؤ اس سے قبل کہ تمہارے پاس عذاب آ جائے اور پھر تمہاری مدد نہ کی جائے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiii{اور پیروری کرو اس بہترین چیزکی جو تمہاری طرف تمہارے پروردگار کی طرف سے نازل کی گئی ہے، اس سے پہلے کہ تم پر اچانک عذاب آجائے اور تمہیں اطلاع بھی نہ ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiv{(ایسا نہ ہو کہ) کوئی شخص کہے ہائے افسوس! اس بات پر کہ میں نے اللہ تعالیٰ کے حق میں کوتاہی کی بلکہ میں تو مذاق اڑانے والوں میں ہی رہا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxv{یا کہے کہ اگر اللہ مجھے ہدایت کرتا تو میں بھی پارسا لوگوں میں ہوتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvi{یا عذاب کو دیکھ کر کہے کاش! کہ کسی طرح میرا لوٹ جانا ہوجاتا تو میں بھی نیکو کاروں میں ہوجاتا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvii{ہاں (ہاں) بیشک تیرے پاس میری آیتیں پہنچ چکی تھیں جنہیں تونے جھٹلایا اور غرور وتکبر کیا اور تو تھا ہی کافروں میں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxviii{اور جن لوگوں نے اللہ پر جھوٹ باندھا ہے تو آپ دیکھیں گے کہ قیامت کے دن ان کے چہرے سیاه ہوگئے ہوں گے کیا تکبر کرنے والوں کاٹھکانا جہنم میں نہیں؟\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxix{اور جن لوگوں نے پرہیزگاری کی انہیں اللہ تعالیٰ ان کی کامیابی کے ساتھ بچا لے گا، انہیں کوئی دکھ چھو بھی نہ سکے گا اور نہ وه کسی طرح غمگین ہوں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxx{اللہ ہر چیز کا پیدا کرنے واﻻ ہے اور وہی ہر چیز پر نگہبان ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxi{آسمانوں اور زمین کی کنجیوں کامالک وہی ہے جن جن لوگوں نے اللہ کی آیتوں کا انکار کیا وہی خساره پانے والے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxii{آپ کہہ دیجئے اے جاہلو! کیا تم مجھ سے اللہ کے سوا اوروں کی عبادت کو کہتے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiii{یقیناً تیری طرف بھی اور تجھ سے پہلے (کے تمام نبیوں) کی طرف بھی وحی کی گئی ہے کہ اگر تو نے شرک کیا تو بلاشبہ تیرا عمل ضائع ہو جائے گا اور بالیقین تو زیاںکاروں میں سے ہوجائے گا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiv{بلکہ تو اللہ ہی کی عبادت کر اور شکر کرنے والوں میں سے ہو جا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxv{اور ان لوگوں نے جیسی قدر اللہ تعالیٰ کی کرنی چاہئے تھی نہیں کی، ساری زمین قیامت کے دن اس کی مٹھی میں ہوگی اور تمام آسمان اس کے داہنے ہاتھ میں لپیٹے ہوئے ہوں گے، وه پاک اور برتر ہے ہر اس چیز سے جسے لوگ اس کا شریک بنائیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvi{اور صور پھونک دیا جائے گا پس آسمانوں اور زمین والے سب بے ہوش ہوکر گر پڑیں گے مگر جسے اللہ چاہے، پھر دوباره صور پھونکا جائے گا پس وه ایک دم کھڑے ہو کر دیکھنے لگ جائیں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvii{اور زمین اپنے پروردگار کے نور سے جگمگا اٹھے گی، نامہٴ اعمال حاضر کیے جائیں گے نبیوں اور گواہوں کو ﻻیا جائے گا اور لوگوں کے درمیان حق حق فیصلے کر دیے جائیں گے، اور وه ﻇلم نہ کیے جائیں گے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxviii{اور جس شخص نے جو کچھ کیا ہے بھرپور دے دیا جائے گا، جو کچھ لوگ کر رہے ہیں وه بخوبی جاننے واﻻ ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxix{کافروں کے غول کے غول جہنم کی طرف ہنکائے جائیں گے، جب وه اس کے پاس پہنچ جائیں گے اس کے دروازے ان کے لیے کھول دیے جائیں گے، اور وہاں کے نگہبان ان سے سوال کریں گے کہ کیا تمہارے پاس تم میں سے رسول نہیں آئے تھے؟ جو تم پر تمہارے رب کی آیتیں پڑھتے تھے اور تمہیں اس دن کی ملاقات سے ڈراتے تھے؟ یہ جواب دیں گے کہ ہاں درست ہے لیکن عذاب کا حکم کافروں پر ﺛابت ہو گیا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxx{کہا جائے گا کہ اب جہنم کے دروازوں میں داخل ہو جاؤ جہاں ہمیشہ رہیں گے، پس سرکشوں کا ٹھکانا بہت ہی برا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxi{اور جو لوگ اپنے رب سے ڈرتے تھے ان کے گروه کے گروه جنت کی طرف روانہ کیے جائیں گے یہاں تک کہ جب اس کے پاس آ جائیں گے اور دروازے کھول دیے جائیں گے اور وہاں کے نگہبان ان سے کہیں گے تم پر سلام ہو، تم خوش حال رہو تم اس میں ہمیشہ کے لیے چلے جاؤ\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxii{یہ کہیں گے کہ اللہ کاشکر ہے کہ جس نے ہم سے اپنا وعده پورا کیا اور ہمیں اس زمین کا وارث بنا دیا کہ جنت میں جہاں چاہیں مقام کریں پس عمل کرنے والوں کا کیا ہی اچھا بدلہ ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiii{اور تو فرشتوں کو اللہ کے عرش کے اردگرد حلقہ باندھے ہوئے اپنے رب کی حمد و تسبیح کرتے ہوئے دیکھے گا اور ان میں انصاف کا فیصلہ کیا جائے گا اور کہہ دیا جائے گا کہ ساری خوبی اللہ ہی کے لیے ہے جو تمام جہانوں کا پالنہار ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiv{\basmalahur حٰم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxv{اس کتاب کا نازل فرمانا اس اللہ کی طرف سے ہے جو غالب اور دانا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvi{گناه کا بخشنے واﻻ اور توبہ کا قبول فرمانے واﻻ سخت عذاب واﻻ انعام و قدرت واﻻ، جس کے سوا کوئی معبود نہیں۔ اسی کی طرف واپس لوٹنا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvii{اللہ تعالیٰ کی آیتوں میں وہی لوگ جھگڑتے ہیں جو کافر ہیں پس ان لوگوں کا شہروں میں چلنا پھرنا آپ کو دھوکے میں نہ ڈالے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxviii{قوم نوح نے اور ان کے بعد کے گروہوں نے بھی جھٹلایا تھا۔ اور ہر امت نے اپنے رسول کو گرفتار کر لینے کا اراده کیا اور باطل کے ذریعہ کج بحثیاں کیں، تاکہ ان سے حق کو بگاڑ دیں پس میں نے ان کو پکڑ لیا، سو میری طرف سے کیسی سزا ہوئی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxix{اور اسی طرح آپ کے رب کا حکم کافروں پر ﺛابت ہو گیا کہ وه دوزخی ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcxl{عرش کے اٹھانے والے اور اسکے آس پاس کے (فرشتے) اپنے رب کی تسبیح حمد کے ساتھ ساتھ کرتے ہیں اور اس پر ایمان رکھتے ہیں اور ایمان والوں کے لیے استفغار کرتے ہیں، کہتے ہیں کہ اے ہمارے پروردگار! تو نے ہر چیز کو اپنی بخشش اور علم سے گھیر رکھا ہے، پس تو انہیں بخش دے جو توبہ کریں اور تیری راه کی پیروی کریں اور تو انہیں دوزخ کے عذاب سے بھی بچا لے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcxli{اے ہمارے رب! تو انہیں ہمیشگی والی جنتوں میں لے جا جن کا تو نے ان سے وعده کیا ہے اور ان کے باپ دادوں اور بیویوں اور اوﻻد میں سے (بھی) ان (سب) کو جو نیک عمل ہیں۔ یقیناً تو تو غالب و باحکمت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlii{انہیں برائیوں سے بھی محفوظ رکھ، حق تو یہ ہے کہ اس دن تونے جسے برائیوں سے بچا لیا اس پر تو نے رحمت کر دی اور بہت بڑی کامیابی تو یہی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliii{بےشک جن لوگوں نے کفر کیا انہیں یہ آواز دی جائے گی کہ یقیناً اللہ کا تم پر غصہ ہونااس سے بہت زیاده ہے جو تم غصہ ہوتے تھے اپنے جی سے، جب تم ایمان کی طرف بلائے جاتے تھے پھر کفر کرنے لگتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliv{وه کہیں گے اے ہمارے پروردگار! تو نے ہمیں دوبار مارا اور دو بار ہی جلایا، اب ہم اپنے گناہوں کے اقراری ہیں، تو کیا اب کوئی راه نکلنے کی بھی ہے؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlv{یہ (عذاب) تمہیں اس لیے ہے کہ جب صرف اکیلے اللہ کا ذکر کیا جاتا تو تم انکار کر جاتے تھے اور اگر اس کے ساتھ کسی کو شریک کیا جاتا تھا تو تم مان لیتے تھے پس اب فیصلہ اللہ بلند و بزرگ ہی کا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvi{وہی ہے جو تمہیں اپنی نشانیاں دکھلاتا ہے اور تمہارے لیےآسمان سے روزی اتارتا ہے، نصیحت تو صرف وہی حاصل کرتے ہیں جو (اللہ کی طرف) رجوع کرتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvii{تم اللہ کو پکارتے رہو اس کے لیے دین کو خالص کر کے گو کافر برا مانیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlviii{بلند درجوں واﻻ عرش کامالک وه اپنے بندوں میں سے جس پر چاہتا ہے وحی نازل فرماتا ہے، تاکہ وه ملاقات کے دن سے ڈرائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlix{جس دن سب لوگ ﻇاہر ہو جائیں گے، ان کی کوئی چیز اللہ سے پوشیده نہ رہے گی۔ آج کس کی بادشاہی ہے؟ فقط اللہ واحد و قہار کی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcl{آج ہر نفس کو اس کی کمائی کا بدلہ دیا جائے گا۔ آج (کسی قسم کا) ﻇلم نہیں، یقیناً اللہ تعالیٰ بہت جلد حساب کرنے واﻻ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcli{اور انہیں بہت ہی قریب آنے والی (قیامت سے) آگاه کر دیجئے، جب کہ دل حلق تک پہنچ جائیں گے اور سب خاموش ہوں گے، ﻇالموں کا نہ کوئی دلی دوست ہوگا نہ سفارشی، کہ جس کی بات مانی جائے گی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmclii{وه آنکھوں کی خیانت کو اور سینوں کی پوشیده باتوں کو (خوب) جانتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcliii{اور اللہ تعالیٰ ٹھیک ٹھیک فیصلہ کر دے گا اس کے سوا جنہیں یہ لوگ پکارتے ہیں وه کسی چیز کا بھی فیصلہ نہیں کرسکتے، بیشک اللہ تعالیٰ خوب سنتا خوب دیکھتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcliv{کیا یہ لوگ زمین میں چلے پھرے نہیں کہ دیکھتے کہ جو لوگ ان سے پہلے تھے ان کا نتیجہ کیسا کچھ ہوا؟ وه باعتبار قوت و طاقت کے اور باعتبار زمین میں اپنی یادگاروں کے ان سے بہت زیاده تھے، پس اللہ نے انہیں ان کے گناہوں پر پکڑ لیا اور کوئی نہ ہوا جو انہیں اللہ کے عذاب سے بچا لیتا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmclv{یہ اس وجہ سے کہ ان کے پاس ان کے پیغمبر معجزے لے لے کرآتے تھے تو وه انکار کر دیتے تھے، پس اللہ انہیں پکڑ لیتا تھا۔ یقیناً وه طاقتور اور سخت عذاب واﻻ ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmclvi{اور ہم نے موسیٰ (علیہ السلام) کو اپنی آیتوں اور کھلی دلیلوں کے ساتھ بھیجا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmclvii{فرعون ہامان اور قارون کی طرف تو انہوں نے کہا (یہ تو) جادوگر اور جھوٹا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmclviii{پس جب ان کے پاس (موسیٰ علیہ السلام) ہماری طرف سے (دین) حق کولے کر آئے توانہوں نے کہا کہ اس کے ساتھ جوایمان والے ہیں ان کے لڑکوں کو تو مار ڈالو اور ان کی لڑکیوں کو زنده رکھو اور کافروں کی جو حیلہ سازی ہے وه غلطی میں ہی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmclix{اور فرعون نے کہا مجھے چھوڑ دو کہ میں موسیٰ (علیہ السلام) کو مار ڈالوں اور اسے چاہئے کہ اپنے رب کو پکارے، مجھے تو ڈر ہے کہ یہ کہیں تمہارا دین نہ بدل ڈالے یا ملک میں کوئی (بہت بڑا) فساد برپا نہ کردے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmclx{موسیٰ (علیہ السلام) نے کہا میں اپنے اور تمہارے رب کی پناه میں آتا ہوں ہر اس تکبر کرنے والے شخص (کی برائی) سے جو روز حساب پر ایمان نہیں رکھتا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmclxi{اور ایک مومن شخص نے، جو فرعون کے خاندان میں سے تھا اور اپنا ایمان چھپائے ہوئے تھا، کہا کہ کیا تم ایک شحض کو محض اس بات پر قتل کرتے ہو کہ وه کہتا ہے میرا رب اللہ ہے اور تمہارے رب کی طرف سے دلیلیں لے کر آیا ہے، اگر وه جھوٹا ہو تو اس کا جھوٹ اسی پر ہے اور اگر وه سچا ہو، تو جس (عذاب) کا وه تم سے وعده کر رہا ہے اس میں سے کچھ نہ کچھ تو تم پر آ پڑے گا، اللہ تعالیٰ اس کی رہبری نہیں کرتا جو حد سے گزر جانے والے اور جھوٹے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmclxii{اے میری قوم کے لوگو! آج تو بادشاہت تمہاری ہے کہ اس زمین پر تم غالب ہو لیکن اگر اللہ کا عذاب ہم پر آ گیا تو کون ہماری مدد کرے گا؟ فرعون بوﻻ، میں تو تمہیں وہی رائے دے رہا ہوں جو خود دیکھ رہا ہوں اور میں تو تمہیں بھلائی کی راه ہی بتلا رہا ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiii{اس مومن نے کہا اے میری قوم! (کے لوگو) مجھے تو اندیشہ ہے کہ تم پر بھی ویسا ہی روز (بد عذاب) نہ آئے جو اور امتوں پر آیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiv{جیسے امت نو ح اور عاد وﺛمود اور ان کے بعد والوں کا (حال ہوا)، اللہ اپنے بندوں پر کسی طرح کا ﻇلم کرنا نہیں چاہتا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmclxv{اور مجھے تم پر ہانک پکار کے دن کابھی ڈر ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvi{جس دن تم پیٹھ پھیر کر لوٹو گے، تمہیں اللہ سے بچانے واﻻ کوئی نہ ہوگا اور جسے اللہ گمراه کر دے اس کا ہادی کوئی نہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvii{اور اس سے پہلے تمہارے پاس (حضرت) یوسف دلیلیں لے کر آئے، پھر بھی تم ان کی ﻻئی ہوئی (دلیل) میں شک و شبہ ہی کرتے رہے یہاں تک کہ جب ان کی وفات ہو گئی تو کہنے لگے ان کے بعد تو اللہ کسی رسول کو بھیجے گا ہی نہیں اسی طرح اللہ گمراه کرتا ہے ہر اس شخص کو جو حد سے بڑھ جانے واﻻ شک و شبہ کرنے واﻻ ہو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmclxviii{جو بغیر کسی سند کے جو ان کے پاس آئی ہو اللہ کی آیتوں میں جھگڑتے ہیں، اللہ کے نزدیک اور مومنوں کے نزدیک یہ تو بہت بڑی ناراضگی کی چیز ہے، اللہ تعالیٰ اسی طرح ہر ایک مغرور سرکش کے دل پر مہر کردیتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmclxix{فرعون نے کہا اے ہامان! میرے لیے ایک باﻻخانہ بنا شاید کہ میں آسمان کے جو دروازے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmclxx{(ان) دروازوں تک پہنچ جاؤں اور موسیٰ کے معبود کو جھانک لوں اور بیشک میں سمجھتا ہوں وه جھوٹا ہے اور اسی طرح فرعون کی بدکرداریاں اسے بھلی دکھائی گئیں اور راه سے روک دیا گیا اور فرعون کی (ہر) حیلہ سازی تباہی میں ہی رہی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxi{اور اس مومن شخص نے کہا کہ اے میری قوم! (کے لوگو) تم (سب) میری پیروی کرو میں نیک راه کی طرف تمہاری رہبری کروں گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxii{اے میری قوم! یہ حیات دنیا متاع فانی ہے، (یقین مانو کہ قرار) اور ہمیشگی کا گھر تو آخرت ہی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiii{جس نے گناه کیا ہے اسے تو برابر برابر کا بدلہ ہی ہے اور جس نے نیکی کی ہے خواه وه مرد ہو یا عورت اور وه ایمان واﻻ ہو تو یہ لوگ جنت میں جائیں گے اور وہاں بےشمار روزی پائیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiv{اے میری قوم! یہ کیا بات ہے کہ میں تمہیں نجات کی طرف بلا رہا ہوں اور تم مجھے دوزخ کی طرف بلا رہے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxv{تم مجھے یہ دعوت دے رہے ہوکہ میں اللہ کے ساتھ کفر کروں اور اس کے ساتھ شرک کروں جس کا کوئی علم مجھے نہیں اور میں تمہیں غالب بخشنے والے (معبود) کی طرف دعوت دے رہا ہوں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvi{یہ یقینی امر ہے کہ تم مجھے جس کی طرف بلا رہے ہو وه تو نہ دنیا میں پکارے جانے کے قابل ہے نہ آخرت میں، اور یہ (بھی یقینی بات ہے) کہ ہم سب کا لوٹنا اللہ کی طرف ہے اور حد سے گزر جانے والے ہی (یقیناً) اہل دوزخ ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvii{پس آگے چل کر تم میری باتوں کو یاد کرو گے میں اپنا معاملہ اللہ کے سپرد کرتا ہوں، یقیناً اللہ تعالیٰ بندوں کا نگراں ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxviii{پس اسے اللہ تعالیٰ نے تمام بدیوں سے محفوظ رکھ لیا جو انہوں نے سوچ رکھی تھیں اور فرعون والوں پر بری طرح کا عذاب الٹ پڑا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxix{آگ ہے جس کے سامنے یہ ہر صبح شام ﻻئے جاتے ہیں اور جس دن قیامت قائم ہوگی (فرمان ہوگا کہ) فرعونیوں کو سخت ترین عذاب میں ڈالو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxx{اور جب کہ دوزخ میں ایک دوسرے سے جھگڑیں گے تو کمزور لوگ تکبر والوں سے (جن کے یہ تابع تھے) کہیں گے کہ ہم تو تمہارے پیرو تھے تو کیا اب تم ہم سے اس آگ کا کوئی حصہ ہٹا سکتے ہو؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxi{وه بڑے لوگ جواب دیں گے ہم تو سبھی اس آگ میں ہیں، اللہ تعالیٰ اپنے بندوں کے درمیان فیصلے کر چکا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxii{اور (تمام) جہنمی مل کر جہنم کے داروغوں سے کہیں گے کہ تم ہی اپنے پروردگار سے دعا کرو کہ وه کسی دن تو ہمارے عذاب میں کمی کردے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiii{وه جواب دیں گے کہ کیا تمہارے پاس تمہارے رسول معجزے لے کر نہیں آئے تھے؟ وه کہیں گے کیوں نہیں، وه کہیں گے کہ پھر تم ہی دعا کرو اور کافروں کی دعا محض بے اﺛر اور بےراه ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiv{یقیناً ہم اپنے رسولوں کی اور ایمان والوں کی مدد زندگانیٴ دنیا میں بھی کریں گے اور اس دن بھی جب گواہی دینے والے کھڑے ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxv{جس دن ﻇالموں کو ان کی (عذر) معذرت کچھ نفع نہ دے گی ان کے لیے لعنت ہی ہوگی اور ان کے لیے برا گھر ہو گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvi{ہم نے موسیٰ (علیہ السلام) کو ہدایت نامہ عطا فرمایا اور بنو اسرائیل کو اس کتاب کا وارث بنایا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvii{کہ وه ہدایت و نصیحت تھی عقل مندوں کے لیے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxviii{پس اے نبی! تو صبر کر اللہ کا وعده بلاشک (وشبہ) سچا ہی ہے تو اپنے گناه کی معافی مانگتا ره اور صبح شام اپنے پروردگار کی تسبیح اور حمد بیان کرتا ره\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxix{جو لوگ باوجود اپنے پاس کسی سند کے نہ ہونے کے آیات الٰہی میں جھگڑا کرتے ہیں ان کے دلوں میں بجز نری بڑائی کے اور کچھ نہیں وه اس تک پہنچنے والے ہی نہیں، سو تو اللہ کی پناه مانگتا ره بیشک وه پورا سننے واﻻ اور سب سے زیاده دیکھنے واﻻ ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxc{آسمان و زمین کی پیدائش یقیناً انسان کی پیدائش سے بہت بڑا کام ہے، لیکن (یہ اور بات ہے کہ) اکثر لوگ بےعلم ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxci{اندھا اور بینا برابر نہیں نہ وه لوگ جو ایمان ﻻئے اور بھلے کام کیے بدکاروں کے (برابر ہیں)، تم (بہت) کم نصیحت حاصل کر رہے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcii{قیامت بالیقین اور بےشبہ آنے والی ہے، لیکن (یہ اور بات ہے کہ) بہت سے لوگ ایمان نہیں ﻻتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciii{اور تمہارے رب کا فرمان (سرزد ہوچکا ہے) کہ مجھ سے دعا کرو میں تمہاری دعاؤں کو قبول کروں گا یقین مانو کہ جو لوگ میری عبادت سے خودسری کرتے ہیں وه ابھی ابھی ذلیل ہوکر جہنم میں پہنچ جائیں گے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciv{اللہ تعالیٰ نے تمھارے لیے رات بنادی کہ تم اس میں آرام حاصل کرو اور دن کو دیکھنے واﻻ بنا دیا، بیشک اللہ تعالیٰ لوگوں پر فضل وکرم واﻻ ہے لیکن اکثر لوگ شکر گزاری نہیں کرتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcv{یہی اللہ ہے تم سب کا رب ہر چیز کا خالق اس کے سوا کوئی معبود نہیں پھر کہاں تم پھرے جاتے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvi{اسی طرح وه لوگ بھی پھیرے جاتے رہے جو اللہ کی آیتوں کا انکار کرتے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvii{اللہ ہی ہے جس نے تمہارے لیے زمین کو ٹھہرنے کی جگہ اور آسمان کو چھت بنا دیا اور تمہاری صورتیں بنائیں اور بہت اچھی بنائیں اور تمہیں عمده عمده چیزیں کھانے کو عطا فرمائیں، یہی اللہ تمہارا پروردگار ہے، پس بہت ہی برکتوں واﻻ اللہ ہے سارے جہان کا پرورش کرنے واﻻ\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcviii{وه زنده ہے جس کے سوا کوئی معبود نہیں پس تم خالص اس کی عبادت کرتے ہوئے اسے پکارو، تمام خوبیاں اللہ ہی کے لیے ہیں جو تمام جہانوں کا رب ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcix{آپ کہہ دیجئے! کہ مجھے ان کی عبادت سے روک دیا گیا ہے جنہیں تم اللہ کے سوا پکار رہے ہو اس بنا پر کہ میرے پاس میرے رب کی دلیلیں پہنچ چکی ہیں، مجھے یہ حکم دیا گیا ہے کہ میں تمام جہانوں کے رب کا تابع فرمان ہو جاؤں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcc{وه وہی ہے جس نے تمہیں مٹی سے پھر نطفے سے پھر خون کے لوتھڑے سے پیدا کیا پھر تمہیں بچہ کی صورت میں نکالتا ہے، پھر (تمہیں بڑھاتا ہے کہ) تم اپنی پوری قوت کو پہنچ جاؤ پھر بوڑھے ہو جاؤ، تم میں سے بعض اس سے پہلے ہی فوت ہو جاتے ہیں، (وه تمہیں چھوڑ دیتا ہے) تاکہ تم مدت معین تک پہنچ جاؤ اور تاکہ تم سوچ سمجھ لو\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcci{وہی ہے جو جلاتا ہے اور مار ڈالتا ہے، پھر جب وه کسی کام کا کرنا مقرر کرتا ہے تو اسے صرف یہ کہتا ہے کہ ہو جا پس وه ہو جاتا ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmccii{کیا تو نے انہیں دیکھا جو اللہ کی آیتوں میں جھگڑتے ہیں، وه کہاں پھیر دیے جاتے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcciii{جن لوگوں نے کتاب کو جھٹلایا اور اسے بھی جو ہم نے اپنے رسولوں کے ساتھ بھیجا انہیں ابھی ابھی حقیقت حال معلوم ہو جائے گی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcciv{جب کہ ان کی گردنوں میں طوق ہوں گے اور زنجیریں ہوں گی گھسیٹے جائیں گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmccv{کھولتے ہوئے پانی میں اور پھر جہنم کی آگ میں جلائے جائیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmccvi{پھر ان سے پوچھا جائے گا کہ جنہیں تم شریک کرتے تھے وه کہاں ہیں۔\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmccvii{جو اللہ کے سوا تھے وه کہیں گے کہ وه تو ہم سے بہک گئے بلکہ ہم تو اس سے پہلے کسی کو بھی پکارتے ہی نہ تھے۔ اللہ تعالیٰ کافروں کو اسی طرح گمراه کرتا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmccviii{یہ بدلہ ہے اس چیز کا جو تم زمین میں ناحق پھولے نہ سماتے تھے۔ اور (بےجا) اتراتے پھرتے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmccix{(اب آؤ) جہنم میں ہمیشہ رہنے کے لیے (اس کے) دروازوں میں داخل ہو جاؤ، کیا ہی بری جگہ ہے تکبر کرنے والے کی\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmccx{پس آپ صبر کریں اللہ کا وعده قطعاً سچا ہے، انہیں ہم نے جو وعدے دے رکھے ہیں ان میں سے کچھ ہم آپ کو دکھائیں یا (اس سے پہلے) ہم آپ کو وفات دے دیں، ان کا لوٹایا جانا تو ہماری ہی طرف ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmccxi{یقیناً ہم آپ سے پہلے بھی بہت سے رسول بھیج چکے ہیں جن میں سے بعض کے (واقعات) ہم آپ کو بیان کر چکے ہیں اور ان میں سے بعض کے (قصے) تو ہم نے آپ کو بیان ہی نہیں کیے اور کسی رسول کا یہ (مقدور) نہ تھا کہ کوئی معجزه اللہ کی اجازت کے بغیر ﻻ سکے پھر جس وقت اللہ کا حکم آئےگا حق کے ساتھ فیصلہ کر دیا جائے گا اور اس جگہ اہل باطل خسارے میں ره جائیں گے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmccxii{اللہ وه ہے جس نے تمہارے لیے چوپائے پیدا کیے جن میں سے بعض پر تم سوار ہوتے ہو اور بعض کو تم کھاتے ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiii{اور بھی تمہارے لیے ان میں بہت سے نفع ہیں اور تاکہ اپنے سینوں میں چھپی ہوئی حاجتوں کو انہی پر سواری کر کے تم حاصل کر لو اور ان چوپایوں پر اور کشتیوں پر سوار کیے جاتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiv{اللہ تمہیں اپنی نشانیاں دکھاتا جارہا ہے، پس تم اللہ کی کن کن نشانیوں کے منکر بنتے رہو گے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmccxv{کیا انہوں نے زمین میں چل پھر کر اپنے سے پہلوں کا انجام نہیں دیکھا؟ جو ان سے تعداد میں زیاده تھے قوت میں سخت اور زمین میں بہت ساری یادگاریں چھوڑی تھیں، ان کے کیے کاموں نے انہیں کچھ بھی فائده نہیں پہنچایا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvi{پس جب بھی ان کے پاس ان کے رسول کھلی نشانیاں لے کر آئے تو یہ اپنے پاس کے علم پر اترانے لگے، بالﺂخر جس چیز کو مذاق میں اڑا رہے تھے وه ان پر الٹ پڑی\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvii{ہمارا عذاب دیکھتے ہی کہنے لگے کہ اللہ واحد پر ہم ایمان ﻻئے اور جن جن کو ہم اس کا شریک بنا رہے تھے ہم نے ان سب سے انکار کیا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmccxviii{لیکن ہمارے عذاب کو دیکھ لینے کے بعد ان کے ایمان نے انہیں نفع نہ دیا۔ اللہ نے اپنا معمول یہی مقرر کر رکھا ہے جو اس کے بندوں میں برابر چلا آ رہا ہے۔ اور اس جگہ کافر خراب وخستہ ہوئے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmccxix{\basmalahur حٰم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmccxx{اتاری ہوئی ہے بڑے مہربان بہت رحم والے کی طرف سے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxi{(ایسی) کتاب ہے جس کی آیتوں کی واضح تفصیل کی گئی ہے، (اس حال میں کہ) قرآن عربی زبان میں ہے اس قوم کے لیے جو جانتی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxii{خوش خبری سنانے واﻻ اور ڈرانے واﻻ ہے، پھر بھی ان کی اکثریت نے منھ پھیر لیا اور وه سنتے ہی نہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiii{اور انہوں نے کہا کہ تو جس کی طرف ہمیں بلا رہا ہے ہمارے دل تو اس سے پردے میں ہیں اور ہمارے کانوں میں گرانی ہے اور ہم میں اور تجھ میں ایک حجاب ہے، اچھا تو اب اپنا کام کیے جا ہم بھی یقیناً کام کرنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiv{آپ کہہ دیجیئے! کہ میں تو تم ہی جیسا انسان ہوں مجھ پر وحی نازل کی جاتی ہے کہ تم سب کا معبود ایک اللہ ہی ہے سو تم اس کی طرف متوجہ ہو جاؤ اور اس سے گناہوں کی معافی چاہو، اور ان مشرکوں کے لیے (بڑی ہی) خرابی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxv{جو زکوٰة نہیں دیتے اورآخرت کے بھی منکر ہی رہتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvi{بیشک جو لوگ ایمان ﻻئیں اور بھلے کام کریں ان کے لیے نہ ختم ہونے واﻻ اجر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvii{آپ کہہ دیجئے! کہ کیا تم اس (اللہ) کا انکار کرتے ہو اور تم اس کے شریک مقرر کرتے ہو جس نے دو دن میں زمین پیدا کردی، سارے جہانوں کا پروردگار وہی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxviii{اور اس نے زمین میں اس کے اوپر سے پہاڑ گاڑ دیے اوراس میں برکت رکھ دی اوراس میں (رہنے والوں کی) غذاؤں کی تجویز بھی اسی میں کر دی (صرف) چار دن میں، ضرورت مندوں کے لیے یکساں طور پر\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxix{پھر آسمان کی طرف متوجہ ہوا اور وه دھواں (سا) تھا پس اس سے اور زمین سے فرمایا کہ تم دونوں خوشی سے آؤ یا ناخوشی سے دونوں نے عرض کیا ہم بخوشی حاضر ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxx{پس دو دن میں سات آسمان بنا دیئے اور ہر آسمان میں اس کے مناسب احکام کی وحی بھیج دی اور ہم نے آسمان دنیا کو چراغوں سے زینت دی اور نگہبانی کی، یہ تدبیر اللہ غالب و دانا کی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxi{اب بھی یہ روگرداں ہوں تو کہہ دیجئے! کہ میں تمہیں اس کڑک (عذاب آسمانی) سے ڈراتا ہوں جو مثل عادیوں اور ﺛمودیوں کی کڑک ہوگی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxii{ان کے پاس جب ان کے آگے پیچھے سے پیغمبر آئے کہ تم اللہ کے سوا کسی کی عبادت نہ کرو تو انہوں نے جواب دیا کہ اگر ہمارا پروردگار چاہتا تو فرشتوں کو بھیجتا۔ ہم تو تمہاری رسالت کے بالکل منکر ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiii{اب عاد نے تو بے وجہ زمین میں سرکشی شروع کر دی اور کہنے لگے کہ ہم سے زور آور کون ہے؟ کیا انہیں یہ نظر نہ آیا کہ جس نے انہیں پیدا کیا ہے وه ان سے (بہت ہی) زیاده زور آور ہے، وه (آخر تک) ہماری آیتوں کا انکار ہی کرتے رہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiv{بالﺂخر ہم نے ان پر ایک تیز و تند آندھی منحوس دنوں میں بھیج دی کہ انہیں دنیاوی زندگی میں ذلت کے عذاب کامزه چکھا دیں، اور (یقین مانو) کہ آخرت کا عذاب اس سے بہت زیاده رسوائی واﻻ ہے اور وه مدد نہیں کیے جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxv{رہے ﺛمود، سو ہم نے ان کی بھی رہبری کی پھر بھی انہوں نے ہدایت پر اندھے پن کو ترجیح دی جس بنا پر انہیں (سراپا) ذلت کے عذاب، کی کڑک نے ان کے کرتوتوں کے باعﺚ پکڑ لیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvi{اور (ہاں) ایماندار اور پارساؤں کو ہم نے (بال بال) بچا لیا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvii{اور جس دن اللہ کے دشمن دوزخ کی طرف ﻻئے جائیں گے اور ان (سب) کو جمع کر دیا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxviii{یہاں تک کہ جب بالکل جہنم کےپاس آجائیں گے اور ان پر ان کے کان اور ان کی آنکھیں اور ان کی کھالیں ان کے اعمال کی گواہی دیں گی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxix{یہ اپنی کھالوں سے کہیں گے کہ تم نے ہمارے خلاف شہادت کیوں دی، وه جواب دیں گی کہ ہمیں اس اللہ نے قوت گویائی عطا فرمائی جس نے ہر چیز کو بولنے کی طاقت بخشی ہے، اسی نے تمہیں اول مرتبہ پیدا کیا اور اسی کی طرف تم سب لوٹائے جاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxl{اور تم (اپنی بداعمالیاں) اس وجہ سے پوشیده رکھتے ہی نہ تھے کہ تم پر تمہارے کان اور تمہاری آنکھیں اور تمہاری کھالیں گواہی دیں گی، ہاں تم یہ سمجھتے رہے کہ تم جو کچھ بھی کر رہے ہو اس میں سے بہت سےاعمال سے اللہ بےخبر ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxli{تمہاری اسی بدگمانی نےجو تم نے اپنے رب سے کر رکھی تھی تمہیں ہلاک کر دیا اور بالﺂخر تم زیاں کاروں میں ہو گئے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlii{اب اگر یہ صبر کریں تو بھی ان کا ٹھکانا جہنم ہی ہے۔ اور اگر یہ (عذر اور) معافی کےخواستگار ہوں تو بھی (معذور اور) معاف نہیں رکھے جائیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliii{اور ہم نے ان کے کچھ ہم نشیں مقرر کر رکھے تھے، جنہوں نے ان کے اگلے پچھلے اعمال ان کی نگاہوں میں خوبصورت بنا رکھے تھے اور ان کے حق میں بھی اللہ کا قول ان امتوں کے ساتھ پورا ہوا جو ان سے پہلے جنوں انسانوں کی گزر چکی ہیں۔ یقیناً وه زیاں کار ﺛابت ہوئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliv{اور کافروں نے کہا اس قرآن کو سنو ہی مت (اس کے پڑھے جانے کے وقت) اور بیہوده گوئی کرو کیا عجب کہ تم غالب آجاؤ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlv{پس یقیناً ہم ان کافروں کو سخت عذاب کا مزه چکھائیں گے۔ اور انہیں ان کے بدترین اعمال کا بدلہ (ضرور) ضرور دیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvi{اللہ کے دشمنوں کی سزا یہی دوزح کی آگ ہے جس میں ان کا ہمیشگی کا گھر ہے (یہ) بدلہ ہے ہماری آیتوں سے انکار کرنے کا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvii{اور کافر لوگ کہیں گے اے ہمارے رب! ہمیں جنوں انسانوں (کے وه دونوں فریق) دکھا جنہوں نے ہمیں گمراه کیا (تاکہ) ہم انہیں اپنے قدموں تلے ڈال دیں تاکہ وه جہنم میں سب سے نیچے (سخت عذاب میں) ہو جائیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlviii{(واقعی) جن لوگوں نے کہا کہ ہمارا پروردگار اللہ ہے پھر اسی پر قائم رہے ان کے پاس فرشتے (یہ کہتے ہوئے آتے ہیں کہ تم کچھ بھی اندیشہ اور غم نہ کرو (بلکہ) اس جنت کی بشارت سن لو جس کا تم وعده دیئے گئے ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlix{تمہاری دنیوی زندگی میں بھی ہم تمہارے رفیق تھے اور آخرت میں بھی رہیں گے، جس چیز کو تمہارا جی چاہے اور جو کچھ تم مانگو سب تمہارے لیے (جنت میں موجود﴾ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccl{غفور و رحیم (معبود) کی طرف سے یہ سب کچھ بطور مہمانی کے ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccli{اور اس سے زیاده اچھی بات واﻻ کون ہے جو اللہ کی طرف بلائے اور نیک کام کرے اور کہے کہ میں یقیناً مسلمانوں میں سے ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcclii{نیکی اور بدی برابر نہیں ہوتی۔ برائی کو بھلائی سے دفع کرو پھر وہی جس کے اور تمہارے درمیان دشمنی ہے ایسا ہو جائے گا جیسے دلی دوست\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccliii{اور یہ بات انہیں کو نصیب ہوتی ہے جو صبر کریں اور اسے سوائے بڑے نصیبے والوں کے کوئی نہیں پا سکتا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccliv{اور اگر شیطان کی طرف سے کوئی وسوسہ آئے تو اللہ کی پناه طلب کرو یقیناً وه بہت ہی سننے واﻻ اور جاننے واﻻ ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcclv{اور دن رات اور سورج چاند بھی (اسی کی) نشانیوں میں سے ہیں، تم سورج کو سجده نہ کرو نہ چاند کو بلکہ سجده اس اللہ کے لیے کرو جس نے ان سب کو پیدا کیا ہے، اگر تمہیں اس کی عبادت کرنی ہے تو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvi{پھر بھی اگر یہ کبر و غرور کریں تو وه (فرشتے) جو آپ کے رب کے نزدیک ہیں وه تو رات دن اس کی تسبیح بیان کر رہے ہیں اور (کسی وقت بھی) نہیں اکتاتے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvii{اس اللہ کی نشانیوں میں سے (یہ بھی) ہے کہ تو زمین کو دبی دبائی دیکھتا ہے پھر جب ہم اس پر مینہ برساتے ہیں تو وه تر وتازه ہوکر ابھرنے لگتی ہے جس نے اسے زنده کیا وہی یقینی طور پر مُردوں کو بھی زنده کرنے واﻻ ہے، بیشک وه ہر (ہر) چیز پر قادر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcclviii{بیشک جو لوگ ہماری آیتوں میں کج روی کرتے ہیں وه (کچھ) ہم سے مخفی نہیں، (بتلاؤ تو) جو آگ میں ڈاﻻ جائے وه اچھا ہے یا وه جو امن و امان کے ساتھ قیامت کے دن آئے؟ تم جو چاہو کرتے چلے جاؤ وه تمہارا سب کیا کرایا دیکھ رہا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcclix{جن لوگوں نے اپنے پاس قرآن پہنچ جانے کے باوجود اس سے کفر کیا، (وه بھی ہم سے پوشیده نہیں) یہ بڑی باوقعت کتاب ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcclx{جس کے پاس باطل پھٹک بھی نہیں سکتا نہ اس کے آگے سے نہ اس کے پیچھے سے، یہ ہے نازل کرده حکمتوں والے خوبیوں والے (اللہ) کی طرف سے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxi{آپ سے وہی کہا جاتا ہے جو آپ سے پہلے کے رسولوں سے بھی کہا گیا ہے، یقیناً آپ کا رب معافی واﻻ اور دردناک عذاب واﻻ ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxii{اور اگر ہم اسے عجمی زبان کا قرآن بناتے تو کہتے کہ اس کی آیتیں صاف صاف بیان کیوں نہیں کی گئیں؟ یہ کیا کہ عجمی کتاب اور آپ عربی رسول؟ آپ کہہ دیجئے! کہ یہ تو ایمان والوں کے لیے ہدایت و شفا ہے اور جو ایمان نہیں ﻻتے ان کے کانوں میں تو (بہراپن اور) بوجھ ہے اور یہ ان پر اندھاپن ہے، یہ وه لوگ ہیں جو کسی بہت دور دراز جگہ سے پکارے جا رہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiii{یقیناً ہم نے موسیٰ (علیہ السلام) کو کتاب دی تھی، سو اس میں بھی اختلاف کیا گیا اور اگر (وه) بات نہ ہوتی (جو) آپ کے رب کی طرف سے پہلے ہی مقرر ہو چکی ہے۔ توان کے درمیان (کبھی کا) فیصلہ ہو چکا ہوتا، یہ لوگ تو اس کے بارے میں سخت بےچین کرنے والے شک میں ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiv{جو شخص نیک کام کرے گا وه اپنے نفع کے لیے اور جو برا کام کرے گا اس کا وبال اسی پر ہے۔ اور آپ کا رب بندوں پر ﻇلم کرنے واﻻ نہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxv{قیامت کا علم اللہ ہی کی طرف لوٹایا جاتا ہے اور جو جو پھل اپنے شگوفوں میں سے نکلتے ہیں اور جو ماده حمل سے ہوتی ہے اور جو بچے وه جنتی ہے سب کا علم اسے ہے اور جس دن اللہ تعالیٰ ان (مشرکوں) کو بلا کر دریافت فرمائے گا میرے شریک کہاں ہیں، وه جواب دیں گے کہ ہم نے تو تجھے کہہ سنایا کہ ہم میں سے تو کوئی اس کا گواه نہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvi{اور یہ جن (جن) کی پرستش اس سے پہلے کرتے تھے وه ان کی نگاه سے گم ہوگئے اور انہوں نے سمجھ لیا کہ اب ان کے لیے کوئی بچاؤ نہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvii{بھلائی کے مانگنے سے انسان تھکتا نہیں اور اگر اسے کوئی تکلیف پہنچ جائے تو مایوس اور ناامید ہو جاتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxviii{اور جو مصیبت اسے پہنچ چکی ہے اس کے بعد اگر ہم اسے کسی رحمت کا مزه چکھائیں تو وه کہہ اٹھتا ہے کہ اس کا تو میں حقدار ہی تھا اور میں تو خیال نہیں کرسکتا کہ قیامت قائم ہوگی اور اگر میں اپنے رب کے پاس واپس کیا گیا تو بھی یقیناً میرے لیے اس کے پاس بھی بہتری ہے، یقیناً ہم ان کفار کو ان کے اعمال سے خبردار کریں گے اور انہیں سخت عذاب کا مزه چکھائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxix{اور جب ہم انسان پر اپنا انعام کرتے ہیں تو وه منھ پھیر لیتا ہے اور کناره کش ہوجاتا ہے اور جب اسے مصیبت پڑتی ہے تو بڑی لمبی چوڑی دعائیں کرنے واﻻ بن جاتا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxx{آپ کہہ دیجئے! کہ بھلا یہ تو بتاؤ کہ اگر یہ قرآن اللہ کی طرف سے آیا ہوا ہو پھر تم نے اسے نہ مانا بس اس سے بڑھ کر بہکا ہوا کون ہوگا جو مخالفت میں (حق سے) دور چلا جائے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxi{عنقریب ہم انہیں اپنی نشانیاں آفاق عالم میں بھی دکھائیں گے اور خود ان کی اپنی ذات میں بھی یہاں تک کہ ان پر کھل جائے کہ حق یہی ہے، کیا آپ کے رب کا ہر چیز سے واقف و آگاه ہونا کافی نہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxii{یقین جانو! کہ یہ لوگ اپنے رب کے روبرو جانے سے شک میں ہیں، یاد رکھو کہ اللہ تعالیٰ ہر چیز کا احاطہ کیے ہوئے ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiii{\basmalahur حٰم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiv{عسق\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxv{اللہ تعالیٰ جو زبردست ہے اور حکمت واﻻ ہے اسی طرح تیری طرف اور تجھ سے اگلوں کی طرف وحی بھیجتا رہا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvi{آسمانوں کی (تمام) چیزیں اور جو کچھ زمین میں ہے سب اسی کا ہے وه برتر اور عظیم الشان ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvii{قریب ہے آسمان اوپر سے پھٹ پڑیں اور تمام فرشتے اپنے رب کی پاکی تعریف کے ساتھ بیان کر رہے ہیں اور زمین والوں کے لیے استغفار کر رہے ہیں۔ خوب سمجھ رکھو کہ اللہ تعالیٰ ہی معاف فرمانے واﻻ رحمت واﻻ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxviii{اور جن لوگوں نے اس کے سوا دوسروں کو کارساز بنالیا ہے اللہ تعالیٰ ان پر نگران ہے اور آپ ان کے ذمہ دار نہیں ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxix{اسی طرح ہم نے آپ کی طرف عربی قرآن کی وحی کی ہے تاکہ آپ مکہ والوں کو اور اس کے آس پاس کے لوگوں کو خبردار کردیں اور جمع ہونے کے دن سے جس کے آنے میں کوئی شک نہیں ڈرا دیں۔ ایک گروه جنت میں ہوگا اور ایک گروه جہنم میں ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxx{اگر اللہ تعالیٰ چاہتا تو ان سب کو ایک ہی امت کا بنا دیتا لیکن وه جسے چاہتا ہے اپنی رحمت میں داخل کرلیتا ہے اور ﻇالموں کا حامی اور مددگار کوئی نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxi{کیا ان لوگوں نے اللہ تعالیٰ کے سوا اور کارساز بنالیے ہیں، (حقیقتاً تو) اللہ تعالیٰ ہی کارساز ہے وہی مُردوں کو زنده کرے گا اور وہی ہر چیز پر قادر ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxii{اور جس جس چیز میں تمہارا اختلاف ہو اس کا فیصلہ اللہ تعالیٰ ہی کی طرف ہے، یہی اللہ میرا رب ہے جس پر میں نے بھروسہ کر رکھا ہے اور جس کی طرف میں جھکتا ہوں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiii{وه آسمانوں اور زمین کا پیدا کرنے واﻻ ہے اس نے تمہارے لیے تمہاری جنس کے جوڑے بنادیئے ہیں اور چوپایوں کے جوڑے بنائے ہیں تمہیں وه اس میں پھیلا رہا ہے اس جیسی کوئی چیز نہیں وه سننے اور دیکھنے واﻻ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiv{آسمانوں اور زمین کی کنجیاں اسی کی ہیں، جس کی چاہے روزی کشاده کردے اور تنگ کردے، یقیناً وه ہر چیز کو جاننے واﻻ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxv{اللہ تعالیٰ نے تمہارے لیے وہی دین مقرر کردیا ہے جس کے قائم کرنے کا اس نے نوح (علیہ السلام) کو حکم دیا تھا اور جو (بذریعہ وحی) ہم نے تیری طرف بھیج دی ہے، اور جس کا تاکیدی حکم ہم نے ابراہیم اور موسیٰ اور عیسیٰ (علیہم السلام) کو دیا تھا، کہ اس دین کو قائم رکھنا اور اس میں پھوٹ نہ ڈالنا جس چیز کی طرف آپ انہیں بلا رہے ہیں وه تو (ان) مشرکین پر گراں گزرتی ہے، اللہ تعالیٰ جسے چاہتا ہے اپنا برگزیده بناتا ہے اور جو بھی اس کی طرف رجوع کرے وه اس کی صحیح ره نمائی کرتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvi{ان لوگوں نے اپنے پاس علم آجانے کے بعد ہی اختلاف کیا (اور وه بھی) باہمی ضد بحﺚ سے اور اگر آپ کے رب کی بات ایک وقت مقرر تک کے لیے پہلے ہی سے قرار پا گئی ہوئی نہ ہوتی تو یقیناً ان کا فیصلہ ہوچکا ہوتا اور جن لوگوں کو ان کے بعد کتاب دی گئی ہے وه بھی اس کی طرف سے الجھن والے شک میں پڑے ہوئے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvii{پس آپ لوگوں کو اسی طرف بلاتے رہیں اور جو کچھ آپ سے کہا گیا ہے اس پر مضبوطی سے جم جائیں اور ان کی خواہشوں پر نہ چلیں اور کہہ دیں کہ اللہ تعالیٰ نے جتنی کتابیں نازل فرمائی ہیں میرا ان پر ایمان ہے اور مجھے حکم دیا گیا ہے کہ تم میں انصاف کرتا رہوں۔ ہمارا اور تم سب کا پروردگار اللہ ہی ہے ہمارے اعمال ہمارے لیے ہیں اور تمہارے اعمال تمہارے لیے ہیں، ہم تم میں کوئی کٹ حجتی نہیں اللہ تعالیٰ ہم (سب) کو جمع کرے گا اور اسی کی طرف لوٹنا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxviii{اور جو لوگ اللہ تعالیٰ کی باتوں میں جھگڑا ڈالتے ہیں اس کے بعد کہ (مخلوق) اسے مان چکی ان کی کٹ حجتی اللہ کے نزدیک باطل ہے، اور ان پر غضب ہے اور ان کے لیے سخت عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxix{اللہ تعالیٰ نے حق کے ساتھ کتاب نازل فرمائی ہے اور ترازو بھی (اتاری ہے) اور آپ کو کیا خبر شاید قیامت قریب ہی ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxc{اس کی جلدی انہیں پڑی ہے جو اسے نہیں مانتے اور جو اس پر یقین رکھتے ہیں وه تو اس سے ڈر رہے ہیں انہیں اس کے حق ہونے کا پورا علم ہے۔ یاد رکھو جو لوگ قیامت کے معاملہ میں لڑ جھگڑ رہے ہیں، وه دور کی گمراہی میں پڑے ہوئے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxci{اللہ تعالیٰ اپنے بندوں پر بڑا ہی لطف کرنے واﻻ ہے، جسے چاہتا ہے کشاده روزی دیتا ہے اور وه بڑی طاقت، بڑے غلبہ واﻻ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcii{جس کا اراده آخرت کی کھیتی کا ہو ہم اسے اس کی کھیتی میں ترقی دیں گے اور جو دنیا کی کھیتی کی طلب رکھتا ہو ہم اسے اس میں سے ہی کچھ دے دیں گے، ایسے شخص کا آخرت میں کوئی حصہ نہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciii{کیا ان لوگوں نے ایسے (اللہ کے) شریک (مقرر کر رکھے) ہیں جنہوں نے ایسے احکام دین مقرر کر دیئے ہیں جو اللہ کے فرمائے ہوئے نہیں ہیں۔ اگر فیصلے کے دن کا وعده نہ ہوتا تو (ابھی ہی) ان میں فیصلہ کردیا جاتا۔ یقیناً (ان) ﻇالموں کے لیے ہی دردناک عذاب ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciv{آپ دیکھیں گے کہ یہ ﻇالم اپنے اعمال سے ڈر رہے ہوں گے جن کے وبال ان پر واقع ہونے والے ہیں، اور جو لوگ ایمان ﻻئے اور انہوں نے نیک اعمال کیے وه بہشتوں کے باغات میں ہوں گے وه جو خواہش کریں اپنے رب کے پاس موجود پائیں گے یہی ہے بڑا فضل\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcv{یہی وه ہے جس کی بشارت اللہ تعالیٰ اپنے ان بندوں کو دے رہا ہے جو ایمان ﻻئے اور (سنت کے مطابق) نیک عمل کیے تو کہہ دیجئے! کہ میں اس پر تم سے کوئی بدلہ نہیں چاہتا مگر محبت رشتہ داری کی، جو شخص کوئی نیکی کرے ہم اس کے لیے اس کی نیکی میں اور نیکی بڑھا دیں گے۔ بیشک اللہ تعالیٰ بخشنے واﻻ (اور) بہت قدر دان ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvi{کیا یہ کہتے ہیں کہ (پیغمبر نے) اللہ پر جھوٹ باندھا ہے، اگر اللہ تعالیٰ چاہے تو آپ کے دل پر مہر لگادے اور اللہ تعالیٰ اپنی باتوں سے جھوٹ کو مٹا دیتا ہے اور سچ کو ﺛابت رکھتا ہے۔ وه سینے کی باتوں کو جاننے واﻻ ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvii{وہی ہے جو اپنے بندوں کی توبہ قبول فرماتا ہے اور گناہوں سے درگزر فرماتا ہے اور جو کچھ تم کررہے ہو (سب) جانتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcviii{ایمان والوں اور نیکوکار لوگوں کی سنتا ہے اور انہیں اپنے فضل سے اور بڑھا کر دیتا ہے اور کفار کے لیے سخت عذاب ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcix{اگر اللہ تعالیٰ اپنے (سب) بندوں کی روزی فراخ کر دیتا تو وه زمین میں فساد برپا کردیتے لیکن وه اندازے کے ساتھ جو کچھ چاہتا ہے نازل فرماتا ہے۔ وه اپنے بندوں سے پورا خبردار ہے اور خوب دیکھنے واﻻ ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccc{اور وہی ہے جو لوگوں کے ناامید ہوجانے کے بعد بارش برساتا اور اپنی رحمت پھیلا دیتا ہے وہی ہے کارساز اور قابل حمد و ثنا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccci{اور اس کی نشانیوں میں سے آسمانوں اور زمین کی پیدائش ہے اور ان میں جانداروں کا پھیلانا ہے۔ وه اس پر بھی قادر ہے کہ جب چاہے انہیں جمع کردے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcccii{تمہیں جو کچھ مصیبتیں پہنچتی ہیں وه تمہارے اپنے ہاتھوں کے کرتوت کابدلہ ہے، اور وه تو بہت سی باتوں سے درگزر فرما دیتا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccciii{اور تم ہمیں زمین میں عاجز کرنے والے نہیں ہو، تمہارے لیے سوائے اللہ تعالیٰ کے نہ کوئی کارساز ہے نہ مددگار\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccciv{اور دریا میں چلنے والی پہاڑوں جیسی کشتیاں اس کی نشانیوں میں سے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcccv{اگر وه چاہے تو ہوا بند کردے اور یہ کشتیاں سمندروں پر رکی ره جائیں۔ یقیناً اس میں ہر صبر کرنے والے شکرگزار کے لیے نشانیاں ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvi{یا انہیں ان کے کرتوتوں کے باعﺚ تباه کردے، وه تو بہت سے خطاؤں سے درگزر فرمایا کرتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvii{اور تاکہ جو لوگ ہماری نشانیوں میں جھگڑتے ہیں وه معلوم کرلیں کہ ان کے لیے کوئی چھٹکارا نہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcccviii{تو تمہیں جو کچھ دیا گیا ہے وه زندگانی دنیا کا کچھ یونہی سا اسباب ہے، اور اللہ کے پاس جو ہے وه اس سے بدرجہ بہتر اور پائیدار ہے، وه ان کے لیے ہے جو ایمان ﻻئے اور صرف اپنے رب ہی پر بھروسہ رکھتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcccix{اور کبیره گناہوں سے اور بے حیائیوں سے بچتے ہیں اور غصے کے وقت (بھی) معاف کردیتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcccx{اور اپنے رب کے فرمان کو قبول کرتے ہیں اور نماز کی پابندی کرتے ہیں اور ان کا (ہر) کام آپس کے مشورے سے ہوتا ہے، اور جو ہم نے انہیں دے رکھا ہے اس میں سے (ہمارے نام پر) دیتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxi{اور جب ان پر ﻇلم (و زیادتی) ہو تو وه صرف بدلہ لے لیتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxii{اور برائی کا بدلہ اسی جیسی برائی ہے، اور جو معاف کر دے اور اصلاح کرلے اس کا اجر اللہ کے ذمے ہے، (فی الواقع) اللہ تعالیٰ ﻇالموں سے محبت نہیں کرتا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiii{اور جو شخص اپنے مظلوم ہونے کے بعد (برابر کا) بدلہ لے لے تو ایسے لوگوں پر (الزام کا) کوئی راستہ نہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiv{یہ راستہ صرف ان لوگوں پر ہے جو خود دوسروں پر ﻇلم کریں اور زمین میں ناحق فساد کرتے پھریں، یہی لوگ ہیں جن کے لیے دردناک عذاب ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxv{اور جو شخص صبر کر لے اور معاف کردے یقیناً یہ بڑی ہمت کے کاموں میں سے (ایک کام) ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvi{اور جسے اللہ تعالیٰ بہکا دے اس کا اس کے بعد کوئی چاره ساز نہیں، اور تو دیکھے گا کہ ﻇالم لوگ عذاب کو دیکھ کر کہہ رہے ہوں گے کہ کیا واپس جانے کی کوئی راه ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvii{اور تو انہیں دیکھے گا کہ وه (جہنم کے) سامنے ﻻکھڑے کیے جائیں گے مارے ذلت کے جھکے جارہے ہوں گے اور کنکھیوں سے دیکھ رہے ہوں گے، ایمان والے صاف کہیں گے کہ حقیقی زیاںکار وه ہیں جنہوں نے آج قیامت کے دن اپنے آپ کو اور اپنے گھر والوں کو نقصان میں ڈال دیا۔ یاد رکھو کہ یقیناً ﻇالم لوگ دائمی عذاب میں ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxviii{ان کے کوئی مددگار نہیں جو اللہ تعالیٰ سے الگ ان کی امداد کرسکیں اور جسے اللہ گمراه کردے اس کے لیے کوئی راستہ ہی نہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxix{اپنے رب کا حکم مان لو اس سے پہلے کہ اللہ کی جانب سے وه دن آجائے جس کا ہٹ جانا ناممکن ہے، تمہیں اس روز نہ تو کوئی پناه کی جگہ ملے گی نہ چھﭗ کر انجان بن جانے کی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxx{اگر یہ منھ پھیرلیں تو ہم نے آپ کو ان پر نگہبان بنا کر نہیں بھیجا، آپ کے ذمہ تو صرف پیغام پہنچا دینا ہے، ہم جب کبھی انسان کو اپنی مہربانی کا مزه چکھاتے ہیں تو وه اس پر اترا جاتا ہے اور اگر انہیں ان کے اعمال کی وجہ سے کوئی مصیبت پہنچتی ہے تو بےشک انسان بڑا ہی ناشکرا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxi{آسمانوں کی اور زمین کی سلطنت اللہ تعالیٰ ہی کے لیے ہے، وه جو چاہتا ہے پیدا کرتا ہے جس کو چاہتا ہے بیٹیاں دیتا ہے اور جسے چاہتا ہے بیٹے دیتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxii{یا انہیں جمع کردیتا ہے بیٹے بھی اور بیٹیاں بھی اور جسے چاہے بانجھ کر دیتا ہے، وه بڑے علم واﻻ اور کامل قدرت واﻻ ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiii{ناممکن ہے کہ کسی بنده سے اللہ تعالیٰ کلام کرے مگر وحی کے ذریعہ یا پردے کے پیچھے سے یا کسی فرشتہ کو بھیجے اور وه اللہ کے حکم سے جو وه چاہے وحی کرے، بیشک وه برتر ہے حکمت واﻻ ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiv{اور اسی طرح ہم نے آپ کی طرف اپنے حکم سے روح کو اتارا ہے، آپ اس سے پہلے یہ بھی نہیں جانتے تھے کہ کتاب اور ایمان کیا چیز ہے؟ لیکن ہم نے اسے نور بنایا، اس کے ذریعہ سے اپنے بندوں میں سے جسے چاہتے ہیں، ہدایت دیتے ہیں، بیشک آپ راه راست کی رہنمائی کر رہے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxv{اس اللہ کی راه کی جس کی ملکیت میں آسمانوں اور زمین کی ہر چیز ہے۔ آگاه رہو سب کام اللہ تعالیٰ ہی کی طرف لوٹتے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvi{\basmalahur حٰم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvii{قسم ہے اس واضح کتاب کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxviii{ہم نے اس کو عربی زبان کا قرآن بنایا ہے کہ تم سمجھ لو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxix{یقیناً یہ لوح محفوظ میں ہے اور ہمارے نزدیک بلند مرتبہ حکمت والی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxx{کیا ہم اس نصیحت کو تم سے اس بنا پر ہٹالیں کہ تم حد سے گزر جانے والے لوگ ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxi{اور ہم نے اگلے لوگوں میں بھی کتنے ہی نبی بھیجے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxii{جو نبی ان کے پاس آیا انہوں نے اس کا مذاق اڑایا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiii{پس ہم نے ان سے زیاده زور آوروں کو تباه کر ڈاﻻ اور اگلوں کی مثال گزر چکی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiv{اگر آپ ان سے دریافت کریں کہ آسمانوں اور زمین کو کس نے پیدا کیا تو یقیناً ان کا جواب یہی ہوگا کہ انہیں غالب و دانا (اللہ) نے ہی پیدا کیا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxv{وہی ہے جس نے تمہارے لیے زمین کو فرش (بچھونا) بنایا اور اس میں تمہارے لیے راستے کردیے تاکہ تم راه پالیا کرو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvi{اسی نے آسمان سے ایک اندازے کے مطابق پانی نازل فرمایا، پس ہم نے اس سے مرده شہر کو زنده کردیا۔ اسی طرح تم نکالے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvii{جس نے تمام چیزوں کے جوڑے بنائے اور تمہارے لیے کشتیاں بنائیں اور چوپائے جانور (پیدا کیے) جن پر تم سوار ہوتے ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxviii{تاکہ تم ان کی پیٹھ پر جم کر سوار ہوا کرو پھر اپنے رب کی نعمت کو یاد کرو جب اس پر ٹھیک ٹھاک بیٹھ جاؤ، اور کہو پاک ذات ہے اس کی جس نے اسے ہمارے بس میں کردیا حاﻻنکہ ہمیں اسے قابو کرنے کی طاقت نہ تھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxix{اور بالیقین ہم اپنے رب کی طرف لوٹ کر جانے والے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxl{اور انہوں نے اللہ کے بعض بندوں کو اس کا جز ٹھہرا دیا یقیناً انسان کھلم کھلا ناشکرا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxli{کیا اللہ تعالیٰ نے اپنی مخلوق میں سے بیٹیاں تو خود رکھ لیں اور تمہیں بیٹوں سے نوازا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlii{(حاﻻنکہ) ان میں سے کسی کو جب اس چیز کی خبر دی جائے جس کی مثال اس نے (اللہ) رحمٰن کے لیے بیان کی ہے تو اس کا چہره سیاه پڑ جاتا ہے اور وه غمگین ہو جاتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliii{کیا (اللہ کی اوﻻد لڑکیاں ہیں) جو زیورات میں پلیں اور جھگڑے میں (اپنی بات) واضح نہ کرسکیں؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliv{اور انہوں نے فرشتوں کو جو رحمٰن کے عبادت گزار ہیں عورتیں قرار دے لیا۔ کیا ان کی پیدائش کے موقع پر یہ موجود تھے؟ ان کی یہ گواہی لکھ لی جائے گی اور ان سے (اس چیز کی) باز پرس کی جائے گی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlv{اور کہتے ہیں اگر اللہ چاہتا تو ہم ان کی عبادت نہ کرتے۔ انہیں اس کی کچھ خبر نہیں، یہ تو صرف اٹکل پچو (جھوٹ باتیں) کہتے ہیں۔\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvi{کیا ہم نے انہیں اس سے پہلے کوئی (اور) کتاب دی ہے جسے یہ مضبوط تھامے ہوئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvii{(نہیں نہیں) بلکہ یہ تو کہتے ہیں کہ ہم نے اپنے باپ دادا کو ایک مذہب پر پایا اور ہم انہی کے نقش قدم پر چل کر راه یافتہ ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlviii{اسی طرح آپ سے پہلے بھی ہم نے جس بستی میں کوئی ڈرانے واﻻ بھیجا وہاں کے آسوده حال لوگوں نے یہی جواب دیا کہ ہم نے اپنے باپ دادا کو (ایک راه پر اور) ایک دین پر پایا اور ہم تو انہی کے نقش پا کی پیروی کرنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlix{(نبی نے) کہا بھی کہ اگرچہ میں تمہارے پاس اس سے بہت بہتر (مقصود تک پہنچانے واﻻ) طریقہ لے آیا ہوں جس پر تم نے اپنے باپ دادوں کو پایا، تو انہوں نے جواب دیا کہ ہم اس کے منکر ہیں جسے دے کر تمہیں بھیجا گیا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcccl{پس ہم نے ان سے انتقام لیا اور دیکھ لے جھٹلانے والوں کا کیسا انجام ہوا؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcccli{اور جبکہ ابراہیم (علیہ السلام) نے اپنے والد سے اور اپنی قوم سے فرمایا کہ میں ان چیزوں سے بیزار ہوں جن کی تم عبادت کرتے ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccclii{بجز اس ذات کے جس نے مجھے پیدا کیا ہے اور وہی مجھے ہدایت بھی کرے گا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliii{اور (ابراہیم علیہ السلام) اسی کو اپنی اوﻻد میں بھی باقی رہنے والی بات قائم کر گئے تاکہ لوگ (شرک سے) باز آتے رہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliv{بلکہ میں نے ان لوگوں کو اور ان کے باپ دادوں کو سامان (اور اسباب) دیا، یہاں تک کہ ان کے پاس حق اور صاف صاف سنانے واﻻ رسول آگیا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccclv{اور حق کے پہنچتے ہی یہ بول پڑے کہ یہ تو جادو ہے اور ہم اس کے منکر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvi{اور کہنے لگے، یہ قرآن ان دونوں بستیوں میں سے کسی بڑے آدمی پر کیوں نہ نازل کیا گیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvii{کیا آپ کے رب کی رحمت کو یہ تقسیم کرتے ہیں؟ ہم نے ہی ان کی زندگانیٴ دنیا کی روزی ان میں تقسیم کی ہے اور ایک کو دوسرے سے بلند کیا ہے تاکہ ایک دوسرے کو ماتحت کر لے جسے یہ لوگ سمیٹتے پھرتے ہیں اس سے آپ کے رب کی رحمت بہت ہی بہتر ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccclviii{اور اگر یہ بات نہ ہوتی کہ تمام لوگ ایک ہی طریقہ پر ہو جائیں گے تو رحمٰن کے ساتھ کفر کرنے والوں کے گھروں کی چھتوں کو ہم چاندی کی بنادیتے۔ اور زینوں کو (بھی) جن پر چڑھا کرتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmccclix{اور ان کے گھروں کے دروازے اور تخت بھی جن پر وه تکیہ لگا لگا کر بیٹھتے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccclx{اور سونے کے بھی، اور یہ سب کچھ یونہی سا دنیا کی زندگی کا فائده ہے اور آخرت تو آپ کے رب کے نزدیک (صرف) پرہیزگاروں کے لیے (ہی) ہے۔\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxi{اور جو شخص رحمٰن کی یاد سے غفلت کرے ہم اس پر ایک شیطان مقرر کردیتے ہیں وہی اس کا ساتھی رہتا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxii{اور وه انہیں راه سے روکتے ہیں اور یہ اسی خیال میں رہتے ہیں کہ یہ ہدایت یافتہ ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiii{یہاں تک کہ جب وه ہمارے پاس آئے گا کہے گا کاش! میرے اور تیرے درمیان مشرق اور مغرب کی دوری ہوتی (تو) بڑا برا ساتھی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiv{اور جب کہ تم ﻇالم ٹھہر چکے تو تمہیں آج ہرگز تم سب کا عذاب میں شریک ہونا کوئی نفع نہ دے گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxv{کیا پس تو بہرے کو سنا سکتا ہے یا اندھے کو راه دکھا سکتا ہے اور اسے جو کھلی گمراہی میں ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvi{پس اگر ہم تجھے یہاں سے لے بھی جائیں تو بھی ہم ان سے بدلہ لینے والے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvii{یا جو کچھ ان سے وعده کیا ہے وه تجھے دکھا دیں ہم ان پر بھی قدرت رکھتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxviii{پس جو وحی آپ کی طرف کی گئی ہے اسے مضبوط تھامے رہیں بیشک آپ راه راست پر ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxix{اور یقیناً یہ (خود) آپ کے لیے اور آپ کی قوم کے لیے نصیحت ہے اور عنقریب تم لوگ پوچھے جاؤ گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxx{اور ہمارے ان نبیوں سے پوچھو! جنہیں ہم نے آپ سے پہلے بھیجا تھا کہ کیا ہم نے سوائے رحمٰن کے اور معبود مقرر کیے تھے جن کی عبادت کی جائے؟\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxi{اور ہم نے موسیٰ (علیہ السلام) کو اپنی نشانیاں دے کر فرعون اور اس کے امراء کے پاس بھیجا تو (موسیٰ علیہ السلام نے جاکر) کہا کہ میں تمام جہانوں کے رب کا رسول ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxii{پس جب وه ہماری نشانیاں لے کر ان کے پاس آئے تو وه بےساختہ ان پر ہنسنے لگے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiii{اور ہم انہیں جو نشانی دکھاتے تھے وه دوسری سے بڑھی چڑھی ہوتی تھی اور ہم نے انہیں عذاب میں پکڑا تاکہ وه باز آجائیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiv{اور انہوں نے کہا اے جادوگر! ہمارے لیے اپنے رب سے اس کی دعا کر جس کا اس نے تجھ سے وعده کر رکھا ہے، یقین مان کہ ہم راه پر لگ جائیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxv{پھر جب ہم نے وه عذاب ان سے ہٹالیا انہوں نے اسی وقت اپنا قول وقرار توڑ دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvi{اور فرعون نے اپنی قوم میں منادی کرائی اور کہا اے میری قوم! کیا مصر کا ملک میرا نہیں؟ اور میرے (محلوں کے) نیچے یہ نہریں بہہ رہی ہیں، کیا تم دیکھتے نہیں؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvii{بلکہ میں بہتر ہوں بہ نسبت اس کے جو بےتوقیر ہے اور صاف بول بھی نہیں سکتا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxviii{اچھا اس پر سونے کے کنگن کیوں نہیں آپڑے یا اس کے ساتھ پر باندھ کر فرشتے ہی آجاتے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxix{اس نے اپنی قوم کو بہلایا پھسلایا اور انہوں نے اسی کی مان لی، یقیناً یہ سارے ہی نافرمان لوگ تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxx{پھر جب انہوں نے ہمیں غصہ دﻻیا تو ہم نے ان سے انتقام لیا اور سب کو ڈبو دیا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxi{پس ہم نے انہیں گیا گزرا کردیا اور پچھلوں کے لیے مثال بنادی\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxii{اور جب ابن مریم کی مثال بیان کی گئی تو اس سے تیری قوم (خوشی سے) چیخنے لگی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiii{اور انہوں نے کہا کہ ہمارے معبود اچھے ہیں یا وه؟ تجھ سے ان کا یہ کہنا محض جھگڑے کی غرض سے ہے، بلکہ یہ لوگ ہیں ہی جھگڑالو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiv{عیسیٰ (علیہ السلام) بھی صرف بنده ہی ہے جس پر ہم نے احسان کیا اور اسے بنی اسرائیل کے لیے نشان قدرت بنایا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxv{اگر ہم چاہتے تو تمہارے عوض فرشتے کردیتے جو زمین میں جانشینی کرتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvi{اور یقیناً عیسیٰ (علیہ السلام) قیامت کی علامت ہے پس تم (قیامت) کے بارے میں شک نہ کرو اور میری تابعداری کرو، یہی سیدھی راه ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvii{اور شیطان تمہیں روک نہ دے، یقیناً وه تمہارا صریح دشمن ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxviii{اور جب عیسیٰ (علیہ السلام) معجزے کو ﻻئے تو کہا۔ کہ میں تمہارے پاس حکمت ﻻیا ہوں اور اس لیے آیا ہوں کہ جن بعض چیزوں میں تم مختلف ہو، انہیں واضح کردوں، پس تم اللہ تعالیٰ سے ڈرو اور میرا کہا مانو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxix{میرا اور تمہارا رب فقط اللہ تعالیٰ ہی ہے۔ پس تم سب اس کی عبادت کرو۔ راه راست (یہی) ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxc{پھر (بنی اسرائیل کی) جماعتوں نے آپس میں اختلاف کیا، پس ﻇالموں کے لیے خرابی ہے دکھ والے دن کی آفت سے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxci{یہ لوگ صرف قیامت کے منتظر ہیں کہ وه اچانک ان پر آپڑے اور انہیں خبر بھی نہ ہو\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcii{اس دن (گہرے) دوست بھی ایک دوسرے کے دشمن بن جائیں گے سوائے پرہیزگاروں کے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciii{میرے بندو! آج تو تم پر کوئی خوف (و ہراس) ہے اور نہ تم (بد دل اور) غمزده ہوگے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciv{جو ہماری آیتوں پر ایمان ﻻئے اور تھے بھی وه (فرماں بردار) مسلمان\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcv{تم اور تمہاری بیویاں ہشاش بشاش (راضی خوشی) جنت میں چلے جاؤ\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvi{ان کے چاروں طرف سے سونے کی رکابیاں اور سونے کے گلاسوں کا دور چلایا جائے گا، ان کے جی جس چیز کی خواہش کریں اور جس سے ان کی آنکھیں لذت پائیں، سب وہاں ہوگا اور تم اس میں ہمیشہ رہو گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvii{یہی وه بہشت ہے کہ تم اپنے اعمال کے بدلے اس کے وارث بنائے گئے ہو\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcviii{یہاں تمہارے لیے بکثرت میوے ہیں جنہیں تم کھاتے رہو گے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcix{بیشک گنہگار لوگ عذاب دوزخ میں ہمیشہ رہیں گے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcd{یہ عذاب کبھی بھی ان سے ہلکا نہ کیا جائے گا اور وه اسی میں مایوس پڑے رہیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcdi{اور ہم نے ان پر ﻇلم نہیں کیا بلکہ یہ خود ہی ﻇالم تھے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcdii{اور پکار پکار کر کہیں گے کہ اے مالک! تیرا رب ہمارا کام ہی تمام کردے، وه کہے گا کہ تمہیں تو (ہمیشہ) رہنا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiii{ہم تو تمہارے پاس حق لے آئے لیکن تم میں سے اکثر لوگ حق سے نفرت رکھنے والے تھے؟\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiv{کیا انہوں نے کسی کام کا پختہ اراده کرلیا ہے تو یقین مانو کہ ہم بھی پختہ کام کرنے والے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmcdv{کیا ان کا یہ خیال ہے کہ ہم ان کی پوشیده باتوں کو اور ان کی سرگوشیوں کو نہیں سنتے، (یقیناً ہم برابر سن رہے ہیں) بلکہ ہمارے بھیجے ہوئے ان کے پاس ہی لکھ رہے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvi{آپ کہہ دیجئے! کہ اگر بالفرض رحمٰن کی اوﻻد ہو تو میں سب سے پہلے عبادت کرنے واﻻ ہوتا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvii{آسمانوں اور زمین اور عرش کا رب جو کچھ یہ بیان کرتے ہیں اس سے (بہت) پاک ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmcdviii{اب آپ انہیں اسی بحﺚ مباحثہ اور کھیل کود میں چھوڑ دیجئے، یہاں تک کہ انہیں اس دن سے سابقہ پڑجائے جن کا یہ وعده دیے جاتے ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmcdix{وہی آسمانوں میں معبود ہے اور زمین میں بھی وہی قابل عبادت ہے اور وه بڑی حکمت واﻻ اور پورے علم واﻻ ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmcdx{اور وه بہت برکتوں واﻻ ہے جس کے پاس آسمان وزمین اور ان کے درمیان کی بادشاہت ہے، اور قیامت کا علم بھی اسی کے پاس ہے اور اسی کی جانب تم سب لوٹائے جاؤ گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxi{جنہیں یہ لوگ اللہ کے سوا پکارتے ہیں وه شفاعت کرنے کا اختیار نہیں رکھتے، ہاں (مستحق شفاعت وه ہیں) جو حق بات کا اقرار کریں اور انہیں علم بھی ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxii{اگر آپ ان سے دریافت کریں کہ انہیں کس نے پیدا کیا ہے؟ تو یقیناً یہ جواب دیں گے کہ اللہ نے، پھر یہ کہاں الٹے جاتے ہیں؟\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiii{اور ان کا (پیغمبر کا اکثر) یہ کہنا کہ اے میرے رب! یقیناً یہ وه لوگ ہیں جو ایمان نہیں ﻻتے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiv{پس آپ ان سے منھ پھیر لیں اور کہہ دیں۔ (اچھا بھائی) سلام! انہیں عنقریب (خود ہی) معلوم ہوجائے گا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxv{\basmalahur حٰم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvi{قسم ہے اس وضاحت والی کتاب کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvii{یقیناً ہم نے اسے بابرکت رات میں اتارا ہے بیشک ہم ڈرانے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxviii{اسی رات میں ہر ایک مضبوط کام کا فیصلہ کیا جاتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxix{ہمارے پاس سے حکم ہوکر، ہم ہی ہیں رسول بناکر بھیجنے والے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxx{آپ کے رب کی مہربانی سے۔ وه ہی ہے سننے واﻻ جاننے واﻻ\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxi{جو رب ہے آسمانوں کا اور زمین کا اور جو کچھ ان کے درمیان ہے۔ اگر تم یقین کرنے والے ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxii{کوئی معبود نہیں اس کے سوا وہی جلاتا ہے اور مارتا ہے، وہی تمہارا رب ہے اور تمہارے اگلے باپ دادوں کا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiii{بلکہ وه شک میں پڑے کھیل رہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiv{آپ اس دن کے منتظر رہیں جب کہ آسمان ﻇاہر دھواں ﻻئے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxv{جو لوگوں کو گھیر لے گا، یہ دردناک عذاب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvi{کہیں گے کہ اے ہمارے رب! یہ آفت ہم سے دور کر ہم ایمان قبول کرتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvii{ان کے لیے نصیحت کہاں ہے؟ کھول کھول کر بیان کرنے والے پیغمبران کے پاس آچکے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxviii{پھر بھی انہوں نے ان سے منھ پھیرا اور کہہ دیا کہ سکھایا پڑھایا ہوا باؤﻻ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxix{ہم عذاب کو تھوڑا دور کردیں گے تو تم پھر اپنی اسی حالت پر آجاؤ گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxx{جس دن ہم بڑی سخت پکڑ پکڑیں گے، بالیقین ہم بدلہ لینے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxi{یقیناً ان سے پہلے ہم قوم فرعون کو (بھی) آزما چکے ہیں جن کے پاس (اللہ) کا باعزت رسول آیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxii{کہ اللہ تعالیٰ کے بندوں کو میرے حوالے کر دو، یقین مانو کہ میں تمہارے لیے امانت دار رسول ہوں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiii{اور تم اللہ تعالیٰ کے سامنے سرکشی نہ کرو، میں تمہارے پاس کھلی دلیل ﻻنے واﻻ ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiv{اور میں اپنے اور تمہارے رب کی پناه میں آتا ہوں اس سے کہ تم مجھے سنگسار کردو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxv{اور اگر تم مجھ پر ایمان نہیں ﻻتے تو مجھ سے الگ ہی رہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvi{پھر انہوں نے اپنے رب سے دعا کی کہ یہ سب گنہگار لوگ ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvii{(ہم نے کہہ دیا) کہ راتوں رات تو میرے بندوں کو لے کر نکل، یقیناً تمہارا پیچھا کیا جائے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxviii{تو دریا کو ساکن چھوڑ کر چلا جا، بلاشبہ یہ لشکر غرق کردیا جائے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxix{وه بہت سے باغات اور چشمے چھوڑ گئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxl{اور کھیتیاں اور راحت بخش ٹھکانے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxli{اور وه آرام کی چیزیں جن میں عیش کررہے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlii{اسی طرح ہوگیا اور ہم نے ان سب کا وارث دوسری قوم کو بنادیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliii{سو ان پر نہ تو آسمان وزمین روئے اور نہ انہیں مہلت ملی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliv{اور بےشک ہم نے (ہی) بنی اسرائیل کو (سخت) رسوا کن سزا سے نجات دی\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlv{(جو) فرعون کی طرف سے (ہو رہی) تھی۔ فیالواقع وه سرکش اور حد سے گزر جانے والوں میں سے تھا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvi{اور ہم نے دانستہ طور پر بنی اسرائیل کو دنیا جہان والوں پر فوقیت دی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvii{اور ہم نے انہیں ایسی نشانیاں دیں جن میں صریح آزمائش تھی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlviii{یہ لوگ تو یہی کہتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlix{کہ (آخری چیز) یہی ہماری پہلی بار (دنیا سے) مرجانا ہے اور ہم دوباره اٹھائے نہیں جائیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcdl{اگر تم سچے ہو تو ہمارے باپ دادوں کو لے آؤ\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcdli{کیا یہ لوگ بہتر ہیں یا تبع کی قوم کے لوگ اور جو ان سے بھی پہلے تھے۔ ہم نے ان سب کو ہلاک کردیا یقیناً وه گنہ گار تھے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlii{ہم نے زمین اور آسمانوں اور ان کے درمیان کی چیزوں کو کھیل کے طور پر پیدا نہیں کیا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliii{بلکہ ہم نے انہیں درست تدبیر کے ساتھ ہی پیدا کیا ہے، لیکن ان میں سے اکثر لوگ نہیں جانتے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliv{یقیناً فیصلے کا دن ان سب کا طے شده وقت ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlv{اس دن کوئی دوست کسی دوست کے کچھ بھی کام نہ آئے گا اور نہ ان کی امداد کی جائے گی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvi{مگر جس پر اللہ کی مہربانی ہوجائے وه زبردست اور رحم کرنے واﻻ ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvii{بیشک زقوم (تھوہر) کا درخت\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlviii{گناه گار کا کھانا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlix{جو مثل تلچھٹ کے ہے اور پیٹ میں کھولتا رہتا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlx{مثل تیز گرم پانی کے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxi{اسے پکڑ لو پھر گھسیٹتے ہوئے بیچ جہنم تک پہنچاؤ\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxii{پھر اس کے سر پر سخت گرم پانی کا عذاب بہاؤ\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiii{(اس سے کہا جائے گا) چکھتا جا تو تو بڑا ذی عزت اور بڑے اکرام واﻻ تھا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiv{یہی وه چیز ہے جس میں تم شک کیا کرتے تھے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxv{بیشک (اللہ سے) ڈرنے والے امن چین کی جگہ میں ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvi{باغوں اور چشموں میں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvii{باریک اور دبیز ریشم کے لباس پہنے ہوئے آمنے سامنے بیٹھے ہوں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxviii{یہ اسی طرح ہے اور ہم بڑی بڑی آنکھوں والی حوروں سے ان کا نکاح کردیں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxix{دل جمعی کے ساتھ وہاں ہر طرح کے میوؤں کی فرمائشیں کرتے ہوں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxx{وہاں وه موت چکھنے کے نہیں ہاں پہلی موت (جو وه مر چکے)، انہیں اللہ تعالیٰ نے دوزخ کی سزا سے بچا دیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxi{یہ صرف تیرے رب کا فضل ہے، یہی ہے بڑی کامیابی\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxii{ہم نے اس (قرآن) کو تیری زبان میں آسان کردیا تاکہ وه نصیحت حاصل کریں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiii{اب تو منتظر ره یہ بھی منتظر ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiv{\basmalahur حٰم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxv{یہ کتاب اللہ غالب حکمت والے کی طرف سے نازل کی ہوئی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvi{آسمانوں اور زمین میں ایمان داروں کے لیے یقیناً بہت سی نشانیاں ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvii{اور خود تمہاری پیدائش میں اور ان جانوروں کی پیدائش میں جنہیں وه پھیلاتا ہے یقین رکھنے والی قوم کے لیے بہت سی نشانیاں ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxviii{اور رات دن کے بدلنے میں اور جو کچھ روزی اللہ تعالیٰ آسمان سے نازل فرما کر زمین کو اس کی موت کے بعد زنده کر دیتا ہے، (اس میں) اور ہواؤں کے بدلنے میں بھی ان لوگوں کے لیے جو عقل رکھتے ہیں نشانیاں ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxix{یہ ہیں اللہ کی آیتیں جنہیں ہم آپ کو راستی سے سنا رہے ہیں، پس اللہ تعالیٰ اور اس کی آیتوں کے بعد یہ کس بات پر ایمان ﻻئیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxx{ویل اور افسوس ہے ہر ایک جھوٹے گنہگار پر\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxi{جو آیتیں اللہ کی اپنے سامنے پڑھی جاتی ہوئی سنے پھر بھی غرور کرتا ہوا اس طرح اڑا رہے کہ گویا سنی ہی نہیں، تو ایسے لوگوں کو دردناک عذاب کی خبر (پہنچا) دیجئے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxii{وه جب ہماری آیتوں میں سے کسی آیت کی خبر پالیتا ہے تو اس کی ہنسی اڑاتا ہے، یہی لوگ ہیں جن کے لیے رسوائی کی مار ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiii{ان کے پیچھے دوزخ ہے، جو کچھ انہوں نے حاصل کیا تھا وه انہیں کچھ بھی نفع نہ دے گا اور نہ وه (کچھ کام آئیں گے) جن کو انہوں نے اللہ کے سوا کارساز بنا رکھا تھا، ان کے لیے تو بہت بڑا عذاب ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiv{یہ (سر تاپا) ہدایت ہے اور جن لوگوں نے اپنے رب کی آیتوں کو نہ مانا ان کے لیے بہت سخت دردناک عذاب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxv{اللہ ہی ہے جس نے تمہارے لیے دریا کو تابع بنادیا تاکہ اس کے حکم سے اس میں کشتیاں چلیں اور تم اس کا فضل تلاش کرو اور تاکہ تم شکر بجاﻻؤ\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvi{اور آسمان وزمین کی ہر ہر چیز کو بھی اس نے اپنی طرف سے تمہارے لیے تابع کر دیا ہے۔ جو غور کریں یقیناً وه اس میں بہت سی نشانیاں پالیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvii{آپ ایمان والوں سے کہہ دیں کہ وه ان لوگوں سے درگزر کریں جو اللہ کے دنوں کی توقع نہیں رکھتے، تاکہ اللہ تعالیٰ ایک قوم کو ان کے کرتوتوں کا بدلہ دے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxviii{جو نیکی کرے گا وه اپنے ذاتی بھلے کے لیے اور جو برائی کرے گا اس کا وبال اسی پر ہے، پھر تم سب اپنے پروردگار کی طرف لوٹائے جاؤ گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxix{یقیناً ہم نے بنی اسرائیل کو کتاب، حکومت اور نبوت دی تھی، اور ہم نے انہیں پاکیزه (اور نفیس) روزیاں دی تھیں اور انہیں دنیا والوں پر فضیلت دی تھی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxc{اور ہم نے انہیں دین کی صاف صاف دلیلیں دیں، پھر انہوں نے اپنے پاس علم کے پہنچ جانے کے بعد آپس کی ضد بحﺚ سے ہی اختلاف برپا کر ڈاﻻ، یہ جن جن چیزوں میں اختلاف کر رہے ہیں ان کا فیصلہ قیامت والے دن ان کے درمیان (خود) تیرا رب کرے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxci{پھر ہم نے آپ کو دین کی (ﻇاہر) راه پر قائم کردیا، سو آپ اسی پر لگے رہیں اور نادانوں کی خواہشوں کی پیروی میں نہ پڑیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcii{(یاد رکھیں) کہ یہ لوگ ہرگز اللہ کے سامنے آپ کے کچھ کام نہیں آسکتے۔ (سمجھ لیں کہ) ﻇالم لوگ آپس میں ایک دوسرے کے رفیق ہوتے ہیں اور پرہیزگاروں کا کارساز اللہ تعالیٰ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciii{یہ (قرآن) لوگوں کے لیے بصیرت کی باتیں اور ہدایت ورحمت ہے اس قوم کے لیے جو یقین رکھتی ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciv{کیا ان لوگوں کا جو برے کام کرتے ہیں یہ گمان ہے کہ ہم انہیں ان لوگوں جیسا کردیں گے جو ایمان ﻻئے اور نیک کام کیے کہ ان کا مرنا جینا یکساں ہوجائے، برا ہے وه فیصلہ جو وه کررہے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcv{اور آسمانوں اور زمین کو اللہ نے بہت ہی عدل کے ساتھ پیدا کیا ہے اور تاکہ ہر شخص کو اس کے کیے ہوئے کام کا پورا بدلہ دیا جائے اور ان پر ﻇلم نہ کیا جائے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvi{کیا آپ نے اسے بھی دیکھا؟ جس نے اپنی خواہش نفس کو اپنا معبود بنا رکھا ہے اور باوجود سمجھ بوجھ کے اللہ نے اسے گمراه کردیا ہے اور اس کے کان اور دل پر مہر لگادی ہے اور اس کی آنکھ پر بھی پرده ڈال دیا ہے، اب ایسے شخص کو اللہ کے بعد کون ہدایت دے سکتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvii{کیا اب بھی تم نصیحت نہیں پکڑتے۔ انہوں نے کہا کہ ہماری زندگی تو صرف دنیا کی زندگی ہی ہے۔ ہم مرتے ہیں اور جیتے ہیں اور ہمیں صرف زمانہ ہی مار ڈالتا ہے، (دراصل) انہیں اس کا کچھ علم ہی نہیں۔ یہ تو صرف (قیاس اور) اٹکل سے ہی کام لے رہے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcviii{اور جب ان کے سامنے ہماری واضح اور روشن آیتوں کی تلاوت کی جاتی ہے، تو ان کے پاس اس قول کے سوا کوئی دلیل نہیں ہوتی کہ اگر تم سچے ہو تو ہمارے باپ دادوں کو ﻻؤ\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcix{آپ کہہ دیجئے! اللہ ہی تمہیں زنده کرتا ہے پھر تمہیں مار ڈالتا ہے پھر تمہیں قیامت کے دن جمع کرے گا جس میں کوئی شک نہیں لیکن اکثر لوگ نہیں سمجھتے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmd{اور آسمانوں اور زمین کی بادشاہی اللہ ہی کی ہے اور جس دن قیامت قائم ہوگی اس دن اہل باطل بڑے نقصان میں پڑیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdi{اور آپ دیکھیں گے کہ ہر امت گھٹنوں کے بل گری ہوئی ہوگی۔ ہر گروه اپنے نامہٴ اعمال کی طرف بلایا جائے گا، آج تمہیں اپنے کیے کا بدلہ دیا جائے گا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdii{یہ ہے ہماری کتاب جو تمہارے بارے میں سچ سچ بول رہی ہے، ہم تمہارے اعمال لکھواتے جاتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdiii{پس لیکن جو لوگ ایمان ﻻئے اور انہوں نے نیک کام کیے تو ان کو ان کا رب اپنی رحمت تلے لے لے گا، یہی صریح کامیابی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdiv{لیکن جن لوگوں نے کفر کیا تو (میں ان سے کہوں گا) کیا میری آیتیں تمہیں سنائی نہیں جاتی تھیں؟ پھر بھی تم تکبر کرتے رہے اور تم تھے ہی گنہ گار لوگ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdv{اور جب کبھی کہا جاتا کہ اللہ کا وعده یقیناً سچا ہے اور قیامت کے آنے میں کوئی شک نہیں تو تم جواب دیتے تھے کہ ہم نہیں جانتے قیامت کیا چیز ہے؟ ہمیں کچھ یوں ہی سا خیال ہوجاتا ہے لیکن ہمیں یقین نہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdvi{اور ان پر اپنے اعمال کی برائیاں کھل گئیں اور جس کا وه مذاق اڑا رہے تھے اس نے انہیں گھیر لیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdvii{اور کہہ دیا گیا کہ آج ہم تمہیں بھلا دیں گے جیسے کہ تم نے اپنے اس دن سے ملنے کو بھلا دیا تھا تمہارا ٹھکانا جہنم ہے اور تمہارا مددگار کوئی نہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdviii{یہ اس لیے ہے کہ تم نے اللہ تعالیٰ کی آیتوں کی ہنسی اڑائی تھی اور دنیا کی زندگی نے تمہیں دھوکے میں ڈال رکھا تھا، پس آج کے دن نہ تو یہ (دوزخ) سے نکالے جائیں گے اور نہ ان سے عذر و معذرت قبول کیا جائے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdix{پس اللہ کی تعریف ہے جو آسمانوں اور زمین اور تمام جہان کا پالنہار ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdx{تمام (بزرگی اور) بڑائی آسمانوں اور زمین میں اسی کی ہے اور وہی غالب اور حکمت واﻻ ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdxi{\basmalahur حٰم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxii{اس کتاب کا اتارنا اللہ تعالیٰ غالب حکمت والے کی طرف سے ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiii{ہم نے آسمانوں اور زمین اور ان دونوں کے درمیان کی تمام چیزوں کو بہترین تدبیر کے ساتھ ہی ایک مدت معین کے لئے پیدا کیا ہے، اور کافر لوگ جس چیز سے ڈرائے جاتے ہیں منھ موڑ لیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiv{آپ کہہ دیجئے! بھلا دیکھو تو جنہیں تم اللہ کے سوا پکارتے ہو مجھے بھی تو دکھاؤ کہ انہوں نے زمین کا کون سا ٹکڑا بنایا ہے یا آسمانوں میں ان کا کون سا حصہ ہے؟ اگر تم سچے ہو تو اس سے پہلے ہی کی کوئی کتاب یا کوئی علم ہی جو نقل کیا جاتا ہو، میرے پاس ﻻؤ\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdxv{اور اس سے بڑھ کر گمراه اور کون ہوگا؟ جو اللہ کے سوا ایسوں کو پکارتا ہے جو قیامت تک اس کی دعا قبول نہ کر سکیں بلکہ ان کے پکارنے سے محض بےخبر ہوں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvi{اور جب لوگوں کو جمع کیا جائے گا تو یہ ان کے دشمن ہو جائیں گے اور ان کی پرستش سے صاف انکار کر جائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvii{اور انہیں جب ہماری واضح آیتیں پڑھ کر سنائی جاتی ہیں تو منکر لوگ سچی بات کو جب کہ ان کے پاس آچکی، کہہ دیتے ہیں کہ یہ تو صریح جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxviii{کیا وه کہتے ہیں کہ اسے تو اس نے خود گھڑ لیا ہے آپ کہہ دیجئے! کہ اگر میں ہی اسے بنا ﻻیا ہوں تو تم میرے لئے اللہ کی طرف سے کسی چیز کا اختیار نہیں رکھتے، تم اس (قرآن) کے بارے میں جو کچھ کہہ سن رہے ہو اسے اللہ خوب جانتا ہے، میرے اور تمہارے درمیان گواہی کے لئے وہی کافی ہے، اور وه بخشنے واﻻ مہربان ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxix{آپ کہہ دیجئے! کہ میں کوئی بالکل انوکھا پیغمبر تو نہیں نہ مجھے یہ معلوم ہے کہ میرے ساتھ اور تمہارے ساتھ کیا کیا جائے گا۔ میں تو صرف اسی کی پیروی کرتا ہوں جو میری طرف وحی بھیجی جاتی ہے اور میں تو صرف علیاﻻعلان آگاه کر دینے واﻻ ہوں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxx{آپ کہہ دیجئے! اگر یہ (قرآن) اللہ ہی کی طرف سے ہو اور تم نے اسے نہ مانا ہو اور بنی اسرائیل کا ایک گواه اس جیسی کی گواہی بھی دے چکا ہو اور وه ایمان بھی ﻻچکا ہو اور تم نے سرکشی کی ہو، تو بیشک اللہ تعالیٰ ﻇالموں کو راه نہیں دکھاتا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxi{اور کافروں نے ایمان داروں کی نسبت کہا کہ اگر یہ (دین) بہتر ہوتا تو یہ لوگ اس کی طرف ہم سے سبقت کرنے نہ پاتے، اور چونکہ انہوں نے قرآن سے ہدایت نہیں پائی پس یہ کہہ دیں گے کہ قدیمی جھوٹ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxii{اور اس سے پہلے موسیٰ کی کتاب پیشوا اور رحمت تھی۔ اور یہ کتاب ہے تصدیق کرنے والی عربی زبان میں تاکہ ﻇالموں کو ڈرائے اور نیک کاروں کو بشارت ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiii{بیشک جن لوگوں نے کہا کہ ہمارا رب اللہ ہے پھر اس پر جمے رہے تو ان پر نہ تو کوئی خوف ہوگا اور نہ غمگین ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiv{یہ تو اہل جنت ہیں جو سدا اسی میں رہیں گے، ان اعمال کے بدلے جو وه کیا کرتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxv{اور ہم نے انسان کو اپنے ماں باپ کے ساتھ حسن سلوک کرنے کا حکم دیا ہے، اس کی ماں نے اسے تکلیف جھیل کر پیٹ میں رکھا اور تکلیف برداشت کرکے اسے جنا۔ اس کے حمل کا اور اس کے دودھ چھڑانے کا زمانہ تیس مہینے کا ہے۔ یہاں تک کہ جب وه پختگی اور چالیس سال کی عمر کو پہنچا تو کہنے لگا اے میرے پروردگار! مجھے توفیق دے کہ میں تیری اس نعمت کا شکر بجا ﻻؤں جو تو نے مجھ پر اور میرے ماں باپ پر انعام کی ہے اور یہ کہ میں ایسے نیک عمل کروں جن سے تو خوش ہو جائے اور تو میری اوﻻد بھی صالح بنا، میں تیری طرف رجوع کرتا ہوں اور میں مسلمانوں میں سے ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvi{یہی وه لوگ ہیں جن کے نیک اعمال تو ہم قبول فرما لیتے ہیں اور جن کے بداعمال سے درگزر کر لیتے ہیں، (یہ) جنتی لوگوں میں ہیں۔ اس سچے وعدے کے مطابق جو ان سے کیا جاتا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvii{اور جس نے اپنے ماں باپ سے کہا کہ تم سے میں تنگ آگیا، تم مجھ سے یہی کہتے رہو گے کہ میں مرنے کے بعد پھر زنده کیا جاؤں گا مجھ سے پہلے بھی امتیں گزر چکی ہیں، وه دونوں جناب باری میں فریادیں کرتے ہیں اور کہتے ہیں تجھے خرابی ہو تو ایمان لے آ، بیشک اللہ کا وعده حق ہے، وه جواب دیتا ہے کہ یہ تو صرف اگلوں کے افسانے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxviii{وه لوگ ہیں جن پر (اللہ کے عذاب کا) وعده صادق آگیا، ان جنات اور انسانوں کے گروہوں کے ساتھ جو ان سے پہلے گزر چکے ہیں، یقیناً یہ نقصان پانے والے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxix{اور ہر ایک کو اپنے اپنے اعمال کے مطابق درجے ملیں گے تاکہ انہیں ان کے اعمال کے پورے بدلے دے اور ان پر ﻇلم نہ کیا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxx{اور جس دن کافر جہنم کے سرے پر ﻻئے جائیں گے (کہا جائے گا) تم نے اپنی نیکیاں دنیا کی زندگی میں ہی برباد کر دیں اور ان سے فائدے اٹھا چکے، پس آج تمہیں ذلت کے عذاب کی سزا دی جائے گی، اس باعﺚ کہ تم زمین میں ناحق تکبر کیا کرتے تھے اور اس باعﺚ بھی کہ تم حکم عدولی کیا کرتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxi{اور عاد کے بھائی کو یاد کرو، جبکہ اس نے اپنی قوم کو احقاف میں ڈرایا اور یقیناً اس سے پہلے بھی ڈرانے والے گزر چکے ہیں اور اس کے بعد بھی یہ کہ تم سوائے اللہ تعالیٰ کے اور کسی کی عبادت نہ کرو، بیشک میں تم پر بڑے دن کے عذاب سے خوف کھاتا ہوں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxii{قوم نے جواب دیا، کیا آپ ہمارے پاس اس لئے آئے ہیں کہ ہمیں اپنے معبودوں (کی پرستش) سے باز رکھیں؟ پس اگر آپ سچے ہیں تو جس عذاب کا آپ وعده کرتے ہیں اسے ہم پر ﻻ ڈالیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiii{(حضرت ہود نے) کہا (اس کا) علم تو اللہ ہی کے پاس ہے، میں تو جو پیغام دے کر بھیجا گیا تھا وه تمہیں پہنچا رہا ہوں لیکن میں دیکھتا ہوں کہ تم لوگ نادانی کر رہے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiv{پھر جب انہوں نے عذاب کو بصورت بادل دیکھا اپنی وادیوں کی طرف آتے ہوئے تو کہنے لگے، یہ ابر ہم پر برسنے واﻻ ہے، (نہیں) بلکہ دراصل یہ ابر وه (عذاب) ہے جس کی تم جلدی کر رہے تھے، ہوا ہے جس میں دردناک عذاب ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxv{جو اپنے رب کے حکم سے ہر چیز کو ہلاک کر دے گی، پس وه ایسے ہوگئے کہ بجر ان کے مکانات کے اور کچھ دکھائی نہ دیتا تھا۔ گنہگاروں کے گروه کو ہم یوں ہی سزا دیتے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvi{اور بالیقین ہم نے (قوم عاد) کو وه مقدور دیئے تھے جو تمہیں تو دیئے بھی نہیں اور ہم نے انہیں کان آنکھیں اور دل بھی دے رکھے تھے۔ لیکن ان کے کانوں اور آنکھوں اور دلوں نے انہیں کچھ بھی نفع نہ پہنچایا جبکہ وه اللہ تعالیٰ کی آیتوں کا انکار کرنے لگے اور جس چیز کا وه مذاق اڑایا کرتے تھے وہی ان پر الٹ پڑی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvii{اور یقیناً ہم نے تمہارے آس پاس کی بستیاں تباه کر دیں اور طرح طرح کی ہم نے اپنی نشانیاں بیان کر دیں تاکہ وه رجوع کر لیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxviii{پس قرب الٰہی حاصل کرنے کے لئے انہوں نے اللہ کے سوا جن جن کو اپنا معبود بنا رکھا تھا انہوں نے ان کی مدد کیوں نہ کی؟ بلکہ وه تو ان سے کھو گئے، (بلکہ دراصل) یہ ان کا محض جھوٹ اور (بالکل) بہتان تھا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxix{اور یاد کرو! جبکہ ہم نے جنوں کی ایک جماعت کو تیری طرف متوجہ کیا کہ وه قرآن سنیں، پس جب (نبی کے) پاس پہنچ گئے تو (ایک دوسرے سے) کہنے لگے خاموش ہو جاؤ، پھر جب پڑھ کر ختم ہوگیا تو اپنی قوم کو خبردار کرنے کے لئے واپس لوٹ گئے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdxl{کہنے لگے اے ہماری قوم! ہم نے یقیناً وه کتاب سنی ہے جو موسیٰ (علیہ السلام) کے بعد نازل کی گئی ہے جو اپنے سے پہلی کتابوں کی تصدیق کرنے والی ہے جو سچے دین کی اور راه راست کی طرف رہنمائی کرتی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdxli{اے ہماری قوم! اللہ کے بلانے والے کا کہا مانو، اس پر ایمان ﻻؤ، تو اللہ تمہارے گناه بخش دے گا اور تمہیں المناک عذاب سے پناه دےگا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlii{اور جو شخص اللہ کے بلانے والے کا کہا نہ مانے گا پس وه زمین میں کہیں (بھاگ کر اللہ کو) عاجز نہیں کر سکتا، نہ اللہ کے سوا اور کوئی اس کے مدد گار ہوں گے، یہ لوگ کھلی گمراہی میں ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliii{کیا وه نہیں دیکھتے کہ جس اللہ نے آسمانوں اور زمین کو پیدا کیا اور ان کے پیدا کرنے سے وه نہ تھکا، وه یقیناً مُردوں کو زنده کرنے پر قادر ہے؟ کیوں نہ ہو؟ وه یقیناً ہر چیز پر قادر ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliv{وه لوگ جنہوں نے کفر کیا جس دن جہنم کے سامنے ﻻئے جائیں گے (اور ان سے کہا جائے گا کہ) کیا یہ حق نہیں ہے؟ تو جواب دیں گے کہ ہاں قسم ہے ہمارے رب کی (حق ہے) (اللہ) فرمائے گا، اب اپنے کفر کے بدلے عذاب کا مزه چکھو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlv{پس (اے پیغمبر!) تم ایسا صبر کرو جیسا صبر عالی ہمت رسولوں نے کیا اور ان کے لئے (عذاب طلب کرنے میں) جلدی نہ کرو، یہ جس دن اس عذاب کو دیکھ لیں گے جس کا وعده دیئے جاتے ہیں تو (یہ معلوم ہونے لگے گا کہ) دن کی ایک گھڑی ہی (دنیا میں) ٹھہرے تھے، یہ ہے پیغام پہنچا دینا، پس بدکاروں کے سوا کوئی ہلاک نہ کیا جائے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvi{\basmalahur جن لوگوں نے کفر کیا اور اللہ کی راه سے روکا اللہ نے ان کے اعمال برباد کر دیئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvii{اور جو لوگ ایمان ﻻئے اور اچھے کام کیے اور اس پر بھی ایمان ﻻئے جو محمد ﴿صلی اللہ علیہ وسلم﴾ پر اتاری گئی ہے اور دراصل ان کے رب کی طرف سے سچا (دین) بھی وہی ہے، اللہ نے ان کے گناه دور کر دیئے اور ان کے حال کی اصلاح کر دی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlviii{یہ اس لئے کہ کافروں نے باطل کی پیروی کی اور مومنوں نے اس دین حق کی اتباع کی جو ان کے اللہ کی طرف سے ہے، اللہ تعالیٰ لوگوں کو ان کے احوال اسی طرح بتاتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlix{تو جب کافروں سے تمہاری مڈبھیڑ ہوتو گردنوں پر وار مارو۔ جب ان کو اچھی طرح کچل ڈالو تو اب خوب مضبوط قید وبند سے گرفتار کرو، (پھر اختیار ہے) کہ خواه احسان رکھ کر چھوڑ دو یا فدیہ لے کر تاوقتیکہ لڑائی اپنے ہتھیار رکھ دے۔ یہی حکم ہے اور اللہ اگر چاہتا تو (خود) ہی ان سے بدلہ لے لیتا، لیکن (اس کا منشا یہ ہے) کہ تم میں سے ایک کا امتحان دوسرے کے ذریعہ سے لے لے، جو لوگ اللہ کی راه میں شہید کر دیے جاتے ہیں اللہ ان کے اعمال ہرگز ضائع نہ کرے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdl{انہیں راه دکھائے گا اور ان کے حاﻻت کی اصلاح کر دے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdli{اور انہیں اس جنت میں لے جائے گا جس سے انہیں شناسا کر دیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdlii{اے ایمان والو! اگر تم اللہ (کے دین) کی مدد کرو گے تو وه تمہاری مدد کرے گا اور تمہیں ﺛابت قدم رکھے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdliii{اور جو لوگ کافر ہوئے انہیں ہلاکی ہو اللہ ان کے اعمال غارت کردے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdliv{یہ اس لئے کہ وه اللہ کی نازل کرده چیز سے ناخوش ہوئے، پس اللہ تعالیٰ نے (بھی) ان کے اعمال ضائع کر دیئے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdlv{کیا ان لوگوں نے زمین میں چل پھر کر اس کا معائنہ نہیں کیا کہ ان سے پہلے کے لوگوں کا نتیجہ کیا ہوا؟ اللہ نے انہیں ہلاک کر دیا اور کافروں کے لئے اسی طرح کی سزائیں ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvi{وه اس لئے کہ ایمان والوں کا کارساز خود اللہ تعالیٰ ہے اور اس لئے کہ کافروں کا کوئی کارساز نہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvii{جو لوگ ایمان ﻻئے اور انہوں نے نیک اعمال کیے انہیں اللہ تعالیٰ ایسے باغوں میں داخل کرے گا جن کے نیچے نہریں جاری ہیں اور جو لوگ کافر ہوئے وه (دنیا ہی کا) فائده اٹھا رہے ہیں اور مثل چوپایوں کے کھا رہے ہیں، ان کا (اصل) ٹھکانہ جہنم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdlviii{ہم نے کتنی بستیوں کو جو طاقت میں تیری اس بستی سے زیاده تھیں جس سے تجھے نکالا ہم نے انہیں ہلاک کر دیا ہے، جن کا مددگار کوئی نہ اٹھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdlix{کیا پس وه شخص جو اپنے پروردگار کی طرف سے دلیل پر ہو اس شخص جیسا ہو سکتا ہے؟ جس کے لئے اس کا برا کام مزین کر دیا گیا ہو اور وه اپنی نفسانی خواہشوں کا پیرو ہو؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdlx{اس جنت کی صفت جس کا پرہیزگاروں سے وعده کیا گیا ہے، یہ ہے کہ اس میں پانی کی نہریں ہیں جو بدبو کرنے واﻻ نہیں، اور دودھ کی نہریں ہیں جن کا مزه نہیں بدﻻ اور شراب کی نہریں ہیں جن میں پینے والوں کے لئے بڑی لذت ہے اور نہریں ہیں شہد کی جو بہت صاف ہیں اور ان کے لئے وہاں ہر قسم کے میوے ہیں اور ان کے رب کی طرف سے مغفرت ہے، کیا یہ مثل اس کے ہیں جو ہمیشہ آگ میں رہنے واﻻ ہے؟ اور جنہیں گرم کھولتا ہوا پانی پلایا جائے گا جو ان کی آنتوں کو ٹکڑے ٹکڑے کر دے گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxi{اور ان میں بعض (ایسے بھی ہیں کہ) تیری طرف کان لگاتے ہیں۔ یہاں تک کہ جب تیرے پاس سے جاتے ہیں تو اہل علم سے (بوجہ کند ذہنی وﻻپرواہی کے) پوچھتے ہیں کہ اس نے ابھی کیا کہا تھا؟ یہی لوگ ہیں جن کے دلوں پر اللہ نے مہر کر دی ہے اور وه اپنی خواہشوں کی پیروی کرتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxii{اور جو لوگ ہدایت یافتہ ہیں اللہ نے انہیں ہدایت میں اور بڑھا دیا ہے اور انہیں ان کی پرہیزگاری عطا فرمائی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiii{تو کیا یہ قیامت کا انتظار کر رہے ہیں کہ وه ان کے پاس اچانک آجائے یقیناً اس کی علامتیں تو آچکی ہیں، پھر جبکہ ان کے پاس قیامت آجائے انہیں نصیحت کرنا کہاں ہوگا؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiv{سو (اے نبی!) آپ یقین کر لیں کہ اللہ کے سوا کوئی معبود نہیں اور اپنے گناہوں کی بخشش مانگا کریں اور مومن مردوں اور مومن عورتوں کے حق میں بھی، اللہ تم لوگوں کی آمد ورفت کی اور رہنے سہنے کی جگہ کو خوب جانتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxv{اور جو لوگ ایمان ﻻئے وه کہتے ہیں کوئی سورت کیوں نازل نہیں کی گئی؟ پھر جب کوئی صاف مطلب والی سورت نازل کی جاتی ہے اور اس میں قتال کا ذکر کیا جاتا ہے تو آپ دیکھتے ہیں کہ جن لوگوں کے دلوں میں بیماری ہے وه آپ کی طرف اس طرح دیکھتے ہیں جیسے اس شخص کی نظر ہوتی ہے جس پر موت کی بیہوشی طاری ہو، پس بہت بہتر تھا ان کے لئے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvi{فرمان کا بجا ﻻنا اور اچھی بات کا کہنا۔ پھر جب کام مقرر ہو جائے، تو اللہ کے ساتھ سچے رہیں تو ان کے لئے بہتری ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvii{اور تم سے یہ بھی بعید نہیں کہ اگر تم کو حکومت مل جائے تو تم زمین میں فساد برپا کر دو اور رشتے ناتے توڑ ڈالو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxviii{یہ وہی لوگ ہیں جن پر اللہ کی پھٹکار ہے اور جن کی سماعت اور آنکھوں کی روشنی چھین لی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxix{کیا یہ قران میں غور وفکر نہیں کرتے؟ یا ان کے دلوں پر تالے لگ گئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxx{جو لوگ اپنی پیٹھ کے بل الٹے پھر گئے اس کے بعد ان کے لئے ہدایت واضح ہو چکی یقیناً شیطان نے ان کے لئے (ان کے فعل کو) مزین کر دیا ہے اور انہیں ڈھیل دے رکھی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxi{یہ اس لئے کہ انہوں نے ان لوگوں سے جنہوں نے اللہ کی نازل کرده وحی کو برا سمجھا یہ کہا کہ ہم بھی عنقریب بعض کاموں میں تمہارا کہا مانیں گے، اور اللہ ان کی پوشیده باتیں خوب جانتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxii{پس ان کی کیسی (درگت) ہوگی جبکہ فرشتے ان کی روح قبض کرتے ہوئے ان کے چہروں اور ان کی سرینوں پر ماریں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiii{یہ اس بنا پر کہ یہ وه راه چلے جس سے انہوں نے اللہ کو ناراض کر دیا اور انہوں نے اس کی رضا مندی کو برا جانا، تو اللہ نے ان کے اعمال اکارت کر دیئے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiv{کیا ان لوگوں نے جن کے دلوں میں بیماری ہے یہ سمجھ رکھا ہے کہ اللہ ان کے کینوں کو ﻇاہر نہ کرے گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxv{اور اگر ہم چاہتے تو ان سب کو تجھے دکھا دیتے پس تو انہیں ان کے چہرے سے ہی پہچان لیتا، اور یقیناً تو انہیں ان کی بات کے ڈھب سے پہچان لے گا، تمہارے سب کام اللہ کو معلوم ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvi{یقیناً ہم تمہارا امتحان کریں گے تاکہ تم میں سے جہاد کرنے والوں اور صبر کرنے والوں کو ﻇاہر کر دیں اور ہم تمہاری حالتوں کی بھی جانچ کر لیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvii{یقیناً جن لوگوں نے کفر کیا اور اللہ کی راه سے لوگوں کو روکا اور رسول کی مخالفت کی اس کے بعد کہ ان کے لئے ہدایت ﻇاہر ہو چکی یہ ہرگز ہرگز اللہ کا کچھ نقصان نہ کر سکیں گے۔ عنقریب ان کے اعمال وه غارت کردے گا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxviii{اے ایمان والو! اللہ کی اطاعت کرو اور رسول کا کہا مانو اور اپنے اعمال کو غارت نہ کرو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxix{جن لوگوں نے کفر کیا اور اللہ کی راه سے اوروں کو روکا پھر کفر کی حالت میں ہی مرگئے (یقین کر لو) کہ اللہ انہیں ہرگز نہ بخشے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxx{پس تم بودے بن کر صلح کی درخواست پر نہ اتر آؤ جبکہ تم ہی بلند وغالب رہو گے اور اللہ تمہارے ساتھ ہے، ناممکن ہے کہ وه تمہارے اعمال ضائع کر دے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxi{واقعی زندگانیٴ دنیا تو صرف کھیل کود ہے اور اگر تم ایمان لے آؤ گے اور تقویٰ اختیار کرو گے تو اللہ تمہیں تمہارے اجر دے گا اور وه تم سے تمہارے مال نہیں مانگتا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxii{اگر وه تم سے تمہارا مال مانگے اور زور دے کر مانگے تو تم اس سے بخیلی کرنے لگو گے اور وه تمہارے کینے ﻇاہر کر دے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiii{خبردار! تم وه لوگ ہو کہ اللہ کی راه میں خرچ کرنے کے لئے بلائے جاتے ہو، تو تم میں سے بعض بخیلی کرنے لگتے ہیں اور جو بخل کرتا ہے وه تو دراصل اپنی جان سے بخیلی کرتا ہے۔ اللہ تعالیٰ غنی ہے اور تم فقیر (اور محتاج) ہو اور اگر تم روگردان ہو جاؤ تو وه تمہارے بدلے تمہارے سوا اور لوگوں کو ﻻئے گا جو پھر تم جیسے نہ ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiv{\basmalahur بیشک (اے نبی) ہم نے آپ کو ایک کھلم کھلا فتح دی ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxv{تاکہ جو کچھ تیرے گناه آگے ہوئے اور جو پیچھے سب کو اللہ تعالیٰ معاف فرمائے، اور تجھ پر اپنا احسان پورا کر دے اور تجھے سیدھی راه چلائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvi{اور آپ کو ایک زبردست مدد دے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvii{وہی ہے جس نے مسلمانوں کے دلوں میں سکون (اور اطیمنان) ڈال دیا تاکہ اپنے ایمان کے ساتھ ہی ساتھ اور بھی ایمان میں بڑھ جائیں، اور آسمانوں اور زمین کے ﴿کل﴾ لشکر اللہ ہی کے ہیں۔ اور اللہ تعالیٰ دانا باحکمت ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxviii{تاکہ مومن مردوں اور عورتوں کو ان جنتوں میں لے جائے جن کے نیچے نہریں بہ رہی ہیں جہاں وه ہمیشہ رہیں گے اور ان سے ان کے گناه دور کر دے، اور اللہ کے نزدیک یہ بہت بڑی کامیابی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxix{اور تاکہ ان منافق مردوں اور منافق عورتوں اور مشرک مردوں اور مشرکہ عورتوں کو عذاب دے جو اللہ تعالیٰ کے بارے میں بدگمانیاں رکھنے والے ہیں، (دراصل) انہیں پر برائی کا پھیرا ہے، اللہ ان پر ناراض ہوا اور انہیں لعنت کی اور ان کے لئے دوزخ تیار کی اور وه (بہت) بری لوٹنے کی جگہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxc{اور اللہ ہی کے لئے آسمانوں اور زمین کے لشکر ہیں اور اللہ غالب اور حکمت واﻻ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxci{یقیناً ہم نے تجھے گواہی دینے واﻻ اور خوشخبری سنانے واﻻ اور ڈرانے واﻻ بنا کر بھیجا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcii{تاکہ (اے مسلمانو)، تم اللہ اور اس کے رسول پر ایمان ﻻؤ اور اس کی مدد کرو اور اس کا ادب کرو اور اللہ کی پاکی بیان کرو صبح وشام\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciii{جو لوگ تجھ سے بیعت کرتے ہیں وه یقیناً اللہ سے بیعت کرتے ہیں، ان کے ہاتھوں پر اللہ کا ہاتھ ہے، تو جو شخص عہد شکنی کرے وه اپنے نفس پر ہی عہد شکنی کرتا ہے اور جو شخص اس اقرار کو پورا کرے جو اس نے اللہ کے ساتھ کیا ہے تو اسے عنقریب اللہ بہت بڑا اجر دے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciv{دیہاتیوں میں سے جو لوگ پیچھے چھوڑ دیئے گئے تھے وه اب تجھ سے کہیں گے کہ ہم اپنے مال اور بال بچوں میں لگے ره گئے پس آپ ہمارے لئے مغفرت طلب کیجئے۔ یہ لوگ اپنی زبانوں سے وه کہتے ہیں جو ان کے دلوں میں نہیں ہے۔ آپ جواب دے دیجئے کہ تمہارے لئے اللہ کی طرف سے کسی چیز کا بھی اختیار کون رکھتا ہے اگر وه تمہیں نقصان پہنچانا چاہے تو یا تمہیں کوئی نفع دینا چاہے تو، بلکہ تم جو کچھ کر رہے ہو اس سے اللہ خوب باخبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcv{(نہیں) بلکہ تم نے تو یہ گمان کر رکھا تھا کہ پیغمبر اور مسلمانوں کا اپنے گھروں کی طرف لوٹ آنا قطعاً ناممکن ہے اور یہی خیال تمہارے دلوں میں رچ بس گیا تھا اور تم نے برا گمان کر رکھا تھا۔ دراصل تم لوگ ہو بھی ہلاک ہونے والے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvi{اور جو شخص اللہ پر اور اس کے رسول پر ایمان نہ ﻻئے تو ہم نے بھی ایسے کافروں کے لئے دہکتی آگ تیار کر رکھی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvii{اور زمین اور آسمانوں کی بادشاہت اللہ ہی کے لئے ہے جسے چاہے بخشے اور جسے چاہے عذاب کرے۔ اور اللہ بڑا بخشنے واﻻ مہربان ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcviii{جب تم غنیمتیں لینے جانے لگو گے تو جھٹ سے یہ پیچھے چھوڑے ہوئے لوگ کہنے لگیں گے کہ ہمیں بھی اپنے ساتھ چلنے کی اجازت دیجئے، وه چاہتے ہیں کہ اللہ تعالیٰ کے کلام کو بدل دیں آپ کہہ دیجئے! کہ اللہ تعالیٰ پہلے ہی فرما چکا ہے کہ تم ہرگز ہمارے ساتھ نہیں چلو گے، وه اس کا جواب دیں گے (نہیں نہیں) بلکہ تم ہم سے حسد کرتے ہو، (اصل بات یہ ہے) کہ وه لوگ بہت ہی کم سمجھتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcix{آپ پیچھے چھوڑے ہوئے بدویوں سے کہہ دو کہ عنقریب تم ایک سخت جنگجو قوم کی طرف بلائے جاؤ گے کہ تم ان سے لڑوگے یا وه مسلمان ہوجائیں گے پس اگر تم اطاعت کرو گے تو اللہ تمہیں بہت بہتر بدلہ دے گا اور اگر تم نے منھ پھیر لیا جیسا کہ اس سے پہلے تم منھ پھیر چکے ہو تو وه تمہیں دردناک عذاب دے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdc{اندھے پر کوئی حرج نہیں ہے اور نہ لنگڑے پر کوئی حرج ہے اور نہ بیمار پر کوئی حرج ہے، جو کوئی اللہ اور اس کے رسول کی فرمانبرداری کرے اسے اللہ ایسی جنتوں میں داخل کرے گا جس کے (درختوں) تلے نہریں جاری ہیں اور جو منھ پھیر لے اسے دردناک عذاب (کی سزا) دے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdci{یقیناً اللہ تعالیٰ مومنوں سے خوش ہوگیا جبکہ وه درخت تلے تجھ سے بیعت کر رہے تھے۔ ان کے دلوں میں جو تھا اسے اس نے معلوم کر لیا اور ان پر اطمینان نازل فرمایا اور انہیں قریب کی فتح عنایت فرمائی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcii{اور بہت سی غنیمتیں جنہیں وه حاصل کریں گے اور اللہ غالب حکمت واﻻ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdciii{اللہ تعالیٰ نے تم سے بہت ساری غنیمتوں کا وعده کیا ہے جنہیں تم حاصل کرو گے پس یہ تو تمہیں جلدی ہی عطا فرما دی اور لوگوں کے ہاتھ تم سے روک دیئے، تاکہ مومنوں کے لئے یہ ایک نشانی ہو جائے اور (تاکہ) وه تمہیں سیدھی راه چلائے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdciv{اور تمہیں اور (غنیمتیں) بھی دے جن پر اب تک تم نے قابو نہیں پایا۔ اللہ تعالیٰ نے انہیں اپنے قابو میں رکھا ہے اور اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcv{اور اگر تم سے کافر جنگ کرتے تو یقیناً پیٹھ دکھا کر بھاگتے پھر نہ تو کوئی کار ساز پاتے نہ مددگار\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvi{اللہ کے اس قاعدے کے مطابق جو پہلے سے چلا آیا ہے، تو کبھی بھی اللہ کے قاعدے کو بدلتا ہوا نہ پائے گا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvii{وہی ہے جس نے خاص مکہ میں کافروں کے ہاتھوں کو تم سے اور تمہارے ہاتھوں کو ان سے روک لیا اس کے بعد کہ اس نے تمہیں ان پر غلبہ دے دیا تھا، اور تم جو کچھ کر رہے ہو اللہ تعالیٰ اسے دیکھ رہا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcviii{یہی وه لوگ ہیں جنہوں نے کفر کیا اور تم کو مسجد حرام سے روکا اور قربانی کے لئے موقوف جانور کو اس کی قربان گاه میں پہنچنے سے (روکا)، اور اگر ایسے (بہت سے) مسلمان مرد اور (بہت سی) مسلمان عورتیں نہ ہوتیں جن کی تم کو خبر نہ تھی یعنی ان کے پس جانے کا احتمال نہ ہوتا جس پر ان کی وجہ سے تم کو بھی بے خبری میں ضرر پہنچتا، (تو تمہیں لڑنے کی اجازت دے دی جاتی لیکن ایسا نہیں کیا گیا) تاکہ اللہ تعالیٰ اپنی رحمت میں جس کو چاہے داخل کرے اور اگر یہ الگ الگ ہوتے تو ان میں جو کافر تھے ہم ان کو درد ناک سزا دیتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcix{جب کہ ان کافروں نے اپنے دلوں میں حمیت کو جگہ دی اور حمیت بھی جاہلیت کی، سو اللہ تعالیٰ نے اپنے رسول پر اور مومنین پر اپنی طرف سے تسکین نازل فرمائی اور اللہ تعالیٰ نے مسلمانوں کو تقوے کی بات پر جمائے رکھا اور وه اس کے اہل اور زیاده مستحق تھے اور اللہ تعالیٰ ہر چیز کو خوب جانتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcx{یقیناً اللہ تعالیٰ نے اپنے رسول کو خواب سچا دکھایا کہ انشاءاللہ تم یقیناً پورے امن وامان کے ساتھ مسجد حرام میں داخل ہوگے سرمنڈواتے ہوئے اور سر کے بال کترواتے ہوئے (چین کے ساتھ) نڈر ہو کر، وه ان امور کو جانتا ہے جنہیں تم نہیں جانتے، پس اس نے اس سے پہلے ایک نزدیک کی فتح تمہیں میسر کی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxi{وہی ہے جس نےاپنے رسول کو ہدایت اور دین حق کے ساتھ بھیجا تاکہ اسے ہر دین پر غالب کرے، اور اللہ تعالیٰ کافی ہے گواہی دینے واﻻ\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxii{محمد (صلی اللہ علیہ وسلم) اللہ کے رسول ہیں اور جو لوگ ان کے ساتھ کافروں پر سخت ہیں آپس میں رحمدل ہیں، تو انہیں دیکھے گا کہ رکوع اور سجدے کر رہے ہیں اللہ تعالیٰ کے فضل اور رضامندی کی جستجو میں ہیں، ان کا نشان ان کے چہروں پر سجدوں کے اﺛر سے ہے، ان کی یہی مثال تورات میں ہے اور ان کی مثال انجیل میں ہے، مثل اسی کھیتی کے جس نے اپنا انکھوا نکالا پھر اسے مضبوط کیا اور وه موٹا ہوگیا پھر اپنے تنے پر سیدھا کھڑا ہوگیا اور کسانوں کو خوش کرنے لگا تاکہ ان کی وجہ سے کافروں کو چڑائے، ان ایمان والوں اور نیک اعمال والوں سے اللہ نے بخشش کا اور بہت بڑے ﺛواب کا وعده کیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiii{\basmalahur اے ایمان والے لوگو! اللہ اور اس کے رسول سے آگے نہ بڑھو اور اللہ سے ڈرتے رہا کرو۔ یقیناً اللہ تعالیٰ سننے واﻻ، جاننے واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiv{اے ایمان والو! اپنی آوازیں نبی کی آواز سے اوپر نہ کرو اور نہ ان سے اونچی آواز سے بات کرو جیسے آپس میں ایک دوسرے سے کرتے ہو، کہیں (ایسا نہ ہو کہ) تمہارے اعمال اکارت جائیں اور تمہیں خبر بھی نہ ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxv{بیشک جو لوگ رسول اللہ (صلی اللہ علیہ وسلم) کے حضور میں اپنی آوازیں پست رکھتے ہیں، یہی وه لوگ ہیں جن کے دلوں کو اللہ نے پرہیزگاری کے لئے جانچ لیا ہے۔ ان کے لئے مغفرت ہے اور بڑا ﺛواب ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvi{جو لوگ آپ کو حجروں کے پیچھے سے پکارتے ہیں ان میں سے اکثر (بالکل) بے عقل ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvii{اگر یہ لوگ یہاں تک صبر کرتے کہ آپ خود سے نکل کر ان کے پاس آجاتے تو یہی ان کے لئے بہتر ہوتا، اور اللہ غفور ورحیم ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxviii{اے مسلمانو! اگر تمہیں کوئی فاسق خبر دے تو تم اس کی اچھی طرح تحقیق کر لیا کرو ایسا نہ ہو کہ نادانی میں کسی قوم کو ایذا پہنچا دو پھر اپنے کیے پر پشیمانی اٹھاؤ\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxix{اور جان رکھو کہ تم میں اللہ کے رسول موجود ہیں، اگر وه تمہارا کہا کرتے رہے بہت امور میں، تو تم مشکل میں پڑجاؤ لیکن اللہ تعالیٰ نے ایمان کو تمہارے لئے محبوب بنا دیا ہے اور اسے تمہارے دلوں میں زینت دے رکھی ہے اور کفر کو اور گناه کو اور نافرمانی کو تمہارے نگاہوں میں ناپسندیده بنا دیا ہے، یہی لوگ راه یافتہ ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxx{اللہ کے احسان وانعام سے اور اللہ دانا اور باحکمت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxi{اور اگر مسلمانوں کی دو جماعتیں آپس میں لڑ پڑیں تو ان میں میل ملاپ کرا دیا کرو۔ پھر اگر ان دونوں میں سے ایک جماعت دوسری جماعت پر زیادتی کرے تو تم (سب) اس گروه سے جو زیادتی کرتا ہے لڑو۔ یہاں تک کہ وه اللہ کے حکم کی طرف لوٹ آئے، اگر لوٹ آئے تو پھر انصاف کے ساتھ صلح کرا دو اور عدل کرو بیشک اللہ تعالیٰ انصاف کرنے والوں سے محبت کرتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxii{(یاد رکھو) سارے مسلمان بھائی بھائی ہیں پس اپنے دو بھائیوں میں ملاپ کرا دیا کرو، اور اللہ سے ڈرتے رہو تاکہ تم پر رحم کیا جائے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiii{اے ایمان والو! مرد دوسرے مردوں کا مذاق نہ اڑائیں ممکن ہے کہ یہ ان سے بہتر ہو اور نہ عورتیں عورتوں کا مذاق اڑائیں ممکن ہے یہ ان سے بہتر ہوں، اور آپس میں ایک دوسرے کو عیب نہ لگاؤ اور نہ کسی کو برے لقب دو۔ ایمان کے بعد فسق برا نام ہے، اور جو توبہ نہ کریں وہی ﻇالم لوگ ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiv{اے ایمان والو! بہت بدگمانیوں سے بچو یقین مانو کہ بعض بدگمانیاں گناه ہیں۔ اور بھید نہ ٹٹوﻻ کرو اور نہ تم میں سے کوئی کسی کی غیبت کرے۔ کیا تم میں سے کوئی بھی اپنے مرده بھائی کا گوشت کھانا پسند کرتا ہے؟ تم کو اس سے گھن آئے گی، اور اللہ سے ڈرتے رہو، بیشک اللہ توبہ قبول کرنے واﻻ مہربان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxv{اے لوگو! ہم نے تم سب کو ایک (ہی) مرد وعورت سے پیدا کیا ہے اور اس لئے کہ تم آپس میں ایک دوسرے کو پہچانو کنبے اور قبیلے بنا دیئے ہیں، اللہ کے نزدیک تم سب میں باعزت وه ہے جو سب سے زیاده ڈرنے واﻻ ہے۔ یقین مانو کہ اللہ دانا اور باخبر ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvi{دیہاتی لوگ کہتے ہیں کہ ہم ایمان ﻻئے۔ آپ کہہ دیجئے کہ درحقیقت تم ایمان نہیں ﻻئے لیکن تم یوں کہو کہ ہم اسلام ﻻئے (مخالفت چھوڑ کر مطیع ہوگئے) حاﻻنکہ ابھی تک تمہارے دلوں میں ایمان داخل ہی نہیں ہوا۔ تم اگر اللہ کی اور اس کے رسول کی فرمانبرداری کرنے لگو گے تو اللہ تمہارے اعمال میں سے کچھ بھی کم نہ کرے گا۔ بیشک اللہ بخشنے واﻻ مہربان ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvii{مومن تو وه ہیں جو اللہ اور اس کے رسول پر (پکا) ایمان ﻻئیں پھر شک وشبہ نہ کریں اور اپنے مالوں سے اور اپنی جانوں سے اللہ کی راه میں جہاد کرتے رہیں، (اپنے دعوائے ایمان میں) یہی سچے اور راست گو ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxviii{کہہ دیجئے! کہ کیا تم اللہ تعالیٰ کو اپنی دینداری سے آگاه کر رہے ہو، اللہ ہر اس چیز سے جو آسمانوں میں اور زمین میں ہے بخوبی آگاه ہے۔ اور اللہ ہر چیز کا جاننے واﻻ ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxix{اپنے مسلمان ہونے کا آپ پر احسان جتاتے ہیں۔ آپ کہہ دیجئے کہ اپنے مسلمان ہونے کا احسان مجھ پر نہ رکھو، بلکہ دراصل اللہ کا تم پر احسان ہے کہ اس نے تمہیں ایمان کی ہدایت کی اگر تم راست گو ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxx{یقین مانو کہ آسمانوں اور زمین کی پوشیده باتیں اللہ خوب جانتا ہے۔ اور جو کچھ تم کر رہے ہو اسے اللہ خوب دیکھ رہا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxi{\basmalahur ق! بہت بڑی شان والے اس قرآن کی قسم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxii{بلکہ انہیں تعجب معلوم ہوا کہ ان کے پاس انہی میں سے ایک آگاه کرنے واﻻ آیا تو کافروں نے کہا کہ یہ ایک عجیب چیز ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiii{کیا جب ہم مر کر مٹی ہو جائیں گے۔ پھر یہ واپسی دور (از عقل) ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiv{زمین جو کچھ ان سے گھٹاتی ہے وه ہمیں معلوم ہے اور ہمارے پاس سب یاد رکھنے والی کتاب ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxv{بلکہ انہوں نے سچی بات کو جھوٹ کہا ہے جبکہ وه ان کے پاس پہنچ چکی پس وه ایک الجھاؤ میں پڑ گئے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvi{کیا انہوں نے آسمان کو اپنے اوپر نہیں دیکھا؟ کہ ہم نے اسے کس طرح بنایا ہے اور زینت دی ہے اس میں کوئی شگاف نہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvii{اور زمین کو ہم نے بچھا دیا اور اس میں ہم نے پہاڑ ڈال دیئے ہیں اور اس میں ہم نے قسم قسم کی خوشنما چیزیں اگا دی ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxviii{تاکہ ہر رجوع کرنے والے بندے کے لئے بینائی اور دانائی کا ذریعہ ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxix{اور ہم نے آسمان سے بابرکت پانی برسایا اور اس سے باغات اور کٹنے والے کھیت کے غلے پیدا کیے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxl{اور کھجوروں کے بلند وباﻻ درخت جن کے خوشے تہ بہ تہ ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxli{بندوں کی روزی کے لئے اور ہم نے پانی سے مرده شہر کو زنده کر دیا۔ اسی طرح (قبروں سے) نکلنا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlii{ان سے پہلے نوح کی قوم نے اور رس والوں نے اور ﺛمود نے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliii{اور عاد نے فرعون نے اور برادران لوط نے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliv{اور ایکہ والوں نے تبع کی قوم نے بھی تکذیب کی تھی۔ سب نے پیغمبروں کو جھٹلایا پس میرا وعدہٴ عذاب ان پر صادق آگیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlv{کیا ہم پہلی بار کے پیدا کرنے سے تھک گئے؟ بلکہ یہ لوگ نئی پیدائش کی طرف سے شک میں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvi{ہم نے انسان کو پیدا کیا ہے اور اس کے دل میں جو خیاﻻت اٹھتے ہیں ان سے ہم واقف ہیں اور ہم اس کی رگ جان سے بھی زیاده اس سے قریب ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvii{جس وقت دو لینے والے جا لیتے ہیں ایک دائیں طرف اور ایک بائیں طرف بیٹھا ہوا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlviii{(انسان) منھ سے کوئی لفﻆ نکال نہیں پاتا مگر کہ اس کے پاس نگہبان تیار ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlix{اور موت کی بے ہوشی حق لے کر آ پہنچی، یہی ہے جس سے تو بدکتا پھرتا تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcl{اور صور پھونک دیا جائے گا۔ وعدہٴ عذاب کا دن یہی ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcli{اور ہر شخص اس طرح آئے گا کہ اس کے ساتھ ایک ﻻنے واﻻ ہوگا اور ایک گواہی دینے واﻻ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdclii{یقیناً تو اس سے غفلت میں تھا لیکن ہم نے تیرے سامنے سے پرده ہٹا دیا پس آج تیری نگاه بہت تیز ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliii{اس کا ہم نشین (فرشتہ) کہے گا یہ حاضر ہے جو کہ میرے پاس تھا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliv{ڈال دو جہنم میں ہر کافر سرکش کو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdclv{جو نیک کام سے روکنے واﻻ حد سے گزر جانے واﻻ اور شک کرنے واﻻ تھا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvi{جس نے اللہ کے ساتھ دوسرا معبود بنا لیا تھا پس اسے سخت عذاب میں ڈال دو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvii{اس کا ہمنشین (شیطان) کہے گا اے ہمارے رب! میں نے اسے گمراه نہیں کیا تھا بلکہ یہ خود ہی دور دراز کی گمراہی میں تھا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdclviii{حق تعالیٰ فرمائے گا بس میرے سامنے جھگڑنے کی بات مت کرو میں تو پہلے ہی تمہاری طرف وعید (وعدہٴ عذاب) بھیج چکا تھا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdclix{میرے ہاں بات بدلتی نہیں اور نہ میں اپنے بندوں پر ذرا بھی ﻇلم کرنے واﻻ ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdclx{جس دن ہم دوزخ سے پوچھیں گے کیا تو بھر چکی؟ وه جواب دے گی کیا کچھ اور زیاده بھی ہے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxi{اور جنت پرہیزگاروں کے لئے بالکل قریب کر دی جائے گی ذرا بھی دور نہ ہوگی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxii{یہ ہے جس کا تم سے وعده کیا جاتا تھا ہر اس شخص کے لئے جو رجوع کرنے واﻻ اور پابندی کرنے واﻻ ہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiii{جو رحمٰن کا غائبانہ خوف رکھتا ہو اور توجہ واﻻ دل ﻻیا ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiv{تم اس جنت میں سلامتی کے ساتھ داخل ہو جاؤ۔ یہ ہمیشہ رہنے کا دن ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxv{یہ وہاں جو چاہیں انھیں ملے گا (بلکہ) ہمارے پاس اور بھی زیاده ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvi{اور ان سے پہلے بھی ہم بہت سی امتوں کو ہلاک کر چکے ہیں جو ان سے طاقت میں بہت زیاده تھیں وه شہروں میں ڈھونڈھتے ہی ره گئے، کہ کوئی بھاگنے کا ٹھکانہ ہے؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvii{اس میں ہر صاحب دل کے لئے عبرت ہے اور اس کے لئے جو دل سے متوجہ ہو کر کان لگائے اور وه حاضر ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxviii{یقیناً ہم نے آسمانوں اور زمین اور جو کچھ اس کے درمیان ہے سب کو (صرف) چھ دن میں پیدا کر دیا اور ہمیں تکان نے چھوا تک نہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxix{پس یہ جو کچھ کہتے ہیں آپ اس پر صبر کریں اور اپنے رب کی تسبیح تعریف کے ساتھ بیان کریں سورج نکلنے سے پہلے بھی اور سورج غروب ہونے سے پہلے بھی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxx{اور رات کے وقت بھی تسبیح کریں اور نماز کے بعد بھی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxi{اور سن رکھیں کہ جس دن ایک پکارنے واﻻ قریب ہی کی جگہ سے پکارے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxii{جس روز اس تند وتیز چیﺦ کو یقین کے ساتھ سن لیں گے، یہ دن ہوگا نکلنے کا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiii{ہم ہی جلاتے ہیں اور ہم ہی مارتے ہیں اور ہماری ہی طرف لوٹ پھر کر آنا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiv{جس دن زمین پھٹ جائے گی اور یہ دوڑتے ہوئے (نکل پڑیں گے) یہ جمع کر لینا ہم پر بہت ہی آسان ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxv{یہ جو کچھ کہہ رہے ہیں ہم بخوبی جانتے ہیں اور آپ ان پر جبر کرنے والے نہیں، تو آپ قرآن کے ذریعے انہیں سمجھاتے رہیں جو میرے وعید (ڈرانے کے وعدوں) سے ڈرتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvi{\basmalahur قسم ہے بکھیرنے والیوں کی اڑا کر\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvii{پھر اٹھانے والیاں بوجھ کو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxviii{پھر چلنے والیاں نرمی سے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxix{پھر کام کو تقسیم کرنے والیاں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxx{یقین مانو کہ تم سے جو وعدے کیے جاتے ہیں (سب) سچے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxi{اور بیشک انصاف ہونے واﻻ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxii{قسم ہے راہوں والے آسمان کی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiii{یقیناً تم مختلف بات میں پڑے ہوئے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiv{اس سے وہی باز رکھا جاتا ہے جو پھیر دیا گیا ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxv{بے سند باتیں کرنے والے غارت کر دیئے گئے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvi{جو غفلت میں ہیں اور بھولے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvii{پوچھتے ہیں کہ یوم جزا کب ہوگا؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxviii{ہاں یہ وه دن ہے کہ یہ آگ پر تپائے جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxix{اپنی فتنہ پردازی کا مزه چکھو، یہی ہے جس کی تم جلدی مچا رہے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxc{بیشک تقویٰ والے لوگ بہشتوں اور چشموں میں ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxci{ان کے رب نے جو کچھ انہیں عطا فرمایا ہے اسے لے رہے ہوں گے وه تو اس سے پہلے ہی نیکوکار تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcii{وه رات کو بہت کم سویا کرتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciii{اور وقت سحر استغفار کیا کرتے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciv{اور ان کے مال میں مانگنے والوں کا اور سوال سے بچنے والوں کا حق تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcv{اور یقین والوں کے لئے تو زمین میں بہت سی نشانیاں ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvi{اور خود تمہاری ذات میں بھی، تو کیا تم دیکھتے نہیں ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvii{اور تمہاری روزی اور جو تم سے وعده کیا جاتا ہے سب آسمان میں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcviii{آسمان وزمین کے پروردگار کی قسم! کہ یہ بالکل برحق ہے ایسا ہی جیسے کہ تم باتیں کرتے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcix{کیا تجھے ابراہیم (علیہ السلام) کے معزز مہمانوں کی خبر بھی پہنچی ہے؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcc{وه جب ان کے ہاں آئے تو سلام کیا، ابراہیم نے جواب سلام دیا (اور کہا یہ تو) اجنبی لوگ ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcci{پھر (چﭗ چاپ جلدی جلدی) اپنے گھر والوں کی طرف گئے اور ایک فربہ بچھڑے (کا گوشت) ﻻئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccii{اور اسے ان کے پاس رکھا اور کہا آپ کھاتے کیوں نہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciii{پھر تو دل ہی دل میں ان سے خوفزده ہوگئے انہوں نے کہا آپ خوف نہ کیجئے۔ اور انہوں نے اس (حضرت ابراہیم) کو ایک علم والے لڑکے کی بشارت دی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciv{پس ان کی بیوی آگے بڑھی اور حیرت میں آکر اپنے منھ پر ہاتھ مار کر کہا کہ میں تو بوڑھیا ہوں اور ساتھ ہی بانجھ\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccv{انہوں نے کہا ہاں تیرے پروردگار نے اسی طرح فرمایا ہے، بیشک وه حکیم وعلیم ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvi{(حضرت ابرہیم علیہ السلام) نے کہا کہ اللہ کے بھیجے ہوئے (فرشتو!) تمہارا کیا مقصد ہے؟\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvii{انہوں نے جواب دیا کہ ہم گناه گار قوم کی طرف بھیجے گئے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccviii{تاکہ ہم ان پر مٹی کے کنکر برسائیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccix{جو تیرے رب کی طرف سے نشان زده ہیں، ان حد سے گزر جانے والوں کے لیے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccx{پس جتنے ایمان والے وہاں تھے ہم نے انہیں نکال لیا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxi{اور ہم نے وہاں مسلمانوں کا صرف ایک ہی گھر پایا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxii{اور وہاں ہم نے ان کے لیے جو درد ناک عذاب کا ڈر رکھتے ہیں ایک (کامل) علامت چھوڑی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiii{موسیٰ (علیہ السلام کے قصے) میں (بھی ہماری طرف سے تنبیہ ہے) کہ ہم نے اسے فرعون کی طرف کھلی دلیل دے کر بھیجا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiv{پس اس نےاپنے بل بوتے پر منھ موڑا اور کہنے لگا یہ جادوگر ہے یا دیوانہ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxv{بالﺂخر ہم نے اسے اور اس کے لشکروں کو اپنے عذاب میں پکڑ کر دریا میں ڈال دیا وه تھا ہی ملامت کے قابل\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvi{اسی طرح عادیوں میں بھی (ہماری طرف سے تنبیہ ہے) جب کہ ہم نے ان پر خیر وبرکت سے خالی آندھی بھیجی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvii{وه جس جس چیز پر گرتی تھی اسے بوسیده ہدی کی طرح (چورا چورا) کردیتی تھی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxviii{اور ﺛمود (کے قصے) میں بھی (عبرت) ہے جب ان سے کہا گیا کہ تم کچھ دنوں تک فائده اٹھا لو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxix{لیکن انہوں نے اپنے رب کے حکم سے سرتابی کی جس پر انہیں ان کے دیکھتے دیکھتے (تیز وتند) کڑاکے نے ہلاک کر دیا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxx{پس نہ تو وه کھڑے ہو سکے اور نہ بدلہ لے سکے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxi{اور نوح (علیہ السلام) کی قوم کا بھی اس سے پہلے (یہی حال ہو چکا تھا) وه بھی بڑے نافرمان لوگ تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxii{آسمان کو ہم نے (اپنے) ہاتھوں سے بنایا ہے اور یقیناً ہم کشادگی کرنے والے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiii{اور زمین کو ہم نے فرش بنا دیاہے پس ہم بہت ہی اچھے بچھانے والے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiv{اور ہر چیز کو ہم نے جوڑا جوڑا پیداکیا ہے تاکہ تم نصیحت حاصل کرو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxv{پس تم اللہ کی طرف دوڑ بھاگ (یعنی رجوع) کرو، یقیناً میں تمہیں اس کی طرف سے صاف صاف تنبیہ کرنے واﻻ ہوں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvi{اور اللہ کے ساتھ کسی اور کو معبود نہ ٹھراؤ۔ بیشک میں تمہیں اس کی طرف سے کھلا ڈرانے واﻻ ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvii{اسی طرح جو لوگ ان سے پہلے گزرے ہیں ان کے پاس جو بھی رسول آیا انہوں نے کہہ دیا کہ یا تو یہ جادوگر ہے یا دیوانہ ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxviii{کیایہ اس بات کی ایک دوسرے کو وصیت کرتے گئے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxix{(نہیں) بلکہ یہ سب کے سب سرکش ہیں۔ تو آپ ان سے منھ پھیر لیں آپ پر کوئی ملامت نہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxx{اور نصیحت کرتے رہیں یقیناً یہ نصیحت ایمان والوں کو نفع دے گی\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxi{میں نے جنات اورانسانوں کو محض اسی لیے پیدا کیا ہے کہ وه صرف میری عبادت کریں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxii{نہ میں ان سے روزی چاہتا ہوں نہ میری یہ چاہت ہے کہ یہ مجھے کھلائیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiii{اللہ تعالیٰ تو خود ہی سب کا روزی رساں توانائی واﻻ اور زور آور ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiv{پس جن لوگوں نے ﻇلم کیا ہے انہیں بھی ان کے ساتھیوں کے حصہ کے مثل حصہ ملے گا، لہٰذا وه مجھ سے جلدی طلب نہ کریں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxv{پس خرابی ہے منکروں کو ان کے اس دن کی جس کا وعده دیئے جاتے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvi{\basmalahur قسم ہے طور کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvii{اور لکھی ہوئی کتاب کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxviii{جو جھلی کے کھلے ہوئے ورق میں ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxix{اورآباد گھر کی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxl{اور اونچی چھت کی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxli{اور بھڑکائے ہوئے سمندر کی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlii{بیشک آپ کے رب کا عذاب ہو کر رہنے واﻻ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliii{اسے کوئی روکنے واﻻ نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliv{جس دن آسمان تھرتھرانے لگے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlv{اور پہاڑ چلنے پھرنے لگیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvi{اس دن جھٹلانے والوں کو (پوری) خرابی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvii{جو اپنی بیہوده گوئی میں اچھل کود کر رہے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlviii{جس دن وه دھکے دے دے کر آتش جہنم کی طرف ﻻئیں جائیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlix{یہی وه آتش دوزخ ہے جسے تم جھوٹ بتلاتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccl{(اب بتاؤ) کیا یہ جادو ہے؟ یا تم دیکھتے ہی نہیں ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccli{جاؤ دوزخ میں اب تمہارا صبر کرنا اور نہ کرنا تمہارے لیے یکساں ہے تمہیں فقط تمہارے کیے کا بدلہ دیا جائے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclii{یقیناً پرہیزگار لوگ جنتوں میں اور نعمتوں میں ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliii{جو انہیں ان کے رب نے دے رکھی ہیں اس پر خوش خوش ہیں، اوران کے پروردگار نے انہیں جہنم کے عذاب سے بھی بچا لیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliv{تم مزے سے کھاتے پیتے رہو ان اعمال کے بدلے جو تم کرتے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclv{برابر بچھے ہوئے شاندار تختے پر تکیے لگائے ہوئے۔ اور ہم نے ان کے نکاح بڑی بڑی آنکھوں والی (حوروں) سے کر دیئے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvi{اور جو لوگ ایمان ﻻئے اور ان کی اوﻻد نے بھی ایمان میں ان کی پیروی کی ہم ان کی اوﻻد کو ان تک پہنچا دیں گے اور ان کے عمل سے ہم کچھ کم نہ کریں گے، ہر شخص اپنے اپنے اعمال کا گروی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvii{ہم ان کے لیے میوے اورمرغوب گوشت کی ریل پیل کردیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclviii{(خوش طبعی کے ساتھ) ایک دوسرے سے جام (شراب) کی چھینا جھپٹی کریں گے جس شراب کے سرور میں تو بیہوده گوئی ہوگی نہ گناه\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclix{اور ان کے اردگرد ان کے نو عمر غلام چل پھر رہے ہوں گے، گویا کہ وه موتی تھے جو ڈھکے رکھے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclx{اور آپس میں ایک دوسرے کی طرف متوجہ ہو کر سوال کریں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxi{کہیں گے کہ اس سے پہلے ہم اپنے گھر والوں کے درمیان بہت ڈرا کرتے تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxii{پس اللہ تعالیٰ نے ہم پر بڑا احسان کیا اور ہمیں تیز وتند گرم ہواؤں کے عذاب سے بچا لیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiii{ہم اس سے پہلے ہی اس کی عبادت کیا کرتے تھے، بیشک وه محسن اور مہربان ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiv{تو آپ سمجھاتے رہیں کیونکہ آپ اپنے رب کے فضل سے نہ تو کاہن ہیں نہ دیوانہ\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxv{کیا کافر یوں کہتے ہیں کہ یہ شاعر ہے ہم اس پر زمانے کے حوادث (یعنی موت) کا انتظار کر رہے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvi{کہہ دیجئے! تم منتظر رہو میں بھی تمہارے ساتھ انتظار کرنے والوں میں ہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvii{کیا ان کی عقلیں انہیں یہی سکھاتی ہیں؟ یا یہ لوگ ہی سرکش ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxviii{کیا یہ کہتے ہیں کہ اس نبی نے (قرآن) خود گھڑ لیا ہے، واقعہ یہ ہے کہ وه ایمان نہیں ﻻتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxix{اچھا اگر یہ سچے ہیں تو بھلا اس جیسی ایک (ہی) بات یہ (بھی) تو لے آئیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxx{کیا یہ بغیر کسی (پیدا کرنے والے) کے خود بخود پیدا ہوگئے ہیں؟ یا یہ خود پیدا کرنے والے ہیں؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxi{کیا انہوں نے ہی آسمانوں اور زمین کو پیدا کیا ہے؟ بلکہ یہ یقین نہ کرنے والے لوگ ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxii{یا کیا ان کے پاس تیرے رب کے خزانے ہیں؟ یا (ان خزانوں کے) یہ داروغہ ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiii{یا کیا ان کے پاس کوئی سیڑھی ہے جس پر چڑھ کر سنتے ہیں؟ (اگر ایسا ہے) تو ان کا سننے واﻻ کوئی روشن دلیل پیش کرے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiv{کیا اللہ کی تو سب لڑکیاں ہیں اور تمہارے ہاں لڑکے ہیں؟\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxv{کیا تو ان سے کوئی اجرت طلب کرتا ہے کہ یہ اس کے تاوان سے بوجھل ہو رہے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvi{کیا ان کے پاس علم غیب ہے جسے یہ لکھ لیتے ہیں؟\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvii{کیا یہ لوگ کوئی فریب کرنا چاہتے ہیں؟ تو یقین کرلیں کہ فریب خورده کافر ہی ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxviii{کیا اللہ کے سوا ان کا کوئی معبود ہے؟ (ہرگز نہیں) اللہ تعالیٰ ان کے شرک سے پاک ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxix{اگر یہ لوگ آسمان کے کسی ٹکڑے کو گرتا ہوا دیکھ لیں تب بھی کہہ دیں کہ یہ تہ بہ تہ بادل ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxx{تو انہیں چھوڑ دے یہاں تک کہ انہیں اس دن سے سابقہ پڑے جس میں یہ بے ہوش کر دیئے جائیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxi{جس دن انہیں ان کا مکر کچھ کام نہ دے گا اور نہ وه مدد کیے جائیں گے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxii{بیشک ﻇالموں کے لیے اس کے علاوه اور عذاب بھی ہیں۔ لیکن ان لوگوں میں سے اکثر بےعلم ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiii{تو اپنے رب کے حکم کے انتظار میں صبر سے کام لے، بیشک تو ہماری آنکھوں کے سامنے ہے۔ صبح کو جب تو اٹھے اپنے رب کی پاکی اور حمد بیان کر\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiv{اور رات کو بھی اس کی تسبیح پڑھ اور ستاروں کے ڈوبتے وقت بھی\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxv{\basmalahur قسم ہے ستارے کی جب وه گرے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvi{کہ تمہارے ساتھی نے نہ راه گم کی ہے نہ وه ٹیڑھی راه پر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvii{اور نہ وه اپنی خواہش سے کوئی بات کہتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxviii{وه تو صرف وحی ہے جو اتاری جاتی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxix{اسے پوری طاقت والے فرشتے نے سکھایا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxc{جو زور آور ہے پھر وه سیدھا کھڑا ہو گیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxci{اور وه بلند آسمان کے کناروں پر تھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcii{پھر نزدیک ہوا اور اتر آیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciii{پس وه دو کمانوں کے بقدر فاصلہ ره گیا بلکہ اس سے بھی کم\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciv{پس اس نے اللہ کے بندے کو وحی پہنچائی جو بھی پہنچائی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcv{دل نے جھوٹ نہیں کہا جسے (پیغمبر نے) دیکھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvi{کیا تم جھگڑا کرتے ہو اس پر جو (پیغمبر) دیکھتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvii{اسے تو ایک مرتبہ اور بھی دیکھا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcviii{سدرةالمنتہیٰ کے پاس\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcix{اسی کے پاس جنہ الماویٰ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccc{جب کہ سدره کو چھپائے لیتی تھی وه چیز جو اس پر چھا رہی تھی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccci{نہ تو نگاه بہکی نہ حد سے بڑھی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccii{یقیناً اس نے اپنے رب کی بڑی بڑی نشانیوں میں سے بعض نشانیاں دیکھ لیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciii{کیا تم نے ﻻت اور عزیٰ کو دیکھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciv{اور منات تیسرے پچھلے کو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccv{کیا تمہارے لیے لڑکے اور اللہ کے لیے لڑکیاں ہیں؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvi{یہ تو اب بڑی بےانصافی کی تقسیم ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvii{دراصل یہ صرف نام ہیں جو تم نے اور تمہارے باپ دادوں نے ان کے رکھ لیے ہیں اللہ نے ان کی کوئی دلیل نہیں اتاری۔ یہ لوگ تو صرف اٹکل کے اور اپنی نفسانی خواہشوں کے پیچھے پڑے ہوئے ہیں۔ اور یقیناً ان کے رب کی طرف سے ان کے پاس ہدایت آ چکی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccviii{کیا ہر شخص جو آرزو کرے اسے میسر ہے؟\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccix{اللہ ہی کے ہاتھ ہے یہ جہان اور وه جہان\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccx{اور بہت سے فرشتے آسمانوں میں ہیں جن کی سفارش کچھ بھی نفع نہیں دے سکتی مگر یہ اور بات ہے کہ اللہ تعالیٰ اپنی خوشی اور اپنی چاہت سے جس کے لیے چاہے اجازت دے دے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxi{بیشک جو لوگ آخرت پر ایمان نہیں رکھتے وه فرشتوں کا زنانہ نام مقرر کرتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxii{حاﻻنکہ انہیں اس کا کوئی علم نہیں وه صرف اپنے گمان کے پیچھے پڑے ہوئے ہیں اور بیشک وہم (و گمان) حق کے مقابلے میں کچھ کام نہیں دیتا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiii{تو آپ اس سے منھ موڑ لیں جو ہماری یاد سے منھ موڑے اور جن کا اراده بجز زندگانیٴ دنیا کے اور کچھ نہ ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiv{یہی ان کے علم کی انتہا ہے۔ آپ کا رب اس سے خوب واقف ہے جو اس کی راه سے بھٹک گیا ہے اور وہی خوب واقف ہےاس سے بھی جو راه یافتہ ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxv{اور اللہ ہی کا ہے جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے تاکہ اللہ تعالیٰ برے عمل کرنے والوں کو ان کے اعمال کا بدلہ دے اور نیک کام کرنے والوں کو اچھا بدلہ عنایت فرمائے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvi{ان لوگوں کو جو بڑے گناہوں سے بچتے ہیں اور بے حیائی سے بھی۔ سوائے کسی چھوٹے سے گناه کے۔ بیشک تیرا رب بہت کشاده مغفرت واﻻ ہے، وه تمہیں بخوبی جانتا ہے جبکہ اس نے تمہیں زمین سے پیدا کیا اور جبکہ تم اپنی ماؤں کے پیٹ میں بچے تھے۔ پس تم اپنی پاکیزگی آپ بیان نہ کرو، وہی پرہیزگاروں کو خوب جانتا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvii{کیا آپ نے اسے دیکھا جس نے منھ موڑ لیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxviii{اور بہت کم دیا اور ہاتھ روک لیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxix{کیا اسے علم غیب ہے کہ وه (سب کچھ) دیکھ رہا ہے؟\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxx{کیا اسے اس چیز کی خبر نہیں دی گئی جو موسیٰ (علیہ السلام) کے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxi{اور وفادار ابراہیم (علیہ السلام) کے صحیفوں میں تھا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxii{کہ کوئی شخص کسی دوسرے کا بوجھ نہ اٹھائے گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiii{اور یہ کہ ہر انسان کے لیے صرف وہی ہے جس کی کوشش خود اس نے کی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiv{اور یہ کہ بیشک اس کی کوشش عنقریب دیکھی جائے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxv{پھر اسے پورا پورا بدلہ دیا جائے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvi{اور یہ کہ آپ کے رب ہی کی طرف پہنچنا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvii{اور یہ کہ وہی ہنساتا ہے اور وہی رﻻتا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxviii{اور یہ کہ وہی مارتا ہے اور جلاتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxix{اور یہ کہ اسی نے جوڑا یعنی نر ماده پیدا کیا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxx{نطفہ سے جبکہ وه ٹپکایا جاتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxi{اور یہ کہ اسی کے ذمہ دوباره پیدا کرنا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxii{اور یہ کہ وہی مالدار بناتا ہے اور سرمایہ دیتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiii{اور یہ کہ وہی شعریٰ (ستارے) کا رب ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiv{اور یہ کہ اس نے عاد اول کو ہلاک کیا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxv{اور ﺛمود کو بھی (جن میں سے) ایک کو بھی باقی نہ رکھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvi{اور اس سے پہلے قوم نوح کو، یقیناً وه بڑے ﻇالم اور سرکش تھے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvii{اور مؤتفکہ (شہر یا الٹی ہوئی بستیوں کو) اسی نے الٹ دیا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxviii{پھر اس پر چھا دیا جو چھایا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxix{پس اے انسان تو اپنے رب کی کس کس نعمت کے بارے میں جھگڑے گا؟\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxl{یہ (نبی) ڈرانے والے ہیں پہلے ڈرانے والوں میں سے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxli{آنے والی گھڑی قریب آ گئی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlii{اللہ کے سوا اس کا (وقت معین پر کھول) دکھانے واﻻ اور کوئی نہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliii{پس کیا تم اس بات سے تعجب کرتے ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliv{اور ہنس رہے ہو؟ روتے نہیں؟\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlv{(بلکہ) تم کھیل رہے ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvi{اب اللہ کے سامنے سجدے کرو اور (اسی) کی عبادت کرو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvii{\basmalahur قیامت قریب آ گئی اور چاند پھٹ گیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlviii{یہ اگر کوئی معجزه دیکھتے ہیں تو منھ پھیر لیتے ہیں اور کہہ دیتے ہیں کہ یہ پہلے سے چلا آتا ہوا جادو ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlix{انہوں نے جھٹلایا اور اپنی خواہشوں کی پیروی کی اور ہر کام ٹھہرے ہوئے وقت پر مقرر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccl{یقیناً ان کے پاس وه خبریں آچکی ہیں جن میں ڈانٹ ڈپٹ (کی نصیحت) ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccli{اور کامل عقل کی بات ہے لیکن ان ڈراؤنی باتوں نے بھی کچھ فائده نہ دیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclii{پس (اے نبی) تم ان سے اعراض کرو جس دن ایک پکارنے واﻻ ناگوار چیز کی طرف پکارے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliii{یہ جھکی آنکھوں قبروں سے اس طرح نکل کھڑے ہوں گے کہ گویا وه پھیلا ہوا ٹڈی دل ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliv{پکارنے والے کی طرف دوڑتے ہوں گے اور کافر کہیں گے یہ دن تو بہت سخت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclv{ان سے پہلے قوم نوح نے بھی ہمارے بندے کو جھٹلایا تھا اور یہ دیوانہ بتلا کر جھڑک دیا گیا تھا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvi{پس اس نے اپنے رب سے دعا کی کہ میں بے بس ہوں تو میری مدد کر\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvii{پس ہم نے آسمان کے دروازوں کو زور کے مینہ سے کھول دیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclviii{اور زمین سے چشموں کو جاری کر دیا پس اس کام کے لیے جو مقدر کیا گیا تھا (دونوں) پانی جمع ہو گئے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclix{اور ہم نے اسے تختوں اور کیلوں والی (کشتی) پر سوار کر لیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclx{جو ہماری آنکھوں کے سامنے چل رہی تھی۔ بدلہ اس کی طرف سے جس کا کفر کیا گیا تھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxi{اور بیشک ہم نے اس واقعہ کو نشانی بنا کر باقی رکھا پس کوئی ہے نصیحت حاصل کرنے واﻻ\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxii{بتاؤ میرا عذاب اور میری ڈرانے والی باتیں کیسی رہیں؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiii{اور بیشک ہم نے قرآن کو سمجھنے کے لیے آسان کر دیا ہے۔ پس کیا کوئی نصیحت حاصل کرنے واﻻ ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiv{قوم عاد نے بھی جھٹلایا پس کیسا ہوا میرا عذاب اور میری ڈرانے والی باتیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxv{ہم نے ان پر تیز وتند مسلسل چلنے والی ہوا، ایک پیہم منحوس دن میں بھیج دی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvi{جو لوگوں کو اٹھا اٹھا کر دے پٹختی تھی، گویا کہ وه جڑ سے کٹے ہوئے کھجور کے تنے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvii{پس کیسی رہی میری سزا اور میرا ڈرانا؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxviii{یقیناً ہم نے قرآن کو نصیحت کے لیے آسان کر دیا ہے، پس کیا ہے کوئی نصیحت حاصل کرنے واﻻ؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxix{قوم ﺛمود نے ڈرانے والوں کو جھٹلایا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxx{اور کہنے لگے کیا ہمیں میں سے ایک شخص کی ہم فرمانبرداری کرنے لگیں؟ تب تو ہم یقیناً غلطی اور دیوانگی میں پڑے ہوئے ہوں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxi{کیا ہمارے سب کے درمیان صرف اسی پر وحی اتاری گئی؟ نہیں بلکہ وه جھوٹا اور شیخی خور ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxii{اب سب جان لیں گے کل کو کہ کون جھوٹا اور شیخی خور تھا؟\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiii{بیشک ہم ان کی آزمائش کے لیے اونٹنی بھیجیں گے پس (اے صالح) توان کا منتظر ره اور صبر کر\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiv{ہاں انہیں خبر کر دے کہ پانی ان میں تقسیم شده ہے، ہرایک اپنی باری پر حاضر ہوگا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxv{انہوں نے اپنے ساتھی کو آواز دی جس نے (اونٹنی پر) وار کیا اور (اس کی) کوچیں کاٹ دیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvi{پس کیونکر ہوا میرا عذاب اور میرا ڈرانا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvii{ہم نے ان پر ایک چیﺦ بھیجی پس ایسے ہو گئے جیسے باڑ بنانے والے کی روندی ہوئی گھاس\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxviii{اور ہم نے نصیحت کے لیے قرآن کو آسان کر دیا ہے پس کیا ہے کوئی جو نصیحت قبول کرے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxix{قوم لوط نے بھی ڈرانے والوں کی تکذیب کی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxx{بیشک ہم نے ان پر پتھر برسانے والی ہوا بھیجی سوائے لوط (علیہ السلام) کے گھر والوں کے، انہیں ہم نے سحر کے وقت نجات دے دی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxi{اپنے احسان سے ہر ہر شکر گزار کو ہم اسی طرح بدلہ دیتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxii{یقیناً (لوط علیہ السلام) نے انہیں ہماری پکڑ سے ڈرایا تھا لیکن انہوں نے ڈرانے والوں کے بارے میں (شک وشبہ اور) جھگڑا کیا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiii{اور ان (لوط علیہ السلام) کو ان کے مہمانوں کے بارے میں پھسلایا پس ہم نے ان کی آنکھیں اندھی کردیں، (اور کہہ دیا) میرا عذاب اور میرا ڈرانا چکھو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiv{اور یقینی بات ہے کہ انہیں صبح سویرے ہی ایک جگہ پکڑنے والے مقرره عذاب نے غارت کر دیا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxv{پس میرے عذاب اور میرے ڈراوے کا مزه چکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvi{اور یقیناً ہم نے قرآن کو پند ووعﻆ کے لیے آسان کر دیا ہے۔ پس کیا کوئی ہے نصحیت پکڑنے واﻻ\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvii{اور فرعونیوں کے پاس بھی ڈرانے والے آئے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxviii{انہوں نے ہماری تمام نشانیاں جھٹلائیں پس ہم نے انہیں بڑے غالب قوی پکڑنے والے کی طرح پکڑ لیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxix{(اے قریشیو!) کیا تمہارے کافر ان کافروں سے کچھ بہتر ہیں؟ یا تمہارے لیے اگلی کتابوں میں چھٹکارا لکھا ہوا ہے؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxc{یا یہ کہتے ہیں کہ ہم غلبہ پانے والی جماعت ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxci{عنقریب یہ جماعت شکست دی جائےگی اور پیٹھ دے کر بھاگے گی\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcii{بلکہ قیامت کی گھڑی ان کے وعدے کے وقت ہے اور قیامت بڑی سخت اور کڑوی چیز ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciii{بیشک گناه گار گمراہی میں اور عذاب میں ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciv{جس دن وه اپنے منھ کے بل آگ میں گھسیٹے جائیں گے (اوران سے کہا جائے گا) دوزخ کی آگ لگنے کے مزے چکھو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcv{بیشک ہم نے ہر چیز کو ایک (مقرره) اندازے پر پیدا کیا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvi{اور ہمارا حکم صرف ایک دفعہ (کا ایک کلمہ) ہی ہوتا ہے جیسے آنکھ کا جھپکنا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvii{اور ہم نے تم جیسے بہتیروں کو ہلاک کر دیا ہے، پس کوئی ہے نصیحت لینے واﻻ\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcviii{جوکچھ انہوں نے (اعمال) کیے ہیں سب نامہٴ اعمال میں لکھے ہوئے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcix{(اسی طرح) ہر چھوٹی بڑی بات بھی لکھی ہوئی ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcm{یقیناً ہمارا ڈر رکھنے والے جنتوں اور نہروں میں ہوں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmi{راستی اور عزت کی بیٹھک میں قدرت والے بادشاه کے پاس\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmii{\basmalahur رحمٰن نے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiii{قرآن سکھایا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiv{اسی نے انسان کو پیدا کیا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmv{اور اسے بولنا سکھایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvi{آفتاب اور ماہتاب (مقرره) حساب سے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvii{اور ستارے اور درخت دونوں سجده کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmviii{اسی نے آسمان کو بلند کیا اور اسی نے ترازو رکھی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmix{تاکہ تم تولنے میں تجاوز نہ کرو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmx{انصاف کے ساتھ وزن کو ٹھیک رکھو اور تول میں کم نہ دو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxi{اور اسی نے مخلوق کے لیے زمین بچھا دی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxii{جس میں میوے ہیں اور خوشے والے کھجور کے درخت ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiii{اور بھس واﻻ اناج ہے۔ اور خوشبودار پھول ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiv{پس (اے انسانو اور جنو!) تم اپنے پروردگار کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxv{اس نےانسان کو بجنے والی مٹی سے پیدا کیا جو ٹھیکری کی طرح تھی\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvi{اور جنات کو آگ کے شعلے سے پیدا کیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvii{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxviii{وه رب ہے دونوں مشرقوں اور دونوں مغربوں کا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxix{تو (اے جنو اورانسانو!) تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxx{اس نے دو دریا جاری کر دیے جو ایک دوسرے سے مل جاتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxi{ان دونوں میں ایک آڑ ہے کہ اس سے بڑھ نہیں سکتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxii{پس اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiii{ان دونوں میں سے موتی اور مونگے برآمد ہوتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxv{اور اللہ ہی کی (ملکیت میں) ہیں وه جہاز جو سمندروں میں پہاڑ کی طرح بلند (چل پھر رہے) ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvi{پس (اے انسانو اور جنو!) تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvii{زمین پر جو ہیں سب فنا ہونے والے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxviii{صرف تیرے رب کی ذات جو عظمت اور عزت والی ہے باقی ره جائے گی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxix{پھرتم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxx{سب آسمان وزمین والے اسی سے مانگتے ہیں۔ ہر روز وه ایک شان میں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxi{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxii{(جنوں اور انسانوں کے گروہو!) عنقریب ہم تمہاری طرف پوری طرح متوجہ ہو جائیں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤگے؟\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiv{اے گروه جنات و انسان! اگر تم میں آسمانوں اور زمین کے کناروں سے باہر نکل جانے کی طاقت ہے تو نکل بھاگو! بغیر غلبہ اور طاقت کے تم نہیں نکل سکتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvi{تم پر آگ کے شعلے اور دھواں چھوڑا جائے گا پھر تم مقابلہ نہ کر سکو گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvii{پھر اپنے رب کی نعمتوں میں سے کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxviii{پس جب کہ آسمان پھٹ کر سرخ ہو جائے جیسے کہ سرخ چمڑه\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxix{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxl{اس دن کسی انسان اورکسی جن سے اس کے گناہوں کی پرسش نہ کی جائے گی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxli{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlii{گناه گار صرف حلیہ ہی سے پہچان لیے جائیں گے اور ان کی پیشانیوں کے بال اور قدم پکڑ لیے جائیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliii{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliv{یہ ہے وه جہنم جسے مجرم جھوٹا جانتے تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlv{اس کے اور کھولتے ہوئے گرم پانی کے درمیان چکر کھائیں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvi{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvii{اور اس شخص کے لیے جو اپنے رب کے سامنے کھڑا ہونے سے ڈرا دو جنتیں ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlviii{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlix{(دونوں جنتیں) بہت سی ٹہنیوں اور شاخوں والی ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcml{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcmli{ان دونوں (جنتوں) میں دو بہتے ہوئے چشمے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlii{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliii{ان دونوں جنتوں میں ہر قسم کے میوؤں کی دو قسمیں ہوگی\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliv{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlv{جنتی ایسے فرشوں پر تکیہ لگائے ہوئے ہوں گے جن کے استر دبیز ریشم کے ہوں گے، اور ان دونوں جنتوں کے میوے بالکل قریب ہوں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvi{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvii{وہاں (شرمیلی) نیچی نگاه والی حوریں ہیں جنہیں ان سے پہلے کسی جن وانس نے ہاتھ نہیں لگایا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlviii{پس اپنے پالنے والے کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlix{وه حوریں مثل یاقوت اور مونگے کے ہوں گی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlx{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxi{احسان کا بدلہ احسان کے سوا کیا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxii{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiii{اور ان کے سوا دو جنتیں اور ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiv{پس تم اپنے پرورش کرنے والے کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxv{جو دونوں گہری سبز سیاہی مائل ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvi{بتاؤ اب اپنے پروردگار کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvii{ان میں دو (جوش سے) ابلنے والے چشمے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxviii{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxix{ان دونوں میں میوے اور کھجور اور انار ہوں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxx{کیا اب بھی رب کی کسی نعمت کی تکذیب تم کرو گے؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxi{ان میں نیک سیرت خوبصورت عورتیں ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxii{پس تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiii{(گوری رنگت کی) حوریں جنتی خیموں میں رہنے والیاں ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiv{پس (اے انسانو اور جنو!) تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxv{ان کو ہاتھ نہیں لگایا کسی انسان یا جن نے اس سے قبل\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvi{پس اپنے پروردگار کی کون کون سی نعمت کے ساتھ تم تکذیب کرتے ہو؟\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvii{سبز مسندوں اور عمده فرشوں پر تکیہ لگائے ہوئے ہوں گے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxviii{پس (اے جنو اور انسانو!) تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے؟\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxix{تیرے پروردگار کا نام بابرکت ہے جو عزت وجلال واﻻ ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxx{\basmalahur جب قیامت قائم ہو جائے گی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxi{جس کے واقع ہونے میں کوئی جھوٹ نہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxii{وه پست کرنے والی اور بلند کرنے والی ہوگی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiii{جبکہ زمین زلزلہ کے ساتھ ہلا دی جائے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiv{اور پہاڑ بالکل ریزه ریزه کر دیے جائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxv{پھر وه مثل پراگنده غبار کے ہو جائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvi{اور تم تین جماعتوں میں ہو جاؤ گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvii{پس داہنے ہاتھ والے کیسے اچھے ہیں داہنے ہاتھ والے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxviii{اور بائیں ہاتھ والے کیا حال ہے بائیں ہاتھ والوں کا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxix{اور جو آگے والے ہیں وه تو آگے والے ہی ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxc{وه بالکل نزدیکی حاصل کیے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxci{نعمتوں والی جنتوں میں ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcii{(بہت بڑا) گروه تو اگلے لوگوں میں سے ہوگا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciii{اور تھوڑے سے پچھلے لوگوں میں سے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciv{یہ لوگ سونے کے تاروں سے بنے ہوئے تختوں پر\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcv{ایک دوسرے کےسامنے تکیہ لگائے بیٹھے ہوں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvi{ان کے پاس ایسے لڑکے جو ہمیشہ (لڑکے ہی) رہیں گے آمدورفت کریں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvii{آبخورے اور جگ لے کر اور ایسا جام لے کر جو بہتی ہوئی شراب سے پر ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcviii{جس سے نہ سر میں درد ہو نہ عقل میں فتور آئے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcix{اور ایسے میوے لیے ہوئے جو ان کی پسند کے ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmm{اور پرندوں کے گوشت جو انہیں مرغوب ہوں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmi{اور بڑی بڑی آنکھوں والی حوریں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmii{جو چھپے ہوئے موتیوں کی طرح ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmiii{یہ صلہ ہے ان کے اعمال کا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmiv{نہ وہاں بکواس سنیں گے اور نہ گناه کی بات\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmv{صرف سلام ہی سلام کی آواز ہوگی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmvi{اور داہنے ہاتھ والے کیا ہی اچھے ہیں داہنے ہاتھ والے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmvii{وه بغیرکانٹوں کی بیریوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmviii{اور تہ بہ تہ کیلوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmix{اور لمبے لمبے سایوں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmx{اور بہتے ہوئے پانیوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmxi{اور بکثرت پھلوں میں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmxii{جو نہ ختم ہوں نہ روک لیے جائیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiii{اور اونچے اونچے فرشوں میں ہوں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiv{ہم نے ان کی (بیویوں کو) خاص طور پر بنایا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmxv{اور ہم نے انہیں کنواریاں بنا دیا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvi{محبت والیاں اور ہم عمر ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvii{دائیں ہاتھ والوں کے لیے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmxviii{جم غفیر ہے اگلوں میں سے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmxix{اور بہت بڑی جماعت ہے پچھلوں میں سے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmxx{اور بائیں ہاتھ والے کیا ہیں بائیں ہاتھ والے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxi{گرم ہوا اور گرم پانی میں (ہوں گے)\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxii{اورسیاه دھوئیں کے سائے میں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiii{جو نہ ٹھنڈا ہے نہ فرحت بخش\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiv{بیشک یہ لوگ اس سے پہلے بہت نازوں میں پلے ہوئے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxv{اور بڑے بڑے گناہوں پر اصرار کرتے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvi{اور کہتے تھے کہ کیا جب ہم مر جائیں گے اور مٹی اور ہڈی ہو جائیں گے تو کیا ہم پھر دوباره اٹھا کھڑے کیے جائیں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvii{اور کیا ہمارے اگلے باپ دادا بھی؟\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxviii{آپ کہہ دیجئے کہ یقیناً سب اگلے اور پچھلے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxix{ضرور جمع کئے جائیں گے ایک مقرر دن کے وقت\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxx{پھر تم اے گمراہو جھٹلانے والو!\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxi{البتہ کھانے والے ہو تھوہر کا درخت\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxii{اور اسی سے پیٹ بھرنے والے ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiii{پھر اس پر گرم کھولتا پانی پینے والے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiv{پھر پینے والے بھی پیاسے اونٹوں کی طرح\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxv{قیامت کے دن ان کی مہمانی یہ ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvi{ہم ہی نے تم سب کو پیدا کیا ہے پھر تم کیوں باور نہیں کرتے؟\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvii{اچھا پھر یہ تو بتلاؤ کہ جو منی تم ٹپکاتے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxviii{کیا اس کا (انسان) تم بناتے ہو یا پیدا کرنے والے ہم ہی ہیں؟\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxix{ہم ہی نے تم میں موت کو متعین کر دیا ہے اور ہم اس سے ہارے ہوئے نہیں ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmmxl{کہ تمہاری جگہ تم جیسے اور پیدا کر دیں اور تمہیں نئے سرے سے اس عالم میں پیدا کریں جس سے تم (بالکل) بےخبر ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmmxli{تمہیں یقینی طور پر پہلی دفعہ کی پیدائش معلوم ہی ہے پھر کیوں عبرت حاصل نہیں کرتے؟\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlii{اچھا پھر یہ بھی بتلاؤ کہ تم جو کچھ بوتے ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliii{اسے تم ہی اگاتے ہو یا ہم اگانے والے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliv{اگر ہم چاہیں تواسے ریزه ریزه کر ڈالیں اور تم حیرت کے ساتھ باتیں بناتے ہی ره جاؤ\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlv{کہ ہم پر تو تاوان ہی پڑ گیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvi{بلکہ ہم بالکل محروم ہی ره گئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvii{اچھا یہ بتاؤ کہ جس پانی کو تم پیتے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlviii{اسے بادلوں سے بھی تم ہی اتارتے ہو یا ہم برساتے ہیں؟\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlix{اگر ہماری منشا ہو تو ہم اسے کڑوا زہر کردیں پھر تم ہماری شکرگزاری کیوں نہیں کرتے؟\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmml{اچھا ذرا یہ بھی بتاؤ کہ جو آگ تم سلگاتے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmmli{اس کے درخت کو تم نے پیدا کیا ہے یا ہم اس کے پیدا کرنے والے ہیں؟\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmmlii{ہم نے اسے سبب نصیحت اور مسافروں کے فائدے کی چیز بنایا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmmliii{پس اپنے بہت بڑے رب کے نام کی تسبیح کیا کرو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmmliv{پس میں قسم کھاتا ہوں ستاروں کے گرنے کی\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmmlv{اور اگرتمہیں علم ہو تو یہ بہت بڑی قسم ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvi{کہ بیشک یہ قرآن بہت بڑی عزت واﻻ ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvii{جو ایک محفوظ کتاب میں درج ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmmlviii{جسے صرف پاک لوگ ہی چھو سکتے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmmlix{یہ رب العالمین کی طرف سےاترا ہوا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmmlx{پس کیا تم ایسی بات کو سرسری (اور معمولی) سمجھ رہے ہو؟\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxi{اور اپنے حصے میں یہی لیتے ہو کہ جھٹلاتے پھرو\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxii{پس جبکہ روح نرخرے تک پہنچ جائے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiii{اور تم اس وقت آنکھوں سے دیکھتے رہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiv{ہم اس شخص سے بہ نسبت تمہارے بہت زیاده قریب ہوتے ہیں لیکن تم نہیں دیکھ سکتے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxv{پس اگر تم کسی کے زیرفرمان نہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvi{اور اس قول میں سچے ہو تو (ذرا) اس روح کو تو لوٹاؤ\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvii{پس جو کوئی بارگاه الٰہی سے قریب کیا ہوا ہوگا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxviii{اسے تو راحت ہے اور غذائیں ہیں اور آرام والی جنت ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxix{اور جو شحص داہنے (ہاتھ) والوں میں سے ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxx{تو بھی سلامتی ہے تیرے لیے کہ تو داہنے والوں میں سے ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxi{لیکن اگر کوئی جھٹلانے والوں گمراہوں میں سے ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxii{تو کھولتے ہوئے گرم پانی کی مہمانی ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiii{اور دوزخ میں جانا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiv{یہ خبر سراسر حق اور قطعاً یقینی ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxv{پس تواپنے عظیم الشان پروردگار کی تسبیح کر\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvi{\basmalahur آسمانوں اور زمین میں جو ہے (سب) اللہ کی تسبیح کر رہے ہیں، وه زبردست باحکمت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvii{آسمانوں اور زمین کی بادشاہت اسی کی ہے، وہی زندگی دیتا ہے اور موت بھی اور وه ہر چیز پر قادر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxviii{وہی پہلے ہے اور وہی پیچھے، وہی ﻇاہر ہے اور وہی مخفی، اور وه ہر چیز کو بخوبی جاننے واﻻ ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxix{وہی ہے جس نے آسمانوں اور زمین کو چھ دن میں پیدا کیا پھر عرش پر مستوی ہو گیا۔ وه (خوب) جانتا ہےاس چیز کو جو زمین میں جائے اور جو اس سے نکلے اور جو آسمان سے نیچے آئے اور جو کچھ چڑھ کر اس میں جائے، اور جہاں کہیں تم ہو وه تمہارے ساتھ ہے اور جو تم کر رہے ہو اللہ دیکھ رہا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxx{آسمانوں کی اور زمین کی بادشاہی اسی کی ہے۔ اور تمام کام اسی کی طرف لوٹائے جاتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxi{وہی رات کو دن میں لے جاتا ہے اور وہی دن کو رات میں داخل کر دیتا ہے اور سینوں کے بھیدوں کا وه پورا عالم ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxii{اللہ پر اور اس کے رسول پر ایمان لے آؤ اور اس مال میں سے خرچ کرو جس میں اللہ نے تمہیں (دوسروں کا) جانشین بنایا ہے پس تم میں سے جو ایمان ﻻئیں اور خیرات کریں انہیں بہت بڑا ﺛواب ملے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiii{تم اللہ پر ایمان کیوں نہیں ﻻتے؟ حاﻻنکہ خود رسول تمہیں اپنے رب پر ایمان ﻻنےکی دعوت دے رہا ہے اور اگر تم مومن ہو تو وه تو تم سے مضبوط عہد وپیمان بھی لے چکا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiv{وه (اللہ) ہی ہے جو اپنے بندے پر واضح آیتیں اتارتا ہے تاکہ وه تمہیں اندھیروں سے نور کی طرف لے جائے یقیناً اللہ تعالیٰ تم پر نرمی کرنے واﻻ رحم کرنے واﻻ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxv{تمہیں کیا ہو گیا ہے جو تم اللہ کی راه میں خرچ نہیں کرتے؟ دراصل آسمانوں اور زمینوں کی میراث کا مالک (تنہا) اللہ ہی ہے تم میں سے جن لوگوں نے فتح سے پہلے فی سبیل اللہ دیا ہے اور قتال کیا ہے وه (دوسروں کے) برابر نہیں، بلکہ ان سے بہت بڑے درجے کے ہیں جنہوں نے فتح کے بعد خیراتیں دیں اور جہاد کیے۔ ہاں بھلائی کا وعده تو اللہ تعالیٰ کاان سب سے ہے جو کچھ تم کر رہے ہو اس سے اللہ خبردار ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvi{کون ہے جو اللہ تعالیٰ کو اچھی طرح قرض دے پھر اللہ تعالیٰ اسے اس کے لیے بڑھاتا چلا جائے اور اس کے لیے پسندیده اجر ﺛابت ہو جائے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvii{(قیامت کے دن تو دیکھے گا کہ مومن مردوں اور عورتوں کا نور ان کے آگے آگے اور ان کے دائیں دوڑ رہا ہوگا آج تمہیں ان جنتوں کی خوش خبری ہے جن کے نیچے نہریں جاری ہیں جن میں ہمیشہ کی رہائش ہے۔ یہ ہے بڑی کامیابی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxviii{اس دن منافق مرد وعورت ایمان والوں سے کہیں گے کہ ہمارا انتظار تو کرو کہ ہم بھی تمہارے نور سے کچھ روشنی حاصل کر لیں۔ جواب دیا جائے گا کہ تم اپنے پیچھے لوٹ جاؤ اور روشنی تلاش کرو۔ پھر ان کے اور ان کے درمیان ایک دیوار حائل کر دی جائے گی جس میں دروازه بھی ہوگا۔ اس کے اندرونی حصہ میں تو رحمت ہوگی اور باہر کی طرف عذاب ہوگا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxix{یہ چلا چلا کر ان سے کہیں گے کہ کیا ہم تمھارے ساتھ نہ تھے وه کہیں گے کہ ہاں تھے تو سہی لیکن تم نے اپنے آپ کو فتنہ میں پھنسا رکھا تھا اور انتظار میں ہی رہے اور شک و شبہ کرتے رہے اور تمہیں تمہاری فضول تمناؤں نے دھوکے میں ہی رکھا یہاں تک کہ اللہ کا حکم آ پہنچا اور تمہیں اللہ کے بارے میں دھوکہ دینے والے نے دھوکے میں ہی رکھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmxc{الغرض، آج تم سے نہ فدیہ (اور نہ بدلہ) قبول کیا جائے گا اور نہ کافروں سے تم (سب) کا ٹھکانا دوزخ ہے۔ وہی تمہاری رفیق ہے اور وه برا ٹھکانا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmxci{کیا اب تک ایمان والوں کے لیے وقت نہیں آیا کہ ان کے دل ذکر الٰہی سے اور جو حق اتر چکا ہے اس سے نرم ہو جائیں اور ان کی طرح نہ ہو جائیں جنہیں ان سے پہلے کتاب دی گئی تھی پھر جب ان پر ایک زمانہ دراز گزر گیا تو ان کے دل سخت ہو گئے اور ان میں بہت سے فاسق ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcii{یقین مانوکہ اللہ ہی زمین کو اس کی موت کے بعد زنده کر دیتا ہے۔ ہم نے تو تمہارے لیے اپنی آیتیں بیان کردیں تاکہ تم سمجھو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciii{بیشک صدقہ دینے والے مرد اور صدقہ دینے والی عورتیں اور جو اللہ کو خلوص کے ساتھ قرض دے رہے ہیں۔ ان کے لیے یہ بڑھایا جائے گا اور ان کے لیے پسندیده اجر وﺛواب ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciv{اللہ اوراس کے رسول پر جو ایمان رکھتے ہیں وہی لوگ اپنے رب کے نزدیک صدیق اور شہید ہیں ان کے لیے ان کا اجر اور ان کا نور ہے، اور جو لوگ کفر کرتے ہیں اور ہماری آیتوں کوجھٹلاتے ہیں وه جہنمی ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcv{خوب جان رکھو کہ دنیا کی زندگی صرف کھیل تماشا زینت اور آپس میں فخر (و غرور) اور مال واوﻻد میں ایک کا دوسرے سے اپنے آپ کو زیاده بتلانا ہے، جیسے بارش اور اس کی پیداوار کسانوں کو اچھی معلوم ہوتی ہے پھر جب وه خشک ہو جاتی ہے تو زرد رنگ میں اس کو تم دیکھتے ہو پھر وه بالکل چورا چورا ہو جاتی ہے اور آخرت میں سخت عذاب اور اللہ کی مغفرت اور رضامندی ہے اور دنیا کی زندگی بجز دھوکے کے سامان کے اور کچھ بھی تو نہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvi{(آؤ) دوڑو اپنے رب کی مغفرت کی طرف اور اس جنت کی طرف جس کی وسعت آسمان وزمین کی وسعت کے برابر ہے یہ ان کے لیے بنائی ہے جو اللہ پر اور اس کے رسولوں پر ایمان رکھتے ہیں۔ یہ اللہ کا فضل ہے جسے چاہے دے اور اللہ بڑے فضل واﻻ ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvii{نہ کوئی مصیبت دنیا میں آتی ہے نہ (خاص) تمہاری جانوں میں، مگر اس سے پہلے کہ ہم اس کو پیدا کریں وه ایک خاص کتاب میں لکھی ہوئی ہے، یہ (کام) اللہ تعالیٰ پر (بالکل) آسان ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcviii{تاکہ تم اپنے سے فوت شده کسی چیز پر رنجیده نہ ہو جایا کرو اور نہ عطا کرده چیز پر اترا جاؤ، اور اترانے والے شیخی خوروں کو اللہ پسند نہیں فرماتا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcix{جو (خود بھی) بخل کریں اور دوسروں کو (بھی) بخل کی تعلیم دیں۔ سنو! جو بھی منھ پھیرے اللہ بےنیاز اور سزاوار حمد وﺛنا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmc{یقیناً ہم نے اپنے پیغمبروں کو کھلی دلیلیں دے کر بھیجا اور ان کے ساتھ کتاب اور میزان (ترازو) نازل فرمایا تاکہ لوگ عدل پر قائم رہیں۔ اور ہم نے لوہے کو اتارا جس میں سخت ہیبت وقوت ہے اور لوگوں کے لیے اور بھی (بہت سے) فائدے ہیں اور اس لیے بھی کہ اللہ جان لے کہ اس کی اور اس کے رسولوں کی مدد بےدیکھے کون کرتا ہے، بیشک اللہ قوت واﻻ اور زبردست ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmci{بیشک ہم نے نوح اور ابراہیم (علیہ السلام) کو (پیغمبر بنا کر) بھیجا اور ہم نے ان دونوں کی اوﻻد میں پیغمبری اور کتاب جاری رکھی تو ان میں سے کچھ تو راه یافتہ ہوئے اور ان میں سے اکثر بہت نافرمان رہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcii{ان کے بعد پھر بھی ہم اپنے رسولوں کو پے در پے بھیجتے رہے اور ان کے بعد عیسیٰ بن مریم (علیہ السلام) کو بھیجا اور انہیں انجیل عطا فرمائی اور ان کے ماننے والوں کے دلوں میں شفقت اور رحم پیدا کردیا ہاں رہبانیت (ترک دنیا) تو ان لوگوں نے ازخود ایجاد کرلی تھی ہم نے ان پر اسے واجب نہ کیا تھا سوائے اللہ کی رضاجوئی کے۔ سو انہوں نے اس کی پوری رعایت نہ کی، پھر بھی ہم نے ان میں سے جو ایمان ﻻئے تھے۔ انہیں ان کا اجر دیا اور ان میں زیاده تر لوگ نافرمان ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmciii{اے وه لوگو جو ایمان ﻻئے ہو! اللہ سے ڈرتے رہا کرو اور اس کے رسول پر ایمان ﻻؤ اللہ تمہیں اپنی رحمت کا دوہرا حصہ دے گا اور تمہیں نور دے گا جس کی روشنی میں تم چلو پھرو گے اور تمہارے گناه بھی معاف فرمادے گا، اللہ بخشنے واﻻ مہربان ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmciv{یہ اس لیے کہ اہل کتاب جان لیں کہ اللہ کے فضل کے کسی حصہ پر بھی انہیں اختیار نہیں اور یہ کہ (سارا) فضل اللہ ہی کے ہاتھ ہے وه جسے چاہے دے، اور اللہ ہے ہی بڑے فضل واﻻ\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcv{\basmalahur یقیناً اللہ تعالیٰ نے اس عورت کی بات سنی جو تجھ سے اپنے شوہر کے بارے میں تکرار کر رہی تھی اور اللہ کے آگے شکایت کر رہی تھی، اللہ تعالیٰ تم دونوں کے سوال وجواب سن رہا تھا، بیشک اللہ تعالیٰ سننے دیکھنے واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvi{تم میں سے جو لوگ اپنی بیویوں سے ﻇہار کرتے ہیں (یعنی انہیں ماں کہہ بیٹھتے ہیں) وه دراصل ان کی مائیں نہیں بن جاتیں، ان کی مائیں تو وہی ہیں جن کے بطن سے وه پیدا ہوئے، یقیناً یہ لوگ ایک نامعقول اور جھوٹی بات کہتے ہیں۔ بیشک اللہ تعالیٰ معاف کرنے واﻻ اور بخشنے واﻻ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvii{جو لوگ اپنی بیویوں سے ﻇہار کریں پھر اپنی کہی ہوئی بات سے رجوع کرلیں تو ان کے ذمہ آپس میں ایک دوسرے کو ہاتھ لگانے سے پہلے ایک غلام آزاد کرنا ہے، اس کے ذریعہ تم نصیحت کیے جاتے ہو۔ اور اللہ تعالیٰ تمہارے تمام اعمال سے باخبر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcviii{ہاں جو شخص نہ پائے اس کے ذمہ دو مہینوں کے لگاتار روزے ہیں اس سے پہلے کہ ایک دوسرے کو ہاتھ لگائیں اور جس شخص کو یہ طاقت بھی نہ ہو اس پر ساٹھ مسکینوں کا کھانا کھلانا ہے۔ یہ اس لیے کہ تم اللہ کی اور اس کے رسول کی حکم برداری کرو، یہ اللہ تعالیٰ کی مقرر کرده حدیں ہیں اور کفار ہی کے لیے درد ناک عذاب ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcix{بیشک جو لوگ اللہ اور اس کے رسول کی مخالفت کرتے ہیں وه ذلیل کیے جائیں گے جیسے ان سے پہلے کے لوگ ذلیل کیے گئے تھے، اور بیشک ہم واضح آیتیں اتار چکے ہیں اور کافروں کے لیے تو ذلت واﻻ عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcx{جس دن اللہ تعالیٰ ان سب کو اٹھائے گا پھر انہیں ان کے کیے ہوئے عمل سے آگاه کرے گا، جسے اللہ نے شمار رکھا ہے اور جسے یہ بھول گئے تھے، اور اللہ تعالیٰ ہر چیز سے واقف ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxi{کیا تو نے نہیں دیکھا کہ اللہ آسمانوں کی اور زمین کی ہر چیز سے واقف ہے۔ تین آدمیوں کی سرگوشی نہیں ہوتی مگر اللہ ان کا چوتھا ہوتا ہے اور نہ پانچ کی مگر ان کا چھٹا وه ہوتا ہے اور نہ اس سے کم کی اور نہ زیاده کی مگر وه ساتھ ہی ہوتا ہے جہاں بھی وه ہوں، پھر قیامت کے دن انہیں ان کے اعمال سے آگاه کرے گا بیشک اللہ تعالیٰ ہر چیز سے واقف ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxii{کیا تو نے ان لوگوں کو نہیں دیکھا؟ جنہیں کانا پھوسی سے روک دیا گیا تھا وه پھر بھی اس روکے ہوئے کام کو دوباره کرتے ہیں اور آپس میں گناه کی اور ﻇلم وزیادتی کی اور نافرمانیٴ پیغمبر کی سرگوشیاں کرتے ہیں، اور جب تیرے پاس آتے ہیں تو تجھے ان لفظوں میں سلام کرتے ہیں جن لفظوں میں اللہ تعالیٰ نے نہیں کہا اور اپنے دل میں کہتے ہیں کہ اللہ تعالیٰ ہمیں اس پر جو ہم کہتے ہیں سزا کیوں نہیں دیتا، ان کے لیے جہنم کافی (سزا) ہے جس میں یہ جائیں گے، سو وه برا ٹھکانا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiii{اے ایمان والو! تم جب سرگوشی کرو تو یہ سرگوشیاں گناه اور ﻇلم (زیادتی) اور نافرمانیٴ پیغمبر کی نہ ہوں، بلکہ نیکی اور پرہیزگاری کی باتوں پر سرگوشی کرو اور اس اللہ سے ڈرتے رہو جس کے پاس تم سب جمع کیے جاؤ گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiv{(بری) سرگوشیاں، پس شیطانی کام ہے جس سے ایمان داروں کو رنج پہنچے۔ گو اللہ تعالیٰ کی اجازت کے بغیر وه انہیں کوئی نقصان نہیں پہنچا سکتا۔ اور ایمان والوں کو چاہئے کہ اللہ ہی پر بھروسہ رکھیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxv{اے مسلمانو! جب تم سے کہا جائے کہ مجلسوں میں ذرا کشادگی پیدا کرو تو تم جگہ کشاده کر دو اللہ تمہیں کشادگی دے گا، اور جب کہا جائے کہ اٹھ کھڑے ہو جاؤ تو تم اٹھ کھڑے ہو جاؤ اللہ تعالیٰ تم میں سے ان لوگوں کے جو ایمان ﻻئے ہیں اور جو علم دیئے گئے ہیں درجے بلند کر دے گا، اور اللہ تعالیٰ (ہر اس کام سے) جو تم کر رہے ہو (خوب) خبردار ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvi{اے مسلمانو! جب تم رسول ﴿صلی اللہ علیہ وسلم﴾ سے سرگوشی کرنا چاہو تو اپنی سرگوشی سے پہلے کچھ صدقہ دے دیا کرو یہ تمہارے حق میں بہتر اور پاکیزه تر ہے، ہاں اگر نہ پاؤ تو بیشک اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvii{کیا تم اپنی سرگوشی سے پہلے صدقہ نکالنے سے ڈر گئے؟ پس جب تم نے یہ نہ کیا اور اللہ تعالیٰ نے بھی تمہیں معاف فرما دیا تو اب (بخوبی) نمازوں کو قائم رکھو زکوٰة دیتے رہا کرو اور اللہ تعالیٰ کی اور اس کے رسول کی تابعداری کرتے رہو۔ تم جو کچھ کرتے ہو اس (سب) سے اللہ (خوب) خبردار ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxviii{کیا تو نے ان لوگوں کو نہیں دیکھا؟ جنہوں نے اس قوم سے دوستی کی جن پر اللہ غضبناک ہوچکا ہے، نہ یہ (منافق) تمہارے ہی ہیں نہ ان کے ہیں باوجود علم کے پھر بھی جھوٹ پر قسمیں کھا رہے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxix{اللہ تعالیٰ نے ان کے لیے سخت عذاب تیار کر رکھا ہے، تحقیق جو کچھ یہ کر رہے ہیں برا کر رہے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxx{ان لوگوں نے تو اپنی قسموں کو ڈھال بنا رکھا ہے اور لوگوں کو اللہ کی راه سے روکتے ہیں ان کے لیے رسوا کرنے واﻻ عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxi{ان کے مال اور ان کی اوﻻد اللہ کے ہاں کچھ کام نہ آئیں گی۔ یہ تو جہنمی ہیں ہمیشہ ہی اس میں رہیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxii{جس دن اللہ تعالیٰ ان سب کو اٹھا کھڑا کرے گا تو یہ جس طرح تمہارے سامنے قسمیں کھاتے ہیں (اللہ تعالیٰ) کے سامنے بھی قسمیں کھانے لگیں گے اور سمجھیں گے کہ وه بھی کسی (دلیل) پر ہیں، یقین مانو کہ بیشک وہی جھوٹے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiii{ان پر شیطان نے غلبہ حاصل کرلیا ہے، اور انہیں اللہ کا ذکر بھلا دیا ہے یہ شیطانی لشکر ہے۔ کوئی شک نہیں کہ شیطانی لشکر ہی خسارے واﻻ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiv{بیشک اللہ تعالیٰ کی اور اس کے رسول کی جو لوگ مخالفت کرتے ہیں وہی لوگ سب سے زیاده ذلیلوں میں ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxv{اللہ تعالیٰ لکھ چکا ہے کہ بیشک میں اور میرے پیغمبر غالب رہیں گے۔ یقیناً اللہ تعالیٰ زور آور اور غالب ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvi{اللہ تعالیٰ پر اور قیامت کے دن پر ایمان رکھنے والوں کو آپ اللہ اور اس کے رسول کی مخالفت کرنے والوں سے محبت رکھتے ہوئے ہرگز نہ پائیں گے گو وه ان کے باپ یا ان کے بیٹے یا ان کے بھائی یا ان کے کنبہ (قبیلے) کے (عزیز) ہی کیوں نہ ہوں۔ یہی لوگ ہیں جن کے دلوں میں اللہ تعالیٰ نے ایمان کو لکھ دیا ہے اور جن کی تائید اپنی روح سے کی ہے اور جنہیں ان جنتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہیں جہاں یہ ہمیشہ رہیں گے، اللہ ان سے راضی ہے اور یہ اللہ سے خوش ہیں یہ خدائی لشکر ہے، آگاه رہو بیشک اللہ کے گروه والے ہی کامیاب لوگ ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvii{\basmalahur آسمانوں اور زمین کی ہر چیز اللہ تعالیٰ کی پاکی بیان کرتی ہے، اور وه غالب باحکمت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxviii{وہی ہے جس نے اہل کتاب میں سے کافروں کو ان کے گھروں سے پہلے حشر کے وقت نکالا، تمہارا گمان (بھی) نہ تھا کہ وه نکلیں گے اور وه خود (بھی) سمجھ رہے تھے کہ ان کے (سنگین) قلعے انہیں اللہ (کے عذاب) سے بچا لیں گے پس ان پر اللہ (کا عذاب) ایسی جگہ سے آپڑا کہ انہیں گمان بھی نہ تھا اور ان کے دلوں میں اللہ نے رعب ڈال دیا وه اپنے گھروں کو اپنے ہی ہاتھوں اجاڑ رہے تھے اور مسلمانوں کے ہاتھوں (برباد کروا رہے تھے) پس اے آنکھوں والو! عبرت حاصل کرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxix{اور اگر اللہ تعالیٰ نے ان پر جلا وطنی کو مقدر نہ کر دیا ہوتا تو یقیناً انہیں دنیا ہی میں عذاب دیتا، اور آخرت میں (تو) ان کے لیے آگ کا عذاب ہے ہی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxx{یہ اس لیے کہ انہوں نے اللہ تعالیٰ کی اور اس کے رسول کی مخالفت کی اور جو بھی اللہ کی مخالفت کرے گا تو اللہ تعالیٰ بھی سخت عذاب کرنے واﻻ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxi{تم نے کھجوروں کے جو درخت کاٹ ڈالے یا جنہیں تم نے ان کی جڑوں پر باقی رہنے دیا۔ یہ سب اللہ تعالیٰ کے فرمان سے تھا اور اس لیے بھی کہ فاسقوں کو اللہ تعالیٰ رسوا کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxii{اور ان کا جو مال اللہ تعالیٰ نے اپنے رسول کے ہاتھ لگایا ہے جس پر نہ تو تم نے اپنے گھوڑے دوڑائے ہیں اور نہ اونٹ بلکہ اللہ تعالیٰ اپنے رسول کو جس پر چاہے غالب کر دیتا ہے، اور اللہ تعالیٰ ہر چیز پر قادر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiii{بستیوں والوں کا جو (مال) اللہ تعالیٰ تمہارے لڑے بھڑے بغیر اپنے رسول کے ہاتھ لگائے وه اللہ کا ہے اور رسول کا اور قرابت والوں کا اور یتیموں مسکینوں کا اور مسافروں کا ہے تاکہ تمہارے دولت مندوں کے ہاتھ میں ہی یہ مال گردش کرتا نہ ره جائے اور تمہیں جو کچھ رسول دے لے لو، اور جس سے روکے رک جاؤ اور اللہ تعالیٰ سے ڈرتے رہا کرو، یقیناً اللہ تعالیٰ سخت عذاب واﻻ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiv{(فیء کا مال) ان مہاجر مسکینوں کے لیے ہے جو اپنے گھروں سے اور اپنے مالوں سے نکال دیئے گئے ہیں وه اللہ کے فضل اور اس کی رضامندی کے طلب گار ہیں اور اللہ تعالیٰ کی اور اس کے رسول کی مدد کرتے ہیں یہی راست باز لوگ ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxv{اور (ان کے لیے) جنہوں نے اس گھر میں (یعنی مدینہ) اور ایمان میں ان سے پہلے جگہ بنالی ہے اور اپنی طرف ہجرت کرکے آنے والوں سے محبت کرتے ہیں اور مہاجرین کو جو کچھ دے دیا جائے اس سے وه اپنے دلوں میں کوئی تنگی نہیں رکھتے بلکہ خود اپنے اوپر انہیں ترجیح دیتے ہیں گو خود کو کتنی ہی سخت حاجت ہو (بات یہ ہے) کہ جو بھی اپنے نفس کے بخل سے بچایا گیا وہی کامیاب (اور بامراد) ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvi{اور (ان کے لیے) جو ان کے بعد آئیں جو کہیں گے کہ اے ہمارے پروردگار ہمیں بخش دے اور ہمارے ان بھائیوں کو بھی جو ہم سے پہلے ایمان ﻻچکے ہیں اور ایمان داروں کی طرف سے ہمارے دل میں کینہ (اور دشمنی) نہ ڈال، اے ہمارے رب بیشک تو شفقت ومہربانی کرنے واﻻ ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvii{کیا تو نے منافقوں کو نہ دیکھا؟ کہ اپنے اہل کتاب کافر بھائیوں سے کہتے ہیں اگر تم جلا وطن کیے گئے تو ضرور بالضرور ہم بھی تمہارے ساتھ نکل کھڑے ہوں گے اور تمہارے بارے میں ہم کبھی بھی کسی کی بات نہ مانیں گے اور اگر تم سے جنگ کی جائے گی تو بخدا ہم تمہاری مدد کریں گے، لیکن اللہ تعالیٰ گواہی دیتا ہے کہ یہ قطعاً جھوٹے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxviii{اگر وه جلاوطن کیے گئے تو یہ ان کے ساتھ نہ جائیں گے اور اگر ان سے جنگ کی گئی تو یہ ان کی مدد (بھی) نہ کریں گے اور اگر (بالفرض) مدد پر آبھی گئے تو پیٹھ پھیر کر (بھاگ کھڑے) ہوں گے پھر مدد نہ کیے جائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxix{(مسلمانو! یقین مانو) کہ تمہاری ہیبت ان کے دلوں میں بہ نسبت اللہ کی ہیبت کے بہت زیاده ہے، یہ اس لیے کہ یہ بے سمجھ لوگ ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxl{یہ سب مل کر بھی تم سے لڑ نہیں سکتے ہاں یہ اور بات ہے کہ قلعہ بند مقامات میں ہوں یا دیواروں کی آڑ میں ہوں، ان کی لڑائی تو ان میں آپس میں ہی بہت سخت ہے گو آپ انہیں متحد سمجھ رہے ہیں لیکن ان کے دل دراصل ایک دوسرے سے جدا ہیں۔ اس لیے کہ یہ بےعقل لوگ ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxli{ان لوگوں کی طرح جو ان سے کچھ ہی پہلے گزرے ہیں جنہوں نے اپنے کام کا وبال چکھ لیا اور جن کے لیے المناک عذاب (تیار) ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlii{شیطان کی طرح کہ اس نے انسان سے کہا کفر کر، جب وه کفر کر چکا تو کہنے لگا میں تو تجھ سے بری ہوں، میں تو اللہ رب العالمین سے ڈرتا ہوں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliii{پس دونوں کا انجام یہ ہوا کہ آتش (دوزخ) میں ہمیشہ کے لیے گئے اور ﻇالموں کی یہی سزا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliv{اے ایمان والو! اللہ سے ڈرتے رہو اور ہر شخص دیکھ (بھال) لے کہ کل (قیامت) کے واسطے اس نے (اعمال کا) کیا (ذخیره) بھیجا ہے۔ اور (ہر وقت) اللہ سے ڈرتے رہو۔ اللہ تمہارے سب اعمال سے باخبر ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlv{اور تم ان لوگوں کی طرح مت ہو جانا جنہوں نے اللہ (کے احکام) کو بھلا دیا تو اللہ نے بھی انہیں اپنی جانوں سے غافل کر دیا، اور ایسے ہی لوگ نافرمان (فاسق) ہوتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvi{اہل نار اور اہل جنت (باہم) برابر نہیں۔ جو اہل جنت ہیں وہی کامیاب ہیں (اور جو اہل نار ہیں وه ناکام ہیں)\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvii{اگر ہم اس قرآن کو کسی پہاڑ پر اتارتے تو تو دیکھتا کہ خوف الٰہی سے وه پست ہوکر ٹکڑے ٹکڑے ہو جاتا ہم ان مثالوں کو لوگوں کے سامنے بیان کرتے ہیں تاکہ وه غور وفکر کریں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlviii{وہی اللہ ہے جس کے سوا کوئی معبود نہیں، چھپے کھلے کا جاننے واﻻ مہربان اور رحم کرنے واﻻ\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlix{وہی اللہ ہے جس کے سوا کوئی معبود نہیں، بادشاه، نہایت پاک، سب عیبوں سے صاف، امن دینے واﻻ، نگہبان، غالب زورآور، اور بڑائی واﻻ، پاک ہے اللہ ان چیزوں سے جنہیں یہ اس کا شریک بناتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcl{وہی اللہ ہے پیدا کرنے واﻻ وجود بخشنے واﻻ، صورت بنانے واﻻ، اسی کے لیے (نہایت) اچھے نام ہیں، ہر چیز خواه وه آسمانوں میں ہو خواه زمین میں ہو اس کی پاکی بیان کرتی ہے، اور وہی غالب حکمت واﻻ ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcli{\basmalahur اے وه لوگو جو ایمان ﻻئے ہو! میرے اور (خود) اپنے دشمنوں کو اپنا دوست نہ بناؤ تم تو دوستی سے ان کی طرف پیغام بھیجتے ہو اور وه اس حق کے ساتھ جو تمہارے پاس آچکا ہے کفر کرتے ہیں، پیغمبر کو اور خود تمہیں بھی محض اس وجہ سے جلاوطن کرتے ہیں کہ تم اپنے رب پر ایمان رکھتے ہو، اگر تم میری راه میں جہاد کے لیے اور میری رضا مندی کی طلب میں نکلتے ہو (تو ان سے دوستیاں نہ کرو)، تم ان کے پاس محبت کا پیغام پوشیده پوشیده بھیجتے ہو اور مجھے خوب معلوم ہے جو تم نے چھپایا اور وه بھی جو تم نے ﻇاہر کیا، تم میں سے جو بھی اس کام کو کرے گا وه یقیناً راه راست سے بہک جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclii{اگر وه تم پر کہیں قابو پالیں تو وه تمہارے (کھلے) دشمن ہو جائیں اور برائی کے ساتھ تم پر دست درازی اور زبان درازی کرنے لگیں اور (دل سے) چاہنے لگیں کہ تم بھی کفر کرنے لگ جاؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliii{تمہاری قرابتیں، رشتہداریاں، اور اوﻻد تمہیں قیامت کے دن کام نہ آئیں گی، اللہ تعالیٰ تمہارے درمیان فیصلہ کر دے گا اور جو کچھ تم کر رہے ہو اسے اللہ خوب دیکھ رہا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliv{(مسلمانو!) تمہارے لیے حضرت ابراہیم میں اور ان کے ساتھیوں میں بہترین نمونہ ہے، جبکہ ان سب نے اپنی قوم سے برملا کہہ دیا کہ ہم تم سے اور جن جن کی تم اللہ کے سوا عبادت کرتے ہو ان سب سے بالکل بیزار ہیں۔ ہم تمہارے (عقائد کے) منکر ہیں جب تک تم اللہ کی وحدانیت پر ایمان نہ ﻻؤ ہم میں تم میں ہمیشہ کے لیے بغض وعداوت ﻇاہر ہوگئی لیکن ابراہیم کی اتنی بات تو اپنے باپ سے ہوئی تھی کہ میں تمہارے لیے استغفار ضرور کروں گا اور تمہارے لیے مجھے اللہ کے سامنے کسی چیز کا اختیار کچھ بھی نہیں۔ اے ہمارے پروردگار تجھی پر ہم نے بھروسہ کیا ہے اور تیری ہی طرف رجوع کرتے ہیں اور تیری ہی طرف لوٹنا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclv{اے ہمارے رب! تو ہمیں کافروں کی آزمائش میں نہ ڈال اور اے ہمارے پالنے والے ہماری خطاؤں کو بخش دے، بیشک تو ہی غالب، حکمت واﻻ ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvi{یقیناً تمہارے لیے ان میں اچھا نمونہ (اور عمده پیروی ہے خاص کر) ہر اس شخص کے لیے جو اللہ کی اور قیامت کے دن کی ملاقات کی امید رکھتا ہو، اور اگر کوئی روگردانی کرے تو اللہ تعالیٰ بالکل بےنیاز ہے اور سزا وار حمد وﺛنا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvii{کیا عجب کہ عنقریب ہی اللہ تعالیٰ تم میں اور تمہارے دشمنوں میں محبت پیدا کر دے۔ اللہ کو سب قدرتیں ہیں اور اللہ (بڑا) غفور رحیم ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclviii{جن لوگوں نے تم سے دین کے بارے میں لڑائی نہیں لڑی اور تمہیں جلاوطن نہیں کیا ان کے ساتھ سلوک واحسان کرنے اور منصفانہ بھلے برتاؤ کرنے سے اللہ تعالیٰ تمہیں نہیں روکتا، بلکہ اللہ تعالیٰ تو انصاف کرنے والوں سے محبت کرتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclix{اللہ تعالیٰ تمہیں صرف ان لوگوں کی محبت سے روکتا ہے جنہوں نے تم سے دین کے بارے میں لڑائیاں لڑیں اور تمہیں شہر سے نکال دیئے اور شہر سے نکالنے والوں کی مدد کی جو لوگ ایسے کفار سے محبت کریں وه (قطعاً) ﻇالم ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclx{اے ایمان والو! جب تمہارے پاس مومن عورتیں ہجرت کرکے آئیں تو تم ان کا امتحان لو۔ دراصل ان کے ایمان کو بخوبی جاننے واﻻ تو اللہ ہی ہے لیکن اگر وه تمہیں ایمان والیاں معلوم ہوں تو اب تم انہیں کافروں کی طرف واپس نہ کرو، یہ ان کے لیے حلال نہیں اور نہ وه ان کے لیے حلال ہیں، اور جو خرچ ان کافروں کا ہوا ہو وه انہیں ادا کردو، ان عورتوں کو ان کے مہر دے کر ان سے نکاح کر لینے میں تم پر کوئی گناه نہیں اور کافر عورتوں کی ناموس اپنے قبضہ میں نہ رکھو اور جو کچھ تم نے خرچ کیا ہو، مانگ لو اور جو کچھ ان کافروں نے خرچ کیا ہو وه بھی مانگ لیں یہ اللہ کا فیصلہ ہے جو تمہارے درمیان کر رہا ہے، اللہ تعالیٰ بڑے علم (اور) حکمت واﻻ ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxi{اور اگر تمہاری کوئی بیوی تمہارے ہاتھ سے نکل جائے اور کافروں کے پاس چلی جائے پھر تمہیں اس کے بدلے کا وقت مل جائے تو جن کی بیویاں چلی گئی ہیں انہیں ان کے اخراجات کے برابر ادا کر دو، اور اس اللہ تعالیٰ سے ڈرتے رہو جس پر تم ایمان رکھتے ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxii{اے پیغمبر! جب مسلمان عورتیں آپ سے ان باتوں پر بیعت کرنے آئیں کہ وه اللہ کے ساتھ کسی کو شریک نہ کریں گی، چوری نہ کریں گی، زنا کاری نہ کریں گی، اپنی اوﻻد کو نہ مار ڈالیں گی اور کوئی ایسا بہتان نہ باندھیں گی جو خود اپنے ہاتھوں پیروں کے سامنے گھڑ لیں اور کسی نیک کام میں تیری بےحکمی نہ کریں گی تو آپ ان سے بیعت کر لیا کریں، اور ان کے لیے اللہ سے مغفرت طلب کریں بیشک اللہ تعالیٰ بخشنے اور معاف کرنے واﻻ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiii{اے مسلمانو! تم اس قوم سے دوستی نہ رکھو جن پر اللہ کا غضب نازل ہوچکا ہے جو آخرت سے اس طرح مایوس ہوچکے ہیں جیسے کہ مرده اہل قبر سے کافر ناامید ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiv{\basmalahur زمین وآسمان کی ہر ہر چیز اللہ تعالیٰ کی پاکی بیان کرتی ہے اور وہی غالب حکمت واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxv{اے ایمان والو! تم وه بات کیوں کہتے ہو جو کرتے نہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvi{تم جو کرتے نہیں اس کا کہنا اللہ تعالیٰ کو سخت ناپسند ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvii{بیشک اللہ تعالیٰ ان لوگوں سے محبت کرتا ہے جو اس کی راه میں صف بستہ جہاد کرتے ہیں گویا وه سیسہ پلائی ہوئی عمارت ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxviii{اور (یاد کرو) جبکہ موسیٰ نے اپنی قوم سے کہا اے میری قوم کے لوگو! تم مجھے کیوں ستا رہے ہو حاﻻنکہ تمہیں (بخوبی) معلوم ہے کہ میں تمہاری جانب اللہ کا رسول ہوں پس جب وه لوگ ٹیڑھے ہی رہے تو اللہ نے ان کے دلوں کو (اور) ٹیڑھا کر دیا، اور اللہ تعالیٰ نافرمان قوم کو ہدایت نہیں دیتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxix{اور جب مریم کے بیٹے عیسیٰ نے کہا اے (میری قوم)، بنی اسرائیل! میں تم سب کی طرف اللہ کا رسول ہوں مجھ سے پہلے کی کتاب تورات کی میں تصدیق کرنے واﻻ ہوں اور اپنے بعد آنے والے ایک رسول کی میں تمہیں خوشخبری سنانے واﻻ ہوں جنکا نام احمد ہے۔ پھر جب وه ان کے پاس کھلی دلیلیں ﻻئے تو یہ کہنے لگے، یہ تو کھلا جادو ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxx{اس شخص سے زیاده ﻇالم اور کون ہوگا جو اللہ پر جھوٹ (افترا) باندھے حاﻻنکہ وه اسلام کی طرف بلایا جاتا ہے اور اللہ ایسے ﻇالموں کو ہدایت نہیں کرتا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxi{وه چاہتے ہیں کہ اللہ کے نور کو اپنے منھ سے بجھا دیں اور اللہ اپنے نور کو کمال تک پہنچانے واﻻ ہے گو کافر برا مانیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxii{وہی ہے جس نے اپنے رسول کو ہدایت اور سچا دین دے کر بھیجا تاکہ اسے اور تمام مذاہب پر غالب کر دے اگرچہ مشرکین ناخوش ہوں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiii{اے ایمان والو! کیا میں تمہیں وه تجارت بتلا دوں جو تمہیں درد ناک عذاب سے بچا لے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiv{اللہ تعالیٰ پر اور اس کے رسول پر ایمان ﻻؤ اور اللہ کی راه میں اپنے مال اور اپنی جانوں سے جہاد کرو۔ یہ تمہارے لیے بہتر ہے اگر تم میں علم ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxv{اللہ تعالیٰ تمہارے گناه معاف فرما دے گا اور تمہیں ان جنتوں میں پہنچائے گا جن کے نیچے نہریں جاری ہوں گی اور صاف ستھرے گھروں میں جو جنت عدن میں ہوں گے، یہ بہت بڑی کامیابی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvi{اور تمہیں ایک دوسری (نعمت) بھی دے گا جسے تم چاہتے ہو وه اللہ کی مدد اور جلد فتح یابی ہے، ایمان والوں کو خوشخبری دے دو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvii{اے ایمان والو! تم اللہ تعالیٰ کے مددگار بن جاؤ۔ جس طرح حضرت مریم کے بیٹے حضرت عیسیٰ نے حواریوں سے فرمایا کہ کون ہے جو اللہ کی راه میں میرا مددگار بنے؟ حواریوں نے کہا ہم اللہ کی راه میں مددگار ہیں، پس بنی اسرائیل میں سے ایک جماعت تو ایمان ﻻئی اور ایک جماعت نے کفر کیا تو ہم نے مومنوں کی انکے دشمنوں کے مقابلہ میں مدد کی پس وه غالب آ گئے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxviii{\basmalahur (ساری چیزیں) جو آسمانوں اور زمین میں ہیں اللہ تعالیٰ کی پاکی بیان کرتی ہیں (جو) بادشاه نہایت پاک (ہے) غالب وباحکمت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxix{وہی ہے جس نے ناخوانده لوگوں میں ان ہی میں سے ایک رسول بھیجا جو انہیں اس کی آیتیں پڑھ کر سناتا ہے اور ان کو پاک کرتا ہے اور انہیں کتاب وحکمت سکھاتا ہے۔ یقیناً یہ اس سے پہلے کھلی گمراہی میں تھے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxx{اور دوسروں کے لیے بھی انہیں میں سے جو اب تک ان سے نہیں ملے۔ اور وہی غالب باحکمت ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxi{یہ اللہ کا فضل ہے جسے چاہے اپنا فضل دے اور اللہ تعالیٰ بہت بڑے فضل کا مالک ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxii{جن لوگوں کو تورات پر عمل کرنے کا حکم دیا گیا پھر انہوں نے اس پر عمل نہیں کیا ان کی مثال اس گدھے کی سی ہے جو بہت سی کتابیں ﻻدے ہو۔ اللہ کی باتوں کو جھٹلانے والوں کی بڑی بری مثال ہے اور اللہ (ایسے) ﻇالم قوم کو ہدایت نہیں دیتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiii{کہہ دیجئے کہ اے یہودیو! اگر تمہارا دعویٰ ہے کہ تم اللہ کے دوست ہو دوسرے لوگوں کے سوا تو تم موت کی تمنا کرو اگر تم سچے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiv{یہ کبھی بھی موت کی تمنا نہ کریں گے بوجہ ان اعمال کے جو اپنے آگے اپنے ہاتھوں بھیج رکھے ہیں اور اللہ ﻇالموں کو خوب جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxv{کہہ دیجئے! کہ جس موت سے تم بھاگتے پھرتے ہو وه تو تمہیں پہنچ کر رہے گی پھر تم سب چھپے کھلے کے جاننے والے (اللہ) کی طرف لوٹائے جاؤ گے اور وه تمہیں تمہارے کیے ہوئے تمام کام بتلا دے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvi{اے وه لوگو جو ایمان ﻻئے ہو! جمعہ کے دن نماز کی اذان دی جائے تو تم اللہ کے ذکر کی طرف دوڑ پڑو اور خرید وفروخت چھوڑ دو۔ یہ تمہارے حق میں بہت ہی بہتر ہے اگر تم جانتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvii{پھر جب نماز ہو چکے تو زمین میں پھیل جاؤ اور اللہ کا فضل تلاش کرو اور بکثرت اللہ کا ذکر کیا کرو تاکہ تم فلاح پالو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxviii{اور جب کوئی سودا بکتا دیکھیں یا کوئی تماشا نظر آجائے تو اس کی طرف دوڑ جاتے ہیں اور آپ کو کھڑا ہی چھوڑ دیتے ہیں۔ آپ کہہ دیجئے کہ اللہ کے پاس جو ہے وه کھیل اور تجارت سے بہتر ہے۔ اور اللہ تعالیٰ بہترین روزی رساں ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxix{\basmalahur تیرے پاس جب منافق آتے ہیں تو کہتے ہیں کہ ہم اس بات کے گواه ہیں کہ بیشک آپ اللہ کے رسول ہیں، اور اللہ جانتا ہے کہ یقیناً آپ اس کے رسول ہیں۔ اور اللہ گواہی دیتا ہے کہ یہ منافق قطعاً جھوٹے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxc{انہوں نے اپنی قسموں کو ڈھال بنا رکھا ہے پس اللہ کی راه سے رک گئے بیشک برا ہے وه کام جو یہ کر رہے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxci{یہ اس سبب سے ہے کہ یہ ایمان ﻻکر پھر کافر ہوگئے پس ان کے دلوں پر مہر کر دی گئی۔ اب یہ نہیں سمجھتے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcii{جب آپ انہیں دیکھ لیں تو ان کے جسم آپ کو خوشنما معلوم ہوں، یہ جب باتیں کرنے لگیں تو آپ ان کی باتوں پر (اپنا) کان لگائیں، گویا کہ یہ لکڑیاں ہیں دیوار کے سہارے سے لگائی ہوئیں، ہر (سخت) آواز کو اپنے خلاف سمجھتے ہیں۔ یہی حقیقی دشمن ہیں ان سے بچو اللہ انہیں غارت کرے کہاں سے پھرے جاتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciii{اور جب ان سے کہا جاتا ہے کہ آؤ تمہارے لیے اللہ کے رسول استغفار کریں تو اپنے سر مٹکاتے ہیں اور آپ دیکھیں گے کہ وه تکبر کرتے ہوئے رک جاتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciv{ان کے حق میں آپ کا استغفار کرنا اور نہ کرنا دونوں برابر ہے۔ اللہ تعالیٰ انہیں ہر گز نہ بخشے گا۔ بیشک اللہ تعالیٰ (ایسے) نافرمان لوگوں کو ہدایت نہیں دیتا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcv{یہی وه ہیں جو کہتے ہیں کہ جو لوگ رسول اللہ کے پاس ہیں ان پر کچھ خرچ نہ کرو یہاں تک کہ وه ادھر ادھر ہو جائیں اور آسمان وزمین کے کل خزانے اللہ تعالیٰ کی ملکیت ہیں لیکن یہ منافق بے سمجھ ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvi{یہ کہتے ہیں کہ اگر ہم اب لوٹ کر مدینہ جائیں گے تو عزت واﻻ وہاں سے ذلت والے کو نکال دے گا۔ سنو! عزت تو صرف اللہ تعالیٰ کے لیے اور اس کے رسول کے لیے اور ایمان داروں کے لیے ہے لیکن یہ منافق جانتے نہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvii{اے مسلمانو! تمہارے مال اور تمہاری اوﻻد تمہیں اللہ کے ذکر سے غافل نہ کر دیں۔ اور جو ایسا کریں وه بڑے ہی زیاں کار لوگ ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcviii{اور جو کچھ ہم نے تمہیں دے رکھا ہے اس میں سے (ہماری راه میں) اس سے پہلے خرچ کرو کہ تم میں سے کسی کو موت آ جائے تو کہنے لگے اے میرے پروردگار! مجھے تو تھوڑی دیر کی مہلت کیوں نہیں دیتا؟ کہ میں صدقہ کروں اور نیک لوگوں میں سے ہو جاؤں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcix{اور جب کسی کا مقرره وقت آجاتا ہے پھر اسے اللہ تعالیٰ ہر گز مہلت نہیں دیتا اور جو کچھ تم کرتے ہو اس سے اللہ تعالیٰ بخوبی باخبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcc{\basmalahur (تمام چیزیں) جو آسمانوں اور زمین میں ہیں اللہ کی پاکی بیان کرتی ہیں اسی کی سلطنت ہے اور اسی کی تعریف ہے، اور وه ہر ہر چیز پر قادر ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcci{اسی نے تمہیں پیدا کیا ہے سو تم میں سے بعضے تو کافر ہیں اور بعض ایمان والے ہیں، اور جو کچھ تم کر رہے ہو اللہ تعالیٰ خوب دیکھ رہا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccii{اسی نے آسمانوں کو اور زمین کو عدل وحکمت سے پیدا کیا، اسی نے تمہاری صورتیں بنائیں اور بہت اچھی بنائیں اور اسی کی طرف لوٹنا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciii{وه آسمان وزمین کی ہر ہر چیز کا علم رکھتا ہے اور جو کچھ تم چھپاؤ اور جو ﻇاہر کرو وه (سب کو) جانتا ہے۔ اللہ تو سینوں کی باتوں تک کو جاننے واﻻ ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciv{کیا تمہارے پاس اس سے پہلے کے کافروں کی خبر نہیں پہنچی؟ جنہوں نے اپنے اعمال کا وبال چکھ لیا اور جن کے لیے دردناک عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccv{یہ اس لیے کہ ان کے پاس ان کے رسول واضح دﻻئل لے کر آئے تو انہوں نے کہہ دیا کہ کیا انسان ہماری رہنمائی کرے گا؟ پس انکار کر دیا اور منھ پھیر لیا اور اللہ نے بھی بےنیازی کی، اور اللہ تو ہے ہی بہت بےنیاز سب خوبیوں واﻻ\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvi{ان کافروں نے خیال کیا ہے کہ دوباره زنده نہ کیے جائیں گے۔ آپ کہہ دیجئے کہ کیوں نہیں اللہ کی قسم! تم ضرور دوباره اٹھائے جاؤ گے پھر جو تم نے کیا ہے اس کی خبر دیئے جاؤ گے اور اللہ پر یہ بالکل ہی آسان ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvii{سو تم اللہ پر اور اس کے رسول پر اور اس نور پر جسے ہم نے نازل فرمایا ہے ایمان ﻻؤ اور اللہ تعالیٰ تمہارے ہر عمل پر باخبر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccviii{جس دن تم سب کو اس جمع ہونے کے دن جمع کرے گا وہی دن ہے ہار جیت کا اور جو شخص اللہ پر ایمان ﻻکر نیک عمل کرے اللہ اس سے اس کی برائیاں دور کر دے گا اور اسے جنتوں میں داخل کرے گا جن کے نیچے نہریں بہہ رہی ہیں جن میں وه ہمیشہ ہمیشہ رہیں گے۔ یہی بہت بڑی کامیابی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccix{اور جن لوگوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہی (سب) جہنمی ہیں (جو) جہنم میں ہمیشہ رہیں گے، وه بہت برا ٹھکانا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccx{کوئی مصیبت اللہ کی اجازت کے بغیر نہیں پہنچ سکتی، جو اللہ پر ایمان ﻻئے اللہ اس کے دل کو ہدایت دیتا ہے اور اللہ ہر چیز کو خوب جاننے واﻻ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxi{(لوگو) اللہ کا کہنا مانو اور رسول کا کہنا مانو۔ پس اگر تم اعراض کرو تو ہمارے رسول کے ذمہ صرف صاف صاف پہنچا دینا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxii{اللہ کے سوا کوئی معبود برحق نہیں اور مومنوں کو اللہ ہی پر توکل رکھنا چاہئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiii{اے ایمان والو! تمہاری بعض بیویاں اور بعض بچے تمہارے دشمن ہیں پس ان سے ہوشیار رہنا اور اگر تم معاف کر دو اور درگزر کر جاؤ اور بخش دو تو اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiv{تمہارے مال اور اوﻻد تو سراسر تمہاری آزمائش ہیں۔ اور بہت بڑا اجر اللہ کے پاس ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxv{پس جہاں تک تم سے ہوسکے اللہ سے ڈرتے رہو اور سنتے اور مانتے چلے جاؤ اور اللہ کی راه میں خیرات کرتے رہو جو تمہارے لیے بہتر ہے اور جو شخص اپنے نفس کی حرص سے محفوظ رکھا جائے وہی کامیاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvi{اگر تم اللہ کو اچھا قرض دو گے (یعنی اس کی راه میں خرچ کرو گے) تو وه اسے تمہارے لیے بڑھاتا جائے گا اور تمہارے گناه بھی معاف فرما دے گا۔ اللہ بڑا قدر دان بڑا بردبار ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvii{وه پوشیده اور ﻇاہر کا جاننے واﻻ ہے زبردست حکمت واﻻ (ہے)\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxviii{\basmalahur اے نبی! (اپنی امت سے کہو کہ) جب تم اپنی بیویوں کو طلاق دینا چاہو تو ان کی عدت (کے دنوں کے آغاز) میں انہیں طلاق دو اور عدت کا حساب رکھو، اور اللہ سے جو تمہارا پروردگار ہے ڈرتے رہو، نہ تم انہیں ان کے گھروں سے نکالو اور نہ وه (خود) نکلیں ہاں یہ اور بات ہے کہ وه کھلی برائی کر بیٹھیں، یہ اللہ کی مقرر کرده حدیں ہیں، جو شخص اللہ کی حدوں سے آگے بڑھ جائے اس نے یقیناً اپنے اوپر ﻇلم کیا، تم نہیں جانتے شاید اس کے بعد اللہ تعالیٰ کوئی نئی بات پیدا کر دے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxix{پس جب یہ عورتیں اپنی عدت پوری کرنے کے قریب پہنچ جائیں تو انہیں یا تو قاعده کے مطابق اپنے نکاح میں رہنے دو یا دستور کے مطابق انہیں الگ کر دو اور آپس میں سے دو عادل شخصوں کو گواه کر لو اور اللہ کی رضامندی کے لیے ٹھیک ٹھیک گواہی دو۔ یہی ہے وه جس کی نصیحت اسے کی جاتی ہے جو اللہ پر اور قیامت کے دن پر ایمان رکھتا ہو اور جو شخص اللہ سے ڈرتا ہے اللہ اس کے لیے چھٹکارے کی شکل نکال دیتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxx{اور اسے ایسی جگہ سے روزی دیتا ہے جس کا اسے گمان بھی نہ ہو اور جو شخص اللہ پر توکل کرے گا اللہ اسے کافی ہوگا۔ اللہ تعالیٰ اپنا کام پورا کرکے ہی رہے گا۔ اللہ تعالیٰ نے ہر چیز کا ایک اندازه مقرر کر رکھا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxi{تمہاری عورتوں میں سے جو عورتیں حیض سے ناامید ہو گئی ہوں، اگر تمہیں شبہ ہو تو ان کی عدت تین مہینے ہے اور ان کی بھی جنہیں حیض آنا شروع ہی نہ ہوا ہو اور حاملہ عورتوں کی عدت ان کے وضع حمل ہے اور جو شخص اللہ تعالیٰ سے ڈرے گا اللہ اس کے (ہر) کام میں آسانی کر دے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxii{یہ اللہ کا حکم ہے جو اس نے تمہاری طرف اتارا ہے اور جو شخص اللہ سے ڈرے گا اللہ اس کے گناه مٹا دے گا اور اسے بڑا بھاری اجر دے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiii{تم اپنی طاقت کے مطابق جہاں تم رہتے ہو وہاں ان (طلاق والی) عورتوں کو رکھو اور انہیں تنگ کرنے کے لیے تکلیف نہ پہنچاؤ اور اگر وه حمل سے ہوں تو جب تک بچہ پیدا ہولے انہیں خرچ دیتے رہا کرو پھر اگر تمہارے کہنے سے وہی دودھ پلائیں تو تم انہیں ان کی اجرت دے دو اور باہم مناسب طور پر مشوره کر لیا کرو اور اگر تم آپس میں کشمکش کرو تو اس کے کہنے سے کوئی اور دودھ پلائے گی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiv{کشادگی والے کو اپنی کشادگی سے خرچ کرنا چاہئے اور جس پر اس کے رزق کی تنگی کی گئی ہو اسے چاہئے کہ جو کچھ اللہ تعالیٰ نے اسے دے رکھا ہے اسی میں سے (اپنی حسب حیثیت) دے، کسی شخص کو اللہ تکلیف نہیں دیتا مگر اتنی ہی جتنی طاقت اسے دے رکھی ہے، اللہ تنگی کے بعد آسانی وفراغت بھی کر دے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxv{اور بہت سی بستی والوں نے اپنے رب کے حکم سے اور اس کے رسولوں سے سرتابی کی تو ہم نے بھی ان سے سخت حساب کیا اور انہیں عذاب دیا ان دیکھا (سخت) عذاب\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvi{پس انہوں نے اپنے کرتوت کا مزه چکھ لیا اور انجام کار ان کا خساره ہی ہوا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvii{ان کے لیے اللہ تعالیٰ نے سخت عذاب تیار کر رکھا ہے، پس اللہ سے ڈرو اے عقل مند ایمان والو۔ یقیناً اللہ نے تمہاری طرف نصیحت اتار دی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxviii{(یعنی) رسول جو تمہیں اللہ کے صاف صاف احکام پڑھ سناتا ہے تاکہ ان لوگوں کو جو ایمان ﻻئیں اور نیک عمل کریں وه تاریکیوں سے روشنی کی طرف لے آئے، اور جو شخص اللہ پر ایمان ﻻئے اور نیک عمل کرے اللہ اسے ایسی جنتوں میں داخل کرے گا جس کے نیچے نہریں جاری ہیں جن میں یہ ہمیشہ ہمیشہ رہیں گے۔ بیشک اللہ نے اسے بہترین روزی دے رکھی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxix{اللہ وه ہے جس نے سات آسمان بنائے اور اسی کے مثل زمینیں بھی۔ اس کا حکم ان کے درمیان اترتا ہے تاکہ تم جان لو کہ اللہ ہر چیز پر قادر ہے۔ اور اللہ تعالیٰ نے ہر چیز کو بہ اعتبار علم گھیر رکھا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxx{\basmalahur اے نبی! جس چیز کو اللہ نے آپ کے لیے حلال کر دیا ہے اسے آپ کیوں حرام کرتے ہیں؟ (کیا) آپ اپنی بیویوں کی رضامندی حاصل کرنا چاہتے ہیں اور اللہ بخشنے واﻻ رحم کرنے واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxi{تحقیق کہ اللہ تعالیٰ نے تمہارے لیے قسموں کو کھول ڈالنا مقرر کر دیا ہے اور اللہ تمہارا کارساز ہے اور وہی (پورے) علم واﻻ، حکمت واﻻ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxii{اور یاد کر جب نبی نے اپنی بعض عورتوں سے ایک پوشیده بات کہی، پس جب اس نے اس بات کی خبر کر دی اور اللہ نے اپنے نبی کو اس پر آگاه کر دیا تو نبی نے تھوڑی سی بات تو بتا دی اور تھوڑی سی ٹال گئے، پھر جب نبی نے اپنی اس بیوی کو یہ بات بتائی تو وه کہنے لگی اس کی خبر آپ کو کس نے دی۔ کہا سب جاننے والے پوری خبر رکھنے والے اللہ نے مجھے یہ بتلایا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiii{(اے نبی کی دونوں بیویو!) اگر تم دونوں اللہ کے سامنے توبہ کرلو (تو بہت بہتر ہے) یقیناً تمہارے دل جھک پڑے ہیں اور اگر تم نبی کے خلاف ایک دوسرے کی مدد کرو گی پس یقیناً اس کا کارساز اللہ ہے اور جبریل ہیں اور نیک اہل ایمان اور ان کے علاوه فرشتے بھی مدد کرنے والے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiv{اگر وه (پیغمبر) تمہیں طلاق دے دیں تو بہت جلد انہیں ان کا رب! تمہارے بدلے تم سے بہتر بیویاں عنایت فرمائے گا، جو اسلام والیاں، ایمان والیاں اللہ کے حضور جھکنے والیاں توبہ کرنے والیاں، عبادت بجا ﻻنے والیاں روزے رکھنے والیاں ہوں گی بیوه اور کنواریاں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxv{اے ایمان والو! تم اپنے آپ کو اور اپنے گھر والوں کو اس آگ سے بچاؤ جس کا ایندھن انسان ہیں اور پتھر جس پر سخت دل مضبوط فرشتے مقرر ہیں جنہیں جو حکم اللہ تعالیٰ دیتا ہے اس کی نافرمانی نہیں کرتے بلکہ جو حکم دیا جائے بجا ﻻتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvi{اے کافرو! آج تم عذر وبہانہ مت کرو۔ تمہیں صرف تمہارے کرتوت کا بدلہ دیا جارہا ہے۔\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvii{اے ایمان والو! تم اللہ کے سامنے سچی خالص توبہ کرو۔ قریب ہے کہ تمہارا رب تمہارے گناه دور کر دے اور تمہیں ایسی جنتوں میں داخل کرے جن کے نیچے نہریں جاری ہیں۔ جس دن اللہ تعالیٰ نبی کو اور ایمان والوں کو جو ان کے ساتھ ہیں رسوا نہ کرے گا۔ ان کا نور ان کے سامنے اور ان کے دائیں دوڑ رہا ہوگا۔ یہ دعائیں کرتے ہوں گے اے ہمارے رب ہمیں کامل نور عطا فرما اور ہمیں بخش دے یقیناً تو ہر چیز پر قادر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxviii{اے نبی! کافروں اور منافقوں سے جہاد کرو اور ان پر سختی کرو ان کا ٹھکانا جہنم ہے اور وه بہت بری جگہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxix{اللہ تعالیٰ نے کافروں کے لیے نوح کی اور لوط کی بیوی کی مثال بیان فرمائی یہ دونوں ہمارے بندوں میں سے دو (شائستہ اور) نیک بندوں کے گھر میں تھیں، پھر ان کی انہوں نے خیانت کی پس وه دونوں (نیک بندے) ان سے اللہ کے (کسی عذاب کو) نہ روک سکے اور حکم دے دیا گیا (اے عورتوں) دوزخ میں جانے والوں کے ساتھ تم دونوں بھی چلی جاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxl{اور اللہ تعالیٰ نے ایمان والوں کے لیے فرعون کی بیوی کی مثال بیان فرمائی جبکہ اس نے دعا کی کہ اے میرے رب! میرے لیے اپنے پاس جنت میں مکان بنا اور مجھے فرعون سے اور اس کے عمل سے بچا اور مجھے ﻇالم لوگوں سے خلاصی دے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxli{اور (مثال بیان فرمائی) مریم بنت عمران کی جس نے اپنے ناموس کی حفاﻇت کی پھر ہم نے اپنی طرف سے اس میں جان پھونک دی اور (مریم) اس نے اپنے رب کی باتوں اور اس کی کتابوں کی تصدیق کی اور عبادت گزاروں میں سے تھی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlii{\basmalahur بہت بابرکت ہے وه (اللہ) جس کے ہاتھ میں بادشاہی ہے اور جو ہر چیز پر قدرت رکھنے واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliii{جس نے موت اور حیات کو اس لیے پیدا کیاکہ تمہیں آزمائے کہ تم میں سے اچھے کام کون کرتا ہے، اور وه غالب (اور) بخشنے واﻻ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliv{جس نے سات آسمان اوپر تلے بنائے۔ (تو اے دیکھنے والے) اللہ رحمٰن کی پیدائش میں کوئی بے ضابطگی نہ دیکھے گا، دوباره (نظریں ڈال کر) دیکھ لے کیا کوئی شگاف بھی نظر آرہا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlv{پھر دوہرا کر دو دو بار دیکھ لے تیری نگاه تیری طرف ذلیل (و عاجز) ہو کر تھکی ہوئی لوٹ آئے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvi{بیشک ہم نے آسمان دنیا کو چراغوں (ستاروں) سے آراستہ کیا اور انہیں شیطانوں کے مارنے کا ذریعہ بنا دیا اور شیطانوں کے لیے ہم نے (دوزخ کا جلانے واﻻ) عذاب تیار کر دیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvii{اور اپنے رب کے ساتھ کفر کرنے والوں کے لیے جہنم کا عذاب ہے اور وه کیا ہی بری جگہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlviii{جب اس میں یہ ڈالے جائیں گے تو اس کی بڑے زور کی آواز سنیں گے اور وه جوش مار رہی ہوگی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlix{قریب ہے کہ (ابھی) غصے کے مارے پھٹ جائے، جب کبھی اس میں کوئی گروه ڈاﻻ جائے گا اس سے جہنم کے داروغے پوچھیں گے کہ کیا تمہارے پاس ڈرانے واﻻ کوئی نہیں آیا تھا؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccl{وه جواب دیں گے کہ بیشک آیا تھا لیکن ہم نے اسے جھٹلایا اور ہم نے کہا کہ اللہ تعالیٰ نےکچھ بھی نازل نہیں فرمایا۔ تم بہت بڑی گمراہی میں ہی ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccli{اور کہیں گے اگر ہم سنتے ہوتے یا عقل رکھتے ہوتے تو دوزخیوں میں (شریک) نہ ہوتے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclii{پس انہوں نے اپنے جرم کا اقبال کر لیا۔ اب یہ دوزخی دفع ہوں (دور ہوں)\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliii{بیشک جو لوگ اپنے پروردگار سےغائبانہ طور پر ڈرتے رہتے ہیں ان کے لیے بخشش ہے اور بڑا ﺛواب ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliv{تم اپنی باتوں کو چھپاؤ یا ﻇاہر کرو وه تو سینوں کی پوشیدگی کو بھی بخوبی جانتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclv{کیا وہی نہ جانے جس نے پیدا کیا؟ پھر وه باریک بین اور باخبر بھی ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvi{وه ذات جس نے تمہارے لیے زمین کو پست ومطیع کردیا تاکہ تم اس کی راہوں میں چلتے پھرتے رہو اور اللہ کی روزیاں کھاؤ (پیو) اسی کی طرف (تمہیں) جی کر اٹھ کھڑا ہونا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvii{کیا تم اس بات سے بے خوف ہوگئے ہو کہ آسمانوں واﻻ تمہیں زمین میں دھنسا دے اور اچانک زمین لرزنے لگے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclviii{یا کیا تم اس بات سے نڈر ہوگئے ہو کہ آسمانوں واﻻ تم پر پتھر برسادے؟ پھر تو تمہیں معلوم ہو ہی جائے گا کہ میرا ڈرانا کیسا تھا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclix{اوران سے پہلے لوگوں نے بھی جھٹلایا تھا تو دیکھو ان پر میرا عذاب کیسا کچھ ہوا؟\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclx{کیا یہ اپنے اوپر پر کھولے ہوئے اور (کبھی کبھی) سمیٹے ہوئے (اڑنے والے) پرندوں کو نہیں دیکھتے، انہیں (اللہ) رحمٰن ہی (ہوا وفضا میں) تھامے ہوئے ہے۔ بیشک ہر چیز اس کی نگاه میں ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxi{سوائے اللہ کے تمہارا وه کون سا لشکر ہے جو تمہاری مدد کرسکے کافر تو سراسر دھوکے ہی میں ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxii{اگر اللہ تعالیٰ اپنی روزی روک لے تو بتاؤ کون ہے جو پھر تمہیں روزی دے گا؟ بلکہ (کافر) تو سرکشی اور بدکنے پر اڑگئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiii{اچھا وه شخص زیاده ہدایت واﻻ ہے جو اپنے منھ کے بل اوندھا ہو کر چلے یا وه جو سیدھا (پیروں کے بل) راه راست پر چلا ہو؟\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiv{کہہ دیجئے کہ وہی (اللہ) ہے جس نے تمہیں پیدا کیا اور تمہارے کان آنکھیں اور دل بنائے تم بہت ہی کم شکر گزاری کرتے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxv{کہہ دیجئے! کہ وہی ہے جس نے تمہیں زمین میں پھیلا دیا اور اس کی طرف سے تم اکٹھے کیے جاؤ گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvi{(کافر) پوچھتے ہیں کہ وه وعده کب ﻇاہر ہوگا اگر تم سچے ہو (تو بتاؤ؟)\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvii{آپ کہہ دیجئے کہ اس کا علم تو اللہ ہی کو ہے، میں تو صرف کھلے طور پر آگاه کر دینے واﻻ ہوں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxviii{جب یہ لوگ اس وعدے کو قریب تر پالیں گے اس وقت ان کافروں کے چہرے بگڑ جائیں گے اور کہہ دیا جائے گا کہ یہی ہے جسے تم طلب کیا کرتے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxix{آپ کہہ دیجئے! اچھا اگر مجھے اور میرے ساتھیوں کو اللہ تعالیٰ ہلاک کردے یا ہم پر رحم کرے (بہر صورت یہ تو بتاؤ) کہ کافروں کو دردناک عذاب سے کون بچائے گا؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxx{آپ کہہ دیجئے! کہ وہی رحمٰن ہے ہم تو اس پر ایمان ﻻچکے اور اسی پر ہمارا بھروسہ ہے۔ تمہیں عنقریب معلوم ہو جائے گا کہ صریح گمراہی میں کون ہے؟\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxi{آپ کہہ دیجئے! کہ اچھا یہ تو بتاؤ کہ اگر تمہارے (پینے کا) پانی زمین میں اتر جائے تو کون ہے جو تمہارے لیے نتھرا ہوا پانی ﻻئے؟\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxii{\basmalahur ن، قسم ہے قلم کی اور اس کی جو کچھ کہ وه (فرشتے) لکھتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiii{تو اپنے رب کے فضل سے دیوانہ نہیں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiv{اور بے شک تیرے لیے بے انتہا اجر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxv{اور بیشک تو بہت بڑے (عمده) اخلاق پر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvi{پس اب تو بھی دیکھ لے گا اور یہ بھی دیکھ لیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvii{کہ تم میں سے کون فتنہ میں پڑا ہوا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxviii{بیشک تیرا رب اپنی راه سے بہکنے والوں کو خوب جانتا ہے، اور وه راه یافتہ لوگوں کو بھی بخوبی جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxix{پس تو جھٹلانے والوں کی نہ مان\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxx{وه تو چاہتے ہیں کہ تو ذرا ڈھیلا ہو تو یہ بھی ڈھیلے پڑ جائیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxi{اور تو کسی ایسے شخص کا بھی کہا نہ ماننا جو زیاده قسمیں کھانے واﻻ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxii{بے وقار، کمینہ، عیب گو، چغل خور\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiii{بھلائی سے روکنے واﻻ حد سے بڑھ جانے واﻻ گنہگار\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiv{گردن کش پھر ساتھ ہی بے نسب ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxv{اس کی سرکشی صرف اس لیے ہے کہ وه مال واﻻ اور بیٹوں واﻻ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvi{جب اس کے سامنے ہماری آیتیں پڑھی جاتی ہیں تو کہہ دیتا ہے کہ یہ تو اگلوں کے قصے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvii{ہم بھی اس کی سونڈ (ناک) پر داغ دیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxviii{بیشک ہم نے انہیں اسی طرح آزما لیا جس طرح ہم نے باغ والوں کو آزمایا تھا جبکہ انہوں نے قسمیں کھائیں کہ صبح ہوتے ہی اس باغ کے پھل اتار لیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxix{اور انشاءاللہ نہ کہا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxc{پس اس پر تیرے رب کی جانب سے ایک بلا چاروں طرف گھوم گئی اور یہ سو ہی رہے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxci{پس وه باغ ایسا ہو گیا جیسے کٹی ہوئی کھیتی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcii{اب صبح ہوتے ہی انہوں نے ایک دوسرے کو آوازیں دیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciii{کہ اگر تمہیں پھل اتارنے ہیں تو اپنی کھیتی پر سویرے ہی سویرے چل پڑو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciv{پھر یہ سب چپکے چپکے یہ باتیں کرتے ہوئے چلے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcv{کہ آج کے دن کوئی مسکین تمہارے پاس نہ آنے پائے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvi{اور لپکے ہوئے صبح صبح گئے۔ (سمجھ رہے تھے) کہ ہم قابو پاگئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvii{جب انہوں نے باغ دیکھا تو کہنے لگے یقیناً ہم راستہ بھول گئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcviii{نہیں نہیں بلکہ ہماری قسمت پھوٹ گئی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcix{ان سب میں جو بہتر تھا اس نے کہا کہ میں تم سے نہ کہتا تھا کہ تم اللہ کی پاکیزگی کیوں نہیں بیان کرتے؟\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccc{تو سب کہنے لگے ہمارا رب پاک ہے بیشک ہم ہی ﻇالم تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmccci{پھر وه ایک دوسرے کی طرف رخ کر کے آپس میں ملامت کرنے لگے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccii{کہنے لگے ہائے افسوس! یقیناً ہم سرکش تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciii{کیا عجب ہے کہ ہمارا رب ہمیں اس سے بہتر بدلہ دے دے ہم تو اب اپنے رب سے ہی آرزو رکھتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciv{یوں ہی آفت آتی ہے اور آخرت کی آفت بہت بڑی ہے۔ کاش انہیں سمجھ ہوتی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccv{پرہیزگاروں کے لیے ان کے رب کے پاس نعمتوں والی جنتیں ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvi{کیا ہم مسلمانوں کو مثل گناه گاروں کے کردیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvii{تمہیں کیا ہوگیا، کیسے فیصلے کر رہے ہو؟\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccviii{کیا تمہارے پاس کوئی کتاب ہے جس میں تم پڑھتے ہو؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccix{کہ اس میں تمہاری من مانی باتیں ہوں؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccx{یا تم نے ہم سے کچھ قسمیں لی ہیں؟ جو قیامت تک باقی رہیں کہ تمہارے لیے وه سب ہے جو تم اپنی طرف سے مقرر کر لو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxi{ان سے پوچھو تو کہ ان میں سے کون اس بات کا ذمہدار (اور دعویدار) ہے؟\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxii{کیا ان کے کوئی شریک ہیں؟ تو چاہئے کہ اپنے اپنے شریکوں کو لے آئیں اگر یہ سچے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiii{جس دن پنڈلی کھول دی جائے گی اور سجدے کے لیے بلائے جائیں گے تو (سجده) نہ کر سکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiv{نگاہیں نیچی ہوں گی اور ان پر ذلت و خواری چھارہی ہوگی، حاﻻنکہ یہ سجدے کے لیے (اس وقت بھی) بلائے جاتے تھے جب کہ صحیح سالم تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxv{پس مجھے اور اس کلام کو جھٹلانے والے کو چھوڑ دے ہم انہیں اس طرح آہستہ آہستہ کھینچیں گے کہ انہیں معلوم بھی نہ ہوگا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvi{اور میں انہیں ڈھیل دوں گا، بیشک میری تدبیر بڑی مضبوط ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvii{کیا تو ان سے کوئی اجرت چاہتا ہے جس کے تاوان سے یہ دبے جاتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxviii{یا کیا ان کے پاس علم غیب ہے جسے وه لکھتے ہوں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxix{پس تو اپنے رب کے حکم کا صبر سے (انتظار کر) اور مچھلی والے کی طرح نہ ہو جا جب کہ اس نے غم کی حالت میں دعا کی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxx{اگر اسے اس کے رب کی نعمت نہ پالیتی تو یقیناً وه برے حالوں میں چٹیل میدان میں ڈال دیا جاتا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxi{اسے اس کے رب نے پھر نوازا اور اسے نیک کاروں میں کر دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxii{اور قریب ہے کہ کافر اپنی تیز نگاہوں سے آپ کو پھسلا دیں، جب کبھی قرآن سنتے ہیں اور کہہ دیتے ہیں یہ تو ضرور دیوانہ ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiii{در حقیقت یہ (قرآن) تو تمام جہان والوں کے لیے سراسر نصیحت ہی ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiv{\basmalahur ﺛابت ہونے والی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxv{ﺛابت ہونے والی کیا ہے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvi{اور تجھے کیا معلوم ہے کہ وه ﺛابت شده کیا ہے؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvii{اس کھڑکا دینے والی کو ﺛمود اور عاد نے جھٹلا دیا تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxviii{(جس کے نتیجہ میں) ﺛمود تو بے حد خوفناک (اور اونچی) آواز سے ہلاک کردیئے گئے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxix{اور عاد بیحد تیز وتند ہوا سے غارت کردیئے گئے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxx{جسے ان پر لگاتار سات رات اور آٹھ دن تک (اللہ نے) مسلط رکھا پس تم دیکھتے کہ یہ لوگ زمین پر اس طرح گر گئے جیسے کہ کھجور کے کھوکھلے تنے ہوں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxi{کیا ان میں سے کوئی بھی تجھے باقی نظر آرہا ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxii{فرعون اور اس سے پہلے کے لوگ اور جن کی بستیاں الٹ دی گئی، انہوں نے بھی خطائیں کیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiii{اور اپنے رب کے رسول کی نافرمانی کی (بالﺂخر) اللہ نے انہیں (بھی) زبردست گرفت میں لے لیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiv{جب پانی میں طغیانی آگئی تو اس وقت ہم نے تمہیں کشتی میں چڑھا لیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxv{تاکہ اسے تمہارے لیے نصیحت اور یادگار بنادیں، اور (تاکہ) یاد رکھنے والے کان اسے یاد رکھیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvi{پس جب کہ صور میں ایک پھونک پھونکی جائے گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvii{اور زمین اور پہاڑ اٹھا لیے جائیں گے اور ایک ہی چوٹ میں ریزه ریزه کر دیے جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxviii{اس دن ہو پڑنے والی (قیامت) ہو پڑے گی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxix{اور آسمان پھٹ جائے گا اور اس دن بالکل بودا ہوجائے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxl{اس کے کناروں پر فرشتے ہوں گے، اور تیرے پروردگار کا عرش اس دن آٹھ (فرشتے) اپنے اوپر اٹھائے ہوئے ہوں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxli{اس دن تم سب سامنے پیش کیے جاؤ گے، تمہارا کوئی بھید پوشیده نہ رہے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlii{سو جسے اس کا نامہٴ اعمال اس کے دائیں ہاتھ میں دیا جائے گا تو وه کہنے لگے گا کہ لو میرا نامہٴ اعمال پڑھو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliii{مجھے تو کامل یقین تھا کہ مجھے اپنا حساب ملنا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliv{پس وه ایک دل پسند زندگی میں ہوگا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlv{بلند وباﻻ جنت میں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvi{جس کے میوے جھکے پڑے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvii{(ان سے کہا جائے گا) کہ مزے سے کھاؤ، پیو اپنے ان اعمال کے بدلے جو تم نے گزشتہ زمانے میں کیے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlviii{لیکن جسے اس (کے اعمال) کی کتاب اس کے بائیں ہاتھ میں دی جائے گی، وه تو کہے گا کہ کاش کہ مجھے میری کتاب دی ہی نہ جاتی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlix{اور میں جانتا ہی نہ کہ حساب کیا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccl{کاش! کہ موت (میرا) کام ہی تمام کر دیتی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccli{میرے مال نے بھی مجھے کچھ نفع نہ دیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclii{میرا غلبہ بھی مجھ سے جاتا رہا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliii{(حکم ہوگا) اسے پکڑ لو پھر اسے طوق پہنادو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliv{پھر اسے دوزخ میں ڈال دو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclv{پھر اسے ایسی زنجیر میں جس کی پیمائش ستر ہاتھ کی ہے جکڑ دو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvi{بیشک یہ اللہ عظمت والے پرایمان نہ رکھتا تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvii{اور مسکین کے کھلانے پر رغبت نہ دﻻتا تھا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclviii{پس آج اس کا نہ کوئی دوست ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclix{اور نہ سوائے پیﭗ کے اس کی کوئی غذا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclx{جسے گناه گاروں کے سوا کوئی نہیں کھائے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxi{پس مجھے قسم ہے ان چیزوں کی جنہیں تم دیکھتے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxii{اور ان چیزوں کی جنہیں تم نہیں دیکھتے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiii{کہ بیشک یہ (قرآن) بزرگ رسول کا قول ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiv{یہ کسی شاعر کا قول نہیں (افسوس) تمہیں بہت کم یقین ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxv{اور نہ کسی کاہن کا قول ہے، (افسوس) بہت کم نصیحت لے رہے ہو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvi{(یہ تو) رب العالمین کا اتارا ہوا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvii{اور اگر یہ ہم پر کوئی بھی بات بنا لیتا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxviii{تو البتہ ہم اس کا داہنا ہاتھ پکڑ لیتے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxix{پھر اس کی شہ رگ کاٹ دیتے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxx{پھر تم میں سے کوئی بھی مجھے اس سے روکنے واﻻ نہ ہوتا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxi{یقیناً یہ قرآن پرہیزگاروں کے لیے نصیحت ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxii{ہمیں پوری طرح معلوم ہے کہ تم میں سے بعض اس کے جھٹلانے والے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiii{بیشک (یہ جھٹلانا) کافروں پر حسرت ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiv{اور بیشک (و شبہ) یہ یقینی حق ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxv{پس تو اپنے رب عظیم کی پاکی بیان کر\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvi{\basmalahur ایک سوال کرنے والے نے اس عذاب کا سوال کیا جو واضح ہونے واﻻ ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvii{کافروں پر، جسے کوئی ہٹانے واﻻ نہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxviii{اس اللہ کی طرف سے جو سیڑھیوں واﻻ ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxix{جس کی طرف فرشتے اور روح چڑھتے ہیں ایک دن میں جس کی مقدار پچاس ہزار سال کی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxx{پس تو اچھی طرح صبر کر\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxi{بیشک یہ اس (عذاب) کو دور سمجھ رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxii{اور ہم اسے قریب ہی دیکھتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiii{جس دن آسمان مثل تیل کی تلچھٹ کے ہو جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiv{اور پہاڑ مثل رنگین اون کے ہو جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxv{اور کوئی دوست کسی دوست کو نہ پوچھے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvi{(حاﻻنکہ) ایک دوسرے کو دکھا دیئے جائیں گے، گناهگار اس دن کے عذاب کے بدلے فدیے میں اپنے بیٹوں کو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvii{اپنی بیوی کو اور اپنے بھائی کو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxviii{اور اپنے کنبے کو جو اسے پناه دیتا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxix{اور روئے زمین کے سب لوگوں کو دینا چاہے گا تاکہ یہ اسے نجات دﻻ دے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxc{(مگر) ہرگز یہ نہ ہوگا، یقیناً وه شعلہ والی (آگ) ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxci{جو منھ اور سر کی کھال کھینچ ﻻنے والی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcii{وه ہر اس شخص کو پکارے گی جو پیچھے ہٹتا اور منھ موڑتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciii{اور جمع کرکے سنبھال رکھتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciv{بیشک انسان بڑے کچے دل واﻻ بنایا گیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcv{جب اسے مصیبت پہنچتی ہے تو ہڑبڑا اٹھتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvi{اور جب راحت ملتی ہے تو بخل کرنے لگتا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvii{مگر وه نمازی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcviii{جو اپنی نماز پر ہمیشگی کرنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcix{اور جن کے مالوں میں مقرره حصہ ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcd{مانگنے والوں کا بھی اور سوال سے بچنے والوں کا بھی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdi{اور جو انصاف کے دن پر یقین رکھتے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdii{اور جو اپنے رب کے عذاب سے ڈرتے رہتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiii{بیشک ان کے رب کا عذاب بے خوف ہونے کی چیز نہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiv{اور جو لوگ اپنی شرم گاہوں کی (حرام سے) حفاﻇت کرتے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdv{ہاں ان کی بیویوں اور لونڈیوں کے بارے میں جن کے وه مالک ہیں انہیں کوئی ملامت نہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvi{اب جو کوئی اس کے علاوه (راه) ڈھونڈے گا توایسے لوگ حد سے گزر جانے والے ہوں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvii{اور جو اپنی امانتوں کا اور اپنے قول و قرار کا پاس رکھتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdviii{اور جو اپنی گواہیوں پر سیدھے اور قائم رہتے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdix{اور جو اپنی نمازوں کی حفاﻇت کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdx{یہی لوگ جنتوں میں عزت والے ہوں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxi{پس کافروں کو کیاہو گیا ہے کہ وه تیری طرف دوڑتے آتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxii{دائیں اور بائیں سے گروه کے گروه\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiii{کیا ان میں سے ہر ایک کی توقع یہ ہے کہ وه نعمتوں والی جنت میں داخل کیا جائے گا؟\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiv{(ایسا) ہرگز نہ ہوگا۔ ہم نے انہیں اس (چیز) سے پیدا کیا ہے جسے وه جانتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxv{پس مجھے قسم ہے مشرقوں اور مغربوں کے رب کی (کہ) ہم یقیناً قادر ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvi{اس پر کہ ان کے عوض ان سے اچھے لوگ لے آئیں اور ہم عاجز نہیں ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvii{پس تو انہیں جھگڑتا کھیلتا چھوڑ دے یہاں تک کہ یہ اپنے اس دن سے جاملیں جس کا ان سے وعده کیا جاتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxviii{جس دن یہ قبروں سے دوڑتے ہوئے نکلیں گے، گویا کہ وه کسی جگہ کی طرف تیز تیز جا رہے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxix{ان کی آنکھیں جھکی ہوئی ہوں گی، ان پر ذلت چھا رہی ہوگی، یہ ہے وه دن جس کا ان سے وعده کیا جاتا تھا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxx{\basmalahur یقیناً ہم نے نوح (علیہ السلام) کو ان کی قوم کی طرف بھیجا کہ اپنی قوم کو ڈرا دو (اور خبردار کردو) اس سے پہلے کہ ان کے پاس دردناک عذاب آجائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxi{(نوح علیہ السلام نے) کہا اے میری قوم! میں تمہیں صاف صاف ڈرانے واﻻ ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxii{کہ تم اللہ کی عبادت کرو اور اسی سے ڈرو اور میرا کہا مانو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiii{تو وه تمہارے گناه بخش دے گا اور تمہیں ایک وقت مقرره تک چھوڑ دے گا۔ یقیناً اللہ کا وعده جب آجاتا ہے تو مؤخر نہیں ہوتا۔ کاش کہ تمہیں سمجھ ہوتی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiv{(نوح علیہ السلام نے) کہا اے میرے پرورگار! میں نے اپنی قوم کو رات دن تیری طرف بلایا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxv{مگر میرے بلانے سے یہ لوگ اور زیاده بھاگنے لگے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvi{میں نے جب کبھی انہیں تیری بخشش کے لیے بلایا انہوں نے اپنی انگلیاں اپنے کانوں میں ڈال لیں اور اپنے کپڑوں کو اوڑھ لیا اور اڑ گئے اور بڑا تکبر کیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvii{پھر میں نے انہیں بﺂواز بلند بلایا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxviii{اور بیشک میں نےان سے علانیہ بھی کہا اور چپکے چپکے بھی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxix{اور میں نے کہا کہ اپنے رب سے اپنے گناه بخشواؤ (اور معافی مانگو) وه یقیناً بڑا بخشنے واﻻ ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxx{وه تم پر آسمان کو خوب برستا ہوا چھوڑ دے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxi{اور تمہیں خوب پے درپے مال اور اوﻻد میں ترقی دے گا اور تمہیں باغات دے گا اور تمہارے لیے نہریں نکال دے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxii{تمہیں کیا ہوگیا ہے کہ تم اللہ کی برتری کا عقیده نہیں رکھتے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiii{حاﻻنکہ اس نے تمہیں طرح طرح سے پیدا کیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiv{کیا تم نہیں دیکھتے کہ اللہ تعالیٰ نے اوپر تلے کس طرح سات آسمان پیدا کر دیئے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxv{اور ان میں چاند کو جگمگاتا بنایا ہے اور سورج کو روشن چراغ بنایا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvi{اور تم کو زمین سے ایک (خاص اہتمام سے) اگایا ہے (اور پیدا کیا ہے)\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvii{پھر تمہیں اسی میں لوٹا لے جائے گا اور (ایک خاص طریقہ) سے پھر نکالے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxviii{اور تمہارے لیے زمین کو اللہ تعالیٰ نے فرش بنادیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxix{تاکہ تم اس کی کشاده راہوں میں چلو پھرو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxl{نوح (علیہ السلام) نے کہا اے میرے پروردگار! ان لوگوں نے میری تو نافرمانی کی اور ایسوں کی فرمانبرداری کی جن کے مال واوﻻد نے ان کو (یقیناً) نقصان ہی میں بڑھایا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxli{اور ان لوگوں نے بڑا سخت فریب کیا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlii{اور کہا انہوں نے کہ ہرگز اپنے معبودوں کو نہ چھوڑنا اور نہ ود اور سواع اور یغوث اور یعوق اور نسر کو (چھوڑنا)\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliii{اور انہوں نے بہت سے لوگوں کو گمراه کیا (الٰہی) تو ان ﻇالموں کی گمراہی اور بڑھا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliv{یہ لوگ بہ سبب اپنے گناہوں کے ڈبو دیئے گئے اور جہنم میں پہنچا دیئے گئے اور اللہ کے سوا اپنا کوئی مددگار انہوں نے نہ پایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlv{اور (حضرت) نوح (علیہ السلام) نے کہا کہ اے میرے پالنے والے! تو روئے زمین پر کسی کافر کو رہنے سہنے واﻻ نہ چھوڑ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvi{اگر تو انہیں چھوڑ دے گا تو (یقیناً) یہ تیرے (اور) بندوں کو (بھی) گمراه کر دیں گے اور یہ فاجروں اور ڈھیٹ کافروں ہی کو جنم دیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvii{اے میرے پروردگار! تو مجھے اور میرے ماں باپ اور جو بھی ایمان کی حالت میں میرے گھر میں آئے اور تمام مومن مردوں اور عورتوں کو بخش دے اور کافروں کو سوائے بربادی کے اور کسی بات میں نہ بڑھا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlviii{\basmalahur (اے محمد صلی اللہ علیہ وسلم) آپ کہہ دیں کہ مجھے وحی کی گئی ہے کہ جنوں کی ایک جماعت نے (قرآن) سنا اور کہا کہ ہم نے عجیب قرآن سنا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlix{جو راه راست کے طرف رہنمائی کرتا ہے۔ ہم اس پر ایمان ﻻ چکے (اب) ہم ہرگز کسی کو بھی اپنے رب کا شریک نہ بنائیں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdl{اور بیشک ہمارے رب کی شان بڑی بلند ہے نہ اس نے کسی کو (اپنی) بیوی بنایا ہے نہ بیٹا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdli{اور یہ کہ ہم میں کا بیوقوف اللہ کے بارے میں خلاف حق باتیں کہا کرتا تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlii{اور ہم تو یہی سمجھتے رہے کہ ناممکن ہے کہ انسانوں اور جنات اللہ پر جھوٹی باتیں لگائیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliii{بات یہ ہے کہ چند انسان بعض جنات سے پناه طلب کیا کرتے تھے جس سے جنات اپنی سرکشی میں اور بڑھ گئے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliv{اور (انسانوں) نے بھی تم جنوں کی طرح گمان کر لیا تھا کہ اللہ کسی کو نہ بھیجے گا (یا کسی کو دوباره زنده نہ کرے گا)\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlv{اور ہم نے آسمان کو ٹٹول کر دیکھا تو اسے سخت چوکیداروں اور سخت شعلوں سے پر پایا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvi{اس سے پہلے ہم باتیں سننے کے لیے آسمان میں جگہ جگہ بیٹھ جایا کرتے تھے۔ اب جو بھی کان لگاتا ہے وه ایک شعلے کو اپنی تاک میں پاتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvii{ہم نہیں جانتے کہ زمین والوں کے ساتھ کسی برائی کا اراده کیا گیا ہے یا ان کے رب کا اراده ان کے ساتھ بھلائی کا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlviii{اور یہ کہ (بیشک) بعض تو ہم میں نیکو کار ہیں اور بعض اس کے برعکس بھی ہیں، ہم مختلف طریقوں سے بٹے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlix{اور ہم نے سمجھ لیا کہ ہم اللہ تعالیٰ کو زمین میں ہرگز عاجز نہیں کرسکتے اور نہ ہم بھاگ کر اسے ہرا سکتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlx{ہم تو ہدایت کی بات سنتے ہی اس پر ایمان ﻻئے چکے اور جو بھی اپنے رب پر ایمان ﻻئے گا اسے نہ کسی نقصان کا اندیشہ ہے نہ ﻇلم وستم کا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxi{ہاں ہم میں بعض تو مسلمان ہیں اور بعض بےانصاف ہیں پس جو فرماں بردار ہوگئے انہوں نے تو راه راست کا قصد کیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxii{اور جو ﻇالم ہیں وه جہنم کا ایندھن بن گئے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiii{اور (اے نبی یہ بھی کہہ دو) کہ اگر لوگ راه راست پر سیدھے رہتے تو یقیناً ہم انہیں بہت وافر پانی پلاتے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiv{تاکہ ہم اس میں انہیں آزمالیں، اور جو شخص اپنے پروردگار کے ذکر سے منھ پھیر لے گا تو اللہ تعالیٰ اسے سخت عذاب میں مبتلا کردے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxv{اور یہ کہ مسجدیں صرف اللہ ہی کے لئے خاص ہیں پس اللہ تعالیٰ کے ساتھ کسی اور کو نہ پکارو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvi{اور جب اللہ کا بنده اس کی عبادت کے لیے کھڑا ہوا تو قریب تھا کہ وه بھیڑ کی بھیڑ بن کر اس پر پل پڑیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvii{آپ کہہ دیجئے کہ میں تو صرف اپنے رب ہی کو پکارتا ہوں اور اس کے ساتھ کسی کو شریک نہیں کرتا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxviii{کہہ دیجئے کہ مجھے تمہارے کسی نقصان نفع کا اختیار نہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxix{کہہ دیجئے کہ مجھے ہرگز کوئی اللہ سے بچا نہیں سکتا اور میں ہرگز اس کے سوا کوئی جائے پناه بھی پا نہیں سکتا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxx{البتہ (میرا کام) اللہ کی بات اور اس کے پیغامات (لوگوں کو) پہنچا دینا ہے، (اب) جو بھی اللہ اور اس کے رسول کی نہ مانے گا اس کے لیے جہنم کی آگ ہے جس میں ایسے لوگ ہمیشہ رہیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxi{(ان کی آنکھ نہ کھلے گی) یہاں تک کہ اسے دیکھ لیں جس کا ان کو وعده دیا جاتا ہے پس عنقریب جان لیں گے کہ کس کا مددگار کمزور اور کس کی جماعت کم ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxii{کہہ دیجئے کہ مجھے معلوم نہیں کہ جس کا وعده تم سے کیا جاتا ہے وه قریب ہے یا میرا رب اس کے لیے دور کی مدت مقرر کرے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiii{وه غیب کا جاننے واﻻ ہے اور اپنے غیب پر کسی کو مطلع نہیں کرتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiv{سوائے اس پیغمبر کے جسے وه پسند کرلے لیکن اس کے بھی آگے پیچھے پہرے دار مقرر کردیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxv{تاکہ ان کے اپنے رب کے پیغام پہنچا دینے کا علم ہو جائے اللہ تعالیٰ نے ان کے آس پاس (کی تمام چیزوں) کا احاطہ کر رکھا ہے اور ہر چیز کی گنتی شمار کر رکھا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvi{\basmalahur اے کپڑے میں لپٹنے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvii{رات (کے وقت نماز) میں کھڑے ہوجاؤ مگر کم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxviii{آدھی رات یا اس سے بھی کچھ کم کرلے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxix{یا اس پر بڑھا دے اور قرآن کو ٹھہر ٹھہر کر (صاف) پڑھا کر\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxx{یقیناً ہم تجھ پر بہت بھاری بات عنقریب نازل کریں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxi{بیشک رات کا اٹھنا دل جمعی کے لیے انتہائی مناسب ہے اور بات کو بہت درست کر دینے واﻻ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxii{یقیناً تجھے دن میں بہت شغل رہتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiii{تو اپنے رب کے نام کا ذکر کیا کر اور تمام خلائق سے کٹ کر اس کی طرف متوجہ ہوجا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiv{مشرق ومغرب کا پروردگار جس کے سوا کوئی معبود نہیں، تو اسی کو اپنا کار ساز بنالے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxv{اور جو کچھ وه کہیں تو سہتا ره اور وضعداری کے ساتھ ان سے الگ تھلگ ره\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvi{اور مجھے اور ان جھٹلانے والے آسوده حال لوگوں کو چھوڑ دے اور انہیں ذرا سی مہلت دے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvii{یقیناً ہمارے ہاں سخت بیڑیاں ہیں اور سلگتی ہوئی جہنم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxviii{اور حلق میں اٹکنے واﻻ کھانا ہے اور درد دینے واﻻ عذاب ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxix{جس دن زمین اور پہاڑ تھرتھرا جائیں گے اور پہاڑ مثل بھربھری ریت کے ٹیلوں کے ہوجائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxc{بیشک ہم نے تمہاری طرف بھی تم پر گواہی دینے واﻻ رسول بھیج دیا ہے جیسے کہ ہم نے فرعون کے پاس رسول بھیجا تھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxci{تو فرعون نے اس رسول کی نافرمانی کی تو ہم نے اسے سخت (وبال کی) پکڑ میں پکڑ لیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcii{تم اگر کافر رہے تو اس دن کیسے پناه پاؤ گے جو دن بچوں کو بوڑھا کردے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciii{جس دن آسمان پھٹ جائے گا اللہ تعالیٰ کا یہ وعده ہو کر ہی رہنے واﻻ ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciv{بیشک یہ نصیحت ہے پس جو چاہے اپنے رب کی طرف راه اختیار کرے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcv{آپ کا رب بخوبی جانتا ہے کہ آپ اور آپ کے ساتھ کے لوگوں کی ایک جماعت قریب دو تہائی رات کے اور آدھی رات کے اور ایک تہائی رات کے تہجد پڑھتی ہے اور رات دن کا پورا اندازه اللہ تعالیٰ کو ہی ہے، وه (خوب) جانتا ہے کہ تم اسے ہرگز نہ نبھا سکو گے پس اس نے تم پر مہربانی کی لہٰذا جتنا قرآن پڑھنا تمہارے لیے آسان ہو اتنا ہی پڑھو، وه جانتا ہے کہ تم میں بعض بیمار بھی ہوں گے، بعض دوسرے زمین میں چل پھر کر اللہ تعالیٰ کا فضل (یعنی روزی بھی) تلاش کریں گے اور کچھ لوگ اللہ تعالیٰ کی راه میں جہاد بھی کریں گے، سو تم بہ آسانی جتنا قرآن پڑھ سکو پڑھو اور نماز کی پابندی رکھو اور زکوٰة دیتے رہا کرو اور اللہ تعالیٰ کو اچھا قرض دو۔ اور جو نیکی تم اپنے لیے آگے بھیجو گے اسے اللہ تعالیٰ کے ہاں بہتر سے بہتر اور ﺛواب میں بہت زیاده پاؤ گے اللہ تعالیٰ سے معافی مانگتے رہو۔ یقیناً اللہ تعالیٰ بخشنے واﻻ مہربان ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvi{\basmalahur اے کپڑا اوڑھنے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvii{کھڑا ہوجا اور آگاه کردے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcviii{اور اپنے رب ہی کی بڑائیاں بیان کر\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcix{اپنے کپڑوں کو پاک رکھا کر\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmd{ناپاکی کو چھوڑ دے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdi{اور احسان کرکے زیاده لینے کی خواہش نہ کر\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdii{اور اپنے رب کی راه میں صبر کر\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiii{پس جب کہ صور میں پھونک ماری جائے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiv{تو وه دن بڑا سخت دن ہوگا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdv{جو کافروں پر آسان نہ ہوگا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvi{مجھے اور اسے چھوڑ دے جسے میں نے اکیلا پیدا کیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvii{اور اسے بہت سا مال دے رکھا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdviii{اور حاضر باش فرزند بھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdix{اور میں نے اسے بہت کچھ کشادگی دے رکھی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdx{پھر بھی اس کی چاہت ہے کہ میں اسے اور زیاده دوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxi{نہیں نہیں، وه ہماری آیتوں کا مخالف ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxii{عنقریب میں اسے ایک سخت چڑھائی چڑھاؤں گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiii{اس نے غور کرکے تجویز کی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiv{اسے ہلاکت ہو کیسی (تجویز) سوچی؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxv{وه پھر غارت ہو کس طرح اندازه کیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvi{اس نے پھر دیکھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvii{پھر تیوری چڑھائی اور منھ بنایا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxviii{پھر پیچھے ہٹ گیا اور غرور کیا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxix{اور کہنے لگا تو یہ صرف جادو ہے جو نقل کیا جاتا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxx{سوائے انسانی کلام کے کچھ بھی نہیں ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxi{میں عنقریب اسے دوزخ میں ڈالوں گا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxii{اور تجھے کیا خبر کہ دوزخ کیا چیز ہے؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiii{نہ وه باقی رکھتی ہے نہ چھوڑتی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiv{کھال کو جھلسا دیتی ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxv{اور اس میں انیس (فرشتے مقرر) ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvi{ہم نے دوزخ کے داروغے صرف فرشتے رکھے ہیں۔ اور ہم نے ان کی تعداد صرف کافروں کی آزمائش کے لیے مقرر کی ہے تاکہ اہل کتاب یقین کرلیں، اوراہل ایمان کے ایمان میں اضافہ ہو جائے اور اہل کتاب اور اہل ایمان شک نہ کریں اور جن کے دلوں میں بیماری ہے وه اور کافر کہیں کہ اس بیان سے اللہ تعالیٰ کی کیا مراد ہے؟ اسی طرح اللہ تعالیٰ جسے چاہتا ہے گمراه کرتا ہے اور جسے چاہتا ہے ہدایت دیتا ہے۔ تیرے رب کے لشکروں کو اس کے سوا کوئی نہیں جانتا، یہ تو کل بنی آدم کے لیے سراسر پند ونصیحت ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvii{سچ کہتا ہوں قسم ہے چاند کی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxviii{اور رات کی جب وه پیچھے ہٹے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxix{اور صبح کی جب کہ روشن ہو جائے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxx{کہ (یقیناً وه جہنم) بڑی چیزوں میں سے ایک ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxi{بنی آدم کو ڈرانے والی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxii{(یعنی) اسے جو تم میں سے آگے بڑھنا چاہے یا پیچھے ہٹنا چاہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiii{ہر شخص اپنے اعمال کے بدلے میں گروی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiv{مگر دائیں ہاتھ والے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxv{کہ وه بہشتوں میں (بیٹھے ہوئے) گناه گاروں سے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvi{سوال کرتے ہوں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvii{تمہیں دوزخ میں کس چیز نے ڈاﻻ\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxviii{وه جواب دیں گے کہ ہم نمازی نہ تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxix{نہ مسکینوں کو کھانا کھلاتے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxl{اور ہم بحﺚ کرنے والے (انکاریوں) کا ساتھ دے کر بحﺚ مباحثہ میں مشغول رہا کرتے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxli{اور روز جزا کو جھٹلاتے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlii{یہاں تک کہ ہمیں موت آگئی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliii{پس انہیں سفارش کرنے والوں کی سفارش نفع نہ دے گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliv{انہیں کیا ہو گیا ہے؟ کہ نصیحت سے منھ موڑ رہے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlv{گویا کہ وه بِدکے ہوئے گدھے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvi{جو شیر سے بھاگے ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvii{بلکہ ان میں سے ہر شخص چاہتا ہے کہ اسے کھلی ہوئی کتابیں دی جائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlviii{ہرگز ایسا نہیں (ہوسکتا بلکہ) یہ قیامت سے بے خوف ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlix{سچی بات تو یہ ہے کہ یہ (قرآن) ایک نصیحت ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmdl{اب جو چاہے اس سے نصیحت حاصل کرے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmdli{اور وه اس وقت نصیحت حاصل کریں گے جب اللہ تعالیٰ چاہے، وه اسی ﻻئق ہے کہ اس سے ڈریں اور اس ﻻئق بھی کہ وه بخشے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlii{\basmalahur میں قسم کھاتا ہوں قیامت کے دن کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliii{اور قسم کھاتا ہوں اس نفس کی جو ملامت کرنے واﻻ ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliv{کیا انسان یہ خیال کرتا ہے کہ ہم اس کی ہڈیاں جمع کریں گے ہی نہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlv{ہاں ضرور کریں گے ہم تو قادر ہیں کہ اس کی پور پور تک درست کردیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvi{بلکہ انسان تو چاہتا ہے کہ آگے آگے نافرمانیاں کرتا جائے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvii{پوچھتا ہے کہ قیامت کا دن کب آئے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlviii{پس جس وقت کہ نگاه پتھرا جائے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlix{اور چاند بے نور ہو جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlx{اور سورج اور چاند جمع کردیئے جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxi{اس دن انسان کہے گا کہ آج بھاگنے کی جگہ کہاں ہے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxii{نہیں نہیں کوئی پناہ گاه نہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiii{آج تو تیرے پروردگار کی طرف ہی قرار گاه ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiv{آج انسان کو اس کے آگے بھیجے ہوئے اور پیچھے چھوڑے ہوئے سے آگاه کیا جائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxv{بلکہ انسان خود اپنے اوپر آپ حجت ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvi{اگر چہ کتنے ہی بہانے پیش کرے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvii{(اے نبی) آپ قرآن کو جلدی (یاد کرنے) کے لیے اپنی زبان کو حرکت نہ دیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxviii{اس کا جمع کرنا اور (آپ کی زبان سے) پڑھنا ہمارے ذمہ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxix{ہم جب اسے پڑھ لیں تو آپ اس کے پڑھنے کی پیروی کریں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxx{پھر اس کا واضح کر دینا ہمارے ذمہ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxi{نہیں نہیں تم جلدی ملنے والی (دنیا) کی محبت رکھتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxii{اور آخرت کو چھوڑ بیٹھے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiii{اس روز بہت سے چہرے تروتازه اور بارونق ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiv{اپنے رب کی طرف دیکھتے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxv{اور کتنے چہرے اس دن (بد رونق اور) اداس ہوں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvi{سمجھتے ہوں گے کہ ان کے ساتھ کمر توڑ دینے واﻻ معاملہ کیا جائے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvii{نہیں نہیں جب روح ہنسلی تک پہنچے گی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxviii{اور کہا جائے گا کہ کوئی جھاڑ پھونک کرنے واﻻ ہے؟\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxix{اور جان لیا اس نے کہ یہ وقت جدائی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxx{اور پنڈلی سے پنڈلی لپٹ جائے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxi{آج تیرے پروردگار کی طرف چلنا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxii{اس نے نہ تو تصدیق کی نہ نماز ادا کی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiii{بلکہ جھٹلایا اور روگردانی کی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiv{پھر اپنے گھر والوں کے پاس اتراتا ہوا گیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxv{افسوس ہے تجھ پر حسرت ہے تجھ پر\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvi{وائے ہے اور خرابی ہے تیرے لیے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvii{کیا انسان یہ سمجھتا ہے کہ اسے بیکار چھوڑ دیا جائے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxviii{کیا وه ایک گاڑھے پانی کا قطره نہ تھا جو ٹپکایا گیا تھا؟\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxix{پھر وه لہو کا لوتھڑا ہوگیا پھر اللہ نے اسے پیدا کیا اور درست بنا دیا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxc{پھر اس سے جوڑے یعنی نر وماده بنائے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxci{کیا (اللہ تعالیٰ) اس (امر) پر قادر نہیں کہ مردے کو زنده کردے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcii{\basmalahur یقیناً گزرا ہے انسان پر ایک وقت زمانے میں جب کہ یہ کوئی قابل ذکر چیز نہ تھا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciii{بیشک ہم نے انسان کو ملے جلے نطفے سے امتحان کے لیے پیدا کیا اور اس کو سنتا دیکھتا بنایا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciv{ہم نے اسے راه دکھائی اب خواه وه شکر گزار بنے خواه ناشکرا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcv{یقیناً ہم نے کافروں کے لیے زنجیریں اور طوق اور شعلوں والی آگ تیار کر رکھی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvi{بیشک نیک لوگ وه جام پئیں گے جس کی آمیزش کافور کی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvii{جو ایک چشمہ ہے۔ جس سے اللہ کے بندے پئیں گے اس کی نہریں نکال لے جائیں گے (جدھر چاہیں)\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcviii{جو نذر پوری کرتے ہیں اور اس دن سے ڈرتے ہیں جس کی برائی چاروں طرف پھیل جانے والی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcix{اور اللہ تعالیٰ کی محبت میں کھانا کھلاتے ہیں مسکین، یتیم اور قیدیوں کو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdc{ہم تو تمہیں صرف اللہ تعالیٰ کی رضامندی کے لیے کھلاتے ہیں نہ تم سے بدلہ چاہتے ہیں نہ شکر گزاری\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdci{بیشک ہم اپنے پروردگار سے اس دن کا خوف کرتے ہیں جو اداسی اور سختی واﻻ ہوگا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcii{پس انہیں اللہ تعالیٰ نے اس دن کی برائی سے بچا لیا اور انہیں تازگی اور خوشی پہنچائی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciii{اور انہیں ان کے صبر کے بدلے جنت اور ریشمی لباس عطا فرمائے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciv{یہ وہاں تختوں پر تکیے لگائے ہوئے بیٹھیں گے۔ نہ وہاں آفتاب کی گرمی دیکھیں گے نہ جاڑے کی سختی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcv{ان جنتوں کے سائے ان پر جھکے ہوئے ہوں گے اور ان کے (میوے اور) گچھے نیچے لٹکائے ہوئے ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvi{اور ان پر چاندی کے برتنوں اور ان جاموں کا دور کرایا جائے گا جو شیشے کے ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvii{شیشے بھی چاندی کے جن کو (ساقی نے) اندازے سے ناپ رکھا ہوگا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcviii{اور انہیں وہاں وه جام پلائے جائیں گے جن کی آمیزش زنجبیل کی ہوگی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcix{جنت کی ایک نہر سے جس کا نام سلسبیل ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcx{اور ان کے ارد گرد گھومتے پھرتے ہوں گے وه کم سن بچے جو ہمیشہ رہنے والے ہیں جب تو انہیں دیکھے تو سمجھے کہ وه بکھرے ہوئے سچے موتی ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxi{تو وہاں جہاں کہیں بھی نظر ڈالے گا سراسر نعمتیں اور عظیم الشان سلطنت ہی دیکھے گا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxii{ان کے جسموں پر سبز باریک اور موٹے ریشمی کپڑے ہوں گے اور انہیں چاندی کے کنگن کا زیور پہنایا جائے گا۔ اور انہیں ان کا رب پاک صاف شراب پلائے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiii{(کہا جائے گا) کہ یہ ہے تمہارے اعمال کا بدلہ اور تمہاری کوشش کی قدر کی گئی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiv{بیشک ہم نے تجھ پر بتدریج قرآن نازل کیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxv{پس تو اپنے رب کے حکم پر قائم ره اور ان میں سے کسی گنہگار یا ناشکرے کا کہا نہ مان\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvi{اور اپنے رب کے نام کا صبح وشام ذکر کیا کر\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvii{اور رات کے وقت اس کے سامنے سجدے کر اور بہت رات تک اس کی تسبیح کیا کر\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxviii{بیشک یہ لوگ جلدی ملنے والی (دنیا) کو چاہتے ہیں اور اپنے پیچھے ایک بڑے بھاری دن کو چھوڑے دیتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxix{ہم نے انہیں پیدا کیا اور ہم نے ہی ان کے جوڑ اور بندھن مضبوط کیے اور ہم جب چاہیں ان کے عوض ان جیسے اوروں کو بدل ﻻئیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxx{یقیناً یہ تو ایک نصیحت ہے پس جو چاہے اپنے رب کی راه لے لے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxi{اور تم نہ چاہو گے مگر یہ کہ اللہ تعالیٰ ہی چاہے بیشک اللہ تعالیٰ علم واﻻ باحکمت ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxii{جسے چاہے اپنی رحمت میں داخل کرلے، اور ﻇالموں کے لیے اس نے دردناک عذاب تیار کر رکھا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiii{\basmalahur دل خوش کن چلتی ہواؤں کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiv{پھر زور سے جھونکا دینے والیوں کی قسم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxv{پھر (ابر کو) ابھار کر پراگنده کرنے والیوں کی قسم\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvi{پھر حق وباطل کو جدا جدا کر دینے والے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvii{اور وحی ﻻنے والے فرشتوں کی قسم\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxviii{جو (وحی) الزام اتارنے یا آگاه کردینے کے لیے ہوتی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxix{جس چیز کا تم سے وعده کیا جاتا ہے وہ یقیناً ہونے والی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxx{پس جب ستارے بے نور کردئے جائیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxi{اور جب آسمان توڑ پھوڑ دیا جائے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxii{اور جب پہاڑ ٹکڑے ٹکڑے کر کے اڑا دیئے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiii{اور جب رسولوں کو وقت مقرره پر ﻻیا جائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiv{کس دن کے لیے (ان سب کو) مؤخر کیا گیا ہے؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxv{فیصلے کے دن کے لیے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvi{اور تجھے کیا معلوم کہ فیصلے کا دن کیا ہے؟\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvii{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxviii{کیا ہم نے اگلوں کو ہلاک نہیں کیا؟\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxix{پھر ہم ان کے بعد پچھلوں کو ﻻئے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxl{ہم گنہگاروں کے ساتھ اسی طرح کرتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxli{اس دن جھٹلانے والوں کے لیے ویل (افسوس) ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlii{کیا ہم نے تمہیں حقیر پانی سے (منی سے) پیدا نہیں کیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliii{پھر ہم نے اسے مضبوط ومحفوظ جگہ میں رکھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliv{ایک مقرره وقت تک\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlv{پھر ہم نے اندازه کیا اور ہم کیا خوب اندازه کرنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvi{اس دن تکذیب کرنے والوں کی خرابی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvii{کیا ہم نے زمین کو سمیٹنے والی نہیں بنایا؟\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlviii{زندوں کو بھی اور مردوں کو بھی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlix{اور ہم نے اس میں بلند وبھاری پہاڑ بنادیے اور تمہیں سیراب کرنے واﻻ میٹھا پانی پلایا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcl{اس دن جھٹلانے والوں کے لیے وائے اور افسوس ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcli{اس دوزخ کی طرف جاؤ جسے تم جھٹلاتے رہے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclii{چلو تین شاخوں والے سائے کی طرف\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliii{جو در اصل نہ سایہ دینے واﻻ ہے اور نہ شعلے سے بچاسکتا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliv{یقیناً دوزخ چنگاریاں پھینکتی ہے جو مثل محل کے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclv{گویا کہ وه زرد اونٹ ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvi{آج ان جھٹلانے والوں کی درگت ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvii{آج (کا دن) وه دن ہے کہ یہ بول بھی نہ سکیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclviii{نہ انہیں معذرت کی اجازت دی جائے گی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclix{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclx{یہ ہے فیصلے کا دن ہم نے تمہیں اور اگلوں کو سب کو جمع کرلیا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxi{پس اگر تم مجھ سے کوئی چال چل سکتے ہو تو چل لو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxii{وائے ہے اس دن جھٹلانے والوں کے لیے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiii{بیشک پرہیزگار لوگ سایوں میں ہیں اور بہتے چشموں میں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiv{اور ان میووں میں جن کی وه خواہش کریں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxv{(اے جنتیو!) کھاؤ پیو مزے سےاپنے کیے ہوئے اعمال کے بدلے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvi{یقیناً ہم نیکی کرنے والوں کو اسی طرح جزا دیتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvii{اس دن سچا نہ جاننے والوں کے لیے ویل (افسوس) ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxviii{(اے جھٹلانے والو) تم دنیا میں تھوڑا سا کھا لو اور فائده اٹھا لو بیشک تم گنہگار ہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxix{اس دن جھٹلانے والوں کے لیے سخت ہلاکت ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxx{ان سے جب کہا جاتا ہے کہ رکوع کر لو تو نہیں کرتے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxi{اس دن جھٹلانے والوں کی تباہی ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxii{اب اس قرآن کے بعد کس بات پر ایمان ﻻئیں گے؟\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiii{\basmalahur یہ لوگ کس چیز کے بارے میں پوچھ گچھ کر رہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiv{اس بڑی خبر کے متعلق\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxv{جس کے بارے میں یہ اختلاف کر رہے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvi{یقیناً یہ ابھی جان لیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvii{پھر بالیقین انہیں بہت جلد معلوم ہو جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxviii{کیا ہم نے زمین کو فرش نہیں بنایا؟\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxix{اور پہاڑوں کو میخیں (نہیں بنایا؟)\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxx{اور ہم نے تمہیں جوڑا جوڑا پیدا کیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxi{اور ہم نے تمہاری نیند کو آرام کا سبب بنایا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxii{اور رات کو ہم نے پرده بنایا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiii{اور دن کو ہم نے وقت روزگار بنایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiv{اور تمہارے اوپر ہم نے سات مضبوط آسمان بنائے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxv{اور ایک چمکتا ہوا روشن چراغ (سورج) پیدا کیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvi{اور بدلیوں سے ہم نے بکثرت بہتا ہوا پانی برسایا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvii{تاکہ اس سے اناج اور سبزه اگائیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxviii{اور گھنے باغ (بھی اگائیں)\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxix{بیشک فیصلہ کے دن کا وقت مقرر ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxc{جس دن کہ صور میں پھونکا جائے گا۔ پھر تم فوج در فوج چلے آؤ گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxci{اور آسمان کھول دیا جائے گا تو اس میں دروازے دروازے ہو جائیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcii{اور پہاڑ چلائے جائیں گے پس وه سراب ہو جائیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciii{بیشک دوزخ گھات میں ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciv{سرکشوں کا ٹھکانہ وہی ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcv{اس میں وه مدتوں تک پڑے رہیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvi{نہ کبھی اس میں خنکی کا مزه چکھیں گے، نہ پانی کا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvii{سوائے گرم پانی اور (بہتی) پیﭗ کے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcviii{(ان کو) پورا پورا بدلہ ملے گا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcix{انہیں تو حساب کی توقع ہی نہ تھی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcc{اور بے باکی سے ہماری آیتوں کی تکذیب کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcci{ہم نے ہر ایک چیز کو لکھ کر شمار کر رکھا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccii{اب تم (اپنے کیے کا) مزه چکھو ہم تمہارا عذاب ہی بڑھاتے رہیں گے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciii{یقیناً پرہیزگار لوگوں کے لئے کامیابی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciv{باغات ہیں اور انگور ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccv{اور نوجوان کنواری ہم عمر عورتیں ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvi{اور چھلکتے ہوئے جام شراب ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvii{وہاں نہ تو وه بیہوده باتیں سنیں گے اور نہ جھوٹی باتیں سنیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccviii{(ان کو) تیرے رب کی طرف سے (ان کے نیک اعمال کا) بدلہ ملے گا جو کافی انعام ہوگا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccix{(اس رب کی طرف سے ملے گا جو کہ) آسمانوں کا اور زمین کا اور جو کچھ ان کے درمیان ہے ان کا پروردگار ہے اور بڑی بخشش کرنے واﻻ ہے۔ کسی کو اس سے بات چیت کرنے کا اختیار نہیں ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccx{جس دن روح اور فرشتے صفیں باندھ کر کھڑے ہوں گے تو کوئی کلام نہ کر سکے گا مگر جسے رحمٰن اجازت دے دے اور وه ٹھیک بات زبان سے نکالے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxi{یہ دن حق ہے اب جو چاہے اپنے رب کے پاس (نیک اعمال کر کے) ٹھکانا بنالے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxii{ہم نے تمہیں عنقریب آنے والے عذاب سے ڈرا دیا (اور چوکنا کر دیا) ہے۔ جس دن انسان اپنے ہاتھوں کی کمائی کو دیکھ لے گا اور کافر کہے گا کہ کاش! میں مٹی ہو جاتا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiii{\basmalahur ڈوب کر سختی سے کھینچنے والوں کی قسم!\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiv{بند کھول کر چھڑا دینے والوں کی قسم!\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxv{اور تیرنے پھرنے والوں کی قسم!\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvi{پھر دوڑ کر آگے بڑھنے والوں کی قسم!\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvii{پھر کام کی تدبیر کرنے والوں کی قسم!\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxviii{جس دن کانپنے والی کانپے گی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxix{اس کے بعد ایک پیچھے آنے والی (پیچھے پیچھے) آئے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxx{(بہت سے) دل اس دن دھڑکتے ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxi{جن کی نگاہیں نیچی ہوں گی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxii{کہتے ہیں کہ کیا ہم پہلی کی سی حالت کی طرف پھر لوٹائے جائیں گے؟\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiii{کیا اس وقت جب کہ ہم بوسیده ہڈیاں ہو جائیں گے؟\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiv{کہتے ہیں کہ پھر تو یہ لوٹنا نقصان ده ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxv{(معلوم ہونا چاہئے) وه تو صرف ایک (خوفناک) ڈانٹ ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvi{کہ (جس کے ﻇاہر ہوتے ہی) وه ایک دم میدان میں جمع ہو جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvii{کیا موسیٰ (علیہ السلام) کی خبر تمہیں پہنچی ہے؟\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxviii{جب کہ انہیں ان کے رب نے پاک میدان طویٰ میں پکارا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxix{(کہ) تم فرعون کے پاس جاؤ اس نے سرکشی اختیار کر لی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxx{اس سے کہو کہ کیا تو اپنی درستگی اور اصلاح چاہتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxi{اور یہ کہ میں تجھے تیرے رب کی راه دکھاؤں تاکہ تو (اس سے) ڈرنے لگے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxii{پس اسے بڑی نشانی دکھائی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiii{تو اس نے جھٹلایا اور نافرمانی کی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiv{پھر پلٹا دوڑ دھوپ کرتے ہوئے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxv{پھر سب کو جمع کرکے پکارا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvi{تم سب کا رب میں ہی ہوں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvii{تو (سب سے بلند وباﻻ) اللہ نے بھی اسے آخرت کے اور دنیا کے عذاب میں گرفتار کرلیا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxviii{بیشک اس میں اس شخص کے لئے عبرت ہے جو ڈرے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxix{کیا تمہارا پیدا کرنا زیاده دشوار ہے یا آسمان کا؟ اللہ تعالیٰ نے اسے بنایا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxl{اس کی بلندی اونچی کی پھر اسے ٹھیک ٹھاک کر دیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxli{اسکی رات کو تاریک بنایا اور اس کے دن کو نکالا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlii{اور اس کے بعد زمین کو (ہموار) بچھا دیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliii{اس میں سے پانی اور چاره نکالا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliv{اور پہاڑوں کو (مضبوط) گاڑ دیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlv{یہ سب تمہارے اور تمہارے جانوروں کے فائدے کے لئے (ہیں)\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvi{پس جب وه بڑی آفت (قیامت) آجائے گی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvii{جس دن کہ انسان اپنے کیے ہوئے کاموں کو یاد کرے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlviii{اور (ہر) دیکھنے والے کے سامنے جہنم ﻇاہر کی جائے گی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlix{تو جس (شخص) نے سرکشی کی (ہوگی)\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccl{اور دنیوی زندگی کو ترجیح دی (ہوگی)\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccli{اس کا ٹھکانا جہنم ہی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclii{ہاں جو شخص اپنے رب کے سامنے کھڑے ہونے سے ڈرتا رہا ہوگا اور اپنے نفس کو خواہش سے روکا ہوگا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliii{تو اس کا ٹھکانا جنت ہی ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliv{لوگ آپ سے قیامت کے واقع ہونے کا وقت دریافت کرتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclv{آپ کو اس کے بیان کرنے سے کیا تعلق؟\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvi{اس کے علم کی انتہا تو اللہ کی جانب ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvii{آپ تو صرف اس سے ڈرتے رہنے والوں کو آگاه کرنے والے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclviii{جس روز یہ اسے دیکھ لیں گے تو ایسا معلوم ہوگا کہ صرف دن کا آخری حصہ یا اول حصہ ہی (دنیا میں) رہے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclix{\basmalahur وه ترش رو ہوا اور منھ موڑ لیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclx{(صرف اس لئے) کہ اس کے پاس ایک نابینا آیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxi{تجھے کیا خبر شاید وه سنور جاتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxii{یا نصیحت سنتا اور اسے نصیحت فائده پہنچاتی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiii{جو بے پرواہی کرتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiv{اس کی طرف تو تو پوری توجہ کرتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxv{حاﻻنکہ اس کے نہ سنورنے سے تجھ پر کوئی الزام نہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvi{اور جو شخص تیرے پاس دوڑتا ہوا آتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvii{اور وه ڈر (بھی) رہا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxviii{تو اس سے بےرخی برتتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxix{یہ ٹھیک نہیں قرآن تو نصیحت (کی چیز) ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxx{جو چاہے اس سے نصیحت لے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxi{(یہ تو) پر عظمت صحیفوں میں (ہے)\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxii{جو بلند وباﻻ اور پاک صاف ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiii{ایسے لکھنے والوں کے ہاتھوں میں ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiv{جو بزرگ اور پاکباز ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxv{اللہ کی مار انسان پر کیسا ناشکرا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvi{اسے اللہ نے کس چیز سے پیدا کیا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvii{(اسے) ایک نطفہ سے، پھر اندازه پر رکھا اس کو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxviii{پھر اس کے لئے راستہ آسان کیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxix{پھر اسے موت دی اور پھر قبر میں دفن کیا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxx{پھر جب چاہے گا اسے زنده کر دے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxi{ہرگز نہیں۔ اس نے اب تک اللہ کے حکم کی بجا آوری نہیں کی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxii{انسان کو چاہئے کہ اپنے کھانے کو دیکھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiii{کہ ہم نے خوب پانی برسایا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiv{پھر پھاڑا زمین کو اچھی طرح\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxv{پھر اس میں سے اناج اگائے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvi{اور انگور اور ترکاری\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvii{اور زیتون اور کھجور\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxviii{اور گنجان باغات\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxix{اور میوه اور (گھاس) چاره (بھی اگایا)\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxc{تمہارے استعمال وفائدے کے لئے اور تمہارے چوپایوں کے لئے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxci{پس جب کہ کان بہرے کر دینے والی (قیامت) آجائے گی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcii{اس دن آدمی اپنے بھائی سے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciii{اور اپنی ماں اور اپنے باپ سے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciv{اور اپنی بیوی اور اپنی اوﻻد سے بھاگے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcv{ان میں سے ہر ایک کو اس دن ایسی فکر (دامنگیر) ہوگی جو اس کے لئے کافی ہوگی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvi{اس دن بہت سے چہرے روشن ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvii{(جو) ہنستے ہوئے اور ہشاش بشاش ہوں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcviii{اور بہت سے چہرے اس دن غبار آلود ہوں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcix{جن پر سیاہی چڑھی ہوئی ہوگی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccc{وه یہی کافر بدکردار لوگ ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccci{\basmalahur جب سورج لپیٹ لیا جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccii{اور جب ستارے بے نور ہو جائیں گی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciii{اور جب پہاڑ چلائے جائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciv{اور جب دس ماه کی حاملہ اونٹنیاں چھوڑ دی جائیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccv{اور جب وحشی جانور اکھٹے کیے جائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvi{اور جب سمندر بھڑکائے جائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvii{اور جب جانیں (جسموں سے) ملا دی جائیں گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccviii{اور جب زنده گاڑی ہوئی لڑکی سے سوال کیا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccix{کہ کس گناه کی وجہ سے وه قتل کی گئی؟\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccx{اور جب نامہٴ اعمال کھول دیئے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxi{اور جب آسمان کی کھال اتار لی جائے گی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxii{اور جب جہنم بھڑکائی جائے گی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiii{اور جب جنت نزدیک کر دی جائے گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiv{تو اس دن ہر شخص جان لے گا جو کچھ لے کر آیا ہوگا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxv{میں قسم کھاتا ہوں پیچھے ہٹنے والے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvi{چلنے پھرنے والے چھپنے والے ستاروں کی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvii{اور رات کی جب جانے لگے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxviii{اور صبح کی جب چمکنے لگے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxix{یقیناً یہ ایک بزرگ رسول کا کہا ہوا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxx{جو قوت واﻻ ہے، عرش والے (اللہ) کے نزدیک بلند مرتبہ ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxi{جس کی (آسمانوں میں) اطاعت کی جاتی ہے امین ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxii{اور تمہارا ساتھی دیوانہ نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiii{اس نے اس (فرشتے) کو آسمان کے کھلے کنارے پر دیکھا بھی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiv{اور یہ غیب کی باتوں کو بتلانے میں بخیل بھی نہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxv{اور یہ قرآن شیطان مردود کا کلام نہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvi{پھر تم کہاں جا رہے ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvii{یہ تو تمام جہان والوں کے لئے نصیحت نامہ ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxviii{(بالخصوص) اس کے لئے جو تم میں سے سیدھی راه پر چلنا چاہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxix{اور تم بغیر پروردگار عالم کے چاہے کچھ نہیں چاه سکتے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxx{\basmalahur جب آسمان پھٹ جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxi{اور جب ستارے جھڑ جائیں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxii{اور جب سمندر بہہ نکلیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiii{اور جب قبریں (شق کر کے) اکھاڑ دی جائیں گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiv{(اس وقت) ہر شخص اپنے آگے بھیجے ہوئے اور پیچھے چھوڑے ہوئے (یعنی اگلے پچھلے اعمال) کو معلوم کر لے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxv{اے انسان! تجھے اپنے رب کریم سے کس چیز نے بہکایا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvi{جس (رب نے) تجھے پیدا کیا، پھر ٹھیک ٹھاک کیا، پھر (درست اور) برابر بنایا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvii{جس صورت میں چاہا تجھے جوڑ دیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxviii{ہرگز نہیں بلکہ تم تو جزا وسزا کے دن کو جھٹلاتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxix{یقیناً تم پر نگہبان عزت والے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxl{لکھنے والے مقرر ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxli{جوکچھ تم کرتے ہو وه جانتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlii{یقیناً نیک لوگ (جنت کے عیش وآرام اور) نعمتوں میں ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliii{اور یقیناً بدکار لوگ دوزخ میں ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliv{بدلے والے دن اس میں جائیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlv{وه اس سے کبھی غائب نہ ہونے پائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvi{تجھے کچھ خبر بھی ہے کہ بدلے کا دن کیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvii{میں پھر (کہتا ہوں کہ) تجھے کیا معلوم کہ جزا (اور سزا) کا دن کیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlviii{(وه ہے) جس دن کوئی شخص کسی شخص کے لئے کسی چیز کا مختار نہ ہوگا، اور (تمام تر) احکام اس روز اللہ کے ہی ہوں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlix{\basmalahur بڑی خرابی ہے ناپ تول میں کمی کرنے والوں کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccl{کہ جب لوگوں سے ناپ کر لیتے ہیں تو پورا پورا لیتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccli{اور جب انہیں ناپ کر یا تول کر دیتے ہیں تو کم دیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclii{کیا انہیں اپنے مرنے کے بعد جی اٹھنے کا خیال نہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliii{اس عظیم دن کے لئے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliv{جس دن سب لوگ رب العالمین کے سامنے کھڑے ہوں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclv{یقیناً بدکاروں کا نامہٴ اعمال سِجِّينٌ میں ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvi{تجھے کیا معلوم سِجِّينٌ کیا ہے؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvii{(یہ تو) لکھی ہوئی کتاب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclviii{اس دن جھٹلانے والوں کی بڑی خرابی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclix{جو جزا وسزا کے دن کو جھٹلاتے رہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclx{اسے صرف وہی جھٹلاتا ہےجو حد سے آگے نکل جانے واﻻ (اور) گناه گار ہوتا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxi{جب اس کے سامنے ہماری آیتیں پڑھی جاتی ہیں تو کہہ دیتا ہے کہ یہ اگلوں کے افسانے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxii{یوں نہیں بلکہ ان کے دلوں پر ان کےاعمال کی وجہ سے زنگ (چڑھ گیا) ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiii{ہرگز نہیں یہ لوگ اس دن اپنے رب سےاوٹ میں رکھے جائیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiv{پھر یہ لوگ بالیقین جہنم میں جھونکے جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxv{پھر کہہ دیا جائے گا کہ یہی ہے وه جسے تم جھٹلاتے رہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvi{یقیناً یقیناً نیکو کاروں کا نامہٴ اعمال عِلِّیین میں ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvii{تجھے کیا پتہ کہ عِلِّیین کیا ہے؟\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxviii{(وه تو) لکھی ہوئی کتاب ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxix{مقرب (فرشتے) اس کا مشاہده کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxx{یقیناً نیک لوگ (بڑی) نعمتوں میں ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxi{مسہریوں پر بیٹھے دیکھ رہے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxii{تو ان کے چہروں سے ہی نعمتوں کی تروتازگی پہچان لے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiii{یہ لوگ سربمہر خالص شراب پلائے جائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiv{جس پر مشک کی مہر ہوگی، سبقت لے جانے والوں کو اسی میں سبقت کرنی چاہئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxv{اور اس کی آمیزش تسنیم کی ہوگی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvi{(یعنی) وه چشمہ جس کا پانی مقرب لوگ پیئں گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvii{گنہگار لوگ ایمان والوں کی ہنسی اڑایا کرتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxviii{اور ان کے پاس سے گزرتے ہوئے آپس میں آنکھ کےاشارے کرتے تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxix{اور جب اپنے والوں کی طرف لوٹتے تو دل لگیاں کرتے تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxx{اور جب انہیں دیکھتے تو کہتے یقیناً یہ لوگ گمراه (بے راه) ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxi{یہ ان پر پاسبان بنا کر تو نہیں بھیجے گئے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxii{پس آج ایمان والے ان کافروں پر ہنسیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiii{تختوں پر بیٹھے دیکھ رہے ہوں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiv{کہ اب ان منکروں نے جیسا یہ کرتے تھے پورا پورا بدلہ پالیا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxv{\basmalahur جب آسمان پھٹ جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvi{اور اپنے رب کے حکم پر کان لگائے گا اور اسی کے ﻻئق وه ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvii{اور جب زمین (کھینچ کر) پھیلا دی جائے گی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxviii{اور اس میں جو ہے اسے وه اگل دے گی اور خالی ہو جائے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxix{اور اپنے رب کے حکم پر کان لگائے گی اور اسی کے ﻻئق وه ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxc{اے انسان! تو اپنے رب سے ملنے تک یہ کوشش اور تمام کام اور محنتیں کرکے اس سے ملاقات کرنے واﻻ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxci{تو (اس وقت) جس شخص کے داہنے ہاتھ میں اعمال نامہ دیا جائے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcii{اس کا حساب تو بڑی آسانی سے لیا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciii{اور وه اپنے اہل کی طرف ہنسی خوشی لوٹ آئے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciv{ہاں جس شخص کا اعمال نامہ اس کی پیٹھ کے پیچھے سے دیا جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcv{تو وه موت کو بلانے لگے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvi{اور بھڑکتی ہوئی جہنم میں داخل ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvii{یہ شخص اپنے متعلقین میں (دنیا میں) خوش تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcviii{اس کا خیال تھا کہ اللہ کی طرف لوٹ کر ہی نہ جائے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcix{کیوں نہیں، حاﻻنکہ اس کا رب اسے بخوبی دیکھ رہا تھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcm{مجھے شفق کی قسم! اور رات کی!\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmi{اور اس کی جمع کرده چیزوں کی قسم\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmii{اور چاند کی جب کہ وه کامل ہو جاتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiii{یقیناً تم ایک حالت سے دوسری حالت پر پہنچو گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiv{انہیں کیا ہو گیا کہ ایمان نہیں ﻻتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmv{اور جب ان کے پاس قرآن پڑھا جاتا ہے تو سجده نہیں کرتے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvi{بلکہ جنہوں نے کفر کیا وه جھٹلا رہے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvii{اور اللہ تعالیٰ خوب جانتا ہے جو کچھ یہ دلوں میں رکھتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmviii{انہیں المناک عذابوں کی خوشخبری سنا دو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmix{ہاں ایمان والوں اور نیک اعمال والوں کو بے شمار اور نہ ختم ہونے واﻻ اجر ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmx{\basmalahur برجوں والے آسمان کی قسم!\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxi{وعده کیے ہوئے دن کی قسم!\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxii{حاضر ہونے والے اور حاضر کئے گئے کی قسم!\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiii{﴿کہ﴾ خندقوں والے ہلاک کیے گئے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiv{وه ایک آگ تھی ایندھن والی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxv{جب کہ وه لوگ اس کے آس پاس بیٹھے تھے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvi{اور مسلمانوں کے ساتھ جو کر رہے تھے اس کو اپنے سامنے دیکھ رہے تھے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvii{یہ لوگ ان مسلمانوں (کے کسی اور گناه کا) بدلہ نہیں لے رہے تھے، سوائے اس کے کہ وه اللہ غالب ﻻئق حمد کی ذات پر ایمان ﻻئے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxviii{جس کے لئے آسمان وزمین کا ملک ہے۔ اور اللہ تعالیٰ کے سامنے ہے ہر چیز\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxix{بیشک جن لوگوں نے مسلمان مردوں اور عورتوں کو ستایا پھر توبہ (بھی) نہ کی تو ان کے لئے جہنم کا عذاب ہے اور جلنے کا عذاب ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxx{بیشک ایمان قبول کرنے والوں اور نیک کام کرنے والوں کے لئے وه باغات ہیں۔ جن کے نیچے بہریں بہہ رہی ہیں۔ یہی بڑی کامیابی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxi{یقیناً تیرے رب کی پکڑ بڑی سخت ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxii{وہی پہلی مرتبہ پیدا کرتا ہے اور وہی دوباره پیدا کرے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiii{وه بڑا بخشش کرنے واﻻ اور بہت محبت کرنے واﻻ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiv{عرش کا مالک عظمت واﻻ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxv{جو چاہے اسے کر گزرنے واﻻ ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvi{تجھے لشکروں کی خبر بھی ملی ہے؟\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvii{(یعنی) فرعون اور ﺛمود کی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxviii{(کچھ نہیں) بلکہ کافر تو جھٹلانے میں پڑے ہوئے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxix{اور اللہ تعالیٰ بھی انہیں ہر طرف سے گھیرے ہوئے ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxx{بلکہ یہ قرآن ہے بڑی شان واﻻ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxi{لوح محفوظ میں (لکھا ہوا)\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxii{\basmalahur قسم ہے آسمان کی اور اندھیرے میں روشن ہونے والے کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiii{تجھے معلوم بھی ہے کہ وه رات کو نمودار ہونے والی چیز کیا ہے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiv{وه روشن ستاره ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxv{کوئی ایسا نہیں جس پر نگہبان فرشتہ نہ ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvi{انسان کو دیکھنا چاہئے کہ وه کس چیز سے پیدا کیا گیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvii{وه ایک اچھلتے پانی سے پیدا کیا گیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxviii{جو پیٹھ اور سینے کے درمیان سے نکلتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxix{بیشک وه اسے پھیر ﻻنے پر یقیناً قدرت رکھنے واﻻ ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxl{جس دن پوشیده بھیدوں کی جانچ پڑتال ہوگی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxli{تو نہ ہوگا اس کے پاس کچھ زور نہ مدددگار\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlii{بارش والے آسمان کی قسم!\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliii{اور پھٹنے والی زمین کی قسم!\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliv{بیشک یہ (قرآن) البتہ دو ٹوک فیصلہ کرنے واﻻ کلام ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlv{یہ ہنسی کی (اور بے فائده) بات نہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvi{البتہ کافر داؤ گھات میں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvii{اور میں بھی ایک چال چل رہا ہوں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlviii{تو کافروں کو مہلت دے انہیں تھوڑے دنوں چھوڑ دے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlix{\basmalahur اپنے بہت ہی بلند اللہ کے نام کی پاکیزگی بیان کر\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcml{جس نے پیدا کیا اور صحیح سالم بنایا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmli{اور جس نے (ٹھیک ٹھاک) اندازه کیا اور پھر راه دکھائی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlii{اور جس نے تازه گھاس پیدا کی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliii{پھر اس نے اس کو (سکھا کر) سیاه کوڑا کر دیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliv{ہم تجھے پڑھائیں گے پھر تو نہ بھولے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlv{مگر جو کچھ اللہ چاہے۔ وه ﻇاہر اور پوشیده کو جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvi{ہم آپ کے لئے آسانی پیدا کر دیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvii{تو آپ نصیحت کرتے رہیں اگر نصیحت کچھ فائده دے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlviii{ڈرنے واﻻ تو نصیحت لے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlix{(ہاں) بد بخت اس سے گریز کرے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlx{جو بڑی آگ میں جائے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxi{جہاں پھر نہ وه مرے گا نہ جیے گا، (بلکہ حالت نزع میں پڑا رہے گا)\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxii{بیشک اس نے فلاح پالی جو پاک ہوگیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiii{اور جس نے اپنے رب کا نام یاد رکھا اور نماز پڑھتا رہا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiv{لیکن تم تو دنیا کی زندگی کو ترجیح دیتے ہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxv{اور آخرت بہت بہتر اور بہت بقا والی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvi{یہ باتیں پہلی کتابوں میں بھی ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvii{(یعنی) ابراہیم اور موسیٰ کی کتابوں میں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxviii{\basmalahur کیا تجھے بھی چھپا لینے والی (قیامت) کی خبر پہنچی ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxix{اس دن بہت سے چہرے ذلیل ہوں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxx{(اور) محنت کرنے والے تھکے ہوئے ہوں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxi{وه دہکتی ہوئی آگ میں جائیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxii{اور نہایت گرم چشمے کا پانی ان کو پلایا جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiii{ان کے لئے سوائے کانٹے دار درختوں کے اور کچھ کھانے کو نہ ہوگا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiv{جو نہ موٹا کرے گا نہ بھوک مٹائے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxv{بہت سے چہرے اس دن تروتازه اور (آسوده حال) ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvi{اپنی کوشش پر خوش ہوں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvii{بلند وباﻻ جنتوں میں ہوں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxviii{جہاں کوئی بیہوده بات نہیں سنیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxix{جہاں بہتا ہوا چشمہ ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxx{(اور) اس میں اونچے اونچے تخت ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxi{اور آبخورے رکھے ہوئے (ہوں گے)\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxii{اور ایک قطار میں لگے ہوئے تکیے ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiii{اور مخملی مسندیں پھیلی پڑی ہوں گی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiv{کیا یہ اونٹوں کو نہیں دیکھتے کہ وه کس طرح پیدا کیے گئے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxv{اور آسمان کو کہ کس طرح اونچا کیا گیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvi{اور پہاڑوں کی طرف کہ کس طرح گاڑ دیئے گئے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvii{اور زمین کی طرف کہ کس طرح بچھائی گئی ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxviii{پس آپ نصیحت کر دیا کریں (کیونکہ) آپ صرف نصیحت کرنے والے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxix{آپ کچھ ان پر داروغہ نہیں ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxc{ہاں! جو شخص روگردانی کرے اور کفر کرے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxci{اسے اللہ تعالیٰ بہت بڑا عذاب دے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcii{بیشک ہماری طرف ان کا لوٹنا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciii{پھر بیشک ہمارے ذمہ ہے ان سے حساب لینا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciv{\basmalahur قسم ہے فجر کی!\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcv{اور دس راتوں کی!\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvi{اور جفت اور طاق کی!\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvii{اور رات کی جب وه چلنے لگے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcviii{کیا ان میں عقلمند کے واسطے کافی قسم ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcix{کیا آپ نے نہیں دیکھا کہ آپ کے رب نے عادیوں کے ساتھ کیا کیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmm{ستونوں والے ارم کے ساتھ\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmi{جس کی مانند (کوئی قوم) ملکوں میں پیدا نہیں کی گئی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmii{اور ﺛمودیوں کے ساتھ جنہوں نے وادی میں بڑے بڑے پتھر تراشے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiii{اور فرعون کے ساتھ جو میخوں واﻻ تھا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiv{ان سبھوں نے شہروں میں سر اٹھا رکھا تھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmv{اور بہت فساد مچا رکھا تھا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvi{آخر تیرے رب نے ان سب پر عذاب کا کوڑا برسایا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvii{یقیناً تیرا رب گھات میں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmviii{انسان (کا یہ حال ہے کہ) جب اسے اس کا رب آزماتا ہے اور عزت ونعمت دیتا ہے تو وه کہنے لگتا ہے کہ میرے رب نے مجھے عزت دار بنایا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmix{اور جب وه اس کو آزماتا ہے اس کی روزی تنگ کر دیتا ہے تو وه کہنے لگتا ہے کہ میرے رب نے میری اہانت کی (اور ذلیل کیا)\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmx{ایسا ہرگز نہیں بلکہ (بات یہ ہے) کہ تم (ہی) لوگ یتیموں کی عزت نہیں کرتے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxi{اور مسکینوں کے کھلانے کی ایک دوسرے کو ترغیب نہیں دیتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxii{اور (مردوں کی) میراث سمیٹ سمیٹ کر کھاتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiii{اور مال کو جی بھر کر عزیز رکھتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiv{یقیناً جس وقت زمین کوٹ کوٹ کر برابر کر دی جائے گی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxv{اور تیرا رب (خود) آجائے گا اور فرشتے صفیں باندھ کر (آ جائیں گے)\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvi{اور جس دن جہنم بھی ﻻئی جائے گی اس دن انسان کو سمجھ آئے گی مگر آج اس کے سمجھنے کا فائده کہاں؟\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvii{وه کہے گا کہ کاش کہ میں نے اپنی اس زندگی کے لئے کچھ پیشگی سامان کیا ہوتا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxviii{پس آج اللہ کے عذاب جیسا عذاب کسی کا نہ ہوگا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxix{نہ اسکی قید وبند جیسی کسی کی قید وبند ہوگی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxx{اے اطمینان والی روح\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxi{تو اپنے رب کی طرف لوٹ چل اس طرح کہ تو اس سے راضی وه تجھ سے خوش\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxii{پس میرے خاص بندوں میں داخل ہو جا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiii{اور میری جنت میں چلی جا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiv{\basmalahur میں اس شہر کی قسم کھاتا ہوں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxv{اور آپ اس شہر میں مقیم ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvi{اور (قسم ہے) انسانی باپ اور اوﻻد کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvii{یقیناً ہم نے انسان کو (بڑی) مشقت میں پیدا کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxviii{کیا یہ گمان کرتا ہے کہ یہ کسی کے بس میں ہی نہیں؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxix{کہتا (پھرتا) ہے کہ میں نے تو بہت کچھ مال خرچ کر ڈاﻻ\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxx{کیا (یوں) سمجھتا ہے کہ کسی نے اسے دیکھا (ہی) نہیں؟\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxi{کیا ہم نے اس کی دو آنکھیں نہیں بنائیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxii{اور زبان اور ہونٹ (نہیں بنائے)\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiii{ہم نے دکھا دیئے اس کو دونوں راستے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiv{سو اس سے نہ ہو سکا کہ گھاٹی میں داخل ہوتا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxv{اور کیا سمجھا کہ گھاٹی ہے کیا؟\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvi{کسی گردن (غلام لونڈی) کو آزاد کرنا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvii{یا بھوک والے دن کھانا کھلانا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxviii{کسی رشتہ دار یتیم کو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxix{یا خاکسار مسکین کو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxl{پھر ان لوگوں میں سے ہو جاتا جو ایمان ﻻتے اور ایک دوسرے کو صبر کی اور رحم کرنے کی وصیت کرتے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxli{یہی لوگ ہیں دائیں بازو والے (خوش بختی والے)\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlii{اور جن لوگوں نے ہماری آیتوں کے ساتھ کفر کیا یہ کم بختی والے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliii{انہی پر آگ ہوگی جو چاروں طرف سے گھیری ہوئی ہوگی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliv{\basmalahur قسم ہے سورج کی اور اس کی دھوپ کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlv{قسم ہے چاند کی جب اس کے پیچھے آئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvi{قسم ہے دن کی جب سورج کو نمایاں کرے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvii{قسم ہے رات کی جب اسے ڈھانﭗ لے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlviii{قسم ہے آسمان کی اور اس کے بنانے کی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlix{قسم ہے زمین کی اور اسے ہموار کرنے کی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmml{قسم ہے نفس کی اور اسے درست بنانے کی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmli{پھر سمجھ دی اس کو بدکاری کی اور بچ کر چلنے کی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlii{جس نے اسے پاک کیا وه کامیاب ہوا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliii{اور جس نے اسے خاک میں ملا دیا وه ناکام ہوا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliv{(قوم) ﺛمود نے اپنی سرکشی کے باعﺚ جھٹلایا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlv{جب ان میں کا بڑا بدبخت اٹھ کھڑا ہوا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvi{انہیں اللہ کے رسول نے فرما دیا تھا کہ اللہ تعالیٰ کی اونٹنی اور اس کے پینے کی باری کی (حفاﻇت کرو)\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvii{ان لوگوں نے اپنے پیغمبر کو جھوٹا سمجھ کر اس اونٹنی کی کوچیں کاٹ دیں، پس ان کے رب نے ان کے گناہوں کے باعﺚ ان پر ہلاکت ڈالی اور پھر ہلاکت کو عام کر دیا اور اس بستی کو برابر کردیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlviii{وه نہیں ڈرتا اس کے تباه کن انجام سے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlix{\basmalahur قسم ہے اس رات کی جب چھا جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlx{اور قسم ہے دن کی جب روشن ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxi{اور قسم ہے اس ذات کی جس نے نر وماده کو پیدا کیا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxii{یقیناً تمہاری کوشش مختلف قسم کی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiii{جس نے دیا (اللہ کی راه میں) اور ڈرا (اپنے رب سے)\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiv{اور نیک بات کی تصدیق کرتا رہے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxv{تو ہم بھی اس کو آسان راستے کی سہولت دیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvi{لیکن جس نے بخیلی کی اور بے پرواہی برتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvii{اور نیک بات کی تکذیب کی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxviii{تو ہم بھی اس کی تنگی ومشکل کے سامان میسر کر دیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxix{اس کا مال اسے (اوندھا) گرنے کے وقت کچھ کام نہ آئے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxx{بیشک راه دکھا دینا ہمارے ذمہ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxi{اور ہمارے ہی ہاتھ آخرت اور دنیا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxii{میں نے تو تمہیں شعلے مارتی ہوئی آگ سے ڈرا دیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiii{جس میں صرف وہی بدبخت داخل ہوگا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiv{جس نے جھٹلایا اور (اس کی پیروی سے) منھ پھیر لیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxv{اور اس سے ایسا شخص دور رکھا جائے گا جو بڑا پرہیزگار ہو گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvi{جو پاکی حاصل کرنے کے لئے اپنا مال دیتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvii{کسی کا اس پر کوئی احسان نہیں کہ جس کا بدلہ دیا جا رہا ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxviii{بلکہ صرف اپنے پروردگار بزرگ وبلند کی رضا چاہنے کے لئے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxix{یقیناً وه (اللہ بھی) عنقریب رضامند ہو جائے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxx{\basmalahur قسم ہے چاشت کے وقت کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxi{اور قسم ہے رات کی جب چھا جائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxii{نہ تو تیرے رب نے تجھے چھوڑا ہے اور نہ وه بیزار ہو گیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiii{یقیناً تیرے لئے انجام آغاز سے بہتر ہوگا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiv{تجھے تیرا رب بہت جلد (انعام) دے گا اور تو راضی (وخوش) ہو جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxv{کیا اس نے تجھے یتیم پا کر جگہ نہیں دی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvi{اور تجھے راه بھوﻻ پا کر ہدایت نہیں دی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvii{اور تجھے نادار پاکر تونگر نہیں بنا دیا؟\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxviii{پس یتیم پر تو بھی سختی نہ کیا کر\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxix{اور نہ سوال کرنے والے کو ڈانٹ ڈپٹ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxc{اور اپنے رب کی نعمتوں کو بیان کرتا ره\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxci{\basmalahur کیا ہم نے تیرا سینہ نہیں کھول دیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcii{اور تجھ پر سے تیرا بوجھ ہم نے اتار دیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciii{جس نے تیری پیٹھ توڑ دی تھی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciv{اور ہمنے تیرا ذکر بلند کر دیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcv{پس یقیناً مشکل کے ساتھ آسانی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvi{بیشک مشکل کے ساتھ آسانی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvii{پس جب تو فارغ ہو تو عبادت میں محنت کر\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcviii{اور اپنے پروردگار ہی کی طرف دل لگا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcix{\basmalahur قسم ہے انجیر کی اور زیتون کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmc{اور طور سِینِین کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmci{اور اس امن والے شہر کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcii{یقیناً ہم نے انسان کو بہترین صورت میں پیدا کیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciii{پھر اسے نیچوں سے نیچا کر دیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciv{لیکن جو لوگ ایمان ﻻئے اور (پھر) نیک عمل کیے تو ان کے لئے ایسا اجر ہے جو کبھی ختم نہ ہوگا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcv{پس تجھے اب روز جزا کے جھٹلانے پر کون سی چیز آماده کرتی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvi{کیا اللہ تعالیٰ (سب) حاکموں کا حاکم نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvii{\basmalahur پڑھ اپنے رب کے نام سے جس نے پیدا کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcviii{جس نے انسان کو خون کے لوتھڑے سے پیدا کیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcix{تو پڑھتا ره تیرا رب بڑے کرم واﻻ ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcx{جس نے قلم کے ذریعے (علم) سکھایا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxi{جس نے انسان کو وه سکھایا جسے وه نہیں جانتا تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxii{سچ مچ انسان تو آپے سے باہر ہو جاتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiii{اس لئے کہ وه اپنے آپ کو بے پروا (یا تونگر) سمجھتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiv{یقیناً لوٹنا تیرے رب کی طرف ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxv{(بھلا) اسے بھی تو نے دیکھا جو بندے کو روکتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvi{جبکہ وه بنده نماز ادا کرتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvii{بھلا بتلا تو اگر وه ہدایت پر ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxviii{یا پرہیز گاری کا حکم دیتا ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxix{بھلا دیکھو تو اگر یہ جھٹلاتا ہو اور منھ پھیرتا ہو تو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxx{کیا اس نے نہیں جانا کہ اللہ تعالیٰ اسے خوب دیکھ رہا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxi{یقیناً اگر یہ باز نہ رہا تو ہم اس کی پیشانی کے بال پکڑ کر گھسیٹیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxii{ایسی پیشانی جو جھوٹی خطا کار ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiii{یہ اپنی مجلس والوں کو بلالے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiv{ہم بھی (دوزخ کے) پیادوں کو بلالیں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxv{خبردار! اس کا کہنا ہرگز نہ ماننا اور سجده کر اور قریب ہو جا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvi{\basmalahur یقیناً ہم نے اسے شب قدر میں نازل فرمایا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvii{تو کیا سمجھا کہ شب قدر کیا ہے؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxviii{شب قدر ایک ہزار مہینوں سے بہتر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxix{اس (میں ہر کام) کے سر انجام دینے کو اپنے رب کے حکم سے فرشتے اور روح (جبرائیل) اترتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxx{یہ رات سراسر سلامتی کی ہوتی ہے اور فجر کے طلوع ہونے تک (رہتی ہے)\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxi{\basmalahur اہل کتاب کے کافر اور مشرک لوگ جب تک کہ ان کے پاس ﻇاہر دلیل نہ آجائے باز رہنے والے نہ تھے (وه دلیل یہ تھی کہ)\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxii{اللہ تعالیٰ کا ایک رسول جو پاک صحیفے پڑھے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiii{جن میں صحیح اور درست احکام ہوں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiv{اہل کتاب اپنے پاس ﻇاہر دلیل آجانے کے بعد ہی (اختلاف میں پڑ کر) متفرق ہوگئے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxv{انہیں اس کے سوا کوئی حکم نہیں دیا گیا کہ صرف اللہ کی عبادت کریں اسی کے لئے دین کو خالص رکھیں۔ ابراہیم حنیف کے دین پر اور نماز کو قائم رکھیں اور زکوٰة دیتے رہیں یہی ہے دین سیدھی ملت کا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvi{بیشک جو لوگ اہل کتاب میں کافر ہوئے اور مشرکین سب دوزخ کی آگ میں (جائیں گے) جہاں وه ہمیشہ (ہمیشہ) رہیں گے۔ یہ لوگ بدترین خلائق ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvii{بیشک جو لوگ ایمان ﻻئےاور نیک عمل کیے یہ لوگ بہترین خلائق ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxviii{ان کا بدلہ ان کے رب کے پاس ہمیشگی والی جنتیں ہیں جن کے نیچے نہریں بہہ رہی ہیں جن میں وه ہمیشہ ہمیشہ رہیں گے۔ اللہ تعالیٰ ان سے راضی ہوا اور یہ اس سے راضی ہوئے۔ یہ ہے اس کے لئے جو اپنے پروردگار سے ڈرے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxix{\basmalahur جب زمین پوری طرح جھنجھوڑ دی جائے گی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxl{اور اپنے بوجھ باہر نکال پھینکے گی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxli{انسان کہنے لگے گا کہ اسے کیا ہوگیا؟\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlii{اس دن زمین اپنی سب خبریں بیان کردے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliii{اس لئے کہ تیرے رب نے اسے حکم دیا ہوگا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliv{اس روز لوگ مختلف جماعتیں ہو کر (واپس) لوٹیں گے تاکہ انہیں ان کے اعمال دکھا دیئے جائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlv{پس جس نے ذره برابر نیکی کی ہوگی وه اسے دیکھ لے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvi{اور جس نے ذره برابر برائی کی ہوگی وه اسے دیکھ لے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvii{\basmalahur ہانپتے ہوئے دوڑنے والے گھوڑوں کی قسم!\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlviii{پھر ٹاپ مار کر آگ جھاڑنے والوں کی قسم!\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlix{پھر صبح کے وقت دھاوا بولنے والوں کی قسم\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcl{پس اس وقت گرد وغبار اڑاتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcli{پھر اسی کے ساتھ فوجیوں کے درمیان گھس جاتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclii{یقیناً انسان اپنے رب کا بڑا ناشکرا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliii{اور یقیناً وه خود بھی اس پر گواه ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliv{یہ مال کی محنت میں بھی بڑا سخت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclv{کیا اسے وه وقت معلوم نہیں جب قبروں میں جو (کچھ) ہے نکال لیا جائے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvi{اور سینوں کی پوشیده باتیں ﻇاہر کر دی جائیں گی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvii{بیشک ان کا رب اس دن ان کے حال سے پورا باخبر ہوگا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclviii{\basmalahur کھڑکھڑا دینے والی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclix{کیا ہے وه کھڑکھڑا دینے والی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclx{تجھے کیا معلوم کہ وه کھڑ کھڑا دینے والی کیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxi{جس دن انسان بکھرے ہوئے پروانوں کی طرح ہو جائیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxii{اور پہاڑ دھنے ہوئے رنگین اون کی طرح ہو جائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiii{پھر جس کے پلڑے بھاری ہوں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiv{وه تو دل پسند آرام کی زندگی میں ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxv{اور جس کے پلڑے ہلکے ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvi{اس کا ٹھکانا ہاویہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvii{تجھے کیا معلوم کہ وه کیا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxviii{وه تند وتیز آگ (ہے)\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxix{\basmalahur زیادتی کی چاہت نے تمہیں غافل کردیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxx{یہاں تک کہ تم قبرستان جا پہنچے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxi{ہرگز نہیں تم عنقریب معلوم کر لو گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxii{ہرگز نہیں پھر تمہیں جلد علم ہو جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiii{ہرگز نہیں اگر تم یقینی طور پر جان لو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiv{تو بیشک تم جہنم دیکھ لو گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxv{اور تم اسے یقین کی آنکھ سے دیکھ لو گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvi{پھر اس دن تم سے ضرور بالضرور نعمتوں کا سوال ہوگا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvii{\basmalahur زمانے کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxviii{بیشک (بالیقین) انسان سرتا سر نقصان میں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxix{سوائے ان لوگوں کے جو ایمان ﻻئے اور نیک عمل کیے اور (جنہوں نے) آپس میں حق کی وصیت کی اور ایک دوسرے کو صبر کی نصیحت کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxx{\basmalahur بڑی خرابی ہے ہر ایسے شخص کی جو عیب ٹٹولنے واﻻ غیبت کرنے واﻻ ہو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxi{جو مال کو جمع کرتا جائے اور گنتا جائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxii{وه سمجھتا ہے کہ اس کا مال اس کے پاس سدا رہے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiii{ہرگز نہیں یہ تو ضرور توڑ پھوڑ دینے والی آگ میں پھینک دیا جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiv{اور تجھے کیا معلوم کہ ایسی آگ کیا ہوگی؟\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxv{وه اللہ تعالیٰ کی سلگائی ہوئی آگ ہوگی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvi{جو دلوں پر چڑھتی چلی جائے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvii{وہ ان پر ہر طرف سے بند کی ہوئی ہوگی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxviii{بڑے بڑے ستونوں میں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxix{\basmalahur کیا تو نے نہ دیکھا کہ تیرے رب نے ہاتھی والوں کے ساتھ کیا کیا؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxc{کیا ان کے مکر کو بےکار نہیں کردیا؟\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxci{اور ان پر پرندوں کے جھنڈ کے جھنڈ بھیج دیئے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcii{جو انہیں مٹی اور پتھر کی کنکریاں مار رہے تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciii{پس انہیں کھائے ہوئے بھوسے کی طرح کردیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciv{\basmalahur قریش کے مانوس کرنے کے لئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcv{(یعنی) انہیں جاڑے اور گرمی کے سفر سے مانوس کرنے کے لئے۔ (اس کے شکریہ میں)\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvi{پس انہیں چاہئے کہ اسی گھر کے رب کی عبادت کرتے رہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvii{جس نے انہیں بھوک میں کھانا دیا اور ڈر (اور خوف) میں امن (وامان) دیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcviii{\basmalahur کیا تو نے (اسے بھی) دیکھا جو (روز) جزا کو جھٹلاتا ہے؟\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcix{یہی وه ہے جو یتیم کو دھکے دیتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcc{اور مسکین کو کھلانے کی ترغیب نہیں دیتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcci{ان نمازیوں کے لئے افسوس (اور ویل نامی جہنم کی جگہ) ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccii{جو اپنی نماز سے غافل ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciii{جو ریاکاری کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciv{اور برتنے کی چیز روکتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccv{\basmalahur یقیناً ہم نے تجھے (حوض) کوﺛر (اور بہت کچھ) دیا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvi{پس تو اپنے رب کے لئے نماز پڑھ اور قربانی کر\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvii{یقیناً تیرا دشمن ہی ﻻوارث اور بے نام ونشان ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccviii{\basmalahur آپ کہہ دیجئے کہ اے کافرو!\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccix{نہ میں عبادت کرتا ہوں اس کی جس کی تم عبادت کرتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccx{نہ تم عبادت کرنے والے ہو اس کی جس کی میں عبادت کرتا ہوں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxi{اور نہ میں عبادت کروں گا جس کی تم عبادت کرتے ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxii{اور نہ تم اس کی عبادت کرنے والے ہو جس کی میں عبادت کر رہا ہوں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiii{تمہارے لئے تمہارا دین ہے اور میرے لئے میرا دین ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiv{\basmalahur جب اللہ کی مدد اور فتح آجائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxv{اور تو لوگوں کو اللہ کے دین میں جوق در جوق آتا دیکھ لے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvi{تو اپنے رب کی تسبیح کرنے لگ حمد کے ساتھ اور اس سے مغفرت کی دعا مانگ، بیشک وه بڑا ہی توبہ قبول کرنے واﻻ ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvii{\basmalahur ابولہب کے دونوں ہاتھ ٹوٹ گئے اور وه (خود) ہلاک ہو گیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxviii{نہ تو اس کا مال اس کے کام آیا اور نہ اس کی کمائی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxix{وه عنقریب بھڑکنے والی آگ میں جائے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxx{اور اس کی بیوی بھی (جائے گی،) جو لکڑیاں ڈھونے والی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxi{اس کی گردن میں پوست کھجور کی بٹی ہوئی رسی ہوگی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxii{\basmalahur آپ کہہ دیجئے کہ وه اللہ تعالیٰ ایک (ہی) ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiii{اللہ تعالیٰ بے نیاز ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiv{نہ اس سے کوئی پیدا ہوا نہ وه کسی سے پیدا ہوا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxv{اور نہ کوئی اس کا ہمسر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvi{\basmalahur آپ کہہ دیجئے! کہ میں صبح کے رب کی پناه میں آتا ہوں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvii{ہر اس چیز کے شر سے جو اس نے پیدا کی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxviii{اور اندھیری رات کی تاریکی کے شر سے جب اس کا اندھیرا پھیل جائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxix{اور گره (لگا کر ان) میں پھونکنے والیوں کے شر سے (بھی)\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxx{اور حسد کرنے والے کی برائی سے بھی جب وه حسد کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxi{\basmalahur آپ کہہ دیجئے! کہ میں لوگوں کے پروردگار کی پناه میں آتا ہوں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxii{لوگوں کے مالک کی (اور)\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiii{لوگوں کے معبود کی (پناه میں)\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiv{وسوسہ ڈالنے والے پیچھے ہٹ جانے والے کے شر سے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxv{جو لوگوں کے سینوں میں وسوسہ ڈالتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxvi{(خواه) وه جن میں سے ہو یا انسان میں سے\qt@no{(6)}}%
%% End of file `qurantext-uriv.translation.def'.
