%% This is file `qurantext-uthmani-min.def',
%% 
%% Copyright © 2015-2021
%% Seiied-Mohammad-Javad Razavian <javadr@gmail.com>
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%% 
%% This work is “author-maintained” (as per LPPL maintenance status).
%% 
%% The Current Maintainer of this work is Seiied-Mohammad-Javad Razavian.
%% 
%% to one who has devoted his life to Quran
%%
\qt@newcmd\qurantext@i{بِسمِ اللَّهِ الرَّحمٰنِ الرَّحيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ii{الحَمدُ لِلَّهِ رَبِّ العٰلَمينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@iii{الرَّحمٰنِ الرَّحيمِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@iv{مٰلِكِ يَومِ الدّينِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@v{إِيّاكَ نَعبُدُ وَإِيّاكَ نَستَعينُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@vi{اهدِنَا الصِّرٰطَ المُستَقيمَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@vii{صِرٰطَ الَّذينَ أَنعَمتَ عَلَيهِم غَيرِ المَغضوبِ عَلَيهِم وَلَا الضّالّينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@viii{\basmalah  الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ix{ذٰلِكَ الكِتٰبُ لا رَيبَ فيهِ هُدًى لِلمُتَّقينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@x{الَّذينَ يُؤمِنونَ بِالغَيبِ وَيُقيمونَ الصَّلوٰةَ وَمِمّا رَزَقنٰهُم يُنفِقونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@xi{وَالَّذينَ يُؤمِنونَ بِما أُنزِلَ إِلَيكَ وَما أُنزِلَ مِن قَبلِكَ وَبِالءاخِرَةِ هُم يوقِنونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@xii{أُولٰئِكَ عَلىٰ هُدًى مِن رَبِّهِم وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@xiii{إِنَّ الَّذينَ كَفَروا سَواءٌ عَلَيهِم ءَأَنذَرتَهُم أَم لَم تُنذِرهُم لا يُؤمِنونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@xiv{خَتَمَ اللَّهُ عَلىٰ قُلوبِهِم وَعَلىٰ سَمعِهِم وَعَلىٰ أَبصٰرِهِم غِشٰوَةٌ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@xv{وَمِنَ النّاسِ مَن يَقولُ ءامَنّا بِاللَّهِ وَبِاليَومِ الءاخِرِ وَما هُم بِمُؤمِنينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@xvi{يُخٰدِعونَ اللَّهَ وَالَّذينَ ءامَنوا وَما يَخدَعونَ إِلّا أَنفُسَهُم وَما يَشعُرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@xvii{فى قُلوبِهِم مَرَضٌ فَزادَهُمُ اللَّهُ مَرَضًا وَلَهُم عَذابٌ أَليمٌ بِما كانوا يَكذِبونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@xviii{وَإِذا قيلَ لَهُم لا تُفسِدوا فِى الأَرضِ قالوا إِنَّما نَحنُ مُصلِحونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@xix{أَلا إِنَّهُم هُمُ المُفسِدونَ وَلٰكِن لا يَشعُرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@xx{وَإِذا قيلَ لَهُم ءامِنوا كَما ءامَنَ النّاسُ قالوا أَنُؤمِنُ كَما ءامَنَ السُّفَهاءُ أَلا إِنَّهُم هُمُ السُّفَهاءُ وَلٰكِن لا يَعلَمونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@xxi{وَإِذا لَقُوا الَّذينَ ءامَنوا قالوا ءامَنّا وَإِذا خَلَوا إِلىٰ شَيٰطينِهِم قالوا إِنّا مَعَكُم إِنَّما نَحنُ مُستَهزِءونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@xxii{اللَّهُ يَستَهزِئُ بِهِم وَيَمُدُّهُم فى طُغيٰنِهِم يَعمَهونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@xxiii{أُولٰئِكَ الَّذينَ اشتَرَوُا الضَّلٰلَةَ بِالهُدىٰ فَما رَبِحَت تِجٰرَتُهُم وَما كانوا مُهتَدينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@xxiv{مَثَلُهُم كَمَثَلِ الَّذِى استَوقَدَ نارًا فَلَمّا أَضاءَت ما حَولَهُ ذَهَبَ اللَّهُ بِنورِهِم وَتَرَكَهُم فى ظُلُمٰتٍ لا يُبصِرونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@xxv{صُمٌّ بُكمٌ عُمىٌ فَهُم لا يَرجِعونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@xxvi{أَو كَصَيِّبٍ مِنَ السَّماءِ فيهِ ظُلُمٰتٌ وَرَعدٌ وَبَرقٌ يَجعَلونَ أَصٰبِعَهُم فى ءاذانِهِم مِنَ الصَّوٰعِقِ حَذَرَ المَوتِ وَاللَّهُ مُحيطٌ بِالكٰفِرينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@xxvii{يَكادُ البَرقُ يَخطَفُ أَبصٰرَهُم كُلَّما أَضاءَ لَهُم مَشَوا فيهِ وَإِذا أَظلَمَ عَلَيهِم قاموا وَلَو شاءَ اللَّهُ لَذَهَبَ بِسَمعِهِم وَأَبصٰرِهِم إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@xxviii{يٰأَيُّهَا النّاسُ اعبُدوا رَبَّكُمُ الَّذى خَلَقَكُم وَالَّذينَ مِن قَبلِكُم لَعَلَّكُم تَتَّقونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@xxix{الَّذى جَعَلَ لَكُمُ الأَرضَ فِرٰشًا وَالسَّماءَ بِناءً وَأَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجَ بِهِ مِنَ الثَّمَرٰتِ رِزقًا لَكُم فَلا تَجعَلوا لِلَّهِ أَندادًا وَأَنتُم تَعلَمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@xxx{وَإِن كُنتُم فى رَيبٍ مِمّا نَزَّلنا عَلىٰ عَبدِنا فَأتوا بِسورَةٍ مِن مِثلِهِ وَادعوا شُهَداءَكُم مِن دونِ اللَّهِ إِن كُنتُم صٰدِقينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@xxxi{فَإِن لَم تَفعَلوا وَلَن تَفعَلوا فَاتَّقُوا النّارَ الَّتى وَقودُهَا النّاسُ وَالحِجارَةُ أُعِدَّت لِلكٰفِرينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@xxxii{وَبَشِّرِ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ أَنَّ لَهُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ كُلَّما رُزِقوا مِنها مِن ثَمَرَةٍ رِزقًا قالوا هٰذَا الَّذى رُزِقنا مِن قَبلُ وَأُتوا بِهِ مُتَشٰبِهًا وَلَهُم فيها أَزوٰجٌ مُطَهَّرَةٌ وَهُم فيها خٰلِدونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@xxxiii{إِنَّ اللَّهَ لا يَستَحيۦ أَن يَضرِبَ مَثَلًا ما بَعوضَةً فَما فَوقَها فَأَمَّا الَّذينَ ءامَنوا فَيَعلَمونَ أَنَّهُ الحَقُّ مِن رَبِّهِم وَأَمَّا الَّذينَ كَفَروا فَيَقولونَ ماذا أَرادَ اللَّهُ بِهٰذا مَثَلًا يُضِلُّ بِهِ كَثيرًا وَيَهدى بِهِ كَثيرًا وَما يُضِلُّ بِهِ إِلَّا الفٰسِقينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@xxxiv{الَّذينَ يَنقُضونَ عَهدَ اللَّهِ مِن بَعدِ ميثٰقِهِ وَيَقطَعونَ ما أَمَرَ اللَّهُ بِهِ أَن يوصَلَ وَيُفسِدونَ فِى الأَرضِ أُولٰئِكَ هُمُ الخٰسِرونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@xxxv{كَيفَ تَكفُرونَ بِاللَّهِ وَكُنتُم أَموٰتًا فَأَحيٰكُم ثُمَّ يُميتُكُم ثُمَّ يُحييكُم ثُمَّ إِلَيهِ تُرجَعونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@xxxvi{هُوَ الَّذى خَلَقَ لَكُم ما فِى الأَرضِ جَميعًا ثُمَّ استَوىٰ إِلَى السَّماءِ فَسَوّىٰهُنَّ سَبعَ سَمٰوٰتٍ وَهُوَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@xxxvii{وَإِذ قالَ رَبُّكَ لِلمَلٰئِكَةِ إِنّى جاعِلٌ فِى الأَرضِ خَليفَةً قالوا أَتَجعَلُ فيها مَن يُفسِدُ فيها وَيَسفِكُ الدِّماءَ وَنَحنُ نُسَبِّحُ بِحَمدِكَ وَنُقَدِّسُ لَكَ قالَ إِنّى أَعلَمُ ما لا تَعلَمونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@xxxviii{وَعَلَّمَ ءادَمَ الأَسماءَ كُلَّها ثُمَّ عَرَضَهُم عَلَى المَلٰئِكَةِ فَقالَ أَنبِـٔونى بِأَسماءِ هٰؤُلاءِ إِن كُنتُم صٰدِقينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@xxxix{قالوا سُبحٰنَكَ لا عِلمَ لَنا إِلّا ما عَلَّمتَنا إِنَّكَ أَنتَ العَليمُ الحَكيمُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@xl{قالَ يٰـٔادَمُ أَنبِئهُم بِأَسمائِهِم فَلَمّا أَنبَأَهُم بِأَسمائِهِم قالَ أَلَم أَقُل لَكُم إِنّى أَعلَمُ غَيبَ السَّمٰوٰتِ وَالأَرضِ وَأَعلَمُ ما تُبدونَ وَما كُنتُم تَكتُمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@xli{وَإِذ قُلنا لِلمَلٰئِكَةِ اسجُدوا لِءادَمَ فَسَجَدوا إِلّا إِبليسَ أَبىٰ وَاستَكبَرَ وَكانَ مِنَ الكٰفِرينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@xlii{وَقُلنا يٰـٔادَمُ اسكُن أَنتَ وَزَوجُكَ الجَنَّةَ وَكُلا مِنها رَغَدًا حَيثُ شِئتُما وَلا تَقرَبا هٰذِهِ الشَّجَرَةَ فَتَكونا مِنَ الظّٰلِمينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@xliii{فَأَزَلَّهُمَا الشَّيطٰنُ عَنها فَأَخرَجَهُما مِمّا كانا فيهِ وَقُلنَا اهبِطوا بَعضُكُم لِبَعضٍ عَدُوٌّ وَلَكُم فِى الأَرضِ مُستَقَرٌّ وَمَتٰعٌ إِلىٰ حينٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@xliv{فَتَلَقّىٰ ءادَمُ مِن رَبِّهِ كَلِمٰتٍ فَتابَ عَلَيهِ إِنَّهُ هُوَ التَّوّابُ الرَّحيمُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@xlv{قُلنَا اهبِطوا مِنها جَميعًا فَإِمّا يَأتِيَنَّكُم مِنّى هُدًى فَمَن تَبِعَ هُداىَ فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@xlvi{وَالَّذينَ كَفَروا وَكَذَّبوا بِـٔايٰتِنا أُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@xlvii{يٰبَنى إِسرٰءيلَ اذكُروا نِعمَتِىَ الَّتى أَنعَمتُ عَلَيكُم وَأَوفوا بِعَهدى أوفِ بِعَهدِكُم وَإِيّٰىَ فَارهَبونِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@xlviii{وَءامِنوا بِما أَنزَلتُ مُصَدِّقًا لِما مَعَكُم وَلا تَكونوا أَوَّلَ كافِرٍ بِهِ وَلا تَشتَروا بِـٔايٰتى ثَمَنًا قَليلًا وَإِيّٰىَ فَاتَّقونِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@xlix{وَلا تَلبِسُوا الحَقَّ بِالبٰطِلِ وَتَكتُمُوا الحَقَّ وَأَنتُم تَعلَمونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@l{وَأَقيمُوا الصَّلوٰةَ وَءاتُوا الزَّكوٰةَ وَاركَعوا مَعَ الرّٰكِعينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@li{أَتَأمُرونَ النّاسَ بِالبِرِّ وَتَنسَونَ أَنفُسَكُم وَأَنتُم تَتلونَ الكِتٰبَ أَفَلا تَعقِلونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@lii{وَاستَعينوا بِالصَّبرِ وَالصَّلوٰةِ وَإِنَّها لَكَبيرَةٌ إِلّا عَلَى الخٰشِعينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@liii{الَّذينَ يَظُنّونَ أَنَّهُم مُلٰقوا رَبِّهِم وَأَنَّهُم إِلَيهِ رٰجِعونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@liv{يٰبَنى إِسرٰءيلَ اذكُروا نِعمَتِىَ الَّتى أَنعَمتُ عَلَيكُم وَأَنّى فَضَّلتُكُم عَلَى العٰلَمينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@lv{وَاتَّقوا يَومًا لا تَجزى نَفسٌ عَن نَفسٍ شَيـًٔا وَلا يُقبَلُ مِنها شَفٰعَةٌ وَلا يُؤخَذُ مِنها عَدلٌ وَلا هُم يُنصَرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@lvi{وَإِذ نَجَّينٰكُم مِن ءالِ فِرعَونَ يَسومونَكُم سوءَ العَذابِ يُذَبِّحونَ أَبناءَكُم وَيَستَحيونَ نِساءَكُم وَفى ذٰلِكُم بَلاءٌ مِن رَبِّكُم عَظيمٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@lvii{وَإِذ فَرَقنا بِكُمُ البَحرَ فَأَنجَينٰكُم وَأَغرَقنا ءالَ فِرعَونَ وَأَنتُم تَنظُرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@lviii{وَإِذ وٰعَدنا موسىٰ أَربَعينَ لَيلَةً ثُمَّ اتَّخَذتُمُ العِجلَ مِن بَعدِهِ وَأَنتُم ظٰلِمونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@lix{ثُمَّ عَفَونا عَنكُم مِن بَعدِ ذٰلِكَ لَعَلَّكُم تَشكُرونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@lx{وَإِذ ءاتَينا موسَى الكِتٰبَ وَالفُرقانَ لَعَلَّكُم تَهتَدونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@lxi{وَإِذ قالَ موسىٰ لِقَومِهِ يٰقَومِ إِنَّكُم ظَلَمتُم أَنفُسَكُم بِاتِّخاذِكُمُ العِجلَ فَتوبوا إِلىٰ بارِئِكُم فَاقتُلوا أَنفُسَكُم ذٰلِكُم خَيرٌ لَكُم عِندَ بارِئِكُم فَتابَ عَلَيكُم إِنَّهُ هُوَ التَّوّابُ الرَّحيمُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@lxii{وَإِذ قُلتُم يٰموسىٰ لَن نُؤمِنَ لَكَ حَتّىٰ نَرَى اللَّهَ جَهرَةً فَأَخَذَتكُمُ الصّٰعِقَةُ وَأَنتُم تَنظُرونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@lxiii{ثُمَّ بَعَثنٰكُم مِن بَعدِ مَوتِكُم لَعَلَّكُم تَشكُرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@lxiv{وَظَلَّلنا عَلَيكُمُ الغَمامَ وَأَنزَلنا عَلَيكُمُ المَنَّ وَالسَّلوىٰ كُلوا مِن طَيِّبٰتِ ما رَزَقنٰكُم وَما ظَلَمونا وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@lxv{وَإِذ قُلنَا ادخُلوا هٰذِهِ القَريَةَ فَكُلوا مِنها حَيثُ شِئتُم رَغَدًا وَادخُلُوا البابَ سُجَّدًا وَقولوا حِطَّةٌ نَغفِر لَكُم خَطٰيٰكُم وَسَنَزيدُ المُحسِنينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@lxvi{فَبَدَّلَ الَّذينَ ظَلَموا قَولًا غَيرَ الَّذى قيلَ لَهُم فَأَنزَلنا عَلَى الَّذينَ ظَلَموا رِجزًا مِنَ السَّماءِ بِما كانوا يَفسُقونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@lxvii{وَإِذِ استَسقىٰ موسىٰ لِقَومِهِ فَقُلنَا اضرِب بِعَصاكَ الحَجَرَ فَانفَجَرَت مِنهُ اثنَتا عَشرَةَ عَينًا قَد عَلِمَ كُلُّ أُناسٍ مَشرَبَهُم كُلوا وَاشرَبوا مِن رِزقِ اللَّهِ وَلا تَعثَوا فِى الأَرضِ مُفسِدينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@lxviii{وَإِذ قُلتُم يٰموسىٰ لَن نَصبِرَ عَلىٰ طَعامٍ وٰحِدٍ فَادعُ لَنا رَبَّكَ يُخرِج لَنا مِمّا تُنبِتُ الأَرضُ مِن بَقلِها وَقِثّائِها وَفومِها وَعَدَسِها وَبَصَلِها قالَ أَتَستَبدِلونَ الَّذى هُوَ أَدنىٰ بِالَّذى هُوَ خَيرٌ اهبِطوا مِصرًا فَإِنَّ لَكُم ما سَأَلتُم وَضُرِبَت عَلَيهِمُ الذِّلَّةُ وَالمَسكَنَةُ وَباءو بِغَضَبٍ مِنَ اللَّهِ ذٰلِكَ بِأَنَّهُم كانوا يَكفُرونَ بِـٔايٰتِ اللَّهِ وَيَقتُلونَ النَّبِيّۦنَ بِغَيرِ الحَقِّ ذٰلِكَ بِما عَصَوا وَكانوا يَعتَدونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@lxix{إِنَّ الَّذينَ ءامَنوا وَالَّذينَ هادوا وَالنَّصٰرىٰ وَالصّٰبِـٔينَ مَن ءامَنَ بِاللَّهِ وَاليَومِ الءاخِرِ وَعَمِلَ صٰلِحًا فَلَهُم أَجرُهُم عِندَ رَبِّهِم وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@lxx{وَإِذ أَخَذنا ميثٰقَكُم وَرَفَعنا فَوقَكُمُ الطّورَ خُذوا ما ءاتَينٰكُم بِقُوَّةٍ وَاذكُروا ما فيهِ لَعَلَّكُم تَتَّقونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@lxxi{ثُمَّ تَوَلَّيتُم مِن بَعدِ ذٰلِكَ فَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ لَكُنتُم مِنَ الخٰسِرينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@lxxii{وَلَقَد عَلِمتُمُ الَّذينَ اعتَدَوا مِنكُم فِى السَّبتِ فَقُلنا لَهُم كونوا قِرَدَةً خٰسِـٔينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@lxxiii{فَجَعَلنٰها نَكٰلًا لِما بَينَ يَدَيها وَما خَلفَها وَمَوعِظَةً لِلمُتَّقينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@lxxiv{وَإِذ قالَ موسىٰ لِقَومِهِ إِنَّ اللَّهَ يَأمُرُكُم أَن تَذبَحوا بَقَرَةً قالوا أَتَتَّخِذُنا هُزُوًا قالَ أَعوذُ بِاللَّهِ أَن أَكونَ مِنَ الجٰهِلينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@lxxv{قالُوا ادعُ لَنا رَبَّكَ يُبَيِّن لَنا ما هِىَ قالَ إِنَّهُ يَقولُ إِنَّها بَقَرَةٌ لا فارِضٌ وَلا بِكرٌ عَوانٌ بَينَ ذٰلِكَ فَافعَلوا ما تُؤمَرونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@lxxvi{قالُوا ادعُ لَنا رَبَّكَ يُبَيِّن لَنا ما لَونُها قالَ إِنَّهُ يَقولُ إِنَّها بَقَرَةٌ صَفراءُ فاقِعٌ لَونُها تَسُرُّ النّٰظِرينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@lxxvii{قالُوا ادعُ لَنا رَبَّكَ يُبَيِّن لَنا ما هِىَ إِنَّ البَقَرَ تَشٰبَهَ عَلَينا وَإِنّا إِن شاءَ اللَّهُ لَمُهتَدونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@lxxviii{قالَ إِنَّهُ يَقولُ إِنَّها بَقَرَةٌ لا ذَلولٌ تُثيرُ الأَرضَ وَلا تَسقِى الحَرثَ مُسَلَّمَةٌ لا شِيَةَ فيها قالُوا الـٰٔنَ جِئتَ بِالحَقِّ فَذَبَحوها وَما كادوا يَفعَلونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@lxxix{وَإِذ قَتَلتُم نَفسًا فَادّٰرَءتُم فيها وَاللَّهُ مُخرِجٌ ما كُنتُم تَكتُمونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@lxxx{فَقُلنَا اضرِبوهُ بِبَعضِها كَذٰلِكَ يُحىِ اللَّهُ المَوتىٰ وَيُريكُم ءايٰتِهِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@lxxxi{ثُمَّ قَسَت قُلوبُكُم مِن بَعدِ ذٰلِكَ فَهِىَ كَالحِجارَةِ أَو أَشَدُّ قَسوَةً وَإِنَّ مِنَ الحِجارَةِ لَما يَتَفَجَّرُ مِنهُ الأَنهٰرُ وَإِنَّ مِنها لَما يَشَّقَّقُ فَيَخرُجُ مِنهُ الماءُ وَإِنَّ مِنها لَما يَهبِطُ مِن خَشيَةِ اللَّهِ وَمَا اللَّهُ بِغٰفِلٍ عَمّا تَعمَلونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@lxxxii{أَفَتَطمَعونَ أَن يُؤمِنوا لَكُم وَقَد كانَ فَريقٌ مِنهُم يَسمَعونَ كَلٰمَ اللَّهِ ثُمَّ يُحَرِّفونَهُ مِن بَعدِ ما عَقَلوهُ وَهُم يَعلَمونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@lxxxiii{وَإِذا لَقُوا الَّذينَ ءامَنوا قالوا ءامَنّا وَإِذا خَلا بَعضُهُم إِلىٰ بَعضٍ قالوا أَتُحَدِّثونَهُم بِما فَتَحَ اللَّهُ عَلَيكُم لِيُحاجّوكُم بِهِ عِندَ رَبِّكُم أَفَلا تَعقِلونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@lxxxiv{أَوَلا يَعلَمونَ أَنَّ اللَّهَ يَعلَمُ ما يُسِرّونَ وَما يُعلِنونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@lxxxv{وَمِنهُم أُمِّيّونَ لا يَعلَمونَ الكِتٰبَ إِلّا أَمانِىَّ وَإِن هُم إِلّا يَظُنّونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@lxxxvi{فَوَيلٌ لِلَّذينَ يَكتُبونَ الكِتٰبَ بِأَيديهِم ثُمَّ يَقولونَ هٰذا مِن عِندِ اللَّهِ لِيَشتَروا بِهِ ثَمَنًا قَليلًا فَوَيلٌ لَهُم مِمّا كَتَبَت أَيديهِم وَوَيلٌ لَهُم مِمّا يَكسِبونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@lxxxvii{وَقالوا لَن تَمَسَّنَا النّارُ إِلّا أَيّامًا مَعدودَةً قُل أَتَّخَذتُم عِندَ اللَّهِ عَهدًا فَلَن يُخلِفَ اللَّهُ عَهدَهُ أَم تَقولونَ عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@lxxxviii{بَلىٰ مَن كَسَبَ سَيِّئَةً وَأَحٰطَت بِهِ خَطيـَٔتُهُ فَأُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@lxxxix{وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ أُولٰئِكَ أَصحٰبُ الجَنَّةِ هُم فيها خٰلِدونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@xc{وَإِذ أَخَذنا ميثٰقَ بَنى إِسرٰءيلَ لا تَعبُدونَ إِلَّا اللَّهَ وَبِالوٰلِدَينِ إِحسانًا وَذِى القُربىٰ وَاليَتٰمىٰ وَالمَسٰكينِ وَقولوا لِلنّاسِ حُسنًا وَأَقيمُوا الصَّلوٰةَ وَءاتُوا الزَّكوٰةَ ثُمَّ تَوَلَّيتُم إِلّا قَليلًا مِنكُم وَأَنتُم مُعرِضونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@xci{وَإِذ أَخَذنا ميثٰقَكُم لا تَسفِكونَ دِماءَكُم وَلا تُخرِجونَ أَنفُسَكُم مِن دِيٰرِكُم ثُمَّ أَقرَرتُم وَأَنتُم تَشهَدونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@xcii{ثُمَّ أَنتُم هٰؤُلاءِ تَقتُلونَ أَنفُسَكُم وَتُخرِجونَ فَريقًا مِنكُم مِن دِيٰرِهِم تَظٰهَرونَ عَلَيهِم بِالإِثمِ وَالعُدوٰنِ وَإِن يَأتوكُم أُسٰرىٰ تُفٰدوهُم وَهُوَ مُحَرَّمٌ عَلَيكُم إِخراجُهُم أَفَتُؤمِنونَ بِبَعضِ الكِتٰبِ وَتَكفُرونَ بِبَعضٍ فَما جَزاءُ مَن يَفعَلُ ذٰلِكَ مِنكُم إِلّا خِزىٌ فِى الحَيوٰةِ الدُّنيا وَيَومَ القِيٰمَةِ يُرَدّونَ إِلىٰ أَشَدِّ العَذابِ وَمَا اللَّهُ بِغٰفِلٍ عَمّا تَعمَلونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@xciii{أُولٰئِكَ الَّذينَ اشتَرَوُا الحَيوٰةَ الدُّنيا بِالءاخِرَةِ فَلا يُخَفَّفُ عَنهُمُ العَذابُ وَلا هُم يُنصَرونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@xciv{وَلَقَد ءاتَينا موسَى الكِتٰبَ وَقَفَّينا مِن بَعدِهِ بِالرُّسُلِ وَءاتَينا عيسَى ابنَ مَريَمَ البَيِّنٰتِ وَأَيَّدنٰهُ بِروحِ القُدُسِ أَفَكُلَّما جاءَكُم رَسولٌ بِما لا تَهوىٰ أَنفُسُكُمُ استَكبَرتُم فَفَريقًا كَذَّبتُم وَفَريقًا تَقتُلونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@xcv{وَقالوا قُلوبُنا غُلفٌ بَل لَعَنَهُمُ اللَّهُ بِكُفرِهِم فَقَليلًا ما يُؤمِنونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@xcvi{وَلَمّا جاءَهُم كِتٰبٌ مِن عِندِ اللَّهِ مُصَدِّقٌ لِما مَعَهُم وَكانوا مِن قَبلُ يَستَفتِحونَ عَلَى الَّذينَ كَفَروا فَلَمّا جاءَهُم ما عَرَفوا كَفَروا بِهِ فَلَعنَةُ اللَّهِ عَلَى الكٰفِرينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@xcvii{بِئسَمَا اشتَرَوا بِهِ أَنفُسَهُم أَن يَكفُروا بِما أَنزَلَ اللَّهُ بَغيًا أَن يُنَزِّلَ اللَّهُ مِن فَضلِهِ عَلىٰ مَن يَشاءُ مِن عِبادِهِ فَباءو بِغَضَبٍ عَلىٰ غَضَبٍ وَلِلكٰفِرينَ عَذابٌ مُهينٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@xcviii{وَإِذا قيلَ لَهُم ءامِنوا بِما أَنزَلَ اللَّهُ قالوا نُؤمِنُ بِما أُنزِلَ عَلَينا وَيَكفُرونَ بِما وَراءَهُ وَهُوَ الحَقُّ مُصَدِّقًا لِما مَعَهُم قُل فَلِمَ تَقتُلونَ أَنبِياءَ اللَّهِ مِن قَبلُ إِن كُنتُم مُؤمِنينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@xcix{وَلَقَد جاءَكُم موسىٰ بِالبَيِّنٰتِ ثُمَّ اتَّخَذتُمُ العِجلَ مِن بَعدِهِ وَأَنتُم ظٰلِمونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@c{وَإِذ أَخَذنا ميثٰقَكُم وَرَفَعنا فَوقَكُمُ الطّورَ خُذوا ما ءاتَينٰكُم بِقُوَّةٍ وَاسمَعوا قالوا سَمِعنا وَعَصَينا وَأُشرِبوا فى قُلوبِهِمُ العِجلَ بِكُفرِهِم قُل بِئسَما يَأمُرُكُم بِهِ إيمٰنُكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@ci{قُل إِن كانَت لَكُمُ الدّارُ الءاخِرَةُ عِندَ اللَّهِ خالِصَةً مِن دونِ النّاسِ فَتَمَنَّوُا المَوتَ إِن كُنتُم صٰدِقينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@cii{وَلَن يَتَمَنَّوهُ أَبَدًا بِما قَدَّمَت أَيديهِم وَاللَّهُ عَليمٌ بِالظّٰلِمينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ciii{وَلَتَجِدَنَّهُم أَحرَصَ النّاسِ عَلىٰ حَيوٰةٍ وَمِنَ الَّذينَ أَشرَكوا يَوَدُّ أَحَدُهُم لَو يُعَمَّرُ أَلفَ سَنَةٍ وَما هُوَ بِمُزَحزِحِهِ مِنَ العَذابِ أَن يُعَمَّرَ وَاللَّهُ بَصيرٌ بِما يَعمَلونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@civ{قُل مَن كانَ عَدُوًّا لِجِبريلَ فَإِنَّهُ نَزَّلَهُ عَلىٰ قَلبِكَ بِإِذنِ اللَّهِ مُصَدِّقًا لِما بَينَ يَدَيهِ وَهُدًى وَبُشرىٰ لِلمُؤمِنينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@cv{مَن كانَ عَدُوًّا لِلَّهِ وَمَلٰئِكَتِهِ وَرُسُلِهِ وَجِبريلَ وَميكىٰلَ فَإِنَّ اللَّهَ عَدُوٌّ لِلكٰفِرينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@cvi{وَلَقَد أَنزَلنا إِلَيكَ ءايٰتٍ بَيِّنٰتٍ وَما يَكفُرُ بِها إِلَّا الفٰسِقونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@cvii{أَوَكُلَّما عٰهَدوا عَهدًا نَبَذَهُ فَريقٌ مِنهُم بَل أَكثَرُهُم لا يُؤمِنونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@cviii{وَلَمّا جاءَهُم رَسولٌ مِن عِندِ اللَّهِ مُصَدِّقٌ لِما مَعَهُم نَبَذَ فَريقٌ مِنَ الَّذينَ أوتُوا الكِتٰبَ كِتٰبَ اللَّهِ وَراءَ ظُهورِهِم كَأَنَّهُم لا يَعلَمونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@cix{وَاتَّبَعوا ما تَتلُوا الشَّيٰطينُ عَلىٰ مُلكِ سُلَيمٰنَ وَما كَفَرَ سُلَيمٰنُ وَلٰكِنَّ الشَّيٰطينَ كَفَروا يُعَلِّمونَ النّاسَ السِّحرَ وَما أُنزِلَ عَلَى المَلَكَينِ بِبابِلَ هٰروتَ وَمٰروتَ وَما يُعَلِّمانِ مِن أَحَدٍ حَتّىٰ يَقولا إِنَّما نَحنُ فِتنَةٌ فَلا تَكفُر فَيَتَعَلَّمونَ مِنهُما ما يُفَرِّقونَ بِهِ بَينَ المَرءِ وَزَوجِهِ وَما هُم بِضارّينَ بِهِ مِن أَحَدٍ إِلّا بِإِذنِ اللَّهِ وَيَتَعَلَّمونَ ما يَضُرُّهُم وَلا يَنفَعُهُم وَلَقَد عَلِموا لَمَنِ اشتَرىٰهُ ما لَهُ فِى الءاخِرَةِ مِن خَلٰقٍ وَلَبِئسَ ما شَرَوا بِهِ أَنفُسَهُم لَو كانوا يَعلَمونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@cx{وَلَو أَنَّهُم ءامَنوا وَاتَّقَوا لَمَثوبَةٌ مِن عِندِ اللَّهِ خَيرٌ لَو كانوا يَعلَمونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@cxi{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَقولوا رٰعِنا وَقولُوا انظُرنا وَاسمَعوا وَلِلكٰفِرينَ عَذابٌ أَليمٌ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@cxii{ما يَوَدُّ الَّذينَ كَفَروا مِن أَهلِ الكِتٰبِ وَلَا المُشرِكينَ أَن يُنَزَّلَ عَلَيكُم مِن خَيرٍ مِن رَبِّكُم وَاللَّهُ يَختَصُّ بِرَحمَتِهِ مَن يَشاءُ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@cxiii{ما نَنسَخ مِن ءايَةٍ أَو نُنسِها نَأتِ بِخَيرٍ مِنها أَو مِثلِها أَلَم تَعلَم أَنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@cxiv{أَلَم تَعلَم أَنَّ اللَّهَ لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَما لَكُم مِن دونِ اللَّهِ مِن وَلِىٍّ وَلا نَصيرٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@cxv{أَم تُريدونَ أَن تَسـَٔلوا رَسولَكُم كَما سُئِلَ موسىٰ مِن قَبلُ وَمَن يَتَبَدَّلِ الكُفرَ بِالإيمٰنِ فَقَد ضَلَّ سَواءَ السَّبيلِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@cxvi{وَدَّ كَثيرٌ مِن أَهلِ الكِتٰبِ لَو يَرُدّونَكُم مِن بَعدِ إيمٰنِكُم كُفّارًا حَسَدًا مِن عِندِ أَنفُسِهِم مِن بَعدِ ما تَبَيَّنَ لَهُمُ الحَقُّ فَاعفوا وَاصفَحوا حَتّىٰ يَأتِىَ اللَّهُ بِأَمرِهِ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@cxvii{وَأَقيمُوا الصَّلوٰةَ وَءاتُوا الزَّكوٰةَ وَما تُقَدِّموا لِأَنفُسِكُم مِن خَيرٍ تَجِدوهُ عِندَ اللَّهِ إِنَّ اللَّهَ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cxviii{وَقالوا لَن يَدخُلَ الجَنَّةَ إِلّا مَن كانَ هودًا أَو نَصٰرىٰ تِلكَ أَمانِيُّهُم قُل هاتوا بُرهٰنَكُم إِن كُنتُم صٰدِقينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cxix{بَلىٰ مَن أَسلَمَ وَجهَهُ لِلَّهِ وَهُوَ مُحسِنٌ فَلَهُ أَجرُهُ عِندَ رَبِّهِ وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cxx{وَقالَتِ اليَهودُ لَيسَتِ النَّصٰرىٰ عَلىٰ شَيءٍ وَقالَتِ النَّصٰرىٰ لَيسَتِ اليَهودُ عَلىٰ شَيءٍ وَهُم يَتلونَ الكِتٰبَ كَذٰلِكَ قالَ الَّذينَ لا يَعلَمونَ مِثلَ قَولِهِم فَاللَّهُ يَحكُمُ بَينَهُم يَومَ القِيٰمَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cxxi{وَمَن أَظلَمُ مِمَّن مَنَعَ مَسٰجِدَ اللَّهِ أَن يُذكَرَ فيهَا اسمُهُ وَسَعىٰ فى خَرابِها أُولٰئِكَ ما كانَ لَهُم أَن يَدخُلوها إِلّا خائِفينَ لَهُم فِى الدُّنيا خِزىٌ وَلَهُم فِى الءاخِرَةِ عَذابٌ عَظيمٌ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cxxii{وَلِلَّهِ المَشرِقُ وَالمَغرِبُ فَأَينَما تُوَلّوا فَثَمَّ وَجهُ اللَّهِ إِنَّ اللَّهَ وٰسِعٌ عَليمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cxxiii{وَقالُوا اتَّخَذَ اللَّهُ وَلَدًا سُبحٰنَهُ بَل لَهُ ما فِى السَّمٰوٰتِ وَالأَرضِ كُلٌّ لَهُ قٰنِتونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cxxiv{بَديعُ السَّمٰوٰتِ وَالأَرضِ وَإِذا قَضىٰ أَمرًا فَإِنَّما يَقولُ لَهُ كُن فَيَكونُ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cxxv{وَقالَ الَّذينَ لا يَعلَمونَ لَولا يُكَلِّمُنَا اللَّهُ أَو تَأتينا ءايَةٌ كَذٰلِكَ قالَ الَّذينَ مِن قَبلِهِم مِثلَ قَولِهِم تَشٰبَهَت قُلوبُهُم قَد بَيَّنَّا الءايٰتِ لِقَومٍ يوقِنونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cxxvi{إِنّا أَرسَلنٰكَ بِالحَقِّ بَشيرًا وَنَذيرًا وَلا تُسـَٔلُ عَن أَصحٰبِ الجَحيمِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cxxvii{وَلَن تَرضىٰ عَنكَ اليَهودُ وَلَا النَّصٰرىٰ حَتّىٰ تَتَّبِعَ مِلَّتَهُم قُل إِنَّ هُدَى اللَّهِ هُوَ الهُدىٰ وَلَئِنِ اتَّبَعتَ أَهواءَهُم بَعدَ الَّذى جاءَكَ مِنَ العِلمِ ما لَكَ مِنَ اللَّهِ مِن وَلِىٍّ وَلا نَصيرٍ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cxxviii{الَّذينَ ءاتَينٰهُمُ الكِتٰبَ يَتلونَهُ حَقَّ تِلاوَتِهِ أُولٰئِكَ يُؤمِنونَ بِهِ وَمَن يَكفُر بِهِ فَأُولٰئِكَ هُمُ الخٰسِرونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cxxix{يٰبَنى إِسرٰءيلَ اذكُروا نِعمَتِىَ الَّتى أَنعَمتُ عَلَيكُم وَأَنّى فَضَّلتُكُم عَلَى العٰلَمينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cxxx{وَاتَّقوا يَومًا لا تَجزى نَفسٌ عَن نَفسٍ شَيـًٔا وَلا يُقبَلُ مِنها عَدلٌ وَلا تَنفَعُها شَفٰعَةٌ وَلا هُم يُنصَرونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cxxxi{وَإِذِ ابتَلىٰ إِبرٰهۦمَ رَبُّهُ بِكَلِمٰتٍ فَأَتَمَّهُنَّ قالَ إِنّى جاعِلُكَ لِلنّاسِ إِمامًا قالَ وَمِن ذُرِّيَّتى قالَ لا يَنالُ عَهدِى الظّٰلِمينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cxxxii{وَإِذ جَعَلنَا البَيتَ مَثابَةً لِلنّاسِ وَأَمنًا وَاتَّخِذوا مِن مَقامِ إِبرٰهۦمَ مُصَلًّى وَعَهِدنا إِلىٰ إِبرٰهۦمَ وَإِسمٰعيلَ أَن طَهِّرا بَيتِىَ لِلطّائِفينَ وَالعٰكِفينَ وَالرُّكَّعِ السُّجودِ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cxxxiii{وَإِذ قالَ إِبرٰهۦمُ رَبِّ اجعَل هٰذا بَلَدًا ءامِنًا وَارزُق أَهلَهُ مِنَ الثَّمَرٰتِ مَن ءامَنَ مِنهُم بِاللَّهِ وَاليَومِ الءاخِرِ قالَ وَمَن كَفَرَ فَأُمَتِّعُهُ قَليلًا ثُمَّ أَضطَرُّهُ إِلىٰ عَذابِ النّارِ وَبِئسَ المَصيرُ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cxxxiv{وَإِذ يَرفَعُ إِبرٰهۦمُ القَواعِدَ مِنَ البَيتِ وَإِسمٰعيلُ رَبَّنا تَقَبَّل مِنّا إِنَّكَ أَنتَ السَّميعُ العَليمُ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cxxxv{رَبَّنا وَاجعَلنا مُسلِمَينِ لَكَ وَمِن ذُرِّيَّتِنا أُمَّةً مُسلِمَةً لَكَ وَأَرِنا مَناسِكَنا وَتُب عَلَينا إِنَّكَ أَنتَ التَّوّابُ الرَّحيمُ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cxxxvi{رَبَّنا وَابعَث فيهِم رَسولًا مِنهُم يَتلوا عَلَيهِم ءايٰتِكَ وَيُعَلِّمُهُمُ الكِتٰبَ وَالحِكمَةَ وَيُزَكّيهِم إِنَّكَ أَنتَ العَزيزُ الحَكيمُ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cxxxvii{وَمَن يَرغَبُ عَن مِلَّةِ إِبرٰهۦمَ إِلّا مَن سَفِهَ نَفسَهُ وَلَقَدِ اصطَفَينٰهُ فِى الدُّنيا وَإِنَّهُ فِى الءاخِرَةِ لَمِنَ الصّٰلِحينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cxxxviii{إِذ قالَ لَهُ رَبُّهُ أَسلِم قالَ أَسلَمتُ لِرَبِّ العٰلَمينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cxxxix{وَوَصّىٰ بِها إِبرٰهۦمُ بَنيهِ وَيَعقوبُ يٰبَنِىَّ إِنَّ اللَّهَ اصطَفىٰ لَكُمُ الدّينَ فَلا تَموتُنَّ إِلّا وَأَنتُم مُسلِمونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cxl{أَم كُنتُم شُهَداءَ إِذ حَضَرَ يَعقوبَ المَوتُ إِذ قالَ لِبَنيهِ ما تَعبُدونَ مِن بَعدى قالوا نَعبُدُ إِلٰهَكَ وَإِلٰهَ ءابائِكَ إِبرٰهۦمَ وَإِسمٰعيلَ وَإِسحٰقَ إِلٰهًا وٰحِدًا وَنَحنُ لَهُ مُسلِمونَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cxli{تِلكَ أُمَّةٌ قَد خَلَت لَها ما كَسَبَت وَلَكُم ما كَسَبتُم وَلا تُسـَٔلونَ عَمّا كانوا يَعمَلونَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cxlii{وَقالوا كونوا هودًا أَو نَصٰرىٰ تَهتَدوا قُل بَل مِلَّةَ إِبرٰهۦمَ حَنيفًا وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cxliii{قولوا ءامَنّا بِاللَّهِ وَما أُنزِلَ إِلَينا وَما أُنزِلَ إِلىٰ إِبرٰهۦمَ وَإِسمٰعيلَ وَإِسحٰقَ وَيَعقوبَ وَالأَسباطِ وَما أوتِىَ موسىٰ وَعيسىٰ وَما أوتِىَ النَّبِيّونَ مِن رَبِّهِم لا نُفَرِّقُ بَينَ أَحَدٍ مِنهُم وَنَحنُ لَهُ مُسلِمونَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cxliv{فَإِن ءامَنوا بِمِثلِ ما ءامَنتُم بِهِ فَقَدِ اهتَدَوا وَإِن تَوَلَّوا فَإِنَّما هُم فى شِقاقٍ فَسَيَكفيكَهُمُ اللَّهُ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cxlv{صِبغَةَ اللَّهِ وَمَن أَحسَنُ مِنَ اللَّهِ صِبغَةً وَنَحنُ لَهُ عٰبِدونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cxlvi{قُل أَتُحاجّونَنا فِى اللَّهِ وَهُوَ رَبُّنا وَرَبُّكُم وَلَنا أَعمٰلُنا وَلَكُم أَعمٰلُكُم وَنَحنُ لَهُ مُخلِصونَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cxlvii{أَم تَقولونَ إِنَّ إِبرٰهۦمَ وَإِسمٰعيلَ وَإِسحٰقَ وَيَعقوبَ وَالأَسباطَ كانوا هودًا أَو نَصٰرىٰ قُل ءَأَنتُم أَعلَمُ أَمِ اللَّهُ وَمَن أَظلَمُ مِمَّن كَتَمَ شَهٰدَةً عِندَهُ مِنَ اللَّهِ وَمَا اللَّهُ بِغٰفِلٍ عَمّا تَعمَلونَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cxlviii{تِلكَ أُمَّةٌ قَد خَلَت لَها ما كَسَبَت وَلَكُم ما كَسَبتُم وَلا تُسـَٔلونَ عَمّا كانوا يَعمَلونَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cxlix{سَيَقولُ السُّفَهاءُ مِنَ النّاسِ ما وَلّىٰهُم عَن قِبلَتِهِمُ الَّتى كانوا عَلَيها قُل لِلَّهِ المَشرِقُ وَالمَغرِبُ يَهدى مَن يَشاءُ إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cl{وَكَذٰلِكَ جَعَلنٰكُم أُمَّةً وَسَطًا لِتَكونوا شُهَداءَ عَلَى النّاسِ وَيَكونَ الرَّسولُ عَلَيكُم شَهيدًا وَما جَعَلنَا القِبلَةَ الَّتى كُنتَ عَلَيها إِلّا لِنَعلَمَ مَن يَتَّبِعُ الرَّسولَ مِمَّن يَنقَلِبُ عَلىٰ عَقِبَيهِ وَإِن كانَت لَكَبيرَةً إِلّا عَلَى الَّذينَ هَدَى اللَّهُ وَما كانَ اللَّهُ لِيُضيعَ إيمٰنَكُم إِنَّ اللَّهَ بِالنّاسِ لَرَءوفٌ رَحيمٌ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cli{قَد نَرىٰ تَقَلُّبَ وَجهِكَ فِى السَّماءِ فَلَنُوَلِّيَنَّكَ قِبلَةً تَرضىٰها فَوَلِّ وَجهَكَ شَطرَ المَسجِدِ الحَرامِ وَحَيثُ ما كُنتُم فَوَلّوا وُجوهَكُم شَطرَهُ وَإِنَّ الَّذينَ أوتُوا الكِتٰبَ لَيَعلَمونَ أَنَّهُ الحَقُّ مِن رَبِّهِم وَمَا اللَّهُ بِغٰفِلٍ عَمّا يَعمَلونَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@clii{وَلَئِن أَتَيتَ الَّذينَ أوتُوا الكِتٰبَ بِكُلِّ ءايَةٍ ما تَبِعوا قِبلَتَكَ وَما أَنتَ بِتابِعٍ قِبلَتَهُم وَما بَعضُهُم بِتابِعٍ قِبلَةَ بَعضٍ وَلَئِنِ اتَّبَعتَ أَهواءَهُم مِن بَعدِ ما جاءَكَ مِنَ العِلمِ إِنَّكَ إِذًا لَمِنَ الظّٰلِمينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cliii{الَّذينَ ءاتَينٰهُمُ الكِتٰبَ يَعرِفونَهُ كَما يَعرِفونَ أَبناءَهُم وَإِنَّ فَريقًا مِنهُم لَيَكتُمونَ الحَقَّ وَهُم يَعلَمونَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cliv{الحَقُّ مِن رَبِّكَ فَلا تَكونَنَّ مِنَ المُمتَرينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@clv{وَلِكُلٍّ وِجهَةٌ هُوَ مُوَلّيها فَاستَبِقُوا الخَيرٰتِ أَينَ ما تَكونوا يَأتِ بِكُمُ اللَّهُ جَميعًا إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@clvi{وَمِن حَيثُ خَرَجتَ فَوَلِّ وَجهَكَ شَطرَ المَسجِدِ الحَرامِ وَإِنَّهُ لَلحَقُّ مِن رَبِّكَ وَمَا اللَّهُ بِغٰفِلٍ عَمّا تَعمَلونَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@clvii{وَمِن حَيثُ خَرَجتَ فَوَلِّ وَجهَكَ شَطرَ المَسجِدِ الحَرامِ وَحَيثُ ما كُنتُم فَوَلّوا وُجوهَكُم شَطرَهُ لِئَلّا يَكونَ لِلنّاسِ عَلَيكُم حُجَّةٌ إِلَّا الَّذينَ ظَلَموا مِنهُم فَلا تَخشَوهُم وَاخشَونى وَلِأُتِمَّ نِعمَتى عَلَيكُم وَلَعَلَّكُم تَهتَدونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@clviii{كَما أَرسَلنا فيكُم رَسولًا مِنكُم يَتلوا عَلَيكُم ءايٰتِنا وَيُزَكّيكُم وَيُعَلِّمُكُمُ الكِتٰبَ وَالحِكمَةَ وَيُعَلِّمُكُم ما لَم تَكونوا تَعلَمونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@clix{فَاذكُرونى أَذكُركُم وَاشكُروا لى وَلا تَكفُرونِ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@clx{يٰأَيُّهَا الَّذينَ ءامَنُوا استَعينوا بِالصَّبرِ وَالصَّلوٰةِ إِنَّ اللَّهَ مَعَ الصّٰبِرينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@clxi{وَلا تَقولوا لِمَن يُقتَلُ فى سَبيلِ اللَّهِ أَموٰتٌ بَل أَحياءٌ وَلٰكِن لا تَشعُرونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@clxii{وَلَنَبلُوَنَّكُم بِشَيءٍ مِنَ الخَوفِ وَالجوعِ وَنَقصٍ مِنَ الأَموٰلِ وَالأَنفُسِ وَالثَّمَرٰتِ وَبَشِّرِ الصّٰبِرينَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@clxiii{الَّذينَ إِذا أَصٰبَتهُم مُصيبَةٌ قالوا إِنّا لِلَّهِ وَإِنّا إِلَيهِ رٰجِعونَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@clxiv{أُولٰئِكَ عَلَيهِم صَلَوٰتٌ مِن رَبِّهِم وَرَحمَةٌ وَأُولٰئِكَ هُمُ المُهتَدونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@clxv{إِنَّ الصَّفا وَالمَروَةَ مِن شَعائِرِ اللَّهِ فَمَن حَجَّ البَيتَ أَوِ اعتَمَرَ فَلا جُناحَ عَلَيهِ أَن يَطَّوَّفَ بِهِما وَمَن تَطَوَّعَ خَيرًا فَإِنَّ اللَّهَ شاكِرٌ عَليمٌ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@clxvi{إِنَّ الَّذينَ يَكتُمونَ ما أَنزَلنا مِنَ البَيِّنٰتِ وَالهُدىٰ مِن بَعدِ ما بَيَّنّٰهُ لِلنّاسِ فِى الكِتٰبِ أُولٰئِكَ يَلعَنُهُمُ اللَّهُ وَيَلعَنُهُمُ اللّٰعِنونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@clxvii{إِلَّا الَّذينَ تابوا وَأَصلَحوا وَبَيَّنوا فَأُولٰئِكَ أَتوبُ عَلَيهِم وَأَنَا التَّوّابُ الرَّحيمُ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@clxviii{إِنَّ الَّذينَ كَفَروا وَماتوا وَهُم كُفّارٌ أُولٰئِكَ عَلَيهِم لَعنَةُ اللَّهِ وَالمَلٰئِكَةِ وَالنّاسِ أَجمَعينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@clxix{خٰلِدينَ فيها لا يُخَفَّفُ عَنهُمُ العَذابُ وَلا هُم يُنظَرونَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@clxx{وَإِلٰهُكُم إِلٰهٌ وٰحِدٌ لا إِلٰهَ إِلّا هُوَ الرَّحمٰنُ الرَّحيمُ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@clxxi{إِنَّ فى خَلقِ السَّمٰوٰتِ وَالأَرضِ وَاختِلٰفِ الَّيلِ وَالنَّهارِ وَالفُلكِ الَّتى تَجرى فِى البَحرِ بِما يَنفَعُ النّاسَ وَما أَنزَلَ اللَّهُ مِنَ السَّماءِ مِن ماءٍ فَأَحيا بِهِ الأَرضَ بَعدَ مَوتِها وَبَثَّ فيها مِن كُلِّ دابَّةٍ وَتَصريفِ الرِّيٰحِ وَالسَّحابِ المُسَخَّرِ بَينَ السَّماءِ وَالأَرضِ لَءايٰتٍ لِقَومٍ يَعقِلونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@clxxii{وَمِنَ النّاسِ مَن يَتَّخِذُ مِن دونِ اللَّهِ أَندادًا يُحِبّونَهُم كَحُبِّ اللَّهِ وَالَّذينَ ءامَنوا أَشَدُّ حُبًّا لِلَّهِ وَلَو يَرَى الَّذينَ ظَلَموا إِذ يَرَونَ العَذابَ أَنَّ القُوَّةَ لِلَّهِ جَميعًا وَأَنَّ اللَّهَ شَديدُ العَذابِ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@clxxiii{إِذ تَبَرَّأَ الَّذينَ اتُّبِعوا مِنَ الَّذينَ اتَّبَعوا وَرَأَوُا العَذابَ وَتَقَطَّعَت بِهِمُ الأَسبابُ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@clxxiv{وَقالَ الَّذينَ اتَّبَعوا لَو أَنَّ لَنا كَرَّةً فَنَتَبَرَّأَ مِنهُم كَما تَبَرَّءوا مِنّا كَذٰلِكَ يُريهِمُ اللَّهُ أَعمٰلَهُم حَسَرٰتٍ عَلَيهِم وَما هُم بِخٰرِجينَ مِنَ النّارِ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@clxxv{يٰأَيُّهَا النّاسُ كُلوا مِمّا فِى الأَرضِ حَلٰلًا طَيِّبًا وَلا تَتَّبِعوا خُطُوٰتِ الشَّيطٰنِ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@clxxvi{إِنَّما يَأمُرُكُم بِالسّوءِ وَالفَحشاءِ وَأَن تَقولوا عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@clxxvii{وَإِذا قيلَ لَهُمُ اتَّبِعوا ما أَنزَلَ اللَّهُ قالوا بَل نَتَّبِعُ ما أَلفَينا عَلَيهِ ءاباءَنا أَوَلَو كانَ ءاباؤُهُم لا يَعقِلونَ شَيـًٔا وَلا يَهتَدونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@clxxviii{وَمَثَلُ الَّذينَ كَفَروا كَمَثَلِ الَّذى يَنعِقُ بِما لا يَسمَعُ إِلّا دُعاءً وَنِداءً صُمٌّ بُكمٌ عُمىٌ فَهُم لا يَعقِلونَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@clxxix{يٰأَيُّهَا الَّذينَ ءامَنوا كُلوا مِن طَيِّبٰتِ ما رَزَقنٰكُم وَاشكُروا لِلَّهِ إِن كُنتُم إِيّاهُ تَعبُدونَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@clxxx{إِنَّما حَرَّمَ عَلَيكُمُ المَيتَةَ وَالدَّمَ وَلَحمَ الخِنزيرِ وَما أُهِلَّ بِهِ لِغَيرِ اللَّهِ فَمَنِ اضطُرَّ غَيرَ باغٍ وَلا عادٍ فَلا إِثمَ عَلَيهِ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@clxxxi{إِنَّ الَّذينَ يَكتُمونَ ما أَنزَلَ اللَّهُ مِنَ الكِتٰبِ وَيَشتَرونَ بِهِ ثَمَنًا قَليلًا أُولٰئِكَ ما يَأكُلونَ فى بُطونِهِم إِلَّا النّارَ وَلا يُكَلِّمُهُمُ اللَّهُ يَومَ القِيٰمَةِ وَلا يُزَكّيهِم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@clxxxii{أُولٰئِكَ الَّذينَ اشتَرَوُا الضَّلٰلَةَ بِالهُدىٰ وَالعَذابَ بِالمَغفِرَةِ فَما أَصبَرَهُم عَلَى النّارِ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@clxxxiii{ذٰلِكَ بِأَنَّ اللَّهَ نَزَّلَ الكِتٰبَ بِالحَقِّ وَإِنَّ الَّذينَ اختَلَفوا فِى الكِتٰبِ لَفى شِقاقٍ بَعيدٍ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@clxxxiv{لَيسَ البِرَّ أَن تُوَلّوا وُجوهَكُم قِبَلَ المَشرِقِ وَالمَغرِبِ وَلٰكِنَّ البِرَّ مَن ءامَنَ بِاللَّهِ وَاليَومِ الءاخِرِ وَالمَلٰئِكَةِ وَالكِتٰبِ وَالنَّبِيّۦنَ وَءاتَى المالَ عَلىٰ حُبِّهِ ذَوِى القُربىٰ وَاليَتٰمىٰ وَالمَسٰكينَ وَابنَ السَّبيلِ وَالسّائِلينَ وَفِى الرِّقابِ وَأَقامَ الصَّلوٰةَ وَءاتَى الزَّكوٰةَ وَالموفونَ بِعَهدِهِم إِذا عٰهَدوا وَالصّٰبِرينَ فِى البَأساءِ وَالضَّرّاءِ وَحينَ البَأسِ أُولٰئِكَ الَّذينَ صَدَقوا وَأُولٰئِكَ هُمُ المُتَّقونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@clxxxv{يٰأَيُّهَا الَّذينَ ءامَنوا كُتِبَ عَلَيكُمُ القِصاصُ فِى القَتلَى الحُرُّ بِالحُرِّ وَالعَبدُ بِالعَبدِ وَالأُنثىٰ بِالأُنثىٰ فَمَن عُفِىَ لَهُ مِن أَخيهِ شَيءٌ فَاتِّباعٌ بِالمَعروفِ وَأَداءٌ إِلَيهِ بِإِحسٰنٍ ذٰلِكَ تَخفيفٌ مِن رَبِّكُم وَرَحمَةٌ فَمَنِ اعتَدىٰ بَعدَ ذٰلِكَ فَلَهُ عَذابٌ أَليمٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@clxxxvi{وَلَكُم فِى القِصاصِ حَيوٰةٌ يٰأُولِى الأَلبٰبِ لَعَلَّكُم تَتَّقونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@clxxxvii{كُتِبَ عَلَيكُم إِذا حَضَرَ أَحَدَكُمُ المَوتُ إِن تَرَكَ خَيرًا الوَصِيَّةُ لِلوٰلِدَينِ وَالأَقرَبينَ بِالمَعروفِ حَقًّا عَلَى المُتَّقينَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@clxxxviii{فَمَن بَدَّلَهُ بَعدَما سَمِعَهُ فَإِنَّما إِثمُهُ عَلَى الَّذينَ يُبَدِّلونَهُ إِنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@clxxxix{فَمَن خافَ مِن موصٍ جَنَفًا أَو إِثمًا فَأَصلَحَ بَينَهُم فَلا إِثمَ عَلَيهِ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@cxc{يٰأَيُّهَا الَّذينَ ءامَنوا كُتِبَ عَلَيكُمُ الصِّيامُ كَما كُتِبَ عَلَى الَّذينَ مِن قَبلِكُم لَعَلَّكُم تَتَّقونَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@cxci{أَيّامًا مَعدودٰتٍ فَمَن كانَ مِنكُم مَريضًا أَو عَلىٰ سَفَرٍ فَعِدَّةٌ مِن أَيّامٍ أُخَرَ وَعَلَى الَّذينَ يُطيقونَهُ فِديَةٌ طَعامُ مِسكينٍ فَمَن تَطَوَّعَ خَيرًا فَهُوَ خَيرٌ لَهُ وَأَن تَصوموا خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@cxcii{شَهرُ رَمَضانَ الَّذى أُنزِلَ فيهِ القُرءانُ هُدًى لِلنّاسِ وَبَيِّنٰتٍ مِنَ الهُدىٰ وَالفُرقانِ فَمَن شَهِدَ مِنكُمُ الشَّهرَ فَليَصُمهُ وَمَن كانَ مَريضًا أَو عَلىٰ سَفَرٍ فَعِدَّةٌ مِن أَيّامٍ أُخَرَ يُريدُ اللَّهُ بِكُمُ اليُسرَ وَلا يُريدُ بِكُمُ العُسرَ وَلِتُكمِلُوا العِدَّةَ وَلِتُكَبِّرُوا اللَّهَ عَلىٰ ما هَدىٰكُم وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@cxciii{وَإِذا سَأَلَكَ عِبادى عَنّى فَإِنّى قَريبٌ أُجيبُ دَعوَةَ الدّاعِ إِذا دَعانِ فَليَستَجيبوا لى وَليُؤمِنوا بى لَعَلَّهُم يَرشُدونَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@cxciv{أُحِلَّ لَكُم لَيلَةَ الصِّيامِ الرَّفَثُ إِلىٰ نِسائِكُم هُنَّ لِباسٌ لَكُم وَأَنتُم لِباسٌ لَهُنَّ عَلِمَ اللَّهُ أَنَّكُم كُنتُم تَختانونَ أَنفُسَكُم فَتابَ عَلَيكُم وَعَفا عَنكُم فَالـٰٔنَ بٰشِروهُنَّ وَابتَغوا ما كَتَبَ اللَّهُ لَكُم وَكُلوا وَاشرَبوا حَتّىٰ يَتَبَيَّنَ لَكُمُ الخَيطُ الأَبيَضُ مِنَ الخَيطِ الأَسوَدِ مِنَ الفَجرِ ثُمَّ أَتِمُّوا الصِّيامَ إِلَى الَّيلِ وَلا تُبٰشِروهُنَّ وَأَنتُم عٰكِفونَ فِى المَسٰجِدِ تِلكَ حُدودُ اللَّهِ فَلا تَقرَبوها كَذٰلِكَ يُبَيِّنُ اللَّهُ ءايٰتِهِ لِلنّاسِ لَعَلَّهُم يَتَّقونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@cxcv{وَلا تَأكُلوا أَموٰلَكُم بَينَكُم بِالبٰطِلِ وَتُدلوا بِها إِلَى الحُكّامِ لِتَأكُلوا فَريقًا مِن أَموٰلِ النّاسِ بِالإِثمِ وَأَنتُم تَعلَمونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@cxcvi{يَسـَٔلونَكَ عَنِ الأَهِلَّةِ قُل هِىَ مَوٰقيتُ لِلنّاسِ وَالحَجِّ وَلَيسَ البِرُّ بِأَن تَأتُوا البُيوتَ مِن ظُهورِها وَلٰكِنَّ البِرَّ مَنِ اتَّقىٰ وَأتُوا البُيوتَ مِن أَبوٰبِها وَاتَّقُوا اللَّهَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@cxcvii{وَقٰتِلوا فى سَبيلِ اللَّهِ الَّذينَ يُقٰتِلونَكُم وَلا تَعتَدوا إِنَّ اللَّهَ لا يُحِبُّ المُعتَدينَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@cxcviii{وَاقتُلوهُم حَيثُ ثَقِفتُموهُم وَأَخرِجوهُم مِن حَيثُ أَخرَجوكُم وَالفِتنَةُ أَشَدُّ مِنَ القَتلِ وَلا تُقٰتِلوهُم عِندَ المَسجِدِ الحَرامِ حَتّىٰ يُقٰتِلوكُم فيهِ فَإِن قٰتَلوكُم فَاقتُلوهُم كَذٰلِكَ جَزاءُ الكٰفِرينَ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@cxcix{فَإِنِ انتَهَوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@cc{وَقٰتِلوهُم حَتّىٰ لا تَكونَ فِتنَةٌ وَيَكونَ الدّينُ لِلَّهِ فَإِنِ انتَهَوا فَلا عُدوٰنَ إِلّا عَلَى الظّٰلِمينَ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@cci{الشَّهرُ الحَرامُ بِالشَّهرِ الحَرامِ وَالحُرُمٰتُ قِصاصٌ فَمَنِ اعتَدىٰ عَلَيكُم فَاعتَدوا عَلَيهِ بِمِثلِ مَا اعتَدىٰ عَلَيكُم وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّ اللَّهَ مَعَ المُتَّقينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@ccii{وَأَنفِقوا فى سَبيلِ اللَّهِ وَلا تُلقوا بِأَيديكُم إِلَى التَّهلُكَةِ وَأَحسِنوا إِنَّ اللَّهَ يُحِبُّ المُحسِنينَ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@cciii{وَأَتِمُّوا الحَجَّ وَالعُمرَةَ لِلَّهِ فَإِن أُحصِرتُم فَمَا استَيسَرَ مِنَ الهَدىِ وَلا تَحلِقوا رُءوسَكُم حَتّىٰ يَبلُغَ الهَدىُ مَحِلَّهُ فَمَن كانَ مِنكُم مَريضًا أَو بِهِ أَذًى مِن رَأسِهِ فَفِديَةٌ مِن صِيامٍ أَو صَدَقَةٍ أَو نُسُكٍ فَإِذا أَمِنتُم فَمَن تَمَتَّعَ بِالعُمرَةِ إِلَى الحَجِّ فَمَا استَيسَرَ مِنَ الهَدىِ فَمَن لَم يَجِد فَصِيامُ ثَلٰثَةِ أَيّامٍ فِى الحَجِّ وَسَبعَةٍ إِذا رَجَعتُم تِلكَ عَشَرَةٌ كامِلَةٌ ذٰلِكَ لِمَن لَم يَكُن أَهلُهُ حاضِرِى المَسجِدِ الحَرامِ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@cciv{الحَجُّ أَشهُرٌ مَعلومٰتٌ فَمَن فَرَضَ فيهِنَّ الحَجَّ فَلا رَفَثَ وَلا فُسوقَ وَلا جِدالَ فِى الحَجِّ وَما تَفعَلوا مِن خَيرٍ يَعلَمهُ اللَّهُ وَتَزَوَّدوا فَإِنَّ خَيرَ الزّادِ التَّقوىٰ وَاتَّقونِ يٰأُولِى الأَلبٰبِ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@ccv{لَيسَ عَلَيكُم جُناحٌ أَن تَبتَغوا فَضلًا مِن رَبِّكُم فَإِذا أَفَضتُم مِن عَرَفٰتٍ فَاذكُرُوا اللَّهَ عِندَ المَشعَرِ الحَرامِ وَاذكُروهُ كَما هَدىٰكُم وَإِن كُنتُم مِن قَبلِهِ لَمِنَ الضّالّينَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@ccvi{ثُمَّ أَفيضوا مِن حَيثُ أَفاضَ النّاسُ وَاستَغفِرُوا اللَّهَ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@ccvii{فَإِذا قَضَيتُم مَنٰسِكَكُم فَاذكُرُوا اللَّهَ كَذِكرِكُم ءاباءَكُم أَو أَشَدَّ ذِكرًا فَمِنَ النّاسِ مَن يَقولُ رَبَّنا ءاتِنا فِى الدُّنيا وَما لَهُ فِى الءاخِرَةِ مِن خَلٰقٍ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@ccviii{وَمِنهُم مَن يَقولُ رَبَّنا ءاتِنا فِى الدُّنيا حَسَنَةً وَفِى الءاخِرَةِ حَسَنَةً وَقِنا عَذابَ النّارِ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@ccix{أُولٰئِكَ لَهُم نَصيبٌ مِمّا كَسَبوا وَاللَّهُ سَريعُ الحِسابِ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@ccx{وَاذكُرُوا اللَّهَ فى أَيّامٍ مَعدودٰتٍ فَمَن تَعَجَّلَ فى يَومَينِ فَلا إِثمَ عَلَيهِ وَمَن تَأَخَّرَ فَلا إِثمَ عَلَيهِ لِمَنِ اتَّقىٰ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّكُم إِلَيهِ تُحشَرونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@ccxi{وَمِنَ النّاسِ مَن يُعجِبُكَ قَولُهُ فِى الحَيوٰةِ الدُّنيا وَيُشهِدُ اللَّهَ عَلىٰ ما فى قَلبِهِ وَهُوَ أَلَدُّ الخِصامِ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@ccxii{وَإِذا تَوَلّىٰ سَعىٰ فِى الأَرضِ لِيُفسِدَ فيها وَيُهلِكَ الحَرثَ وَالنَّسلَ وَاللَّهُ لا يُحِبُّ الفَسادَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@ccxiii{وَإِذا قيلَ لَهُ اتَّقِ اللَّهَ أَخَذَتهُ العِزَّةُ بِالإِثمِ فَحَسبُهُ جَهَنَّمُ وَلَبِئسَ المِهادُ\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@ccxiv{وَمِنَ النّاسِ مَن يَشرى نَفسَهُ ابتِغاءَ مَرضاتِ اللَّهِ وَاللَّهُ رَءوفٌ بِالعِبادِ\qt@no{﴿٢٠٧﴾}}
\qt@newcmd\qurantext@ccxv{يٰأَيُّهَا الَّذينَ ءامَنُوا ادخُلوا فِى السِّلمِ كافَّةً وَلا تَتَّبِعوا خُطُوٰتِ الشَّيطٰنِ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿٢٠٨﴾}}
\qt@newcmd\qurantext@ccxvi{فَإِن زَلَلتُم مِن بَعدِ ما جاءَتكُمُ البَيِّنٰتُ فَاعلَموا أَنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٢٠٩﴾}}
\qt@newcmd\qurantext@ccxvii{هَل يَنظُرونَ إِلّا أَن يَأتِيَهُمُ اللَّهُ فى ظُلَلٍ مِنَ الغَمامِ وَالمَلٰئِكَةُ وَقُضِىَ الأَمرُ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٢١٠﴾}}
\qt@newcmd\qurantext@ccxviii{سَل بَنى إِسرٰءيلَ كَم ءاتَينٰهُم مِن ءايَةٍ بَيِّنَةٍ وَمَن يُبَدِّل نِعمَةَ اللَّهِ مِن بَعدِ ما جاءَتهُ فَإِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٢١١﴾}}
\qt@newcmd\qurantext@ccxix{زُيِّنَ لِلَّذينَ كَفَرُوا الحَيوٰةُ الدُّنيا وَيَسخَرونَ مِنَ الَّذينَ ءامَنوا وَالَّذينَ اتَّقَوا فَوقَهُم يَومَ القِيٰمَةِ وَاللَّهُ يَرزُقُ مَن يَشاءُ بِغَيرِ حِسابٍ\qt@no{﴿٢١٢﴾}}
\qt@newcmd\qurantext@ccxx{كانَ النّاسُ أُمَّةً وٰحِدَةً فَبَعَثَ اللَّهُ النَّبِيّۦنَ مُبَشِّرينَ وَمُنذِرينَ وَأَنزَلَ مَعَهُمُ الكِتٰبَ بِالحَقِّ لِيَحكُمَ بَينَ النّاسِ فيمَا اختَلَفوا فيهِ وَمَا اختَلَفَ فيهِ إِلَّا الَّذينَ أوتوهُ مِن بَعدِ ما جاءَتهُمُ البَيِّنٰتُ بَغيًا بَينَهُم فَهَدَى اللَّهُ الَّذينَ ءامَنوا لِمَا اختَلَفوا فيهِ مِنَ الحَقِّ بِإِذنِهِ وَاللَّهُ يَهدى مَن يَشاءُ إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٢١٣﴾}}
\qt@newcmd\qurantext@ccxxi{أَم حَسِبتُم أَن تَدخُلُوا الجَنَّةَ وَلَمّا يَأتِكُم مَثَلُ الَّذينَ خَلَوا مِن قَبلِكُم مَسَّتهُمُ البَأساءُ وَالضَّرّاءُ وَزُلزِلوا حَتّىٰ يَقولَ الرَّسولُ وَالَّذينَ ءامَنوا مَعَهُ مَتىٰ نَصرُ اللَّهِ أَلا إِنَّ نَصرَ اللَّهِ قَريبٌ\qt@no{﴿٢١٤﴾}}
\qt@newcmd\qurantext@ccxxii{يَسـَٔلونَكَ ماذا يُنفِقونَ قُل ما أَنفَقتُم مِن خَيرٍ فَلِلوٰلِدَينِ وَالأَقرَبينَ وَاليَتٰمىٰ وَالمَسٰكينِ وَابنِ السَّبيلِ وَما تَفعَلوا مِن خَيرٍ فَإِنَّ اللَّهَ بِهِ عَليمٌ\qt@no{﴿٢١٥﴾}}
\qt@newcmd\qurantext@ccxxiii{كُتِبَ عَلَيكُمُ القِتالُ وَهُوَ كُرهٌ لَكُم وَعَسىٰ أَن تَكرَهوا شَيـًٔا وَهُوَ خَيرٌ لَكُم وَعَسىٰ أَن تُحِبّوا شَيـًٔا وَهُوَ شَرٌّ لَكُم وَاللَّهُ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿٢١٦﴾}}
\qt@newcmd\qurantext@ccxxiv{يَسـَٔلونَكَ عَنِ الشَّهرِ الحَرامِ قِتالٍ فيهِ قُل قِتالٌ فيهِ كَبيرٌ وَصَدٌّ عَن سَبيلِ اللَّهِ وَكُفرٌ بِهِ وَالمَسجِدِ الحَرامِ وَإِخراجُ أَهلِهِ مِنهُ أَكبَرُ عِندَ اللَّهِ وَالفِتنَةُ أَكبَرُ مِنَ القَتلِ وَلا يَزالونَ يُقٰتِلونَكُم حَتّىٰ يَرُدّوكُم عَن دينِكُم إِنِ استَطٰعوا وَمَن يَرتَدِد مِنكُم عَن دينِهِ فَيَمُت وَهُوَ كافِرٌ فَأُولٰئِكَ حَبِطَت أَعمٰلُهُم فِى الدُّنيا وَالءاخِرَةِ وَأُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿٢١٧﴾}}
\qt@newcmd\qurantext@ccxxv{إِنَّ الَّذينَ ءامَنوا وَالَّذينَ هاجَروا وَجٰهَدوا فى سَبيلِ اللَّهِ أُولٰئِكَ يَرجونَ رَحمَتَ اللَّهِ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢١٨﴾}}
\qt@newcmd\qurantext@ccxxvi{يَسـَٔلونَكَ عَنِ الخَمرِ وَالمَيسِرِ قُل فيهِما إِثمٌ كَبيرٌ وَمَنٰفِعُ لِلنّاسِ وَإِثمُهُما أَكبَرُ مِن نَفعِهِما وَيَسـَٔلونَكَ ماذا يُنفِقونَ قُلِ العَفوَ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُمُ الءايٰتِ لَعَلَّكُم تَتَفَكَّرونَ\qt@no{﴿٢١٩﴾}}
\qt@newcmd\qurantext@ccxxvii{فِى الدُّنيا وَالءاخِرَةِ وَيَسـَٔلونَكَ عَنِ اليَتٰمىٰ قُل إِصلاحٌ لَهُم خَيرٌ وَإِن تُخالِطوهُم فَإِخوٰنُكُم وَاللَّهُ يَعلَمُ المُفسِدَ مِنَ المُصلِحِ وَلَو شاءَ اللَّهُ لَأَعنَتَكُم إِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٢٢٠﴾}}
\qt@newcmd\qurantext@ccxxviii{وَلا تَنكِحُوا المُشرِكٰتِ حَتّىٰ يُؤمِنَّ وَلَأَمَةٌ مُؤمِنَةٌ خَيرٌ مِن مُشرِكَةٍ وَلَو أَعجَبَتكُم وَلا تُنكِحُوا المُشرِكينَ حَتّىٰ يُؤمِنوا وَلَعَبدٌ مُؤمِنٌ خَيرٌ مِن مُشرِكٍ وَلَو أَعجَبَكُم أُولٰئِكَ يَدعونَ إِلَى النّارِ وَاللَّهُ يَدعوا إِلَى الجَنَّةِ وَالمَغفِرَةِ بِإِذنِهِ وَيُبَيِّنُ ءايٰتِهِ لِلنّاسِ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٢٢١﴾}}
\qt@newcmd\qurantext@ccxxix{وَيَسـَٔلونَكَ عَنِ المَحيضِ قُل هُوَ أَذًى فَاعتَزِلُوا النِّساءَ فِى المَحيضِ وَلا تَقرَبوهُنَّ حَتّىٰ يَطهُرنَ فَإِذا تَطَهَّرنَ فَأتوهُنَّ مِن حَيثُ أَمَرَكُمُ اللَّهُ إِنَّ اللَّهَ يُحِبُّ التَّوّٰبينَ وَيُحِبُّ المُتَطَهِّرينَ\qt@no{﴿٢٢٢﴾}}
\qt@newcmd\qurantext@ccxxx{نِساؤُكُم حَرثٌ لَكُم فَأتوا حَرثَكُم أَنّىٰ شِئتُم وَقَدِّموا لِأَنفُسِكُم وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّكُم مُلٰقوهُ وَبَشِّرِ المُؤمِنينَ\qt@no{﴿٢٢٣﴾}}
\qt@newcmd\qurantext@ccxxxi{وَلا تَجعَلُوا اللَّهَ عُرضَةً لِأَيمٰنِكُم أَن تَبَرّوا وَتَتَّقوا وَتُصلِحوا بَينَ النّاسِ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٢٢٤﴾}}
\qt@newcmd\qurantext@ccxxxii{لا يُؤاخِذُكُمُ اللَّهُ بِاللَّغوِ فى أَيمٰنِكُم وَلٰكِن يُؤاخِذُكُم بِما كَسَبَت قُلوبُكُم وَاللَّهُ غَفورٌ حَليمٌ\qt@no{﴿٢٢٥﴾}}
\qt@newcmd\qurantext@ccxxxiii{لِلَّذينَ يُؤلونَ مِن نِسائِهِم تَرَبُّصُ أَربَعَةِ أَشهُرٍ فَإِن فاءو فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٢٢٦﴾}}
\qt@newcmd\qurantext@ccxxxiv{وَإِن عَزَمُوا الطَّلٰقَ فَإِنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿٢٢٧﴾}}
\qt@newcmd\qurantext@ccxxxv{وَالمُطَلَّقٰتُ يَتَرَبَّصنَ بِأَنفُسِهِنَّ ثَلٰثَةَ قُروءٍ وَلا يَحِلُّ لَهُنَّ أَن يَكتُمنَ ما خَلَقَ اللَّهُ فى أَرحامِهِنَّ إِن كُنَّ يُؤمِنَّ بِاللَّهِ وَاليَومِ الءاخِرِ وَبُعولَتُهُنَّ أَحَقُّ بِرَدِّهِنَّ فى ذٰلِكَ إِن أَرادوا إِصلٰحًا وَلَهُنَّ مِثلُ الَّذى عَلَيهِنَّ بِالمَعروفِ وَلِلرِّجالِ عَلَيهِنَّ دَرَجَةٌ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٢٢٨﴾}}
\qt@newcmd\qurantext@ccxxxvi{الطَّلٰقُ مَرَّتانِ فَإِمساكٌ بِمَعروفٍ أَو تَسريحٌ بِإِحسٰنٍ وَلا يَحِلُّ لَكُم أَن تَأخُذوا مِمّا ءاتَيتُموهُنَّ شَيـًٔا إِلّا أَن يَخافا أَلّا يُقيما حُدودَ اللَّهِ فَإِن خِفتُم أَلّا يُقيما حُدودَ اللَّهِ فَلا جُناحَ عَلَيهِما فيمَا افتَدَت بِهِ تِلكَ حُدودُ اللَّهِ فَلا تَعتَدوها وَمَن يَتَعَدَّ حُدودَ اللَّهِ فَأُولٰئِكَ هُمُ الظّٰلِمونَ\qt@no{﴿٢٢٩﴾}}
\qt@newcmd\qurantext@ccxxxvii{فَإِن طَلَّقَها فَلا تَحِلُّ لَهُ مِن بَعدُ حَتّىٰ تَنكِحَ زَوجًا غَيرَهُ فَإِن طَلَّقَها فَلا جُناحَ عَلَيهِما أَن يَتَراجَعا إِن ظَنّا أَن يُقيما حُدودَ اللَّهِ وَتِلكَ حُدودُ اللَّهِ يُبَيِّنُها لِقَومٍ يَعلَمونَ\qt@no{﴿٢٣٠﴾}}
\qt@newcmd\qurantext@ccxxxviii{وَإِذا طَلَّقتُمُ النِّساءَ فَبَلَغنَ أَجَلَهُنَّ فَأَمسِكوهُنَّ بِمَعروفٍ أَو سَرِّحوهُنَّ بِمَعروفٍ وَلا تُمسِكوهُنَّ ضِرارًا لِتَعتَدوا وَمَن يَفعَل ذٰلِكَ فَقَد ظَلَمَ نَفسَهُ وَلا تَتَّخِذوا ءايٰتِ اللَّهِ هُزُوًا وَاذكُروا نِعمَتَ اللَّهِ عَلَيكُم وَما أَنزَلَ عَلَيكُم مِنَ الكِتٰبِ وَالحِكمَةِ يَعِظُكُم بِهِ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٢٣١﴾}}
\qt@newcmd\qurantext@ccxxxix{وَإِذا طَلَّقتُمُ النِّساءَ فَبَلَغنَ أَجَلَهُنَّ فَلا تَعضُلوهُنَّ أَن يَنكِحنَ أَزوٰجَهُنَّ إِذا تَرٰضَوا بَينَهُم بِالمَعروفِ ذٰلِكَ يوعَظُ بِهِ مَن كانَ مِنكُم يُؤمِنُ بِاللَّهِ وَاليَومِ الءاخِرِ ذٰلِكُم أَزكىٰ لَكُم وَأَطهَرُ وَاللَّهُ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿٢٣٢﴾}}
\qt@newcmd\qurantext@ccxl{وَالوٰلِدٰتُ يُرضِعنَ أَولٰدَهُنَّ حَولَينِ كامِلَينِ لِمَن أَرادَ أَن يُتِمَّ الرَّضاعَةَ وَعَلَى المَولودِ لَهُ رِزقُهُنَّ وَكِسوَتُهُنَّ بِالمَعروفِ لا تُكَلَّفُ نَفسٌ إِلّا وُسعَها لا تُضارَّ وٰلِدَةٌ بِوَلَدِها وَلا مَولودٌ لَهُ بِوَلَدِهِ وَعَلَى الوارِثِ مِثلُ ذٰلِكَ فَإِن أَرادا فِصالًا عَن تَراضٍ مِنهُما وَتَشاوُرٍ فَلا جُناحَ عَلَيهِما وَإِن أَرَدتُم أَن تَستَرضِعوا أَولٰدَكُم فَلا جُناحَ عَلَيكُم إِذا سَلَّمتُم ما ءاتَيتُم بِالمَعروفِ وَاتَّقُوا اللَّهَ وَاعلَموا أَنَّ اللَّهَ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٢٣٣﴾}}
\qt@newcmd\qurantext@ccxli{وَالَّذينَ يُتَوَفَّونَ مِنكُم وَيَذَرونَ أَزوٰجًا يَتَرَبَّصنَ بِأَنفُسِهِنَّ أَربَعَةَ أَشهُرٍ وَعَشرًا فَإِذا بَلَغنَ أَجَلَهُنَّ فَلا جُناحَ عَلَيكُم فيما فَعَلنَ فى أَنفُسِهِنَّ بِالمَعروفِ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٢٣٤﴾}}
\qt@newcmd\qurantext@ccxlii{وَلا جُناحَ عَلَيكُم فيما عَرَّضتُم بِهِ مِن خِطبَةِ النِّساءِ أَو أَكنَنتُم فى أَنفُسِكُم عَلِمَ اللَّهُ أَنَّكُم سَتَذكُرونَهُنَّ وَلٰكِن لا تُواعِدوهُنَّ سِرًّا إِلّا أَن تَقولوا قَولًا مَعروفًا وَلا تَعزِموا عُقدَةَ النِّكاحِ حَتّىٰ يَبلُغَ الكِتٰبُ أَجَلَهُ وَاعلَموا أَنَّ اللَّهَ يَعلَمُ ما فى أَنفُسِكُم فَاحذَروهُ وَاعلَموا أَنَّ اللَّهَ غَفورٌ حَليمٌ\qt@no{﴿٢٣٥﴾}}
\qt@newcmd\qurantext@ccxliii{لا جُناحَ عَلَيكُم إِن طَلَّقتُمُ النِّساءَ ما لَم تَمَسّوهُنَّ أَو تَفرِضوا لَهُنَّ فَريضَةً وَمَتِّعوهُنَّ عَلَى الموسِعِ قَدَرُهُ وَعَلَى المُقتِرِ قَدَرُهُ مَتٰعًا بِالمَعروفِ حَقًّا عَلَى المُحسِنينَ\qt@no{﴿٢٣٦﴾}}
\qt@newcmd\qurantext@ccxliv{وَإِن طَلَّقتُموهُنَّ مِن قَبلِ أَن تَمَسّوهُنَّ وَقَد فَرَضتُم لَهُنَّ فَريضَةً فَنِصفُ ما فَرَضتُم إِلّا أَن يَعفونَ أَو يَعفُوَا۟ الَّذى بِيَدِهِ عُقدَةُ النِّكاحِ وَأَن تَعفوا أَقرَبُ لِلتَّقوىٰ وَلا تَنسَوُا الفَضلَ بَينَكُم إِنَّ اللَّهَ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٢٣٧﴾}}
\qt@newcmd\qurantext@ccxlv{حٰفِظوا عَلَى الصَّلَوٰتِ وَالصَّلوٰةِ الوُسطىٰ وَقوموا لِلَّهِ قٰنِتينَ\qt@no{﴿٢٣٨﴾}}
\qt@newcmd\qurantext@ccxlvi{فَإِن خِفتُم فَرِجالًا أَو رُكبانًا فَإِذا أَمِنتُم فَاذكُرُوا اللَّهَ كَما عَلَّمَكُم ما لَم تَكونوا تَعلَمونَ\qt@no{﴿٢٣٩﴾}}
\qt@newcmd\qurantext@ccxlvii{وَالَّذينَ يُتَوَفَّونَ مِنكُم وَيَذَرونَ أَزوٰجًا وَصِيَّةً لِأَزوٰجِهِم مَتٰعًا إِلَى الحَولِ غَيرَ إِخراجٍ فَإِن خَرَجنَ فَلا جُناحَ عَلَيكُم فى ما فَعَلنَ فى أَنفُسِهِنَّ مِن مَعروفٍ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٢٤٠﴾}}
\qt@newcmd\qurantext@ccxlviii{وَلِلمُطَلَّقٰتِ مَتٰعٌ بِالمَعروفِ حَقًّا عَلَى المُتَّقينَ\qt@no{﴿٢٤١﴾}}
\qt@newcmd\qurantext@ccxlix{كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُم ءايٰتِهِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿٢٤٢﴾}}
\qt@newcmd\qurantext@ccl{أَلَم تَرَ إِلَى الَّذينَ خَرَجوا مِن دِيٰرِهِم وَهُم أُلوفٌ حَذَرَ المَوتِ فَقالَ لَهُمُ اللَّهُ موتوا ثُمَّ أَحيٰهُم إِنَّ اللَّهَ لَذو فَضلٍ عَلَى النّاسِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَشكُرونَ\qt@no{﴿٢٤٣﴾}}
\qt@newcmd\qurantext@ccli{وَقٰتِلوا فى سَبيلِ اللَّهِ وَاعلَموا أَنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿٢٤٤﴾}}
\qt@newcmd\qurantext@cclii{مَن ذَا الَّذى يُقرِضُ اللَّهَ قَرضًا حَسَنًا فَيُضٰعِفَهُ لَهُ أَضعافًا كَثيرَةً وَاللَّهُ يَقبِضُ وَيَبصُۜطُ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٢٤٥﴾}}
\qt@newcmd\qurantext@ccliii{أَلَم تَرَ إِلَى المَلَإِ مِن بَنى إِسرٰءيلَ مِن بَعدِ موسىٰ إِذ قالوا لِنَبِىٍّ لَهُمُ ابعَث لَنا مَلِكًا نُقٰتِل فى سَبيلِ اللَّهِ قالَ هَل عَسَيتُم إِن كُتِبَ عَلَيكُمُ القِتالُ أَلّا تُقٰتِلوا قالوا وَما لَنا أَلّا نُقٰتِلَ فى سَبيلِ اللَّهِ وَقَد أُخرِجنا مِن دِيٰرِنا وَأَبنائِنا فَلَمّا كُتِبَ عَلَيهِمُ القِتالُ تَوَلَّوا إِلّا قَليلًا مِنهُم وَاللَّهُ عَليمٌ بِالظّٰلِمينَ\qt@no{﴿٢٤٦﴾}}
\qt@newcmd\qurantext@ccliv{وَقالَ لَهُم نَبِيُّهُم إِنَّ اللَّهَ قَد بَعَثَ لَكُم طالوتَ مَلِكًا قالوا أَنّىٰ يَكونُ لَهُ المُلكُ عَلَينا وَنَحنُ أَحَقُّ بِالمُلكِ مِنهُ وَلَم يُؤتَ سَعَةً مِنَ المالِ قالَ إِنَّ اللَّهَ اصطَفىٰهُ عَلَيكُم وَزادَهُ بَسطَةً فِى العِلمِ وَالجِسمِ وَاللَّهُ يُؤتى مُلكَهُ مَن يَشاءُ وَاللَّهُ وٰسِعٌ عَليمٌ\qt@no{﴿٢٤٧﴾}}
\qt@newcmd\qurantext@cclv{وَقالَ لَهُم نَبِيُّهُم إِنَّ ءايَةَ مُلكِهِ أَن يَأتِيَكُمُ التّابوتُ فيهِ سَكينَةٌ مِن رَبِّكُم وَبَقِيَّةٌ مِمّا تَرَكَ ءالُ موسىٰ وَءالُ هٰرونَ تَحمِلُهُ المَلٰئِكَةُ إِنَّ فى ذٰلِكَ لَءايَةً لَكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٢٤٨﴾}}
\qt@newcmd\qurantext@cclvi{فَلَمّا فَصَلَ طالوتُ بِالجُنودِ قالَ إِنَّ اللَّهَ مُبتَليكُم بِنَهَرٍ فَمَن شَرِبَ مِنهُ فَلَيسَ مِنّى وَمَن لَم يَطعَمهُ فَإِنَّهُ مِنّى إِلّا مَنِ اغتَرَفَ غُرفَةً بِيَدِهِ فَشَرِبوا مِنهُ إِلّا قَليلًا مِنهُم فَلَمّا جاوَزَهُ هُوَ وَالَّذينَ ءامَنوا مَعَهُ قالوا لا طاقَةَ لَنَا اليَومَ بِجالوتَ وَجُنودِهِ قالَ الَّذينَ يَظُنّونَ أَنَّهُم مُلٰقُوا اللَّهِ كَم مِن فِئَةٍ قَليلَةٍ غَلَبَت فِئَةً كَثيرَةً بِإِذنِ اللَّهِ وَاللَّهُ مَعَ الصّٰبِرينَ\qt@no{﴿٢٤٩﴾}}
\qt@newcmd\qurantext@cclvii{وَلَمّا بَرَزوا لِجالوتَ وَجُنودِهِ قالوا رَبَّنا أَفرِغ عَلَينا صَبرًا وَثَبِّت أَقدامَنا وَانصُرنا عَلَى القَومِ الكٰفِرينَ\qt@no{﴿٢٥٠﴾}}
\qt@newcmd\qurantext@cclviii{فَهَزَموهُم بِإِذنِ اللَّهِ وَقَتَلَ داوۥدُ جالوتَ وَءاتىٰهُ اللَّهُ المُلكَ وَالحِكمَةَ وَعَلَّمَهُ مِمّا يَشاءُ وَلَولا دَفعُ اللَّهِ النّاسَ بَعضَهُم بِبَعضٍ لَفَسَدَتِ الأَرضُ وَلٰكِنَّ اللَّهَ ذو فَضلٍ عَلَى العٰلَمينَ\qt@no{﴿٢٥١﴾}}
\qt@newcmd\qurantext@cclix{تِلكَ ءايٰتُ اللَّهِ نَتلوها عَلَيكَ بِالحَقِّ وَإِنَّكَ لَمِنَ المُرسَلينَ\qt@no{﴿٢٥٢﴾}}
\qt@newcmd\qurantext@cclx{تِلكَ الرُّسُلُ فَضَّلنا بَعضَهُم عَلىٰ بَعضٍ مِنهُم مَن كَلَّمَ اللَّهُ وَرَفَعَ بَعضَهُم دَرَجٰتٍ وَءاتَينا عيسَى ابنَ مَريَمَ البَيِّنٰتِ وَأَيَّدنٰهُ بِروحِ القُدُسِ وَلَو شاءَ اللَّهُ مَا اقتَتَلَ الَّذينَ مِن بَعدِهِم مِن بَعدِ ما جاءَتهُمُ البَيِّنٰتُ وَلٰكِنِ اختَلَفوا فَمِنهُم مَن ءامَنَ وَمِنهُم مَن كَفَرَ وَلَو شاءَ اللَّهُ مَا اقتَتَلوا وَلٰكِنَّ اللَّهَ يَفعَلُ ما يُريدُ\qt@no{﴿٢٥٣﴾}}
\qt@newcmd\qurantext@cclxi{يٰأَيُّهَا الَّذينَ ءامَنوا أَنفِقوا مِمّا رَزَقنٰكُم مِن قَبلِ أَن يَأتِىَ يَومٌ لا بَيعٌ فيهِ وَلا خُلَّةٌ وَلا شَفٰعَةٌ وَالكٰفِرونَ هُمُ الظّٰلِمونَ\qt@no{﴿٢٥٤﴾}}
\qt@newcmd\qurantext@cclxii{اللَّهُ لا إِلٰهَ إِلّا هُوَ الحَىُّ القَيّومُ لا تَأخُذُهُ سِنَةٌ وَلا نَومٌ لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ مَن ذَا الَّذى يَشفَعُ عِندَهُ إِلّا بِإِذنِهِ يَعلَمُ ما بَينَ أَيديهِم وَما خَلفَهُم وَلا يُحيطونَ بِشَيءٍ مِن عِلمِهِ إِلّا بِما شاءَ وَسِعَ كُرسِيُّهُ السَّمٰوٰتِ وَالأَرضَ وَلا يَـٔودُهُ حِفظُهُما وَهُوَ العَلِىُّ العَظيمُ\qt@no{﴿٢٥٥﴾}}
\qt@newcmd\qurantext@cclxiii{لا إِكراهَ فِى الدّينِ قَد تَبَيَّنَ الرُّشدُ مِنَ الغَىِّ فَمَن يَكفُر بِالطّٰغوتِ وَيُؤمِن بِاللَّهِ فَقَدِ استَمسَكَ بِالعُروَةِ الوُثقىٰ لَا انفِصامَ لَها وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٢٥٦﴾}}
\qt@newcmd\qurantext@cclxiv{اللَّهُ وَلِىُّ الَّذينَ ءامَنوا يُخرِجُهُم مِنَ الظُّلُمٰتِ إِلَى النّورِ وَالَّذينَ كَفَروا أَولِياؤُهُمُ الطّٰغوتُ يُخرِجونَهُم مِنَ النّورِ إِلَى الظُّلُمٰتِ أُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿٢٥٧﴾}}
\qt@newcmd\qurantext@cclxv{أَلَم تَرَ إِلَى الَّذى حاجَّ إِبرٰهۦمَ فى رَبِّهِ أَن ءاتىٰهُ اللَّهُ المُلكَ إِذ قالَ إِبرٰهۦمُ رَبِّىَ الَّذى يُحيۦ وَيُميتُ قالَ أَنا۠ أُحيۦ وَأُميتُ قالَ إِبرٰهۦمُ فَإِنَّ اللَّهَ يَأتى بِالشَّمسِ مِنَ المَشرِقِ فَأتِ بِها مِنَ المَغرِبِ فَبُهِتَ الَّذى كَفَرَ وَاللَّهُ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿٢٥٨﴾}}
\qt@newcmd\qurantext@cclxvi{أَو كَالَّذى مَرَّ عَلىٰ قَريَةٍ وَهِىَ خاوِيَةٌ عَلىٰ عُروشِها قالَ أَنّىٰ يُحيۦ هٰذِهِ اللَّهُ بَعدَ مَوتِها فَأَماتَهُ اللَّهُ مِا۟ئَةَ عامٍ ثُمَّ بَعَثَهُ قالَ كَم لَبِثتَ قالَ لَبِثتُ يَومًا أَو بَعضَ يَومٍ قالَ بَل لَبِثتَ مِا۟ئَةَ عامٍ فَانظُر إِلىٰ طَعامِكَ وَشَرابِكَ لَم يَتَسَنَّه وَانظُر إِلىٰ حِمارِكَ وَلِنَجعَلَكَ ءايَةً لِلنّاسِ وَانظُر إِلَى العِظامِ كَيفَ نُنشِزُها ثُمَّ نَكسوها لَحمًا فَلَمّا تَبَيَّنَ لَهُ قالَ أَعلَمُ أَنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٥٩﴾}}
\qt@newcmd\qurantext@cclxvii{وَإِذ قالَ إِبرٰهۦمُ رَبِّ أَرِنى كَيفَ تُحىِ المَوتىٰ قالَ أَوَلَم تُؤمِن قالَ بَلىٰ وَلٰكِن لِيَطمَئِنَّ قَلبى قالَ فَخُذ أَربَعَةً مِنَ الطَّيرِ فَصُرهُنَّ إِلَيكَ ثُمَّ اجعَل عَلىٰ كُلِّ جَبَلٍ مِنهُنَّ جُزءًا ثُمَّ ادعُهُنَّ يَأتينَكَ سَعيًا وَاعلَم أَنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٢٦٠﴾}}
\qt@newcmd\qurantext@cclxviii{مَثَلُ الَّذينَ يُنفِقونَ أَموٰلَهُم فى سَبيلِ اللَّهِ كَمَثَلِ حَبَّةٍ أَنبَتَت سَبعَ سَنابِلَ فى كُلِّ سُنبُلَةٍ مِا۟ئَةُ حَبَّةٍ وَاللَّهُ يُضٰعِفُ لِمَن يَشاءُ وَاللَّهُ وٰسِعٌ عَليمٌ\qt@no{﴿٢٦١﴾}}
\qt@newcmd\qurantext@cclxix{الَّذينَ يُنفِقونَ أَموٰلَهُم فى سَبيلِ اللَّهِ ثُمَّ لا يُتبِعونَ ما أَنفَقوا مَنًّا وَلا أَذًى لَهُم أَجرُهُم عِندَ رَبِّهِم وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٢٦٢﴾}}
\qt@newcmd\qurantext@cclxx{قَولٌ مَعروفٌ وَمَغفِرَةٌ خَيرٌ مِن صَدَقَةٍ يَتبَعُها أَذًى وَاللَّهُ غَنِىٌّ حَليمٌ\qt@no{﴿٢٦٣﴾}}
\qt@newcmd\qurantext@cclxxi{يٰأَيُّهَا الَّذينَ ءامَنوا لا تُبطِلوا صَدَقٰتِكُم بِالمَنِّ وَالأَذىٰ كَالَّذى يُنفِقُ مالَهُ رِئاءَ النّاسِ وَلا يُؤمِنُ بِاللَّهِ وَاليَومِ الءاخِرِ فَمَثَلُهُ كَمَثَلِ صَفوانٍ عَلَيهِ تُرابٌ فَأَصابَهُ وابِلٌ فَتَرَكَهُ صَلدًا لا يَقدِرونَ عَلىٰ شَيءٍ مِمّا كَسَبوا وَاللَّهُ لا يَهدِى القَومَ الكٰفِرينَ\qt@no{﴿٢٦٤﴾}}
\qt@newcmd\qurantext@cclxxii{وَمَثَلُ الَّذينَ يُنفِقونَ أَموٰلَهُمُ ابتِغاءَ مَرضاتِ اللَّهِ وَتَثبيتًا مِن أَنفُسِهِم كَمَثَلِ جَنَّةٍ بِرَبوَةٍ أَصابَها وابِلٌ فَـٔاتَت أُكُلَها ضِعفَينِ فَإِن لَم يُصِبها وابِلٌ فَطَلٌّ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٢٦٥﴾}}
\qt@newcmd\qurantext@cclxxiii{أَيَوَدُّ أَحَدُكُم أَن تَكونَ لَهُ جَنَّةٌ مِن نَخيلٍ وَأَعنابٍ تَجرى مِن تَحتِهَا الأَنهٰرُ لَهُ فيها مِن كُلِّ الثَّمَرٰتِ وَأَصابَهُ الكِبَرُ وَلَهُ ذُرِّيَّةٌ ضُعَفاءُ فَأَصابَها إِعصارٌ فيهِ نارٌ فَاحتَرَقَت كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُمُ الءايٰتِ لَعَلَّكُم تَتَفَكَّرونَ\qt@no{﴿٢٦٦﴾}}
\qt@newcmd\qurantext@cclxxiv{يٰأَيُّهَا الَّذينَ ءامَنوا أَنفِقوا مِن طَيِّبٰتِ ما كَسَبتُم وَمِمّا أَخرَجنا لَكُم مِنَ الأَرضِ وَلا تَيَمَّمُوا الخَبيثَ مِنهُ تُنفِقونَ وَلَستُم بِـٔاخِذيهِ إِلّا أَن تُغمِضوا فيهِ وَاعلَموا أَنَّ اللَّهَ غَنِىٌّ حَميدٌ\qt@no{﴿٢٦٧﴾}}
\qt@newcmd\qurantext@cclxxv{الشَّيطٰنُ يَعِدُكُمُ الفَقرَ وَيَأمُرُكُم بِالفَحشاءِ وَاللَّهُ يَعِدُكُم مَغفِرَةً مِنهُ وَفَضلًا وَاللَّهُ وٰسِعٌ عَليمٌ\qt@no{﴿٢٦٨﴾}}
\qt@newcmd\qurantext@cclxxvi{يُؤتِى الحِكمَةَ مَن يَشاءُ وَمَن يُؤتَ الحِكمَةَ فَقَد أوتِىَ خَيرًا كَثيرًا وَما يَذَّكَّرُ إِلّا أُولُوا الأَلبٰبِ\qt@no{﴿٢٦٩﴾}}
\qt@newcmd\qurantext@cclxxvii{وَما أَنفَقتُم مِن نَفَقَةٍ أَو نَذَرتُم مِن نَذرٍ فَإِنَّ اللَّهَ يَعلَمُهُ وَما لِلظّٰلِمينَ مِن أَنصارٍ\qt@no{﴿٢٧٠﴾}}
\qt@newcmd\qurantext@cclxxviii{إِن تُبدُوا الصَّدَقٰتِ فَنِعِمّا هِىَ وَإِن تُخفوها وَتُؤتوهَا الفُقَراءَ فَهُوَ خَيرٌ لَكُم وَيُكَفِّرُ عَنكُم مِن سَيِّـٔاتِكُم وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٢٧١﴾}}
\qt@newcmd\qurantext@cclxxix{لَيسَ عَلَيكَ هُدىٰهُم وَلٰكِنَّ اللَّهَ يَهدى مَن يَشاءُ وَما تُنفِقوا مِن خَيرٍ فَلِأَنفُسِكُم وَما تُنفِقونَ إِلَّا ابتِغاءَ وَجهِ اللَّهِ وَما تُنفِقوا مِن خَيرٍ يُوَفَّ إِلَيكُم وَأَنتُم لا تُظلَمونَ\qt@no{﴿٢٧٢﴾}}
\qt@newcmd\qurantext@cclxxx{لِلفُقَراءِ الَّذينَ أُحصِروا فى سَبيلِ اللَّهِ لا يَستَطيعونَ ضَربًا فِى الأَرضِ يَحسَبُهُمُ الجاهِلُ أَغنِياءَ مِنَ التَّعَفُّفِ تَعرِفُهُم بِسيمٰهُم لا يَسـَٔلونَ النّاسَ إِلحافًا وَما تُنفِقوا مِن خَيرٍ فَإِنَّ اللَّهَ بِهِ عَليمٌ\qt@no{﴿٢٧٣﴾}}
\qt@newcmd\qurantext@cclxxxi{الَّذينَ يُنفِقونَ أَموٰلَهُم بِالَّيلِ وَالنَّهارِ سِرًّا وَعَلانِيَةً فَلَهُم أَجرُهُم عِندَ رَبِّهِم وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٢٧٤﴾}}
\qt@newcmd\qurantext@cclxxxii{الَّذينَ يَأكُلونَ الرِّبوٰا۟ لا يَقومونَ إِلّا كَما يَقومُ الَّذى يَتَخَبَّطُهُ الشَّيطٰنُ مِنَ المَسِّ ذٰلِكَ بِأَنَّهُم قالوا إِنَّمَا البَيعُ مِثلُ الرِّبوٰا۟ وَأَحَلَّ اللَّهُ البَيعَ وَحَرَّمَ الرِّبوٰا۟ فَمَن جاءَهُ مَوعِظَةٌ مِن رَبِّهِ فَانتَهىٰ فَلَهُ ما سَلَفَ وَأَمرُهُ إِلَى اللَّهِ وَمَن عادَ فَأُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿٢٧٥﴾}}
\qt@newcmd\qurantext@cclxxxiii{يَمحَقُ اللَّهُ الرِّبوٰا۟ وَيُربِى الصَّدَقٰتِ وَاللَّهُ لا يُحِبُّ كُلَّ كَفّارٍ أَثيمٍ\qt@no{﴿٢٧٦﴾}}
\qt@newcmd\qurantext@cclxxxiv{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ وَأَقامُوا الصَّلوٰةَ وَءاتَوُا الزَّكوٰةَ لَهُم أَجرُهُم عِندَ رَبِّهِم وَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٢٧٧﴾}}
\qt@newcmd\qurantext@cclxxxv{يٰأَيُّهَا الَّذينَ ءامَنُوا اتَّقُوا اللَّهَ وَذَروا ما بَقِىَ مِنَ الرِّبوٰا۟ إِن كُنتُم مُؤمِنينَ\qt@no{﴿٢٧٨﴾}}
\qt@newcmd\qurantext@cclxxxvi{فَإِن لَم تَفعَلوا فَأذَنوا بِحَربٍ مِنَ اللَّهِ وَرَسولِهِ وَإِن تُبتُم فَلَكُم رُءوسُ أَموٰلِكُم لا تَظلِمونَ وَلا تُظلَمونَ\qt@no{﴿٢٧٩﴾}}
\qt@newcmd\qurantext@cclxxxvii{وَإِن كانَ ذو عُسرَةٍ فَنَظِرَةٌ إِلىٰ مَيسَرَةٍ وَأَن تَصَدَّقوا خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿٢٨٠﴾}}
\qt@newcmd\qurantext@cclxxxviii{وَاتَّقوا يَومًا تُرجَعونَ فيهِ إِلَى اللَّهِ ثُمَّ تُوَفّىٰ كُلُّ نَفسٍ ما كَسَبَت وَهُم لا يُظلَمونَ\qt@no{﴿٢٨١﴾}}
\qt@newcmd\qurantext@cclxxxix{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا تَدايَنتُم بِدَينٍ إِلىٰ أَجَلٍ مُسَمًّى فَاكتُبوهُ وَليَكتُب بَينَكُم كاتِبٌ بِالعَدلِ وَلا يَأبَ كاتِبٌ أَن يَكتُبَ كَما عَلَّمَهُ اللَّهُ فَليَكتُب وَليُملِلِ الَّذى عَلَيهِ الحَقُّ وَليَتَّقِ اللَّهَ رَبَّهُ وَلا يَبخَس مِنهُ شَيـًٔا فَإِن كانَ الَّذى عَلَيهِ الحَقُّ سَفيهًا أَو ضَعيفًا أَو لا يَستَطيعُ أَن يُمِلَّ هُوَ فَليُملِل وَلِيُّهُ بِالعَدلِ وَاستَشهِدوا شَهيدَينِ مِن رِجالِكُم فَإِن لَم يَكونا رَجُلَينِ فَرَجُلٌ وَامرَأَتانِ مِمَّن تَرضَونَ مِنَ الشُّهَداءِ أَن تَضِلَّ إِحدىٰهُما فَتُذَكِّرَ إِحدىٰهُمَا الأُخرىٰ وَلا يَأبَ الشُّهَداءُ إِذا ما دُعوا وَلا تَسـَٔموا أَن تَكتُبوهُ صَغيرًا أَو كَبيرًا إِلىٰ أَجَلِهِ ذٰلِكُم أَقسَطُ عِندَ اللَّهِ وَأَقوَمُ لِلشَّهٰدَةِ وَأَدنىٰ أَلّا تَرتابوا إِلّا أَن تَكونَ تِجٰرَةً حاضِرَةً تُديرونَها بَينَكُم فَلَيسَ عَلَيكُم جُناحٌ أَلّا تَكتُبوها وَأَشهِدوا إِذا تَبايَعتُم وَلا يُضارَّ كاتِبٌ وَلا شَهيدٌ وَإِن تَفعَلوا فَإِنَّهُ فُسوقٌ بِكُم وَاتَّقُوا اللَّهَ وَيُعَلِّمُكُمُ اللَّهُ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٢٨٢﴾}}
\qt@newcmd\qurantext@ccxc{وَإِن كُنتُم عَلىٰ سَفَرٍ وَلَم تَجِدوا كاتِبًا فَرِهٰنٌ مَقبوضَةٌ فَإِن أَمِنَ بَعضُكُم بَعضًا فَليُؤَدِّ الَّذِى اؤتُمِنَ أَمٰنَتَهُ وَليَتَّقِ اللَّهَ رَبَّهُ وَلا تَكتُمُوا الشَّهٰدَةَ وَمَن يَكتُمها فَإِنَّهُ ءاثِمٌ قَلبُهُ وَاللَّهُ بِما تَعمَلونَ عَليمٌ\qt@no{﴿٢٨٣﴾}}
\qt@newcmd\qurantext@ccxci{لِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَإِن تُبدوا ما فى أَنفُسِكُم أَو تُخفوهُ يُحاسِبكُم بِهِ اللَّهُ فَيَغفِرُ لِمَن يَشاءُ وَيُعَذِّبُ مَن يَشاءُ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٨٤﴾}}
\qt@newcmd\qurantext@ccxcii{ءامَنَ الرَّسولُ بِما أُنزِلَ إِلَيهِ مِن رَبِّهِ وَالمُؤمِنونَ كُلٌّ ءامَنَ بِاللَّهِ وَمَلٰئِكَتِهِ وَكُتُبِهِ وَرُسُلِهِ لا نُفَرِّقُ بَينَ أَحَدٍ مِن رُسُلِهِ وَقالوا سَمِعنا وَأَطَعنا غُفرانَكَ رَبَّنا وَإِلَيكَ المَصيرُ\qt@no{﴿٢٨٥﴾}}
\qt@newcmd\qurantext@ccxciii{لا يُكَلِّفُ اللَّهُ نَفسًا إِلّا وُسعَها لَها ما كَسَبَت وَعَلَيها مَا اكتَسَبَت رَبَّنا لا تُؤاخِذنا إِن نَسينا أَو أَخطَأنا رَبَّنا وَلا تَحمِل عَلَينا إِصرًا كَما حَمَلتَهُ عَلَى الَّذينَ مِن قَبلِنا رَبَّنا وَلا تُحَمِّلنا ما لا طاقَةَ لَنا بِهِ وَاعفُ عَنّا وَاغفِر لَنا وَارحَمنا أَنتَ مَولىٰنا فَانصُرنا عَلَى القَومِ الكٰفِرينَ\qt@no{﴿٢٨٦﴾}}
\qt@newcmd\qurantext@ccxciv{\basmalah  الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@ccxcv{اللَّهُ لا إِلٰهَ إِلّا هُوَ الحَىُّ القَيّومُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@ccxcvi{نَزَّلَ عَلَيكَ الكِتٰبَ بِالحَقِّ مُصَدِّقًا لِما بَينَ يَدَيهِ وَأَنزَلَ التَّورىٰةَ وَالإِنجيلَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@ccxcvii{مِن قَبلُ هُدًى لِلنّاسِ وَأَنزَلَ الفُرقانَ إِنَّ الَّذينَ كَفَروا بِـٔايٰتِ اللَّهِ لَهُم عَذابٌ شَديدٌ وَاللَّهُ عَزيزٌ ذُو انتِقامٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@ccxcviii{إِنَّ اللَّهَ لا يَخفىٰ عَلَيهِ شَيءٌ فِى الأَرضِ وَلا فِى السَّماءِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@ccxcix{هُوَ الَّذى يُصَوِّرُكُم فِى الأَرحامِ كَيفَ يَشاءُ لا إِلٰهَ إِلّا هُوَ العَزيزُ الحَكيمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@ccc{هُوَ الَّذى أَنزَلَ عَلَيكَ الكِتٰبَ مِنهُ ءايٰتٌ مُحكَمٰتٌ هُنَّ أُمُّ الكِتٰبِ وَأُخَرُ مُتَشٰبِهٰتٌ فَأَمَّا الَّذينَ فى قُلوبِهِم زَيغٌ فَيَتَّبِعونَ ما تَشٰبَهَ مِنهُ ابتِغاءَ الفِتنَةِ وَابتِغاءَ تَأويلِهِ وَما يَعلَمُ تَأويلَهُ إِلَّا اللَّهُ وَالرّٰسِخونَ فِى العِلمِ يَقولونَ ءامَنّا بِهِ كُلٌّ مِن عِندِ رَبِّنا وَما يَذَّكَّرُ إِلّا أُولُوا الأَلبٰبِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@ccci{رَبَّنا لا تُزِغ قُلوبَنا بَعدَ إِذ هَدَيتَنا وَهَب لَنا مِن لَدُنكَ رَحمَةً إِنَّكَ أَنتَ الوَهّابُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@cccii{رَبَّنا إِنَّكَ جامِعُ النّاسِ لِيَومٍ لا رَيبَ فيهِ إِنَّ اللَّهَ لا يُخلِفُ الميعادَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@ccciii{إِنَّ الَّذينَ كَفَروا لَن تُغنِىَ عَنهُم أَموٰلُهُم وَلا أَولٰدُهُم مِنَ اللَّهِ شَيـًٔا وَأُولٰئِكَ هُم وَقودُ النّارِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@ccciv{كَدَأبِ ءالِ فِرعَونَ وَالَّذينَ مِن قَبلِهِم كَذَّبوا بِـٔايٰتِنا فَأَخَذَهُمُ اللَّهُ بِذُنوبِهِم وَاللَّهُ شَديدُ العِقابِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@cccv{قُل لِلَّذينَ كَفَروا سَتُغلَبونَ وَتُحشَرونَ إِلىٰ جَهَنَّمَ وَبِئسَ المِهادُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@cccvi{قَد كانَ لَكُم ءايَةٌ فى فِئَتَينِ التَقَتا فِئَةٌ تُقٰتِلُ فى سَبيلِ اللَّهِ وَأُخرىٰ كافِرَةٌ يَرَونَهُم مِثلَيهِم رَأىَ العَينِ وَاللَّهُ يُؤَيِّدُ بِنَصرِهِ مَن يَشاءُ إِنَّ فى ذٰلِكَ لَعِبرَةً لِأُولِى الأَبصٰرِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@cccvii{زُيِّنَ لِلنّاسِ حُبُّ الشَّهَوٰتِ مِنَ النِّساءِ وَالبَنينَ وَالقَنٰطيرِ المُقَنطَرَةِ مِنَ الذَّهَبِ وَالفِضَّةِ وَالخَيلِ المُسَوَّمَةِ وَالأَنعٰمِ وَالحَرثِ ذٰلِكَ مَتٰعُ الحَيوٰةِ الدُّنيا وَاللَّهُ عِندَهُ حُسنُ المَـٔابِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@cccviii{قُل أَؤُنَبِّئُكُم بِخَيرٍ مِن ذٰلِكُم لِلَّذينَ اتَّقَوا عِندَ رَبِّهِم جَنّٰتٌ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها وَأَزوٰجٌ مُطَهَّرَةٌ وَرِضوٰنٌ مِنَ اللَّهِ وَاللَّهُ بَصيرٌ بِالعِبادِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@cccix{الَّذينَ يَقولونَ رَبَّنا إِنَّنا ءامَنّا فَاغفِر لَنا ذُنوبَنا وَقِنا عَذابَ النّارِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@cccx{الصّٰبِرينَ وَالصّٰدِقينَ وَالقٰنِتينَ وَالمُنفِقينَ وَالمُستَغفِرينَ بِالأَسحارِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@cccxi{شَهِدَ اللَّهُ أَنَّهُ لا إِلٰهَ إِلّا هُوَ وَالمَلٰئِكَةُ وَأُولُوا العِلمِ قائِمًا بِالقِسطِ لا إِلٰهَ إِلّا هُوَ العَزيزُ الحَكيمُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@cccxii{إِنَّ الدّينَ عِندَ اللَّهِ الإِسلٰمُ وَمَا اختَلَفَ الَّذينَ أوتُوا الكِتٰبَ إِلّا مِن بَعدِ ما جاءَهُمُ العِلمُ بَغيًا بَينَهُم وَمَن يَكفُر بِـٔايٰتِ اللَّهِ فَإِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@cccxiii{فَإِن حاجّوكَ فَقُل أَسلَمتُ وَجهِىَ لِلَّهِ وَمَنِ اتَّبَعَنِ وَقُل لِلَّذينَ أوتُوا الكِتٰبَ وَالأُمِّيّۦنَ ءَأَسلَمتُم فَإِن أَسلَموا فَقَدِ اهتَدَوا وَإِن تَوَلَّوا فَإِنَّما عَلَيكَ البَلٰغُ وَاللَّهُ بَصيرٌ بِالعِبادِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@cccxiv{إِنَّ الَّذينَ يَكفُرونَ بِـٔايٰتِ اللَّهِ وَيَقتُلونَ النَّبِيّۦنَ بِغَيرِ حَقٍّ وَيَقتُلونَ الَّذينَ يَأمُرونَ بِالقِسطِ مِنَ النّاسِ فَبَشِّرهُم بِعَذابٍ أَليمٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@cccxv{أُولٰئِكَ الَّذينَ حَبِطَت أَعمٰلُهُم فِى الدُّنيا وَالءاخِرَةِ وَما لَهُم مِن نٰصِرينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@cccxvi{أَلَم تَرَ إِلَى الَّذينَ أوتوا نَصيبًا مِنَ الكِتٰبِ يُدعَونَ إِلىٰ كِتٰبِ اللَّهِ لِيَحكُمَ بَينَهُم ثُمَّ يَتَوَلّىٰ فَريقٌ مِنهُم وَهُم مُعرِضونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@cccxvii{ذٰلِكَ بِأَنَّهُم قالوا لَن تَمَسَّنَا النّارُ إِلّا أَيّامًا مَعدودٰتٍ وَغَرَّهُم فى دينِهِم ما كانوا يَفتَرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@cccxviii{فَكَيفَ إِذا جَمَعنٰهُم لِيَومٍ لا رَيبَ فيهِ وَوُفِّيَت كُلُّ نَفسٍ ما كَسَبَت وَهُم لا يُظلَمونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@cccxix{قُلِ اللَّهُمَّ مٰلِكَ المُلكِ تُؤتِى المُلكَ مَن تَشاءُ وَتَنزِعُ المُلكَ مِمَّن تَشاءُ وَتُعِزُّ مَن تَشاءُ وَتُذِلُّ مَن تَشاءُ بِيَدِكَ الخَيرُ إِنَّكَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@cccxx{تولِجُ الَّيلَ فِى النَّهارِ وَتولِجُ النَّهارَ فِى الَّيلِ وَتُخرِجُ الحَىَّ مِنَ المَيِّتِ وَتُخرِجُ المَيِّتَ مِنَ الحَىِّ وَتَرزُقُ مَن تَشاءُ بِغَيرِ حِسابٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@cccxxi{لا يَتَّخِذِ المُؤمِنونَ الكٰفِرينَ أَولِياءَ مِن دونِ المُؤمِنينَ وَمَن يَفعَل ذٰلِكَ فَلَيسَ مِنَ اللَّهِ فى شَيءٍ إِلّا أَن تَتَّقوا مِنهُم تُقىٰةً وَيُحَذِّرُكُمُ اللَّهُ نَفسَهُ وَإِلَى اللَّهِ المَصيرُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@cccxxii{قُل إِن تُخفوا ما فى صُدورِكُم أَو تُبدوهُ يَعلَمهُ اللَّهُ وَيَعلَمُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@cccxxiii{يَومَ تَجِدُ كُلُّ نَفسٍ ما عَمِلَت مِن خَيرٍ مُحضَرًا وَما عَمِلَت مِن سوءٍ تَوَدُّ لَو أَنَّ بَينَها وَبَينَهُ أَمَدًا بَعيدًا وَيُحَذِّرُكُمُ اللَّهُ نَفسَهُ وَاللَّهُ رَءوفٌ بِالعِبادِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@cccxxiv{قُل إِن كُنتُم تُحِبّونَ اللَّهَ فَاتَّبِعونى يُحبِبكُمُ اللَّهُ وَيَغفِر لَكُم ذُنوبَكُم وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@cccxxv{قُل أَطيعُوا اللَّهَ وَالرَّسولَ فَإِن تَوَلَّوا فَإِنَّ اللَّهَ لا يُحِبُّ الكٰفِرينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@cccxxvi{إِنَّ اللَّهَ اصطَفىٰ ءادَمَ وَنوحًا وَءالَ إِبرٰهيمَ وَءالَ عِمرٰنَ عَلَى العٰلَمينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@cccxxvii{ذُرِّيَّةً بَعضُها مِن بَعضٍ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@cccxxviii{إِذ قالَتِ امرَأَتُ عِمرٰنَ رَبِّ إِنّى نَذَرتُ لَكَ ما فى بَطنى مُحَرَّرًا فَتَقَبَّل مِنّى إِنَّكَ أَنتَ السَّميعُ العَليمُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@cccxxix{فَلَمّا وَضَعَتها قالَت رَبِّ إِنّى وَضَعتُها أُنثىٰ وَاللَّهُ أَعلَمُ بِما وَضَعَت وَلَيسَ الذَّكَرُ كَالأُنثىٰ وَإِنّى سَمَّيتُها مَريَمَ وَإِنّى أُعيذُها بِكَ وَذُرِّيَّتَها مِنَ الشَّيطٰنِ الرَّجيمِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@cccxxx{فَتَقَبَّلَها رَبُّها بِقَبولٍ حَسَنٍ وَأَنبَتَها نَباتًا حَسَنًا وَكَفَّلَها زَكَرِيّا كُلَّما دَخَلَ عَلَيها زَكَرِيَّا المِحرابَ وَجَدَ عِندَها رِزقًا قالَ يٰمَريَمُ أَنّىٰ لَكِ هٰذا قالَت هُوَ مِن عِندِ اللَّهِ إِنَّ اللَّهَ يَرزُقُ مَن يَشاءُ بِغَيرِ حِسابٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@cccxxxi{هُنالِكَ دَعا زَكَرِيّا رَبَّهُ قالَ رَبِّ هَب لى مِن لَدُنكَ ذُرِّيَّةً طَيِّبَةً إِنَّكَ سَميعُ الدُّعاءِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@cccxxxii{فَنادَتهُ المَلٰئِكَةُ وَهُوَ قائِمٌ يُصَلّى فِى المِحرابِ أَنَّ اللَّهَ يُبَشِّرُكَ بِيَحيىٰ مُصَدِّقًا بِكَلِمَةٍ مِنَ اللَّهِ وَسَيِّدًا وَحَصورًا وَنَبِيًّا مِنَ الصّٰلِحينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@cccxxxiii{قالَ رَبِّ أَنّىٰ يَكونُ لى غُلٰمٌ وَقَد بَلَغَنِىَ الكِبَرُ وَامرَأَتى عاقِرٌ قالَ كَذٰلِكَ اللَّهُ يَفعَلُ ما يَشاءُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@cccxxxiv{قالَ رَبِّ اجعَل لى ءايَةً قالَ ءايَتُكَ أَلّا تُكَلِّمَ النّاسَ ثَلٰثَةَ أَيّامٍ إِلّا رَمزًا وَاذكُر رَبَّكَ كَثيرًا وَسَبِّح بِالعَشِىِّ وَالإِبكٰرِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@cccxxxv{وَإِذ قالَتِ المَلٰئِكَةُ يٰمَريَمُ إِنَّ اللَّهَ اصطَفىٰكِ وَطَهَّرَكِ وَاصطَفىٰكِ عَلىٰ نِساءِ العٰلَمينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@cccxxxvi{يٰمَريَمُ اقنُتى لِرَبِّكِ وَاسجُدى وَاركَعى مَعَ الرّٰكِعينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@cccxxxvii{ذٰلِكَ مِن أَنباءِ الغَيبِ نوحيهِ إِلَيكَ وَما كُنتَ لَدَيهِم إِذ يُلقونَ أَقلٰمَهُم أَيُّهُم يَكفُلُ مَريَمَ وَما كُنتَ لَدَيهِم إِذ يَختَصِمونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@cccxxxviii{إِذ قالَتِ المَلٰئِكَةُ يٰمَريَمُ إِنَّ اللَّهَ يُبَشِّرُكِ بِكَلِمَةٍ مِنهُ اسمُهُ المَسيحُ عيسَى ابنُ مَريَمَ وَجيهًا فِى الدُّنيا وَالءاخِرَةِ وَمِنَ المُقَرَّبينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@cccxxxix{وَيُكَلِّمُ النّاسَ فِى المَهدِ وَكَهلًا وَمِنَ الصّٰلِحينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@cccxl{قالَت رَبِّ أَنّىٰ يَكونُ لى وَلَدٌ وَلَم يَمسَسنى بَشَرٌ قالَ كَذٰلِكِ اللَّهُ يَخلُقُ ما يَشاءُ إِذا قَضىٰ أَمرًا فَإِنَّما يَقولُ لَهُ كُن فَيَكونُ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@cccxli{وَيُعَلِّمُهُ الكِتٰبَ وَالحِكمَةَ وَالتَّورىٰةَ وَالإِنجيلَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@cccxlii{وَرَسولًا إِلىٰ بَنى إِسرٰءيلَ أَنّى قَد جِئتُكُم بِـٔايَةٍ مِن رَبِّكُم أَنّى أَخلُقُ لَكُم مِنَ الطّينِ كَهَيـَٔةِ الطَّيرِ فَأَنفُخُ فيهِ فَيَكونُ طَيرًا بِإِذنِ اللَّهِ وَأُبرِئُ الأَكمَهَ وَالأَبرَصَ وَأُحىِ المَوتىٰ بِإِذنِ اللَّهِ وَأُنَبِّئُكُم بِما تَأكُلونَ وَما تَدَّخِرونَ فى بُيوتِكُم إِنَّ فى ذٰلِكَ لَءايَةً لَكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@cccxliii{وَمُصَدِّقًا لِما بَينَ يَدَىَّ مِنَ التَّورىٰةِ وَلِأُحِلَّ لَكُم بَعضَ الَّذى حُرِّمَ عَلَيكُم وَجِئتُكُم بِـٔايَةٍ مِن رَبِّكُم فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@cccxliv{إِنَّ اللَّهَ رَبّى وَرَبُّكُم فَاعبُدوهُ هٰذا صِرٰطٌ مُستَقيمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@cccxlv{فَلَمّا أَحَسَّ عيسىٰ مِنهُمُ الكُفرَ قالَ مَن أَنصارى إِلَى اللَّهِ قالَ الحَوارِيّونَ نَحنُ أَنصارُ اللَّهِ ءامَنّا بِاللَّهِ وَاشهَد بِأَنّا مُسلِمونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@cccxlvi{رَبَّنا ءامَنّا بِما أَنزَلتَ وَاتَّبَعنَا الرَّسولَ فَاكتُبنا مَعَ الشّٰهِدينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@cccxlvii{وَمَكَروا وَمَكَرَ اللَّهُ وَاللَّهُ خَيرُ المٰكِرينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@cccxlviii{إِذ قالَ اللَّهُ يٰعيسىٰ إِنّى مُتَوَفّيكَ وَرافِعُكَ إِلَىَّ وَمُطَهِّرُكَ مِنَ الَّذينَ كَفَروا وَجاعِلُ الَّذينَ اتَّبَعوكَ فَوقَ الَّذينَ كَفَروا إِلىٰ يَومِ القِيٰمَةِ ثُمَّ إِلَىَّ مَرجِعُكُم فَأَحكُمُ بَينَكُم فيما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@cccxlix{فَأَمَّا الَّذينَ كَفَروا فَأُعَذِّبُهُم عَذابًا شَديدًا فِى الدُّنيا وَالءاخِرَةِ وَما لَهُم مِن نٰصِرينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@cccl{وَأَمَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ فَيُوَفّيهِم أُجورَهُم وَاللَّهُ لا يُحِبُّ الظّٰلِمينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@cccli{ذٰلِكَ نَتلوهُ عَلَيكَ مِنَ الءايٰتِ وَالذِّكرِ الحَكيمِ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@ccclii{إِنَّ مَثَلَ عيسىٰ عِندَ اللَّهِ كَمَثَلِ ءادَمَ خَلَقَهُ مِن تُرابٍ ثُمَّ قالَ لَهُ كُن فَيَكونُ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@cccliii{الحَقُّ مِن رَبِّكَ فَلا تَكُن مِنَ المُمتَرينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@cccliv{فَمَن حاجَّكَ فيهِ مِن بَعدِ ما جاءَكَ مِنَ العِلمِ فَقُل تَعالَوا نَدعُ أَبناءَنا وَأَبناءَكُم وَنِساءَنا وَنِساءَكُم وَأَنفُسَنا وَأَنفُسَكُم ثُمَّ نَبتَهِل فَنَجعَل لَعنَتَ اللَّهِ عَلَى الكٰذِبينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@ccclv{إِنَّ هٰذا لَهُوَ القَصَصُ الحَقُّ وَما مِن إِلٰهٍ إِلَّا اللَّهُ وَإِنَّ اللَّهَ لَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@ccclvi{فَإِن تَوَلَّوا فَإِنَّ اللَّهَ عَليمٌ بِالمُفسِدينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@ccclvii{قُل يٰأَهلَ الكِتٰبِ تَعالَوا إِلىٰ كَلِمَةٍ سَواءٍ بَينَنا وَبَينَكُم أَلّا نَعبُدَ إِلَّا اللَّهَ وَلا نُشرِكَ بِهِ شَيـًٔا وَلا يَتَّخِذَ بَعضُنا بَعضًا أَربابًا مِن دونِ اللَّهِ فَإِن تَوَلَّوا فَقولُوا اشهَدوا بِأَنّا مُسلِمونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@ccclviii{يٰأَهلَ الكِتٰبِ لِمَ تُحاجّونَ فى إِبرٰهيمَ وَما أُنزِلَتِ التَّورىٰةُ وَالإِنجيلُ إِلّا مِن بَعدِهِ أَفَلا تَعقِلونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@ccclix{هٰأَنتُم هٰؤُلاءِ حٰجَجتُم فيما لَكُم بِهِ عِلمٌ فَلِمَ تُحاجّونَ فيما لَيسَ لَكُم بِهِ عِلمٌ وَاللَّهُ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@ccclx{ما كانَ إِبرٰهيمُ يَهودِيًّا وَلا نَصرانِيًّا وَلٰكِن كانَ حَنيفًا مُسلِمًا وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@ccclxi{إِنَّ أَولَى النّاسِ بِإِبرٰهيمَ لَلَّذينَ اتَّبَعوهُ وَهٰذَا النَّبِىُّ وَالَّذينَ ءامَنوا وَاللَّهُ وَلِىُّ المُؤمِنينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@ccclxii{وَدَّت طائِفَةٌ مِن أَهلِ الكِتٰبِ لَو يُضِلّونَكُم وَما يُضِلّونَ إِلّا أَنفُسَهُم وَما يَشعُرونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@ccclxiii{يٰأَهلَ الكِتٰبِ لِمَ تَكفُرونَ بِـٔايٰتِ اللَّهِ وَأَنتُم تَشهَدونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@ccclxiv{يٰأَهلَ الكِتٰبِ لِمَ تَلبِسونَ الحَقَّ بِالبٰطِلِ وَتَكتُمونَ الحَقَّ وَأَنتُم تَعلَمونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@ccclxv{وَقالَت طائِفَةٌ مِن أَهلِ الكِتٰبِ ءامِنوا بِالَّذى أُنزِلَ عَلَى الَّذينَ ءامَنوا وَجهَ النَّهارِ وَاكفُروا ءاخِرَهُ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@ccclxvi{وَلا تُؤمِنوا إِلّا لِمَن تَبِعَ دينَكُم قُل إِنَّ الهُدىٰ هُدَى اللَّهِ أَن يُؤتىٰ أَحَدٌ مِثلَ ما أوتيتُم أَو يُحاجّوكُم عِندَ رَبِّكُم قُل إِنَّ الفَضلَ بِيَدِ اللَّهِ يُؤتيهِ مَن يَشاءُ وَاللَّهُ وٰسِعٌ عَليمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@ccclxvii{يَختَصُّ بِرَحمَتِهِ مَن يَشاءُ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@ccclxviii{وَمِن أَهلِ الكِتٰبِ مَن إِن تَأمَنهُ بِقِنطارٍ يُؤَدِّهِ إِلَيكَ وَمِنهُم مَن إِن تَأمَنهُ بِدينارٍ لا يُؤَدِّهِ إِلَيكَ إِلّا ما دُمتَ عَلَيهِ قائِمًا ذٰلِكَ بِأَنَّهُم قالوا لَيسَ عَلَينا فِى الأُمِّيّۦنَ سَبيلٌ وَيَقولونَ عَلَى اللَّهِ الكَذِبَ وَهُم يَعلَمونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@ccclxix{بَلىٰ مَن أَوفىٰ بِعَهدِهِ وَاتَّقىٰ فَإِنَّ اللَّهَ يُحِبُّ المُتَّقينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@ccclxx{إِنَّ الَّذينَ يَشتَرونَ بِعَهدِ اللَّهِ وَأَيمٰنِهِم ثَمَنًا قَليلًا أُولٰئِكَ لا خَلٰقَ لَهُم فِى الءاخِرَةِ وَلا يُكَلِّمُهُمُ اللَّهُ وَلا يَنظُرُ إِلَيهِم يَومَ القِيٰمَةِ وَلا يُزَكّيهِم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@ccclxxi{وَإِنَّ مِنهُم لَفَريقًا يَلوۥنَ أَلسِنَتَهُم بِالكِتٰبِ لِتَحسَبوهُ مِنَ الكِتٰبِ وَما هُوَ مِنَ الكِتٰبِ وَيَقولونَ هُوَ مِن عِندِ اللَّهِ وَما هُوَ مِن عِندِ اللَّهِ وَيَقولونَ عَلَى اللَّهِ الكَذِبَ وَهُم يَعلَمونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@ccclxxii{ما كانَ لِبَشَرٍ أَن يُؤتِيَهُ اللَّهُ الكِتٰبَ وَالحُكمَ وَالنُّبُوَّةَ ثُمَّ يَقولَ لِلنّاسِ كونوا عِبادًا لى مِن دونِ اللَّهِ وَلٰكِن كونوا رَبّٰنِيّۦنَ بِما كُنتُم تُعَلِّمونَ الكِتٰبَ وَبِما كُنتُم تَدرُسونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@ccclxxiii{وَلا يَأمُرَكُم أَن تَتَّخِذُوا المَلٰئِكَةَ وَالنَّبِيّۦنَ أَربابًا أَيَأمُرُكُم بِالكُفرِ بَعدَ إِذ أَنتُم مُسلِمونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@ccclxxiv{وَإِذ أَخَذَ اللَّهُ ميثٰقَ النَّبِيّۦنَ لَما ءاتَيتُكُم مِن كِتٰبٍ وَحِكمَةٍ ثُمَّ جاءَكُم رَسولٌ مُصَدِّقٌ لِما مَعَكُم لَتُؤمِنُنَّ بِهِ وَلَتَنصُرُنَّهُ قالَ ءَأَقرَرتُم وَأَخَذتُم عَلىٰ ذٰلِكُم إِصرى قالوا أَقرَرنا قالَ فَاشهَدوا وَأَنا۠ مَعَكُم مِنَ الشّٰهِدينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@ccclxxv{فَمَن تَوَلّىٰ بَعدَ ذٰلِكَ فَأُولٰئِكَ هُمُ الفٰسِقونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@ccclxxvi{أَفَغَيرَ دينِ اللَّهِ يَبغونَ وَلَهُ أَسلَمَ مَن فِى السَّمٰوٰتِ وَالأَرضِ طَوعًا وَكَرهًا وَإِلَيهِ يُرجَعونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@ccclxxvii{قُل ءامَنّا بِاللَّهِ وَما أُنزِلَ عَلَينا وَما أُنزِلَ عَلىٰ إِبرٰهيمَ وَإِسمٰعيلَ وَإِسحٰقَ وَيَعقوبَ وَالأَسباطِ وَما أوتِىَ موسىٰ وَعيسىٰ وَالنَّبِيّونَ مِن رَبِّهِم لا نُفَرِّقُ بَينَ أَحَدٍ مِنهُم وَنَحنُ لَهُ مُسلِمونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@ccclxxviii{وَمَن يَبتَغِ غَيرَ الإِسلٰمِ دينًا فَلَن يُقبَلَ مِنهُ وَهُوَ فِى الءاخِرَةِ مِنَ الخٰسِرينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@ccclxxix{كَيفَ يَهدِى اللَّهُ قَومًا كَفَروا بَعدَ إيمٰنِهِم وَشَهِدوا أَنَّ الرَّسولَ حَقٌّ وَجاءَهُمُ البَيِّنٰتُ وَاللَّهُ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@ccclxxx{أُولٰئِكَ جَزاؤُهُم أَنَّ عَلَيهِم لَعنَةَ اللَّهِ وَالمَلٰئِكَةِ وَالنّاسِ أَجمَعينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@ccclxxxi{خٰلِدينَ فيها لا يُخَفَّفُ عَنهُمُ العَذابُ وَلا هُم يُنظَرونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@ccclxxxii{إِلَّا الَّذينَ تابوا مِن بَعدِ ذٰلِكَ وَأَصلَحوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@ccclxxxiii{إِنَّ الَّذينَ كَفَروا بَعدَ إيمٰنِهِم ثُمَّ ازدادوا كُفرًا لَن تُقبَلَ تَوبَتُهُم وَأُولٰئِكَ هُمُ الضّالّونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@ccclxxxiv{إِنَّ الَّذينَ كَفَروا وَماتوا وَهُم كُفّارٌ فَلَن يُقبَلَ مِن أَحَدِهِم مِلءُ الأَرضِ ذَهَبًا وَلَوِ افتَدىٰ بِهِ أُولٰئِكَ لَهُم عَذابٌ أَليمٌ وَما لَهُم مِن نٰصِرينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@ccclxxxv{لَن تَنالُوا البِرَّ حَتّىٰ تُنفِقوا مِمّا تُحِبّونَ وَما تُنفِقوا مِن شَيءٍ فَإِنَّ اللَّهَ بِهِ عَليمٌ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@ccclxxxvi{كُلُّ الطَّعامِ كانَ حِلًّا لِبَنى إِسرٰءيلَ إِلّا ما حَرَّمَ إِسرٰءيلُ عَلىٰ نَفسِهِ مِن قَبلِ أَن تُنَزَّلَ التَّورىٰةُ قُل فَأتوا بِالتَّورىٰةِ فَاتلوها إِن كُنتُم صٰدِقينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@ccclxxxvii{فَمَنِ افتَرىٰ عَلَى اللَّهِ الكَذِبَ مِن بَعدِ ذٰلِكَ فَأُولٰئِكَ هُمُ الظّٰلِمونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@ccclxxxviii{قُل صَدَقَ اللَّهُ فَاتَّبِعوا مِلَّةَ إِبرٰهيمَ حَنيفًا وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ccclxxxix{إِنَّ أَوَّلَ بَيتٍ وُضِعَ لِلنّاسِ لَلَّذى بِبَكَّةَ مُبارَكًا وَهُدًى لِلعٰلَمينَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@cccxc{فيهِ ءايٰتٌ بَيِّنٰتٌ مَقامُ إِبرٰهيمَ وَمَن دَخَلَهُ كانَ ءامِنًا وَلِلَّهِ عَلَى النّاسِ حِجُّ البَيتِ مَنِ استَطاعَ إِلَيهِ سَبيلًا وَمَن كَفَرَ فَإِنَّ اللَّهَ غَنِىٌّ عَنِ العٰلَمينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@cccxci{قُل يٰأَهلَ الكِتٰبِ لِمَ تَكفُرونَ بِـٔايٰتِ اللَّهِ وَاللَّهُ شَهيدٌ عَلىٰ ما تَعمَلونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@cccxcii{قُل يٰأَهلَ الكِتٰبِ لِمَ تَصُدّونَ عَن سَبيلِ اللَّهِ مَن ءامَنَ تَبغونَها عِوَجًا وَأَنتُم شُهَداءُ وَمَا اللَّهُ بِغٰفِلٍ عَمّا تَعمَلونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@cccxciii{يٰأَيُّهَا الَّذينَ ءامَنوا إِن تُطيعوا فَريقًا مِنَ الَّذينَ أوتُوا الكِتٰبَ يَرُدّوكُم بَعدَ إيمٰنِكُم كٰفِرينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@cccxciv{وَكَيفَ تَكفُرونَ وَأَنتُم تُتلىٰ عَلَيكُم ءايٰتُ اللَّهِ وَفيكُم رَسولُهُ وَمَن يَعتَصِم بِاللَّهِ فَقَد هُدِىَ إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@cccxcv{يٰأَيُّهَا الَّذينَ ءامَنُوا اتَّقُوا اللَّهَ حَقَّ تُقاتِهِ وَلا تَموتُنَّ إِلّا وَأَنتُم مُسلِمونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@cccxcvi{وَاعتَصِموا بِحَبلِ اللَّهِ جَميعًا وَلا تَفَرَّقوا وَاذكُروا نِعمَتَ اللَّهِ عَلَيكُم إِذ كُنتُم أَعداءً فَأَلَّفَ بَينَ قُلوبِكُم فَأَصبَحتُم بِنِعمَتِهِ إِخوٰنًا وَكُنتُم عَلىٰ شَفا حُفرَةٍ مِنَ النّارِ فَأَنقَذَكُم مِنها كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُم ءايٰتِهِ لَعَلَّكُم تَهتَدونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@cccxcvii{وَلتَكُن مِنكُم أُمَّةٌ يَدعونَ إِلَى الخَيرِ وَيَأمُرونَ بِالمَعروفِ وَيَنهَونَ عَنِ المُنكَرِ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@cccxcviii{وَلا تَكونوا كَالَّذينَ تَفَرَّقوا وَاختَلَفوا مِن بَعدِ ما جاءَهُمُ البَيِّنٰتُ وَأُولٰئِكَ لَهُم عَذابٌ عَظيمٌ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@cccxcix{يَومَ تَبيَضُّ وُجوهٌ وَتَسوَدُّ وُجوهٌ فَأَمَّا الَّذينَ اسوَدَّت وُجوهُهُم أَكَفَرتُم بَعدَ إيمٰنِكُم فَذوقُوا العَذابَ بِما كُنتُم تَكفُرونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@cd{وَأَمَّا الَّذينَ ابيَضَّت وُجوهُهُم فَفى رَحمَةِ اللَّهِ هُم فيها خٰلِدونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@cdi{تِلكَ ءايٰتُ اللَّهِ نَتلوها عَلَيكَ بِالحَقِّ وَمَا اللَّهُ يُريدُ ظُلمًا لِلعٰلَمينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@cdii{وَلِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@cdiii{كُنتُم خَيرَ أُمَّةٍ أُخرِجَت لِلنّاسِ تَأمُرونَ بِالمَعروفِ وَتَنهَونَ عَنِ المُنكَرِ وَتُؤمِنونَ بِاللَّهِ وَلَو ءامَنَ أَهلُ الكِتٰبِ لَكانَ خَيرًا لَهُم مِنهُمُ المُؤمِنونَ وَأَكثَرُهُمُ الفٰسِقونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cdiv{لَن يَضُرّوكُم إِلّا أَذًى وَإِن يُقٰتِلوكُم يُوَلّوكُمُ الأَدبارَ ثُمَّ لا يُنصَرونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cdv{ضُرِبَت عَلَيهِمُ الذِّلَّةُ أَينَ ما ثُقِفوا إِلّا بِحَبلٍ مِنَ اللَّهِ وَحَبلٍ مِنَ النّاسِ وَباءو بِغَضَبٍ مِنَ اللَّهِ وَضُرِبَت عَلَيهِمُ المَسكَنَةُ ذٰلِكَ بِأَنَّهُم كانوا يَكفُرونَ بِـٔايٰتِ اللَّهِ وَيَقتُلونَ الأَنبِياءَ بِغَيرِ حَقٍّ ذٰلِكَ بِما عَصَوا وَكانوا يَعتَدونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cdvi{لَيسوا سَواءً مِن أَهلِ الكِتٰبِ أُمَّةٌ قائِمَةٌ يَتلونَ ءايٰتِ اللَّهِ ءاناءَ الَّيلِ وَهُم يَسجُدونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cdvii{يُؤمِنونَ بِاللَّهِ وَاليَومِ الءاخِرِ وَيَأمُرونَ بِالمَعروفِ وَيَنهَونَ عَنِ المُنكَرِ وَيُسٰرِعونَ فِى الخَيرٰتِ وَأُولٰئِكَ مِنَ الصّٰلِحينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cdviii{وَما يَفعَلوا مِن خَيرٍ فَلَن يُكفَروهُ وَاللَّهُ عَليمٌ بِالمُتَّقينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cdix{إِنَّ الَّذينَ كَفَروا لَن تُغنِىَ عَنهُم أَموٰلُهُم وَلا أَولٰدُهُم مِنَ اللَّهِ شَيـًٔا وَأُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cdx{مَثَلُ ما يُنفِقونَ فى هٰذِهِ الحَيوٰةِ الدُّنيا كَمَثَلِ ريحٍ فيها صِرٌّ أَصابَت حَرثَ قَومٍ ظَلَموا أَنفُسَهُم فَأَهلَكَتهُ وَما ظَلَمَهُمُ اللَّهُ وَلٰكِن أَنفُسَهُم يَظلِمونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cdxi{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَتَّخِذوا بِطانَةً مِن دونِكُم لا يَألونَكُم خَبالًا وَدّوا ما عَنِتُّم قَد بَدَتِ البَغضاءُ مِن أَفوٰهِهِم وَما تُخفى صُدورُهُم أَكبَرُ قَد بَيَّنّا لَكُمُ الءايٰتِ إِن كُنتُم تَعقِلونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cdxii{هٰأَنتُم أُولاءِ تُحِبّونَهُم وَلا يُحِبّونَكُم وَتُؤمِنونَ بِالكِتٰبِ كُلِّهِ وَإِذا لَقوكُم قالوا ءامَنّا وَإِذا خَلَوا عَضّوا عَلَيكُمُ الأَنامِلَ مِنَ الغَيظِ قُل موتوا بِغَيظِكُم إِنَّ اللَّهَ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cdxiii{إِن تَمسَسكُم حَسَنَةٌ تَسُؤهُم وَإِن تُصِبكُم سَيِّئَةٌ يَفرَحوا بِها وَإِن تَصبِروا وَتَتَّقوا لا يَضُرُّكُم كَيدُهُم شَيـًٔا إِنَّ اللَّهَ بِما يَعمَلونَ مُحيطٌ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cdxiv{وَإِذ غَدَوتَ مِن أَهلِكَ تُبَوِّئُ المُؤمِنينَ مَقٰعِدَ لِلقِتالِ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cdxv{إِذ هَمَّت طائِفَتانِ مِنكُم أَن تَفشَلا وَاللَّهُ وَلِيُّهُما وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cdxvi{وَلَقَد نَصَرَكُمُ اللَّهُ بِبَدرٍ وَأَنتُم أَذِلَّةٌ فَاتَّقُوا اللَّهَ لَعَلَّكُم تَشكُرونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cdxvii{إِذ تَقولُ لِلمُؤمِنينَ أَلَن يَكفِيَكُم أَن يُمِدَّكُم رَبُّكُم بِثَلٰثَةِ ءالٰفٍ مِنَ المَلٰئِكَةِ مُنزَلينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cdxviii{بَلىٰ إِن تَصبِروا وَتَتَّقوا وَيَأتوكُم مِن فَورِهِم هٰذا يُمدِدكُم رَبُّكُم بِخَمسَةِ ءالٰفٍ مِنَ المَلٰئِكَةِ مُسَوِّمينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cdxix{وَما جَعَلَهُ اللَّهُ إِلّا بُشرىٰ لَكُم وَلِتَطمَئِنَّ قُلوبُكُم بِهِ وَمَا النَّصرُ إِلّا مِن عِندِ اللَّهِ العَزيزِ الحَكيمِ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cdxx{لِيَقطَعَ طَرَفًا مِنَ الَّذينَ كَفَروا أَو يَكبِتَهُم فَيَنقَلِبوا خائِبينَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cdxxi{لَيسَ لَكَ مِنَ الأَمرِ شَيءٌ أَو يَتوبَ عَلَيهِم أَو يُعَذِّبَهُم فَإِنَّهُم ظٰلِمونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cdxxii{وَلِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ يَغفِرُ لِمَن يَشاءُ وَيُعَذِّبُ مَن يَشاءُ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cdxxiii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَأكُلُوا الرِّبوٰا۟ أَضعٰفًا مُضٰعَفَةً وَاتَّقُوا اللَّهَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cdxxiv{وَاتَّقُوا النّارَ الَّتى أُعِدَّت لِلكٰفِرينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cdxxv{وَأَطيعُوا اللَّهَ وَالرَّسولَ لَعَلَّكُم تُرحَمونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cdxxvi{وَسارِعوا إِلىٰ مَغفِرَةٍ مِن رَبِّكُم وَجَنَّةٍ عَرضُهَا السَّمٰوٰتُ وَالأَرضُ أُعِدَّت لِلمُتَّقينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cdxxvii{الَّذينَ يُنفِقونَ فِى السَّرّاءِ وَالضَّرّاءِ وَالكٰظِمينَ الغَيظَ وَالعافينَ عَنِ النّاسِ وَاللَّهُ يُحِبُّ المُحسِنينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cdxxviii{وَالَّذينَ إِذا فَعَلوا فٰحِشَةً أَو ظَلَموا أَنفُسَهُم ذَكَرُوا اللَّهَ فَاستَغفَروا لِذُنوبِهِم وَمَن يَغفِرُ الذُّنوبَ إِلَّا اللَّهُ وَلَم يُصِرّوا عَلىٰ ما فَعَلوا وَهُم يَعلَمونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cdxxix{أُولٰئِكَ جَزاؤُهُم مَغفِرَةٌ مِن رَبِّهِم وَجَنّٰتٌ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها وَنِعمَ أَجرُ العٰمِلينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cdxxx{قَد خَلَت مِن قَبلِكُم سُنَنٌ فَسيروا فِى الأَرضِ فَانظُروا كَيفَ كانَ عٰقِبَةُ المُكَذِّبينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cdxxxi{هٰذا بَيانٌ لِلنّاسِ وَهُدًى وَمَوعِظَةٌ لِلمُتَّقينَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cdxxxii{وَلا تَهِنوا وَلا تَحزَنوا وَأَنتُمُ الأَعلَونَ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cdxxxiii{إِن يَمسَسكُم قَرحٌ فَقَد مَسَّ القَومَ قَرحٌ مِثلُهُ وَتِلكَ الأَيّامُ نُداوِلُها بَينَ النّاسِ وَلِيَعلَمَ اللَّهُ الَّذينَ ءامَنوا وَيَتَّخِذَ مِنكُم شُهَداءَ وَاللَّهُ لا يُحِبُّ الظّٰلِمينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cdxxxiv{وَلِيُمَحِّصَ اللَّهُ الَّذينَ ءامَنوا وَيَمحَقَ الكٰفِرينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cdxxxv{أَم حَسِبتُم أَن تَدخُلُوا الجَنَّةَ وَلَمّا يَعلَمِ اللَّهُ الَّذينَ جٰهَدوا مِنكُم وَيَعلَمَ الصّٰبِرينَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cdxxxvi{وَلَقَد كُنتُم تَمَنَّونَ المَوتَ مِن قَبلِ أَن تَلقَوهُ فَقَد رَأَيتُموهُ وَأَنتُم تَنظُرونَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cdxxxvii{وَما مُحَمَّدٌ إِلّا رَسولٌ قَد خَلَت مِن قَبلِهِ الرُّسُلُ أَفَإِي۟ن ماتَ أَو قُتِلَ انقَلَبتُم عَلىٰ أَعقٰبِكُم وَمَن يَنقَلِب عَلىٰ عَقِبَيهِ فَلَن يَضُرَّ اللَّهَ شَيـًٔا وَسَيَجزِى اللَّهُ الشّٰكِرينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@cdxxxviii{وَما كانَ لِنَفسٍ أَن تَموتَ إِلّا بِإِذنِ اللَّهِ كِتٰبًا مُؤَجَّلًا وَمَن يُرِد ثَوابَ الدُّنيا نُؤتِهِ مِنها وَمَن يُرِد ثَوابَ الءاخِرَةِ نُؤتِهِ مِنها وَسَنَجزِى الشّٰكِرينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cdxxxix{وَكَأَيِّن مِن نَبِىٍّ قٰتَلَ مَعَهُ رِبِّيّونَ كَثيرٌ فَما وَهَنوا لِما أَصابَهُم فى سَبيلِ اللَّهِ وَما ضَعُفوا وَمَا استَكانوا وَاللَّهُ يُحِبُّ الصّٰبِرينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cdxl{وَما كانَ قَولَهُم إِلّا أَن قالوا رَبَّنَا اغفِر لَنا ذُنوبَنا وَإِسرافَنا فى أَمرِنا وَثَبِّت أَقدامَنا وَانصُرنا عَلَى القَومِ الكٰفِرينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@cdxli{فَـٔاتىٰهُمُ اللَّهُ ثَوابَ الدُّنيا وَحُسنَ ثَوابِ الءاخِرَةِ وَاللَّهُ يُحِبُّ المُحسِنينَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@cdxlii{يٰأَيُّهَا الَّذينَ ءامَنوا إِن تُطيعُوا الَّذينَ كَفَروا يَرُدّوكُم عَلىٰ أَعقٰبِكُم فَتَنقَلِبوا خٰسِرينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@cdxliii{بَلِ اللَّهُ مَولىٰكُم وَهُوَ خَيرُ النّٰصِرينَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@cdxliv{سَنُلقى فى قُلوبِ الَّذينَ كَفَرُوا الرُّعبَ بِما أَشرَكوا بِاللَّهِ ما لَم يُنَزِّل بِهِ سُلطٰنًا وَمَأوىٰهُمُ النّارُ وَبِئسَ مَثوَى الظّٰلِمينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@cdxlv{وَلَقَد صَدَقَكُمُ اللَّهُ وَعدَهُ إِذ تَحُسّونَهُم بِإِذنِهِ حَتّىٰ إِذا فَشِلتُم وَتَنٰزَعتُم فِى الأَمرِ وَعَصَيتُم مِن بَعدِ ما أَرىٰكُم ما تُحِبّونَ مِنكُم مَن يُريدُ الدُّنيا وَمِنكُم مَن يُريدُ الءاخِرَةَ ثُمَّ صَرَفَكُم عَنهُم لِيَبتَلِيَكُم وَلَقَد عَفا عَنكُم وَاللَّهُ ذو فَضلٍ عَلَى المُؤمِنينَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@cdxlvi{إِذ تُصعِدونَ وَلا تَلوۥنَ عَلىٰ أَحَدٍ وَالرَّسولُ يَدعوكُم فى أُخرىٰكُم فَأَثٰبَكُم غَمًّا بِغَمٍّ لِكَيلا تَحزَنوا عَلىٰ ما فاتَكُم وَلا ما أَصٰبَكُم وَاللَّهُ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@cdxlvii{ثُمَّ أَنزَلَ عَلَيكُم مِن بَعدِ الغَمِّ أَمَنَةً نُعاسًا يَغشىٰ طائِفَةً مِنكُم وَطائِفَةٌ قَد أَهَمَّتهُم أَنفُسُهُم يَظُنّونَ بِاللَّهِ غَيرَ الحَقِّ ظَنَّ الجٰهِلِيَّةِ يَقولونَ هَل لَنا مِنَ الأَمرِ مِن شَيءٍ قُل إِنَّ الأَمرَ كُلَّهُ لِلَّهِ يُخفونَ فى أَنفُسِهِم ما لا يُبدونَ لَكَ يَقولونَ لَو كانَ لَنا مِنَ الأَمرِ شَيءٌ ما قُتِلنا هٰهُنا قُل لَو كُنتُم فى بُيوتِكُم لَبَرَزَ الَّذينَ كُتِبَ عَلَيهِمُ القَتلُ إِلىٰ مَضاجِعِهِم وَلِيَبتَلِىَ اللَّهُ ما فى صُدورِكُم وَلِيُمَحِّصَ ما فى قُلوبِكُم وَاللَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@cdxlviii{إِنَّ الَّذينَ تَوَلَّوا مِنكُم يَومَ التَقَى الجَمعانِ إِنَّمَا استَزَلَّهُمُ الشَّيطٰنُ بِبَعضِ ما كَسَبوا وَلَقَد عَفَا اللَّهُ عَنهُم إِنَّ اللَّهَ غَفورٌ حَليمٌ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@cdxlix{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَكونوا كَالَّذينَ كَفَروا وَقالوا لِإِخوٰنِهِم إِذا ضَرَبوا فِى الأَرضِ أَو كانوا غُزًّى لَو كانوا عِندَنا ما ماتوا وَما قُتِلوا لِيَجعَلَ اللَّهُ ذٰلِكَ حَسرَةً فى قُلوبِهِم وَاللَّهُ يُحيۦ وَيُميتُ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@cdl{وَلَئِن قُتِلتُم فى سَبيلِ اللَّهِ أَو مُتُّم لَمَغفِرَةٌ مِنَ اللَّهِ وَرَحمَةٌ خَيرٌ مِمّا يَجمَعونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@cdli{وَلَئِن مُتُّم أَو قُتِلتُم لَإِلَى اللَّهِ تُحشَرونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@cdlii{فَبِما رَحمَةٍ مِنَ اللَّهِ لِنتَ لَهُم وَلَو كُنتَ فَظًّا غَليظَ القَلبِ لَانفَضّوا مِن حَولِكَ فَاعفُ عَنهُم وَاستَغفِر لَهُم وَشاوِرهُم فِى الأَمرِ فَإِذا عَزَمتَ فَتَوَكَّل عَلَى اللَّهِ إِنَّ اللَّهَ يُحِبُّ المُتَوَكِّلينَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@cdliii{إِن يَنصُركُمُ اللَّهُ فَلا غالِبَ لَكُم وَإِن يَخذُلكُم فَمَن ذَا الَّذى يَنصُرُكُم مِن بَعدِهِ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@cdliv{وَما كانَ لِنَبِىٍّ أَن يَغُلَّ وَمَن يَغلُل يَأتِ بِما غَلَّ يَومَ القِيٰمَةِ ثُمَّ تُوَفّىٰ كُلُّ نَفسٍ ما كَسَبَت وَهُم لا يُظلَمونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@cdlv{أَفَمَنِ اتَّبَعَ رِضوٰنَ اللَّهِ كَمَن باءَ بِسَخَطٍ مِنَ اللَّهِ وَمَأوىٰهُ جَهَنَّمُ وَبِئسَ المَصيرُ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@cdlvi{هُم دَرَجٰتٌ عِندَ اللَّهِ وَاللَّهُ بَصيرٌ بِما يَعمَلونَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@cdlvii{لَقَد مَنَّ اللَّهُ عَلَى المُؤمِنينَ إِذ بَعَثَ فيهِم رَسولًا مِن أَنفُسِهِم يَتلوا عَلَيهِم ءايٰتِهِ وَيُزَكّيهِم وَيُعَلِّمُهُمُ الكِتٰبَ وَالحِكمَةَ وَإِن كانوا مِن قَبلُ لَفى ضَلٰلٍ مُبينٍ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@cdlviii{أَوَلَمّا أَصٰبَتكُم مُصيبَةٌ قَد أَصَبتُم مِثلَيها قُلتُم أَنّىٰ هٰذا قُل هُوَ مِن عِندِ أَنفُسِكُم إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@cdlix{وَما أَصٰبَكُم يَومَ التَقَى الجَمعانِ فَبِإِذنِ اللَّهِ وَلِيَعلَمَ المُؤمِنينَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@cdlx{وَلِيَعلَمَ الَّذينَ نافَقوا وَقيلَ لَهُم تَعالَوا قٰتِلوا فى سَبيلِ اللَّهِ أَوِ ادفَعوا قالوا لَو نَعلَمُ قِتالًا لَاتَّبَعنٰكُم هُم لِلكُفرِ يَومَئِذٍ أَقرَبُ مِنهُم لِلإيمٰنِ يَقولونَ بِأَفوٰهِهِم ما لَيسَ فى قُلوبِهِم وَاللَّهُ أَعلَمُ بِما يَكتُمونَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@cdlxi{الَّذينَ قالوا لِإِخوٰنِهِم وَقَعَدوا لَو أَطاعونا ما قُتِلوا قُل فَادرَءوا عَن أَنفُسِكُمُ المَوتَ إِن كُنتُم صٰدِقينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@cdlxii{وَلا تَحسَبَنَّ الَّذينَ قُتِلوا فى سَبيلِ اللَّهِ أَموٰتًا بَل أَحياءٌ عِندَ رَبِّهِم يُرزَقونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@cdlxiii{فَرِحينَ بِما ءاتىٰهُمُ اللَّهُ مِن فَضلِهِ وَيَستَبشِرونَ بِالَّذينَ لَم يَلحَقوا بِهِم مِن خَلفِهِم أَلّا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@cdlxiv{يَستَبشِرونَ بِنِعمَةٍ مِنَ اللَّهِ وَفَضلٍ وَأَنَّ اللَّهَ لا يُضيعُ أَجرَ المُؤمِنينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@cdlxv{الَّذينَ استَجابوا لِلَّهِ وَالرَّسولِ مِن بَعدِ ما أَصابَهُمُ القَرحُ لِلَّذينَ أَحسَنوا مِنهُم وَاتَّقَوا أَجرٌ عَظيمٌ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@cdlxvi{الَّذينَ قالَ لَهُمُ النّاسُ إِنَّ النّاسَ قَد جَمَعوا لَكُم فَاخشَوهُم فَزادَهُم إيمٰنًا وَقالوا حَسبُنَا اللَّهُ وَنِعمَ الوَكيلُ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@cdlxvii{فَانقَلَبوا بِنِعمَةٍ مِنَ اللَّهِ وَفَضلٍ لَم يَمسَسهُم سوءٌ وَاتَّبَعوا رِضوٰنَ اللَّهِ وَاللَّهُ ذو فَضلٍ عَظيمٍ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@cdlxviii{إِنَّما ذٰلِكُمُ الشَّيطٰنُ يُخَوِّفُ أَولِياءَهُ فَلا تَخافوهُم وَخافونِ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@cdlxix{وَلا يَحزُنكَ الَّذينَ يُسٰرِعونَ فِى الكُفرِ إِنَّهُم لَن يَضُرُّوا اللَّهَ شَيـًٔا يُريدُ اللَّهُ أَلّا يَجعَلَ لَهُم حَظًّا فِى الءاخِرَةِ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@cdlxx{إِنَّ الَّذينَ اشتَرَوُا الكُفرَ بِالإيمٰنِ لَن يَضُرُّوا اللَّهَ شَيـًٔا وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@cdlxxi{وَلا يَحسَبَنَّ الَّذينَ كَفَروا أَنَّما نُملى لَهُم خَيرٌ لِأَنفُسِهِم إِنَّما نُملى لَهُم لِيَزدادوا إِثمًا وَلَهُم عَذابٌ مُهينٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@cdlxxii{ما كانَ اللَّهُ لِيَذَرَ المُؤمِنينَ عَلىٰ ما أَنتُم عَلَيهِ حَتّىٰ يَميزَ الخَبيثَ مِنَ الطَّيِّبِ وَما كانَ اللَّهُ لِيُطلِعَكُم عَلَى الغَيبِ وَلٰكِنَّ اللَّهَ يَجتَبى مِن رُسُلِهِ مَن يَشاءُ فَـٔامِنوا بِاللَّهِ وَرُسُلِهِ وَإِن تُؤمِنوا وَتَتَّقوا فَلَكُم أَجرٌ عَظيمٌ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@cdlxxiii{وَلا يَحسَبَنَّ الَّذينَ يَبخَلونَ بِما ءاتىٰهُمُ اللَّهُ مِن فَضلِهِ هُوَ خَيرًا لَهُم بَل هُوَ شَرٌّ لَهُم سَيُطَوَّقونَ ما بَخِلوا بِهِ يَومَ القِيٰمَةِ وَلِلَّهِ ميرٰثُ السَّمٰوٰتِ وَالأَرضِ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@cdlxxiv{لَقَد سَمِعَ اللَّهُ قَولَ الَّذينَ قالوا إِنَّ اللَّهَ فَقيرٌ وَنَحنُ أَغنِياءُ سَنَكتُبُ ما قالوا وَقَتلَهُمُ الأَنبِياءَ بِغَيرِ حَقٍّ وَنَقولُ ذوقوا عَذابَ الحَريقِ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@cdlxxv{ذٰلِكَ بِما قَدَّمَت أَيديكُم وَأَنَّ اللَّهَ لَيسَ بِظَلّامٍ لِلعَبيدِ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@cdlxxvi{الَّذينَ قالوا إِنَّ اللَّهَ عَهِدَ إِلَينا أَلّا نُؤمِنَ لِرَسولٍ حَتّىٰ يَأتِيَنا بِقُربانٍ تَأكُلُهُ النّارُ قُل قَد جاءَكُم رُسُلٌ مِن قَبلى بِالبَيِّنٰتِ وَبِالَّذى قُلتُم فَلِمَ قَتَلتُموهُم إِن كُنتُم صٰدِقينَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@cdlxxvii{فَإِن كَذَّبوكَ فَقَد كُذِّبَ رُسُلٌ مِن قَبلِكَ جاءو بِالبَيِّنٰتِ وَالزُّبُرِ وَالكِتٰبِ المُنيرِ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@cdlxxviii{كُلُّ نَفسٍ ذائِقَةُ المَوتِ وَإِنَّما تُوَفَّونَ أُجورَكُم يَومَ القِيٰمَةِ فَمَن زُحزِحَ عَنِ النّارِ وَأُدخِلَ الجَنَّةَ فَقَد فازَ وَمَا الحَيوٰةُ الدُّنيا إِلّا مَتٰعُ الغُرورِ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@cdlxxix{لَتُبلَوُنَّ فى أَموٰلِكُم وَأَنفُسِكُم وَلَتَسمَعُنَّ مِنَ الَّذينَ أوتُوا الكِتٰبَ مِن قَبلِكُم وَمِنَ الَّذينَ أَشرَكوا أَذًى كَثيرًا وَإِن تَصبِروا وَتَتَّقوا فَإِنَّ ذٰلِكَ مِن عَزمِ الأُمورِ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@cdlxxx{وَإِذ أَخَذَ اللَّهُ ميثٰقَ الَّذينَ أوتُوا الكِتٰبَ لَتُبَيِّنُنَّهُ لِلنّاسِ وَلا تَكتُمونَهُ فَنَبَذوهُ وَراءَ ظُهورِهِم وَاشتَرَوا بِهِ ثَمَنًا قَليلًا فَبِئسَ ما يَشتَرونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@cdlxxxi{لا تَحسَبَنَّ الَّذينَ يَفرَحونَ بِما أَتَوا وَيُحِبّونَ أَن يُحمَدوا بِما لَم يَفعَلوا فَلا تَحسَبَنَّهُم بِمَفازَةٍ مِنَ العَذابِ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@cdlxxxii{وَلِلَّهِ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@cdlxxxiii{إِنَّ فى خَلقِ السَّمٰوٰتِ وَالأَرضِ وَاختِلٰفِ الَّيلِ وَالنَّهارِ لَءايٰتٍ لِأُولِى الأَلبٰبِ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@cdlxxxiv{الَّذينَ يَذكُرونَ اللَّهَ قِيٰمًا وَقُعودًا وَعَلىٰ جُنوبِهِم وَيَتَفَكَّرونَ فى خَلقِ السَّمٰوٰتِ وَالأَرضِ رَبَّنا ما خَلَقتَ هٰذا بٰطِلًا سُبحٰنَكَ فَقِنا عَذابَ النّارِ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@cdlxxxv{رَبَّنا إِنَّكَ مَن تُدخِلِ النّارَ فَقَد أَخزَيتَهُ وَما لِلظّٰلِمينَ مِن أَنصارٍ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@cdlxxxvi{رَبَّنا إِنَّنا سَمِعنا مُنادِيًا يُنادى لِلإيمٰنِ أَن ءامِنوا بِرَبِّكُم فَـٔامَنّا رَبَّنا فَاغفِر لَنا ذُنوبَنا وَكَفِّر عَنّا سَيِّـٔاتِنا وَتَوَفَّنا مَعَ الأَبرارِ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@cdlxxxvii{رَبَّنا وَءاتِنا ما وَعَدتَنا عَلىٰ رُسُلِكَ وَلا تُخزِنا يَومَ القِيٰمَةِ إِنَّكَ لا تُخلِفُ الميعادَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@cdlxxxviii{فَاستَجابَ لَهُم رَبُّهُم أَنّى لا أُضيعُ عَمَلَ عٰمِلٍ مِنكُم مِن ذَكَرٍ أَو أُنثىٰ بَعضُكُم مِن بَعضٍ فَالَّذينَ هاجَروا وَأُخرِجوا مِن دِيٰرِهِم وَأوذوا فى سَبيلى وَقٰتَلوا وَقُتِلوا لَأُكَفِّرَنَّ عَنهُم سَيِّـٔاتِهِم وَلَأُدخِلَنَّهُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ ثَوابًا مِن عِندِ اللَّهِ وَاللَّهُ عِندَهُ حُسنُ الثَّوابِ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@cdlxxxix{لا يَغُرَّنَّكَ تَقَلُّبُ الَّذينَ كَفَروا فِى البِلٰدِ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@cdxc{مَتٰعٌ قَليلٌ ثُمَّ مَأوىٰهُم جَهَنَّمُ وَبِئسَ المِهادُ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@cdxci{لٰكِنِ الَّذينَ اتَّقَوا رَبَّهُم لَهُم جَنّٰتٌ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها نُزُلًا مِن عِندِ اللَّهِ وَما عِندَ اللَّهِ خَيرٌ لِلأَبرارِ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@cdxcii{وَإِنَّ مِن أَهلِ الكِتٰبِ لَمَن يُؤمِنُ بِاللَّهِ وَما أُنزِلَ إِلَيكُم وَما أُنزِلَ إِلَيهِم خٰشِعينَ لِلَّهِ لا يَشتَرونَ بِـٔايٰتِ اللَّهِ ثَمَنًا قَليلًا أُولٰئِكَ لَهُم أَجرُهُم عِندَ رَبِّهِم إِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@cdxciii{يٰأَيُّهَا الَّذينَ ءامَنُوا اصبِروا وَصابِروا وَرابِطوا وَاتَّقُوا اللَّهَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@cdxciv{\basmalah  يٰأَيُّهَا النّاسُ اتَّقوا رَبَّكُمُ الَّذى خَلَقَكُم مِن نَفسٍ وٰحِدَةٍ وَخَلَقَ مِنها زَوجَها وَبَثَّ مِنهُما رِجالًا كَثيرًا وَنِساءً وَاتَّقُوا اللَّهَ الَّذى تَساءَلونَ بِهِ وَالأَرحامَ إِنَّ اللَّهَ كانَ عَلَيكُم رَقيبًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@cdxcv{وَءاتُوا اليَتٰمىٰ أَموٰلَهُم وَلا تَتَبَدَّلُوا الخَبيثَ بِالطَّيِّبِ وَلا تَأكُلوا أَموٰلَهُم إِلىٰ أَموٰلِكُم إِنَّهُ كانَ حوبًا كَبيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@cdxcvi{وَإِن خِفتُم أَلّا تُقسِطوا فِى اليَتٰمىٰ فَانكِحوا ما طابَ لَكُم مِنَ النِّساءِ مَثنىٰ وَثُلٰثَ وَرُبٰعَ فَإِن خِفتُم أَلّا تَعدِلوا فَوٰحِدَةً أَو ما مَلَكَت أَيمٰنُكُم ذٰلِكَ أَدنىٰ أَلّا تَعولوا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@cdxcvii{وَءاتُوا النِّساءَ صَدُقٰتِهِنَّ نِحلَةً فَإِن طِبنَ لَكُم عَن شَيءٍ مِنهُ نَفسًا فَكُلوهُ هَنيـًٔا مَريـًٔا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@cdxcviii{وَلا تُؤتُوا السُّفَهاءَ أَموٰلَكُمُ الَّتى جَعَلَ اللَّهُ لَكُم قِيٰمًا وَارزُقوهُم فيها وَاكسوهُم وَقولوا لَهُم قَولًا مَعروفًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@cdxcix{وَابتَلُوا اليَتٰمىٰ حَتّىٰ إِذا بَلَغُوا النِّكاحَ فَإِن ءانَستُم مِنهُم رُشدًا فَادفَعوا إِلَيهِم أَموٰلَهُم وَلا تَأكُلوها إِسرافًا وَبِدارًا أَن يَكبَروا وَمَن كانَ غَنِيًّا فَليَستَعفِف وَمَن كانَ فَقيرًا فَليَأكُل بِالمَعروفِ فَإِذا دَفَعتُم إِلَيهِم أَموٰلَهُم فَأَشهِدوا عَلَيهِم وَكَفىٰ بِاللَّهِ حَسيبًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@d{لِلرِّجالِ نَصيبٌ مِمّا تَرَكَ الوٰلِدانِ وَالأَقرَبونَ وَلِلنِّساءِ نَصيبٌ مِمّا تَرَكَ الوٰلِدانِ وَالأَقرَبونَ مِمّا قَلَّ مِنهُ أَو كَثُرَ نَصيبًا مَفروضًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@di{وَإِذا حَضَرَ القِسمَةَ أُولُوا القُربىٰ وَاليَتٰمىٰ وَالمَسٰكينُ فَارزُقوهُم مِنهُ وَقولوا لَهُم قَولًا مَعروفًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dii{وَليَخشَ الَّذينَ لَو تَرَكوا مِن خَلفِهِم ذُرِّيَّةً ضِعٰفًا خافوا عَلَيهِم فَليَتَّقُوا اللَّهَ وَليَقولوا قَولًا سَديدًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@diii{إِنَّ الَّذينَ يَأكُلونَ أَموٰلَ اليَتٰمىٰ ظُلمًا إِنَّما يَأكُلونَ فى بُطونِهِم نارًا وَسَيَصلَونَ سَعيرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@div{يوصيكُمُ اللَّهُ فى أَولٰدِكُم لِلذَّكَرِ مِثلُ حَظِّ الأُنثَيَينِ فَإِن كُنَّ نِساءً فَوقَ اثنَتَينِ فَلَهُنَّ ثُلُثا ما تَرَكَ وَإِن كانَت وٰحِدَةً فَلَهَا النِّصفُ وَلِأَبَوَيهِ لِكُلِّ وٰحِدٍ مِنهُمَا السُّدُسُ مِمّا تَرَكَ إِن كانَ لَهُ وَلَدٌ فَإِن لَم يَكُن لَهُ وَلَدٌ وَوَرِثَهُ أَبَواهُ فَلِأُمِّهِ الثُّلُثُ فَإِن كانَ لَهُ إِخوَةٌ فَلِأُمِّهِ السُّدُسُ مِن بَعدِ وَصِيَّةٍ يوصى بِها أَو دَينٍ ءاباؤُكُم وَأَبناؤُكُم لا تَدرونَ أَيُّهُم أَقرَبُ لَكُم نَفعًا فَريضَةً مِنَ اللَّهِ إِنَّ اللَّهَ كانَ عَليمًا حَكيمًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dv{وَلَكُم نِصفُ ما تَرَكَ أَزوٰجُكُم إِن لَم يَكُن لَهُنَّ وَلَدٌ فَإِن كانَ لَهُنَّ وَلَدٌ فَلَكُمُ الرُّبُعُ مِمّا تَرَكنَ مِن بَعدِ وَصِيَّةٍ يوصينَ بِها أَو دَينٍ وَلَهُنَّ الرُّبُعُ مِمّا تَرَكتُم إِن لَم يَكُن لَكُم وَلَدٌ فَإِن كانَ لَكُم وَلَدٌ فَلَهُنَّ الثُّمُنُ مِمّا تَرَكتُم مِن بَعدِ وَصِيَّةٍ توصونَ بِها أَو دَينٍ وَإِن كانَ رَجُلٌ يورَثُ كَلٰلَةً أَوِ امرَأَةٌ وَلَهُ أَخٌ أَو أُختٌ فَلِكُلِّ وٰحِدٍ مِنهُمَا السُّدُسُ فَإِن كانوا أَكثَرَ مِن ذٰلِكَ فَهُم شُرَكاءُ فِى الثُّلُثِ مِن بَعدِ وَصِيَّةٍ يوصىٰ بِها أَو دَينٍ غَيرَ مُضارٍّ وَصِيَّةً مِنَ اللَّهِ وَاللَّهُ عَليمٌ حَليمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dvi{تِلكَ حُدودُ اللَّهِ وَمَن يُطِعِ اللَّهَ وَرَسولَهُ يُدخِلهُ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها وَذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dvii{وَمَن يَعصِ اللَّهَ وَرَسولَهُ وَيَتَعَدَّ حُدودَهُ يُدخِلهُ نارًا خٰلِدًا فيها وَلَهُ عَذابٌ مُهينٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dviii{وَالّٰتى يَأتينَ الفٰحِشَةَ مِن نِسائِكُم فَاستَشهِدوا عَلَيهِنَّ أَربَعَةً مِنكُم فَإِن شَهِدوا فَأَمسِكوهُنَّ فِى البُيوتِ حَتّىٰ يَتَوَفّىٰهُنَّ المَوتُ أَو يَجعَلَ اللَّهُ لَهُنَّ سَبيلًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dix{وَالَّذانِ يَأتِيٰنِها مِنكُم فَـٔاذوهُما فَإِن تابا وَأَصلَحا فَأَعرِضوا عَنهُما إِنَّ اللَّهَ كانَ تَوّابًا رَحيمًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dx{إِنَّمَا التَّوبَةُ عَلَى اللَّهِ لِلَّذينَ يَعمَلونَ السّوءَ بِجَهٰلَةٍ ثُمَّ يَتوبونَ مِن قَريبٍ فَأُولٰئِكَ يَتوبُ اللَّهُ عَلَيهِم وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dxi{وَلَيسَتِ التَّوبَةُ لِلَّذينَ يَعمَلونَ السَّيِّـٔاتِ حَتّىٰ إِذا حَضَرَ أَحَدَهُمُ المَوتُ قالَ إِنّى تُبتُ الـٰٔنَ وَلَا الَّذينَ يَموتونَ وَهُم كُفّارٌ أُولٰئِكَ أَعتَدنا لَهُم عَذابًا أَليمًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dxii{يٰأَيُّهَا الَّذينَ ءامَنوا لا يَحِلُّ لَكُم أَن تَرِثُوا النِّساءَ كَرهًا وَلا تَعضُلوهُنَّ لِتَذهَبوا بِبَعضِ ما ءاتَيتُموهُنَّ إِلّا أَن يَأتينَ بِفٰحِشَةٍ مُبَيِّنَةٍ وَعاشِروهُنَّ بِالمَعروفِ فَإِن كَرِهتُموهُنَّ فَعَسىٰ أَن تَكرَهوا شَيـًٔا وَيَجعَلَ اللَّهُ فيهِ خَيرًا كَثيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dxiii{وَإِن أَرَدتُمُ استِبدالَ زَوجٍ مَكانَ زَوجٍ وَءاتَيتُم إِحدىٰهُنَّ قِنطارًا فَلا تَأخُذوا مِنهُ شَيـًٔا أَتَأخُذونَهُ بُهتٰنًا وَإِثمًا مُبينًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dxiv{وَكَيفَ تَأخُذونَهُ وَقَد أَفضىٰ بَعضُكُم إِلىٰ بَعضٍ وَأَخَذنَ مِنكُم ميثٰقًا غَليظًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dxv{وَلا تَنكِحوا ما نَكَحَ ءاباؤُكُم مِنَ النِّساءِ إِلّا ما قَد سَلَفَ إِنَّهُ كانَ فٰحِشَةً وَمَقتًا وَساءَ سَبيلًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dxvi{حُرِّمَت عَلَيكُم أُمَّهٰتُكُم وَبَناتُكُم وَأَخَوٰتُكُم وَعَمّٰتُكُم وَخٰلٰتُكُم وَبَناتُ الأَخِ وَبَناتُ الأُختِ وَأُمَّهٰتُكُمُ الّٰتى أَرضَعنَكُم وَأَخَوٰتُكُم مِنَ الرَّضٰعَةِ وَأُمَّهٰتُ نِسائِكُم وَرَبٰئِبُكُمُ الّٰتى فى حُجورِكُم مِن نِسائِكُمُ الّٰتى دَخَلتُم بِهِنَّ فَإِن لَم تَكونوا دَخَلتُم بِهِنَّ فَلا جُناحَ عَلَيكُم وَحَلٰئِلُ أَبنائِكُمُ الَّذينَ مِن أَصلٰبِكُم وَأَن تَجمَعوا بَينَ الأُختَينِ إِلّا ما قَد سَلَفَ إِنَّ اللَّهَ كانَ غَفورًا رَحيمًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dxvii{وَالمُحصَنٰتُ مِنَ النِّساءِ إِلّا ما مَلَكَت أَيمٰنُكُم كِتٰبَ اللَّهِ عَلَيكُم وَأُحِلَّ لَكُم ما وَراءَ ذٰلِكُم أَن تَبتَغوا بِأَموٰلِكُم مُحصِنينَ غَيرَ مُسٰفِحينَ فَمَا استَمتَعتُم بِهِ مِنهُنَّ فَـٔاتوهُنَّ أُجورَهُنَّ فَريضَةً وَلا جُناحَ عَلَيكُم فيما تَرٰضَيتُم بِهِ مِن بَعدِ الفَريضَةِ إِنَّ اللَّهَ كانَ عَليمًا حَكيمًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dxviii{وَمَن لَم يَستَطِع مِنكُم طَولًا أَن يَنكِحَ المُحصَنٰتِ المُؤمِنٰتِ فَمِن ما مَلَكَت أَيمٰنُكُم مِن فَتَيٰتِكُمُ المُؤمِنٰتِ وَاللَّهُ أَعلَمُ بِإيمٰنِكُم بَعضُكُم مِن بَعضٍ فَانكِحوهُنَّ بِإِذنِ أَهلِهِنَّ وَءاتوهُنَّ أُجورَهُنَّ بِالمَعروفِ مُحصَنٰتٍ غَيرَ مُسٰفِحٰتٍ وَلا مُتَّخِذٰتِ أَخدانٍ فَإِذا أُحصِنَّ فَإِن أَتَينَ بِفٰحِشَةٍ فَعَلَيهِنَّ نِصفُ ما عَلَى المُحصَنٰتِ مِنَ العَذابِ ذٰلِكَ لِمَن خَشِىَ العَنَتَ مِنكُم وَأَن تَصبِروا خَيرٌ لَكُم وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dxix{يُريدُ اللَّهُ لِيُبَيِّنَ لَكُم وَيَهدِيَكُم سُنَنَ الَّذينَ مِن قَبلِكُم وَيَتوبَ عَلَيكُم وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dxx{وَاللَّهُ يُريدُ أَن يَتوبَ عَلَيكُم وَيُريدُ الَّذينَ يَتَّبِعونَ الشَّهَوٰتِ أَن تَميلوا مَيلًا عَظيمًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dxxi{يُريدُ اللَّهُ أَن يُخَفِّفَ عَنكُم وَخُلِقَ الإِنسٰنُ ضَعيفًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dxxii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَأكُلوا أَموٰلَكُم بَينَكُم بِالبٰطِلِ إِلّا أَن تَكونَ تِجٰرَةً عَن تَراضٍ مِنكُم وَلا تَقتُلوا أَنفُسَكُم إِنَّ اللَّهَ كانَ بِكُم رَحيمًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dxxiii{وَمَن يَفعَل ذٰلِكَ عُدوٰنًا وَظُلمًا فَسَوفَ نُصليهِ نارًا وَكانَ ذٰلِكَ عَلَى اللَّهِ يَسيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dxxiv{إِن تَجتَنِبوا كَبائِرَ ما تُنهَونَ عَنهُ نُكَفِّر عَنكُم سَيِّـٔاتِكُم وَنُدخِلكُم مُدخَلًا كَريمًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dxxv{وَلا تَتَمَنَّوا ما فَضَّلَ اللَّهُ بِهِ بَعضَكُم عَلىٰ بَعضٍ لِلرِّجالِ نَصيبٌ مِمَّا اكتَسَبوا وَلِلنِّساءِ نَصيبٌ مِمَّا اكتَسَبنَ وَسـَٔلُوا اللَّهَ مِن فَضلِهِ إِنَّ اللَّهَ كانَ بِكُلِّ شَيءٍ عَليمًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dxxvi{وَلِكُلٍّ جَعَلنا مَوٰلِىَ مِمّا تَرَكَ الوٰلِدانِ وَالأَقرَبونَ وَالَّذينَ عَقَدَت أَيمٰنُكُم فَـٔاتوهُم نَصيبَهُم إِنَّ اللَّهَ كانَ عَلىٰ كُلِّ شَيءٍ شَهيدًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dxxvii{الرِّجالُ قَوّٰمونَ عَلَى النِّساءِ بِما فَضَّلَ اللَّهُ بَعضَهُم عَلىٰ بَعضٍ وَبِما أَنفَقوا مِن أَموٰلِهِم فَالصّٰلِحٰتُ قٰنِتٰتٌ حٰفِظٰتٌ لِلغَيبِ بِما حَفِظَ اللَّهُ وَالّٰتى تَخافونَ نُشوزَهُنَّ فَعِظوهُنَّ وَاهجُروهُنَّ فِى المَضاجِعِ وَاضرِبوهُنَّ فَإِن أَطَعنَكُم فَلا تَبغوا عَلَيهِنَّ سَبيلًا إِنَّ اللَّهَ كانَ عَلِيًّا كَبيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dxxviii{وَإِن خِفتُم شِقاقَ بَينِهِما فَابعَثوا حَكَمًا مِن أَهلِهِ وَحَكَمًا مِن أَهلِها إِن يُريدا إِصلٰحًا يُوَفِّقِ اللَّهُ بَينَهُما إِنَّ اللَّهَ كانَ عَليمًا خَبيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dxxix{وَاعبُدُوا اللَّهَ وَلا تُشرِكوا بِهِ شَيـًٔا وَبِالوٰلِدَينِ إِحسٰنًا وَبِذِى القُربىٰ وَاليَتٰمىٰ وَالمَسٰكينِ وَالجارِ ذِى القُربىٰ وَالجارِ الجُنُبِ وَالصّاحِبِ بِالجَنبِ وَابنِ السَّبيلِ وَما مَلَكَت أَيمٰنُكُم إِنَّ اللَّهَ لا يُحِبُّ مَن كانَ مُختالًا فَخورًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dxxx{الَّذينَ يَبخَلونَ وَيَأمُرونَ النّاسَ بِالبُخلِ وَيَكتُمونَ ما ءاتىٰهُمُ اللَّهُ مِن فَضلِهِ وَأَعتَدنا لِلكٰفِرينَ عَذابًا مُهينًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dxxxi{وَالَّذينَ يُنفِقونَ أَموٰلَهُم رِئاءَ النّاسِ وَلا يُؤمِنونَ بِاللَّهِ وَلا بِاليَومِ الءاخِرِ وَمَن يَكُنِ الشَّيطٰنُ لَهُ قَرينًا فَساءَ قَرينًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dxxxii{وَماذا عَلَيهِم لَو ءامَنوا بِاللَّهِ وَاليَومِ الءاخِرِ وَأَنفَقوا مِمّا رَزَقَهُمُ اللَّهُ وَكانَ اللَّهُ بِهِم عَليمًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dxxxiii{إِنَّ اللَّهَ لا يَظلِمُ مِثقالَ ذَرَّةٍ وَإِن تَكُ حَسَنَةً يُضٰعِفها وَيُؤتِ مِن لَدُنهُ أَجرًا عَظيمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dxxxiv{فَكَيفَ إِذا جِئنا مِن كُلِّ أُمَّةٍ بِشَهيدٍ وَجِئنا بِكَ عَلىٰ هٰؤُلاءِ شَهيدًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dxxxv{يَومَئِذٍ يَوَدُّ الَّذينَ كَفَروا وَعَصَوُا الرَّسولَ لَو تُسَوّىٰ بِهِمُ الأَرضُ وَلا يَكتُمونَ اللَّهَ حَديثًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dxxxvi{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَقرَبُوا الصَّلوٰةَ وَأَنتُم سُكٰرىٰ حَتّىٰ تَعلَموا ما تَقولونَ وَلا جُنُبًا إِلّا عابِرى سَبيلٍ حَتّىٰ تَغتَسِلوا وَإِن كُنتُم مَرضىٰ أَو عَلىٰ سَفَرٍ أَو جاءَ أَحَدٌ مِنكُم مِنَ الغائِطِ أَو لٰمَستُمُ النِّساءَ فَلَم تَجِدوا ماءً فَتَيَمَّموا صَعيدًا طَيِّبًا فَامسَحوا بِوُجوهِكُم وَأَيديكُم إِنَّ اللَّهَ كانَ عَفُوًّا غَفورًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dxxxvii{أَلَم تَرَ إِلَى الَّذينَ أوتوا نَصيبًا مِنَ الكِتٰبِ يَشتَرونَ الضَّلٰلَةَ وَيُريدونَ أَن تَضِلُّوا السَّبيلَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dxxxviii{وَاللَّهُ أَعلَمُ بِأَعدائِكُم وَكَفىٰ بِاللَّهِ وَلِيًّا وَكَفىٰ بِاللَّهِ نَصيرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dxxxix{مِنَ الَّذينَ هادوا يُحَرِّفونَ الكَلِمَ عَن مَواضِعِهِ وَيَقولونَ سَمِعنا وَعَصَينا وَاسمَع غَيرَ مُسمَعٍ وَرٰعِنا لَيًّا بِأَلسِنَتِهِم وَطَعنًا فِى الدّينِ وَلَو أَنَّهُم قالوا سَمِعنا وَأَطَعنا وَاسمَع وَانظُرنا لَكانَ خَيرًا لَهُم وَأَقوَمَ وَلٰكِن لَعَنَهُمُ اللَّهُ بِكُفرِهِم فَلا يُؤمِنونَ إِلّا قَليلًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dxl{يٰأَيُّهَا الَّذينَ أوتُوا الكِتٰبَ ءامِنوا بِما نَزَّلنا مُصَدِّقًا لِما مَعَكُم مِن قَبلِ أَن نَطمِسَ وُجوهًا فَنَرُدَّها عَلىٰ أَدبارِها أَو نَلعَنَهُم كَما لَعَنّا أَصحٰبَ السَّبتِ وَكانَ أَمرُ اللَّهِ مَفعولًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dxli{إِنَّ اللَّهَ لا يَغفِرُ أَن يُشرَكَ بِهِ وَيَغفِرُ ما دونَ ذٰلِكَ لِمَن يَشاءُ وَمَن يُشرِك بِاللَّهِ فَقَدِ افتَرىٰ إِثمًا عَظيمًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dxlii{أَلَم تَرَ إِلَى الَّذينَ يُزَكّونَ أَنفُسَهُم بَلِ اللَّهُ يُزَكّى مَن يَشاءُ وَلا يُظلَمونَ فَتيلًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dxliii{انظُر كَيفَ يَفتَرونَ عَلَى اللَّهِ الكَذِبَ وَكَفىٰ بِهِ إِثمًا مُبينًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dxliv{أَلَم تَرَ إِلَى الَّذينَ أوتوا نَصيبًا مِنَ الكِتٰبِ يُؤمِنونَ بِالجِبتِ وَالطّٰغوتِ وَيَقولونَ لِلَّذينَ كَفَروا هٰؤُلاءِ أَهدىٰ مِنَ الَّذينَ ءامَنوا سَبيلًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dxlv{أُولٰئِكَ الَّذينَ لَعَنَهُمُ اللَّهُ وَمَن يَلعَنِ اللَّهُ فَلَن تَجِدَ لَهُ نَصيرًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dxlvi{أَم لَهُم نَصيبٌ مِنَ المُلكِ فَإِذًا لا يُؤتونَ النّاسَ نَقيرًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dxlvii{أَم يَحسُدونَ النّاسَ عَلىٰ ما ءاتىٰهُمُ اللَّهُ مِن فَضلِهِ فَقَد ءاتَينا ءالَ إِبرٰهيمَ الكِتٰبَ وَالحِكمَةَ وَءاتَينٰهُم مُلكًا عَظيمًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dxlviii{فَمِنهُم مَن ءامَنَ بِهِ وَمِنهُم مَن صَدَّ عَنهُ وَكَفىٰ بِجَهَنَّمَ سَعيرًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dxlix{إِنَّ الَّذينَ كَفَروا بِـٔايٰتِنا سَوفَ نُصليهِم نارًا كُلَّما نَضِجَت جُلودُهُم بَدَّلنٰهُم جُلودًا غَيرَها لِيَذوقُوا العَذابَ إِنَّ اللَّهَ كانَ عَزيزًا حَكيمًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dl{وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ سَنُدخِلُهُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها أَبَدًا لَهُم فيها أَزوٰجٌ مُطَهَّرَةٌ وَنُدخِلُهُم ظِلًّا ظَليلًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dli{إِنَّ اللَّهَ يَأمُرُكُم أَن تُؤَدُّوا الأَمٰنٰتِ إِلىٰ أَهلِها وَإِذا حَكَمتُم بَينَ النّاسِ أَن تَحكُموا بِالعَدلِ إِنَّ اللَّهَ نِعِمّا يَعِظُكُم بِهِ إِنَّ اللَّهَ كانَ سَميعًا بَصيرًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dlii{يٰأَيُّهَا الَّذينَ ءامَنوا أَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ وَأُولِى الأَمرِ مِنكُم فَإِن تَنٰزَعتُم فى شَيءٍ فَرُدّوهُ إِلَى اللَّهِ وَالرَّسولِ إِن كُنتُم تُؤمِنونَ بِاللَّهِ وَاليَومِ الءاخِرِ ذٰلِكَ خَيرٌ وَأَحسَنُ تَأويلًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dliii{أَلَم تَرَ إِلَى الَّذينَ يَزعُمونَ أَنَّهُم ءامَنوا بِما أُنزِلَ إِلَيكَ وَما أُنزِلَ مِن قَبلِكَ يُريدونَ أَن يَتَحاكَموا إِلَى الطّٰغوتِ وَقَد أُمِروا أَن يَكفُروا بِهِ وَيُريدُ الشَّيطٰنُ أَن يُضِلَّهُم ضَلٰلًا بَعيدًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dliv{وَإِذا قيلَ لَهُم تَعالَوا إِلىٰ ما أَنزَلَ اللَّهُ وَإِلَى الرَّسولِ رَأَيتَ المُنٰفِقينَ يَصُدّونَ عَنكَ صُدودًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dlv{فَكَيفَ إِذا أَصٰبَتهُم مُصيبَةٌ بِما قَدَّمَت أَيديهِم ثُمَّ جاءوكَ يَحلِفونَ بِاللَّهِ إِن أَرَدنا إِلّا إِحسٰنًا وَتَوفيقًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dlvi{أُولٰئِكَ الَّذينَ يَعلَمُ اللَّهُ ما فى قُلوبِهِم فَأَعرِض عَنهُم وَعِظهُم وَقُل لَهُم فى أَنفُسِهِم قَولًا بَليغًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dlvii{وَما أَرسَلنا مِن رَسولٍ إِلّا لِيُطاعَ بِإِذنِ اللَّهِ وَلَو أَنَّهُم إِذ ظَلَموا أَنفُسَهُم جاءوكَ فَاستَغفَرُوا اللَّهَ وَاستَغفَرَ لَهُمُ الرَّسولُ لَوَجَدُوا اللَّهَ تَوّابًا رَحيمًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dlviii{فَلا وَرَبِّكَ لا يُؤمِنونَ حَتّىٰ يُحَكِّموكَ فيما شَجَرَ بَينَهُم ثُمَّ لا يَجِدوا فى أَنفُسِهِم حَرَجًا مِمّا قَضَيتَ وَيُسَلِّموا تَسليمًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dlix{وَلَو أَنّا كَتَبنا عَلَيهِم أَنِ اقتُلوا أَنفُسَكُم أَوِ اخرُجوا مِن دِيٰرِكُم ما فَعَلوهُ إِلّا قَليلٌ مِنهُم وَلَو أَنَّهُم فَعَلوا ما يوعَظونَ بِهِ لَكانَ خَيرًا لَهُم وَأَشَدَّ تَثبيتًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dlx{وَإِذًا لَءاتَينٰهُم مِن لَدُنّا أَجرًا عَظيمًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dlxi{وَلَهَدَينٰهُم صِرٰطًا مُستَقيمًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dlxii{وَمَن يُطِعِ اللَّهَ وَالرَّسولَ فَأُولٰئِكَ مَعَ الَّذينَ أَنعَمَ اللَّهُ عَلَيهِم مِنَ النَّبِيّۦنَ وَالصِّدّيقينَ وَالشُّهَداءِ وَالصّٰلِحينَ وَحَسُنَ أُولٰئِكَ رَفيقًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dlxiii{ذٰلِكَ الفَضلُ مِنَ اللَّهِ وَكَفىٰ بِاللَّهِ عَليمًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dlxiv{يٰأَيُّهَا الَّذينَ ءامَنوا خُذوا حِذرَكُم فَانفِروا ثُباتٍ أَوِ انفِروا جَميعًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dlxv{وَإِنَّ مِنكُم لَمَن لَيُبَطِّئَنَّ فَإِن أَصٰبَتكُم مُصيبَةٌ قالَ قَد أَنعَمَ اللَّهُ عَلَىَّ إِذ لَم أَكُن مَعَهُم شَهيدًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dlxvi{وَلَئِن أَصٰبَكُم فَضلٌ مِنَ اللَّهِ لَيَقولَنَّ كَأَن لَم تَكُن بَينَكُم وَبَينَهُ مَوَدَّةٌ يٰلَيتَنى كُنتُ مَعَهُم فَأَفوزَ فَوزًا عَظيمًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dlxvii{فَليُقٰتِل فى سَبيلِ اللَّهِ الَّذينَ يَشرونَ الحَيوٰةَ الدُّنيا بِالءاخِرَةِ وَمَن يُقٰتِل فى سَبيلِ اللَّهِ فَيُقتَل أَو يَغلِب فَسَوفَ نُؤتيهِ أَجرًا عَظيمًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dlxviii{وَما لَكُم لا تُقٰتِلونَ فى سَبيلِ اللَّهِ وَالمُستَضعَفينَ مِنَ الرِّجالِ وَالنِّساءِ وَالوِلدٰنِ الَّذينَ يَقولونَ رَبَّنا أَخرِجنا مِن هٰذِهِ القَريَةِ الظّالِمِ أَهلُها وَاجعَل لَنا مِن لَدُنكَ وَلِيًّا وَاجعَل لَنا مِن لَدُنكَ نَصيرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dlxix{الَّذينَ ءامَنوا يُقٰتِلونَ فى سَبيلِ اللَّهِ وَالَّذينَ كَفَروا يُقٰتِلونَ فى سَبيلِ الطّٰغوتِ فَقٰتِلوا أَولِياءَ الشَّيطٰنِ إِنَّ كَيدَ الشَّيطٰنِ كانَ ضَعيفًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dlxx{أَلَم تَرَ إِلَى الَّذينَ قيلَ لَهُم كُفّوا أَيدِيَكُم وَأَقيمُوا الصَّلوٰةَ وَءاتُوا الزَّكوٰةَ فَلَمّا كُتِبَ عَلَيهِمُ القِتالُ إِذا فَريقٌ مِنهُم يَخشَونَ النّاسَ كَخَشيَةِ اللَّهِ أَو أَشَدَّ خَشيَةً وَقالوا رَبَّنا لِمَ كَتَبتَ عَلَينَا القِتالَ لَولا أَخَّرتَنا إِلىٰ أَجَلٍ قَريبٍ قُل مَتٰعُ الدُّنيا قَليلٌ وَالءاخِرَةُ خَيرٌ لِمَنِ اتَّقىٰ وَلا تُظلَمونَ فَتيلًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dlxxi{أَينَما تَكونوا يُدرِككُمُ المَوتُ وَلَو كُنتُم فى بُروجٍ مُشَيَّدَةٍ وَإِن تُصِبهُم حَسَنَةٌ يَقولوا هٰذِهِ مِن عِندِ اللَّهِ وَإِن تُصِبهُم سَيِّئَةٌ يَقولوا هٰذِهِ مِن عِندِكَ قُل كُلٌّ مِن عِندِ اللَّهِ فَمالِ هٰؤُلاءِ القَومِ لا يَكادونَ يَفقَهونَ حَديثًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dlxxii{ما أَصابَكَ مِن حَسَنَةٍ فَمِنَ اللَّهِ وَما أَصابَكَ مِن سَيِّئَةٍ فَمِن نَفسِكَ وَأَرسَلنٰكَ لِلنّاسِ رَسولًا وَكَفىٰ بِاللَّهِ شَهيدًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dlxxiii{مَن يُطِعِ الرَّسولَ فَقَد أَطاعَ اللَّهَ وَمَن تَوَلّىٰ فَما أَرسَلنٰكَ عَلَيهِم حَفيظًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dlxxiv{وَيَقولونَ طاعَةٌ فَإِذا بَرَزوا مِن عِندِكَ بَيَّتَ طائِفَةٌ مِنهُم غَيرَ الَّذى تَقولُ وَاللَّهُ يَكتُبُ ما يُبَيِّتونَ فَأَعرِض عَنهُم وَتَوَكَّل عَلَى اللَّهِ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dlxxv{أَفَلا يَتَدَبَّرونَ القُرءانَ وَلَو كانَ مِن عِندِ غَيرِ اللَّهِ لَوَجَدوا فيهِ اختِلٰفًا كَثيرًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dlxxvi{وَإِذا جاءَهُم أَمرٌ مِنَ الأَمنِ أَوِ الخَوفِ أَذاعوا بِهِ وَلَو رَدّوهُ إِلَى الرَّسولِ وَإِلىٰ أُولِى الأَمرِ مِنهُم لَعَلِمَهُ الَّذينَ يَستَنبِطونَهُ مِنهُم وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ لَاتَّبَعتُمُ الشَّيطٰنَ إِلّا قَليلًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dlxxvii{فَقٰتِل فى سَبيلِ اللَّهِ لا تُكَلَّفُ إِلّا نَفسَكَ وَحَرِّضِ المُؤمِنينَ عَسَى اللَّهُ أَن يَكُفَّ بَأسَ الَّذينَ كَفَروا وَاللَّهُ أَشَدُّ بَأسًا وَأَشَدُّ تَنكيلًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dlxxviii{مَن يَشفَع شَفٰعَةً حَسَنَةً يَكُن لَهُ نَصيبٌ مِنها وَمَن يَشفَع شَفٰعَةً سَيِّئَةً يَكُن لَهُ كِفلٌ مِنها وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ مُقيتًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dlxxix{وَإِذا حُيّيتُم بِتَحِيَّةٍ فَحَيّوا بِأَحسَنَ مِنها أَو رُدّوها إِنَّ اللَّهَ كانَ عَلىٰ كُلِّ شَيءٍ حَسيبًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dlxxx{اللَّهُ لا إِلٰهَ إِلّا هُوَ لَيَجمَعَنَّكُم إِلىٰ يَومِ القِيٰمَةِ لا رَيبَ فيهِ وَمَن أَصدَقُ مِنَ اللَّهِ حَديثًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dlxxxi{فَما لَكُم فِى المُنٰفِقينَ فِئَتَينِ وَاللَّهُ أَركَسَهُم بِما كَسَبوا أَتُريدونَ أَن تَهدوا مَن أَضَلَّ اللَّهُ وَمَن يُضلِلِ اللَّهُ فَلَن تَجِدَ لَهُ سَبيلًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dlxxxii{وَدّوا لَو تَكفُرونَ كَما كَفَروا فَتَكونونَ سَواءً فَلا تَتَّخِذوا مِنهُم أَولِياءَ حَتّىٰ يُهاجِروا فى سَبيلِ اللَّهِ فَإِن تَوَلَّوا فَخُذوهُم وَاقتُلوهُم حَيثُ وَجَدتُموهُم وَلا تَتَّخِذوا مِنهُم وَلِيًّا وَلا نَصيرًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dlxxxiii{إِلَّا الَّذينَ يَصِلونَ إِلىٰ قَومٍ بَينَكُم وَبَينَهُم ميثٰقٌ أَو جاءوكُم حَصِرَت صُدورُهُم أَن يُقٰتِلوكُم أَو يُقٰتِلوا قَومَهُم وَلَو شاءَ اللَّهُ لَسَلَّطَهُم عَلَيكُم فَلَقٰتَلوكُم فَإِنِ اعتَزَلوكُم فَلَم يُقٰتِلوكُم وَأَلقَوا إِلَيكُمُ السَّلَمَ فَما جَعَلَ اللَّهُ لَكُم عَلَيهِم سَبيلًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dlxxxiv{سَتَجِدونَ ءاخَرينَ يُريدونَ أَن يَأمَنوكُم وَيَأمَنوا قَومَهُم كُلَّ ما رُدّوا إِلَى الفِتنَةِ أُركِسوا فيها فَإِن لَم يَعتَزِلوكُم وَيُلقوا إِلَيكُمُ السَّلَمَ وَيَكُفّوا أَيدِيَهُم فَخُذوهُم وَاقتُلوهُم حَيثُ ثَقِفتُموهُم وَأُولٰئِكُم جَعَلنا لَكُم عَلَيهِم سُلطٰنًا مُبينًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dlxxxv{وَما كانَ لِمُؤمِنٍ أَن يَقتُلَ مُؤمِنًا إِلّا خَطَـًٔا وَمَن قَتَلَ مُؤمِنًا خَطَـًٔا فَتَحريرُ رَقَبَةٍ مُؤمِنَةٍ وَدِيَةٌ مُسَلَّمَةٌ إِلىٰ أَهلِهِ إِلّا أَن يَصَّدَّقوا فَإِن كانَ مِن قَومٍ عَدُوٍّ لَكُم وَهُوَ مُؤمِنٌ فَتَحريرُ رَقَبَةٍ مُؤمِنَةٍ وَإِن كانَ مِن قَومٍ بَينَكُم وَبَينَهُم ميثٰقٌ فَدِيَةٌ مُسَلَّمَةٌ إِلىٰ أَهلِهِ وَتَحريرُ رَقَبَةٍ مُؤمِنَةٍ فَمَن لَم يَجِد فَصِيامُ شَهرَينِ مُتَتابِعَينِ تَوبَةً مِنَ اللَّهِ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dlxxxvi{وَمَن يَقتُل مُؤمِنًا مُتَعَمِّدًا فَجَزاؤُهُ جَهَنَّمُ خٰلِدًا فيها وَغَضِبَ اللَّهُ عَلَيهِ وَلَعَنَهُ وَأَعَدَّ لَهُ عَذابًا عَظيمًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dlxxxvii{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا ضَرَبتُم فى سَبيلِ اللَّهِ فَتَبَيَّنوا وَلا تَقولوا لِمَن أَلقىٰ إِلَيكُمُ السَّلٰمَ لَستَ مُؤمِنًا تَبتَغونَ عَرَضَ الحَيوٰةِ الدُّنيا فَعِندَ اللَّهِ مَغانِمُ كَثيرَةٌ كَذٰلِكَ كُنتُم مِن قَبلُ فَمَنَّ اللَّهُ عَلَيكُم فَتَبَيَّنوا إِنَّ اللَّهَ كانَ بِما تَعمَلونَ خَبيرًا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dlxxxviii{لا يَستَوِى القٰعِدونَ مِنَ المُؤمِنينَ غَيرُ أُولِى الضَّرَرِ وَالمُجٰهِدونَ فى سَبيلِ اللَّهِ بِأَموٰلِهِم وَأَنفُسِهِم فَضَّلَ اللَّهُ المُجٰهِدينَ بِأَموٰلِهِم وَأَنفُسِهِم عَلَى القٰعِدينَ دَرَجَةً وَكُلًّا وَعَدَ اللَّهُ الحُسنىٰ وَفَضَّلَ اللَّهُ المُجٰهِدينَ عَلَى القٰعِدينَ أَجرًا عَظيمًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dlxxxix{دَرَجٰتٍ مِنهُ وَمَغفِرَةً وَرَحمَةً وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dxc{إِنَّ الَّذينَ تَوَفّىٰهُمُ المَلٰئِكَةُ ظالِمى أَنفُسِهِم قالوا فيمَ كُنتُم قالوا كُنّا مُستَضعَفينَ فِى الأَرضِ قالوا أَلَم تَكُن أَرضُ اللَّهِ وٰسِعَةً فَتُهاجِروا فيها فَأُولٰئِكَ مَأوىٰهُم جَهَنَّمُ وَساءَت مَصيرًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dxci{إِلَّا المُستَضعَفينَ مِنَ الرِّجالِ وَالنِّساءِ وَالوِلدٰنِ لا يَستَطيعونَ حيلَةً وَلا يَهتَدونَ سَبيلًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dxcii{فَأُولٰئِكَ عَسَى اللَّهُ أَن يَعفُوَ عَنهُم وَكانَ اللَّهُ عَفُوًّا غَفورًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dxciii{وَمَن يُهاجِر فى سَبيلِ اللَّهِ يَجِد فِى الأَرضِ مُرٰغَمًا كَثيرًا وَسَعَةً وَمَن يَخرُج مِن بَيتِهِ مُهاجِرًا إِلَى اللَّهِ وَرَسولِهِ ثُمَّ يُدرِكهُ المَوتُ فَقَد وَقَعَ أَجرُهُ عَلَى اللَّهِ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dxciv{وَإِذا ضَرَبتُم فِى الأَرضِ فَلَيسَ عَلَيكُم جُناحٌ أَن تَقصُروا مِنَ الصَّلوٰةِ إِن خِفتُم أَن يَفتِنَكُمُ الَّذينَ كَفَروا إِنَّ الكٰفِرينَ كانوا لَكُم عَدُوًّا مُبينًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dxcv{وَإِذا كُنتَ فيهِم فَأَقَمتَ لَهُمُ الصَّلوٰةَ فَلتَقُم طائِفَةٌ مِنهُم مَعَكَ وَليَأخُذوا أَسلِحَتَهُم فَإِذا سَجَدوا فَليَكونوا مِن وَرائِكُم وَلتَأتِ طائِفَةٌ أُخرىٰ لَم يُصَلّوا فَليُصَلّوا مَعَكَ وَليَأخُذوا حِذرَهُم وَأَسلِحَتَهُم وَدَّ الَّذينَ كَفَروا لَو تَغفُلونَ عَن أَسلِحَتِكُم وَأَمتِعَتِكُم فَيَميلونَ عَلَيكُم مَيلَةً وٰحِدَةً وَلا جُناحَ عَلَيكُم إِن كانَ بِكُم أَذًى مِن مَطَرٍ أَو كُنتُم مَرضىٰ أَن تَضَعوا أَسلِحَتَكُم وَخُذوا حِذرَكُم إِنَّ اللَّهَ أَعَدَّ لِلكٰفِرينَ عَذابًا مُهينًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dxcvi{فَإِذا قَضَيتُمُ الصَّلوٰةَ فَاذكُرُوا اللَّهَ قِيٰمًا وَقُعودًا وَعَلىٰ جُنوبِكُم فَإِذَا اطمَأنَنتُم فَأَقيمُوا الصَّلوٰةَ إِنَّ الصَّلوٰةَ كانَت عَلَى المُؤمِنينَ كِتٰبًا مَوقوتًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dxcvii{وَلا تَهِنوا فِى ابتِغاءِ القَومِ إِن تَكونوا تَألَمونَ فَإِنَّهُم يَألَمونَ كَما تَألَمونَ وَتَرجونَ مِنَ اللَّهِ ما لا يَرجونَ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dxcviii{إِنّا أَنزَلنا إِلَيكَ الكِتٰبَ بِالحَقِّ لِتَحكُمَ بَينَ النّاسِ بِما أَرىٰكَ اللَّهُ وَلا تَكُن لِلخائِنينَ خَصيمًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dxcix{وَاستَغفِرِ اللَّهَ إِنَّ اللَّهَ كانَ غَفورًا رَحيمًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dc{وَلا تُجٰدِل عَنِ الَّذينَ يَختانونَ أَنفُسَهُم إِنَّ اللَّهَ لا يُحِبُّ مَن كانَ خَوّانًا أَثيمًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dci{يَستَخفونَ مِنَ النّاسِ وَلا يَستَخفونَ مِنَ اللَّهِ وَهُوَ مَعَهُم إِذ يُبَيِّتونَ ما لا يَرضىٰ مِنَ القَولِ وَكانَ اللَّهُ بِما يَعمَلونَ مُحيطًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcii{هٰأَنتُم هٰؤُلاءِ جٰدَلتُم عَنهُم فِى الحَيوٰةِ الدُّنيا فَمَن يُجٰدِلُ اللَّهَ عَنهُم يَومَ القِيٰمَةِ أَم مَن يَكونُ عَلَيهِم وَكيلًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dciii{وَمَن يَعمَل سوءًا أَو يَظلِم نَفسَهُ ثُمَّ يَستَغفِرِ اللَّهَ يَجِدِ اللَّهَ غَفورًا رَحيمًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@dciv{وَمَن يَكسِب إِثمًا فَإِنَّما يَكسِبُهُ عَلىٰ نَفسِهِ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@dcv{وَمَن يَكسِب خَطيـَٔةً أَو إِثمًا ثُمَّ يَرمِ بِهِ بَريـًٔا فَقَدِ احتَمَلَ بُهتٰنًا وَإِثمًا مُبينًا\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@dcvi{وَلَولا فَضلُ اللَّهِ عَلَيكَ وَرَحمَتُهُ لَهَمَّت طائِفَةٌ مِنهُم أَن يُضِلّوكَ وَما يُضِلّونَ إِلّا أَنفُسَهُم وَما يَضُرّونَكَ مِن شَيءٍ وَأَنزَلَ اللَّهُ عَلَيكَ الكِتٰبَ وَالحِكمَةَ وَعَلَّمَكَ ما لَم تَكُن تَعلَمُ وَكانَ فَضلُ اللَّهِ عَلَيكَ عَظيمًا\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@dcvii{لا خَيرَ فى كَثيرٍ مِن نَجوىٰهُم إِلّا مَن أَمَرَ بِصَدَقَةٍ أَو مَعروفٍ أَو إِصلٰحٍ بَينَ النّاسِ وَمَن يَفعَل ذٰلِكَ ابتِغاءَ مَرضاتِ اللَّهِ فَسَوفَ نُؤتيهِ أَجرًا عَظيمًا\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@dcviii{وَمَن يُشاقِقِ الرَّسولَ مِن بَعدِ ما تَبَيَّنَ لَهُ الهُدىٰ وَيَتَّبِع غَيرَ سَبيلِ المُؤمِنينَ نُوَلِّهِ ما تَوَلّىٰ وَنُصلِهِ جَهَنَّمَ وَساءَت مَصيرًا\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@dcix{إِنَّ اللَّهَ لا يَغفِرُ أَن يُشرَكَ بِهِ وَيَغفِرُ ما دونَ ذٰلِكَ لِمَن يَشاءُ وَمَن يُشرِك بِاللَّهِ فَقَد ضَلَّ ضَلٰلًا بَعيدًا\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@dcx{إِن يَدعونَ مِن دونِهِ إِلّا إِنٰثًا وَإِن يَدعونَ إِلّا شَيطٰنًا مَريدًا\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@dcxi{لَعَنَهُ اللَّهُ وَقالَ لَأَتَّخِذَنَّ مِن عِبادِكَ نَصيبًا مَفروضًا\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@dcxii{وَلَأُضِلَّنَّهُم وَلَأُمَنِّيَنَّهُم وَلَءامُرَنَّهُم فَلَيُبَتِّكُنَّ ءاذانَ الأَنعٰمِ وَلَءامُرَنَّهُم فَلَيُغَيِّرُنَّ خَلقَ اللَّهِ وَمَن يَتَّخِذِ الشَّيطٰنَ وَلِيًّا مِن دونِ اللَّهِ فَقَد خَسِرَ خُسرانًا مُبينًا\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@dcxiii{يَعِدُهُم وَيُمَنّيهِم وَما يَعِدُهُمُ الشَّيطٰنُ إِلّا غُرورًا\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@dcxiv{أُولٰئِكَ مَأوىٰهُم جَهَنَّمُ وَلا يَجِدونَ عَنها مَحيصًا\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@dcxv{وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ سَنُدخِلُهُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها أَبَدًا وَعدَ اللَّهِ حَقًّا وَمَن أَصدَقُ مِنَ اللَّهِ قيلًا\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@dcxvi{لَيسَ بِأَمانِيِّكُم وَلا أَمانِىِّ أَهلِ الكِتٰبِ مَن يَعمَل سوءًا يُجزَ بِهِ وَلا يَجِد لَهُ مِن دونِ اللَّهِ وَلِيًّا وَلا نَصيرًا\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@dcxvii{وَمَن يَعمَل مِنَ الصّٰلِحٰتِ مِن ذَكَرٍ أَو أُنثىٰ وَهُوَ مُؤمِنٌ فَأُولٰئِكَ يَدخُلونَ الجَنَّةَ وَلا يُظلَمونَ نَقيرًا\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@dcxviii{وَمَن أَحسَنُ دينًا مِمَّن أَسلَمَ وَجهَهُ لِلَّهِ وَهُوَ مُحسِنٌ وَاتَّبَعَ مِلَّةَ إِبرٰهيمَ حَنيفًا وَاتَّخَذَ اللَّهُ إِبرٰهيمَ خَليلًا\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@dcxix{وَلِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَكانَ اللَّهُ بِكُلِّ شَيءٍ مُحيطًا\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@dcxx{وَيَستَفتونَكَ فِى النِّساءِ قُلِ اللَّهُ يُفتيكُم فيهِنَّ وَما يُتلىٰ عَلَيكُم فِى الكِتٰبِ فى يَتٰمَى النِّساءِ الّٰتى لا تُؤتونَهُنَّ ما كُتِبَ لَهُنَّ وَتَرغَبونَ أَن تَنكِحوهُنَّ وَالمُستَضعَفينَ مِنَ الوِلدٰنِ وَأَن تَقوموا لِليَتٰمىٰ بِالقِسطِ وَما تَفعَلوا مِن خَيرٍ فَإِنَّ اللَّهَ كانَ بِهِ عَليمًا\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@dcxxi{وَإِنِ امرَأَةٌ خافَت مِن بَعلِها نُشوزًا أَو إِعراضًا فَلا جُناحَ عَلَيهِما أَن يُصلِحا بَينَهُما صُلحًا وَالصُّلحُ خَيرٌ وَأُحضِرَتِ الأَنفُسُ الشُّحَّ وَإِن تُحسِنوا وَتَتَّقوا فَإِنَّ اللَّهَ كانَ بِما تَعمَلونَ خَبيرًا\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@dcxxii{وَلَن تَستَطيعوا أَن تَعدِلوا بَينَ النِّساءِ وَلَو حَرَصتُم فَلا تَميلوا كُلَّ المَيلِ فَتَذَروها كَالمُعَلَّقَةِ وَإِن تُصلِحوا وَتَتَّقوا فَإِنَّ اللَّهَ كانَ غَفورًا رَحيمًا\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@dcxxiii{وَإِن يَتَفَرَّقا يُغنِ اللَّهُ كُلًّا مِن سَعَتِهِ وَكانَ اللَّهُ وٰسِعًا حَكيمًا\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@dcxxiv{وَلِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَلَقَد وَصَّينَا الَّذينَ أوتُوا الكِتٰبَ مِن قَبلِكُم وَإِيّاكُم أَنِ اتَّقُوا اللَّهَ وَإِن تَكفُروا فَإِنَّ لِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَكانَ اللَّهُ غَنِيًّا حَميدًا\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@dcxxv{وَلِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@dcxxvi{إِن يَشَأ يُذهِبكُم أَيُّهَا النّاسُ وَيَأتِ بِـٔاخَرينَ وَكانَ اللَّهُ عَلىٰ ذٰلِكَ قَديرًا\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@dcxxvii{مَن كانَ يُريدُ ثَوابَ الدُّنيا فَعِندَ اللَّهِ ثَوابُ الدُّنيا وَالءاخِرَةِ وَكانَ اللَّهُ سَميعًا بَصيرًا\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@dcxxviii{يٰأَيُّهَا الَّذينَ ءامَنوا كونوا قَوّٰمينَ بِالقِسطِ شُهَداءَ لِلَّهِ وَلَو عَلىٰ أَنفُسِكُم أَوِ الوٰلِدَينِ وَالأَقرَبينَ إِن يَكُن غَنِيًّا أَو فَقيرًا فَاللَّهُ أَولىٰ بِهِما فَلا تَتَّبِعُوا الهَوىٰ أَن تَعدِلوا وَإِن تَلوۥا أَو تُعرِضوا فَإِنَّ اللَّهَ كانَ بِما تَعمَلونَ خَبيرًا\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@dcxxix{يٰأَيُّهَا الَّذينَ ءامَنوا ءامِنوا بِاللَّهِ وَرَسولِهِ وَالكِتٰبِ الَّذى نَزَّلَ عَلىٰ رَسولِهِ وَالكِتٰبِ الَّذى أَنزَلَ مِن قَبلُ وَمَن يَكفُر بِاللَّهِ وَمَلٰئِكَتِهِ وَكُتُبِهِ وَرُسُلِهِ وَاليَومِ الءاخِرِ فَقَد ضَلَّ ضَلٰلًا بَعيدًا\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@dcxxx{إِنَّ الَّذينَ ءامَنوا ثُمَّ كَفَروا ثُمَّ ءامَنوا ثُمَّ كَفَروا ثُمَّ ازدادوا كُفرًا لَم يَكُنِ اللَّهُ لِيَغفِرَ لَهُم وَلا لِيَهدِيَهُم سَبيلًا\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@dcxxxi{بَشِّرِ المُنٰفِقينَ بِأَنَّ لَهُم عَذابًا أَليمًا\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@dcxxxii{الَّذينَ يَتَّخِذونَ الكٰفِرينَ أَولِياءَ مِن دونِ المُؤمِنينَ أَيَبتَغونَ عِندَهُمُ العِزَّةَ فَإِنَّ العِزَّةَ لِلَّهِ جَميعًا\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@dcxxxiii{وَقَد نَزَّلَ عَلَيكُم فِى الكِتٰبِ أَن إِذا سَمِعتُم ءايٰتِ اللَّهِ يُكفَرُ بِها وَيُستَهزَأُ بِها فَلا تَقعُدوا مَعَهُم حَتّىٰ يَخوضوا فى حَديثٍ غَيرِهِ إِنَّكُم إِذًا مِثلُهُم إِنَّ اللَّهَ جامِعُ المُنٰفِقينَ وَالكٰفِرينَ فى جَهَنَّمَ جَميعًا\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@dcxxxiv{الَّذينَ يَتَرَبَّصونَ بِكُم فَإِن كانَ لَكُم فَتحٌ مِنَ اللَّهِ قالوا أَلَم نَكُن مَعَكُم وَإِن كانَ لِلكٰفِرينَ نَصيبٌ قالوا أَلَم نَستَحوِذ عَلَيكُم وَنَمنَعكُم مِنَ المُؤمِنينَ فَاللَّهُ يَحكُمُ بَينَكُم يَومَ القِيٰمَةِ وَلَن يَجعَلَ اللَّهُ لِلكٰفِرينَ عَلَى المُؤمِنينَ سَبيلًا\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@dcxxxv{إِنَّ المُنٰفِقينَ يُخٰدِعونَ اللَّهَ وَهُوَ خٰدِعُهُم وَإِذا قاموا إِلَى الصَّلوٰةِ قاموا كُسالىٰ يُراءونَ النّاسَ وَلا يَذكُرونَ اللَّهَ إِلّا قَليلًا\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@dcxxxvi{مُذَبذَبينَ بَينَ ذٰلِكَ لا إِلىٰ هٰؤُلاءِ وَلا إِلىٰ هٰؤُلاءِ وَمَن يُضلِلِ اللَّهُ فَلَن تَجِدَ لَهُ سَبيلًا\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@dcxxxvii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَتَّخِذُوا الكٰفِرينَ أَولِياءَ مِن دونِ المُؤمِنينَ أَتُريدونَ أَن تَجعَلوا لِلَّهِ عَلَيكُم سُلطٰنًا مُبينًا\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@dcxxxviii{إِنَّ المُنٰفِقينَ فِى الدَّركِ الأَسفَلِ مِنَ النّارِ وَلَن تَجِدَ لَهُم نَصيرًا\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@dcxxxix{إِلَّا الَّذينَ تابوا وَأَصلَحوا وَاعتَصَموا بِاللَّهِ وَأَخلَصوا دينَهُم لِلَّهِ فَأُولٰئِكَ مَعَ المُؤمِنينَ وَسَوفَ يُؤتِ اللَّهُ المُؤمِنينَ أَجرًا عَظيمًا\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@dcxl{ما يَفعَلُ اللَّهُ بِعَذابِكُم إِن شَكَرتُم وَءامَنتُم وَكانَ اللَّهُ شاكِرًا عَليمًا\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@dcxli{لا يُحِبُّ اللَّهُ الجَهرَ بِالسّوءِ مِنَ القَولِ إِلّا مَن ظُلِمَ وَكانَ اللَّهُ سَميعًا عَليمًا\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@dcxlii{إِن تُبدوا خَيرًا أَو تُخفوهُ أَو تَعفوا عَن سوءٍ فَإِنَّ اللَّهَ كانَ عَفُوًّا قَديرًا\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@dcxliii{إِنَّ الَّذينَ يَكفُرونَ بِاللَّهِ وَرُسُلِهِ وَيُريدونَ أَن يُفَرِّقوا بَينَ اللَّهِ وَرُسُلِهِ وَيَقولونَ نُؤمِنُ بِبَعضٍ وَنَكفُرُ بِبَعضٍ وَيُريدونَ أَن يَتَّخِذوا بَينَ ذٰلِكَ سَبيلًا\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@dcxliv{أُولٰئِكَ هُمُ الكٰفِرونَ حَقًّا وَأَعتَدنا لِلكٰفِرينَ عَذابًا مُهينًا\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@dcxlv{وَالَّذينَ ءامَنوا بِاللَّهِ وَرُسُلِهِ وَلَم يُفَرِّقوا بَينَ أَحَدٍ مِنهُم أُولٰئِكَ سَوفَ يُؤتيهِم أُجورَهُم وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@dcxlvi{يَسـَٔلُكَ أَهلُ الكِتٰبِ أَن تُنَزِّلَ عَلَيهِم كِتٰبًا مِنَ السَّماءِ فَقَد سَأَلوا موسىٰ أَكبَرَ مِن ذٰلِكَ فَقالوا أَرِنَا اللَّهَ جَهرَةً فَأَخَذَتهُمُ الصّٰعِقَةُ بِظُلمِهِم ثُمَّ اتَّخَذُوا العِجلَ مِن بَعدِ ما جاءَتهُمُ البَيِّنٰتُ فَعَفَونا عَن ذٰلِكَ وَءاتَينا موسىٰ سُلطٰنًا مُبينًا\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@dcxlvii{وَرَفَعنا فَوقَهُمُ الطّورَ بِميثٰقِهِم وَقُلنا لَهُمُ ادخُلُوا البابَ سُجَّدًا وَقُلنا لَهُم لا تَعدوا فِى السَّبتِ وَأَخَذنا مِنهُم ميثٰقًا غَليظًا\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@dcxlviii{فَبِما نَقضِهِم ميثٰقَهُم وَكُفرِهِم بِـٔايٰتِ اللَّهِ وَقَتلِهِمُ الأَنبِياءَ بِغَيرِ حَقٍّ وَقَولِهِم قُلوبُنا غُلفٌ بَل طَبَعَ اللَّهُ عَلَيها بِكُفرِهِم فَلا يُؤمِنونَ إِلّا قَليلًا\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@dcxlix{وَبِكُفرِهِم وَقَولِهِم عَلىٰ مَريَمَ بُهتٰنًا عَظيمًا\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@dcl{وَقَولِهِم إِنّا قَتَلنَا المَسيحَ عيسَى ابنَ مَريَمَ رَسولَ اللَّهِ وَما قَتَلوهُ وَما صَلَبوهُ وَلٰكِن شُبِّهَ لَهُم وَإِنَّ الَّذينَ اختَلَفوا فيهِ لَفى شَكٍّ مِنهُ ما لَهُم بِهِ مِن عِلمٍ إِلَّا اتِّباعَ الظَّنِّ وَما قَتَلوهُ يَقينًا\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@dcli{بَل رَفَعَهُ اللَّهُ إِلَيهِ وَكانَ اللَّهُ عَزيزًا حَكيمًا\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@dclii{وَإِن مِن أَهلِ الكِتٰبِ إِلّا لَيُؤمِنَنَّ بِهِ قَبلَ مَوتِهِ وَيَومَ القِيٰمَةِ يَكونُ عَلَيهِم شَهيدًا\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@dcliii{فَبِظُلمٍ مِنَ الَّذينَ هادوا حَرَّمنا عَلَيهِم طَيِّبٰتٍ أُحِلَّت لَهُم وَبِصَدِّهِم عَن سَبيلِ اللَّهِ كَثيرًا\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@dcliv{وَأَخذِهِمُ الرِّبوٰا۟ وَقَد نُهوا عَنهُ وَأَكلِهِم أَموٰلَ النّاسِ بِالبٰطِلِ وَأَعتَدنا لِلكٰفِرينَ مِنهُم عَذابًا أَليمًا\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@dclv{لٰكِنِ الرّٰسِخونَ فِى العِلمِ مِنهُم وَالمُؤمِنونَ يُؤمِنونَ بِما أُنزِلَ إِلَيكَ وَما أُنزِلَ مِن قَبلِكَ وَالمُقيمينَ الصَّلوٰةَ وَالمُؤتونَ الزَّكوٰةَ وَالمُؤمِنونَ بِاللَّهِ وَاليَومِ الءاخِرِ أُولٰئِكَ سَنُؤتيهِم أَجرًا عَظيمًا\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@dclvi{إِنّا أَوحَينا إِلَيكَ كَما أَوحَينا إِلىٰ نوحٍ وَالنَّبِيّۦنَ مِن بَعدِهِ وَأَوحَينا إِلىٰ إِبرٰهيمَ وَإِسمٰعيلَ وَإِسحٰقَ وَيَعقوبَ وَالأَسباطِ وَعيسىٰ وَأَيّوبَ وَيونُسَ وَهٰرونَ وَسُلَيمٰنَ وَءاتَينا داوۥدَ زَبورًا\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@dclvii{وَرُسُلًا قَد قَصَصنٰهُم عَلَيكَ مِن قَبلُ وَرُسُلًا لَم نَقصُصهُم عَلَيكَ وَكَلَّمَ اللَّهُ موسىٰ تَكليمًا\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@dclviii{رُسُلًا مُبَشِّرينَ وَمُنذِرينَ لِئَلّا يَكونَ لِلنّاسِ عَلَى اللَّهِ حُجَّةٌ بَعدَ الرُّسُلِ وَكانَ اللَّهُ عَزيزًا حَكيمًا\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@dclix{لٰكِنِ اللَّهُ يَشهَدُ بِما أَنزَلَ إِلَيكَ أَنزَلَهُ بِعِلمِهِ وَالمَلٰئِكَةُ يَشهَدونَ وَكَفىٰ بِاللَّهِ شَهيدًا\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@dclx{إِنَّ الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ قَد ضَلّوا ضَلٰلًا بَعيدًا\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@dclxi{إِنَّ الَّذينَ كَفَروا وَظَلَموا لَم يَكُنِ اللَّهُ لِيَغفِرَ لَهُم وَلا لِيَهدِيَهُم طَريقًا\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@dclxii{إِلّا طَريقَ جَهَنَّمَ خٰلِدينَ فيها أَبَدًا وَكانَ ذٰلِكَ عَلَى اللَّهِ يَسيرًا\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@dclxiii{يٰأَيُّهَا النّاسُ قَد جاءَكُمُ الرَّسولُ بِالحَقِّ مِن رَبِّكُم فَـٔامِنوا خَيرًا لَكُم وَإِن تَكفُروا فَإِنَّ لِلَّهِ ما فِى السَّمٰوٰتِ وَالأَرضِ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@dclxiv{يٰأَهلَ الكِتٰبِ لا تَغلوا فى دينِكُم وَلا تَقولوا عَلَى اللَّهِ إِلَّا الحَقَّ إِنَّمَا المَسيحُ عيسَى ابنُ مَريَمَ رَسولُ اللَّهِ وَكَلِمَتُهُ أَلقىٰها إِلىٰ مَريَمَ وَروحٌ مِنهُ فَـٔامِنوا بِاللَّهِ وَرُسُلِهِ وَلا تَقولوا ثَلٰثَةٌ انتَهوا خَيرًا لَكُم إِنَّمَا اللَّهُ إِلٰهٌ وٰحِدٌ سُبحٰنَهُ أَن يَكونَ لَهُ وَلَدٌ لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@dclxv{لَن يَستَنكِفَ المَسيحُ أَن يَكونَ عَبدًا لِلَّهِ وَلَا المَلٰئِكَةُ المُقَرَّبونَ وَمَن يَستَنكِف عَن عِبادَتِهِ وَيَستَكبِر فَسَيَحشُرُهُم إِلَيهِ جَميعًا\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@dclxvi{فَأَمَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ فَيُوَفّيهِم أُجورَهُم وَيَزيدُهُم مِن فَضلِهِ وَأَمَّا الَّذينَ استَنكَفوا وَاستَكبَروا فَيُعَذِّبُهُم عَذابًا أَليمًا وَلا يَجِدونَ لَهُم مِن دونِ اللَّهِ وَلِيًّا وَلا نَصيرًا\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@dclxvii{يٰأَيُّهَا النّاسُ قَد جاءَكُم بُرهٰنٌ مِن رَبِّكُم وَأَنزَلنا إِلَيكُم نورًا مُبينًا\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@dclxviii{فَأَمَّا الَّذينَ ءامَنوا بِاللَّهِ وَاعتَصَموا بِهِ فَسَيُدخِلُهُم فى رَحمَةٍ مِنهُ وَفَضلٍ وَيَهديهِم إِلَيهِ صِرٰطًا مُستَقيمًا\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@dclxix{يَستَفتونَكَ قُلِ اللَّهُ يُفتيكُم فِى الكَلٰلَةِ إِنِ امرُؤٌا۟ هَلَكَ لَيسَ لَهُ وَلَدٌ وَلَهُ أُختٌ فَلَها نِصفُ ما تَرَكَ وَهُوَ يَرِثُها إِن لَم يَكُن لَها وَلَدٌ فَإِن كانَتَا اثنَتَينِ فَلَهُمَا الثُّلُثانِ مِمّا تَرَكَ وَإِن كانوا إِخوَةً رِجالًا وَنِساءً فَلِلذَّكَرِ مِثلُ حَظِّ الأُنثَيَينِ يُبَيِّنُ اللَّهُ لَكُم أَن تَضِلّوا وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@dclxx{\basmalah  يٰأَيُّهَا الَّذينَ ءامَنوا أَوفوا بِالعُقودِ أُحِلَّت لَكُم بَهيمَةُ الأَنعٰمِ إِلّا ما يُتلىٰ عَلَيكُم غَيرَ مُحِلِّى الصَّيدِ وَأَنتُم حُرُمٌ إِنَّ اللَّهَ يَحكُمُ ما يُريدُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@dclxxi{يٰأَيُّهَا الَّذينَ ءامَنوا لا تُحِلّوا شَعٰئِرَ اللَّهِ وَلَا الشَّهرَ الحَرامَ وَلَا الهَدىَ وَلَا القَلٰئِدَ وَلا ءامّينَ البَيتَ الحَرامَ يَبتَغونَ فَضلًا مِن رَبِّهِم وَرِضوٰنًا وَإِذا حَلَلتُم فَاصطادوا وَلا يَجرِمَنَّكُم شَنَـٔانُ قَومٍ أَن صَدّوكُم عَنِ المَسجِدِ الحَرامِ أَن تَعتَدوا وَتَعاوَنوا عَلَى البِرِّ وَالتَّقوىٰ وَلا تَعاوَنوا عَلَى الإِثمِ وَالعُدوٰنِ وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@dclxxii{حُرِّمَت عَلَيكُمُ المَيتَةُ وَالدَّمُ وَلَحمُ الخِنزيرِ وَما أُهِلَّ لِغَيرِ اللَّهِ بِهِ وَالمُنخَنِقَةُ وَالمَوقوذَةُ وَالمُتَرَدِّيَةُ وَالنَّطيحَةُ وَما أَكَلَ السَّبُعُ إِلّا ما ذَكَّيتُم وَما ذُبِحَ عَلَى النُّصُبِ وَأَن تَستَقسِموا بِالأَزلٰمِ ذٰلِكُم فِسقٌ اليَومَ يَئِسَ الَّذينَ كَفَروا مِن دينِكُم فَلا تَخشَوهُم وَاخشَونِ اليَومَ أَكمَلتُ لَكُم دينَكُم وَأَتمَمتُ عَلَيكُم نِعمَتى وَرَضيتُ لَكُمُ الإِسلٰمَ دينًا فَمَنِ اضطُرَّ فى مَخمَصَةٍ غَيرَ مُتَجانِفٍ لِإِثمٍ فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@dclxxiii{يَسـَٔلونَكَ ماذا أُحِلَّ لَهُم قُل أُحِلَّ لَكُمُ الطَّيِّبٰتُ وَما عَلَّمتُم مِنَ الجَوارِحِ مُكَلِّبينَ تُعَلِّمونَهُنَّ مِمّا عَلَّمَكُمُ اللَّهُ فَكُلوا مِمّا أَمسَكنَ عَلَيكُم وَاذكُرُوا اسمَ اللَّهِ عَلَيهِ وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@dclxxiv{اليَومَ أُحِلَّ لَكُمُ الطَّيِّبٰتُ وَطَعامُ الَّذينَ أوتُوا الكِتٰبَ حِلٌّ لَكُم وَطَعامُكُم حِلٌّ لَهُم وَالمُحصَنٰتُ مِنَ المُؤمِنٰتِ وَالمُحصَنٰتُ مِنَ الَّذينَ أوتُوا الكِتٰبَ مِن قَبلِكُم إِذا ءاتَيتُموهُنَّ أُجورَهُنَّ مُحصِنينَ غَيرَ مُسٰفِحينَ وَلا مُتَّخِذى أَخدانٍ وَمَن يَكفُر بِالإيمٰنِ فَقَد حَبِطَ عَمَلُهُ وَهُوَ فِى الءاخِرَةِ مِنَ الخٰسِرينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@dclxxv{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا قُمتُم إِلَى الصَّلوٰةِ فَاغسِلوا وُجوهَكُم وَأَيدِيَكُم إِلَى المَرافِقِ وَامسَحوا بِرُءوسِكُم وَأَرجُلَكُم إِلَى الكَعبَينِ وَإِن كُنتُم جُنُبًا فَاطَّهَّروا وَإِن كُنتُم مَرضىٰ أَو عَلىٰ سَفَرٍ أَو جاءَ أَحَدٌ مِنكُم مِنَ الغائِطِ أَو لٰمَستُمُ النِّساءَ فَلَم تَجِدوا ماءً فَتَيَمَّموا صَعيدًا طَيِّبًا فَامسَحوا بِوُجوهِكُم وَأَيديكُم مِنهُ ما يُريدُ اللَّهُ لِيَجعَلَ عَلَيكُم مِن حَرَجٍ وَلٰكِن يُريدُ لِيُطَهِّرَكُم وَلِيُتِمَّ نِعمَتَهُ عَلَيكُم لَعَلَّكُم تَشكُرونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@dclxxvi{وَاذكُروا نِعمَةَ اللَّهِ عَلَيكُم وَميثٰقَهُ الَّذى واثَقَكُم بِهِ إِذ قُلتُم سَمِعنا وَأَطَعنا وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@dclxxvii{يٰأَيُّهَا الَّذينَ ءامَنوا كونوا قَوّٰمينَ لِلَّهِ شُهَداءَ بِالقِسطِ وَلا يَجرِمَنَّكُم شَنَـٔانُ قَومٍ عَلىٰ أَلّا تَعدِلُوا اعدِلوا هُوَ أَقرَبُ لِلتَّقوىٰ وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dclxxviii{وَعَدَ اللَّهُ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَهُم مَغفِرَةٌ وَأَجرٌ عَظيمٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@dclxxix{وَالَّذينَ كَفَروا وَكَذَّبوا بِـٔايٰتِنا أُولٰئِكَ أَصحٰبُ الجَحيمِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@dclxxx{يٰأَيُّهَا الَّذينَ ءامَنُوا اذكُروا نِعمَتَ اللَّهِ عَلَيكُم إِذ هَمَّ قَومٌ أَن يَبسُطوا إِلَيكُم أَيدِيَهُم فَكَفَّ أَيدِيَهُم عَنكُم وَاتَّقُوا اللَّهَ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dclxxxi{وَلَقَد أَخَذَ اللَّهُ ميثٰقَ بَنى إِسرٰءيلَ وَبَعَثنا مِنهُمُ اثنَى عَشَرَ نَقيبًا وَقالَ اللَّهُ إِنّى مَعَكُم لَئِن أَقَمتُمُ الصَّلوٰةَ وَءاتَيتُمُ الزَّكوٰةَ وَءامَنتُم بِرُسُلى وَعَزَّرتُموهُم وَأَقرَضتُمُ اللَّهَ قَرضًا حَسَنًا لَأُكَفِّرَنَّ عَنكُم سَيِّـٔاتِكُم وَلَأُدخِلَنَّكُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ فَمَن كَفَرَ بَعدَ ذٰلِكَ مِنكُم فَقَد ضَلَّ سَواءَ السَّبيلِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dclxxxii{فَبِما نَقضِهِم ميثٰقَهُم لَعَنّٰهُم وَجَعَلنا قُلوبَهُم قٰسِيَةً يُحَرِّفونَ الكَلِمَ عَن مَواضِعِهِ وَنَسوا حَظًّا مِمّا ذُكِّروا بِهِ وَلا تَزالُ تَطَّلِعُ عَلىٰ خائِنَةٍ مِنهُم إِلّا قَليلًا مِنهُم فَاعفُ عَنهُم وَاصفَح إِنَّ اللَّهَ يُحِبُّ المُحسِنينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dclxxxiii{وَمِنَ الَّذينَ قالوا إِنّا نَصٰرىٰ أَخَذنا ميثٰقَهُم فَنَسوا حَظًّا مِمّا ذُكِّروا بِهِ فَأَغرَينا بَينَهُمُ العَداوَةَ وَالبَغضاءَ إِلىٰ يَومِ القِيٰمَةِ وَسَوفَ يُنَبِّئُهُمُ اللَّهُ بِما كانوا يَصنَعونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dclxxxiv{يٰأَهلَ الكِتٰبِ قَد جاءَكُم رَسولُنا يُبَيِّنُ لَكُم كَثيرًا مِمّا كُنتُم تُخفونَ مِنَ الكِتٰبِ وَيَعفوا عَن كَثيرٍ قَد جاءَكُم مِنَ اللَّهِ نورٌ وَكِتٰبٌ مُبينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dclxxxv{يَهدى بِهِ اللَّهُ مَنِ اتَّبَعَ رِضوٰنَهُ سُبُلَ السَّلٰمِ وَيُخرِجُهُم مِنَ الظُّلُمٰتِ إِلَى النّورِ بِإِذنِهِ وَيَهديهِم إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dclxxxvi{لَقَد كَفَرَ الَّذينَ قالوا إِنَّ اللَّهَ هُوَ المَسيحُ ابنُ مَريَمَ قُل فَمَن يَملِكُ مِنَ اللَّهِ شَيـًٔا إِن أَرادَ أَن يُهلِكَ المَسيحَ ابنَ مَريَمَ وَأُمَّهُ وَمَن فِى الأَرضِ جَميعًا وَلِلَّهِ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُما يَخلُقُ ما يَشاءُ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dclxxxvii{وَقالَتِ اليَهودُ وَالنَّصٰرىٰ نَحنُ أَبنٰؤُا۟ اللَّهِ وَأَحِبّٰؤُهُ قُل فَلِمَ يُعَذِّبُكُم بِذُنوبِكُم بَل أَنتُم بَشَرٌ مِمَّن خَلَقَ يَغفِرُ لِمَن يَشاءُ وَيُعَذِّبُ مَن يَشاءُ وَلِلَّهِ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُما وَإِلَيهِ المَصيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dclxxxviii{يٰأَهلَ الكِتٰبِ قَد جاءَكُم رَسولُنا يُبَيِّنُ لَكُم عَلىٰ فَترَةٍ مِنَ الرُّسُلِ أَن تَقولوا ما جاءَنا مِن بَشيرٍ وَلا نَذيرٍ فَقَد جاءَكُم بَشيرٌ وَنَذيرٌ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dclxxxix{وَإِذ قالَ موسىٰ لِقَومِهِ يٰقَومِ اذكُروا نِعمَةَ اللَّهِ عَلَيكُم إِذ جَعَلَ فيكُم أَنبِياءَ وَجَعَلَكُم مُلوكًا وَءاتىٰكُم ما لَم يُؤتِ أَحَدًا مِنَ العٰلَمينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dcxc{يٰقَومِ ادخُلُوا الأَرضَ المُقَدَّسَةَ الَّتى كَتَبَ اللَّهُ لَكُم وَلا تَرتَدّوا عَلىٰ أَدبارِكُم فَتَنقَلِبوا خٰسِرينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dcxci{قالوا يٰموسىٰ إِنَّ فيها قَومًا جَبّارينَ وَإِنّا لَن نَدخُلَها حَتّىٰ يَخرُجوا مِنها فَإِن يَخرُجوا مِنها فَإِنّا دٰخِلونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dcxcii{قالَ رَجُلانِ مِنَ الَّذينَ يَخافونَ أَنعَمَ اللَّهُ عَلَيهِمَا ادخُلوا عَلَيهِمُ البابَ فَإِذا دَخَلتُموهُ فَإِنَّكُم غٰلِبونَ وَعَلَى اللَّهِ فَتَوَكَّلوا إِن كُنتُم مُؤمِنينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dcxciii{قالوا يٰموسىٰ إِنّا لَن نَدخُلَها أَبَدًا ما داموا فيها فَاذهَب أَنتَ وَرَبُّكَ فَقٰتِلا إِنّا هٰهُنا قٰعِدونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dcxciv{قالَ رَبِّ إِنّى لا أَملِكُ إِلّا نَفسى وَأَخى فَافرُق بَينَنا وَبَينَ القَومِ الفٰسِقينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dcxcv{قالَ فَإِنَّها مُحَرَّمَةٌ عَلَيهِم أَربَعينَ سَنَةً يَتيهونَ فِى الأَرضِ فَلا تَأسَ عَلَى القَومِ الفٰسِقينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dcxcvi{وَاتلُ عَلَيهِم نَبَأَ ابنَى ءادَمَ بِالحَقِّ إِذ قَرَّبا قُربانًا فَتُقُبِّلَ مِن أَحَدِهِما وَلَم يُتَقَبَّل مِنَ الءاخَرِ قالَ لَأَقتُلَنَّكَ قالَ إِنَّما يَتَقَبَّلُ اللَّهُ مِنَ المُتَّقينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dcxcvii{لَئِن بَسَطتَ إِلَىَّ يَدَكَ لِتَقتُلَنى ما أَنا۠ بِباسِطٍ يَدِىَ إِلَيكَ لِأَقتُلَكَ إِنّى أَخافُ اللَّهَ رَبَّ العٰلَمينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dcxcviii{إِنّى أُريدُ أَن تَبوأَ بِإِثمى وَإِثمِكَ فَتَكونَ مِن أَصحٰبِ النّارِ وَذٰلِكَ جَزٰؤُا۟ الظّٰلِمينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dcxcix{فَطَوَّعَت لَهُ نَفسُهُ قَتلَ أَخيهِ فَقَتَلَهُ فَأَصبَحَ مِنَ الخٰسِرينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dcc{فَبَعَثَ اللَّهُ غُرابًا يَبحَثُ فِى الأَرضِ لِيُرِيَهُ كَيفَ يُوٰرى سَوءَةَ أَخيهِ قالَ يٰوَيلَتىٰ أَعَجَزتُ أَن أَكونَ مِثلَ هٰذَا الغُرابِ فَأُوٰرِىَ سَوءَةَ أَخى فَأَصبَحَ مِنَ النّٰدِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dcci{مِن أَجلِ ذٰلِكَ كَتَبنا عَلىٰ بَنى إِسرٰءيلَ أَنَّهُ مَن قَتَلَ نَفسًا بِغَيرِ نَفسٍ أَو فَسادٍ فِى الأَرضِ فَكَأَنَّما قَتَلَ النّاسَ جَميعًا وَمَن أَحياها فَكَأَنَّما أَحيَا النّاسَ جَميعًا وَلَقَد جاءَتهُم رُسُلُنا بِالبَيِّنٰتِ ثُمَّ إِنَّ كَثيرًا مِنهُم بَعدَ ذٰلِكَ فِى الأَرضِ لَمُسرِفونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dccii{إِنَّما جَزٰؤُا۟ الَّذينَ يُحارِبونَ اللَّهَ وَرَسولَهُ وَيَسعَونَ فِى الأَرضِ فَسادًا أَن يُقَتَّلوا أَو يُصَلَّبوا أَو تُقَطَّعَ أَيديهِم وَأَرجُلُهُم مِن خِلٰفٍ أَو يُنفَوا مِنَ الأَرضِ ذٰلِكَ لَهُم خِزىٌ فِى الدُّنيا وَلَهُم فِى الءاخِرَةِ عَذابٌ عَظيمٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dcciii{إِلَّا الَّذينَ تابوا مِن قَبلِ أَن تَقدِروا عَلَيهِم فَاعلَموا أَنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dcciv{يٰأَيُّهَا الَّذينَ ءامَنُوا اتَّقُوا اللَّهَ وَابتَغوا إِلَيهِ الوَسيلَةَ وَجٰهِدوا فى سَبيلِهِ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dccv{إِنَّ الَّذينَ كَفَروا لَو أَنَّ لَهُم ما فِى الأَرضِ جَميعًا وَمِثلَهُ مَعَهُ لِيَفتَدوا بِهِ مِن عَذابِ يَومِ القِيٰمَةِ ما تُقُبِّلَ مِنهُم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dccvi{يُريدونَ أَن يَخرُجوا مِنَ النّارِ وَما هُم بِخٰرِجينَ مِنها وَلَهُم عَذابٌ مُقيمٌ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dccvii{وَالسّارِقُ وَالسّارِقَةُ فَاقطَعوا أَيدِيَهُما جَزاءً بِما كَسَبا نَكٰلًا مِنَ اللَّهِ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dccviii{فَمَن تابَ مِن بَعدِ ظُلمِهِ وَأَصلَحَ فَإِنَّ اللَّهَ يَتوبُ عَلَيهِ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dccix{أَلَم تَعلَم أَنَّ اللَّهَ لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ يُعَذِّبُ مَن يَشاءُ وَيَغفِرُ لِمَن يَشاءُ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dccx{يٰأَيُّهَا الرَّسولُ لا يَحزُنكَ الَّذينَ يُسٰرِعونَ فِى الكُفرِ مِنَ الَّذينَ قالوا ءامَنّا بِأَفوٰهِهِم وَلَم تُؤمِن قُلوبُهُم وَمِنَ الَّذينَ هادوا سَمّٰعونَ لِلكَذِبِ سَمّٰعونَ لِقَومٍ ءاخَرينَ لَم يَأتوكَ يُحَرِّفونَ الكَلِمَ مِن بَعدِ مَواضِعِهِ يَقولونَ إِن أوتيتُم هٰذا فَخُذوهُ وَإِن لَم تُؤتَوهُ فَاحذَروا وَمَن يُرِدِ اللَّهُ فِتنَتَهُ فَلَن تَملِكَ لَهُ مِنَ اللَّهِ شَيـًٔا أُولٰئِكَ الَّذينَ لَم يُرِدِ اللَّهُ أَن يُطَهِّرَ قُلوبَهُم لَهُم فِى الدُّنيا خِزىٌ وَلَهُم فِى الءاخِرَةِ عَذابٌ عَظيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dccxi{سَمّٰعونَ لِلكَذِبِ أَكّٰلونَ لِلسُّحتِ فَإِن جاءوكَ فَاحكُم بَينَهُم أَو أَعرِض عَنهُم وَإِن تُعرِض عَنهُم فَلَن يَضُرّوكَ شَيـًٔا وَإِن حَكَمتَ فَاحكُم بَينَهُم بِالقِسطِ إِنَّ اللَّهَ يُحِبُّ المُقسِطينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dccxii{وَكَيفَ يُحَكِّمونَكَ وَعِندَهُمُ التَّورىٰةُ فيها حُكمُ اللَّهِ ثُمَّ يَتَوَلَّونَ مِن بَعدِ ذٰلِكَ وَما أُولٰئِكَ بِالمُؤمِنينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dccxiii{إِنّا أَنزَلنَا التَّورىٰةَ فيها هُدًى وَنورٌ يَحكُمُ بِهَا النَّبِيّونَ الَّذينَ أَسلَموا لِلَّذينَ هادوا وَالرَّبّٰنِيّونَ وَالأَحبارُ بِمَا استُحفِظوا مِن كِتٰبِ اللَّهِ وَكانوا عَلَيهِ شُهَداءَ فَلا تَخشَوُا النّاسَ وَاخشَونِ وَلا تَشتَروا بِـٔايٰتى ثَمَنًا قَليلًا وَمَن لَم يَحكُم بِما أَنزَلَ اللَّهُ فَأُولٰئِكَ هُمُ الكٰفِرونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dccxiv{وَكَتَبنا عَلَيهِم فيها أَنَّ النَّفسَ بِالنَّفسِ وَالعَينَ بِالعَينِ وَالأَنفَ بِالأَنفِ وَالأُذُنَ بِالأُذُنِ وَالسِّنَّ بِالسِّنِّ وَالجُروحَ قِصاصٌ فَمَن تَصَدَّقَ بِهِ فَهُوَ كَفّارَةٌ لَهُ وَمَن لَم يَحكُم بِما أَنزَلَ اللَّهُ فَأُولٰئِكَ هُمُ الظّٰلِمونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dccxv{وَقَفَّينا عَلىٰ ءاثٰرِهِم بِعيسَى ابنِ مَريَمَ مُصَدِّقًا لِما بَينَ يَدَيهِ مِنَ التَّورىٰةِ وَءاتَينٰهُ الإِنجيلَ فيهِ هُدًى وَنورٌ وَمُصَدِّقًا لِما بَينَ يَدَيهِ مِنَ التَّورىٰةِ وَهُدًى وَمَوعِظَةً لِلمُتَّقينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dccxvi{وَليَحكُم أَهلُ الإِنجيلِ بِما أَنزَلَ اللَّهُ فيهِ وَمَن لَم يَحكُم بِما أَنزَلَ اللَّهُ فَأُولٰئِكَ هُمُ الفٰسِقونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dccxvii{وَأَنزَلنا إِلَيكَ الكِتٰبَ بِالحَقِّ مُصَدِّقًا لِما بَينَ يَدَيهِ مِنَ الكِتٰبِ وَمُهَيمِنًا عَلَيهِ فَاحكُم بَينَهُم بِما أَنزَلَ اللَّهُ وَلا تَتَّبِع أَهواءَهُم عَمّا جاءَكَ مِنَ الحَقِّ لِكُلٍّ جَعَلنا مِنكُم شِرعَةً وَمِنهاجًا وَلَو شاءَ اللَّهُ لَجَعَلَكُم أُمَّةً وٰحِدَةً وَلٰكِن لِيَبلُوَكُم فى ما ءاتىٰكُم فَاستَبِقُوا الخَيرٰتِ إِلَى اللَّهِ مَرجِعُكُم جَميعًا فَيُنَبِّئُكُم بِما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dccxviii{وَأَنِ احكُم بَينَهُم بِما أَنزَلَ اللَّهُ وَلا تَتَّبِع أَهواءَهُم وَاحذَرهُم أَن يَفتِنوكَ عَن بَعضِ ما أَنزَلَ اللَّهُ إِلَيكَ فَإِن تَوَلَّوا فَاعلَم أَنَّما يُريدُ اللَّهُ أَن يُصيبَهُم بِبَعضِ ذُنوبِهِم وَإِنَّ كَثيرًا مِنَ النّاسِ لَفٰسِقونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dccxix{أَفَحُكمَ الجٰهِلِيَّةِ يَبغونَ وَمَن أَحسَنُ مِنَ اللَّهِ حُكمًا لِقَومٍ يوقِنونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dccxx{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَتَّخِذُوا اليَهودَ وَالنَّصٰرىٰ أَولِياءَ بَعضُهُم أَولِياءُ بَعضٍ وَمَن يَتَوَلَّهُم مِنكُم فَإِنَّهُ مِنهُم إِنَّ اللَّهَ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dccxxi{فَتَرَى الَّذينَ فى قُلوبِهِم مَرَضٌ يُسٰرِعونَ فيهِم يَقولونَ نَخشىٰ أَن تُصيبَنا دائِرَةٌ فَعَسَى اللَّهُ أَن يَأتِىَ بِالفَتحِ أَو أَمرٍ مِن عِندِهِ فَيُصبِحوا عَلىٰ ما أَسَرّوا فى أَنفُسِهِم نٰدِمينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dccxxii{وَيَقولُ الَّذينَ ءامَنوا أَهٰؤُلاءِ الَّذينَ أَقسَموا بِاللَّهِ جَهدَ أَيمٰنِهِم إِنَّهُم لَمَعَكُم حَبِطَت أَعمٰلُهُم فَأَصبَحوا خٰسِرينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dccxxiii{يٰأَيُّهَا الَّذينَ ءامَنوا مَن يَرتَدَّ مِنكُم عَن دينِهِ فَسَوفَ يَأتِى اللَّهُ بِقَومٍ يُحِبُّهُم وَيُحِبّونَهُ أَذِلَّةٍ عَلَى المُؤمِنينَ أَعِزَّةٍ عَلَى الكٰفِرينَ يُجٰهِدونَ فى سَبيلِ اللَّهِ وَلا يَخافونَ لَومَةَ لائِمٍ ذٰلِكَ فَضلُ اللَّهِ يُؤتيهِ مَن يَشاءُ وَاللَّهُ وٰسِعٌ عَليمٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dccxxiv{إِنَّما وَلِيُّكُمُ اللَّهُ وَرَسولُهُ وَالَّذينَ ءامَنُوا الَّذينَ يُقيمونَ الصَّلوٰةَ وَيُؤتونَ الزَّكوٰةَ وَهُم رٰكِعونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dccxxv{وَمَن يَتَوَلَّ اللَّهَ وَرَسولَهُ وَالَّذينَ ءامَنوا فَإِنَّ حِزبَ اللَّهِ هُمُ الغٰلِبونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dccxxvi{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَتَّخِذُوا الَّذينَ اتَّخَذوا دينَكُم هُزُوًا وَلَعِبًا مِنَ الَّذينَ أوتُوا الكِتٰبَ مِن قَبلِكُم وَالكُفّارَ أَولِياءَ وَاتَّقُوا اللَّهَ إِن كُنتُم مُؤمِنينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dccxxvii{وَإِذا نادَيتُم إِلَى الصَّلوٰةِ اتَّخَذوها هُزُوًا وَلَعِبًا ذٰلِكَ بِأَنَّهُم قَومٌ لا يَعقِلونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dccxxviii{قُل يٰأَهلَ الكِتٰبِ هَل تَنقِمونَ مِنّا إِلّا أَن ءامَنّا بِاللَّهِ وَما أُنزِلَ إِلَينا وَما أُنزِلَ مِن قَبلُ وَأَنَّ أَكثَرَكُم فٰسِقونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dccxxix{قُل هَل أُنَبِّئُكُم بِشَرٍّ مِن ذٰلِكَ مَثوبَةً عِندَ اللَّهِ مَن لَعَنَهُ اللَّهُ وَغَضِبَ عَلَيهِ وَجَعَلَ مِنهُمُ القِرَدَةَ وَالخَنازيرَ وَعَبَدَ الطّٰغوتَ أُولٰئِكَ شَرٌّ مَكانًا وَأَضَلُّ عَن سَواءِ السَّبيلِ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dccxxx{وَإِذا جاءوكُم قالوا ءامَنّا وَقَد دَخَلوا بِالكُفرِ وَهُم قَد خَرَجوا بِهِ وَاللَّهُ أَعلَمُ بِما كانوا يَكتُمونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dccxxxi{وَتَرىٰ كَثيرًا مِنهُم يُسٰرِعونَ فِى الإِثمِ وَالعُدوٰنِ وَأَكلِهِمُ السُّحتَ لَبِئسَ ما كانوا يَعمَلونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dccxxxii{لَولا يَنهىٰهُمُ الرَّبّٰنِيّونَ وَالأَحبارُ عَن قَولِهِمُ الإِثمَ وَأَكلِهِمُ السُّحتَ لَبِئسَ ما كانوا يَصنَعونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dccxxxiii{وَقالَتِ اليَهودُ يَدُ اللَّهِ مَغلولَةٌ غُلَّت أَيديهِم وَلُعِنوا بِما قالوا بَل يَداهُ مَبسوطَتانِ يُنفِقُ كَيفَ يَشاءُ وَلَيَزيدَنَّ كَثيرًا مِنهُم ما أُنزِلَ إِلَيكَ مِن رَبِّكَ طُغيٰنًا وَكُفرًا وَأَلقَينا بَينَهُمُ العَدٰوَةَ وَالبَغضاءَ إِلىٰ يَومِ القِيٰمَةِ كُلَّما أَوقَدوا نارًا لِلحَربِ أَطفَأَهَا اللَّهُ وَيَسعَونَ فِى الأَرضِ فَسادًا وَاللَّهُ لا يُحِبُّ المُفسِدينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dccxxxiv{وَلَو أَنَّ أَهلَ الكِتٰبِ ءامَنوا وَاتَّقَوا لَكَفَّرنا عَنهُم سَيِّـٔاتِهِم وَلَأَدخَلنٰهُم جَنّٰتِ النَّعيمِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dccxxxv{وَلَو أَنَّهُم أَقامُوا التَّورىٰةَ وَالإِنجيلَ وَما أُنزِلَ إِلَيهِم مِن رَبِّهِم لَأَكَلوا مِن فَوقِهِم وَمِن تَحتِ أَرجُلِهِم مِنهُم أُمَّةٌ مُقتَصِدَةٌ وَكَثيرٌ مِنهُم ساءَ ما يَعمَلونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dccxxxvi{يٰأَيُّهَا الرَّسولُ بَلِّغ ما أُنزِلَ إِلَيكَ مِن رَبِّكَ وَإِن لَم تَفعَل فَما بَلَّغتَ رِسالَتَهُ وَاللَّهُ يَعصِمُكَ مِنَ النّاسِ إِنَّ اللَّهَ لا يَهدِى القَومَ الكٰفِرينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dccxxxvii{قُل يٰأَهلَ الكِتٰبِ لَستُم عَلىٰ شَيءٍ حَتّىٰ تُقيمُوا التَّورىٰةَ وَالإِنجيلَ وَما أُنزِلَ إِلَيكُم مِن رَبِّكُم وَلَيَزيدَنَّ كَثيرًا مِنهُم ما أُنزِلَ إِلَيكَ مِن رَبِّكَ طُغيٰنًا وَكُفرًا فَلا تَأسَ عَلَى القَومِ الكٰفِرينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dccxxxviii{إِنَّ الَّذينَ ءامَنوا وَالَّذينَ هادوا وَالصّٰبِـٔونَ وَالنَّصٰرىٰ مَن ءامَنَ بِاللَّهِ وَاليَومِ الءاخِرِ وَعَمِلَ صٰلِحًا فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dccxxxix{لَقَد أَخَذنا ميثٰقَ بَنى إِسرٰءيلَ وَأَرسَلنا إِلَيهِم رُسُلًا كُلَّما جاءَهُم رَسولٌ بِما لا تَهوىٰ أَنفُسُهُم فَريقًا كَذَّبوا وَفَريقًا يَقتُلونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dccxl{وَحَسِبوا أَلّا تَكونَ فِتنَةٌ فَعَموا وَصَمّوا ثُمَّ تابَ اللَّهُ عَلَيهِم ثُمَّ عَموا وَصَمّوا كَثيرٌ مِنهُم وَاللَّهُ بَصيرٌ بِما يَعمَلونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dccxli{لَقَد كَفَرَ الَّذينَ قالوا إِنَّ اللَّهَ هُوَ المَسيحُ ابنُ مَريَمَ وَقالَ المَسيحُ يٰبَنى إِسرٰءيلَ اعبُدُوا اللَّهَ رَبّى وَرَبَّكُم إِنَّهُ مَن يُشرِك بِاللَّهِ فَقَد حَرَّمَ اللَّهُ عَلَيهِ الجَنَّةَ وَمَأوىٰهُ النّارُ وَما لِلظّٰلِمينَ مِن أَنصارٍ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dccxlii{لَقَد كَفَرَ الَّذينَ قالوا إِنَّ اللَّهَ ثالِثُ ثَلٰثَةٍ وَما مِن إِلٰهٍ إِلّا إِلٰهٌ وٰحِدٌ وَإِن لَم يَنتَهوا عَمّا يَقولونَ لَيَمَسَّنَّ الَّذينَ كَفَروا مِنهُم عَذابٌ أَليمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dccxliii{أَفَلا يَتوبونَ إِلَى اللَّهِ وَيَستَغفِرونَهُ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dccxliv{مَا المَسيحُ ابنُ مَريَمَ إِلّا رَسولٌ قَد خَلَت مِن قَبلِهِ الرُّسُلُ وَأُمُّهُ صِدّيقَةٌ كانا يَأكُلانِ الطَّعامَ انظُر كَيفَ نُبَيِّنُ لَهُمُ الءايٰتِ ثُمَّ انظُر أَنّىٰ يُؤفَكونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dccxlv{قُل أَتَعبُدونَ مِن دونِ اللَّهِ ما لا يَملِكُ لَكُم ضَرًّا وَلا نَفعًا وَاللَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dccxlvi{قُل يٰأَهلَ الكِتٰبِ لا تَغلوا فى دينِكُم غَيرَ الحَقِّ وَلا تَتَّبِعوا أَهواءَ قَومٍ قَد ضَلّوا مِن قَبلُ وَأَضَلّوا كَثيرًا وَضَلّوا عَن سَواءِ السَّبيلِ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dccxlvii{لُعِنَ الَّذينَ كَفَروا مِن بَنى إِسرٰءيلَ عَلىٰ لِسانِ داوۥدَ وَعيسَى ابنِ مَريَمَ ذٰلِكَ بِما عَصَوا وَكانوا يَعتَدونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dccxlviii{كانوا لا يَتَناهَونَ عَن مُنكَرٍ فَعَلوهُ لَبِئسَ ما كانوا يَفعَلونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dccxlix{تَرىٰ كَثيرًا مِنهُم يَتَوَلَّونَ الَّذينَ كَفَروا لَبِئسَ ما قَدَّمَت لَهُم أَنفُسُهُم أَن سَخِطَ اللَّهُ عَلَيهِم وَفِى العَذابِ هُم خٰلِدونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dccl{وَلَو كانوا يُؤمِنونَ بِاللَّهِ وَالنَّبِىِّ وَما أُنزِلَ إِلَيهِ مَا اتَّخَذوهُم أَولِياءَ وَلٰكِنَّ كَثيرًا مِنهُم فٰسِقونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dccli{لَتَجِدَنَّ أَشَدَّ النّاسِ عَدٰوَةً لِلَّذينَ ءامَنُوا اليَهودَ وَالَّذينَ أَشرَكوا وَلَتَجِدَنَّ أَقرَبَهُم مَوَدَّةً لِلَّذينَ ءامَنُوا الَّذينَ قالوا إِنّا نَصٰرىٰ ذٰلِكَ بِأَنَّ مِنهُم قِسّيسينَ وَرُهبانًا وَأَنَّهُم لا يَستَكبِرونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dcclii{وَإِذا سَمِعوا ما أُنزِلَ إِلَى الرَّسولِ تَرىٰ أَعيُنَهُم تَفيضُ مِنَ الدَّمعِ مِمّا عَرَفوا مِنَ الحَقِّ يَقولونَ رَبَّنا ءامَنّا فَاكتُبنا مَعَ الشّٰهِدينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dccliii{وَما لَنا لا نُؤمِنُ بِاللَّهِ وَما جاءَنا مِنَ الحَقِّ وَنَطمَعُ أَن يُدخِلَنا رَبُّنا مَعَ القَومِ الصّٰلِحينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dccliv{فَأَثٰبَهُمُ اللَّهُ بِما قالوا جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها وَذٰلِكَ جَزاءُ المُحسِنينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dcclv{وَالَّذينَ كَفَروا وَكَذَّبوا بِـٔايٰتِنا أُولٰئِكَ أَصحٰبُ الجَحيمِ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dcclvi{يٰأَيُّهَا الَّذينَ ءامَنوا لا تُحَرِّموا طَيِّبٰتِ ما أَحَلَّ اللَّهُ لَكُم وَلا تَعتَدوا إِنَّ اللَّهَ لا يُحِبُّ المُعتَدينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dcclvii{وَكُلوا مِمّا رَزَقَكُمُ اللَّهُ حَلٰلًا طَيِّبًا وَاتَّقُوا اللَّهَ الَّذى أَنتُم بِهِ مُؤمِنونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dcclviii{لا يُؤاخِذُكُمُ اللَّهُ بِاللَّغوِ فى أَيمٰنِكُم وَلٰكِن يُؤاخِذُكُم بِما عَقَّدتُمُ الأَيمٰنَ فَكَفّٰرَتُهُ إِطعامُ عَشَرَةِ مَسٰكينَ مِن أَوسَطِ ما تُطعِمونَ أَهليكُم أَو كِسوَتُهُم أَو تَحريرُ رَقَبَةٍ فَمَن لَم يَجِد فَصِيامُ ثَلٰثَةِ أَيّامٍ ذٰلِكَ كَفّٰرَةُ أَيمٰنِكُم إِذا حَلَفتُم وَاحفَظوا أَيمٰنَكُم كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُم ءايٰتِهِ لَعَلَّكُم تَشكُرونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dcclix{يٰأَيُّهَا الَّذينَ ءامَنوا إِنَّمَا الخَمرُ وَالمَيسِرُ وَالأَنصابُ وَالأَزلٰمُ رِجسٌ مِن عَمَلِ الشَّيطٰنِ فَاجتَنِبوهُ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dcclx{إِنَّما يُريدُ الشَّيطٰنُ أَن يوقِعَ بَينَكُمُ العَدٰوَةَ وَالبَغضاءَ فِى الخَمرِ وَالمَيسِرِ وَيَصُدَّكُم عَن ذِكرِ اللَّهِ وَعَنِ الصَّلوٰةِ فَهَل أَنتُم مُنتَهونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dcclxi{وَأَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ وَاحذَروا فَإِن تَوَلَّيتُم فَاعلَموا أَنَّما عَلىٰ رَسولِنَا البَلٰغُ المُبينُ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dcclxii{لَيسَ عَلَى الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ جُناحٌ فيما طَعِموا إِذا مَا اتَّقَوا وَءامَنوا وَعَمِلُوا الصّٰلِحٰتِ ثُمَّ اتَّقَوا وَءامَنوا ثُمَّ اتَّقَوا وَأَحسَنوا وَاللَّهُ يُحِبُّ المُحسِنينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dcclxiii{يٰأَيُّهَا الَّذينَ ءامَنوا لَيَبلُوَنَّكُمُ اللَّهُ بِشَيءٍ مِنَ الصَّيدِ تَنالُهُ أَيديكُم وَرِماحُكُم لِيَعلَمَ اللَّهُ مَن يَخافُهُ بِالغَيبِ فَمَنِ اعتَدىٰ بَعدَ ذٰلِكَ فَلَهُ عَذابٌ أَليمٌ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dcclxiv{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَقتُلُوا الصَّيدَ وَأَنتُم حُرُمٌ وَمَن قَتَلَهُ مِنكُم مُتَعَمِّدًا فَجَزاءٌ مِثلُ ما قَتَلَ مِنَ النَّعَمِ يَحكُمُ بِهِ ذَوا عَدلٍ مِنكُم هَديًا بٰلِغَ الكَعبَةِ أَو كَفّٰرَةٌ طَعامُ مَسٰكينَ أَو عَدلُ ذٰلِكَ صِيامًا لِيَذوقَ وَبالَ أَمرِهِ عَفَا اللَّهُ عَمّا سَلَفَ وَمَن عادَ فَيَنتَقِمُ اللَّهُ مِنهُ وَاللَّهُ عَزيزٌ ذُو انتِقامٍ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dcclxv{أُحِلَّ لَكُم صَيدُ البَحرِ وَطَعامُهُ مَتٰعًا لَكُم وَلِلسَّيّارَةِ وَحُرِّمَ عَلَيكُم صَيدُ البَرِّ ما دُمتُم حُرُمًا وَاتَّقُوا اللَّهَ الَّذى إِلَيهِ تُحشَرونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dcclxvi{جَعَلَ اللَّهُ الكَعبَةَ البَيتَ الحَرامَ قِيٰمًا لِلنّاسِ وَالشَّهرَ الحَرامَ وَالهَدىَ وَالقَلٰئِدَ ذٰلِكَ لِتَعلَموا أَنَّ اللَّهَ يَعلَمُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَأَنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dcclxvii{اعلَموا أَنَّ اللَّهَ شَديدُ العِقابِ وَأَنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dcclxviii{ما عَلَى الرَّسولِ إِلَّا البَلٰغُ وَاللَّهُ يَعلَمُ ما تُبدونَ وَما تَكتُمونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dcclxix{قُل لا يَستَوِى الخَبيثُ وَالطَّيِّبُ وَلَو أَعجَبَكَ كَثرَةُ الخَبيثِ فَاتَّقُوا اللَّهَ يٰأُولِى الأَلبٰبِ لَعَلَّكُم تُفلِحونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dcclxx{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَسـَٔلوا عَن أَشياءَ إِن تُبدَ لَكُم تَسُؤكُم وَإِن تَسـَٔلوا عَنها حينَ يُنَزَّلُ القُرءانُ تُبدَ لَكُم عَفَا اللَّهُ عَنها وَاللَّهُ غَفورٌ حَليمٌ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dcclxxi{قَد سَأَلَها قَومٌ مِن قَبلِكُم ثُمَّ أَصبَحوا بِها كٰفِرينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dcclxxii{ما جَعَلَ اللَّهُ مِن بَحيرَةٍ وَلا سائِبَةٍ وَلا وَصيلَةٍ وَلا حامٍ وَلٰكِنَّ الَّذينَ كَفَروا يَفتَرونَ عَلَى اللَّهِ الكَذِبَ وَأَكثَرُهُم لا يَعقِلونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dcclxxiii{وَإِذا قيلَ لَهُم تَعالَوا إِلىٰ ما أَنزَلَ اللَّهُ وَإِلَى الرَّسولِ قالوا حَسبُنا ما وَجَدنا عَلَيهِ ءاباءَنا أَوَلَو كانَ ءاباؤُهُم لا يَعلَمونَ شَيـًٔا وَلا يَهتَدونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dcclxxiv{يٰأَيُّهَا الَّذينَ ءامَنوا عَلَيكُم أَنفُسَكُم لا يَضُرُّكُم مَن ضَلَّ إِذَا اهتَدَيتُم إِلَى اللَّهِ مَرجِعُكُم جَميعًا فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dcclxxv{يٰأَيُّهَا الَّذينَ ءامَنوا شَهٰدَةُ بَينِكُم إِذا حَضَرَ أَحَدَكُمُ المَوتُ حينَ الوَصِيَّةِ اثنانِ ذَوا عَدلٍ مِنكُم أَو ءاخَرانِ مِن غَيرِكُم إِن أَنتُم ضَرَبتُم فِى الأَرضِ فَأَصٰبَتكُم مُصيبَةُ المَوتِ تَحبِسونَهُما مِن بَعدِ الصَّلوٰةِ فَيُقسِمانِ بِاللَّهِ إِنِ ارتَبتُم لا نَشتَرى بِهِ ثَمَنًا وَلَو كانَ ذا قُربىٰ وَلا نَكتُمُ شَهٰدَةَ اللَّهِ إِنّا إِذًا لَمِنَ الءاثِمينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dcclxxvi{فَإِن عُثِرَ عَلىٰ أَنَّهُمَا استَحَقّا إِثمًا فَـٔاخَرانِ يَقومانِ مَقامَهُما مِنَ الَّذينَ استَحَقَّ عَلَيهِمُ الأَولَيٰنِ فَيُقسِمانِ بِاللَّهِ لَشَهٰدَتُنا أَحَقُّ مِن شَهٰدَتِهِما وَمَا اعتَدَينا إِنّا إِذًا لَمِنَ الظّٰلِمينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dcclxxvii{ذٰلِكَ أَدنىٰ أَن يَأتوا بِالشَّهٰدَةِ عَلىٰ وَجهِها أَو يَخافوا أَن تُرَدَّ أَيمٰنٌ بَعدَ أَيمٰنِهِم وَاتَّقُوا اللَّهَ وَاسمَعوا وَاللَّهُ لا يَهدِى القَومَ الفٰسِقينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcclxxviii{يَومَ يَجمَعُ اللَّهُ الرُّسُلَ فَيَقولُ ماذا أُجِبتُم قالوا لا عِلمَ لَنا إِنَّكَ أَنتَ عَلّٰمُ الغُيوبِ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dcclxxix{إِذ قالَ اللَّهُ يٰعيسَى ابنَ مَريَمَ اذكُر نِعمَتى عَلَيكَ وَعَلىٰ وٰلِدَتِكَ إِذ أَيَّدتُكَ بِروحِ القُدُسِ تُكَلِّمُ النّاسَ فِى المَهدِ وَكَهلًا وَإِذ عَلَّمتُكَ الكِتٰبَ وَالحِكمَةَ وَالتَّورىٰةَ وَالإِنجيلَ وَإِذ تَخلُقُ مِنَ الطّينِ كَهَيـَٔةِ الطَّيرِ بِإِذنى فَتَنفُخُ فيها فَتَكونُ طَيرًا بِإِذنى وَتُبرِئُ الأَكمَهَ وَالأَبرَصَ بِإِذنى وَإِذ تُخرِجُ المَوتىٰ بِإِذنى وَإِذ كَفَفتُ بَنى إِسرٰءيلَ عَنكَ إِذ جِئتَهُم بِالبَيِّنٰتِ فَقالَ الَّذينَ كَفَروا مِنهُم إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@dcclxxx{وَإِذ أَوحَيتُ إِلَى الحَوارِيّۦنَ أَن ءامِنوا بى وَبِرَسولى قالوا ءامَنّا وَاشهَد بِأَنَّنا مُسلِمونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@dcclxxxi{إِذ قالَ الحَوارِيّونَ يٰعيسَى ابنَ مَريَمَ هَل يَستَطيعُ رَبُّكَ أَن يُنَزِّلَ عَلَينا مائِدَةً مِنَ السَّماءِ قالَ اتَّقُوا اللَّهَ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@dcclxxxii{قالوا نُريدُ أَن نَأكُلَ مِنها وَتَطمَئِنَّ قُلوبُنا وَنَعلَمَ أَن قَد صَدَقتَنا وَنَكونَ عَلَيها مِنَ الشّٰهِدينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@dcclxxxiii{قالَ عيسَى ابنُ مَريَمَ اللَّهُمَّ رَبَّنا أَنزِل عَلَينا مائِدَةً مِنَ السَّماءِ تَكونُ لَنا عيدًا لِأَوَّلِنا وَءاخِرِنا وَءايَةً مِنكَ وَارزُقنا وَأَنتَ خَيرُ الرّٰزِقينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@dcclxxxiv{قالَ اللَّهُ إِنّى مُنَزِّلُها عَلَيكُم فَمَن يَكفُر بَعدُ مِنكُم فَإِنّى أُعَذِّبُهُ عَذابًا لا أُعَذِّبُهُ أَحَدًا مِنَ العٰلَمينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@dcclxxxv{وَإِذ قالَ اللَّهُ يٰعيسَى ابنَ مَريَمَ ءَأَنتَ قُلتَ لِلنّاسِ اتَّخِذونى وَأُمِّىَ إِلٰهَينِ مِن دونِ اللَّهِ قالَ سُبحٰنَكَ ما يَكونُ لى أَن أَقولَ ما لَيسَ لى بِحَقٍّ إِن كُنتُ قُلتُهُ فَقَد عَلِمتَهُ تَعلَمُ ما فى نَفسى وَلا أَعلَمُ ما فى نَفسِكَ إِنَّكَ أَنتَ عَلّٰمُ الغُيوبِ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@dcclxxxvi{ما قُلتُ لَهُم إِلّا ما أَمَرتَنى بِهِ أَنِ اعبُدُوا اللَّهَ رَبّى وَرَبَّكُم وَكُنتُ عَلَيهِم شَهيدًا ما دُمتُ فيهِم فَلَمّا تَوَفَّيتَنى كُنتَ أَنتَ الرَّقيبَ عَلَيهِم وَأَنتَ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@dcclxxxvii{إِن تُعَذِّبهُم فَإِنَّهُم عِبادُكَ وَإِن تَغفِر لَهُم فَإِنَّكَ أَنتَ العَزيزُ الحَكيمُ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@dcclxxxviii{قالَ اللَّهُ هٰذا يَومُ يَنفَعُ الصّٰدِقينَ صِدقُهُم لَهُم جَنّٰتٌ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها أَبَدًا رَضِىَ اللَّهُ عَنهُم وَرَضوا عَنهُ ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@dcclxxxix{لِلَّهِ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَما فيهِنَّ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@dccxc{\basmalah  الحَمدُ لِلَّهِ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ وَجَعَلَ الظُّلُمٰتِ وَالنّورَ ثُمَّ الَّذينَ كَفَروا بِرَبِّهِم يَعدِلونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@dccxci{هُوَ الَّذى خَلَقَكُم مِن طينٍ ثُمَّ قَضىٰ أَجَلًا وَأَجَلٌ مُسَمًّى عِندَهُ ثُمَّ أَنتُم تَمتَرونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@dccxcii{وَهُوَ اللَّهُ فِى السَّمٰوٰتِ وَفِى الأَرضِ يَعلَمُ سِرَّكُم وَجَهرَكُم وَيَعلَمُ ما تَكسِبونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@dccxciii{وَما تَأتيهِم مِن ءايَةٍ مِن ءايٰتِ رَبِّهِم إِلّا كانوا عَنها مُعرِضينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@dccxciv{فَقَد كَذَّبوا بِالحَقِّ لَمّا جاءَهُم فَسَوفَ يَأتيهِم أَنبٰؤُا۟ ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@dccxcv{أَلَم يَرَوا كَم أَهلَكنا مِن قَبلِهِم مِن قَرنٍ مَكَّنّٰهُم فِى الأَرضِ ما لَم نُمَكِّن لَكُم وَأَرسَلنَا السَّماءَ عَلَيهِم مِدرارًا وَجَعَلنَا الأَنهٰرَ تَجرى مِن تَحتِهِم فَأَهلَكنٰهُم بِذُنوبِهِم وَأَنشَأنا مِن بَعدِهِم قَرنًا ءاخَرينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@dccxcvi{وَلَو نَزَّلنا عَلَيكَ كِتٰبًا فى قِرطاسٍ فَلَمَسوهُ بِأَيديهِم لَقالَ الَّذينَ كَفَروا إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@dccxcvii{وَقالوا لَولا أُنزِلَ عَلَيهِ مَلَكٌ وَلَو أَنزَلنا مَلَكًا لَقُضِىَ الأَمرُ ثُمَّ لا يُنظَرونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@dccxcviii{وَلَو جَعَلنٰهُ مَلَكًا لَجَعَلنٰهُ رَجُلًا وَلَلَبَسنا عَلَيهِم ما يَلبِسونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@dccxcix{وَلَقَدِ استُهزِئَ بِرُسُلٍ مِن قَبلِكَ فَحاقَ بِالَّذينَ سَخِروا مِنهُم ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@dccc{قُل سيروا فِى الأَرضِ ثُمَّ انظُروا كَيفَ كانَ عٰقِبَةُ المُكَذِّبينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@dccci{قُل لِمَن ما فِى السَّمٰوٰتِ وَالأَرضِ قُل لِلَّهِ كَتَبَ عَلىٰ نَفسِهِ الرَّحمَةَ لَيَجمَعَنَّكُم إِلىٰ يَومِ القِيٰمَةِ لا رَيبَ فيهِ الَّذينَ خَسِروا أَنفُسَهُم فَهُم لا يُؤمِنونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@dcccii{وَلَهُ ما سَكَنَ فِى الَّيلِ وَالنَّهارِ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@dccciii{قُل أَغَيرَ اللَّهِ أَتَّخِذُ وَلِيًّا فاطِرِ السَّمٰوٰتِ وَالأَرضِ وَهُوَ يُطعِمُ وَلا يُطعَمُ قُل إِنّى أُمِرتُ أَن أَكونَ أَوَّلَ مَن أَسلَمَ وَلا تَكونَنَّ مِنَ المُشرِكينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@dccciv{قُل إِنّى أَخافُ إِن عَصَيتُ رَبّى عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@dcccv{مَن يُصرَف عَنهُ يَومَئِذٍ فَقَد رَحِمَهُ وَذٰلِكَ الفَوزُ المُبينُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@dcccvi{وَإِن يَمسَسكَ اللَّهُ بِضُرٍّ فَلا كاشِفَ لَهُ إِلّا هُوَ وَإِن يَمسَسكَ بِخَيرٍ فَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@dcccvii{وَهُوَ القاهِرُ فَوقَ عِبادِهِ وَهُوَ الحَكيمُ الخَبيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@dcccviii{قُل أَىُّ شَيءٍ أَكبَرُ شَهٰدَةً قُلِ اللَّهُ شَهيدٌ بَينى وَبَينَكُم وَأوحِىَ إِلَىَّ هٰذَا القُرءانُ لِأُنذِرَكُم بِهِ وَمَن بَلَغَ أَئِنَّكُم لَتَشهَدونَ أَنَّ مَعَ اللَّهِ ءالِهَةً أُخرىٰ قُل لا أَشهَدُ قُل إِنَّما هُوَ إِلٰهٌ وٰحِدٌ وَإِنَّنى بَريءٌ مِمّا تُشرِكونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@dcccix{الَّذينَ ءاتَينٰهُمُ الكِتٰبَ يَعرِفونَهُ كَما يَعرِفونَ أَبناءَهُمُ الَّذينَ خَسِروا أَنفُسَهُم فَهُم لا يُؤمِنونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@dcccx{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو كَذَّبَ بِـٔايٰتِهِ إِنَّهُ لا يُفلِحُ الظّٰلِمونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@dcccxi{وَيَومَ نَحشُرُهُم جَميعًا ثُمَّ نَقولُ لِلَّذينَ أَشرَكوا أَينَ شُرَكاؤُكُمُ الَّذينَ كُنتُم تَزعُمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@dcccxii{ثُمَّ لَم تَكُن فِتنَتُهُم إِلّا أَن قالوا وَاللَّهِ رَبِّنا ما كُنّا مُشرِكينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@dcccxiii{انظُر كَيفَ كَذَبوا عَلىٰ أَنفُسِهِم وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@dcccxiv{وَمِنهُم مَن يَستَمِعُ إِلَيكَ وَجَعَلنا عَلىٰ قُلوبِهِم أَكِنَّةً أَن يَفقَهوهُ وَفى ءاذانِهِم وَقرًا وَإِن يَرَوا كُلَّ ءايَةٍ لا يُؤمِنوا بِها حَتّىٰ إِذا جاءوكَ يُجٰدِلونَكَ يَقولُ الَّذينَ كَفَروا إِن هٰذا إِلّا أَسٰطيرُ الأَوَّلينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@dcccxv{وَهُم يَنهَونَ عَنهُ وَيَنـَٔونَ عَنهُ وَإِن يُهلِكونَ إِلّا أَنفُسَهُم وَما يَشعُرونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@dcccxvi{وَلَو تَرىٰ إِذ وُقِفوا عَلَى النّارِ فَقالوا يٰلَيتَنا نُرَدُّ وَلا نُكَذِّبَ بِـٔايٰتِ رَبِّنا وَنَكونَ مِنَ المُؤمِنينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@dcccxvii{بَل بَدا لَهُم ما كانوا يُخفونَ مِن قَبلُ وَلَو رُدّوا لَعادوا لِما نُهوا عَنهُ وَإِنَّهُم لَكٰذِبونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@dcccxviii{وَقالوا إِن هِىَ إِلّا حَياتُنَا الدُّنيا وَما نَحنُ بِمَبعوثينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@dcccxix{وَلَو تَرىٰ إِذ وُقِفوا عَلىٰ رَبِّهِم قالَ أَلَيسَ هٰذا بِالحَقِّ قالوا بَلىٰ وَرَبِّنا قالَ فَذوقُوا العَذابَ بِما كُنتُم تَكفُرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@dcccxx{قَد خَسِرَ الَّذينَ كَذَّبوا بِلِقاءِ اللَّهِ حَتّىٰ إِذا جاءَتهُمُ السّاعَةُ بَغتَةً قالوا يٰحَسرَتَنا عَلىٰ ما فَرَّطنا فيها وَهُم يَحمِلونَ أَوزارَهُم عَلىٰ ظُهورِهِم أَلا ساءَ ما يَزِرونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@dcccxxi{وَمَا الحَيوٰةُ الدُّنيا إِلّا لَعِبٌ وَلَهوٌ وَلَلدّارُ الءاخِرَةُ خَيرٌ لِلَّذينَ يَتَّقونَ أَفَلا تَعقِلونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@dcccxxii{قَد نَعلَمُ إِنَّهُ لَيَحزُنُكَ الَّذى يَقولونَ فَإِنَّهُم لا يُكَذِّبونَكَ وَلٰكِنَّ الظّٰلِمينَ بِـٔايٰتِ اللَّهِ يَجحَدونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@dcccxxiii{وَلَقَد كُذِّبَت رُسُلٌ مِن قَبلِكَ فَصَبَروا عَلىٰ ما كُذِّبوا وَأوذوا حَتّىٰ أَتىٰهُم نَصرُنا وَلا مُبَدِّلَ لِكَلِمٰتِ اللَّهِ وَلَقَد جاءَكَ مِن نَبَإِي۟ المُرسَلينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@dcccxxiv{وَإِن كانَ كَبُرَ عَلَيكَ إِعراضُهُم فَإِنِ استَطَعتَ أَن تَبتَغِىَ نَفَقًا فِى الأَرضِ أَو سُلَّمًا فِى السَّماءِ فَتَأتِيَهُم بِـٔايَةٍ وَلَو شاءَ اللَّهُ لَجَمَعَهُم عَلَى الهُدىٰ فَلا تَكونَنَّ مِنَ الجٰهِلينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@dcccxxv{إِنَّما يَستَجيبُ الَّذينَ يَسمَعونَ وَالمَوتىٰ يَبعَثُهُمُ اللَّهُ ثُمَّ إِلَيهِ يُرجَعونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@dcccxxvi{وَقالوا لَولا نُزِّلَ عَلَيهِ ءايَةٌ مِن رَبِّهِ قُل إِنَّ اللَّهَ قادِرٌ عَلىٰ أَن يُنَزِّلَ ءايَةً وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@dcccxxvii{وَما مِن دابَّةٍ فِى الأَرضِ وَلا طٰئِرٍ يَطيرُ بِجَناحَيهِ إِلّا أُمَمٌ أَمثالُكُم ما فَرَّطنا فِى الكِتٰبِ مِن شَيءٍ ثُمَّ إِلىٰ رَبِّهِم يُحشَرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@dcccxxviii{وَالَّذينَ كَذَّبوا بِـٔايٰتِنا صُمٌّ وَبُكمٌ فِى الظُّلُمٰتِ مَن يَشَإِ اللَّهُ يُضلِلهُ وَمَن يَشَأ يَجعَلهُ عَلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@dcccxxix{قُل أَرَءَيتَكُم إِن أَتىٰكُم عَذابُ اللَّهِ أَو أَتَتكُمُ السّاعَةُ أَغَيرَ اللَّهِ تَدعونَ إِن كُنتُم صٰدِقينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@dcccxxx{بَل إِيّاهُ تَدعونَ فَيَكشِفُ ما تَدعونَ إِلَيهِ إِن شاءَ وَتَنسَونَ ما تُشرِكونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@dcccxxxi{وَلَقَد أَرسَلنا إِلىٰ أُمَمٍ مِن قَبلِكَ فَأَخَذنٰهُم بِالبَأساءِ وَالضَّرّاءِ لَعَلَّهُم يَتَضَرَّعونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@dcccxxxii{فَلَولا إِذ جاءَهُم بَأسُنا تَضَرَّعوا وَلٰكِن قَسَت قُلوبُهُم وَزَيَّنَ لَهُمُ الشَّيطٰنُ ما كانوا يَعمَلونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@dcccxxxiii{فَلَمّا نَسوا ما ذُكِّروا بِهِ فَتَحنا عَلَيهِم أَبوٰبَ كُلِّ شَيءٍ حَتّىٰ إِذا فَرِحوا بِما أوتوا أَخَذنٰهُم بَغتَةً فَإِذا هُم مُبلِسونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@dcccxxxiv{فَقُطِعَ دابِرُ القَومِ الَّذينَ ظَلَموا وَالحَمدُ لِلَّهِ رَبِّ العٰلَمينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@dcccxxxv{قُل أَرَءَيتُم إِن أَخَذَ اللَّهُ سَمعَكُم وَأَبصٰرَكُم وَخَتَمَ عَلىٰ قُلوبِكُم مَن إِلٰهٌ غَيرُ اللَّهِ يَأتيكُم بِهِ انظُر كَيفَ نُصَرِّفُ الءايٰتِ ثُمَّ هُم يَصدِفونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@dcccxxxvi{قُل أَرَءَيتَكُم إِن أَتىٰكُم عَذابُ اللَّهِ بَغتَةً أَو جَهرَةً هَل يُهلَكُ إِلَّا القَومُ الظّٰلِمونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@dcccxxxvii{وَما نُرسِلُ المُرسَلينَ إِلّا مُبَشِّرينَ وَمُنذِرينَ فَمَن ءامَنَ وَأَصلَحَ فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@dcccxxxviii{وَالَّذينَ كَذَّبوا بِـٔايٰتِنا يَمَسُّهُمُ العَذابُ بِما كانوا يَفسُقونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@dcccxxxix{قُل لا أَقولُ لَكُم عِندى خَزائِنُ اللَّهِ وَلا أَعلَمُ الغَيبَ وَلا أَقولُ لَكُم إِنّى مَلَكٌ إِن أَتَّبِعُ إِلّا ما يوحىٰ إِلَىَّ قُل هَل يَستَوِى الأَعمىٰ وَالبَصيرُ أَفَلا تَتَفَكَّرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@dcccxl{وَأَنذِر بِهِ الَّذينَ يَخافونَ أَن يُحشَروا إِلىٰ رَبِّهِم لَيسَ لَهُم مِن دونِهِ وَلِىٌّ وَلا شَفيعٌ لَعَلَّهُم يَتَّقونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@dcccxli{وَلا تَطرُدِ الَّذينَ يَدعونَ رَبَّهُم بِالغَدوٰةِ وَالعَشِىِّ يُريدونَ وَجهَهُ ما عَلَيكَ مِن حِسابِهِم مِن شَيءٍ وَما مِن حِسابِكَ عَلَيهِم مِن شَيءٍ فَتَطرُدَهُم فَتَكونَ مِنَ الظّٰلِمينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@dcccxlii{وَكَذٰلِكَ فَتَنّا بَعضَهُم بِبَعضٍ لِيَقولوا أَهٰؤُلاءِ مَنَّ اللَّهُ عَلَيهِم مِن بَينِنا أَلَيسَ اللَّهُ بِأَعلَمَ بِالشّٰكِرينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@dcccxliii{وَإِذا جاءَكَ الَّذينَ يُؤمِنونَ بِـٔايٰتِنا فَقُل سَلٰمٌ عَلَيكُم كَتَبَ رَبُّكُم عَلىٰ نَفسِهِ الرَّحمَةَ أَنَّهُ مَن عَمِلَ مِنكُم سوءًا بِجَهٰلَةٍ ثُمَّ تابَ مِن بَعدِهِ وَأَصلَحَ فَأَنَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@dcccxliv{وَكَذٰلِكَ نُفَصِّلُ الءايٰتِ وَلِتَستَبينَ سَبيلُ المُجرِمينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@dcccxlv{قُل إِنّى نُهيتُ أَن أَعبُدَ الَّذينَ تَدعونَ مِن دونِ اللَّهِ قُل لا أَتَّبِعُ أَهواءَكُم قَد ضَلَلتُ إِذًا وَما أَنا۠ مِنَ المُهتَدينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@dcccxlvi{قُل إِنّى عَلىٰ بَيِّنَةٍ مِن رَبّى وَكَذَّبتُم بِهِ ما عِندى ما تَستَعجِلونَ بِهِ إِنِ الحُكمُ إِلّا لِلَّهِ يَقُصُّ الحَقَّ وَهُوَ خَيرُ الفٰصِلينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@dcccxlvii{قُل لَو أَنَّ عِندى ما تَستَعجِلونَ بِهِ لَقُضِىَ الأَمرُ بَينى وَبَينَكُم وَاللَّهُ أَعلَمُ بِالظّٰلِمينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@dcccxlviii{وَعِندَهُ مَفاتِحُ الغَيبِ لا يَعلَمُها إِلّا هُوَ وَيَعلَمُ ما فِى البَرِّ وَالبَحرِ وَما تَسقُطُ مِن وَرَقَةٍ إِلّا يَعلَمُها وَلا حَبَّةٍ فى ظُلُمٰتِ الأَرضِ وَلا رَطبٍ وَلا يابِسٍ إِلّا فى كِتٰبٍ مُبينٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@dcccxlix{وَهُوَ الَّذى يَتَوَفّىٰكُم بِالَّيلِ وَيَعلَمُ ما جَرَحتُم بِالنَّهارِ ثُمَّ يَبعَثُكُم فيهِ لِيُقضىٰ أَجَلٌ مُسَمًّى ثُمَّ إِلَيهِ مَرجِعُكُم ثُمَّ يُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@dcccl{وَهُوَ القاهِرُ فَوقَ عِبادِهِ وَيُرسِلُ عَلَيكُم حَفَظَةً حَتّىٰ إِذا جاءَ أَحَدَكُمُ المَوتُ تَوَفَّتهُ رُسُلُنا وَهُم لا يُفَرِّطونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@dcccli{ثُمَّ رُدّوا إِلَى اللَّهِ مَولىٰهُمُ الحَقِّ أَلا لَهُ الحُكمُ وَهُوَ أَسرَعُ الحٰسِبينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@dccclii{قُل مَن يُنَجّيكُم مِن ظُلُمٰتِ البَرِّ وَالبَحرِ تَدعونَهُ تَضَرُّعًا وَخُفيَةً لَئِن أَنجىٰنا مِن هٰذِهِ لَنَكونَنَّ مِنَ الشّٰكِرينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@dcccliii{قُلِ اللَّهُ يُنَجّيكُم مِنها وَمِن كُلِّ كَربٍ ثُمَّ أَنتُم تُشرِكونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@dcccliv{قُل هُوَ القادِرُ عَلىٰ أَن يَبعَثَ عَلَيكُم عَذابًا مِن فَوقِكُم أَو مِن تَحتِ أَرجُلِكُم أَو يَلبِسَكُم شِيَعًا وَيُذيقَ بَعضَكُم بَأسَ بَعضٍ انظُر كَيفَ نُصَرِّفُ الءايٰتِ لَعَلَّهُم يَفقَهونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@dccclv{وَكَذَّبَ بِهِ قَومُكَ وَهُوَ الحَقُّ قُل لَستُ عَلَيكُم بِوَكيلٍ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@dccclvi{لِكُلِّ نَبَإٍ مُستَقَرٌّ وَسَوفَ تَعلَمونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@dccclvii{وَإِذا رَأَيتَ الَّذينَ يَخوضونَ فى ءايٰتِنا فَأَعرِض عَنهُم حَتّىٰ يَخوضوا فى حَديثٍ غَيرِهِ وَإِمّا يُنسِيَنَّكَ الشَّيطٰنُ فَلا تَقعُد بَعدَ الذِّكرىٰ مَعَ القَومِ الظّٰلِمينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@dccclviii{وَما عَلَى الَّذينَ يَتَّقونَ مِن حِسابِهِم مِن شَيءٍ وَلٰكِن ذِكرىٰ لَعَلَّهُم يَتَّقونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@dccclix{وَذَرِ الَّذينَ اتَّخَذوا دينَهُم لَعِبًا وَلَهوًا وَغَرَّتهُمُ الحَيوٰةُ الدُّنيا وَذَكِّر بِهِ أَن تُبسَلَ نَفسٌ بِما كَسَبَت لَيسَ لَها مِن دونِ اللَّهِ وَلِىٌّ وَلا شَفيعٌ وَإِن تَعدِل كُلَّ عَدلٍ لا يُؤخَذ مِنها أُولٰئِكَ الَّذينَ أُبسِلوا بِما كَسَبوا لَهُم شَرابٌ مِن حَميمٍ وَعَذابٌ أَليمٌ بِما كانوا يَكفُرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@dccclx{قُل أَنَدعوا مِن دونِ اللَّهِ ما لا يَنفَعُنا وَلا يَضُرُّنا وَنُرَدُّ عَلىٰ أَعقابِنا بَعدَ إِذ هَدىٰنَا اللَّهُ كَالَّذِى استَهوَتهُ الشَّيٰطينُ فِى الأَرضِ حَيرانَ لَهُ أَصحٰبٌ يَدعونَهُ إِلَى الهُدَى ائتِنا قُل إِنَّ هُدَى اللَّهِ هُوَ الهُدىٰ وَأُمِرنا لِنُسلِمَ لِرَبِّ العٰلَمينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@dccclxi{وَأَن أَقيمُوا الصَّلوٰةَ وَاتَّقوهُ وَهُوَ الَّذى إِلَيهِ تُحشَرونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@dccclxii{وَهُوَ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ بِالحَقِّ وَيَومَ يَقولُ كُن فَيَكونُ قَولُهُ الحَقُّ وَلَهُ المُلكُ يَومَ يُنفَخُ فِى الصّورِ عٰلِمُ الغَيبِ وَالشَّهٰدَةِ وَهُوَ الحَكيمُ الخَبيرُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@dccclxiii{وَإِذ قالَ إِبرٰهيمُ لِأَبيهِ ءازَرَ أَتَتَّخِذُ أَصنامًا ءالِهَةً إِنّى أَرىٰكَ وَقَومَكَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@dccclxiv{وَكَذٰلِكَ نُرى إِبرٰهيمَ مَلَكوتَ السَّمٰوٰتِ وَالأَرضِ وَلِيَكونَ مِنَ الموقِنينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@dccclxv{فَلَمّا جَنَّ عَلَيهِ الَّيلُ رَءا كَوكَبًا قالَ هٰذا رَبّى فَلَمّا أَفَلَ قالَ لا أُحِبُّ الءافِلينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@dccclxvi{فَلَمّا رَءَا القَمَرَ بازِغًا قالَ هٰذا رَبّى فَلَمّا أَفَلَ قالَ لَئِن لَم يَهدِنى رَبّى لَأَكونَنَّ مِنَ القَومِ الضّالّينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@dccclxvii{فَلَمّا رَءَا الشَّمسَ بازِغَةً قالَ هٰذا رَبّى هٰذا أَكبَرُ فَلَمّا أَفَلَت قالَ يٰقَومِ إِنّى بَريءٌ مِمّا تُشرِكونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@dccclxviii{إِنّى وَجَّهتُ وَجهِىَ لِلَّذى فَطَرَ السَّمٰوٰتِ وَالأَرضَ حَنيفًا وَما أَنا۠ مِنَ المُشرِكينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@dccclxix{وَحاجَّهُ قَومُهُ قالَ أَتُحٰجّونّى فِى اللَّهِ وَقَد هَدىٰنِ وَلا أَخافُ ما تُشرِكونَ بِهِ إِلّا أَن يَشاءَ رَبّى شَيـًٔا وَسِعَ رَبّى كُلَّ شَيءٍ عِلمًا أَفَلا تَتَذَكَّرونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@dccclxx{وَكَيفَ أَخافُ ما أَشرَكتُم وَلا تَخافونَ أَنَّكُم أَشرَكتُم بِاللَّهِ ما لَم يُنَزِّل بِهِ عَلَيكُم سُلطٰنًا فَأَىُّ الفَريقَينِ أَحَقُّ بِالأَمنِ إِن كُنتُم تَعلَمونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@dccclxxi{الَّذينَ ءامَنوا وَلَم يَلبِسوا إيمٰنَهُم بِظُلمٍ أُولٰئِكَ لَهُمُ الأَمنُ وَهُم مُهتَدونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@dccclxxii{وَتِلكَ حُجَّتُنا ءاتَينٰها إِبرٰهيمَ عَلىٰ قَومِهِ نَرفَعُ دَرَجٰتٍ مَن نَشاءُ إِنَّ رَبَّكَ حَكيمٌ عَليمٌ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@dccclxxiii{وَوَهَبنا لَهُ إِسحٰقَ وَيَعقوبَ كُلًّا هَدَينا وَنوحًا هَدَينا مِن قَبلُ وَمِن ذُرِّيَّتِهِ داوۥدَ وَسُلَيمٰنَ وَأَيّوبَ وَيوسُفَ وَموسىٰ وَهٰرونَ وَكَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@dccclxxiv{وَزَكَرِيّا وَيَحيىٰ وَعيسىٰ وَإِلياسَ كُلٌّ مِنَ الصّٰلِحينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@dccclxxv{وَإِسمٰعيلَ وَاليَسَعَ وَيونُسَ وَلوطًا وَكُلًّا فَضَّلنا عَلَى العٰلَمينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@dccclxxvi{وَمِن ءابائِهِم وَذُرِّيّٰتِهِم وَإِخوٰنِهِم وَاجتَبَينٰهُم وَهَدَينٰهُم إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@dccclxxvii{ذٰلِكَ هُدَى اللَّهِ يَهدى بِهِ مَن يَشاءُ مِن عِبادِهِ وَلَو أَشرَكوا لَحَبِطَ عَنهُم ما كانوا يَعمَلونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@dccclxxviii{أُولٰئِكَ الَّذينَ ءاتَينٰهُمُ الكِتٰبَ وَالحُكمَ وَالنُّبُوَّةَ فَإِن يَكفُر بِها هٰؤُلاءِ فَقَد وَكَّلنا بِها قَومًا لَيسوا بِها بِكٰفِرينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@dccclxxix{أُولٰئِكَ الَّذينَ هَدَى اللَّهُ فَبِهُدىٰهُمُ اقتَدِه قُل لا أَسـَٔلُكُم عَلَيهِ أَجرًا إِن هُوَ إِلّا ذِكرىٰ لِلعٰلَمينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@dccclxxx{وَما قَدَرُوا اللَّهَ حَقَّ قَدرِهِ إِذ قالوا ما أَنزَلَ اللَّهُ عَلىٰ بَشَرٍ مِن شَيءٍ قُل مَن أَنزَلَ الكِتٰبَ الَّذى جاءَ بِهِ موسىٰ نورًا وَهُدًى لِلنّاسِ تَجعَلونَهُ قَراطيسَ تُبدونَها وَتُخفونَ كَثيرًا وَعُلِّمتُم ما لَم تَعلَموا أَنتُم وَلا ءاباؤُكُم قُلِ اللَّهُ ثُمَّ ذَرهُم فى خَوضِهِم يَلعَبونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@dccclxxxi{وَهٰذا كِتٰبٌ أَنزَلنٰهُ مُبارَكٌ مُصَدِّقُ الَّذى بَينَ يَدَيهِ وَلِتُنذِرَ أُمَّ القُرىٰ وَمَن حَولَها وَالَّذينَ يُؤمِنونَ بِالءاخِرَةِ يُؤمِنونَ بِهِ وَهُم عَلىٰ صَلاتِهِم يُحافِظونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@dccclxxxii{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو قالَ أوحِىَ إِلَىَّ وَلَم يوحَ إِلَيهِ شَيءٌ وَمَن قالَ سَأُنزِلُ مِثلَ ما أَنزَلَ اللَّهُ وَلَو تَرىٰ إِذِ الظّٰلِمونَ فى غَمَرٰتِ المَوتِ وَالمَلٰئِكَةُ باسِطوا أَيديهِم أَخرِجوا أَنفُسَكُمُ اليَومَ تُجزَونَ عَذابَ الهونِ بِما كُنتُم تَقولونَ عَلَى اللَّهِ غَيرَ الحَقِّ وَكُنتُم عَن ءايٰتِهِ تَستَكبِرونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@dccclxxxiii{وَلَقَد جِئتُمونا فُرٰدىٰ كَما خَلَقنٰكُم أَوَّلَ مَرَّةٍ وَتَرَكتُم ما خَوَّلنٰكُم وَراءَ ظُهورِكُم وَما نَرىٰ مَعَكُم شُفَعاءَكُمُ الَّذينَ زَعَمتُم أَنَّهُم فيكُم شُرَكٰؤُا۟ لَقَد تَقَطَّعَ بَينَكُم وَضَلَّ عَنكُم ما كُنتُم تَزعُمونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@dccclxxxiv{إِنَّ اللَّهَ فالِقُ الحَبِّ وَالنَّوىٰ يُخرِجُ الحَىَّ مِنَ المَيِّتِ وَمُخرِجُ المَيِّتِ مِنَ الحَىِّ ذٰلِكُمُ اللَّهُ فَأَنّىٰ تُؤفَكونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@dccclxxxv{فالِقُ الإِصباحِ وَجَعَلَ الَّيلَ سَكَنًا وَالشَّمسَ وَالقَمَرَ حُسبانًا ذٰلِكَ تَقديرُ العَزيزِ العَليمِ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@dccclxxxvi{وَهُوَ الَّذى جَعَلَ لَكُمُ النُّجومَ لِتَهتَدوا بِها فى ظُلُمٰتِ البَرِّ وَالبَحرِ قَد فَصَّلنَا الءايٰتِ لِقَومٍ يَعلَمونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@dccclxxxvii{وَهُوَ الَّذى أَنشَأَكُم مِن نَفسٍ وٰحِدَةٍ فَمُستَقَرٌّ وَمُستَودَعٌ قَد فَصَّلنَا الءايٰتِ لِقَومٍ يَفقَهونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@dccclxxxviii{وَهُوَ الَّذى أَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجنا بِهِ نَباتَ كُلِّ شَيءٍ فَأَخرَجنا مِنهُ خَضِرًا نُخرِجُ مِنهُ حَبًّا مُتَراكِبًا وَمِنَ النَّخلِ مِن طَلعِها قِنوانٌ دانِيَةٌ وَجَنّٰتٍ مِن أَعنابٍ وَالزَّيتونَ وَالرُّمّانَ مُشتَبِهًا وَغَيرَ مُتَشٰبِهٍ انظُروا إِلىٰ ثَمَرِهِ إِذا أَثمَرَ وَيَنعِهِ إِنَّ فى ذٰلِكُم لَءايٰتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@dccclxxxix{وَجَعَلوا لِلَّهِ شُرَكاءَ الجِنَّ وَخَلَقَهُم وَخَرَقوا لَهُ بَنينَ وَبَنٰتٍ بِغَيرِ عِلمٍ سُبحٰنَهُ وَتَعٰلىٰ عَمّا يَصِفونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@dcccxc{بَديعُ السَّمٰوٰتِ وَالأَرضِ أَنّىٰ يَكونُ لَهُ وَلَدٌ وَلَم تَكُن لَهُ صٰحِبَةٌ وَخَلَقَ كُلَّ شَيءٍ وَهُوَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@dcccxci{ذٰلِكُمُ اللَّهُ رَبُّكُم لا إِلٰهَ إِلّا هُوَ خٰلِقُ كُلِّ شَيءٍ فَاعبُدوهُ وَهُوَ عَلىٰ كُلِّ شَيءٍ وَكيلٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@dcccxcii{لا تُدرِكُهُ الأَبصٰرُ وَهُوَ يُدرِكُ الأَبصٰرَ وَهُوَ اللَّطيفُ الخَبيرُ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@dcccxciii{قَد جاءَكُم بَصائِرُ مِن رَبِّكُم فَمَن أَبصَرَ فَلِنَفسِهِ وَمَن عَمِىَ فَعَلَيها وَما أَنا۠ عَلَيكُم بِحَفيظٍ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@dcccxciv{وَكَذٰلِكَ نُصَرِّفُ الءايٰتِ وَلِيَقولوا دَرَستَ وَلِنُبَيِّنَهُ لِقَومٍ يَعلَمونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@dcccxcv{اتَّبِع ما أوحِىَ إِلَيكَ مِن رَبِّكَ لا إِلٰهَ إِلّا هُوَ وَأَعرِض عَنِ المُشرِكينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@dcccxcvi{وَلَو شاءَ اللَّهُ ما أَشرَكوا وَما جَعَلنٰكَ عَلَيهِم حَفيظًا وَما أَنتَ عَلَيهِم بِوَكيلٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@dcccxcvii{وَلا تَسُبُّوا الَّذينَ يَدعونَ مِن دونِ اللَّهِ فَيَسُبُّوا اللَّهَ عَدوًا بِغَيرِ عِلمٍ كَذٰلِكَ زَيَّنّا لِكُلِّ أُمَّةٍ عَمَلَهُم ثُمَّ إِلىٰ رَبِّهِم مَرجِعُهُم فَيُنَبِّئُهُم بِما كانوا يَعمَلونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@dcccxcviii{وَأَقسَموا بِاللَّهِ جَهدَ أَيمٰنِهِم لَئِن جاءَتهُم ءايَةٌ لَيُؤمِنُنَّ بِها قُل إِنَّمَا الءايٰتُ عِندَ اللَّهِ وَما يُشعِرُكُم أَنَّها إِذا جاءَت لا يُؤمِنونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@dcccxcix{وَنُقَلِّبُ أَفـِٔدَتَهُم وَأَبصٰرَهُم كَما لَم يُؤمِنوا بِهِ أَوَّلَ مَرَّةٍ وَنَذَرُهُم فى طُغيٰنِهِم يَعمَهونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@cm{وَلَو أَنَّنا نَزَّلنا إِلَيهِمُ المَلٰئِكَةَ وَكَلَّمَهُمُ المَوتىٰ وَحَشَرنا عَلَيهِم كُلَّ شَيءٍ قُبُلًا ما كانوا لِيُؤمِنوا إِلّا أَن يَشاءَ اللَّهُ وَلٰكِنَّ أَكثَرَهُم يَجهَلونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@cmi{وَكَذٰلِكَ جَعَلنا لِكُلِّ نَبِىٍّ عَدُوًّا شَيٰطينَ الإِنسِ وَالجِنِّ يوحى بَعضُهُم إِلىٰ بَعضٍ زُخرُفَ القَولِ غُرورًا وَلَو شاءَ رَبُّكَ ما فَعَلوهُ فَذَرهُم وَما يَفتَرونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@cmii{وَلِتَصغىٰ إِلَيهِ أَفـِٔدَةُ الَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ وَلِيَرضَوهُ وَلِيَقتَرِفوا ما هُم مُقتَرِفونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@cmiii{أَفَغَيرَ اللَّهِ أَبتَغى حَكَمًا وَهُوَ الَّذى أَنزَلَ إِلَيكُمُ الكِتٰبَ مُفَصَّلًا وَالَّذينَ ءاتَينٰهُمُ الكِتٰبَ يَعلَمونَ أَنَّهُ مُنَزَّلٌ مِن رَبِّكَ بِالحَقِّ فَلا تَكونَنَّ مِنَ المُمتَرينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@cmiv{وَتَمَّت كَلِمَتُ رَبِّكَ صِدقًا وَعَدلًا لا مُبَدِّلَ لِكَلِمٰتِهِ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@cmv{وَإِن تُطِع أَكثَرَ مَن فِى الأَرضِ يُضِلّوكَ عَن سَبيلِ اللَّهِ إِن يَتَّبِعونَ إِلَّا الظَّنَّ وَإِن هُم إِلّا يَخرُصونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@cmvi{إِنَّ رَبَّكَ هُوَ أَعلَمُ مَن يَضِلُّ عَن سَبيلِهِ وَهُوَ أَعلَمُ بِالمُهتَدينَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@cmvii{فَكُلوا مِمّا ذُكِرَ اسمُ اللَّهِ عَلَيهِ إِن كُنتُم بِـٔايٰتِهِ مُؤمِنينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@cmviii{وَما لَكُم أَلّا تَأكُلوا مِمّا ذُكِرَ اسمُ اللَّهِ عَلَيهِ وَقَد فَصَّلَ لَكُم ما حَرَّمَ عَلَيكُم إِلّا مَا اضطُرِرتُم إِلَيهِ وَإِنَّ كَثيرًا لَيُضِلّونَ بِأَهوائِهِم بِغَيرِ عِلمٍ إِنَّ رَبَّكَ هُوَ أَعلَمُ بِالمُعتَدينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@cmix{وَذَروا ظٰهِرَ الإِثمِ وَباطِنَهُ إِنَّ الَّذينَ يَكسِبونَ الإِثمَ سَيُجزَونَ بِما كانوا يَقتَرِفونَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@cmx{وَلا تَأكُلوا مِمّا لَم يُذكَرِ اسمُ اللَّهِ عَلَيهِ وَإِنَّهُ لَفِسقٌ وَإِنَّ الشَّيٰطينَ لَيوحونَ إِلىٰ أَولِيائِهِم لِيُجٰدِلوكُم وَإِن أَطَعتُموهُم إِنَّكُم لَمُشرِكونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@cmxi{أَوَمَن كانَ مَيتًا فَأَحيَينٰهُ وَجَعَلنا لَهُ نورًا يَمشى بِهِ فِى النّاسِ كَمَن مَثَلُهُ فِى الظُّلُمٰتِ لَيسَ بِخارِجٍ مِنها كَذٰلِكَ زُيِّنَ لِلكٰفِرينَ ما كانوا يَعمَلونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@cmxii{وَكَذٰلِكَ جَعَلنا فى كُلِّ قَريَةٍ أَكٰبِرَ مُجرِميها لِيَمكُروا فيها وَما يَمكُرونَ إِلّا بِأَنفُسِهِم وَما يَشعُرونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@cmxiii{وَإِذا جاءَتهُم ءايَةٌ قالوا لَن نُؤمِنَ حَتّىٰ نُؤتىٰ مِثلَ ما أوتِىَ رُسُلُ اللَّهِ اللَّهُ أَعلَمُ حَيثُ يَجعَلُ رِسالَتَهُ سَيُصيبُ الَّذينَ أَجرَموا صَغارٌ عِندَ اللَّهِ وَعَذابٌ شَديدٌ بِما كانوا يَمكُرونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@cmxiv{فَمَن يُرِدِ اللَّهُ أَن يَهدِيَهُ يَشرَح صَدرَهُ لِلإِسلٰمِ وَمَن يُرِد أَن يُضِلَّهُ يَجعَل صَدرَهُ ضَيِّقًا حَرَجًا كَأَنَّما يَصَّعَّدُ فِى السَّماءِ كَذٰلِكَ يَجعَلُ اللَّهُ الرِّجسَ عَلَى الَّذينَ لا يُؤمِنونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@cmxv{وَهٰذا صِرٰطُ رَبِّكَ مُستَقيمًا قَد فَصَّلنَا الءايٰتِ لِقَومٍ يَذَّكَّرونَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@cmxvi{لَهُم دارُ السَّلٰمِ عِندَ رَبِّهِم وَهُوَ وَلِيُّهُم بِما كانوا يَعمَلونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@cmxvii{وَيَومَ يَحشُرُهُم جَميعًا يٰمَعشَرَ الجِنِّ قَدِ استَكثَرتُم مِنَ الإِنسِ وَقالَ أَولِياؤُهُم مِنَ الإِنسِ رَبَّنَا استَمتَعَ بَعضُنا بِبَعضٍ وَبَلَغنا أَجَلَنَا الَّذى أَجَّلتَ لَنا قالَ النّارُ مَثوىٰكُم خٰلِدينَ فيها إِلّا ما شاءَ اللَّهُ إِنَّ رَبَّكَ حَكيمٌ عَليمٌ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@cmxviii{وَكَذٰلِكَ نُوَلّى بَعضَ الظّٰلِمينَ بَعضًا بِما كانوا يَكسِبونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@cmxix{يٰمَعشَرَ الجِنِّ وَالإِنسِ أَلَم يَأتِكُم رُسُلٌ مِنكُم يَقُصّونَ عَلَيكُم ءايٰتى وَيُنذِرونَكُم لِقاءَ يَومِكُم هٰذا قالوا شَهِدنا عَلىٰ أَنفُسِنا وَغَرَّتهُمُ الحَيوٰةُ الدُّنيا وَشَهِدوا عَلىٰ أَنفُسِهِم أَنَّهُم كانوا كٰفِرينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@cmxx{ذٰلِكَ أَن لَم يَكُن رَبُّكَ مُهلِكَ القُرىٰ بِظُلمٍ وَأَهلُها غٰفِلونَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@cmxxi{وَلِكُلٍّ دَرَجٰتٌ مِمّا عَمِلوا وَما رَبُّكَ بِغٰفِلٍ عَمّا يَعمَلونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@cmxxii{وَرَبُّكَ الغَنِىُّ ذُو الرَّحمَةِ إِن يَشَأ يُذهِبكُم وَيَستَخلِف مِن بَعدِكُم ما يَشاءُ كَما أَنشَأَكُم مِن ذُرِّيَّةِ قَومٍ ءاخَرينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@cmxxiii{إِنَّ ما توعَدونَ لَءاتٍ وَما أَنتُم بِمُعجِزينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@cmxxiv{قُل يٰقَومِ اعمَلوا عَلىٰ مَكانَتِكُم إِنّى عامِلٌ فَسَوفَ تَعلَمونَ مَن تَكونُ لَهُ عٰقِبَةُ الدّارِ إِنَّهُ لا يُفلِحُ الظّٰلِمونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@cmxxv{وَجَعَلوا لِلَّهِ مِمّا ذَرَأَ مِنَ الحَرثِ وَالأَنعٰمِ نَصيبًا فَقالوا هٰذا لِلَّهِ بِزَعمِهِم وَهٰذا لِشُرَكائِنا فَما كانَ لِشُرَكائِهِم فَلا يَصِلُ إِلَى اللَّهِ وَما كانَ لِلَّهِ فَهُوَ يَصِلُ إِلىٰ شُرَكائِهِم ساءَ ما يَحكُمونَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@cmxxvi{وَكَذٰلِكَ زَيَّنَ لِكَثيرٍ مِنَ المُشرِكينَ قَتلَ أَولٰدِهِم شُرَكاؤُهُم لِيُردوهُم وَلِيَلبِسوا عَلَيهِم دينَهُم وَلَو شاءَ اللَّهُ ما فَعَلوهُ فَذَرهُم وَما يَفتَرونَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@cmxxvii{وَقالوا هٰذِهِ أَنعٰمٌ وَحَرثٌ حِجرٌ لا يَطعَمُها إِلّا مَن نَشاءُ بِزَعمِهِم وَأَنعٰمٌ حُرِّمَت ظُهورُها وَأَنعٰمٌ لا يَذكُرونَ اسمَ اللَّهِ عَلَيهَا افتِراءً عَلَيهِ سَيَجزيهِم بِما كانوا يَفتَرونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@cmxxviii{وَقالوا ما فى بُطونِ هٰذِهِ الأَنعٰمِ خالِصَةٌ لِذُكورِنا وَمُحَرَّمٌ عَلىٰ أَزوٰجِنا وَإِن يَكُن مَيتَةً فَهُم فيهِ شُرَكاءُ سَيَجزيهِم وَصفَهُم إِنَّهُ حَكيمٌ عَليمٌ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@cmxxix{قَد خَسِرَ الَّذينَ قَتَلوا أَولٰدَهُم سَفَهًا بِغَيرِ عِلمٍ وَحَرَّموا ما رَزَقَهُمُ اللَّهُ افتِراءً عَلَى اللَّهِ قَد ضَلّوا وَما كانوا مُهتَدينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@cmxxx{وَهُوَ الَّذى أَنشَأَ جَنّٰتٍ مَعروشٰتٍ وَغَيرَ مَعروشٰتٍ وَالنَّخلَ وَالزَّرعَ مُختَلِفًا أُكُلُهُ وَالزَّيتونَ وَالرُّمّانَ مُتَشٰبِهًا وَغَيرَ مُتَشٰبِهٍ كُلوا مِن ثَمَرِهِ إِذا أَثمَرَ وَءاتوا حَقَّهُ يَومَ حَصادِهِ وَلا تُسرِفوا إِنَّهُ لا يُحِبُّ المُسرِفينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@cmxxxi{وَمِنَ الأَنعٰمِ حَمولَةً وَفَرشًا كُلوا مِمّا رَزَقَكُمُ اللَّهُ وَلا تَتَّبِعوا خُطُوٰتِ الشَّيطٰنِ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@cmxxxii{ثَمٰنِيَةَ أَزوٰجٍ مِنَ الضَّأنِ اثنَينِ وَمِنَ المَعزِ اثنَينِ قُل ءالذَّكَرَينِ حَرَّمَ أَمِ الأُنثَيَينِ أَمَّا اشتَمَلَت عَلَيهِ أَرحامُ الأُنثَيَينِ نَبِّـٔونى بِعِلمٍ إِن كُنتُم صٰدِقينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@cmxxxiii{وَمِنَ الإِبِلِ اثنَينِ وَمِنَ البَقَرِ اثنَينِ قُل ءالذَّكَرَينِ حَرَّمَ أَمِ الأُنثَيَينِ أَمَّا اشتَمَلَت عَلَيهِ أَرحامُ الأُنثَيَينِ أَم كُنتُم شُهَداءَ إِذ وَصّىٰكُمُ اللَّهُ بِهٰذا فَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا لِيُضِلَّ النّاسَ بِغَيرِ عِلمٍ إِنَّ اللَّهَ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@cmxxxiv{قُل لا أَجِدُ فى ما أوحِىَ إِلَىَّ مُحَرَّمًا عَلىٰ طاعِمٍ يَطعَمُهُ إِلّا أَن يَكونَ مَيتَةً أَو دَمًا مَسفوحًا أَو لَحمَ خِنزيرٍ فَإِنَّهُ رِجسٌ أَو فِسقًا أُهِلَّ لِغَيرِ اللَّهِ بِهِ فَمَنِ اضطُرَّ غَيرَ باغٍ وَلا عادٍ فَإِنَّ رَبَّكَ غَفورٌ رَحيمٌ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@cmxxxv{وَعَلَى الَّذينَ هادوا حَرَّمنا كُلَّ ذى ظُفُرٍ وَمِنَ البَقَرِ وَالغَنَمِ حَرَّمنا عَلَيهِم شُحومَهُما إِلّا ما حَمَلَت ظُهورُهُما أَوِ الحَوايا أَو مَا اختَلَطَ بِعَظمٍ ذٰلِكَ جَزَينٰهُم بِبَغيِهِم وَإِنّا لَصٰدِقونَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@cmxxxvi{فَإِن كَذَّبوكَ فَقُل رَبُّكُم ذو رَحمَةٍ وٰسِعَةٍ وَلا يُرَدُّ بَأسُهُ عَنِ القَومِ المُجرِمينَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@cmxxxvii{سَيَقولُ الَّذينَ أَشرَكوا لَو شاءَ اللَّهُ ما أَشرَكنا وَلا ءاباؤُنا وَلا حَرَّمنا مِن شَيءٍ كَذٰلِكَ كَذَّبَ الَّذينَ مِن قَبلِهِم حَتّىٰ ذاقوا بَأسَنا قُل هَل عِندَكُم مِن عِلمٍ فَتُخرِجوهُ لَنا إِن تَتَّبِعونَ إِلَّا الظَّنَّ وَإِن أَنتُم إِلّا تَخرُصونَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@cmxxxviii{قُل فَلِلَّهِ الحُجَّةُ البٰلِغَةُ فَلَو شاءَ لَهَدىٰكُم أَجمَعينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@cmxxxix{قُل هَلُمَّ شُهَداءَكُمُ الَّذينَ يَشهَدونَ أَنَّ اللَّهَ حَرَّمَ هٰذا فَإِن شَهِدوا فَلا تَشهَد مَعَهُم وَلا تَتَّبِع أَهواءَ الَّذينَ كَذَّبوا بِـٔايٰتِنا وَالَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ وَهُم بِرَبِّهِم يَعدِلونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@cmxl{قُل تَعالَوا أَتلُ ما حَرَّمَ رَبُّكُم عَلَيكُم أَلّا تُشرِكوا بِهِ شَيـًٔا وَبِالوٰلِدَينِ إِحسٰنًا وَلا تَقتُلوا أَولٰدَكُم مِن إِملٰقٍ نَحنُ نَرزُقُكُم وَإِيّاهُم وَلا تَقرَبُوا الفَوٰحِشَ ما ظَهَرَ مِنها وَما بَطَنَ وَلا تَقتُلُوا النَّفسَ الَّتى حَرَّمَ اللَّهُ إِلّا بِالحَقِّ ذٰلِكُم وَصّىٰكُم بِهِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@cmxli{وَلا تَقرَبوا مالَ اليَتيمِ إِلّا بِالَّتى هِىَ أَحسَنُ حَتّىٰ يَبلُغَ أَشُدَّهُ وَأَوفُوا الكَيلَ وَالميزانَ بِالقِسطِ لا نُكَلِّفُ نَفسًا إِلّا وُسعَها وَإِذا قُلتُم فَاعدِلوا وَلَو كانَ ذا قُربىٰ وَبِعَهدِ اللَّهِ أَوفوا ذٰلِكُم وَصّىٰكُم بِهِ لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@cmxlii{وَأَنَّ هٰذا صِرٰطى مُستَقيمًا فَاتَّبِعوهُ وَلا تَتَّبِعُوا السُّبُلَ فَتَفَرَّقَ بِكُم عَن سَبيلِهِ ذٰلِكُم وَصّىٰكُم بِهِ لَعَلَّكُم تَتَّقونَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@cmxliii{ثُمَّ ءاتَينا موسَى الكِتٰبَ تَمامًا عَلَى الَّذى أَحسَنَ وَتَفصيلًا لِكُلِّ شَيءٍ وَهُدًى وَرَحمَةً لَعَلَّهُم بِلِقاءِ رَبِّهِم يُؤمِنونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@cmxliv{وَهٰذا كِتٰبٌ أَنزَلنٰهُ مُبارَكٌ فَاتَّبِعوهُ وَاتَّقوا لَعَلَّكُم تُرحَمونَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@cmxlv{أَن تَقولوا إِنَّما أُنزِلَ الكِتٰبُ عَلىٰ طائِفَتَينِ مِن قَبلِنا وَإِن كُنّا عَن دِراسَتِهِم لَغٰفِلينَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@cmxlvi{أَو تَقولوا لَو أَنّا أُنزِلَ عَلَينَا الكِتٰبُ لَكُنّا أَهدىٰ مِنهُم فَقَد جاءَكُم بَيِّنَةٌ مِن رَبِّكُم وَهُدًى وَرَحمَةٌ فَمَن أَظلَمُ مِمَّن كَذَّبَ بِـٔايٰتِ اللَّهِ وَصَدَفَ عَنها سَنَجزِى الَّذينَ يَصدِفونَ عَن ءايٰتِنا سوءَ العَذابِ بِما كانوا يَصدِفونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@cmxlvii{هَل يَنظُرونَ إِلّا أَن تَأتِيَهُمُ المَلٰئِكَةُ أَو يَأتِىَ رَبُّكَ أَو يَأتِىَ بَعضُ ءايٰتِ رَبِّكَ يَومَ يَأتى بَعضُ ءايٰتِ رَبِّكَ لا يَنفَعُ نَفسًا إيمٰنُها لَم تَكُن ءامَنَت مِن قَبلُ أَو كَسَبَت فى إيمٰنِها خَيرًا قُلِ انتَظِروا إِنّا مُنتَظِرونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@cmxlviii{إِنَّ الَّذينَ فَرَّقوا دينَهُم وَكانوا شِيَعًا لَستَ مِنهُم فى شَيءٍ إِنَّما أَمرُهُم إِلَى اللَّهِ ثُمَّ يُنَبِّئُهُم بِما كانوا يَفعَلونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@cmxlix{مَن جاءَ بِالحَسَنَةِ فَلَهُ عَشرُ أَمثالِها وَمَن جاءَ بِالسَّيِّئَةِ فَلا يُجزىٰ إِلّا مِثلَها وَهُم لا يُظلَمونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@cml{قُل إِنَّنى هَدىٰنى رَبّى إِلىٰ صِرٰطٍ مُستَقيمٍ دينًا قِيَمًا مِلَّةَ إِبرٰهيمَ حَنيفًا وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@cmli{قُل إِنَّ صَلاتى وَنُسُكى وَمَحياىَ وَمَماتى لِلَّهِ رَبِّ العٰلَمينَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@cmlii{لا شَريكَ لَهُ وَبِذٰلِكَ أُمِرتُ وَأَنا۠ أَوَّلُ المُسلِمينَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@cmliii{قُل أَغَيرَ اللَّهِ أَبغى رَبًّا وَهُوَ رَبُّ كُلِّ شَيءٍ وَلا تَكسِبُ كُلُّ نَفسٍ إِلّا عَلَيها وَلا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ ثُمَّ إِلىٰ رَبِّكُم مَرجِعُكُم فَيُنَبِّئُكُم بِما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@cmliv{وَهُوَ الَّذى جَعَلَكُم خَلٰئِفَ الأَرضِ وَرَفَعَ بَعضَكُم فَوقَ بَعضٍ دَرَجٰتٍ لِيَبلُوَكُم فى ما ءاتىٰكُم إِنَّ رَبَّكَ سَريعُ العِقابِ وَإِنَّهُ لَغَفورٌ رَحيمٌ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@cmlv{\basmalah  المص\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@cmlvi{كِتٰبٌ أُنزِلَ إِلَيكَ فَلا يَكُن فى صَدرِكَ حَرَجٌ مِنهُ لِتُنذِرَ بِهِ وَذِكرىٰ لِلمُؤمِنينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@cmlvii{اتَّبِعوا ما أُنزِلَ إِلَيكُم مِن رَبِّكُم وَلا تَتَّبِعوا مِن دونِهِ أَولِياءَ قَليلًا ما تَذَكَّرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@cmlviii{وَكَم مِن قَريَةٍ أَهلَكنٰها فَجاءَها بَأسُنا بَيٰتًا أَو هُم قائِلونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@cmlix{فَما كانَ دَعوىٰهُم إِذ جاءَهُم بَأسُنا إِلّا أَن قالوا إِنّا كُنّا ظٰلِمينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@cmlx{فَلَنَسـَٔلَنَّ الَّذينَ أُرسِلَ إِلَيهِم وَلَنَسـَٔلَنَّ المُرسَلينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@cmlxi{فَلَنَقُصَّنَّ عَلَيهِم بِعِلمٍ وَما كُنّا غائِبينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@cmlxii{وَالوَزنُ يَومَئِذٍ الحَقُّ فَمَن ثَقُلَت مَوٰزينُهُ فَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@cmlxiii{وَمَن خَفَّت مَوٰزينُهُ فَأُولٰئِكَ الَّذينَ خَسِروا أَنفُسَهُم بِما كانوا بِـٔايٰتِنا يَظلِمونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@cmlxiv{وَلَقَد مَكَّنّٰكُم فِى الأَرضِ وَجَعَلنا لَكُم فيها مَعٰيِشَ قَليلًا ما تَشكُرونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@cmlxv{وَلَقَد خَلَقنٰكُم ثُمَّ صَوَّرنٰكُم ثُمَّ قُلنا لِلمَلٰئِكَةِ اسجُدوا لِءادَمَ فَسَجَدوا إِلّا إِبليسَ لَم يَكُن مِنَ السّٰجِدينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@cmlxvi{قالَ ما مَنَعَكَ أَلّا تَسجُدَ إِذ أَمَرتُكَ قالَ أَنا۠ خَيرٌ مِنهُ خَلَقتَنى مِن نارٍ وَخَلَقتَهُ مِن طينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@cmlxvii{قالَ فَاهبِط مِنها فَما يَكونُ لَكَ أَن تَتَكَبَّرَ فيها فَاخرُج إِنَّكَ مِنَ الصّٰغِرينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@cmlxviii{قالَ أَنظِرنى إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@cmlxix{قالَ إِنَّكَ مِنَ المُنظَرينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@cmlxx{قالَ فَبِما أَغوَيتَنى لَأَقعُدَنَّ لَهُم صِرٰطَكَ المُستَقيمَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@cmlxxi{ثُمَّ لَءاتِيَنَّهُم مِن بَينِ أَيديهِم وَمِن خَلفِهِم وَعَن أَيمٰنِهِم وَعَن شَمائِلِهِم وَلا تَجِدُ أَكثَرَهُم شٰكِرينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@cmlxxii{قالَ اخرُج مِنها مَذءومًا مَدحورًا لَمَن تَبِعَكَ مِنهُم لَأَملَأَنَّ جَهَنَّمَ مِنكُم أَجمَعينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@cmlxxiii{وَيٰـٔادَمُ اسكُن أَنتَ وَزَوجُكَ الجَنَّةَ فَكُلا مِن حَيثُ شِئتُما وَلا تَقرَبا هٰذِهِ الشَّجَرَةَ فَتَكونا مِنَ الظّٰلِمينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@cmlxxiv{فَوَسوَسَ لَهُمَا الشَّيطٰنُ لِيُبدِىَ لَهُما ما وۥرِىَ عَنهُما مِن سَوءٰتِهِما وَقالَ ما نَهىٰكُما رَبُّكُما عَن هٰذِهِ الشَّجَرَةِ إِلّا أَن تَكونا مَلَكَينِ أَو تَكونا مِنَ الخٰلِدينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@cmlxxv{وَقاسَمَهُما إِنّى لَكُما لَمِنَ النّٰصِحينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@cmlxxvi{فَدَلّىٰهُما بِغُرورٍ فَلَمّا ذاقَا الشَّجَرَةَ بَدَت لَهُما سَوءٰتُهُما وَطَفِقا يَخصِفانِ عَلَيهِما مِن وَرَقِ الجَنَّةِ وَنادىٰهُما رَبُّهُما أَلَم أَنهَكُما عَن تِلكُمَا الشَّجَرَةِ وَأَقُل لَكُما إِنَّ الشَّيطٰنَ لَكُما عَدُوٌّ مُبينٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@cmlxxvii{قالا رَبَّنا ظَلَمنا أَنفُسَنا وَإِن لَم تَغفِر لَنا وَتَرحَمنا لَنَكونَنَّ مِنَ الخٰسِرينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@cmlxxviii{قالَ اهبِطوا بَعضُكُم لِبَعضٍ عَدُوٌّ وَلَكُم فِى الأَرضِ مُستَقَرٌّ وَمَتٰعٌ إِلىٰ حينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@cmlxxix{قالَ فيها تَحيَونَ وَفيها تَموتونَ وَمِنها تُخرَجونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@cmlxxx{يٰبَنى ءادَمَ قَد أَنزَلنا عَلَيكُم لِباسًا يُوٰرى سَوءٰتِكُم وَريشًا وَلِباسُ التَّقوىٰ ذٰلِكَ خَيرٌ ذٰلِكَ مِن ءايٰتِ اللَّهِ لَعَلَّهُم يَذَّكَّرونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@cmlxxxi{يٰبَنى ءادَمَ لا يَفتِنَنَّكُمُ الشَّيطٰنُ كَما أَخرَجَ أَبَوَيكُم مِنَ الجَنَّةِ يَنزِعُ عَنهُما لِباسَهُما لِيُرِيَهُما سَوءٰتِهِما إِنَّهُ يَرىٰكُم هُوَ وَقَبيلُهُ مِن حَيثُ لا تَرَونَهُم إِنّا جَعَلنَا الشَّيٰطينَ أَولِياءَ لِلَّذينَ لا يُؤمِنونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@cmlxxxii{وَإِذا فَعَلوا فٰحِشَةً قالوا وَجَدنا عَلَيها ءاباءَنا وَاللَّهُ أَمَرَنا بِها قُل إِنَّ اللَّهَ لا يَأمُرُ بِالفَحشاءِ أَتَقولونَ عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@cmlxxxiii{قُل أَمَرَ رَبّى بِالقِسطِ وَأَقيموا وُجوهَكُم عِندَ كُلِّ مَسجِدٍ وَادعوهُ مُخلِصينَ لَهُ الدّينَ كَما بَدَأَكُم تَعودونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@cmlxxxiv{فَريقًا هَدىٰ وَفَريقًا حَقَّ عَلَيهِمُ الضَّلٰلَةُ إِنَّهُمُ اتَّخَذُوا الشَّيٰطينَ أَولِياءَ مِن دونِ اللَّهِ وَيَحسَبونَ أَنَّهُم مُهتَدونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@cmlxxxv{يٰبَنى ءادَمَ خُذوا زينَتَكُم عِندَ كُلِّ مَسجِدٍ وَكُلوا وَاشرَبوا وَلا تُسرِفوا إِنَّهُ لا يُحِبُّ المُسرِفينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@cmlxxxvi{قُل مَن حَرَّمَ زينَةَ اللَّهِ الَّتى أَخرَجَ لِعِبادِهِ وَالطَّيِّبٰتِ مِنَ الرِّزقِ قُل هِىَ لِلَّذينَ ءامَنوا فِى الحَيوٰةِ الدُّنيا خالِصَةً يَومَ القِيٰمَةِ كَذٰلِكَ نُفَصِّلُ الءايٰتِ لِقَومٍ يَعلَمونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@cmlxxxvii{قُل إِنَّما حَرَّمَ رَبِّىَ الفَوٰحِشَ ما ظَهَرَ مِنها وَما بَطَنَ وَالإِثمَ وَالبَغىَ بِغَيرِ الحَقِّ وَأَن تُشرِكوا بِاللَّهِ ما لَم يُنَزِّل بِهِ سُلطٰنًا وَأَن تَقولوا عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@cmlxxxviii{وَلِكُلِّ أُمَّةٍ أَجَلٌ فَإِذا جاءَ أَجَلُهُم لا يَستَأخِرونَ ساعَةً وَلا يَستَقدِمونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@cmlxxxix{يٰبَنى ءادَمَ إِمّا يَأتِيَنَّكُم رُسُلٌ مِنكُم يَقُصّونَ عَلَيكُم ءايٰتى فَمَنِ اتَّقىٰ وَأَصلَحَ فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@cmxc{وَالَّذينَ كَذَّبوا بِـٔايٰتِنا وَاستَكبَروا عَنها أُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@cmxci{فَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو كَذَّبَ بِـٔايٰتِهِ أُولٰئِكَ يَنالُهُم نَصيبُهُم مِنَ الكِتٰبِ حَتّىٰ إِذا جاءَتهُم رُسُلُنا يَتَوَفَّونَهُم قالوا أَينَ ما كُنتُم تَدعونَ مِن دونِ اللَّهِ قالوا ضَلّوا عَنّا وَشَهِدوا عَلىٰ أَنفُسِهِم أَنَّهُم كانوا كٰفِرينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@cmxcii{قالَ ادخُلوا فى أُمَمٍ قَد خَلَت مِن قَبلِكُم مِنَ الجِنِّ وَالإِنسِ فِى النّارِ كُلَّما دَخَلَت أُمَّةٌ لَعَنَت أُختَها حَتّىٰ إِذَا ادّارَكوا فيها جَميعًا قالَت أُخرىٰهُم لِأولىٰهُم رَبَّنا هٰؤُلاءِ أَضَلّونا فَـٔاتِهِم عَذابًا ضِعفًا مِنَ النّارِ قالَ لِكُلٍّ ضِعفٌ وَلٰكِن لا تَعلَمونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@cmxciii{وَقالَت أولىٰهُم لِأُخرىٰهُم فَما كانَ لَكُم عَلَينا مِن فَضلٍ فَذوقُوا العَذابَ بِما كُنتُم تَكسِبونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@cmxciv{إِنَّ الَّذينَ كَذَّبوا بِـٔايٰتِنا وَاستَكبَروا عَنها لا تُفَتَّحُ لَهُم أَبوٰبُ السَّماءِ وَلا يَدخُلونَ الجَنَّةَ حَتّىٰ يَلِجَ الجَمَلُ فى سَمِّ الخِياطِ وَكَذٰلِكَ نَجزِى المُجرِمينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@cmxcv{لَهُم مِن جَهَنَّمَ مِهادٌ وَمِن فَوقِهِم غَواشٍ وَكَذٰلِكَ نَجزِى الظّٰلِمينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@cmxcvi{وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لا نُكَلِّفُ نَفسًا إِلّا وُسعَها أُولٰئِكَ أَصحٰبُ الجَنَّةِ هُم فيها خٰلِدونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@cmxcvii{وَنَزَعنا ما فى صُدورِهِم مِن غِلٍّ تَجرى مِن تَحتِهِمُ الأَنهٰرُ وَقالُوا الحَمدُ لِلَّهِ الَّذى هَدىٰنا لِهٰذا وَما كُنّا لِنَهتَدِىَ لَولا أَن هَدىٰنَا اللَّهُ لَقَد جاءَت رُسُلُ رَبِّنا بِالحَقِّ وَنودوا أَن تِلكُمُ الجَنَّةُ أورِثتُموها بِما كُنتُم تَعمَلونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@cmxcviii{وَنادىٰ أَصحٰبُ الجَنَّةِ أَصحٰبَ النّارِ أَن قَد وَجَدنا ما وَعَدَنا رَبُّنا حَقًّا فَهَل وَجَدتُم ما وَعَدَ رَبُّكُم حَقًّا قالوا نَعَم فَأَذَّنَ مُؤَذِّنٌ بَينَهُم أَن لَعنَةُ اللَّهِ عَلَى الظّٰلِمينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@cmxcix{الَّذينَ يَصُدّونَ عَن سَبيلِ اللَّهِ وَيَبغونَها عِوَجًا وَهُم بِالءاخِرَةِ كٰفِرونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@m{وَبَينَهُما حِجابٌ وَعَلَى الأَعرافِ رِجالٌ يَعرِفونَ كُلًّا بِسيمىٰهُم وَنادَوا أَصحٰبَ الجَنَّةِ أَن سَلٰمٌ عَلَيكُم لَم يَدخُلوها وَهُم يَطمَعونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mi{وَإِذا صُرِفَت أَبصٰرُهُم تِلقاءَ أَصحٰبِ النّارِ قالوا رَبَّنا لا تَجعَلنا مَعَ القَومِ الظّٰلِمينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mii{وَنادىٰ أَصحٰبُ الأَعرافِ رِجالًا يَعرِفونَهُم بِسيمىٰهُم قالوا ما أَغنىٰ عَنكُم جَمعُكُم وَما كُنتُم تَستَكبِرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@miii{أَهٰؤُلاءِ الَّذينَ أَقسَمتُم لا يَنالُهُمُ اللَّهُ بِرَحمَةٍ ادخُلُوا الجَنَّةَ لا خَوفٌ عَلَيكُم وَلا أَنتُم تَحزَنونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@miv{وَنادىٰ أَصحٰبُ النّارِ أَصحٰبَ الجَنَّةِ أَن أَفيضوا عَلَينا مِنَ الماءِ أَو مِمّا رَزَقَكُمُ اللَّهُ قالوا إِنَّ اللَّهَ حَرَّمَهُما عَلَى الكٰفِرينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mv{الَّذينَ اتَّخَذوا دينَهُم لَهوًا وَلَعِبًا وَغَرَّتهُمُ الحَيوٰةُ الدُّنيا فَاليَومَ نَنسىٰهُم كَما نَسوا لِقاءَ يَومِهِم هٰذا وَما كانوا بِـٔايٰتِنا يَجحَدونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mvi{وَلَقَد جِئنٰهُم بِكِتٰبٍ فَصَّلنٰهُ عَلىٰ عِلمٍ هُدًى وَرَحمَةً لِقَومٍ يُؤمِنونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mvii{هَل يَنظُرونَ إِلّا تَأويلَهُ يَومَ يَأتى تَأويلُهُ يَقولُ الَّذينَ نَسوهُ مِن قَبلُ قَد جاءَت رُسُلُ رَبِّنا بِالحَقِّ فَهَل لَنا مِن شُفَعاءَ فَيَشفَعوا لَنا أَو نُرَدُّ فَنَعمَلَ غَيرَ الَّذى كُنّا نَعمَلُ قَد خَسِروا أَنفُسَهُم وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mviii{إِنَّ رَبَّكُمُ اللَّهُ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ فى سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ يُغشِى الَّيلَ النَّهارَ يَطلُبُهُ حَثيثًا وَالشَّمسَ وَالقَمَرَ وَالنُّجومَ مُسَخَّرٰتٍ بِأَمرِهِ أَلا لَهُ الخَلقُ وَالأَمرُ تَبارَكَ اللَّهُ رَبُّ العٰلَمينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mix{ادعوا رَبَّكُم تَضَرُّعًا وَخُفيَةً إِنَّهُ لا يُحِبُّ المُعتَدينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mx{وَلا تُفسِدوا فِى الأَرضِ بَعدَ إِصلٰحِها وَادعوهُ خَوفًا وَطَمَعًا إِنَّ رَحمَتَ اللَّهِ قَريبٌ مِنَ المُحسِنينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mxi{وَهُوَ الَّذى يُرسِلُ الرِّيٰحَ بُشرًا بَينَ يَدَى رَحمَتِهِ حَتّىٰ إِذا أَقَلَّت سَحابًا ثِقالًا سُقنٰهُ لِبَلَدٍ مَيِّتٍ فَأَنزَلنا بِهِ الماءَ فَأَخرَجنا بِهِ مِن كُلِّ الثَّمَرٰتِ كَذٰلِكَ نُخرِجُ المَوتىٰ لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mxii{وَالبَلَدُ الطَّيِّبُ يَخرُجُ نَباتُهُ بِإِذنِ رَبِّهِ وَالَّذى خَبُثَ لا يَخرُجُ إِلّا نَكِدًا كَذٰلِكَ نُصَرِّفُ الءايٰتِ لِقَومٍ يَشكُرونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mxiii{لَقَد أَرسَلنا نوحًا إِلىٰ قَومِهِ فَقالَ يٰقَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ إِنّى أَخافُ عَلَيكُم عَذابَ يَومٍ عَظيمٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mxiv{قالَ المَلَأُ مِن قَومِهِ إِنّا لَنَرىٰكَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mxv{قالَ يٰقَومِ لَيسَ بى ضَلٰلَةٌ وَلٰكِنّى رَسولٌ مِن رَبِّ العٰلَمينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mxvi{أُبَلِّغُكُم رِسٰلٰتِ رَبّى وَأَنصَحُ لَكُم وَأَعلَمُ مِنَ اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mxvii{أَوَعَجِبتُم أَن جاءَكُم ذِكرٌ مِن رَبِّكُم عَلىٰ رَجُلٍ مِنكُم لِيُنذِرَكُم وَلِتَتَّقوا وَلَعَلَّكُم تُرحَمونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mxviii{فَكَذَّبوهُ فَأَنجَينٰهُ وَالَّذينَ مَعَهُ فِى الفُلكِ وَأَغرَقنَا الَّذينَ كَذَّبوا بِـٔايٰتِنا إِنَّهُم كانوا قَومًا عَمينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mxix{وَإِلىٰ عادٍ أَخاهُم هودًا قالَ يٰقَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ أَفَلا تَتَّقونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mxx{قالَ المَلَأُ الَّذينَ كَفَروا مِن قَومِهِ إِنّا لَنَرىٰكَ فى سَفاهَةٍ وَإِنّا لَنَظُنُّكَ مِنَ الكٰذِبينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mxxi{قالَ يٰقَومِ لَيسَ بى سَفاهَةٌ وَلٰكِنّى رَسولٌ مِن رَبِّ العٰلَمينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mxxii{أُبَلِّغُكُم رِسٰلٰتِ رَبّى وَأَنا۠ لَكُم ناصِحٌ أَمينٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mxxiii{أَوَعَجِبتُم أَن جاءَكُم ذِكرٌ مِن رَبِّكُم عَلىٰ رَجُلٍ مِنكُم لِيُنذِرَكُم وَاذكُروا إِذ جَعَلَكُم خُلَفاءَ مِن بَعدِ قَومِ نوحٍ وَزادَكُم فِى الخَلقِ بَصۜطَةً فَاذكُروا ءالاءَ اللَّهِ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mxxiv{قالوا أَجِئتَنا لِنَعبُدَ اللَّهَ وَحدَهُ وَنَذَرَ ما كانَ يَعبُدُ ءاباؤُنا فَأتِنا بِما تَعِدُنا إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mxxv{قالَ قَد وَقَعَ عَلَيكُم مِن رَبِّكُم رِجسٌ وَغَضَبٌ أَتُجٰدِلونَنى فى أَسماءٍ سَمَّيتُموها أَنتُم وَءاباؤُكُم ما نَزَّلَ اللَّهُ بِها مِن سُلطٰنٍ فَانتَظِروا إِنّى مَعَكُم مِنَ المُنتَظِرينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mxxvi{فَأَنجَينٰهُ وَالَّذينَ مَعَهُ بِرَحمَةٍ مِنّا وَقَطَعنا دابِرَ الَّذينَ كَذَّبوا بِـٔايٰتِنا وَما كانوا مُؤمِنينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mxxvii{وَإِلىٰ ثَمودَ أَخاهُم صٰلِحًا قالَ يٰقَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ قَد جاءَتكُم بَيِّنَةٌ مِن رَبِّكُم هٰذِهِ ناقَةُ اللَّهِ لَكُم ءايَةً فَذَروها تَأكُل فى أَرضِ اللَّهِ وَلا تَمَسّوها بِسوءٍ فَيَأخُذَكُم عَذابٌ أَليمٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mxxviii{وَاذكُروا إِذ جَعَلَكُم خُلَفاءَ مِن بَعدِ عادٍ وَبَوَّأَكُم فِى الأَرضِ تَتَّخِذونَ مِن سُهولِها قُصورًا وَتَنحِتونَ الجِبالَ بُيوتًا فَاذكُروا ءالاءَ اللَّهِ وَلا تَعثَوا فِى الأَرضِ مُفسِدينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mxxix{قالَ المَلَأُ الَّذينَ استَكبَروا مِن قَومِهِ لِلَّذينَ استُضعِفوا لِمَن ءامَنَ مِنهُم أَتَعلَمونَ أَنَّ صٰلِحًا مُرسَلٌ مِن رَبِّهِ قالوا إِنّا بِما أُرسِلَ بِهِ مُؤمِنونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mxxx{قالَ الَّذينَ استَكبَروا إِنّا بِالَّذى ءامَنتُم بِهِ كٰفِرونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mxxxi{فَعَقَرُوا النّاقَةَ وَعَتَوا عَن أَمرِ رَبِّهِم وَقالوا يٰصٰلِحُ ائتِنا بِما تَعِدُنا إِن كُنتَ مِنَ المُرسَلينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mxxxii{فَأَخَذَتهُمُ الرَّجفَةُ فَأَصبَحوا فى دارِهِم جٰثِمينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mxxxiii{فَتَوَلّىٰ عَنهُم وَقالَ يٰقَومِ لَقَد أَبلَغتُكُم رِسالَةَ رَبّى وَنَصَحتُ لَكُم وَلٰكِن لا تُحِبّونَ النّٰصِحينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mxxxiv{وَلوطًا إِذ قالَ لِقَومِهِ أَتَأتونَ الفٰحِشَةَ ما سَبَقَكُم بِها مِن أَحَدٍ مِنَ العٰلَمينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mxxxv{إِنَّكُم لَتَأتونَ الرِّجالَ شَهوَةً مِن دونِ النِّساءِ بَل أَنتُم قَومٌ مُسرِفونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mxxxvi{وَما كانَ جَوابَ قَومِهِ إِلّا أَن قالوا أَخرِجوهُم مِن قَريَتِكُم إِنَّهُم أُناسٌ يَتَطَهَّرونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mxxxvii{فَأَنجَينٰهُ وَأَهلَهُ إِلَّا امرَأَتَهُ كانَت مِنَ الغٰبِرينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mxxxviii{وَأَمطَرنا عَلَيهِم مَطَرًا فَانظُر كَيفَ كانَ عٰقِبَةُ المُجرِمينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mxxxix{وَإِلىٰ مَديَنَ أَخاهُم شُعَيبًا قالَ يٰقَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ قَد جاءَتكُم بَيِّنَةٌ مِن رَبِّكُم فَأَوفُوا الكَيلَ وَالميزانَ وَلا تَبخَسُوا النّاسَ أَشياءَهُم وَلا تُفسِدوا فِى الأَرضِ بَعدَ إِصلٰحِها ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mxl{وَلا تَقعُدوا بِكُلِّ صِرٰطٍ توعِدونَ وَتَصُدّونَ عَن سَبيلِ اللَّهِ مَن ءامَنَ بِهِ وَتَبغونَها عِوَجًا وَاذكُروا إِذ كُنتُم قَليلًا فَكَثَّرَكُم وَانظُروا كَيفَ كانَ عٰقِبَةُ المُفسِدينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mxli{وَإِن كانَ طائِفَةٌ مِنكُم ءامَنوا بِالَّذى أُرسِلتُ بِهِ وَطائِفَةٌ لَم يُؤمِنوا فَاصبِروا حَتّىٰ يَحكُمَ اللَّهُ بَينَنا وَهُوَ خَيرُ الحٰكِمينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mxlii{قالَ المَلَأُ الَّذينَ استَكبَروا مِن قَومِهِ لَنُخرِجَنَّكَ يٰشُعَيبُ وَالَّذينَ ءامَنوا مَعَكَ مِن قَريَتِنا أَو لَتَعودُنَّ فى مِلَّتِنا قالَ أَوَلَو كُنّا كٰرِهينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mxliii{قَدِ افتَرَينا عَلَى اللَّهِ كَذِبًا إِن عُدنا فى مِلَّتِكُم بَعدَ إِذ نَجّىٰنَا اللَّهُ مِنها وَما يَكونُ لَنا أَن نَعودَ فيها إِلّا أَن يَشاءَ اللَّهُ رَبُّنا وَسِعَ رَبُّنا كُلَّ شَيءٍ عِلمًا عَلَى اللَّهِ تَوَكَّلنا رَبَّنَا افتَح بَينَنا وَبَينَ قَومِنا بِالحَقِّ وَأَنتَ خَيرُ الفٰتِحينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mxliv{وَقالَ المَلَأُ الَّذينَ كَفَروا مِن قَومِهِ لَئِنِ اتَّبَعتُم شُعَيبًا إِنَّكُم إِذًا لَخٰسِرونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mxlv{فَأَخَذَتهُمُ الرَّجفَةُ فَأَصبَحوا فى دارِهِم جٰثِمينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mxlvi{الَّذينَ كَذَّبوا شُعَيبًا كَأَن لَم يَغنَوا فيهَا الَّذينَ كَذَّبوا شُعَيبًا كانوا هُمُ الخٰسِرينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mxlvii{فَتَوَلّىٰ عَنهُم وَقالَ يٰقَومِ لَقَد أَبلَغتُكُم رِسٰلٰتِ رَبّى وَنَصَحتُ لَكُم فَكَيفَ ءاسىٰ عَلىٰ قَومٍ كٰفِرينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mxlviii{وَما أَرسَلنا فى قَريَةٍ مِن نَبِىٍّ إِلّا أَخَذنا أَهلَها بِالبَأساءِ وَالضَّرّاءِ لَعَلَّهُم يَضَّرَّعونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mxlix{ثُمَّ بَدَّلنا مَكانَ السَّيِّئَةِ الحَسَنَةَ حَتّىٰ عَفَوا وَقالوا قَد مَسَّ ءاباءَنَا الضَّرّاءُ وَالسَّرّاءُ فَأَخَذنٰهُم بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@ml{وَلَو أَنَّ أَهلَ القُرىٰ ءامَنوا وَاتَّقَوا لَفَتَحنا عَلَيهِم بَرَكٰتٍ مِنَ السَّماءِ وَالأَرضِ وَلٰكِن كَذَّبوا فَأَخَذنٰهُم بِما كانوا يَكسِبونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mli{أَفَأَمِنَ أَهلُ القُرىٰ أَن يَأتِيَهُم بَأسُنا بَيٰتًا وَهُم نائِمونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mlii{أَوَأَمِنَ أَهلُ القُرىٰ أَن يَأتِيَهُم بَأسُنا ضُحًى وَهُم يَلعَبونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mliii{أَفَأَمِنوا مَكرَ اللَّهِ فَلا يَأمَنُ مَكرَ اللَّهِ إِلَّا القَومُ الخٰسِرونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mliv{أَوَلَم يَهدِ لِلَّذينَ يَرِثونَ الأَرضَ مِن بَعدِ أَهلِها أَن لَو نَشاءُ أَصَبنٰهُم بِذُنوبِهِم وَنَطبَعُ عَلىٰ قُلوبِهِم فَهُم لا يَسمَعونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mlv{تِلكَ القُرىٰ نَقُصُّ عَلَيكَ مِن أَنبائِها وَلَقَد جاءَتهُم رُسُلُهُم بِالبَيِّنٰتِ فَما كانوا لِيُؤمِنوا بِما كَذَّبوا مِن قَبلُ كَذٰلِكَ يَطبَعُ اللَّهُ عَلىٰ قُلوبِ الكٰفِرينَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mlvi{وَما وَجَدنا لِأَكثَرِهِم مِن عَهدٍ وَإِن وَجَدنا أَكثَرَهُم لَفٰسِقينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mlvii{ثُمَّ بَعَثنا مِن بَعدِهِم موسىٰ بِـٔايٰتِنا إِلىٰ فِرعَونَ وَمَلَإِي۟هِ فَظَلَموا بِها فَانظُر كَيفَ كانَ عٰقِبَةُ المُفسِدينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mlviii{وَقالَ موسىٰ يٰفِرعَونُ إِنّى رَسولٌ مِن رَبِّ العٰلَمينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mlix{حَقيقٌ عَلىٰ أَن لا أَقولَ عَلَى اللَّهِ إِلَّا الحَقَّ قَد جِئتُكُم بِبَيِّنَةٍ مِن رَبِّكُم فَأَرسِل مَعِىَ بَنى إِسرٰءيلَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mlx{قالَ إِن كُنتَ جِئتَ بِـٔايَةٍ فَأتِ بِها إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mlxi{فَأَلقىٰ عَصاهُ فَإِذا هِىَ ثُعبانٌ مُبينٌ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mlxii{وَنَزَعَ يَدَهُ فَإِذا هِىَ بَيضاءُ لِلنّٰظِرينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mlxiii{قالَ المَلَأُ مِن قَومِ فِرعَونَ إِنَّ هٰذا لَسٰحِرٌ عَليمٌ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mlxiv{يُريدُ أَن يُخرِجَكُم مِن أَرضِكُم فَماذا تَأمُرونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mlxv{قالوا أَرجِه وَأَخاهُ وَأَرسِل فِى المَدائِنِ حٰشِرينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mlxvi{يَأتوكَ بِكُلِّ سٰحِرٍ عَليمٍ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mlxvii{وَجاءَ السَّحَرَةُ فِرعَونَ قالوا إِنَّ لَنا لَأَجرًا إِن كُنّا نَحنُ الغٰلِبينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mlxviii{قالَ نَعَم وَإِنَّكُم لَمِنَ المُقَرَّبينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mlxix{قالوا يٰموسىٰ إِمّا أَن تُلقِىَ وَإِمّا أَن نَكونَ نَحنُ المُلقينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mlxx{قالَ أَلقوا فَلَمّا أَلقَوا سَحَروا أَعيُنَ النّاسِ وَاستَرهَبوهُم وَجاءو بِسِحرٍ عَظيمٍ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mlxxi{وَأَوحَينا إِلىٰ موسىٰ أَن أَلقِ عَصاكَ فَإِذا هِىَ تَلقَفُ ما يَأفِكونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mlxxii{فَوَقَعَ الحَقُّ وَبَطَلَ ما كانوا يَعمَلونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mlxxiii{فَغُلِبوا هُنالِكَ وَانقَلَبوا صٰغِرينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mlxxiv{وَأُلقِىَ السَّحَرَةُ سٰجِدينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mlxxv{قالوا ءامَنّا بِرَبِّ العٰلَمينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mlxxvi{رَبِّ موسىٰ وَهٰرونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mlxxvii{قالَ فِرعَونُ ءامَنتُم بِهِ قَبلَ أَن ءاذَنَ لَكُم إِنَّ هٰذا لَمَكرٌ مَكَرتُموهُ فِى المَدينَةِ لِتُخرِجوا مِنها أَهلَها فَسَوفَ تَعلَمونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mlxxviii{لَأُقَطِّعَنَّ أَيدِيَكُم وَأَرجُلَكُم مِن خِلٰفٍ ثُمَّ لَأُصَلِّبَنَّكُم أَجمَعينَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mlxxix{قالوا إِنّا إِلىٰ رَبِّنا مُنقَلِبونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mlxxx{وَما تَنقِمُ مِنّا إِلّا أَن ءامَنّا بِـٔايٰتِ رَبِّنا لَمّا جاءَتنا رَبَّنا أَفرِغ عَلَينا صَبرًا وَتَوَفَّنا مُسلِمينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mlxxxi{وَقالَ المَلَأُ مِن قَومِ فِرعَونَ أَتَذَرُ موسىٰ وَقَومَهُ لِيُفسِدوا فِى الأَرضِ وَيَذَرَكَ وَءالِهَتَكَ قالَ سَنُقَتِّلُ أَبناءَهُم وَنَستَحيۦ نِساءَهُم وَإِنّا فَوقَهُم قٰهِرونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mlxxxii{قالَ موسىٰ لِقَومِهِ استَعينوا بِاللَّهِ وَاصبِروا إِنَّ الأَرضَ لِلَّهِ يورِثُها مَن يَشاءُ مِن عِبادِهِ وَالعٰقِبَةُ لِلمُتَّقينَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mlxxxiii{قالوا أوذينا مِن قَبلِ أَن تَأتِيَنا وَمِن بَعدِ ما جِئتَنا قالَ عَسىٰ رَبُّكُم أَن يُهلِكَ عَدُوَّكُم وَيَستَخلِفَكُم فِى الأَرضِ فَيَنظُرَ كَيفَ تَعمَلونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mlxxxiv{وَلَقَد أَخَذنا ءالَ فِرعَونَ بِالسِّنينَ وَنَقصٍ مِنَ الثَّمَرٰتِ لَعَلَّهُم يَذَّكَّرونَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mlxxxv{فَإِذا جاءَتهُمُ الحَسَنَةُ قالوا لَنا هٰذِهِ وَإِن تُصِبهُم سَيِّئَةٌ يَطَّيَّروا بِموسىٰ وَمَن مَعَهُ أَلا إِنَّما طٰئِرُهُم عِندَ اللَّهِ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mlxxxvi{وَقالوا مَهما تَأتِنا بِهِ مِن ءايَةٍ لِتَسحَرَنا بِها فَما نَحنُ لَكَ بِمُؤمِنينَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mlxxxvii{فَأَرسَلنا عَلَيهِمُ الطّوفانَ وَالجَرادَ وَالقُمَّلَ وَالضَّفادِعَ وَالدَّمَ ءايٰتٍ مُفَصَّلٰتٍ فَاستَكبَروا وَكانوا قَومًا مُجرِمينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mlxxxviii{وَلَمّا وَقَعَ عَلَيهِمُ الرِّجزُ قالوا يٰموسَى ادعُ لَنا رَبَّكَ بِما عَهِدَ عِندَكَ لَئِن كَشَفتَ عَنَّا الرِّجزَ لَنُؤمِنَنَّ لَكَ وَلَنُرسِلَنَّ مَعَكَ بَنى إِسرٰءيلَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mlxxxix{فَلَمّا كَشَفنا عَنهُمُ الرِّجزَ إِلىٰ أَجَلٍ هُم بٰلِغوهُ إِذا هُم يَنكُثونَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mxc{فَانتَقَمنا مِنهُم فَأَغرَقنٰهُم فِى اليَمِّ بِأَنَّهُم كَذَّبوا بِـٔايٰتِنا وَكانوا عَنها غٰفِلينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mxci{وَأَورَثنَا القَومَ الَّذينَ كانوا يُستَضعَفونَ مَشٰرِقَ الأَرضِ وَمَغٰرِبَهَا الَّتى بٰرَكنا فيها وَتَمَّت كَلِمَتُ رَبِّكَ الحُسنىٰ عَلىٰ بَنى إِسرٰءيلَ بِما صَبَروا وَدَمَّرنا ما كانَ يَصنَعُ فِرعَونُ وَقَومُهُ وَما كانوا يَعرِشونَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mxcii{وَجٰوَزنا بِبَنى إِسرٰءيلَ البَحرَ فَأَتَوا عَلىٰ قَومٍ يَعكُفونَ عَلىٰ أَصنامٍ لَهُم قالوا يٰموسَى اجعَل لَنا إِلٰهًا كَما لَهُم ءالِهَةٌ قالَ إِنَّكُم قَومٌ تَجهَلونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mxciii{إِنَّ هٰؤُلاءِ مُتَبَّرٌ ما هُم فيهِ وَبٰطِلٌ ما كانوا يَعمَلونَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mxciv{قالَ أَغَيرَ اللَّهِ أَبغيكُم إِلٰهًا وَهُوَ فَضَّلَكُم عَلَى العٰلَمينَ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mxcv{وَإِذ أَنجَينٰكُم مِن ءالِ فِرعَونَ يَسومونَكُم سوءَ العَذابِ يُقَتِّلونَ أَبناءَكُم وَيَستَحيونَ نِساءَكُم وَفى ذٰلِكُم بَلاءٌ مِن رَبِّكُم عَظيمٌ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mxcvi{وَوٰعَدنا موسىٰ ثَلٰثينَ لَيلَةً وَأَتمَمنٰها بِعَشرٍ فَتَمَّ ميقٰتُ رَبِّهِ أَربَعينَ لَيلَةً وَقالَ موسىٰ لِأَخيهِ هٰرونَ اخلُفنى فى قَومى وَأَصلِح وَلا تَتَّبِع سَبيلَ المُفسِدينَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mxcvii{وَلَمّا جاءَ موسىٰ لِميقٰتِنا وَكَلَّمَهُ رَبُّهُ قالَ رَبِّ أَرِنى أَنظُر إِلَيكَ قالَ لَن تَرىٰنى وَلٰكِنِ انظُر إِلَى الجَبَلِ فَإِنِ استَقَرَّ مَكانَهُ فَسَوفَ تَرىٰنى فَلَمّا تَجَلّىٰ رَبُّهُ لِلجَبَلِ جَعَلَهُ دَكًّا وَخَرَّ موسىٰ صَعِقًا فَلَمّا أَفاقَ قالَ سُبحٰنَكَ تُبتُ إِلَيكَ وَأَنا۠ أَوَّلُ المُؤمِنينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mxcviii{قالَ يٰموسىٰ إِنِّى اصطَفَيتُكَ عَلَى النّاسِ بِرِسٰلٰتى وَبِكَلٰمى فَخُذ ما ءاتَيتُكَ وَكُن مِنَ الشّٰكِرينَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mxcix{وَكَتَبنا لَهُ فِى الأَلواحِ مِن كُلِّ شَيءٍ مَوعِظَةً وَتَفصيلًا لِكُلِّ شَيءٍ فَخُذها بِقُوَّةٍ وَأمُر قَومَكَ يَأخُذوا بِأَحسَنِها سَأُو۟ريكُم دارَ الفٰسِقينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mc{سَأَصرِفُ عَن ءايٰتِىَ الَّذينَ يَتَكَبَّرونَ فِى الأَرضِ بِغَيرِ الحَقِّ وَإِن يَرَوا كُلَّ ءايَةٍ لا يُؤمِنوا بِها وَإِن يَرَوا سَبيلَ الرُّشدِ لا يَتَّخِذوهُ سَبيلًا وَإِن يَرَوا سَبيلَ الغَىِّ يَتَّخِذوهُ سَبيلًا ذٰلِكَ بِأَنَّهُم كَذَّبوا بِـٔايٰتِنا وَكانوا عَنها غٰفِلينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mci{وَالَّذينَ كَذَّبوا بِـٔايٰتِنا وَلِقاءِ الءاخِرَةِ حَبِطَت أَعمٰلُهُم هَل يُجزَونَ إِلّا ما كانوا يَعمَلونَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mcii{وَاتَّخَذَ قَومُ موسىٰ مِن بَعدِهِ مِن حُلِيِّهِم عِجلًا جَسَدًا لَهُ خُوارٌ أَلَم يَرَوا أَنَّهُ لا يُكَلِّمُهُم وَلا يَهديهِم سَبيلًا اتَّخَذوهُ وَكانوا ظٰلِمينَ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mciii{وَلَمّا سُقِطَ فى أَيديهِم وَرَأَوا أَنَّهُم قَد ضَلّوا قالوا لَئِن لَم يَرحَمنا رَبُّنا وَيَغفِر لَنا لَنَكونَنَّ مِنَ الخٰسِرينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mciv{وَلَمّا رَجَعَ موسىٰ إِلىٰ قَومِهِ غَضبٰنَ أَسِفًا قالَ بِئسَما خَلَفتُمونى مِن بَعدى أَعَجِلتُم أَمرَ رَبِّكُم وَأَلقَى الأَلواحَ وَأَخَذَ بِرَأسِ أَخيهِ يَجُرُّهُ إِلَيهِ قالَ ابنَ أُمَّ إِنَّ القَومَ استَضعَفونى وَكادوا يَقتُلونَنى فَلا تُشمِت بِىَ الأَعداءَ وَلا تَجعَلنى مَعَ القَومِ الظّٰلِمينَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mcv{قالَ رَبِّ اغفِر لى وَلِأَخى وَأَدخِلنا فى رَحمَتِكَ وَأَنتَ أَرحَمُ الرّٰحِمينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mcvi{إِنَّ الَّذينَ اتَّخَذُوا العِجلَ سَيَنالُهُم غَضَبٌ مِن رَبِّهِم وَذِلَّةٌ فِى الحَيوٰةِ الدُّنيا وَكَذٰلِكَ نَجزِى المُفتَرينَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mcvii{وَالَّذينَ عَمِلُوا السَّيِّـٔاتِ ثُمَّ تابوا مِن بَعدِها وَءامَنوا إِنَّ رَبَّكَ مِن بَعدِها لَغَفورٌ رَحيمٌ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mcviii{وَلَمّا سَكَتَ عَن موسَى الغَضَبُ أَخَذَ الأَلواحَ وَفى نُسخَتِها هُدًى وَرَحمَةٌ لِلَّذينَ هُم لِرَبِّهِم يَرهَبونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mcix{وَاختارَ موسىٰ قَومَهُ سَبعينَ رَجُلًا لِميقٰتِنا فَلَمّا أَخَذَتهُمُ الرَّجفَةُ قالَ رَبِّ لَو شِئتَ أَهلَكتَهُم مِن قَبلُ وَإِيّٰىَ أَتُهلِكُنا بِما فَعَلَ السُّفَهاءُ مِنّا إِن هِىَ إِلّا فِتنَتُكَ تُضِلُّ بِها مَن تَشاءُ وَتَهدى مَن تَشاءُ أَنتَ وَلِيُّنا فَاغفِر لَنا وَارحَمنا وَأَنتَ خَيرُ الغٰفِرينَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mcx{وَاكتُب لَنا فى هٰذِهِ الدُّنيا حَسَنَةً وَفِى الءاخِرَةِ إِنّا هُدنا إِلَيكَ قالَ عَذابى أُصيبُ بِهِ مَن أَشاءُ وَرَحمَتى وَسِعَت كُلَّ شَيءٍ فَسَأَكتُبُها لِلَّذينَ يَتَّقونَ وَيُؤتونَ الزَّكوٰةَ وَالَّذينَ هُم بِـٔايٰتِنا يُؤمِنونَ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mcxi{الَّذينَ يَتَّبِعونَ الرَّسولَ النَّبِىَّ الأُمِّىَّ الَّذى يَجِدونَهُ مَكتوبًا عِندَهُم فِى التَّورىٰةِ وَالإِنجيلِ يَأمُرُهُم بِالمَعروفِ وَيَنهىٰهُم عَنِ المُنكَرِ وَيُحِلُّ لَهُمُ الطَّيِّبٰتِ وَيُحَرِّمُ عَلَيهِمُ الخَبٰئِثَ وَيَضَعُ عَنهُم إِصرَهُم وَالأَغلٰلَ الَّتى كانَت عَلَيهِم فَالَّذينَ ءامَنوا بِهِ وَعَزَّروهُ وَنَصَروهُ وَاتَّبَعُوا النّورَ الَّذى أُنزِلَ مَعَهُ أُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mcxii{قُل يٰأَيُّهَا النّاسُ إِنّى رَسولُ اللَّهِ إِلَيكُم جَميعًا الَّذى لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ لا إِلٰهَ إِلّا هُوَ يُحيۦ وَيُميتُ فَـٔامِنوا بِاللَّهِ وَرَسولِهِ النَّبِىِّ الأُمِّىِّ الَّذى يُؤمِنُ بِاللَّهِ وَكَلِمٰتِهِ وَاتَّبِعوهُ لَعَلَّكُم تَهتَدونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mcxiii{وَمِن قَومِ موسىٰ أُمَّةٌ يَهدونَ بِالحَقِّ وَبِهِ يَعدِلونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mcxiv{وَقَطَّعنٰهُمُ اثنَتَى عَشرَةَ أَسباطًا أُمَمًا وَأَوحَينا إِلىٰ موسىٰ إِذِ استَسقىٰهُ قَومُهُ أَنِ اضرِب بِعَصاكَ الحَجَرَ فَانبَجَسَت مِنهُ اثنَتا عَشرَةَ عَينًا قَد عَلِمَ كُلُّ أُناسٍ مَشرَبَهُم وَظَلَّلنا عَلَيهِمُ الغَمٰمَ وَأَنزَلنا عَلَيهِمُ المَنَّ وَالسَّلوىٰ كُلوا مِن طَيِّبٰتِ ما رَزَقنٰكُم وَما ظَلَمونا وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mcxv{وَإِذ قيلَ لَهُمُ اسكُنوا هٰذِهِ القَريَةَ وَكُلوا مِنها حَيثُ شِئتُم وَقولوا حِطَّةٌ وَادخُلُوا البابَ سُجَّدًا نَغفِر لَكُم خَطيـٰٔتِكُم سَنَزيدُ المُحسِنينَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mcxvi{فَبَدَّلَ الَّذينَ ظَلَموا مِنهُم قَولًا غَيرَ الَّذى قيلَ لَهُم فَأَرسَلنا عَلَيهِم رِجزًا مِنَ السَّماءِ بِما كانوا يَظلِمونَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mcxvii{وَسـَٔلهُم عَنِ القَريَةِ الَّتى كانَت حاضِرَةَ البَحرِ إِذ يَعدونَ فِى السَّبتِ إِذ تَأتيهِم حيتانُهُم يَومَ سَبتِهِم شُرَّعًا وَيَومَ لا يَسبِتونَ لا تَأتيهِم كَذٰلِكَ نَبلوهُم بِما كانوا يَفسُقونَ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mcxviii{وَإِذ قالَت أُمَّةٌ مِنهُم لِمَ تَعِظونَ قَومًا اللَّهُ مُهلِكُهُم أَو مُعَذِّبُهُم عَذابًا شَديدًا قالوا مَعذِرَةً إِلىٰ رَبِّكُم وَلَعَلَّهُم يَتَّقونَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mcxix{فَلَمّا نَسوا ما ذُكِّروا بِهِ أَنجَينَا الَّذينَ يَنهَونَ عَنِ السّوءِ وَأَخَذنَا الَّذينَ ظَلَموا بِعَذابٍ بَـٔيسٍ بِما كانوا يَفسُقونَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mcxx{فَلَمّا عَتَوا عَن ما نُهوا عَنهُ قُلنا لَهُم كونوا قِرَدَةً خٰسِـٔينَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mcxxi{وَإِذ تَأَذَّنَ رَبُّكَ لَيَبعَثَنَّ عَلَيهِم إِلىٰ يَومِ القِيٰمَةِ مَن يَسومُهُم سوءَ العَذابِ إِنَّ رَبَّكَ لَسَريعُ العِقابِ وَإِنَّهُ لَغَفورٌ رَحيمٌ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mcxxii{وَقَطَّعنٰهُم فِى الأَرضِ أُمَمًا مِنهُمُ الصّٰلِحونَ وَمِنهُم دونَ ذٰلِكَ وَبَلَونٰهُم بِالحَسَنٰتِ وَالسَّيِّـٔاتِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mcxxiii{فَخَلَفَ مِن بَعدِهِم خَلفٌ وَرِثُوا الكِتٰبَ يَأخُذونَ عَرَضَ هٰذَا الأَدنىٰ وَيَقولونَ سَيُغفَرُ لَنا وَإِن يَأتِهِم عَرَضٌ مِثلُهُ يَأخُذوهُ أَلَم يُؤخَذ عَلَيهِم ميثٰقُ الكِتٰبِ أَن لا يَقولوا عَلَى اللَّهِ إِلَّا الحَقَّ وَدَرَسوا ما فيهِ وَالدّارُ الءاخِرَةُ خَيرٌ لِلَّذينَ يَتَّقونَ أَفَلا تَعقِلونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mcxxiv{وَالَّذينَ يُمَسِّكونَ بِالكِتٰبِ وَأَقامُوا الصَّلوٰةَ إِنّا لا نُضيعُ أَجرَ المُصلِحينَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mcxxv{وَإِذ نَتَقنَا الجَبَلَ فَوقَهُم كَأَنَّهُ ظُلَّةٌ وَظَنّوا أَنَّهُ واقِعٌ بِهِم خُذوا ما ءاتَينٰكُم بِقُوَّةٍ وَاذكُروا ما فيهِ لَعَلَّكُم تَتَّقونَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mcxxvi{وَإِذ أَخَذَ رَبُّكَ مِن بَنى ءادَمَ مِن ظُهورِهِم ذُرِّيَّتَهُم وَأَشهَدَهُم عَلىٰ أَنفُسِهِم أَلَستُ بِرَبِّكُم قالوا بَلىٰ شَهِدنا أَن تَقولوا يَومَ القِيٰمَةِ إِنّا كُنّا عَن هٰذا غٰفِلينَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mcxxvii{أَو تَقولوا إِنَّما أَشرَكَ ءاباؤُنا مِن قَبلُ وَكُنّا ذُرِّيَّةً مِن بَعدِهِم أَفَتُهلِكُنا بِما فَعَلَ المُبطِلونَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mcxxviii{وَكَذٰلِكَ نُفَصِّلُ الءايٰتِ وَلَعَلَّهُم يَرجِعونَ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mcxxix{وَاتلُ عَلَيهِم نَبَأَ الَّذى ءاتَينٰهُ ءايٰتِنا فَانسَلَخَ مِنها فَأَتبَعَهُ الشَّيطٰنُ فَكانَ مِنَ الغاوينَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mcxxx{وَلَو شِئنا لَرَفَعنٰهُ بِها وَلٰكِنَّهُ أَخلَدَ إِلَى الأَرضِ وَاتَّبَعَ هَوىٰهُ فَمَثَلُهُ كَمَثَلِ الكَلبِ إِن تَحمِل عَلَيهِ يَلهَث أَو تَترُكهُ يَلهَث ذٰلِكَ مَثَلُ القَومِ الَّذينَ كَذَّبوا بِـٔايٰتِنا فَاقصُصِ القَصَصَ لَعَلَّهُم يَتَفَكَّرونَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mcxxxi{ساءَ مَثَلًا القَومُ الَّذينَ كَذَّبوا بِـٔايٰتِنا وَأَنفُسَهُم كانوا يَظلِمونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mcxxxii{مَن يَهدِ اللَّهُ فَهُوَ المُهتَدى وَمَن يُضلِل فَأُولٰئِكَ هُمُ الخٰسِرونَ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mcxxxiii{وَلَقَد ذَرَأنا لِجَهَنَّمَ كَثيرًا مِنَ الجِنِّ وَالإِنسِ لَهُم قُلوبٌ لا يَفقَهونَ بِها وَلَهُم أَعيُنٌ لا يُبصِرونَ بِها وَلَهُم ءاذانٌ لا يَسمَعونَ بِها أُولٰئِكَ كَالأَنعٰمِ بَل هُم أَضَلُّ أُولٰئِكَ هُمُ الغٰفِلونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mcxxxiv{وَلِلَّهِ الأَسماءُ الحُسنىٰ فَادعوهُ بِها وَذَرُوا الَّذينَ يُلحِدونَ فى أَسمٰئِهِ سَيُجزَونَ ما كانوا يَعمَلونَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mcxxxv{وَمِمَّن خَلَقنا أُمَّةٌ يَهدونَ بِالحَقِّ وَبِهِ يَعدِلونَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mcxxxvi{وَالَّذينَ كَذَّبوا بِـٔايٰتِنا سَنَستَدرِجُهُم مِن حَيثُ لا يَعلَمونَ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mcxxxvii{وَأُملى لَهُم إِنَّ كَيدى مَتينٌ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@mcxxxviii{أَوَلَم يَتَفَكَّروا ما بِصاحِبِهِم مِن جِنَّةٍ إِن هُوَ إِلّا نَذيرٌ مُبينٌ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@mcxxxix{أَوَلَم يَنظُروا فى مَلَكوتِ السَّمٰوٰتِ وَالأَرضِ وَما خَلَقَ اللَّهُ مِن شَيءٍ وَأَن عَسىٰ أَن يَكونَ قَدِ اقتَرَبَ أَجَلُهُم فَبِأَىِّ حَديثٍ بَعدَهُ يُؤمِنونَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@mcxl{مَن يُضلِلِ اللَّهُ فَلا هادِىَ لَهُ وَيَذَرُهُم فى طُغيٰنِهِم يَعمَهونَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@mcxli{يَسـَٔلونَكَ عَنِ السّاعَةِ أَيّانَ مُرسىٰها قُل إِنَّما عِلمُها عِندَ رَبّى لا يُجَلّيها لِوَقتِها إِلّا هُوَ ثَقُلَت فِى السَّمٰوٰتِ وَالأَرضِ لا تَأتيكُم إِلّا بَغتَةً يَسـَٔلونَكَ كَأَنَّكَ حَفِىٌّ عَنها قُل إِنَّما عِلمُها عِندَ اللَّهِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@mcxlii{قُل لا أَملِكُ لِنَفسى نَفعًا وَلا ضَرًّا إِلّا ما شاءَ اللَّهُ وَلَو كُنتُ أَعلَمُ الغَيبَ لَاستَكثَرتُ مِنَ الخَيرِ وَما مَسَّنِىَ السّوءُ إِن أَنا۠ إِلّا نَذيرٌ وَبَشيرٌ لِقَومٍ يُؤمِنونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@mcxliii{هُوَ الَّذى خَلَقَكُم مِن نَفسٍ وٰحِدَةٍ وَجَعَلَ مِنها زَوجَها لِيَسكُنَ إِلَيها فَلَمّا تَغَشّىٰها حَمَلَت حَملًا خَفيفًا فَمَرَّت بِهِ فَلَمّا أَثقَلَت دَعَوَا اللَّهَ رَبَّهُما لَئِن ءاتَيتَنا صٰلِحًا لَنَكونَنَّ مِنَ الشّٰكِرينَ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@mcxliv{فَلَمّا ءاتىٰهُما صٰلِحًا جَعَلا لَهُ شُرَكاءَ فيما ءاتىٰهُما فَتَعٰلَى اللَّهُ عَمّا يُشرِكونَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@mcxlv{أَيُشرِكونَ ما لا يَخلُقُ شَيـًٔا وَهُم يُخلَقونَ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@mcxlvi{وَلا يَستَطيعونَ لَهُم نَصرًا وَلا أَنفُسَهُم يَنصُرونَ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@mcxlvii{وَإِن تَدعوهُم إِلَى الهُدىٰ لا يَتَّبِعوكُم سَواءٌ عَلَيكُم أَدَعَوتُموهُم أَم أَنتُم صٰمِتونَ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@mcxlviii{إِنَّ الَّذينَ تَدعونَ مِن دونِ اللَّهِ عِبادٌ أَمثالُكُم فَادعوهُم فَليَستَجيبوا لَكُم إِن كُنتُم صٰدِقينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@mcxlix{أَلَهُم أَرجُلٌ يَمشونَ بِها أَم لَهُم أَيدٍ يَبطِشونَ بِها أَم لَهُم أَعيُنٌ يُبصِرونَ بِها أَم لَهُم ءاذانٌ يَسمَعونَ بِها قُلِ ادعوا شُرَكاءَكُم ثُمَّ كيدونِ فَلا تُنظِرونِ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@mcl{إِنَّ وَلِۦِّىَ اللَّهُ الَّذى نَزَّلَ الكِتٰبَ وَهُوَ يَتَوَلَّى الصّٰلِحينَ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@mcli{وَالَّذينَ تَدعونَ مِن دونِهِ لا يَستَطيعونَ نَصرَكُم وَلا أَنفُسَهُم يَنصُرونَ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@mclii{وَإِن تَدعوهُم إِلَى الهُدىٰ لا يَسمَعوا وَتَرىٰهُم يَنظُرونَ إِلَيكَ وَهُم لا يُبصِرونَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@mcliii{خُذِ العَفوَ وَأمُر بِالعُرفِ وَأَعرِض عَنِ الجٰهِلينَ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@mcliv{وَإِمّا يَنزَغَنَّكَ مِنَ الشَّيطٰنِ نَزغٌ فَاستَعِذ بِاللَّهِ إِنَّهُ سَميعٌ عَليمٌ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@mclv{إِنَّ الَّذينَ اتَّقَوا إِذا مَسَّهُم طٰئِفٌ مِنَ الشَّيطٰنِ تَذَكَّروا فَإِذا هُم مُبصِرونَ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@mclvi{وَإِخوٰنُهُم يَمُدّونَهُم فِى الغَىِّ ثُمَّ لا يُقصِرونَ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@mclvii{وَإِذا لَم تَأتِهِم بِـٔايَةٍ قالوا لَولَا اجتَبَيتَها قُل إِنَّما أَتَّبِعُ ما يوحىٰ إِلَىَّ مِن رَبّى هٰذا بَصائِرُ مِن رَبِّكُم وَهُدًى وَرَحمَةٌ لِقَومٍ يُؤمِنونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@mclviii{وَإِذا قُرِئَ القُرءانُ فَاستَمِعوا لَهُ وَأَنصِتوا لَعَلَّكُم تُرحَمونَ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@mclix{وَاذكُر رَبَّكَ فى نَفسِكَ تَضَرُّعًا وَخيفَةً وَدونَ الجَهرِ مِنَ القَولِ بِالغُدُوِّ وَالءاصالِ وَلا تَكُن مِنَ الغٰفِلينَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@mclx{إِنَّ الَّذينَ عِندَ رَبِّكَ لا يَستَكبِرونَ عَن عِبادَتِهِ وَيُسَبِّحونَهُ وَلَهُ يَسجُدونَ\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@mclxi{\basmalah  يَسـَٔلونَكَ عَنِ الأَنفالِ قُلِ الأَنفالُ لِلَّهِ وَالرَّسولِ فَاتَّقُوا اللَّهَ وَأَصلِحوا ذاتَ بَينِكُم وَأَطيعُوا اللَّهَ وَرَسولَهُ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mclxii{إِنَّمَا المُؤمِنونَ الَّذينَ إِذا ذُكِرَ اللَّهُ وَجِلَت قُلوبُهُم وَإِذا تُلِيَت عَلَيهِم ءايٰتُهُ زادَتهُم إيمٰنًا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mclxiii{الَّذينَ يُقيمونَ الصَّلوٰةَ وَمِمّا رَزَقنٰهُم يُنفِقونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mclxiv{أُولٰئِكَ هُمُ المُؤمِنونَ حَقًّا لَهُم دَرَجٰتٌ عِندَ رَبِّهِم وَمَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mclxv{كَما أَخرَجَكَ رَبُّكَ مِن بَيتِكَ بِالحَقِّ وَإِنَّ فَريقًا مِنَ المُؤمِنينَ لَكٰرِهونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mclxvi{يُجٰدِلونَكَ فِى الحَقِّ بَعدَما تَبَيَّنَ كَأَنَّما يُساقونَ إِلَى المَوتِ وَهُم يَنظُرونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mclxvii{وَإِذ يَعِدُكُمُ اللَّهُ إِحدَى الطّائِفَتَينِ أَنَّها لَكُم وَتَوَدّونَ أَنَّ غَيرَ ذاتِ الشَّوكَةِ تَكونُ لَكُم وَيُريدُ اللَّهُ أَن يُحِقَّ الحَقَّ بِكَلِمٰتِهِ وَيَقطَعَ دابِرَ الكٰفِرينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mclxviii{لِيُحِقَّ الحَقَّ وَيُبطِلَ البٰطِلَ وَلَو كَرِهَ المُجرِمونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mclxix{إِذ تَستَغيثونَ رَبَّكُم فَاستَجابَ لَكُم أَنّى مُمِدُّكُم بِأَلفٍ مِنَ المَلٰئِكَةِ مُردِفينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mclxx{وَما جَعَلَهُ اللَّهُ إِلّا بُشرىٰ وَلِتَطمَئِنَّ بِهِ قُلوبُكُم وَمَا النَّصرُ إِلّا مِن عِندِ اللَّهِ إِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mclxxi{إِذ يُغَشّيكُمُ النُّعاسَ أَمَنَةً مِنهُ وَيُنَزِّلُ عَلَيكُم مِنَ السَّماءِ ماءً لِيُطَهِّرَكُم بِهِ وَيُذهِبَ عَنكُم رِجزَ الشَّيطٰنِ وَلِيَربِطَ عَلىٰ قُلوبِكُم وَيُثَبِّتَ بِهِ الأَقدامَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mclxxii{إِذ يوحى رَبُّكَ إِلَى المَلٰئِكَةِ أَنّى مَعَكُم فَثَبِّتُوا الَّذينَ ءامَنوا سَأُلقى فى قُلوبِ الَّذينَ كَفَرُوا الرُّعبَ فَاضرِبوا فَوقَ الأَعناقِ وَاضرِبوا مِنهُم كُلَّ بَنانٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mclxxiii{ذٰلِكَ بِأَنَّهُم شاقُّوا اللَّهَ وَرَسولَهُ وَمَن يُشاقِقِ اللَّهَ وَرَسولَهُ فَإِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mclxxiv{ذٰلِكُم فَذوقوهُ وَأَنَّ لِلكٰفِرينَ عَذابَ النّارِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mclxxv{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا لَقيتُمُ الَّذينَ كَفَروا زَحفًا فَلا تُوَلّوهُمُ الأَدبارَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mclxxvi{وَمَن يُوَلِّهِم يَومَئِذٍ دُبُرَهُ إِلّا مُتَحَرِّفًا لِقِتالٍ أَو مُتَحَيِّزًا إِلىٰ فِئَةٍ فَقَد باءَ بِغَضَبٍ مِنَ اللَّهِ وَمَأوىٰهُ جَهَنَّمُ وَبِئسَ المَصيرُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mclxxvii{فَلَم تَقتُلوهُم وَلٰكِنَّ اللَّهَ قَتَلَهُم وَما رَمَيتَ إِذ رَمَيتَ وَلٰكِنَّ اللَّهَ رَمىٰ وَلِيُبلِىَ المُؤمِنينَ مِنهُ بَلاءً حَسَنًا إِنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mclxxviii{ذٰلِكُم وَأَنَّ اللَّهَ موهِنُ كَيدِ الكٰفِرينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mclxxix{إِن تَستَفتِحوا فَقَد جاءَكُمُ الفَتحُ وَإِن تَنتَهوا فَهُوَ خَيرٌ لَكُم وَإِن تَعودوا نَعُد وَلَن تُغنِىَ عَنكُم فِئَتُكُم شَيـًٔا وَلَو كَثُرَت وَأَنَّ اللَّهَ مَعَ المُؤمِنينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mclxxx{يٰأَيُّهَا الَّذينَ ءامَنوا أَطيعُوا اللَّهَ وَرَسولَهُ وَلا تَوَلَّوا عَنهُ وَأَنتُم تَسمَعونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mclxxxi{وَلا تَكونوا كَالَّذينَ قالوا سَمِعنا وَهُم لا يَسمَعونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mclxxxii{إِنَّ شَرَّ الدَّوابِّ عِندَ اللَّهِ الصُّمُّ البُكمُ الَّذينَ لا يَعقِلونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mclxxxiii{وَلَو عَلِمَ اللَّهُ فيهِم خَيرًا لَأَسمَعَهُم وَلَو أَسمَعَهُم لَتَوَلَّوا وَهُم مُعرِضونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mclxxxiv{يٰأَيُّهَا الَّذينَ ءامَنُوا استَجيبوا لِلَّهِ وَلِلرَّسولِ إِذا دَعاكُم لِما يُحييكُم وَاعلَموا أَنَّ اللَّهَ يَحولُ بَينَ المَرءِ وَقَلبِهِ وَأَنَّهُ إِلَيهِ تُحشَرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mclxxxv{وَاتَّقوا فِتنَةً لا تُصيبَنَّ الَّذينَ ظَلَموا مِنكُم خاصَّةً وَاعلَموا أَنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mclxxxvi{وَاذكُروا إِذ أَنتُم قَليلٌ مُستَضعَفونَ فِى الأَرضِ تَخافونَ أَن يَتَخَطَّفَكُمُ النّاسُ فَـٔاوىٰكُم وَأَيَّدَكُم بِنَصرِهِ وَرَزَقَكُم مِنَ الطَّيِّبٰتِ لَعَلَّكُم تَشكُرونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mclxxxvii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَخونُوا اللَّهَ وَالرَّسولَ وَتَخونوا أَمٰنٰتِكُم وَأَنتُم تَعلَمونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mclxxxviii{وَاعلَموا أَنَّما أَموٰلُكُم وَأَولٰدُكُم فِتنَةٌ وَأَنَّ اللَّهَ عِندَهُ أَجرٌ عَظيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mclxxxix{يٰأَيُّهَا الَّذينَ ءامَنوا إِن تَتَّقُوا اللَّهَ يَجعَل لَكُم فُرقانًا وَيُكَفِّر عَنكُم سَيِّـٔاتِكُم وَيَغفِر لَكُم وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcxc{وَإِذ يَمكُرُ بِكَ الَّذينَ كَفَروا لِيُثبِتوكَ أَو يَقتُلوكَ أَو يُخرِجوكَ وَيَمكُرونَ وَيَمكُرُ اللَّهُ وَاللَّهُ خَيرُ المٰكِرينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcxci{وَإِذا تُتلىٰ عَلَيهِم ءايٰتُنا قالوا قَد سَمِعنا لَو نَشاءُ لَقُلنا مِثلَ هٰذا إِن هٰذا إِلّا أَسٰطيرُ الأَوَّلينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcxcii{وَإِذ قالُوا اللَّهُمَّ إِن كانَ هٰذا هُوَ الحَقَّ مِن عِندِكَ فَأَمطِر عَلَينا حِجارَةً مِنَ السَّماءِ أَوِ ائتِنا بِعَذابٍ أَليمٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcxciii{وَما كانَ اللَّهُ لِيُعَذِّبَهُم وَأَنتَ فيهِم وَما كانَ اللَّهُ مُعَذِّبَهُم وَهُم يَستَغفِرونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcxciv{وَما لَهُم أَلّا يُعَذِّبَهُمُ اللَّهُ وَهُم يَصُدّونَ عَنِ المَسجِدِ الحَرامِ وَما كانوا أَولِياءَهُ إِن أَولِياؤُهُ إِلَّا المُتَّقونَ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcxcv{وَما كانَ صَلاتُهُم عِندَ البَيتِ إِلّا مُكاءً وَتَصدِيَةً فَذوقُوا العَذابَ بِما كُنتُم تَكفُرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcxcvi{إِنَّ الَّذينَ كَفَروا يُنفِقونَ أَموٰلَهُم لِيَصُدّوا عَن سَبيلِ اللَّهِ فَسَيُنفِقونَها ثُمَّ تَكونُ عَلَيهِم حَسرَةً ثُمَّ يُغلَبونَ وَالَّذينَ كَفَروا إِلىٰ جَهَنَّمَ يُحشَرونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcxcvii{لِيَميزَ اللَّهُ الخَبيثَ مِنَ الطَّيِّبِ وَيَجعَلَ الخَبيثَ بَعضَهُ عَلىٰ بَعضٍ فَيَركُمَهُ جَميعًا فَيَجعَلَهُ فى جَهَنَّمَ أُولٰئِكَ هُمُ الخٰسِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcxcviii{قُل لِلَّذينَ كَفَروا إِن يَنتَهوا يُغفَر لَهُم ما قَد سَلَفَ وَإِن يَعودوا فَقَد مَضَت سُنَّتُ الأَوَّلينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcxcix{وَقٰتِلوهُم حَتّىٰ لا تَكونَ فِتنَةٌ وَيَكونَ الدّينُ كُلُّهُ لِلَّهِ فَإِنِ انتَهَوا فَإِنَّ اللَّهَ بِما يَعمَلونَ بَصيرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcc{وَإِن تَوَلَّوا فَاعلَموا أَنَّ اللَّهَ مَولىٰكُم نِعمَ المَولىٰ وَنِعمَ النَّصيرُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcci{وَاعلَموا أَنَّما غَنِمتُم مِن شَيءٍ فَأَنَّ لِلَّهِ خُمُسَهُ وَلِلرَّسولِ وَلِذِى القُربىٰ وَاليَتٰمىٰ وَالمَسٰكينِ وَابنِ السَّبيلِ إِن كُنتُم ءامَنتُم بِاللَّهِ وَما أَنزَلنا عَلىٰ عَبدِنا يَومَ الفُرقانِ يَومَ التَقَى الجَمعانِ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mccii{إِذ أَنتُم بِالعُدوَةِ الدُّنيا وَهُم بِالعُدوَةِ القُصوىٰ وَالرَّكبُ أَسفَلَ مِنكُم وَلَو تَواعَدتُم لَاختَلَفتُم فِى الميعٰدِ وَلٰكِن لِيَقضِىَ اللَّهُ أَمرًا كانَ مَفعولًا لِيَهلِكَ مَن هَلَكَ عَن بَيِّنَةٍ وَيَحيىٰ مَن حَىَّ عَن بَيِّنَةٍ وَإِنَّ اللَّهَ لَسَميعٌ عَليمٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcciii{إِذ يُريكَهُمُ اللَّهُ فى مَنامِكَ قَليلًا وَلَو أَرىٰكَهُم كَثيرًا لَفَشِلتُم وَلَتَنٰزَعتُم فِى الأَمرِ وَلٰكِنَّ اللَّهَ سَلَّمَ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcciv{وَإِذ يُريكُموهُم إِذِ التَقَيتُم فى أَعيُنِكُم قَليلًا وَيُقَلِّلُكُم فى أَعيُنِهِم لِيَقضِىَ اللَّهُ أَمرًا كانَ مَفعولًا وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mccv{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا لَقيتُم فِئَةً فَاثبُتوا وَاذكُرُوا اللَّهَ كَثيرًا لَعَلَّكُم تُفلِحونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mccvi{وَأَطيعُوا اللَّهَ وَرَسولَهُ وَلا تَنٰزَعوا فَتَفشَلوا وَتَذهَبَ ريحُكُم وَاصبِروا إِنَّ اللَّهَ مَعَ الصّٰبِرينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mccvii{وَلا تَكونوا كَالَّذينَ خَرَجوا مِن دِيٰرِهِم بَطَرًا وَرِئاءَ النّاسِ وَيَصُدّونَ عَن سَبيلِ اللَّهِ وَاللَّهُ بِما يَعمَلونَ مُحيطٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mccviii{وَإِذ زَيَّنَ لَهُمُ الشَّيطٰنُ أَعمٰلَهُم وَقالَ لا غالِبَ لَكُمُ اليَومَ مِنَ النّاسِ وَإِنّى جارٌ لَكُم فَلَمّا تَراءَتِ الفِئَتانِ نَكَصَ عَلىٰ عَقِبَيهِ وَقالَ إِنّى بَريءٌ مِنكُم إِنّى أَرىٰ ما لا تَرَونَ إِنّى أَخافُ اللَّهَ وَاللَّهُ شَديدُ العِقابِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mccix{إِذ يَقولُ المُنٰفِقونَ وَالَّذينَ فى قُلوبِهِم مَرَضٌ غَرَّ هٰؤُلاءِ دينُهُم وَمَن يَتَوَكَّل عَلَى اللَّهِ فَإِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mccx{وَلَو تَرىٰ إِذ يَتَوَفَّى الَّذينَ كَفَرُوا المَلٰئِكَةُ يَضرِبونَ وُجوهَهُم وَأَدبٰرَهُم وَذوقوا عَذابَ الحَريقِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mccxi{ذٰلِكَ بِما قَدَّمَت أَيديكُم وَأَنَّ اللَّهَ لَيسَ بِظَلّٰمٍ لِلعَبيدِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mccxii{كَدَأبِ ءالِ فِرعَونَ وَالَّذينَ مِن قَبلِهِم كَفَروا بِـٔايٰتِ اللَّهِ فَأَخَذَهُمُ اللَّهُ بِذُنوبِهِم إِنَّ اللَّهَ قَوِىٌّ شَديدُ العِقابِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mccxiii{ذٰلِكَ بِأَنَّ اللَّهَ لَم يَكُ مُغَيِّرًا نِعمَةً أَنعَمَها عَلىٰ قَومٍ حَتّىٰ يُغَيِّروا ما بِأَنفُسِهِم وَأَنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mccxiv{كَدَأبِ ءالِ فِرعَونَ وَالَّذينَ مِن قَبلِهِم كَذَّبوا بِـٔايٰتِ رَبِّهِم فَأَهلَكنٰهُم بِذُنوبِهِم وَأَغرَقنا ءالَ فِرعَونَ وَكُلٌّ كانوا ظٰلِمينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mccxv{إِنَّ شَرَّ الدَّوابِّ عِندَ اللَّهِ الَّذينَ كَفَروا فَهُم لا يُؤمِنونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mccxvi{الَّذينَ عٰهَدتَ مِنهُم ثُمَّ يَنقُضونَ عَهدَهُم فى كُلِّ مَرَّةٍ وَهُم لا يَتَّقونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mccxvii{فَإِمّا تَثقَفَنَّهُم فِى الحَربِ فَشَرِّد بِهِم مَن خَلفَهُم لَعَلَّهُم يَذَّكَّرونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mccxviii{وَإِمّا تَخافَنَّ مِن قَومٍ خِيانَةً فَانبِذ إِلَيهِم عَلىٰ سَواءٍ إِنَّ اللَّهَ لا يُحِبُّ الخائِنينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mccxix{وَلا يَحسَبَنَّ الَّذينَ كَفَروا سَبَقوا إِنَّهُم لا يُعجِزونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mccxx{وَأَعِدّوا لَهُم مَا استَطَعتُم مِن قُوَّةٍ وَمِن رِباطِ الخَيلِ تُرهِبونَ بِهِ عَدُوَّ اللَّهِ وَعَدُوَّكُم وَءاخَرينَ مِن دونِهِم لا تَعلَمونَهُمُ اللَّهُ يَعلَمُهُم وَما تُنفِقوا مِن شَيءٍ فى سَبيلِ اللَّهِ يُوَفَّ إِلَيكُم وَأَنتُم لا تُظلَمونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mccxxi{وَإِن جَنَحوا لِلسَّلمِ فَاجنَح لَها وَتَوَكَّل عَلَى اللَّهِ إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mccxxii{وَإِن يُريدوا أَن يَخدَعوكَ فَإِنَّ حَسبَكَ اللَّهُ هُوَ الَّذى أَيَّدَكَ بِنَصرِهِ وَبِالمُؤمِنينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mccxxiii{وَأَلَّفَ بَينَ قُلوبِهِم لَو أَنفَقتَ ما فِى الأَرضِ جَميعًا ما أَلَّفتَ بَينَ قُلوبِهِم وَلٰكِنَّ اللَّهَ أَلَّفَ بَينَهُم إِنَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mccxxiv{يٰأَيُّهَا النَّبِىُّ حَسبُكَ اللَّهُ وَمَنِ اتَّبَعَكَ مِنَ المُؤمِنينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mccxxv{يٰأَيُّهَا النَّبِىُّ حَرِّضِ المُؤمِنينَ عَلَى القِتالِ إِن يَكُن مِنكُم عِشرونَ صٰبِرونَ يَغلِبوا مِا۟ئَتَينِ وَإِن يَكُن مِنكُم مِا۟ئَةٌ يَغلِبوا أَلفًا مِنَ الَّذينَ كَفَروا بِأَنَّهُم قَومٌ لا يَفقَهونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mccxxvi{الـٰٔنَ خَفَّفَ اللَّهُ عَنكُم وَعَلِمَ أَنَّ فيكُم ضَعفًا فَإِن يَكُن مِنكُم مِا۟ئَةٌ صابِرَةٌ يَغلِبوا مِا۟ئَتَينِ وَإِن يَكُن مِنكُم أَلفٌ يَغلِبوا أَلفَينِ بِإِذنِ اللَّهِ وَاللَّهُ مَعَ الصّٰبِرينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mccxxvii{ما كانَ لِنَبِىٍّ أَن يَكونَ لَهُ أَسرىٰ حَتّىٰ يُثخِنَ فِى الأَرضِ تُريدونَ عَرَضَ الدُّنيا وَاللَّهُ يُريدُ الءاخِرَةَ وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mccxxviii{لَولا كِتٰبٌ مِنَ اللَّهِ سَبَقَ لَمَسَّكُم فيما أَخَذتُم عَذابٌ عَظيمٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mccxxix{فَكُلوا مِمّا غَنِمتُم حَلٰلًا طَيِّبًا وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mccxxx{يٰأَيُّهَا النَّبِىُّ قُل لِمَن فى أَيديكُم مِنَ الأَسرىٰ إِن يَعلَمِ اللَّهُ فى قُلوبِكُم خَيرًا يُؤتِكُم خَيرًا مِمّا أُخِذَ مِنكُم وَيَغفِر لَكُم وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mccxxxi{وَإِن يُريدوا خِيانَتَكَ فَقَد خانُوا اللَّهَ مِن قَبلُ فَأَمكَنَ مِنهُم وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mccxxxii{إِنَّ الَّذينَ ءامَنوا وَهاجَروا وَجٰهَدوا بِأَموٰلِهِم وَأَنفُسِهِم فى سَبيلِ اللَّهِ وَالَّذينَ ءاوَوا وَنَصَروا أُولٰئِكَ بَعضُهُم أَولِياءُ بَعضٍ وَالَّذينَ ءامَنوا وَلَم يُهاجِروا ما لَكُم مِن وَلٰيَتِهِم مِن شَيءٍ حَتّىٰ يُهاجِروا وَإِنِ استَنصَروكُم فِى الدّينِ فَعَلَيكُمُ النَّصرُ إِلّا عَلىٰ قَومٍ بَينَكُم وَبَينَهُم ميثٰقٌ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mccxxxiii{وَالَّذينَ كَفَروا بَعضُهُم أَولِياءُ بَعضٍ إِلّا تَفعَلوهُ تَكُن فِتنَةٌ فِى الأَرضِ وَفَسادٌ كَبيرٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mccxxxiv{وَالَّذينَ ءامَنوا وَهاجَروا وَجٰهَدوا فى سَبيلِ اللَّهِ وَالَّذينَ ءاوَوا وَنَصَروا أُولٰئِكَ هُمُ المُؤمِنونَ حَقًّا لَهُم مَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mccxxxv{وَالَّذينَ ءامَنوا مِن بَعدُ وَهاجَروا وَجٰهَدوا مَعَكُم فَأُولٰئِكَ مِنكُم وَأُولُوا الأَرحامِ بَعضُهُم أَولىٰ بِبَعضٍ فى كِتٰبِ اللَّهِ إِنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mccxxxvi{بَراءَةٌ مِنَ اللَّهِ وَرَسولِهِ إِلَى الَّذينَ عٰهَدتُم مِنَ المُشرِكينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mccxxxvii{فَسيحوا فِى الأَرضِ أَربَعَةَ أَشهُرٍ وَاعلَموا أَنَّكُم غَيرُ مُعجِزِى اللَّهِ وَأَنَّ اللَّهَ مُخزِى الكٰفِرينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mccxxxviii{وَأَذٰنٌ مِنَ اللَّهِ وَرَسولِهِ إِلَى النّاسِ يَومَ الحَجِّ الأَكبَرِ أَنَّ اللَّهَ بَريءٌ مِنَ المُشرِكينَ وَرَسولُهُ فَإِن تُبتُم فَهُوَ خَيرٌ لَكُم وَإِن تَوَلَّيتُم فَاعلَموا أَنَّكُم غَيرُ مُعجِزِى اللَّهِ وَبَشِّرِ الَّذينَ كَفَروا بِعَذابٍ أَليمٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mccxxxix{إِلَّا الَّذينَ عٰهَدتُم مِنَ المُشرِكينَ ثُمَّ لَم يَنقُصوكُم شَيـًٔا وَلَم يُظٰهِروا عَلَيكُم أَحَدًا فَأَتِمّوا إِلَيهِم عَهدَهُم إِلىٰ مُدَّتِهِم إِنَّ اللَّهَ يُحِبُّ المُتَّقينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mccxl{فَإِذَا انسَلَخَ الأَشهُرُ الحُرُمُ فَاقتُلُوا المُشرِكينَ حَيثُ وَجَدتُموهُم وَخُذوهُم وَاحصُروهُم وَاقعُدوا لَهُم كُلَّ مَرصَدٍ فَإِن تابوا وَأَقامُوا الصَّلوٰةَ وَءاتَوُا الزَّكوٰةَ فَخَلّوا سَبيلَهُم إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mccxli{وَإِن أَحَدٌ مِنَ المُشرِكينَ استَجارَكَ فَأَجِرهُ حَتّىٰ يَسمَعَ كَلٰمَ اللَّهِ ثُمَّ أَبلِغهُ مَأمَنَهُ ذٰلِكَ بِأَنَّهُم قَومٌ لا يَعلَمونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mccxlii{كَيفَ يَكونُ لِلمُشرِكينَ عَهدٌ عِندَ اللَّهِ وَعِندَ رَسولِهِ إِلَّا الَّذينَ عٰهَدتُم عِندَ المَسجِدِ الحَرامِ فَمَا استَقٰموا لَكُم فَاستَقيموا لَهُم إِنَّ اللَّهَ يُحِبُّ المُتَّقينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mccxliii{كَيفَ وَإِن يَظهَروا عَلَيكُم لا يَرقُبوا فيكُم إِلًّا وَلا ذِمَّةً يُرضونَكُم بِأَفوٰهِهِم وَتَأبىٰ قُلوبُهُم وَأَكثَرُهُم فٰسِقونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mccxliv{اشتَرَوا بِـٔايٰتِ اللَّهِ ثَمَنًا قَليلًا فَصَدّوا عَن سَبيلِهِ إِنَّهُم ساءَ ما كانوا يَعمَلونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mccxlv{لا يَرقُبونَ فى مُؤمِنٍ إِلًّا وَلا ذِمَّةً وَأُولٰئِكَ هُمُ المُعتَدونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mccxlvi{فَإِن تابوا وَأَقامُوا الصَّلوٰةَ وَءاتَوُا الزَّكوٰةَ فَإِخوٰنُكُم فِى الدّينِ وَنُفَصِّلُ الءايٰتِ لِقَومٍ يَعلَمونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mccxlvii{وَإِن نَكَثوا أَيمٰنَهُم مِن بَعدِ عَهدِهِم وَطَعَنوا فى دينِكُم فَقٰتِلوا أَئِمَّةَ الكُفرِ إِنَّهُم لا أَيمٰنَ لَهُم لَعَلَّهُم يَنتَهونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mccxlviii{أَلا تُقٰتِلونَ قَومًا نَكَثوا أَيمٰنَهُم وَهَمّوا بِإِخراجِ الرَّسولِ وَهُم بَدَءوكُم أَوَّلَ مَرَّةٍ أَتَخشَونَهُم فَاللَّهُ أَحَقُّ أَن تَخشَوهُ إِن كُنتُم مُؤمِنينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mccxlix{قٰتِلوهُم يُعَذِّبهُمُ اللَّهُ بِأَيديكُم وَيُخزِهِم وَيَنصُركُم عَلَيهِم وَيَشفِ صُدورَ قَومٍ مُؤمِنينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mccl{وَيُذهِب غَيظَ قُلوبِهِم وَيَتوبُ اللَّهُ عَلىٰ مَن يَشاءُ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mccli{أَم حَسِبتُم أَن تُترَكوا وَلَمّا يَعلَمِ اللَّهُ الَّذينَ جٰهَدوا مِنكُم وَلَم يَتَّخِذوا مِن دونِ اللَّهِ وَلا رَسولِهِ وَلَا المُؤمِنينَ وَليجَةً وَاللَّهُ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcclii{ما كانَ لِلمُشرِكينَ أَن يَعمُروا مَسٰجِدَ اللَّهِ شٰهِدينَ عَلىٰ أَنفُسِهِم بِالكُفرِ أُولٰئِكَ حَبِطَت أَعمٰلُهُم وَفِى النّارِ هُم خٰلِدونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mccliii{إِنَّما يَعمُرُ مَسٰجِدَ اللَّهِ مَن ءامَنَ بِاللَّهِ وَاليَومِ الءاخِرِ وَأَقامَ الصَّلوٰةَ وَءاتَى الزَّكوٰةَ وَلَم يَخشَ إِلَّا اللَّهَ فَعَسىٰ أُولٰئِكَ أَن يَكونوا مِنَ المُهتَدينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mccliv{أَجَعَلتُم سِقايَةَ الحاجِّ وَعِمارَةَ المَسجِدِ الحَرامِ كَمَن ءامَنَ بِاللَّهِ وَاليَومِ الءاخِرِ وَجٰهَدَ فى سَبيلِ اللَّهِ لا يَستَوۥنَ عِندَ اللَّهِ وَاللَّهُ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcclv{الَّذينَ ءامَنوا وَهاجَروا وَجٰهَدوا فى سَبيلِ اللَّهِ بِأَموٰلِهِم وَأَنفُسِهِم أَعظَمُ دَرَجَةً عِندَ اللَّهِ وَأُولٰئِكَ هُمُ الفائِزونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcclvi{يُبَشِّرُهُم رَبُّهُم بِرَحمَةٍ مِنهُ وَرِضوٰنٍ وَجَنّٰتٍ لَهُم فيها نَعيمٌ مُقيمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcclvii{خٰلِدينَ فيها أَبَدًا إِنَّ اللَّهَ عِندَهُ أَجرٌ عَظيمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcclviii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَتَّخِذوا ءاباءَكُم وَإِخوٰنَكُم أَولِياءَ إِنِ استَحَبُّوا الكُفرَ عَلَى الإيمٰنِ وَمَن يَتَوَلَّهُم مِنكُم فَأُولٰئِكَ هُمُ الظّٰلِمونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcclix{قُل إِن كانَ ءاباؤُكُم وَأَبناؤُكُم وَإِخوٰنُكُم وَأَزوٰجُكُم وَعَشيرَتُكُم وَأَموٰلٌ اقتَرَفتُموها وَتِجٰرَةٌ تَخشَونَ كَسادَها وَمَسٰكِنُ تَرضَونَها أَحَبَّ إِلَيكُم مِنَ اللَّهِ وَرَسولِهِ وَجِهادٍ فى سَبيلِهِ فَتَرَبَّصوا حَتّىٰ يَأتِىَ اللَّهُ بِأَمرِهِ وَاللَّهُ لا يَهدِى القَومَ الفٰسِقينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcclx{لَقَد نَصَرَكُمُ اللَّهُ فى مَواطِنَ كَثيرَةٍ وَيَومَ حُنَينٍ إِذ أَعجَبَتكُم كَثرَتُكُم فَلَم تُغنِ عَنكُم شَيـًٔا وَضاقَت عَلَيكُمُ الأَرضُ بِما رَحُبَت ثُمَّ وَلَّيتُم مُدبِرينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcclxi{ثُمَّ أَنزَلَ اللَّهُ سَكينَتَهُ عَلىٰ رَسولِهِ وَعَلَى المُؤمِنينَ وَأَنزَلَ جُنودًا لَم تَرَوها وَعَذَّبَ الَّذينَ كَفَروا وَذٰلِكَ جَزاءُ الكٰفِرينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcclxii{ثُمَّ يَتوبُ اللَّهُ مِن بَعدِ ذٰلِكَ عَلىٰ مَن يَشاءُ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcclxiii{يٰأَيُّهَا الَّذينَ ءامَنوا إِنَّمَا المُشرِكونَ نَجَسٌ فَلا يَقرَبُوا المَسجِدَ الحَرامَ بَعدَ عامِهِم هٰذا وَإِن خِفتُم عَيلَةً فَسَوفَ يُغنيكُمُ اللَّهُ مِن فَضلِهِ إِن شاءَ إِنَّ اللَّهَ عَليمٌ حَكيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcclxiv{قٰتِلُوا الَّذينَ لا يُؤمِنونَ بِاللَّهِ وَلا بِاليَومِ الءاخِرِ وَلا يُحَرِّمونَ ما حَرَّمَ اللَّهُ وَرَسولُهُ وَلا يَدينونَ دينَ الحَقِّ مِنَ الَّذينَ أوتُوا الكِتٰبَ حَتّىٰ يُعطُوا الجِزيَةَ عَن يَدٍ وَهُم صٰغِرونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcclxv{وَقالَتِ اليَهودُ عُزَيرٌ ابنُ اللَّهِ وَقالَتِ النَّصٰرَى المَسيحُ ابنُ اللَّهِ ذٰلِكَ قَولُهُم بِأَفوٰهِهِم يُضٰهِـٔونَ قَولَ الَّذينَ كَفَروا مِن قَبلُ قٰتَلَهُمُ اللَّهُ أَنّىٰ يُؤفَكونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcclxvi{اتَّخَذوا أَحبارَهُم وَرُهبٰنَهُم أَربابًا مِن دونِ اللَّهِ وَالمَسيحَ ابنَ مَريَمَ وَما أُمِروا إِلّا لِيَعبُدوا إِلٰهًا وٰحِدًا لا إِلٰهَ إِلّا هُوَ سُبحٰنَهُ عَمّا يُشرِكونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcclxvii{يُريدونَ أَن يُطفِـٔوا نورَ اللَّهِ بِأَفوٰهِهِم وَيَأبَى اللَّهُ إِلّا أَن يُتِمَّ نورَهُ وَلَو كَرِهَ الكٰفِرونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcclxviii{هُوَ الَّذى أَرسَلَ رَسولَهُ بِالهُدىٰ وَدينِ الحَقِّ لِيُظهِرَهُ عَلَى الدّينِ كُلِّهِ وَلَو كَرِهَ المُشرِكونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcclxix{يٰأَيُّهَا الَّذينَ ءامَنوا إِنَّ كَثيرًا مِنَ الأَحبارِ وَالرُّهبانِ لَيَأكُلونَ أَموٰلَ النّاسِ بِالبٰطِلِ وَيَصُدّونَ عَن سَبيلِ اللَّهِ وَالَّذينَ يَكنِزونَ الذَّهَبَ وَالفِضَّةَ وَلا يُنفِقونَها فى سَبيلِ اللَّهِ فَبَشِّرهُم بِعَذابٍ أَليمٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcclxx{يَومَ يُحمىٰ عَلَيها فى نارِ جَهَنَّمَ فَتُكوىٰ بِها جِباهُهُم وَجُنوبُهُم وَظُهورُهُم هٰذا ما كَنَزتُم لِأَنفُسِكُم فَذوقوا ما كُنتُم تَكنِزونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcclxxi{إِنَّ عِدَّةَ الشُّهورِ عِندَ اللَّهِ اثنا عَشَرَ شَهرًا فى كِتٰبِ اللَّهِ يَومَ خَلَقَ السَّمٰوٰتِ وَالأَرضَ مِنها أَربَعَةٌ حُرُمٌ ذٰلِكَ الدّينُ القَيِّمُ فَلا تَظلِموا فيهِنَّ أَنفُسَكُم وَقٰتِلُوا المُشرِكينَ كافَّةً كَما يُقٰتِلونَكُم كافَّةً وَاعلَموا أَنَّ اللَّهَ مَعَ المُتَّقينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcclxxii{إِنَّمَا النَّسيءُ زِيادَةٌ فِى الكُفرِ يُضَلُّ بِهِ الَّذينَ كَفَروا يُحِلّونَهُ عامًا وَيُحَرِّمونَهُ عامًا لِيُواطِـٔوا عِدَّةَ ما حَرَّمَ اللَّهُ فَيُحِلّوا ما حَرَّمَ اللَّهُ زُيِّنَ لَهُم سوءُ أَعمٰلِهِم وَاللَّهُ لا يَهدِى القَومَ الكٰفِرينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcclxxiii{يٰأَيُّهَا الَّذينَ ءامَنوا ما لَكُم إِذا قيلَ لَكُمُ انفِروا فى سَبيلِ اللَّهِ اثّاقَلتُم إِلَى الأَرضِ أَرَضيتُم بِالحَيوٰةِ الدُّنيا مِنَ الءاخِرَةِ فَما مَتٰعُ الحَيوٰةِ الدُّنيا فِى الءاخِرَةِ إِلّا قَليلٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcclxxiv{إِلّا تَنفِروا يُعَذِّبكُم عَذابًا أَليمًا وَيَستَبدِل قَومًا غَيرَكُم وَلا تَضُرّوهُ شَيـًٔا وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcclxxv{إِلّا تَنصُروهُ فَقَد نَصَرَهُ اللَّهُ إِذ أَخرَجَهُ الَّذينَ كَفَروا ثانِىَ اثنَينِ إِذ هُما فِى الغارِ إِذ يَقولُ لِصٰحِبِهِ لا تَحزَن إِنَّ اللَّهَ مَعَنا فَأَنزَلَ اللَّهُ سَكينَتَهُ عَلَيهِ وَأَيَّدَهُ بِجُنودٍ لَم تَرَوها وَجَعَلَ كَلِمَةَ الَّذينَ كَفَرُوا السُّفلىٰ وَكَلِمَةُ اللَّهِ هِىَ العُليا وَاللَّهُ عَزيزٌ حَكيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcclxxvi{انفِروا خِفافًا وَثِقالًا وَجٰهِدوا بِأَموٰلِكُم وَأَنفُسِكُم فى سَبيلِ اللَّهِ ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcclxxvii{لَو كانَ عَرَضًا قَريبًا وَسَفَرًا قاصِدًا لَاتَّبَعوكَ وَلٰكِن بَعُدَت عَلَيهِمُ الشُّقَّةُ وَسَيَحلِفونَ بِاللَّهِ لَوِ استَطَعنا لَخَرَجنا مَعَكُم يُهلِكونَ أَنفُسَهُم وَاللَّهُ يَعلَمُ إِنَّهُم لَكٰذِبونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcclxxviii{عَفَا اللَّهُ عَنكَ لِمَ أَذِنتَ لَهُم حَتّىٰ يَتَبَيَّنَ لَكَ الَّذينَ صَدَقوا وَتَعلَمَ الكٰذِبينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcclxxix{لا يَستَـٔذِنُكَ الَّذينَ يُؤمِنونَ بِاللَّهِ وَاليَومِ الءاخِرِ أَن يُجٰهِدوا بِأَموٰلِهِم وَأَنفُسِهِم وَاللَّهُ عَليمٌ بِالمُتَّقينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcclxxx{إِنَّما يَستَـٔذِنُكَ الَّذينَ لا يُؤمِنونَ بِاللَّهِ وَاليَومِ الءاخِرِ وَارتابَت قُلوبُهُم فَهُم فى رَيبِهِم يَتَرَدَّدونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcclxxxi{وَلَو أَرادُوا الخُروجَ لَأَعَدّوا لَهُ عُدَّةً وَلٰكِن كَرِهَ اللَّهُ انبِعاثَهُم فَثَبَّطَهُم وَقيلَ اقعُدوا مَعَ القٰعِدينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcclxxxii{لَو خَرَجوا فيكُم ما زادوكُم إِلّا خَبالًا وَلَأَوضَعوا خِلٰلَكُم يَبغونَكُمُ الفِتنَةَ وَفيكُم سَمّٰعونَ لَهُم وَاللَّهُ عَليمٌ بِالظّٰلِمينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcclxxxiii{لَقَدِ ابتَغَوُا الفِتنَةَ مِن قَبلُ وَقَلَّبوا لَكَ الأُمورَ حَتّىٰ جاءَ الحَقُّ وَظَهَرَ أَمرُ اللَّهِ وَهُم كٰرِهونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcclxxxiv{وَمِنهُم مَن يَقولُ ائذَن لى وَلا تَفتِنّى أَلا فِى الفِتنَةِ سَقَطوا وَإِنَّ جَهَنَّمَ لَمُحيطَةٌ بِالكٰفِرينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcclxxxv{إِن تُصِبكَ حَسَنَةٌ تَسُؤهُم وَإِن تُصِبكَ مُصيبَةٌ يَقولوا قَد أَخَذنا أَمرَنا مِن قَبلُ وَيَتَوَلَّوا وَهُم فَرِحونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcclxxxvi{قُل لَن يُصيبَنا إِلّا ما كَتَبَ اللَّهُ لَنا هُوَ مَولىٰنا وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcclxxxvii{قُل هَل تَرَبَّصونَ بِنا إِلّا إِحدَى الحُسنَيَينِ وَنَحنُ نَتَرَبَّصُ بِكُم أَن يُصيبَكُمُ اللَّهُ بِعَذابٍ مِن عِندِهِ أَو بِأَيدينا فَتَرَبَّصوا إِنّا مَعَكُم مُتَرَبِّصونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcclxxxviii{قُل أَنفِقوا طَوعًا أَو كَرهًا لَن يُتَقَبَّلَ مِنكُم إِنَّكُم كُنتُم قَومًا فٰسِقينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcclxxxix{وَما مَنَعَهُم أَن تُقبَلَ مِنهُم نَفَقٰتُهُم إِلّا أَنَّهُم كَفَروا بِاللَّهِ وَبِرَسولِهِ وَلا يَأتونَ الصَّلوٰةَ إِلّا وَهُم كُسالىٰ وَلا يُنفِقونَ إِلّا وَهُم كٰرِهونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mccxc{فَلا تُعجِبكَ أَموٰلُهُم وَلا أَولٰدُهُم إِنَّما يُريدُ اللَّهُ لِيُعَذِّبَهُم بِها فِى الحَيوٰةِ الدُّنيا وَتَزهَقَ أَنفُسُهُم وَهُم كٰفِرونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mccxci{وَيَحلِفونَ بِاللَّهِ إِنَّهُم لَمِنكُم وَما هُم مِنكُم وَلٰكِنَّهُم قَومٌ يَفرَقونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mccxcii{لَو يَجِدونَ مَلجَـًٔا أَو مَغٰرٰتٍ أَو مُدَّخَلًا لَوَلَّوا إِلَيهِ وَهُم يَجمَحونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mccxciii{وَمِنهُم مَن يَلمِزُكَ فِى الصَّدَقٰتِ فَإِن أُعطوا مِنها رَضوا وَإِن لَم يُعطَوا مِنها إِذا هُم يَسخَطونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mccxciv{وَلَو أَنَّهُم رَضوا ما ءاتىٰهُمُ اللَّهُ وَرَسولُهُ وَقالوا حَسبُنَا اللَّهُ سَيُؤتينَا اللَّهُ مِن فَضلِهِ وَرَسولُهُ إِنّا إِلَى اللَّهِ رٰغِبونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mccxcv{إِنَّمَا الصَّدَقٰتُ لِلفُقَراءِ وَالمَسٰكينِ وَالعٰمِلينَ عَلَيها وَالمُؤَلَّفَةِ قُلوبُهُم وَفِى الرِّقابِ وَالغٰرِمينَ وَفى سَبيلِ اللَّهِ وَابنِ السَّبيلِ فَريضَةً مِنَ اللَّهِ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mccxcvi{وَمِنهُمُ الَّذينَ يُؤذونَ النَّبِىَّ وَيَقولونَ هُوَ أُذُنٌ قُل أُذُنُ خَيرٍ لَكُم يُؤمِنُ بِاللَّهِ وَيُؤمِنُ لِلمُؤمِنينَ وَرَحمَةٌ لِلَّذينَ ءامَنوا مِنكُم وَالَّذينَ يُؤذونَ رَسولَ اللَّهِ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mccxcvii{يَحلِفونَ بِاللَّهِ لَكُم لِيُرضوكُم وَاللَّهُ وَرَسولُهُ أَحَقُّ أَن يُرضوهُ إِن كانوا مُؤمِنينَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mccxcviii{أَلَم يَعلَموا أَنَّهُ مَن يُحادِدِ اللَّهَ وَرَسولَهُ فَأَنَّ لَهُ نارَ جَهَنَّمَ خٰلِدًا فيها ذٰلِكَ الخِزىُ العَظيمُ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mccxcix{يَحذَرُ المُنٰفِقونَ أَن تُنَزَّلَ عَلَيهِم سورَةٌ تُنَبِّئُهُم بِما فى قُلوبِهِم قُلِ استَهزِءوا إِنَّ اللَّهَ مُخرِجٌ ما تَحذَرونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mccc{وَلَئِن سَأَلتَهُم لَيَقولُنَّ إِنَّما كُنّا نَخوضُ وَنَلعَبُ قُل أَبِاللَّهِ وَءايٰتِهِ وَرَسولِهِ كُنتُم تَستَهزِءونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mccci{لا تَعتَذِروا قَد كَفَرتُم بَعدَ إيمٰنِكُم إِن نَعفُ عَن طائِفَةٍ مِنكُم نُعَذِّب طائِفَةً بِأَنَّهُم كانوا مُجرِمينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcccii{المُنٰفِقونَ وَالمُنٰفِقٰتُ بَعضُهُم مِن بَعضٍ يَأمُرونَ بِالمُنكَرِ وَيَنهَونَ عَنِ المَعروفِ وَيَقبِضونَ أَيدِيَهُم نَسُوا اللَّهَ فَنَسِيَهُم إِنَّ المُنٰفِقينَ هُمُ الفٰسِقونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mccciii{وَعَدَ اللَّهُ المُنٰفِقينَ وَالمُنٰفِقٰتِ وَالكُفّارَ نارَ جَهَنَّمَ خٰلِدينَ فيها هِىَ حَسبُهُم وَلَعَنَهُمُ اللَّهُ وَلَهُم عَذابٌ مُقيمٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mccciv{كَالَّذينَ مِن قَبلِكُم كانوا أَشَدَّ مِنكُم قُوَّةً وَأَكثَرَ أَموٰلًا وَأَولٰدًا فَاستَمتَعوا بِخَلٰقِهِم فَاستَمتَعتُم بِخَلٰقِكُم كَمَا استَمتَعَ الَّذينَ مِن قَبلِكُم بِخَلٰقِهِم وَخُضتُم كَالَّذى خاضوا أُولٰئِكَ حَبِطَت أَعمٰلُهُم فِى الدُّنيا وَالءاخِرَةِ وَأُولٰئِكَ هُمُ الخٰسِرونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcccv{أَلَم يَأتِهِم نَبَأُ الَّذينَ مِن قَبلِهِم قَومِ نوحٍ وَعادٍ وَثَمودَ وَقَومِ إِبرٰهيمَ وَأَصحٰبِ مَديَنَ وَالمُؤتَفِكٰتِ أَتَتهُم رُسُلُهُم بِالبَيِّنٰتِ فَما كانَ اللَّهُ لِيَظلِمَهُم وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcccvi{وَالمُؤمِنونَ وَالمُؤمِنٰتُ بَعضُهُم أَولِياءُ بَعضٍ يَأمُرونَ بِالمَعروفِ وَيَنهَونَ عَنِ المُنكَرِ وَيُقيمونَ الصَّلوٰةَ وَيُؤتونَ الزَّكوٰةَ وَيُطيعونَ اللَّهَ وَرَسولَهُ أُولٰئِكَ سَيَرحَمُهُمُ اللَّهُ إِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcccvii{وَعَدَ اللَّهُ المُؤمِنينَ وَالمُؤمِنٰتِ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها وَمَسٰكِنَ طَيِّبَةً فى جَنّٰتِ عَدنٍ وَرِضوٰنٌ مِنَ اللَّهِ أَكبَرُ ذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcccviii{يٰأَيُّهَا النَّبِىُّ جٰهِدِ الكُفّارَ وَالمُنٰفِقينَ وَاغلُظ عَلَيهِم وَمَأوىٰهُم جَهَنَّمُ وَبِئسَ المَصيرُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcccix{يَحلِفونَ بِاللَّهِ ما قالوا وَلَقَد قالوا كَلِمَةَ الكُفرِ وَكَفَروا بَعدَ إِسلٰمِهِم وَهَمّوا بِما لَم يَنالوا وَما نَقَموا إِلّا أَن أَغنىٰهُمُ اللَّهُ وَرَسولُهُ مِن فَضلِهِ فَإِن يَتوبوا يَكُ خَيرًا لَهُم وَإِن يَتَوَلَّوا يُعَذِّبهُمُ اللَّهُ عَذابًا أَليمًا فِى الدُّنيا وَالءاخِرَةِ وَما لَهُم فِى الأَرضِ مِن وَلِىٍّ وَلا نَصيرٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcccx{وَمِنهُم مَن عٰهَدَ اللَّهَ لَئِن ءاتىٰنا مِن فَضلِهِ لَنَصَّدَّقَنَّ وَلَنَكونَنَّ مِنَ الصّٰلِحينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcccxi{فَلَمّا ءاتىٰهُم مِن فَضلِهِ بَخِلوا بِهِ وَتَوَلَّوا وَهُم مُعرِضونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcccxii{فَأَعقَبَهُم نِفاقًا فى قُلوبِهِم إِلىٰ يَومِ يَلقَونَهُ بِما أَخلَفُوا اللَّهَ ما وَعَدوهُ وَبِما كانوا يَكذِبونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcccxiii{أَلَم يَعلَموا أَنَّ اللَّهَ يَعلَمُ سِرَّهُم وَنَجوىٰهُم وَأَنَّ اللَّهَ عَلّٰمُ الغُيوبِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcccxiv{الَّذينَ يَلمِزونَ المُطَّوِّعينَ مِنَ المُؤمِنينَ فِى الصَّدَقٰتِ وَالَّذينَ لا يَجِدونَ إِلّا جُهدَهُم فَيَسخَرونَ مِنهُم سَخِرَ اللَّهُ مِنهُم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcccxv{استَغفِر لَهُم أَو لا تَستَغفِر لَهُم إِن تَستَغفِر لَهُم سَبعينَ مَرَّةً فَلَن يَغفِرَ اللَّهُ لَهُم ذٰلِكَ بِأَنَّهُم كَفَروا بِاللَّهِ وَرَسولِهِ وَاللَّهُ لا يَهدِى القَومَ الفٰسِقينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcccxvi{فَرِحَ المُخَلَّفونَ بِمَقعَدِهِم خِلٰفَ رَسولِ اللَّهِ وَكَرِهوا أَن يُجٰهِدوا بِأَموٰلِهِم وَأَنفُسِهِم فى سَبيلِ اللَّهِ وَقالوا لا تَنفِروا فِى الحَرِّ قُل نارُ جَهَنَّمَ أَشَدُّ حَرًّا لَو كانوا يَفقَهونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcccxvii{فَليَضحَكوا قَليلًا وَليَبكوا كَثيرًا جَزاءً بِما كانوا يَكسِبونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcccxviii{فَإِن رَجَعَكَ اللَّهُ إِلىٰ طائِفَةٍ مِنهُم فَاستَـٔذَنوكَ لِلخُروجِ فَقُل لَن تَخرُجوا مَعِىَ أَبَدًا وَلَن تُقٰتِلوا مَعِىَ عَدُوًّا إِنَّكُم رَضيتُم بِالقُعودِ أَوَّلَ مَرَّةٍ فَاقعُدوا مَعَ الخٰلِفينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcccxix{وَلا تُصَلِّ عَلىٰ أَحَدٍ مِنهُم ماتَ أَبَدًا وَلا تَقُم عَلىٰ قَبرِهِ إِنَّهُم كَفَروا بِاللَّهِ وَرَسولِهِ وَماتوا وَهُم فٰسِقونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcccxx{وَلا تُعجِبكَ أَموٰلُهُم وَأَولٰدُهُم إِنَّما يُريدُ اللَّهُ أَن يُعَذِّبَهُم بِها فِى الدُّنيا وَتَزهَقَ أَنفُسُهُم وَهُم كٰفِرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcccxxi{وَإِذا أُنزِلَت سورَةٌ أَن ءامِنوا بِاللَّهِ وَجٰهِدوا مَعَ رَسولِهِ استَـٔذَنَكَ أُولُوا الطَّولِ مِنهُم وَقالوا ذَرنا نَكُن مَعَ القٰعِدينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcccxxii{رَضوا بِأَن يَكونوا مَعَ الخَوالِفِ وَطُبِعَ عَلىٰ قُلوبِهِم فَهُم لا يَفقَهونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcccxxiii{لٰكِنِ الرَّسولُ وَالَّذينَ ءامَنوا مَعَهُ جٰهَدوا بِأَموٰلِهِم وَأَنفُسِهِم وَأُولٰئِكَ لَهُمُ الخَيرٰتُ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcccxxiv{أَعَدَّ اللَّهُ لَهُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcccxxv{وَجاءَ المُعَذِّرونَ مِنَ الأَعرابِ لِيُؤذَنَ لَهُم وَقَعَدَ الَّذينَ كَذَبُوا اللَّهَ وَرَسولَهُ سَيُصيبُ الَّذينَ كَفَروا مِنهُم عَذابٌ أَليمٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcccxxvi{لَيسَ عَلَى الضُّعَفاءِ وَلا عَلَى المَرضىٰ وَلا عَلَى الَّذينَ لا يَجِدونَ ما يُنفِقونَ حَرَجٌ إِذا نَصَحوا لِلَّهِ وَرَسولِهِ ما عَلَى المُحسِنينَ مِن سَبيلٍ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcccxxvii{وَلا عَلَى الَّذينَ إِذا ما أَتَوكَ لِتَحمِلَهُم قُلتَ لا أَجِدُ ما أَحمِلُكُم عَلَيهِ تَوَلَّوا وَأَعيُنُهُم تَفيضُ مِنَ الدَّمعِ حَزَنًا أَلّا يَجِدوا ما يُنفِقونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcccxxviii{إِنَّمَا السَّبيلُ عَلَى الَّذينَ يَستَـٔذِنونَكَ وَهُم أَغنِياءُ رَضوا بِأَن يَكونوا مَعَ الخَوالِفِ وَطَبَعَ اللَّهُ عَلىٰ قُلوبِهِم فَهُم لا يَعلَمونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcccxxix{يَعتَذِرونَ إِلَيكُم إِذا رَجَعتُم إِلَيهِم قُل لا تَعتَذِروا لَن نُؤمِنَ لَكُم قَد نَبَّأَنَا اللَّهُ مِن أَخبارِكُم وَسَيَرَى اللَّهُ عَمَلَكُم وَرَسولُهُ ثُمَّ تُرَدّونَ إِلىٰ عٰلِمِ الغَيبِ وَالشَّهٰدَةِ فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcccxxx{سَيَحلِفونَ بِاللَّهِ لَكُم إِذَا انقَلَبتُم إِلَيهِم لِتُعرِضوا عَنهُم فَأَعرِضوا عَنهُم إِنَّهُم رِجسٌ وَمَأوىٰهُم جَهَنَّمُ جَزاءً بِما كانوا يَكسِبونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcccxxxi{يَحلِفونَ لَكُم لِتَرضَوا عَنهُم فَإِن تَرضَوا عَنهُم فَإِنَّ اللَّهَ لا يَرضىٰ عَنِ القَومِ الفٰسِقينَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcccxxxii{الأَعرابُ أَشَدُّ كُفرًا وَنِفاقًا وَأَجدَرُ أَلّا يَعلَموا حُدودَ ما أَنزَلَ اللَّهُ عَلىٰ رَسولِهِ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcccxxxiii{وَمِنَ الأَعرابِ مَن يَتَّخِذُ ما يُنفِقُ مَغرَمًا وَيَتَرَبَّصُ بِكُمُ الدَّوائِرَ عَلَيهِم دائِرَةُ السَّوءِ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcccxxxiv{وَمِنَ الأَعرابِ مَن يُؤمِنُ بِاللَّهِ وَاليَومِ الءاخِرِ وَيَتَّخِذُ ما يُنفِقُ قُرُبٰتٍ عِندَ اللَّهِ وَصَلَوٰتِ الرَّسولِ أَلا إِنَّها قُربَةٌ لَهُم سَيُدخِلُهُمُ اللَّهُ فى رَحمَتِهِ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcccxxxv{وَالسّٰبِقونَ الأَوَّلونَ مِنَ المُهٰجِرينَ وَالأَنصارِ وَالَّذينَ اتَّبَعوهُم بِإِحسٰنٍ رَضِىَ اللَّهُ عَنهُم وَرَضوا عَنهُ وَأَعَدَّ لَهُم جَنّٰتٍ تَجرى تَحتَهَا الأَنهٰرُ خٰلِدينَ فيها أَبَدًا ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mcccxxxvi{وَمِمَّن حَولَكُم مِنَ الأَعرابِ مُنٰفِقونَ وَمِن أَهلِ المَدينَةِ مَرَدوا عَلَى النِّفاقِ لا تَعلَمُهُم نَحنُ نَعلَمُهُم سَنُعَذِّبُهُم مَرَّتَينِ ثُمَّ يُرَدّونَ إِلىٰ عَذابٍ عَظيمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mcccxxxvii{وَءاخَرونَ اعتَرَفوا بِذُنوبِهِم خَلَطوا عَمَلًا صٰلِحًا وَءاخَرَ سَيِّئًا عَسَى اللَّهُ أَن يَتوبَ عَلَيهِم إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mcccxxxviii{خُذ مِن أَموٰلِهِم صَدَقَةً تُطَهِّرُهُم وَتُزَكّيهِم بِها وَصَلِّ عَلَيهِم إِنَّ صَلوٰتَكَ سَكَنٌ لَهُم وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mcccxxxix{أَلَم يَعلَموا أَنَّ اللَّهَ هُوَ يَقبَلُ التَّوبَةَ عَن عِبادِهِ وَيَأخُذُ الصَّدَقٰتِ وَأَنَّ اللَّهَ هُوَ التَّوّابُ الرَّحيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mcccxl{وَقُلِ اعمَلوا فَسَيَرَى اللَّهُ عَمَلَكُم وَرَسولُهُ وَالمُؤمِنونَ وَسَتُرَدّونَ إِلىٰ عٰلِمِ الغَيبِ وَالشَّهٰدَةِ فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mcccxli{وَءاخَرونَ مُرجَونَ لِأَمرِ اللَّهِ إِمّا يُعَذِّبُهُم وَإِمّا يَتوبُ عَلَيهِم وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mcccxlii{وَالَّذينَ اتَّخَذوا مَسجِدًا ضِرارًا وَكُفرًا وَتَفريقًا بَينَ المُؤمِنينَ وَإِرصادًا لِمَن حارَبَ اللَّهَ وَرَسولَهُ مِن قَبلُ وَلَيَحلِفُنَّ إِن أَرَدنا إِلَّا الحُسنىٰ وَاللَّهُ يَشهَدُ إِنَّهُم لَكٰذِبونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mcccxliii{لا تَقُم فيهِ أَبَدًا لَمَسجِدٌ أُسِّسَ عَلَى التَّقوىٰ مِن أَوَّلِ يَومٍ أَحَقُّ أَن تَقومَ فيهِ فيهِ رِجالٌ يُحِبّونَ أَن يَتَطَهَّروا وَاللَّهُ يُحِبُّ المُطَّهِّرينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mcccxliv{أَفَمَن أَسَّسَ بُنيٰنَهُ عَلىٰ تَقوىٰ مِنَ اللَّهِ وَرِضوٰنٍ خَيرٌ أَم مَن أَسَّسَ بُنيٰنَهُ عَلىٰ شَفا جُرُفٍ هارٍ فَانهارَ بِهِ فى نارِ جَهَنَّمَ وَاللَّهُ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mcccxlv{لا يَزالُ بُنيٰنُهُمُ الَّذى بَنَوا ريبَةً فى قُلوبِهِم إِلّا أَن تَقَطَّعَ قُلوبُهُم وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mcccxlvi{إِنَّ اللَّهَ اشتَرىٰ مِنَ المُؤمِنينَ أَنفُسَهُم وَأَموٰلَهُم بِأَنَّ لَهُمُ الجَنَّةَ يُقٰتِلونَ فى سَبيلِ اللَّهِ فَيَقتُلونَ وَيُقتَلونَ وَعدًا عَلَيهِ حَقًّا فِى التَّورىٰةِ وَالإِنجيلِ وَالقُرءانِ وَمَن أَوفىٰ بِعَهدِهِ مِنَ اللَّهِ فَاستَبشِروا بِبَيعِكُمُ الَّذى بايَعتُم بِهِ وَذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mcccxlvii{التّٰئِبونَ العٰبِدونَ الحٰمِدونَ السّٰئِحونَ الرّٰكِعونَ السّٰجِدونَ الءامِرونَ بِالمَعروفِ وَالنّاهونَ عَنِ المُنكَرِ وَالحٰفِظونَ لِحُدودِ اللَّهِ وَبَشِّرِ المُؤمِنينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mcccxlviii{ما كانَ لِلنَّبِىِّ وَالَّذينَ ءامَنوا أَن يَستَغفِروا لِلمُشرِكينَ وَلَو كانوا أُولى قُربىٰ مِن بَعدِ ما تَبَيَّنَ لَهُم أَنَّهُم أَصحٰبُ الجَحيمِ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mcccxlix{وَما كانَ استِغفارُ إِبرٰهيمَ لِأَبيهِ إِلّا عَن مَوعِدَةٍ وَعَدَها إِيّاهُ فَلَمّا تَبَيَّنَ لَهُ أَنَّهُ عَدُوٌّ لِلَّهِ تَبَرَّأَ مِنهُ إِنَّ إِبرٰهيمَ لَأَوّٰهٌ حَليمٌ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mcccl{وَما كانَ اللَّهُ لِيُضِلَّ قَومًا بَعدَ إِذ هَدىٰهُم حَتّىٰ يُبَيِّنَ لَهُم ما يَتَّقونَ إِنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mcccli{إِنَّ اللَّهَ لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ يُحيۦ وَيُميتُ وَما لَكُم مِن دونِ اللَّهِ مِن وَلِىٍّ وَلا نَصيرٍ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mccclii{لَقَد تابَ اللَّهُ عَلَى النَّبِىِّ وَالمُهٰجِرينَ وَالأَنصارِ الَّذينَ اتَّبَعوهُ فى ساعَةِ العُسرَةِ مِن بَعدِ ما كادَ يَزيغُ قُلوبُ فَريقٍ مِنهُم ثُمَّ تابَ عَلَيهِم إِنَّهُ بِهِم رَءوفٌ رَحيمٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mcccliii{وَعَلَى الثَّلٰثَةِ الَّذينَ خُلِّفوا حَتّىٰ إِذا ضاقَت عَلَيهِمُ الأَرضُ بِما رَحُبَت وَضاقَت عَلَيهِم أَنفُسُهُم وَظَنّوا أَن لا مَلجَأَ مِنَ اللَّهِ إِلّا إِلَيهِ ثُمَّ تابَ عَلَيهِم لِيَتوبوا إِنَّ اللَّهَ هُوَ التَّوّابُ الرَّحيمُ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mcccliv{يٰأَيُّهَا الَّذينَ ءامَنُوا اتَّقُوا اللَّهَ وَكونوا مَعَ الصّٰدِقينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mccclv{ما كانَ لِأَهلِ المَدينَةِ وَمَن حَولَهُم مِنَ الأَعرابِ أَن يَتَخَلَّفوا عَن رَسولِ اللَّهِ وَلا يَرغَبوا بِأَنفُسِهِم عَن نَفسِهِ ذٰلِكَ بِأَنَّهُم لا يُصيبُهُم ظَمَأٌ وَلا نَصَبٌ وَلا مَخمَصَةٌ فى سَبيلِ اللَّهِ وَلا يَطَـٔونَ مَوطِئًا يَغيظُ الكُفّارَ وَلا يَنالونَ مِن عَدُوٍّ نَيلًا إِلّا كُتِبَ لَهُم بِهِ عَمَلٌ صٰلِحٌ إِنَّ اللَّهَ لا يُضيعُ أَجرَ المُحسِنينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mccclvi{وَلا يُنفِقونَ نَفَقَةً صَغيرَةً وَلا كَبيرَةً وَلا يَقطَعونَ وادِيًا إِلّا كُتِبَ لَهُم لِيَجزِيَهُمُ اللَّهُ أَحسَنَ ما كانوا يَعمَلونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mccclvii{وَما كانَ المُؤمِنونَ لِيَنفِروا كافَّةً فَلَولا نَفَرَ مِن كُلِّ فِرقَةٍ مِنهُم طائِفَةٌ لِيَتَفَقَّهوا فِى الدّينِ وَلِيُنذِروا قَومَهُم إِذا رَجَعوا إِلَيهِم لَعَلَّهُم يَحذَرونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mccclviii{يٰأَيُّهَا الَّذينَ ءامَنوا قٰتِلُوا الَّذينَ يَلونَكُم مِنَ الكُفّارِ وَليَجِدوا فيكُم غِلظَةً وَاعلَموا أَنَّ اللَّهَ مَعَ المُتَّقينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mccclix{وَإِذا ما أُنزِلَت سورَةٌ فَمِنهُم مَن يَقولُ أَيُّكُم زادَتهُ هٰذِهِ إيمٰنًا فَأَمَّا الَّذينَ ءامَنوا فَزادَتهُم إيمٰنًا وَهُم يَستَبشِرونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mccclx{وَأَمَّا الَّذينَ فى قُلوبِهِم مَرَضٌ فَزادَتهُم رِجسًا إِلىٰ رِجسِهِم وَماتوا وَهُم كٰفِرونَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mccclxi{أَوَلا يَرَونَ أَنَّهُم يُفتَنونَ فى كُلِّ عامٍ مَرَّةً أَو مَرَّتَينِ ثُمَّ لا يَتوبونَ وَلا هُم يَذَّكَّرونَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mccclxii{وَإِذا ما أُنزِلَت سورَةٌ نَظَرَ بَعضُهُم إِلىٰ بَعضٍ هَل يَرىٰكُم مِن أَحَدٍ ثُمَّ انصَرَفوا صَرَفَ اللَّهُ قُلوبَهُم بِأَنَّهُم قَومٌ لا يَفقَهونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mccclxiii{لَقَد جاءَكُم رَسولٌ مِن أَنفُسِكُم عَزيزٌ عَلَيهِ ما عَنِتُّم حَريصٌ عَلَيكُم بِالمُؤمِنينَ رَءوفٌ رَحيمٌ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mccclxiv{فَإِن تَوَلَّوا فَقُل حَسبِىَ اللَّهُ لا إِلٰهَ إِلّا هُوَ عَلَيهِ تَوَكَّلتُ وَهُوَ رَبُّ العَرشِ العَظيمِ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mccclxv{\basmalah  الر تِلكَ ءايٰتُ الكِتٰبِ الحَكيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mccclxvi{أَكانَ لِلنّاسِ عَجَبًا أَن أَوحَينا إِلىٰ رَجُلٍ مِنهُم أَن أَنذِرِ النّاسَ وَبَشِّرِ الَّذينَ ءامَنوا أَنَّ لَهُم قَدَمَ صِدقٍ عِندَ رَبِّهِم قالَ الكٰفِرونَ إِنَّ هٰذا لَسٰحِرٌ مُبينٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mccclxvii{إِنَّ رَبَّكُمُ اللَّهُ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ فى سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ يُدَبِّرُ الأَمرَ ما مِن شَفيعٍ إِلّا مِن بَعدِ إِذنِهِ ذٰلِكُمُ اللَّهُ رَبُّكُم فَاعبُدوهُ أَفَلا تَذَكَّرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mccclxviii{إِلَيهِ مَرجِعُكُم جَميعًا وَعدَ اللَّهِ حَقًّا إِنَّهُ يَبدَؤُا۟ الخَلقَ ثُمَّ يُعيدُهُ لِيَجزِىَ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ بِالقِسطِ وَالَّذينَ كَفَروا لَهُم شَرابٌ مِن حَميمٍ وَعَذابٌ أَليمٌ بِما كانوا يَكفُرونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mccclxix{هُوَ الَّذى جَعَلَ الشَّمسَ ضِياءً وَالقَمَرَ نورًا وَقَدَّرَهُ مَنازِلَ لِتَعلَموا عَدَدَ السِّنينَ وَالحِسابَ ما خَلَقَ اللَّهُ ذٰلِكَ إِلّا بِالحَقِّ يُفَصِّلُ الءايٰتِ لِقَومٍ يَعلَمونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mccclxx{إِنَّ فِى اختِلٰفِ الَّيلِ وَالنَّهارِ وَما خَلَقَ اللَّهُ فِى السَّمٰوٰتِ وَالأَرضِ لَءايٰتٍ لِقَومٍ يَتَّقونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mccclxxi{إِنَّ الَّذينَ لا يَرجونَ لِقاءَنا وَرَضوا بِالحَيوٰةِ الدُّنيا وَاطمَأَنّوا بِها وَالَّذينَ هُم عَن ءايٰتِنا غٰفِلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mccclxxii{أُولٰئِكَ مَأوىٰهُمُ النّارُ بِما كانوا يَكسِبونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mccclxxiii{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ يَهديهِم رَبُّهُم بِإيمٰنِهِم تَجرى مِن تَحتِهِمُ الأَنهٰرُ فى جَنّٰتِ النَّعيمِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mccclxxiv{دَعوىٰهُم فيها سُبحٰنَكَ اللَّهُمَّ وَتَحِيَّتُهُم فيها سَلٰمٌ وَءاخِرُ دَعوىٰهُم أَنِ الحَمدُ لِلَّهِ رَبِّ العٰلَمينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mccclxxv{وَلَو يُعَجِّلُ اللَّهُ لِلنّاسِ الشَّرَّ استِعجالَهُم بِالخَيرِ لَقُضِىَ إِلَيهِم أَجَلُهُم فَنَذَرُ الَّذينَ لا يَرجونَ لِقاءَنا فى طُغيٰنِهِم يَعمَهونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mccclxxvi{وَإِذا مَسَّ الإِنسٰنَ الضُّرُّ دَعانا لِجَنبِهِ أَو قاعِدًا أَو قائِمًا فَلَمّا كَشَفنا عَنهُ ضُرَّهُ مَرَّ كَأَن لَم يَدعُنا إِلىٰ ضُرٍّ مَسَّهُ كَذٰلِكَ زُيِّنَ لِلمُسرِفينَ ما كانوا يَعمَلونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mccclxxvii{وَلَقَد أَهلَكنَا القُرونَ مِن قَبلِكُم لَمّا ظَلَموا وَجاءَتهُم رُسُلُهُم بِالبَيِّنٰتِ وَما كانوا لِيُؤمِنوا كَذٰلِكَ نَجزِى القَومَ المُجرِمينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mccclxxviii{ثُمَّ جَعَلنٰكُم خَلٰئِفَ فِى الأَرضِ مِن بَعدِهِم لِنَنظُرَ كَيفَ تَعمَلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mccclxxix{وَإِذا تُتلىٰ عَلَيهِم ءاياتُنا بَيِّنٰتٍ قالَ الَّذينَ لا يَرجونَ لِقاءَنَا ائتِ بِقُرءانٍ غَيرِ هٰذا أَو بَدِّلهُ قُل ما يَكونُ لى أَن أُبَدِّلَهُ مِن تِلقائِ نَفسى إِن أَتَّبِعُ إِلّا ما يوحىٰ إِلَىَّ إِنّى أَخافُ إِن عَصَيتُ رَبّى عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mccclxxx{قُل لَو شاءَ اللَّهُ ما تَلَوتُهُ عَلَيكُم وَلا أَدرىٰكُم بِهِ فَقَد لَبِثتُ فيكُم عُمُرًا مِن قَبلِهِ أَفَلا تَعقِلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mccclxxxi{فَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو كَذَّبَ بِـٔايٰتِهِ إِنَّهُ لا يُفلِحُ المُجرِمونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mccclxxxii{وَيَعبُدونَ مِن دونِ اللَّهِ ما لا يَضُرُّهُم وَلا يَنفَعُهُم وَيَقولونَ هٰؤُلاءِ شُفَعٰؤُنا عِندَ اللَّهِ قُل أَتُنَبِّـٔونَ اللَّهَ بِما لا يَعلَمُ فِى السَّمٰوٰتِ وَلا فِى الأَرضِ سُبحٰنَهُ وَتَعٰلىٰ عَمّا يُشرِكونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mccclxxxiii{وَما كانَ النّاسُ إِلّا أُمَّةً وٰحِدَةً فَاختَلَفوا وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ لَقُضِىَ بَينَهُم فيما فيهِ يَختَلِفونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mccclxxxiv{وَيَقولونَ لَولا أُنزِلَ عَلَيهِ ءايَةٌ مِن رَبِّهِ فَقُل إِنَّمَا الغَيبُ لِلَّهِ فَانتَظِروا إِنّى مَعَكُم مِنَ المُنتَظِرينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mccclxxxv{وَإِذا أَذَقنَا النّاسَ رَحمَةً مِن بَعدِ ضَرّاءَ مَسَّتهُم إِذا لَهُم مَكرٌ فى ءاياتِنا قُلِ اللَّهُ أَسرَعُ مَكرًا إِنَّ رُسُلَنا يَكتُبونَ ما تَمكُرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mccclxxxvi{هُوَ الَّذى يُسَيِّرُكُم فِى البَرِّ وَالبَحرِ حَتّىٰ إِذا كُنتُم فِى الفُلكِ وَجَرَينَ بِهِم بِريحٍ طَيِّبَةٍ وَفَرِحوا بِها جاءَتها ريحٌ عاصِفٌ وَجاءَهُمُ المَوجُ مِن كُلِّ مَكانٍ وَظَنّوا أَنَّهُم أُحيطَ بِهِم دَعَوُا اللَّهَ مُخلِصينَ لَهُ الدّينَ لَئِن أَنجَيتَنا مِن هٰذِهِ لَنَكونَنَّ مِنَ الشّٰكِرينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mccclxxxvii{فَلَمّا أَنجىٰهُم إِذا هُم يَبغونَ فِى الأَرضِ بِغَيرِ الحَقِّ يٰأَيُّهَا النّاسُ إِنَّما بَغيُكُم عَلىٰ أَنفُسِكُم مَتٰعَ الحَيوٰةِ الدُّنيا ثُمَّ إِلَينا مَرجِعُكُم فَنُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mccclxxxviii{إِنَّما مَثَلُ الحَيوٰةِ الدُّنيا كَماءٍ أَنزَلنٰهُ مِنَ السَّماءِ فَاختَلَطَ بِهِ نَباتُ الأَرضِ مِمّا يَأكُلُ النّاسُ وَالأَنعٰمُ حَتّىٰ إِذا أَخَذَتِ الأَرضُ زُخرُفَها وَازَّيَّنَت وَظَنَّ أَهلُها أَنَّهُم قٰدِرونَ عَلَيها أَتىٰها أَمرُنا لَيلًا أَو نَهارًا فَجَعَلنٰها حَصيدًا كَأَن لَم تَغنَ بِالأَمسِ كَذٰلِكَ نُفَصِّلُ الءايٰتِ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mccclxxxix{وَاللَّهُ يَدعوا إِلىٰ دارِ السَّلٰمِ وَيَهدى مَن يَشاءُ إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcccxc{لِلَّذينَ أَحسَنُوا الحُسنىٰ وَزِيادَةٌ وَلا يَرهَقُ وُجوهَهُم قَتَرٌ وَلا ذِلَّةٌ أُولٰئِكَ أَصحٰبُ الجَنَّةِ هُم فيها خٰلِدونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcccxci{وَالَّذينَ كَسَبُوا السَّيِّـٔاتِ جَزاءُ سَيِّئَةٍ بِمِثلِها وَتَرهَقُهُم ذِلَّةٌ ما لَهُم مِنَ اللَّهِ مِن عاصِمٍ كَأَنَّما أُغشِيَت وُجوهُهُم قِطَعًا مِنَ الَّيلِ مُظلِمًا أُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcccxcii{وَيَومَ نَحشُرُهُم جَميعًا ثُمَّ نَقولُ لِلَّذينَ أَشرَكوا مَكانَكُم أَنتُم وَشُرَكاؤُكُم فَزَيَّلنا بَينَهُم وَقالَ شُرَكاؤُهُم ما كُنتُم إِيّانا تَعبُدونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcccxciii{فَكَفىٰ بِاللَّهِ شَهيدًا بَينَنا وَبَينَكُم إِن كُنّا عَن عِبادَتِكُم لَغٰفِلينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcccxciv{هُنالِكَ تَبلوا كُلُّ نَفسٍ ما أَسلَفَت وَرُدّوا إِلَى اللَّهِ مَولىٰهُمُ الحَقِّ وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcccxcv{قُل مَن يَرزُقُكُم مِنَ السَّماءِ وَالأَرضِ أَمَّن يَملِكُ السَّمعَ وَالأَبصٰرَ وَمَن يُخرِجُ الحَىَّ مِنَ المَيِّتِ وَيُخرِجُ المَيِّتَ مِنَ الحَىِّ وَمَن يُدَبِّرُ الأَمرَ فَسَيَقولونَ اللَّهُ فَقُل أَفَلا تَتَّقونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcccxcvi{فَذٰلِكُمُ اللَّهُ رَبُّكُمُ الحَقُّ فَماذا بَعدَ الحَقِّ إِلَّا الضَّلٰلُ فَأَنّىٰ تُصرَفونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcccxcvii{كَذٰلِكَ حَقَّت كَلِمَتُ رَبِّكَ عَلَى الَّذينَ فَسَقوا أَنَّهُم لا يُؤمِنونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcccxcviii{قُل هَل مِن شُرَكائِكُم مَن يَبدَؤُا۟ الخَلقَ ثُمَّ يُعيدُهُ قُلِ اللَّهُ يَبدَؤُا۟ الخَلقَ ثُمَّ يُعيدُهُ فَأَنّىٰ تُؤفَكونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcccxcix{قُل هَل مِن شُرَكائِكُم مَن يَهدى إِلَى الحَقِّ قُلِ اللَّهُ يَهدى لِلحَقِّ أَفَمَن يَهدى إِلَى الحَقِّ أَحَقُّ أَن يُتَّبَعَ أَمَّن لا يَهِدّى إِلّا أَن يُهدىٰ فَما لَكُم كَيفَ تَحكُمونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcd{وَما يَتَّبِعُ أَكثَرُهُم إِلّا ظَنًّا إِنَّ الظَّنَّ لا يُغنى مِنَ الحَقِّ شَيـًٔا إِنَّ اللَّهَ عَليمٌ بِما يَفعَلونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcdi{وَما كانَ هٰذَا القُرءانُ أَن يُفتَرىٰ مِن دونِ اللَّهِ وَلٰكِن تَصديقَ الَّذى بَينَ يَدَيهِ وَتَفصيلَ الكِتٰبِ لا رَيبَ فيهِ مِن رَبِّ العٰلَمينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcdii{أَم يَقولونَ افتَرىٰهُ قُل فَأتوا بِسورَةٍ مِثلِهِ وَادعوا مَنِ استَطَعتُم مِن دونِ اللَّهِ إِن كُنتُم صٰدِقينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcdiii{بَل كَذَّبوا بِما لَم يُحيطوا بِعِلمِهِ وَلَمّا يَأتِهِم تَأويلُهُ كَذٰلِكَ كَذَّبَ الَّذينَ مِن قَبلِهِم فَانظُر كَيفَ كانَ عٰقِبَةُ الظّٰلِمينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcdiv{وَمِنهُم مَن يُؤمِنُ بِهِ وَمِنهُم مَن لا يُؤمِنُ بِهِ وَرَبُّكَ أَعلَمُ بِالمُفسِدينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcdv{وَإِن كَذَّبوكَ فَقُل لى عَمَلى وَلَكُم عَمَلُكُم أَنتُم بَريـٔونَ مِمّا أَعمَلُ وَأَنا۠ بَريءٌ مِمّا تَعمَلونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcdvi{وَمِنهُم مَن يَستَمِعونَ إِلَيكَ أَفَأَنتَ تُسمِعُ الصُّمَّ وَلَو كانوا لا يَعقِلونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcdvii{وَمِنهُم مَن يَنظُرُ إِلَيكَ أَفَأَنتَ تَهدِى العُمىَ وَلَو كانوا لا يُبصِرونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcdviii{إِنَّ اللَّهَ لا يَظلِمُ النّاسَ شَيـًٔا وَلٰكِنَّ النّاسَ أَنفُسَهُم يَظلِمونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcdix{وَيَومَ يَحشُرُهُم كَأَن لَم يَلبَثوا إِلّا ساعَةً مِنَ النَّهارِ يَتَعارَفونَ بَينَهُم قَد خَسِرَ الَّذينَ كَذَّبوا بِلِقاءِ اللَّهِ وَما كانوا مُهتَدينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcdx{وَإِمّا نُرِيَنَّكَ بَعضَ الَّذى نَعِدُهُم أَو نَتَوَفَّيَنَّكَ فَإِلَينا مَرجِعُهُم ثُمَّ اللَّهُ شَهيدٌ عَلىٰ ما يَفعَلونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcdxi{وَلِكُلِّ أُمَّةٍ رَسولٌ فَإِذا جاءَ رَسولُهُم قُضِىَ بَينَهُم بِالقِسطِ وَهُم لا يُظلَمونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcdxii{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صٰدِقينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcdxiii{قُل لا أَملِكُ لِنَفسى ضَرًّا وَلا نَفعًا إِلّا ما شاءَ اللَّهُ لِكُلِّ أُمَّةٍ أَجَلٌ إِذا جاءَ أَجَلُهُم فَلا يَستَـٔخِرونَ ساعَةً وَلا يَستَقدِمونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcdxiv{قُل أَرَءَيتُم إِن أَتىٰكُم عَذابُهُ بَيٰتًا أَو نَهارًا ماذا يَستَعجِلُ مِنهُ المُجرِمونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcdxv{أَثُمَّ إِذا ما وَقَعَ ءامَنتُم بِهِ ءالـٰٔنَ وَقَد كُنتُم بِهِ تَستَعجِلونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcdxvi{ثُمَّ قيلَ لِلَّذينَ ظَلَموا ذوقوا عَذابَ الخُلدِ هَل تُجزَونَ إِلّا بِما كُنتُم تَكسِبونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcdxvii{وَيَستَنبِـٔونَكَ أَحَقٌّ هُوَ قُل إى وَرَبّى إِنَّهُ لَحَقٌّ وَما أَنتُم بِمُعجِزينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcdxviii{وَلَو أَنَّ لِكُلِّ نَفسٍ ظَلَمَت ما فِى الأَرضِ لَافتَدَت بِهِ وَأَسَرُّوا النَّدامَةَ لَمّا رَأَوُا العَذابَ وَقُضِىَ بَينَهُم بِالقِسطِ وَهُم لا يُظلَمونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mcdxix{أَلا إِنَّ لِلَّهِ ما فِى السَّمٰوٰتِ وَالأَرضِ أَلا إِنَّ وَعدَ اللَّهِ حَقٌّ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mcdxx{هُوَ يُحيۦ وَيُميتُ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mcdxxi{يٰأَيُّهَا النّاسُ قَد جاءَتكُم مَوعِظَةٌ مِن رَبِّكُم وَشِفاءٌ لِما فِى الصُّدورِ وَهُدًى وَرَحمَةٌ لِلمُؤمِنينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mcdxxii{قُل بِفَضلِ اللَّهِ وَبِرَحمَتِهِ فَبِذٰلِكَ فَليَفرَحوا هُوَ خَيرٌ مِمّا يَجمَعونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mcdxxiii{قُل أَرَءَيتُم ما أَنزَلَ اللَّهُ لَكُم مِن رِزقٍ فَجَعَلتُم مِنهُ حَرامًا وَحَلٰلًا قُل ءاللَّهُ أَذِنَ لَكُم أَم عَلَى اللَّهِ تَفتَرونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mcdxxiv{وَما ظَنُّ الَّذينَ يَفتَرونَ عَلَى اللَّهِ الكَذِبَ يَومَ القِيٰمَةِ إِنَّ اللَّهَ لَذو فَضلٍ عَلَى النّاسِ وَلٰكِنَّ أَكثَرَهُم لا يَشكُرونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mcdxxv{وَما تَكونُ فى شَأنٍ وَما تَتلوا مِنهُ مِن قُرءانٍ وَلا تَعمَلونَ مِن عَمَلٍ إِلّا كُنّا عَلَيكُم شُهودًا إِذ تُفيضونَ فيهِ وَما يَعزُبُ عَن رَبِّكَ مِن مِثقالِ ذَرَّةٍ فِى الأَرضِ وَلا فِى السَّماءِ وَلا أَصغَرَ مِن ذٰلِكَ وَلا أَكبَرَ إِلّا فى كِتٰبٍ مُبينٍ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mcdxxvi{أَلا إِنَّ أَولِياءَ اللَّهِ لا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mcdxxvii{الَّذينَ ءامَنوا وَكانوا يَتَّقونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mcdxxviii{لَهُمُ البُشرىٰ فِى الحَيوٰةِ الدُّنيا وَفِى الءاخِرَةِ لا تَبديلَ لِكَلِمٰتِ اللَّهِ ذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mcdxxix{وَلا يَحزُنكَ قَولُهُم إِنَّ العِزَّةَ لِلَّهِ جَميعًا هُوَ السَّميعُ العَليمُ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mcdxxx{أَلا إِنَّ لِلَّهِ مَن فِى السَّمٰوٰتِ وَمَن فِى الأَرضِ وَما يَتَّبِعُ الَّذينَ يَدعونَ مِن دونِ اللَّهِ شُرَكاءَ إِن يَتَّبِعونَ إِلَّا الظَّنَّ وَإِن هُم إِلّا يَخرُصونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcdxxxi{هُوَ الَّذى جَعَلَ لَكُمُ الَّيلَ لِتَسكُنوا فيهِ وَالنَّهارَ مُبصِرًا إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَسمَعونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mcdxxxii{قالُوا اتَّخَذَ اللَّهُ وَلَدًا سُبحٰنَهُ هُوَ الغَنِىُّ لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ إِن عِندَكُم مِن سُلطٰنٍ بِهٰذا أَتَقولونَ عَلَى اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mcdxxxiii{قُل إِنَّ الَّذينَ يَفتَرونَ عَلَى اللَّهِ الكَذِبَ لا يُفلِحونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcdxxxiv{مَتٰعٌ فِى الدُّنيا ثُمَّ إِلَينا مَرجِعُهُم ثُمَّ نُذيقُهُمُ العَذابَ الشَّديدَ بِما كانوا يَكفُرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcdxxxv{وَاتلُ عَلَيهِم نَبَأَ نوحٍ إِذ قالَ لِقَومِهِ يٰقَومِ إِن كانَ كَبُرَ عَلَيكُم مَقامى وَتَذكيرى بِـٔايٰتِ اللَّهِ فَعَلَى اللَّهِ تَوَكَّلتُ فَأَجمِعوا أَمرَكُم وَشُرَكاءَكُم ثُمَّ لا يَكُن أَمرُكُم عَلَيكُم غُمَّةً ثُمَّ اقضوا إِلَىَّ وَلا تُنظِرونِ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcdxxxvi{فَإِن تَوَلَّيتُم فَما سَأَلتُكُم مِن أَجرٍ إِن أَجرِىَ إِلّا عَلَى اللَّهِ وَأُمِرتُ أَن أَكونَ مِنَ المُسلِمينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcdxxxvii{فَكَذَّبوهُ فَنَجَّينٰهُ وَمَن مَعَهُ فِى الفُلكِ وَجَعَلنٰهُم خَلٰئِفَ وَأَغرَقنَا الَّذينَ كَذَّبوا بِـٔايٰتِنا فَانظُر كَيفَ كانَ عٰقِبَةُ المُنذَرينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcdxxxviii{ثُمَّ بَعَثنا مِن بَعدِهِ رُسُلًا إِلىٰ قَومِهِم فَجاءوهُم بِالبَيِّنٰتِ فَما كانوا لِيُؤمِنوا بِما كَذَّبوا بِهِ مِن قَبلُ كَذٰلِكَ نَطبَعُ عَلىٰ قُلوبِ المُعتَدينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcdxxxix{ثُمَّ بَعَثنا مِن بَعدِهِم موسىٰ وَهٰرونَ إِلىٰ فِرعَونَ وَمَلَإِي۟هِ بِـٔايٰتِنا فَاستَكبَروا وَكانوا قَومًا مُجرِمينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcdxl{فَلَمّا جاءَهُمُ الحَقُّ مِن عِندِنا قالوا إِنَّ هٰذا لَسِحرٌ مُبينٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcdxli{قالَ موسىٰ أَتَقولونَ لِلحَقِّ لَمّا جاءَكُم أَسِحرٌ هٰذا وَلا يُفلِحُ السّٰحِرونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcdxlii{قالوا أَجِئتَنا لِتَلفِتَنا عَمّا وَجَدنا عَلَيهِ ءاباءَنا وَتَكونَ لَكُمَا الكِبرِياءُ فِى الأَرضِ وَما نَحنُ لَكُما بِمُؤمِنينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcdxliii{وَقالَ فِرعَونُ ائتونى بِكُلِّ سٰحِرٍ عَليمٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcdxliv{فَلَمّا جاءَ السَّحَرَةُ قالَ لَهُم موسىٰ أَلقوا ما أَنتُم مُلقونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcdxlv{فَلَمّا أَلقَوا قالَ موسىٰ ما جِئتُم بِهِ السِّحرُ إِنَّ اللَّهَ سَيُبطِلُهُ إِنَّ اللَّهَ لا يُصلِحُ عَمَلَ المُفسِدينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcdxlvi{وَيُحِقُّ اللَّهُ الحَقَّ بِكَلِمٰتِهِ وَلَو كَرِهَ المُجرِمونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcdxlvii{فَما ءامَنَ لِموسىٰ إِلّا ذُرِّيَّةٌ مِن قَومِهِ عَلىٰ خَوفٍ مِن فِرعَونَ وَمَلَإِي۟هِم أَن يَفتِنَهُم وَإِنَّ فِرعَونَ لَعالٍ فِى الأَرضِ وَإِنَّهُ لَمِنَ المُسرِفينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcdxlviii{وَقالَ موسىٰ يٰقَومِ إِن كُنتُم ءامَنتُم بِاللَّهِ فَعَلَيهِ تَوَكَّلوا إِن كُنتُم مُسلِمينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcdxlix{فَقالوا عَلَى اللَّهِ تَوَكَّلنا رَبَّنا لا تَجعَلنا فِتنَةً لِلقَومِ الظّٰلِمينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcdl{وَنَجِّنا بِرَحمَتِكَ مِنَ القَومِ الكٰفِرينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcdli{وَأَوحَينا إِلىٰ موسىٰ وَأَخيهِ أَن تَبَوَّءا لِقَومِكُما بِمِصرَ بُيوتًا وَاجعَلوا بُيوتَكُم قِبلَةً وَأَقيمُوا الصَّلوٰةَ وَبَشِّرِ المُؤمِنينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcdlii{وَقالَ موسىٰ رَبَّنا إِنَّكَ ءاتَيتَ فِرعَونَ وَمَلَأَهُ زينَةً وَأَموٰلًا فِى الحَيوٰةِ الدُّنيا رَبَّنا لِيُضِلّوا عَن سَبيلِكَ رَبَّنَا اطمِس عَلىٰ أَموٰلِهِم وَاشدُد عَلىٰ قُلوبِهِم فَلا يُؤمِنوا حَتّىٰ يَرَوُا العَذابَ الأَليمَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcdliii{قالَ قَد أُجيبَت دَعوَتُكُما فَاستَقيما وَلا تَتَّبِعانِّ سَبيلَ الَّذينَ لا يَعلَمونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcdliv{وَجٰوَزنا بِبَنى إِسرٰءيلَ البَحرَ فَأَتبَعَهُم فِرعَونُ وَجُنودُهُ بَغيًا وَعَدوًا حَتّىٰ إِذا أَدرَكَهُ الغَرَقُ قالَ ءامَنتُ أَنَّهُ لا إِلٰهَ إِلَّا الَّذى ءامَنَت بِهِ بَنوا إِسرٰءيلَ وَأَنا۠ مِنَ المُسلِمينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcdlv{ءالـٰٔنَ وَقَد عَصَيتَ قَبلُ وَكُنتَ مِنَ المُفسِدينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcdlvi{فَاليَومَ نُنَجّيكَ بِبَدَنِكَ لِتَكونَ لِمَن خَلفَكَ ءايَةً وَإِنَّ كَثيرًا مِنَ النّاسِ عَن ءايٰتِنا لَغٰفِلونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcdlvii{وَلَقَد بَوَّأنا بَنى إِسرٰءيلَ مُبَوَّأَ صِدقٍ وَرَزَقنٰهُم مِنَ الطَّيِّبٰتِ فَمَا اختَلَفوا حَتّىٰ جاءَهُمُ العِلمُ إِنَّ رَبَّكَ يَقضى بَينَهُم يَومَ القِيٰمَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcdlviii{فَإِن كُنتَ فى شَكٍّ مِمّا أَنزَلنا إِلَيكَ فَسـَٔلِ الَّذينَ يَقرَءونَ الكِتٰبَ مِن قَبلِكَ لَقَد جاءَكَ الحَقُّ مِن رَبِّكَ فَلا تَكونَنَّ مِنَ المُمتَرينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcdlix{وَلا تَكونَنَّ مِنَ الَّذينَ كَذَّبوا بِـٔايٰتِ اللَّهِ فَتَكونَ مِنَ الخٰسِرينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcdlx{إِنَّ الَّذينَ حَقَّت عَلَيهِم كَلِمَتُ رَبِّكَ لا يُؤمِنونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcdlxi{وَلَو جاءَتهُم كُلُّ ءايَةٍ حَتّىٰ يَرَوُا العَذابَ الأَليمَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcdlxii{فَلَولا كانَت قَريَةٌ ءامَنَت فَنَفَعَها إيمٰنُها إِلّا قَومَ يونُسَ لَمّا ءامَنوا كَشَفنا عَنهُم عَذابَ الخِزىِ فِى الحَيوٰةِ الدُّنيا وَمَتَّعنٰهُم إِلىٰ حينٍ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcdlxiii{وَلَو شاءَ رَبُّكَ لَءامَنَ مَن فِى الأَرضِ كُلُّهُم جَميعًا أَفَأَنتَ تُكرِهُ النّاسَ حَتّىٰ يَكونوا مُؤمِنينَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcdlxiv{وَما كانَ لِنَفسٍ أَن تُؤمِنَ إِلّا بِإِذنِ اللَّهِ وَيَجعَلُ الرِّجسَ عَلَى الَّذينَ لا يَعقِلونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mcdlxv{قُلِ انظُروا ماذا فِى السَّمٰوٰتِ وَالأَرضِ وَما تُغنِى الءايٰتُ وَالنُّذُرُ عَن قَومٍ لا يُؤمِنونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mcdlxvi{فَهَل يَنتَظِرونَ إِلّا مِثلَ أَيّامِ الَّذينَ خَلَوا مِن قَبلِهِم قُل فَانتَظِروا إِنّى مَعَكُم مِنَ المُنتَظِرينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mcdlxvii{ثُمَّ نُنَجّى رُسُلَنا وَالَّذينَ ءامَنوا كَذٰلِكَ حَقًّا عَلَينا نُنجِ المُؤمِنينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mcdlxviii{قُل يٰأَيُّهَا النّاسُ إِن كُنتُم فى شَكٍّ مِن دينى فَلا أَعبُدُ الَّذينَ تَعبُدونَ مِن دونِ اللَّهِ وَلٰكِن أَعبُدُ اللَّهَ الَّذى يَتَوَفّىٰكُم وَأُمِرتُ أَن أَكونَ مِنَ المُؤمِنينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mcdlxix{وَأَن أَقِم وَجهَكَ لِلدّينِ حَنيفًا وَلا تَكونَنَّ مِنَ المُشرِكينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mcdlxx{وَلا تَدعُ مِن دونِ اللَّهِ ما لا يَنفَعُكَ وَلا يَضُرُّكَ فَإِن فَعَلتَ فَإِنَّكَ إِذًا مِنَ الظّٰلِمينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mcdlxxi{وَإِن يَمسَسكَ اللَّهُ بِضُرٍّ فَلا كاشِفَ لَهُ إِلّا هُوَ وَإِن يُرِدكَ بِخَيرٍ فَلا رادَّ لِفَضلِهِ يُصيبُ بِهِ مَن يَشاءُ مِن عِبادِهِ وَهُوَ الغَفورُ الرَّحيمُ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mcdlxxii{قُل يٰأَيُّهَا النّاسُ قَد جاءَكُمُ الحَقُّ مِن رَبِّكُم فَمَنِ اهتَدىٰ فَإِنَّما يَهتَدى لِنَفسِهِ وَمَن ضَلَّ فَإِنَّما يَضِلُّ عَلَيها وَما أَنا۠ عَلَيكُم بِوَكيلٍ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mcdlxxiii{وَاتَّبِع ما يوحىٰ إِلَيكَ وَاصبِر حَتّىٰ يَحكُمَ اللَّهُ وَهُوَ خَيرُ الحٰكِمينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mcdlxxiv{\basmalah  الر كِتٰبٌ أُحكِمَت ءايٰتُهُ ثُمَّ فُصِّلَت مِن لَدُن حَكيمٍ خَبيرٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mcdlxxv{أَلّا تَعبُدوا إِلَّا اللَّهَ إِنَّنى لَكُم مِنهُ نَذيرٌ وَبَشيرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mcdlxxvi{وَأَنِ استَغفِروا رَبَّكُم ثُمَّ توبوا إِلَيهِ يُمَتِّعكُم مَتٰعًا حَسَنًا إِلىٰ أَجَلٍ مُسَمًّى وَيُؤتِ كُلَّ ذى فَضلٍ فَضلَهُ وَإِن تَوَلَّوا فَإِنّى أَخافُ عَلَيكُم عَذابَ يَومٍ كَبيرٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mcdlxxvii{إِلَى اللَّهِ مَرجِعُكُم وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mcdlxxviii{أَلا إِنَّهُم يَثنونَ صُدورَهُم لِيَستَخفوا مِنهُ أَلا حينَ يَستَغشونَ ثِيابَهُم يَعلَمُ ما يُسِرّونَ وَما يُعلِنونَ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mcdlxxix{وَما مِن دابَّةٍ فِى الأَرضِ إِلّا عَلَى اللَّهِ رِزقُها وَيَعلَمُ مُستَقَرَّها وَمُستَودَعَها كُلٌّ فى كِتٰبٍ مُبينٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mcdlxxx{وَهُوَ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ فى سِتَّةِ أَيّامٍ وَكانَ عَرشُهُ عَلَى الماءِ لِيَبلُوَكُم أَيُّكُم أَحسَنُ عَمَلًا وَلَئِن قُلتَ إِنَّكُم مَبعوثونَ مِن بَعدِ المَوتِ لَيَقولَنَّ الَّذينَ كَفَروا إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mcdlxxxi{وَلَئِن أَخَّرنا عَنهُمُ العَذابَ إِلىٰ أُمَّةٍ مَعدودَةٍ لَيَقولُنَّ ما يَحبِسُهُ أَلا يَومَ يَأتيهِم لَيسَ مَصروفًا عَنهُم وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mcdlxxxii{وَلَئِن أَذَقنَا الإِنسٰنَ مِنّا رَحمَةً ثُمَّ نَزَعنٰها مِنهُ إِنَّهُ لَيَـٔوسٌ كَفورٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mcdlxxxiii{وَلَئِن أَذَقنٰهُ نَعماءَ بَعدَ ضَرّاءَ مَسَّتهُ لَيَقولَنَّ ذَهَبَ السَّيِّـٔاتُ عَنّى إِنَّهُ لَفَرِحٌ فَخورٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mcdlxxxiv{إِلَّا الَّذينَ صَبَروا وَعَمِلُوا الصّٰلِحٰتِ أُولٰئِكَ لَهُم مَغفِرَةٌ وَأَجرٌ كَبيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mcdlxxxv{فَلَعَلَّكَ تارِكٌ بَعضَ ما يوحىٰ إِلَيكَ وَضائِقٌ بِهِ صَدرُكَ أَن يَقولوا لَولا أُنزِلَ عَلَيهِ كَنزٌ أَو جاءَ مَعَهُ مَلَكٌ إِنَّما أَنتَ نَذيرٌ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ وَكيلٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mcdlxxxvi{أَم يَقولونَ افتَرىٰهُ قُل فَأتوا بِعَشرِ سُوَرٍ مِثلِهِ مُفتَرَيٰتٍ وَادعوا مَنِ استَطَعتُم مِن دونِ اللَّهِ إِن كُنتُم صٰدِقينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mcdlxxxvii{فَإِلَّم يَستَجيبوا لَكُم فَاعلَموا أَنَّما أُنزِلَ بِعِلمِ اللَّهِ وَأَن لا إِلٰهَ إِلّا هُوَ فَهَل أَنتُم مُسلِمونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mcdlxxxviii{مَن كانَ يُريدُ الحَيوٰةَ الدُّنيا وَزينَتَها نُوَفِّ إِلَيهِم أَعمٰلَهُم فيها وَهُم فيها لا يُبخَسونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mcdlxxxix{أُولٰئِكَ الَّذينَ لَيسَ لَهُم فِى الءاخِرَةِ إِلَّا النّارُ وَحَبِطَ ما صَنَعوا فيها وَبٰطِلٌ ما كانوا يَعمَلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcdxc{أَفَمَن كانَ عَلىٰ بَيِّنَةٍ مِن رَبِّهِ وَيَتلوهُ شاهِدٌ مِنهُ وَمِن قَبلِهِ كِتٰبُ موسىٰ إِمامًا وَرَحمَةً أُولٰئِكَ يُؤمِنونَ بِهِ وَمَن يَكفُر بِهِ مِنَ الأَحزابِ فَالنّارُ مَوعِدُهُ فَلا تَكُ فى مِريَةٍ مِنهُ إِنَّهُ الحَقُّ مِن رَبِّكَ وَلٰكِنَّ أَكثَرَ النّاسِ لا يُؤمِنونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mcdxci{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أُولٰئِكَ يُعرَضونَ عَلىٰ رَبِّهِم وَيَقولُ الأَشهٰدُ هٰؤُلاءِ الَّذينَ كَذَبوا عَلىٰ رَبِّهِم أَلا لَعنَةُ اللَّهِ عَلَى الظّٰلِمينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mcdxcii{الَّذينَ يَصُدّونَ عَن سَبيلِ اللَّهِ وَيَبغونَها عِوَجًا وَهُم بِالءاخِرَةِ هُم كٰفِرونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcdxciii{أُولٰئِكَ لَم يَكونوا مُعجِزينَ فِى الأَرضِ وَما كانَ لَهُم مِن دونِ اللَّهِ مِن أَولِياءَ يُضٰعَفُ لَهُمُ العَذابُ ما كانوا يَستَطيعونَ السَّمعَ وَما كانوا يُبصِرونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcdxciv{أُولٰئِكَ الَّذينَ خَسِروا أَنفُسَهُم وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcdxcv{لا جَرَمَ أَنَّهُم فِى الءاخِرَةِ هُمُ الأَخسَرونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcdxcvi{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ وَأَخبَتوا إِلىٰ رَبِّهِم أُولٰئِكَ أَصحٰبُ الجَنَّةِ هُم فيها خٰلِدونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcdxcvii{مَثَلُ الفَريقَينِ كَالأَعمىٰ وَالأَصَمِّ وَالبَصيرِ وَالسَّميعِ هَل يَستَوِيانِ مَثَلًا أَفَلا تَذَكَّرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcdxcviii{وَلَقَد أَرسَلنا نوحًا إِلىٰ قَومِهِ إِنّى لَكُم نَذيرٌ مُبينٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcdxcix{أَن لا تَعبُدوا إِلَّا اللَّهَ إِنّى أَخافُ عَلَيكُم عَذابَ يَومٍ أَليمٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@md{فَقالَ المَلَأُ الَّذينَ كَفَروا مِن قَومِهِ ما نَرىٰكَ إِلّا بَشَرًا مِثلَنا وَما نَرىٰكَ اتَّبَعَكَ إِلَّا الَّذينَ هُم أَراذِلُنا بادِىَ الرَّأىِ وَما نَرىٰ لَكُم عَلَينا مِن فَضلٍ بَل نَظُنُّكُم كٰذِبينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdi{قالَ يٰقَومِ أَرَءَيتُم إِن كُنتُ عَلىٰ بَيِّنَةٍ مِن رَبّى وَءاتىٰنى رَحمَةً مِن عِندِهِ فَعُمِّيَت عَلَيكُم أَنُلزِمُكُموها وَأَنتُم لَها كٰرِهونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdii{وَيٰقَومِ لا أَسـَٔلُكُم عَلَيهِ مالًا إِن أَجرِىَ إِلّا عَلَى اللَّهِ وَما أَنا۠ بِطارِدِ الَّذينَ ءامَنوا إِنَّهُم مُلٰقوا رَبِّهِم وَلٰكِنّى أَرىٰكُم قَومًا تَجهَلونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdiii{وَيٰقَومِ مَن يَنصُرُنى مِنَ اللَّهِ إِن طَرَدتُهُم أَفَلا تَذَكَّرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdiv{وَلا أَقولُ لَكُم عِندى خَزائِنُ اللَّهِ وَلا أَعلَمُ الغَيبَ وَلا أَقولُ إِنّى مَلَكٌ وَلا أَقولُ لِلَّذينَ تَزدَرى أَعيُنُكُم لَن يُؤتِيَهُمُ اللَّهُ خَيرًا اللَّهُ أَعلَمُ بِما فى أَنفُسِهِم إِنّى إِذًا لَمِنَ الظّٰلِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdv{قالوا يٰنوحُ قَد جٰدَلتَنا فَأَكثَرتَ جِدٰلَنا فَأتِنا بِما تَعِدُنا إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdvi{قالَ إِنَّما يَأتيكُم بِهِ اللَّهُ إِن شاءَ وَما أَنتُم بِمُعجِزينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdvii{وَلا يَنفَعُكُم نُصحى إِن أَرَدتُ أَن أَنصَحَ لَكُم إِن كانَ اللَّهُ يُريدُ أَن يُغوِيَكُم هُوَ رَبُّكُم وَإِلَيهِ تُرجَعونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdviii{أَم يَقولونَ افتَرىٰهُ قُل إِنِ افتَرَيتُهُ فَعَلَىَّ إِجرامى وَأَنا۠ بَريءٌ مِمّا تُجرِمونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdix{وَأوحِىَ إِلىٰ نوحٍ أَنَّهُ لَن يُؤمِنَ مِن قَومِكَ إِلّا مَن قَد ءامَنَ فَلا تَبتَئِس بِما كانوا يَفعَلونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdx{وَاصنَعِ الفُلكَ بِأَعيُنِنا وَوَحيِنا وَلا تُخٰطِبنى فِى الَّذينَ ظَلَموا إِنَّهُم مُغرَقونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdxi{وَيَصنَعُ الفُلكَ وَكُلَّما مَرَّ عَلَيهِ مَلَأٌ مِن قَومِهِ سَخِروا مِنهُ قالَ إِن تَسخَروا مِنّا فَإِنّا نَسخَرُ مِنكُم كَما تَسخَرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdxii{فَسَوفَ تَعلَمونَ مَن يَأتيهِ عَذابٌ يُخزيهِ وَيَحِلُّ عَلَيهِ عَذابٌ مُقيمٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdxiii{حَتّىٰ إِذا جاءَ أَمرُنا وَفارَ التَّنّورُ قُلنَا احمِل فيها مِن كُلٍّ زَوجَينِ اثنَينِ وَأَهلَكَ إِلّا مَن سَبَقَ عَلَيهِ القَولُ وَمَن ءامَنَ وَما ءامَنَ مَعَهُ إِلّا قَليلٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdxiv{وَقالَ اركَبوا فيها بِسمِ اللَّهِ مَجر۪ىٰها وَمُرسىٰها إِنَّ رَبّى لَغَفورٌ رَحيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdxv{وَهِىَ تَجرى بِهِم فى مَوجٍ كَالجِبالِ وَنادىٰ نوحٌ ابنَهُ وَكانَ فى مَعزِلٍ يٰبُنَىَّ اركَب مَعَنا وَلا تَكُن مَعَ الكٰفِرينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdxvi{قالَ سَـٔاوى إِلىٰ جَبَلٍ يَعصِمُنى مِنَ الماءِ قالَ لا عاصِمَ اليَومَ مِن أَمرِ اللَّهِ إِلّا مَن رَحِمَ وَحالَ بَينَهُمَا المَوجُ فَكانَ مِنَ المُغرَقينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdxvii{وَقيلَ يٰأَرضُ ابلَعى ماءَكِ وَيٰسَماءُ أَقلِعى وَغيضَ الماءُ وَقُضِىَ الأَمرُ وَاستَوَت عَلَى الجودِىِّ وَقيلَ بُعدًا لِلقَومِ الظّٰلِمينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdxviii{وَنادىٰ نوحٌ رَبَّهُ فَقالَ رَبِّ إِنَّ ابنى مِن أَهلى وَإِنَّ وَعدَكَ الحَقُّ وَأَنتَ أَحكَمُ الحٰكِمينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdxix{قالَ يٰنوحُ إِنَّهُ لَيسَ مِن أَهلِكَ إِنَّهُ عَمَلٌ غَيرُ صٰلِحٍ فَلا تَسـَٔلنِ ما لَيسَ لَكَ بِهِ عِلمٌ إِنّى أَعِظُكَ أَن تَكونَ مِنَ الجٰهِلينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdxx{قالَ رَبِّ إِنّى أَعوذُ بِكَ أَن أَسـَٔلَكَ ما لَيسَ لى بِهِ عِلمٌ وَإِلّا تَغفِر لى وَتَرحَمنى أَكُن مِنَ الخٰسِرينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdxxi{قيلَ يٰنوحُ اهبِط بِسَلٰمٍ مِنّا وَبَرَكٰتٍ عَلَيكَ وَعَلىٰ أُمَمٍ مِمَّن مَعَكَ وَأُمَمٌ سَنُمَتِّعُهُم ثُمَّ يَمَسُّهُم مِنّا عَذابٌ أَليمٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdxxii{تِلكَ مِن أَنباءِ الغَيبِ نوحيها إِلَيكَ ما كُنتَ تَعلَمُها أَنتَ وَلا قَومُكَ مِن قَبلِ هٰذا فَاصبِر إِنَّ العٰقِبَةَ لِلمُتَّقينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdxxiii{وَإِلىٰ عادٍ أَخاهُم هودًا قالَ يٰقَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ إِن أَنتُم إِلّا مُفتَرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdxxiv{يٰقَومِ لا أَسـَٔلُكُم عَلَيهِ أَجرًا إِن أَجرِىَ إِلّا عَلَى الَّذى فَطَرَنى أَفَلا تَعقِلونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdxxv{وَيٰقَومِ استَغفِروا رَبَّكُم ثُمَّ توبوا إِلَيهِ يُرسِلِ السَّماءَ عَلَيكُم مِدرارًا وَيَزِدكُم قُوَّةً إِلىٰ قُوَّتِكُم وَلا تَتَوَلَّوا مُجرِمينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdxxvi{قالوا يٰهودُ ما جِئتَنا بِبَيِّنَةٍ وَما نَحنُ بِتارِكى ءالِهَتِنا عَن قَولِكَ وَما نَحنُ لَكَ بِمُؤمِنينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdxxvii{إِن نَقولُ إِلَّا اعتَرىٰكَ بَعضُ ءالِهَتِنا بِسوءٍ قالَ إِنّى أُشهِدُ اللَّهَ وَاشهَدوا أَنّى بَريءٌ مِمّا تُشرِكونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdxxviii{مِن دونِهِ فَكيدونى جَميعًا ثُمَّ لا تُنظِرونِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdxxix{إِنّى تَوَكَّلتُ عَلَى اللَّهِ رَبّى وَرَبِّكُم ما مِن دابَّةٍ إِلّا هُوَ ءاخِذٌ بِناصِيَتِها إِنَّ رَبّى عَلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdxxx{فَإِن تَوَلَّوا فَقَد أَبلَغتُكُم ما أُرسِلتُ بِهِ إِلَيكُم وَيَستَخلِفُ رَبّى قَومًا غَيرَكُم وَلا تَضُرّونَهُ شَيـًٔا إِنَّ رَبّى عَلىٰ كُلِّ شَيءٍ حَفيظٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdxxxi{وَلَمّا جاءَ أَمرُنا نَجَّينا هودًا وَالَّذينَ ءامَنوا مَعَهُ بِرَحمَةٍ مِنّا وَنَجَّينٰهُم مِن عَذابٍ غَليظٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdxxxii{وَتِلكَ عادٌ جَحَدوا بِـٔايٰتِ رَبِّهِم وَعَصَوا رُسُلَهُ وَاتَّبَعوا أَمرَ كُلِّ جَبّارٍ عَنيدٍ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdxxxiii{وَأُتبِعوا فى هٰذِهِ الدُّنيا لَعنَةً وَيَومَ القِيٰمَةِ أَلا إِنَّ عادًا كَفَروا رَبَّهُم أَلا بُعدًا لِعادٍ قَومِ هودٍ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdxxxiv{وَإِلىٰ ثَمودَ أَخاهُم صٰلِحًا قالَ يٰقَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ هُوَ أَنشَأَكُم مِنَ الأَرضِ وَاستَعمَرَكُم فيها فَاستَغفِروهُ ثُمَّ توبوا إِلَيهِ إِنَّ رَبّى قَريبٌ مُجيبٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdxxxv{قالوا يٰصٰلِحُ قَد كُنتَ فينا مَرجُوًّا قَبلَ هٰذا أَتَنهىٰنا أَن نَعبُدَ ما يَعبُدُ ءاباؤُنا وَإِنَّنا لَفى شَكٍّ مِمّا تَدعونا إِلَيهِ مُريبٍ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdxxxvi{قالَ يٰقَومِ أَرَءَيتُم إِن كُنتُ عَلىٰ بَيِّنَةٍ مِن رَبّى وَءاتىٰنى مِنهُ رَحمَةً فَمَن يَنصُرُنى مِنَ اللَّهِ إِن عَصَيتُهُ فَما تَزيدونَنى غَيرَ تَخسيرٍ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdxxxvii{وَيٰقَومِ هٰذِهِ ناقَةُ اللَّهِ لَكُم ءايَةً فَذَروها تَأكُل فى أَرضِ اللَّهِ وَلا تَمَسّوها بِسوءٍ فَيَأخُذَكُم عَذابٌ قَريبٌ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdxxxviii{فَعَقَروها فَقالَ تَمَتَّعوا فى دارِكُم ثَلٰثَةَ أَيّامٍ ذٰلِكَ وَعدٌ غَيرُ مَكذوبٍ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdxxxix{فَلَمّا جاءَ أَمرُنا نَجَّينا صٰلِحًا وَالَّذينَ ءامَنوا مَعَهُ بِرَحمَةٍ مِنّا وَمِن خِزىِ يَومِئِذٍ إِنَّ رَبَّكَ هُوَ القَوِىُّ العَزيزُ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdxl{وَأَخَذَ الَّذينَ ظَلَمُوا الصَّيحَةُ فَأَصبَحوا فى دِيٰرِهِم جٰثِمينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdxli{كَأَن لَم يَغنَوا فيها أَلا إِنَّ ثَمودَا۟ كَفَروا رَبَّهُم أَلا بُعدًا لِثَمودَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdxlii{وَلَقَد جاءَت رُسُلُنا إِبرٰهيمَ بِالبُشرىٰ قالوا سَلٰمًا قالَ سَلٰمٌ فَما لَبِثَ أَن جاءَ بِعِجلٍ حَنيذٍ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdxliii{فَلَمّا رَءا أَيدِيَهُم لا تَصِلُ إِلَيهِ نَكِرَهُم وَأَوجَسَ مِنهُم خيفَةً قالوا لا تَخَف إِنّا أُرسِلنا إِلىٰ قَومِ لوطٍ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdxliv{وَامرَأَتُهُ قائِمَةٌ فَضَحِكَت فَبَشَّرنٰها بِإِسحٰقَ وَمِن وَراءِ إِسحٰقَ يَعقوبَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdxlv{قالَت يٰوَيلَتىٰ ءَأَلِدُ وَأَنا۠ عَجوزٌ وَهٰذا بَعلى شَيخًا إِنَّ هٰذا لَشَيءٌ عَجيبٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdxlvi{قالوا أَتَعجَبينَ مِن أَمرِ اللَّهِ رَحمَتُ اللَّهِ وَبَرَكٰتُهُ عَلَيكُم أَهلَ البَيتِ إِنَّهُ حَميدٌ مَجيدٌ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdxlvii{فَلَمّا ذَهَبَ عَن إِبرٰهيمَ الرَّوعُ وَجاءَتهُ البُشرىٰ يُجٰدِلُنا فى قَومِ لوطٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdxlviii{إِنَّ إِبرٰهيمَ لَحَليمٌ أَوّٰهٌ مُنيبٌ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdxlix{يٰإِبرٰهيمُ أَعرِض عَن هٰذا إِنَّهُ قَد جاءَ أَمرُ رَبِّكَ وَإِنَّهُم ءاتيهِم عَذابٌ غَيرُ مَردودٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdl{وَلَمّا جاءَت رُسُلُنا لوطًا سيءَ بِهِم وَضاقَ بِهِم ذَرعًا وَقالَ هٰذا يَومٌ عَصيبٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdli{وَجاءَهُ قَومُهُ يُهرَعونَ إِلَيهِ وَمِن قَبلُ كانوا يَعمَلونَ السَّيِّـٔاتِ قالَ يٰقَومِ هٰؤُلاءِ بَناتى هُنَّ أَطهَرُ لَكُم فَاتَّقُوا اللَّهَ وَلا تُخزونِ فى ضَيفى أَلَيسَ مِنكُم رَجُلٌ رَشيدٌ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdlii{قالوا لَقَد عَلِمتَ ما لَنا فى بَناتِكَ مِن حَقٍّ وَإِنَّكَ لَتَعلَمُ ما نُريدُ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdliii{قالَ لَو أَنَّ لى بِكُم قُوَّةً أَو ءاوى إِلىٰ رُكنٍ شَديدٍ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdliv{قالوا يٰلوطُ إِنّا رُسُلُ رَبِّكَ لَن يَصِلوا إِلَيكَ فَأَسرِ بِأَهلِكَ بِقِطعٍ مِنَ الَّيلِ وَلا يَلتَفِت مِنكُم أَحَدٌ إِلَّا امرَأَتَكَ إِنَّهُ مُصيبُها ما أَصابَهُم إِنَّ مَوعِدَهُمُ الصُّبحُ أَلَيسَ الصُّبحُ بِقَريبٍ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdlv{فَلَمّا جاءَ أَمرُنا جَعَلنا عٰلِيَها سافِلَها وَأَمطَرنا عَلَيها حِجارَةً مِن سِجّيلٍ مَنضودٍ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdlvi{مُسَوَّمَةً عِندَ رَبِّكَ وَما هِىَ مِنَ الظّٰلِمينَ بِبَعيدٍ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdlvii{وَإِلىٰ مَديَنَ أَخاهُم شُعَيبًا قالَ يٰقَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ وَلا تَنقُصُوا المِكيالَ وَالميزانَ إِنّى أَرىٰكُم بِخَيرٍ وَإِنّى أَخافُ عَلَيكُم عَذابَ يَومٍ مُحيطٍ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdlviii{وَيٰقَومِ أَوفُوا المِكيالَ وَالميزانَ بِالقِسطِ وَلا تَبخَسُوا النّاسَ أَشياءَهُم وَلا تَعثَوا فِى الأَرضِ مُفسِدينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdlix{بَقِيَّتُ اللَّهِ خَيرٌ لَكُم إِن كُنتُم مُؤمِنينَ وَما أَنا۠ عَلَيكُم بِحَفيظٍ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdlx{قالوا يٰشُعَيبُ أَصَلوٰتُكَ تَأمُرُكَ أَن نَترُكَ ما يَعبُدُ ءاباؤُنا أَو أَن نَفعَلَ فى أَموٰلِنا ما نَشٰؤُا۟ إِنَّكَ لَأَنتَ الحَليمُ الرَّشيدُ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdlxi{قالَ يٰقَومِ أَرَءَيتُم إِن كُنتُ عَلىٰ بَيِّنَةٍ مِن رَبّى وَرَزَقَنى مِنهُ رِزقًا حَسَنًا وَما أُريدُ أَن أُخالِفَكُم إِلىٰ ما أَنهىٰكُم عَنهُ إِن أُريدُ إِلَّا الإِصلٰحَ مَا استَطَعتُ وَما تَوفيقى إِلّا بِاللَّهِ عَلَيهِ تَوَكَّلتُ وَإِلَيهِ أُنيبُ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdlxii{وَيٰقَومِ لا يَجرِمَنَّكُم شِقاقى أَن يُصيبَكُم مِثلُ ما أَصابَ قَومَ نوحٍ أَو قَومَ هودٍ أَو قَومَ صٰلِحٍ وَما قَومُ لوطٍ مِنكُم بِبَعيدٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdlxiii{وَاستَغفِروا رَبَّكُم ثُمَّ توبوا إِلَيهِ إِنَّ رَبّى رَحيمٌ وَدودٌ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdlxiv{قالوا يٰشُعَيبُ ما نَفقَهُ كَثيرًا مِمّا تَقولُ وَإِنّا لَنَرىٰكَ فينا ضَعيفًا وَلَولا رَهطُكَ لَرَجَمنٰكَ وَما أَنتَ عَلَينا بِعَزيزٍ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdlxv{قالَ يٰقَومِ أَرَهطى أَعَزُّ عَلَيكُم مِنَ اللَّهِ وَاتَّخَذتُموهُ وَراءَكُم ظِهرِيًّا إِنَّ رَبّى بِما تَعمَلونَ مُحيطٌ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdlxvi{وَيٰقَومِ اعمَلوا عَلىٰ مَكانَتِكُم إِنّى عٰمِلٌ سَوفَ تَعلَمونَ مَن يَأتيهِ عَذابٌ يُخزيهِ وَمَن هُوَ كٰذِبٌ وَارتَقِبوا إِنّى مَعَكُم رَقيبٌ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdlxvii{وَلَمّا جاءَ أَمرُنا نَجَّينا شُعَيبًا وَالَّذينَ ءامَنوا مَعَهُ بِرَحمَةٍ مِنّا وَأَخَذَتِ الَّذينَ ظَلَمُوا الصَّيحَةُ فَأَصبَحوا فى دِيٰرِهِم جٰثِمينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdlxviii{كَأَن لَم يَغنَوا فيها أَلا بُعدًا لِمَديَنَ كَما بَعِدَت ثَمودُ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdlxix{وَلَقَد أَرسَلنا موسىٰ بِـٔايٰتِنا وَسُلطٰنٍ مُبينٍ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdlxx{إِلىٰ فِرعَونَ وَمَلَإِي۟هِ فَاتَّبَعوا أَمرَ فِرعَونَ وَما أَمرُ فِرعَونَ بِرَشيدٍ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mdlxxi{يَقدُمُ قَومَهُ يَومَ القِيٰمَةِ فَأَورَدَهُمُ النّارَ وَبِئسَ الوِردُ المَورودُ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mdlxxii{وَأُتبِعوا فى هٰذِهِ لَعنَةً وَيَومَ القِيٰمَةِ بِئسَ الرِّفدُ المَرفودُ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mdlxxiii{ذٰلِكَ مِن أَنباءِ القُرىٰ نَقُصُّهُ عَلَيكَ مِنها قائِمٌ وَحَصيدٌ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mdlxxiv{وَما ظَلَمنٰهُم وَلٰكِن ظَلَموا أَنفُسَهُم فَما أَغنَت عَنهُم ءالِهَتُهُمُ الَّتى يَدعونَ مِن دونِ اللَّهِ مِن شَيءٍ لَمّا جاءَ أَمرُ رَبِّكَ وَما زادوهُم غَيرَ تَتبيبٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mdlxxv{وَكَذٰلِكَ أَخذُ رَبِّكَ إِذا أَخَذَ القُرىٰ وَهِىَ ظٰلِمَةٌ إِنَّ أَخذَهُ أَليمٌ شَديدٌ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mdlxxvi{إِنَّ فى ذٰلِكَ لَءايَةً لِمَن خافَ عَذابَ الءاخِرَةِ ذٰلِكَ يَومٌ مَجموعٌ لَهُ النّاسُ وَذٰلِكَ يَومٌ مَشهودٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mdlxxvii{وَما نُؤَخِّرُهُ إِلّا لِأَجَلٍ مَعدودٍ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mdlxxviii{يَومَ يَأتِ لا تَكَلَّمُ نَفسٌ إِلّا بِإِذنِهِ فَمِنهُم شَقِىٌّ وَسَعيدٌ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mdlxxix{فَأَمَّا الَّذينَ شَقوا فَفِى النّارِ لَهُم فيها زَفيرٌ وَشَهيقٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mdlxxx{خٰلِدينَ فيها ما دامَتِ السَّمٰوٰتُ وَالأَرضُ إِلّا ما شاءَ رَبُّكَ إِنَّ رَبَّكَ فَعّالٌ لِما يُريدُ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mdlxxxi{وَأَمَّا الَّذينَ سُعِدوا فَفِى الجَنَّةِ خٰلِدينَ فيها ما دامَتِ السَّمٰوٰتُ وَالأَرضُ إِلّا ما شاءَ رَبُّكَ عَطاءً غَيرَ مَجذوذٍ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mdlxxxii{فَلا تَكُ فى مِريَةٍ مِمّا يَعبُدُ هٰؤُلاءِ ما يَعبُدونَ إِلّا كَما يَعبُدُ ءاباؤُهُم مِن قَبلُ وَإِنّا لَمُوَفّوهُم نَصيبَهُم غَيرَ مَنقوصٍ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mdlxxxiii{وَلَقَد ءاتَينا موسَى الكِتٰبَ فَاختُلِفَ فيهِ وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ لَقُضِىَ بَينَهُم وَإِنَّهُم لَفى شَكٍّ مِنهُ مُريبٍ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mdlxxxiv{وَإِنَّ كُلًّا لَمّا لَيُوَفِّيَنَّهُم رَبُّكَ أَعمٰلَهُم إِنَّهُ بِما يَعمَلونَ خَبيرٌ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mdlxxxv{فَاستَقِم كَما أُمِرتَ وَمَن تابَ مَعَكَ وَلا تَطغَوا إِنَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mdlxxxvi{وَلا تَركَنوا إِلَى الَّذينَ ظَلَموا فَتَمَسَّكُمُ النّارُ وَما لَكُم مِن دونِ اللَّهِ مِن أَولِياءَ ثُمَّ لا تُنصَرونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mdlxxxvii{وَأَقِمِ الصَّلوٰةَ طَرَفَىِ النَّهارِ وَزُلَفًا مِنَ الَّيلِ إِنَّ الحَسَنٰتِ يُذهِبنَ السَّيِّـٔاتِ ذٰلِكَ ذِكرىٰ لِلذّٰكِرينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mdlxxxviii{وَاصبِر فَإِنَّ اللَّهَ لا يُضيعُ أَجرَ المُحسِنينَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mdlxxxix{فَلَولا كانَ مِنَ القُرونِ مِن قَبلِكُم أُولوا بَقِيَّةٍ يَنهَونَ عَنِ الفَسادِ فِى الأَرضِ إِلّا قَليلًا مِمَّن أَنجَينا مِنهُم وَاتَّبَعَ الَّذينَ ظَلَموا ما أُترِفوا فيهِ وَكانوا مُجرِمينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mdxc{وَما كانَ رَبُّكَ لِيُهلِكَ القُرىٰ بِظُلمٍ وَأَهلُها مُصلِحونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mdxci{وَلَو شاءَ رَبُّكَ لَجَعَلَ النّاسَ أُمَّةً وٰحِدَةً وَلا يَزالونَ مُختَلِفينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mdxcii{إِلّا مَن رَحِمَ رَبُّكَ وَلِذٰلِكَ خَلَقَهُم وَتَمَّت كَلِمَةُ رَبِّكَ لَأَملَأَنَّ جَهَنَّمَ مِنَ الجِنَّةِ وَالنّاسِ أَجمَعينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mdxciii{وَكُلًّا نَقُصُّ عَلَيكَ مِن أَنباءِ الرُّسُلِ ما نُثَبِّتُ بِهِ فُؤادَكَ وَجاءَكَ فى هٰذِهِ الحَقُّ وَمَوعِظَةٌ وَذِكرىٰ لِلمُؤمِنينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mdxciv{وَقُل لِلَّذينَ لا يُؤمِنونَ اعمَلوا عَلىٰ مَكانَتِكُم إِنّا عٰمِلونَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mdxcv{وَانتَظِروا إِنّا مُنتَظِرونَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mdxcvi{وَلِلَّهِ غَيبُ السَّمٰوٰتِ وَالأَرضِ وَإِلَيهِ يُرجَعُ الأَمرُ كُلُّهُ فَاعبُدهُ وَتَوَكَّل عَلَيهِ وَما رَبُّكَ بِغٰفِلٍ عَمّا تَعمَلونَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mdxcvii{\basmalah  الر تِلكَ ءايٰتُ الكِتٰبِ المُبينِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdxcviii{إِنّا أَنزَلنٰهُ قُرءٰنًا عَرَبِيًّا لَعَلَّكُم تَعقِلونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdxcix{نَحنُ نَقُصُّ عَلَيكَ أَحسَنَ القَصَصِ بِما أَوحَينا إِلَيكَ هٰذَا القُرءانَ وَإِن كُنتَ مِن قَبلِهِ لَمِنَ الغٰفِلينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdc{إِذ قالَ يوسُفُ لِأَبيهِ يٰأَبَتِ إِنّى رَأَيتُ أَحَدَ عَشَرَ كَوكَبًا وَالشَّمسَ وَالقَمَرَ رَأَيتُهُم لى سٰجِدينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdci{قالَ يٰبُنَىَّ لا تَقصُص رُءياكَ عَلىٰ إِخوَتِكَ فَيَكيدوا لَكَ كَيدًا إِنَّ الشَّيطٰنَ لِلإِنسٰنِ عَدُوٌّ مُبينٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcii{وَكَذٰلِكَ يَجتَبيكَ رَبُّكَ وَيُعَلِّمُكَ مِن تَأويلِ الأَحاديثِ وَيُتِمُّ نِعمَتَهُ عَلَيكَ وَعَلىٰ ءالِ يَعقوبَ كَما أَتَمَّها عَلىٰ أَبَوَيكَ مِن قَبلُ إِبرٰهيمَ وَإِسحٰقَ إِنَّ رَبَّكَ عَليمٌ حَكيمٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdciii{لَقَد كانَ فى يوسُفَ وَإِخوَتِهِ ءايٰتٌ لِلسّائِلينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdciv{إِذ قالوا لَيوسُفُ وَأَخوهُ أَحَبُّ إِلىٰ أَبينا مِنّا وَنَحنُ عُصبَةٌ إِنَّ أَبانا لَفى ضَلٰلٍ مُبينٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcv{اقتُلوا يوسُفَ أَوِ اطرَحوهُ أَرضًا يَخلُ لَكُم وَجهُ أَبيكُم وَتَكونوا مِن بَعدِهِ قَومًا صٰلِحينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcvi{قالَ قائِلٌ مِنهُم لا تَقتُلوا يوسُفَ وَأَلقوهُ فى غَيٰبَتِ الجُبِّ يَلتَقِطهُ بَعضُ السَّيّارَةِ إِن كُنتُم فٰعِلينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcvii{قالوا يٰأَبانا ما لَكَ لا تَأمَ۫نّا عَلىٰ يوسُفَ وَإِنّا لَهُ لَنٰصِحونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcviii{أَرسِلهُ مَعَنا غَدًا يَرتَع وَيَلعَب وَإِنّا لَهُ لَحٰفِظونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcix{قالَ إِنّى لَيَحزُنُنى أَن تَذهَبوا بِهِ وَأَخافُ أَن يَأكُلَهُ الذِّئبُ وَأَنتُم عَنهُ غٰفِلونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcx{قالوا لَئِن أَكَلَهُ الذِّئبُ وَنَحنُ عُصبَةٌ إِنّا إِذًا لَخٰسِرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcxi{فَلَمّا ذَهَبوا بِهِ وَأَجمَعوا أَن يَجعَلوهُ فى غَيٰبَتِ الجُبِّ وَأَوحَينا إِلَيهِ لَتُنَبِّئَنَّهُم بِأَمرِهِم هٰذا وَهُم لا يَشعُرونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcxii{وَجاءو أَباهُم عِشاءً يَبكونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcxiii{قالوا يٰأَبانا إِنّا ذَهَبنا نَستَبِقُ وَتَرَكنا يوسُفَ عِندَ مَتٰعِنا فَأَكَلَهُ الذِّئبُ وَما أَنتَ بِمُؤمِنٍ لَنا وَلَو كُنّا صٰدِقينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcxiv{وَجاءو عَلىٰ قَميصِهِ بِدَمٍ كَذِبٍ قالَ بَل سَوَّلَت لَكُم أَنفُسُكُم أَمرًا فَصَبرٌ جَميلٌ وَاللَّهُ المُستَعانُ عَلىٰ ما تَصِفونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcxv{وَجاءَت سَيّارَةٌ فَأَرسَلوا وارِدَهُم فَأَدلىٰ دَلوَهُ قالَ يٰبُشرىٰ هٰذا غُلٰمٌ وَأَسَرّوهُ بِضٰعَةً وَاللَّهُ عَليمٌ بِما يَعمَلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcxvi{وَشَرَوهُ بِثَمَنٍ بَخسٍ دَرٰهِمَ مَعدودَةٍ وَكانوا فيهِ مِنَ الزّٰهِدينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcxvii{وَقالَ الَّذِى اشتَرىٰهُ مِن مِصرَ لِامرَأَتِهِ أَكرِمى مَثوىٰهُ عَسىٰ أَن يَنفَعَنا أَو نَتَّخِذَهُ وَلَدًا وَكَذٰلِكَ مَكَّنّا لِيوسُفَ فِى الأَرضِ وَلِنُعَلِّمَهُ مِن تَأويلِ الأَحاديثِ وَاللَّهُ غالِبٌ عَلىٰ أَمرِهِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcxviii{وَلَمّا بَلَغَ أَشُدَّهُ ءاتَينٰهُ حُكمًا وَعِلمًا وَكَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcxix{وَرٰوَدَتهُ الَّتى هُوَ فى بَيتِها عَن نَفسِهِ وَغَلَّقَتِ الأَبوٰبَ وَقالَت هَيتَ لَكَ قالَ مَعاذَ اللَّهِ إِنَّهُ رَبّى أَحسَنَ مَثواىَ إِنَّهُ لا يُفلِحُ الظّٰلِمونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcxx{وَلَقَد هَمَّت بِهِ وَهَمَّ بِها لَولا أَن رَءا بُرهٰنَ رَبِّهِ كَذٰلِكَ لِنَصرِفَ عَنهُ السّوءَ وَالفَحشاءَ إِنَّهُ مِن عِبادِنَا المُخلَصينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcxxi{وَاستَبَقَا البابَ وَقَدَّت قَميصَهُ مِن دُبُرٍ وَأَلفَيا سَيِّدَها لَدَا البابِ قالَت ما جَزاءُ مَن أَرادَ بِأَهلِكَ سوءًا إِلّا أَن يُسجَنَ أَو عَذابٌ أَليمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcxxii{قالَ هِىَ رٰوَدَتنى عَن نَفسى وَشَهِدَ شاهِدٌ مِن أَهلِها إِن كانَ قَميصُهُ قُدَّ مِن قُبُلٍ فَصَدَقَت وَهُوَ مِنَ الكٰذِبينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcxxiii{وَإِن كانَ قَميصُهُ قُدَّ مِن دُبُرٍ فَكَذَبَت وَهُوَ مِنَ الصّٰدِقينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcxxiv{فَلَمّا رَءا قَميصَهُ قُدَّ مِن دُبُرٍ قالَ إِنَّهُ مِن كَيدِكُنَّ إِنَّ كَيدَكُنَّ عَظيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcxxv{يوسُفُ أَعرِض عَن هٰذا وَاستَغفِرى لِذَنبِكِ إِنَّكِ كُنتِ مِنَ الخاطِـٔينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcxxvi{وَقالَ نِسوَةٌ فِى المَدينَةِ امرَأَتُ العَزيزِ تُرٰوِدُ فَتىٰها عَن نَفسِهِ قَد شَغَفَها حُبًّا إِنّا لَنَرىٰها فى ضَلٰلٍ مُبينٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcxxvii{فَلَمّا سَمِعَت بِمَكرِهِنَّ أَرسَلَت إِلَيهِنَّ وَأَعتَدَت لَهُنَّ مُتَّكَـًٔا وَءاتَت كُلَّ وٰحِدَةٍ مِنهُنَّ سِكّينًا وَقالَتِ اخرُج عَلَيهِنَّ فَلَمّا رَأَينَهُ أَكبَرنَهُ وَقَطَّعنَ أَيدِيَهُنَّ وَقُلنَ حٰشَ لِلَّهِ ما هٰذا بَشَرًا إِن هٰذا إِلّا مَلَكٌ كَريمٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcxxviii{قالَت فَذٰلِكُنَّ الَّذى لُمتُنَّنى فيهِ وَلَقَد رٰوَدتُهُ عَن نَفسِهِ فَاستَعصَمَ وَلَئِن لَم يَفعَل ما ءامُرُهُ لَيُسجَنَنَّ وَلَيَكونًا مِنَ الصّٰغِرينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcxxix{قالَ رَبِّ السِّجنُ أَحَبُّ إِلَىَّ مِمّا يَدعونَنى إِلَيهِ وَإِلّا تَصرِف عَنّى كَيدَهُنَّ أَصبُ إِلَيهِنَّ وَأَكُن مِنَ الجٰهِلينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcxxx{فَاستَجابَ لَهُ رَبُّهُ فَصَرَفَ عَنهُ كَيدَهُنَّ إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcxxxi{ثُمَّ بَدا لَهُم مِن بَعدِ ما رَأَوُا الءايٰتِ لَيَسجُنُنَّهُ حَتّىٰ حينٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcxxxii{وَدَخَلَ مَعَهُ السِّجنَ فَتَيانِ قالَ أَحَدُهُما إِنّى أَرىٰنى أَعصِرُ خَمرًا وَقالَ الءاخَرُ إِنّى أَرىٰنى أَحمِلُ فَوقَ رَأسى خُبزًا تَأكُلُ الطَّيرُ مِنهُ نَبِّئنا بِتَأويلِهِ إِنّا نَرىٰكَ مِنَ المُحسِنينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcxxxiii{قالَ لا يَأتيكُما طَعامٌ تُرزَقانِهِ إِلّا نَبَّأتُكُما بِتَأويلِهِ قَبلَ أَن يَأتِيَكُما ذٰلِكُما مِمّا عَلَّمَنى رَبّى إِنّى تَرَكتُ مِلَّةَ قَومٍ لا يُؤمِنونَ بِاللَّهِ وَهُم بِالءاخِرَةِ هُم كٰفِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcxxxiv{وَاتَّبَعتُ مِلَّةَ ءاباءى إِبرٰهيمَ وَإِسحٰقَ وَيَعقوبَ ما كانَ لَنا أَن نُشرِكَ بِاللَّهِ مِن شَيءٍ ذٰلِكَ مِن فَضلِ اللَّهِ عَلَينا وَعَلَى النّاسِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَشكُرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcxxxv{يٰصىٰحِبَىِ السِّجنِ ءَأَربابٌ مُتَفَرِّقونَ خَيرٌ أَمِ اللَّهُ الوٰحِدُ القَهّارُ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdcxxxvi{ما تَعبُدونَ مِن دونِهِ إِلّا أَسماءً سَمَّيتُموها أَنتُم وَءاباؤُكُم ما أَنزَلَ اللَّهُ بِها مِن سُلطٰنٍ إِنِ الحُكمُ إِلّا لِلَّهِ أَمَرَ أَلّا تَعبُدوا إِلّا إِيّاهُ ذٰلِكَ الدّينُ القَيِّمُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdcxxxvii{يٰصىٰحِبَىِ السِّجنِ أَمّا أَحَدُكُما فَيَسقى رَبَّهُ خَمرًا وَأَمَّا الءاخَرُ فَيُصلَبُ فَتَأكُلُ الطَّيرُ مِن رَأسِهِ قُضِىَ الأَمرُ الَّذى فيهِ تَستَفتِيانِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdcxxxviii{وَقالَ لِلَّذى ظَنَّ أَنَّهُ ناجٍ مِنهُمَا اذكُرنى عِندَ رَبِّكَ فَأَنسىٰهُ الشَّيطٰنُ ذِكرَ رَبِّهِ فَلَبِثَ فِى السِّجنِ بِضعَ سِنينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdcxxxix{وَقالَ المَلِكُ إِنّى أَرىٰ سَبعَ بَقَرٰتٍ سِمانٍ يَأكُلُهُنَّ سَبعٌ عِجافٌ وَسَبعَ سُنبُلٰتٍ خُضرٍ وَأُخَرَ يابِسٰتٍ يٰأَيُّهَا المَلَأُ أَفتونى فى رُءيٰىَ إِن كُنتُم لِلرُّءيا تَعبُرونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdcxl{قالوا أَضغٰثُ أَحلٰمٍ وَما نَحنُ بِتَأويلِ الأَحلٰمِ بِعٰلِمينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdcxli{وَقالَ الَّذى نَجا مِنهُما وَادَّكَرَ بَعدَ أُمَّةٍ أَنا۠ أُنَبِّئُكُم بِتَأويلِهِ فَأَرسِلونِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdcxlii{يوسُفُ أَيُّهَا الصِّدّيقُ أَفتِنا فى سَبعِ بَقَرٰتٍ سِمانٍ يَأكُلُهُنَّ سَبعٌ عِجافٌ وَسَبعِ سُنبُلٰتٍ خُضرٍ وَأُخَرَ يابِسٰتٍ لَعَلّى أَرجِعُ إِلَى النّاسِ لَعَلَّهُم يَعلَمونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdcxliii{قالَ تَزرَعونَ سَبعَ سِنينَ دَأَبًا فَما حَصَدتُم فَذَروهُ فى سُنبُلِهِ إِلّا قَليلًا مِمّا تَأكُلونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdcxliv{ثُمَّ يَأتى مِن بَعدِ ذٰلِكَ سَبعٌ شِدادٌ يَأكُلنَ ما قَدَّمتُم لَهُنَّ إِلّا قَليلًا مِمّا تُحصِنونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdcxlv{ثُمَّ يَأتى مِن بَعدِ ذٰلِكَ عامٌ فيهِ يُغاثُ النّاسُ وَفيهِ يَعصِرونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdcxlvi{وَقالَ المَلِكُ ائتونى بِهِ فَلَمّا جاءَهُ الرَّسولُ قالَ ارجِع إِلىٰ رَبِّكَ فَسـَٔلهُ ما بالُ النِّسوَةِ الّٰتى قَطَّعنَ أَيدِيَهُنَّ إِنَّ رَبّى بِكَيدِهِنَّ عَليمٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdcxlvii{قالَ ما خَطبُكُنَّ إِذ رٰوَدتُنَّ يوسُفَ عَن نَفسِهِ قُلنَ حٰشَ لِلَّهِ ما عَلِمنا عَلَيهِ مِن سوءٍ قالَتِ امرَأَتُ العَزيزِ الـٰٔنَ حَصحَصَ الحَقُّ أَنا۠ رٰوَدتُهُ عَن نَفسِهِ وَإِنَّهُ لَمِنَ الصّٰدِقينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcxlviii{ذٰلِكَ لِيَعلَمَ أَنّى لَم أَخُنهُ بِالغَيبِ وَأَنَّ اللَّهَ لا يَهدى كَيدَ الخائِنينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdcxlix{وَما أُبَرِّئُ نَفسى إِنَّ النَّفسَ لَأَمّارَةٌ بِالسّوءِ إِلّا ما رَحِمَ رَبّى إِنَّ رَبّى غَفورٌ رَحيمٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdcl{وَقالَ المَلِكُ ائتونى بِهِ أَستَخلِصهُ لِنَفسى فَلَمّا كَلَّمَهُ قالَ إِنَّكَ اليَومَ لَدَينا مَكينٌ أَمينٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdcli{قالَ اجعَلنى عَلىٰ خَزائِنِ الأَرضِ إِنّى حَفيظٌ عَليمٌ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdclii{وَكَذٰلِكَ مَكَّنّا لِيوسُفَ فِى الأَرضِ يَتَبَوَّأُ مِنها حَيثُ يَشاءُ نُصيبُ بِرَحمَتِنا مَن نَشاءُ وَلا نُضيعُ أَجرَ المُحسِنينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdcliii{وَلَأَجرُ الءاخِرَةِ خَيرٌ لِلَّذينَ ءامَنوا وَكانوا يَتَّقونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdcliv{وَجاءَ إِخوَةُ يوسُفَ فَدَخَلوا عَلَيهِ فَعَرَفَهُم وَهُم لَهُ مُنكِرونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdclv{وَلَمّا جَهَّزَهُم بِجَهازِهِم قالَ ائتونى بِأَخٍ لَكُم مِن أَبيكُم أَلا تَرَونَ أَنّى أوفِى الكَيلَ وَأَنا۠ خَيرُ المُنزِلينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdclvi{فَإِن لَم تَأتونى بِهِ فَلا كَيلَ لَكُم عِندى وَلا تَقرَبونِ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdclvii{قالوا سَنُرٰوِدُ عَنهُ أَباهُ وَإِنّا لَفٰعِلونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdclviii{وَقالَ لِفِتيٰنِهِ اجعَلوا بِضٰعَتَهُم فى رِحالِهِم لَعَلَّهُم يَعرِفونَها إِذَا انقَلَبوا إِلىٰ أَهلِهِم لَعَلَّهُم يَرجِعونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdclix{فَلَمّا رَجَعوا إِلىٰ أَبيهِم قالوا يٰأَبانا مُنِعَ مِنَّا الكَيلُ فَأَرسِل مَعَنا أَخانا نَكتَل وَإِنّا لَهُ لَحٰفِظونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdclx{قالَ هَل ءامَنُكُم عَلَيهِ إِلّا كَما أَمِنتُكُم عَلىٰ أَخيهِ مِن قَبلُ فَاللَّهُ خَيرٌ حٰفِظًا وَهُوَ أَرحَمُ الرّٰحِمينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdclxi{وَلَمّا فَتَحوا مَتٰعَهُم وَجَدوا بِضٰعَتَهُم رُدَّت إِلَيهِم قالوا يٰأَبانا ما نَبغى هٰذِهِ بِضٰعَتُنا رُدَّت إِلَينا وَنَميرُ أَهلَنا وَنَحفَظُ أَخانا وَنَزدادُ كَيلَ بَعيرٍ ذٰلِكَ كَيلٌ يَسيرٌ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdclxii{قالَ لَن أُرسِلَهُ مَعَكُم حَتّىٰ تُؤتونِ مَوثِقًا مِنَ اللَّهِ لَتَأتُنَّنى بِهِ إِلّا أَن يُحاطَ بِكُم فَلَمّا ءاتَوهُ مَوثِقَهُم قالَ اللَّهُ عَلىٰ ما نَقولُ وَكيلٌ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdclxiii{وَقالَ يٰبَنِىَّ لا تَدخُلوا مِن بابٍ وٰحِدٍ وَادخُلوا مِن أَبوٰبٍ مُتَفَرِّقَةٍ وَما أُغنى عَنكُم مِنَ اللَّهِ مِن شَيءٍ إِنِ الحُكمُ إِلّا لِلَّهِ عَلَيهِ تَوَكَّلتُ وَعَلَيهِ فَليَتَوَكَّلِ المُتَوَكِّلونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdclxiv{وَلَمّا دَخَلوا مِن حَيثُ أَمَرَهُم أَبوهُم ما كانَ يُغنى عَنهُم مِنَ اللَّهِ مِن شَيءٍ إِلّا حاجَةً فى نَفسِ يَعقوبَ قَضىٰها وَإِنَّهُ لَذو عِلمٍ لِما عَلَّمنٰهُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdclxv{وَلَمّا دَخَلوا عَلىٰ يوسُفَ ءاوىٰ إِلَيهِ أَخاهُ قالَ إِنّى أَنا۠ أَخوكَ فَلا تَبتَئِس بِما كانوا يَعمَلونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdclxvi{فَلَمّا جَهَّزَهُم بِجَهازِهِم جَعَلَ السِّقايَةَ فى رَحلِ أَخيهِ ثُمَّ أَذَّنَ مُؤَذِّنٌ أَيَّتُهَا العيرُ إِنَّكُم لَسٰرِقونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdclxvii{قالوا وَأَقبَلوا عَلَيهِم ماذا تَفقِدونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdclxviii{قالوا نَفقِدُ صُواعَ المَلِكِ وَلِمَن جاءَ بِهِ حِملُ بَعيرٍ وَأَنا۠ بِهِ زَعيمٌ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdclxix{قالوا تَاللَّهِ لَقَد عَلِمتُم ما جِئنا لِنُفسِدَ فِى الأَرضِ وَما كُنّا سٰرِقينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdclxx{قالوا فَما جَزٰؤُهُ إِن كُنتُم كٰذِبينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdclxxi{قالوا جَزٰؤُهُ مَن وُجِدَ فى رَحلِهِ فَهُوَ جَزٰؤُهُ كَذٰلِكَ نَجزِى الظّٰلِمينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdclxxii{فَبَدَأَ بِأَوعِيَتِهِم قَبلَ وِعاءِ أَخيهِ ثُمَّ استَخرَجَها مِن وِعاءِ أَخيهِ كَذٰلِكَ كِدنا لِيوسُفَ ما كانَ لِيَأخُذَ أَخاهُ فى دينِ المَلِكِ إِلّا أَن يَشاءَ اللَّهُ نَرفَعُ دَرَجٰتٍ مَن نَشاءُ وَفَوقَ كُلِّ ذى عِلمٍ عَليمٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdclxxiii{قالوا إِن يَسرِق فَقَد سَرَقَ أَخٌ لَهُ مِن قَبلُ فَأَسَرَّها يوسُفُ فى نَفسِهِ وَلَم يُبدِها لَهُم قالَ أَنتُم شَرٌّ مَكانًا وَاللَّهُ أَعلَمُ بِما تَصِفونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdclxxiv{قالوا يٰأَيُّهَا العَزيزُ إِنَّ لَهُ أَبًا شَيخًا كَبيرًا فَخُذ أَحَدَنا مَكانَهُ إِنّا نَرىٰكَ مِنَ المُحسِنينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdclxxv{قالَ مَعاذَ اللَّهِ أَن نَأخُذَ إِلّا مَن وَجَدنا مَتٰعَنا عِندَهُ إِنّا إِذًا لَظٰلِمونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdclxxvi{فَلَمَّا استَيـَٔسوا مِنهُ خَلَصوا نَجِيًّا قالَ كَبيرُهُم أَلَم تَعلَموا أَنَّ أَباكُم قَد أَخَذَ عَلَيكُم مَوثِقًا مِنَ اللَّهِ وَمِن قَبلُ ما فَرَّطتُم فى يوسُفَ فَلَن أَبرَحَ الأَرضَ حَتّىٰ يَأذَنَ لى أَبى أَو يَحكُمَ اللَّهُ لى وَهُوَ خَيرُ الحٰكِمينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdclxxvii{ارجِعوا إِلىٰ أَبيكُم فَقولوا يٰأَبانا إِنَّ ابنَكَ سَرَقَ وَما شَهِدنا إِلّا بِما عَلِمنا وَما كُنّا لِلغَيبِ حٰفِظينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdclxxviii{وَسـَٔلِ القَريَةَ الَّتى كُنّا فيها وَالعيرَ الَّتى أَقبَلنا فيها وَإِنّا لَصٰدِقونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdclxxix{قالَ بَل سَوَّلَت لَكُم أَنفُسُكُم أَمرًا فَصَبرٌ جَميلٌ عَسَى اللَّهُ أَن يَأتِيَنى بِهِم جَميعًا إِنَّهُ هُوَ العَليمُ الحَكيمُ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdclxxx{وَتَوَلّىٰ عَنهُم وَقالَ يٰأَسَفىٰ عَلىٰ يوسُفَ وَابيَضَّت عَيناهُ مِنَ الحُزنِ فَهُوَ كَظيمٌ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdclxxxi{قالوا تَاللَّهِ تَفتَؤُا۟ تَذكُرُ يوسُفَ حَتّىٰ تَكونَ حَرَضًا أَو تَكونَ مِنَ الهٰلِكينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdclxxxii{قالَ إِنَّما أَشكوا بَثّى وَحُزنى إِلَى اللَّهِ وَأَعلَمُ مِنَ اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdclxxxiii{يٰبَنِىَّ اذهَبوا فَتَحَسَّسوا مِن يوسُفَ وَأَخيهِ وَلا تَا۟يـَٔسوا مِن رَوحِ اللَّهِ إِنَّهُ لا يَا۟يـَٔسُ مِن رَوحِ اللَّهِ إِلَّا القَومُ الكٰفِرونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdclxxxiv{فَلَمّا دَخَلوا عَلَيهِ قالوا يٰأَيُّهَا العَزيزُ مَسَّنا وَأَهلَنَا الضُّرُّ وَجِئنا بِبِضٰعَةٍ مُزجىٰةٍ فَأَوفِ لَنَا الكَيلَ وَتَصَدَّق عَلَينا إِنَّ اللَّهَ يَجزِى المُتَصَدِّقينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdclxxxv{قالَ هَل عَلِمتُم ما فَعَلتُم بِيوسُفَ وَأَخيهِ إِذ أَنتُم جٰهِلونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdclxxxvi{قالوا أَءِنَّكَ لَأَنتَ يوسُفُ قالَ أَنا۠ يوسُفُ وَهٰذا أَخى قَد مَنَّ اللَّهُ عَلَينا إِنَّهُ مَن يَتَّقِ وَيَصبِر فَإِنَّ اللَّهَ لا يُضيعُ أَجرَ المُحسِنينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdclxxxvii{قالوا تَاللَّهِ لَقَد ءاثَرَكَ اللَّهُ عَلَينا وَإِن كُنّا لَخٰطِـٔينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdclxxxviii{قالَ لا تَثريبَ عَلَيكُمُ اليَومَ يَغفِرُ اللَّهُ لَكُم وَهُوَ أَرحَمُ الرّٰحِمينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdclxxxix{اذهَبوا بِقَميصى هٰذا فَأَلقوهُ عَلىٰ وَجهِ أَبى يَأتِ بَصيرًا وَأتونى بِأَهلِكُم أَجمَعينَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdcxc{وَلَمّا فَصَلَتِ العيرُ قالَ أَبوهُم إِنّى لَأَجِدُ ريحَ يوسُفَ لَولا أَن تُفَنِّدونِ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdcxci{قالوا تَاللَّهِ إِنَّكَ لَفى ضَلٰلِكَ القَديمِ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdcxcii{فَلَمّا أَن جاءَ البَشيرُ أَلقىٰهُ عَلىٰ وَجهِهِ فَارتَدَّ بَصيرًا قالَ أَلَم أَقُل لَكُم إِنّى أَعلَمُ مِنَ اللَّهِ ما لا تَعلَمونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdcxciii{قالوا يٰأَبانَا استَغفِر لَنا ذُنوبَنا إِنّا كُنّا خٰطِـٔينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mdcxciv{قالَ سَوفَ أَستَغفِرُ لَكُم رَبّى إِنَّهُ هُوَ الغَفورُ الرَّحيمُ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mdcxcv{فَلَمّا دَخَلوا عَلىٰ يوسُفَ ءاوىٰ إِلَيهِ أَبَوَيهِ وَقالَ ادخُلوا مِصرَ إِن شاءَ اللَّهُ ءامِنينَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mdcxcvi{وَرَفَعَ أَبَوَيهِ عَلَى العَرشِ وَخَرّوا لَهُ سُجَّدًا وَقالَ يٰأَبَتِ هٰذا تَأويلُ رُءيٰىَ مِن قَبلُ قَد جَعَلَها رَبّى حَقًّا وَقَد أَحسَنَ بى إِذ أَخرَجَنى مِنَ السِّجنِ وَجاءَ بِكُم مِنَ البَدوِ مِن بَعدِ أَن نَزَغَ الشَّيطٰنُ بَينى وَبَينَ إِخوَتى إِنَّ رَبّى لَطيفٌ لِما يَشاءُ إِنَّهُ هُوَ العَليمُ الحَكيمُ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mdcxcvii{رَبِّ قَد ءاتَيتَنى مِنَ المُلكِ وَعَلَّمتَنى مِن تَأويلِ الأَحاديثِ فاطِرَ السَّمٰوٰتِ وَالأَرضِ أَنتَ وَلِيّۦ فِى الدُّنيا وَالءاخِرَةِ تَوَفَّنى مُسلِمًا وَأَلحِقنى بِالصّٰلِحينَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mdcxcviii{ذٰلِكَ مِن أَنباءِ الغَيبِ نوحيهِ إِلَيكَ وَما كُنتَ لَدَيهِم إِذ أَجمَعوا أَمرَهُم وَهُم يَمكُرونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mdcxcix{وَما أَكثَرُ النّاسِ وَلَو حَرَصتَ بِمُؤمِنينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mdcc{وَما تَسـَٔلُهُم عَلَيهِ مِن أَجرٍ إِن هُوَ إِلّا ذِكرٌ لِلعٰلَمينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mdcci{وَكَأَيِّن مِن ءايَةٍ فِى السَّمٰوٰتِ وَالأَرضِ يَمُرّونَ عَلَيها وَهُم عَنها مُعرِضونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mdccii{وَما يُؤمِنُ أَكثَرُهُم بِاللَّهِ إِلّا وَهُم مُشرِكونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mdcciii{أَفَأَمِنوا أَن تَأتِيَهُم غٰشِيَةٌ مِن عَذابِ اللَّهِ أَو تَأتِيَهُمُ السّاعَةُ بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mdcciv{قُل هٰذِهِ سَبيلى أَدعوا إِلَى اللَّهِ عَلىٰ بَصيرَةٍ أَنا۠ وَمَنِ اتَّبَعَنى وَسُبحٰنَ اللَّهِ وَما أَنا۠ مِنَ المُشرِكينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mdccv{وَما أَرسَلنا مِن قَبلِكَ إِلّا رِجالًا نوحى إِلَيهِم مِن أَهلِ القُرىٰ أَفَلَم يَسيروا فِى الأَرضِ فَيَنظُروا كَيفَ كانَ عٰقِبَةُ الَّذينَ مِن قَبلِهِم وَلَدارُ الءاخِرَةِ خَيرٌ لِلَّذينَ اتَّقَوا أَفَلا تَعقِلونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mdccvi{حَتّىٰ إِذَا استَيـَٔسَ الرُّسُلُ وَظَنّوا أَنَّهُم قَد كُذِبوا جاءَهُم نَصرُنا فَنُجِّىَ مَن نَشاءُ وَلا يُرَدُّ بَأسُنا عَنِ القَومِ المُجرِمينَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mdccvii{لَقَد كانَ فى قَصَصِهِم عِبرَةٌ لِأُولِى الأَلبٰبِ ما كانَ حَديثًا يُفتَرىٰ وَلٰكِن تَصديقَ الَّذى بَينَ يَدَيهِ وَتَفصيلَ كُلِّ شَيءٍ وَهُدًى وَرَحمَةً لِقَومٍ يُؤمِنونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mdccviii{\basmalah  المر تِلكَ ءايٰتُ الكِتٰبِ وَالَّذى أُنزِلَ إِلَيكَ مِن رَبِّكَ الحَقُّ وَلٰكِنَّ أَكثَرَ النّاسِ لا يُؤمِنونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdccix{اللَّهُ الَّذى رَفَعَ السَّمٰوٰتِ بِغَيرِ عَمَدٍ تَرَونَها ثُمَّ استَوىٰ عَلَى العَرشِ وَسَخَّرَ الشَّمسَ وَالقَمَرَ كُلٌّ يَجرى لِأَجَلٍ مُسَمًّى يُدَبِّرُ الأَمرَ يُفَصِّلُ الءايٰتِ لَعَلَّكُم بِلِقاءِ رَبِّكُم توقِنونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdccx{وَهُوَ الَّذى مَدَّ الأَرضَ وَجَعَلَ فيها رَوٰسِىَ وَأَنهٰرًا وَمِن كُلِّ الثَّمَرٰتِ جَعَلَ فيها زَوجَينِ اثنَينِ يُغشِى الَّيلَ النَّهارَ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdccxi{وَفِى الأَرضِ قِطَعٌ مُتَجٰوِرٰتٌ وَجَنّٰتٌ مِن أَعنٰبٍ وَزَرعٌ وَنَخيلٌ صِنوانٌ وَغَيرُ صِنوانٍ يُسقىٰ بِماءٍ وٰحِدٍ وَنُفَضِّلُ بَعضَها عَلىٰ بَعضٍ فِى الأُكُلِ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَعقِلونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdccxii{وَإِن تَعجَب فَعَجَبٌ قَولُهُم أَءِذا كُنّا تُرٰبًا أَءِنّا لَفى خَلقٍ جَديدٍ أُولٰئِكَ الَّذينَ كَفَروا بِرَبِّهِم وَأُولٰئِكَ الأَغلٰلُ فى أَعناقِهِم وَأُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdccxiii{وَيَستَعجِلونَكَ بِالسَّيِّئَةِ قَبلَ الحَسَنَةِ وَقَد خَلَت مِن قَبلِهِمُ المَثُلٰتُ وَإِنَّ رَبَّكَ لَذو مَغفِرَةٍ لِلنّاسِ عَلىٰ ظُلمِهِم وَإِنَّ رَبَّكَ لَشَديدُ العِقابِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdccxiv{وَيَقولُ الَّذينَ كَفَروا لَولا أُنزِلَ عَلَيهِ ءايَةٌ مِن رَبِّهِ إِنَّما أَنتَ مُنذِرٌ وَلِكُلِّ قَومٍ هادٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdccxv{اللَّهُ يَعلَمُ ما تَحمِلُ كُلُّ أُنثىٰ وَما تَغيضُ الأَرحامُ وَما تَزدادُ وَكُلُّ شَيءٍ عِندَهُ بِمِقدارٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdccxvi{عٰلِمُ الغَيبِ وَالشَّهٰدَةِ الكَبيرُ المُتَعالِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdccxvii{سَواءٌ مِنكُم مَن أَسَرَّ القَولَ وَمَن جَهَرَ بِهِ وَمَن هُوَ مُستَخفٍ بِالَّيلِ وَسارِبٌ بِالنَّهارِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdccxviii{لَهُ مُعَقِّبٰتٌ مِن بَينِ يَدَيهِ وَمِن خَلفِهِ يَحفَظونَهُ مِن أَمرِ اللَّهِ إِنَّ اللَّهَ لا يُغَيِّرُ ما بِقَومٍ حَتّىٰ يُغَيِّروا ما بِأَنفُسِهِم وَإِذا أَرادَ اللَّهُ بِقَومٍ سوءًا فَلا مَرَدَّ لَهُ وَما لَهُم مِن دونِهِ مِن والٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdccxix{هُوَ الَّذى يُريكُمُ البَرقَ خَوفًا وَطَمَعًا وَيُنشِئُ السَّحابَ الثِّقالَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdccxx{وَيُسَبِّحُ الرَّعدُ بِحَمدِهِ وَالمَلٰئِكَةُ مِن خيفَتِهِ وَيُرسِلُ الصَّوٰعِقَ فَيُصيبُ بِها مَن يَشاءُ وَهُم يُجٰدِلونَ فِى اللَّهِ وَهُوَ شَديدُ المِحالِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdccxxi{لَهُ دَعوَةُ الحَقِّ وَالَّذينَ يَدعونَ مِن دونِهِ لا يَستَجيبونَ لَهُم بِشَيءٍ إِلّا كَبٰسِطِ كَفَّيهِ إِلَى الماءِ لِيَبلُغَ فاهُ وَما هُوَ بِبٰلِغِهِ وَما دُعاءُ الكٰفِرينَ إِلّا فى ضَلٰلٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdccxxii{وَلِلَّهِ يَسجُدُ مَن فِى السَّمٰوٰتِ وَالأَرضِ طَوعًا وَكَرهًا وَظِلٰلُهُم بِالغُدُوِّ وَالءاصالِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdccxxiii{قُل مَن رَبُّ السَّمٰوٰتِ وَالأَرضِ قُلِ اللَّهُ قُل أَفَاتَّخَذتُم مِن دونِهِ أَولِياءَ لا يَملِكونَ لِأَنفُسِهِم نَفعًا وَلا ضَرًّا قُل هَل يَستَوِى الأَعمىٰ وَالبَصيرُ أَم هَل تَستَوِى الظُّلُمٰتُ وَالنّورُ أَم جَعَلوا لِلَّهِ شُرَكاءَ خَلَقوا كَخَلقِهِ فَتَشٰبَهَ الخَلقُ عَلَيهِم قُلِ اللَّهُ خٰلِقُ كُلِّ شَيءٍ وَهُوَ الوٰحِدُ القَهّٰرُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdccxxiv{أَنزَلَ مِنَ السَّماءِ ماءً فَسالَت أَودِيَةٌ بِقَدَرِها فَاحتَمَلَ السَّيلُ زَبَدًا رابِيًا وَمِمّا يوقِدونَ عَلَيهِ فِى النّارِ ابتِغاءَ حِليَةٍ أَو مَتٰعٍ زَبَدٌ مِثلُهُ كَذٰلِكَ يَضرِبُ اللَّهُ الحَقَّ وَالبٰطِلَ فَأَمَّا الزَّبَدُ فَيَذهَبُ جُفاءً وَأَمّا ما يَنفَعُ النّاسَ فَيَمكُثُ فِى الأَرضِ كَذٰلِكَ يَضرِبُ اللَّهُ الأَمثالَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdccxxv{لِلَّذينَ استَجابوا لِرَبِّهِمُ الحُسنىٰ وَالَّذينَ لَم يَستَجيبوا لَهُ لَو أَنَّ لَهُم ما فِى الأَرضِ جَميعًا وَمِثلَهُ مَعَهُ لَافتَدَوا بِهِ أُولٰئِكَ لَهُم سوءُ الحِسابِ وَمَأوىٰهُم جَهَنَّمُ وَبِئسَ المِهادُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdccxxvi{أَفَمَن يَعلَمُ أَنَّما أُنزِلَ إِلَيكَ مِن رَبِّكَ الحَقُّ كَمَن هُوَ أَعمىٰ إِنَّما يَتَذَكَّرُ أُولُوا الأَلبٰبِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdccxxvii{الَّذينَ يوفونَ بِعَهدِ اللَّهِ وَلا يَنقُضونَ الميثٰقَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdccxxviii{وَالَّذينَ يَصِلونَ ما أَمَرَ اللَّهُ بِهِ أَن يوصَلَ وَيَخشَونَ رَبَّهُم وَيَخافونَ سوءَ الحِسابِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdccxxix{وَالَّذينَ صَبَرُوا ابتِغاءَ وَجهِ رَبِّهِم وَأَقامُوا الصَّلوٰةَ وَأَنفَقوا مِمّا رَزَقنٰهُم سِرًّا وَعَلانِيَةً وَيَدرَءونَ بِالحَسَنَةِ السَّيِّئَةَ أُولٰئِكَ لَهُم عُقبَى الدّارِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdccxxx{جَنّٰتُ عَدنٍ يَدخُلونَها وَمَن صَلَحَ مِن ءابائِهِم وَأَزوٰجِهِم وَذُرِّيّٰتِهِم وَالمَلٰئِكَةُ يَدخُلونَ عَلَيهِم مِن كُلِّ بابٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdccxxxi{سَلٰمٌ عَلَيكُم بِما صَبَرتُم فَنِعمَ عُقبَى الدّارِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdccxxxii{وَالَّذينَ يَنقُضونَ عَهدَ اللَّهِ مِن بَعدِ ميثٰقِهِ وَيَقطَعونَ ما أَمَرَ اللَّهُ بِهِ أَن يوصَلَ وَيُفسِدونَ فِى الأَرضِ أُولٰئِكَ لَهُمُ اللَّعنَةُ وَلَهُم سوءُ الدّارِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdccxxxiii{اللَّهُ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ وَفَرِحوا بِالحَيوٰةِ الدُّنيا وَمَا الحَيوٰةُ الدُّنيا فِى الءاخِرَةِ إِلّا مَتٰعٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdccxxxiv{وَيَقولُ الَّذينَ كَفَروا لَولا أُنزِلَ عَلَيهِ ءايَةٌ مِن رَبِّهِ قُل إِنَّ اللَّهَ يُضِلُّ مَن يَشاءُ وَيَهدى إِلَيهِ مَن أَنابَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdccxxxv{الَّذينَ ءامَنوا وَتَطمَئِنُّ قُلوبُهُم بِذِكرِ اللَّهِ أَلا بِذِكرِ اللَّهِ تَطمَئِنُّ القُلوبُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdccxxxvi{الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ طوبىٰ لَهُم وَحُسنُ مَـٔابٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdccxxxvii{كَذٰلِكَ أَرسَلنٰكَ فى أُمَّةٍ قَد خَلَت مِن قَبلِها أُمَمٌ لِتَتلُوَا۟ عَلَيهِمُ الَّذى أَوحَينا إِلَيكَ وَهُم يَكفُرونَ بِالرَّحمٰنِ قُل هُوَ رَبّى لا إِلٰهَ إِلّا هُوَ عَلَيهِ تَوَكَّلتُ وَإِلَيهِ مَتابِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdccxxxviii{وَلَو أَنَّ قُرءانًا سُيِّرَت بِهِ الجِبالُ أَو قُطِّعَت بِهِ الأَرضُ أَو كُلِّمَ بِهِ المَوتىٰ بَل لِلَّهِ الأَمرُ جَميعًا أَفَلَم يَا۟يـَٔسِ الَّذينَ ءامَنوا أَن لَو يَشاءُ اللَّهُ لَهَدَى النّاسَ جَميعًا وَلا يَزالُ الَّذينَ كَفَروا تُصيبُهُم بِما صَنَعوا قارِعَةٌ أَو تَحُلُّ قَريبًا مِن دارِهِم حَتّىٰ يَأتِىَ وَعدُ اللَّهِ إِنَّ اللَّهَ لا يُخلِفُ الميعادَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdccxxxix{وَلَقَدِ استُهزِئَ بِرُسُلٍ مِن قَبلِكَ فَأَملَيتُ لِلَّذينَ كَفَروا ثُمَّ أَخَذتُهُم فَكَيفَ كانَ عِقابِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdccxl{أَفَمَن هُوَ قائِمٌ عَلىٰ كُلِّ نَفسٍ بِما كَسَبَت وَجَعَلوا لِلَّهِ شُرَكاءَ قُل سَمّوهُم أَم تُنَبِّـٔونَهُ بِما لا يَعلَمُ فِى الأَرضِ أَم بِظٰهِرٍ مِنَ القَولِ بَل زُيِّنَ لِلَّذينَ كَفَروا مَكرُهُم وَصُدّوا عَنِ السَّبيلِ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن هادٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdccxli{لَهُم عَذابٌ فِى الحَيوٰةِ الدُّنيا وَلَعَذابُ الءاخِرَةِ أَشَقُّ وَما لَهُم مِنَ اللَّهِ مِن واقٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdccxlii{مَثَلُ الجَنَّةِ الَّتى وُعِدَ المُتَّقونَ تَجرى مِن تَحتِهَا الأَنهٰرُ أُكُلُها دائِمٌ وَظِلُّها تِلكَ عُقبَى الَّذينَ اتَّقَوا وَعُقبَى الكٰفِرينَ النّارُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdccxliii{وَالَّذينَ ءاتَينٰهُمُ الكِتٰبَ يَفرَحونَ بِما أُنزِلَ إِلَيكَ وَمِنَ الأَحزابِ مَن يُنكِرُ بَعضَهُ قُل إِنَّما أُمِرتُ أَن أَعبُدَ اللَّهَ وَلا أُشرِكَ بِهِ إِلَيهِ أَدعوا وَإِلَيهِ مَـٔابِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdccxliv{وَكَذٰلِكَ أَنزَلنٰهُ حُكمًا عَرَبِيًّا وَلَئِنِ اتَّبَعتَ أَهواءَهُم بَعدَما جاءَكَ مِنَ العِلمِ ما لَكَ مِنَ اللَّهِ مِن وَلِىٍّ وَلا واقٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdccxlv{وَلَقَد أَرسَلنا رُسُلًا مِن قَبلِكَ وَجَعَلنا لَهُم أَزوٰجًا وَذُرِّيَّةً وَما كانَ لِرَسولٍ أَن يَأتِىَ بِـٔايَةٍ إِلّا بِإِذنِ اللَّهِ لِكُلِّ أَجَلٍ كِتابٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdccxlvi{يَمحُوا اللَّهُ ما يَشاءُ وَيُثبِتُ وَعِندَهُ أُمُّ الكِتٰبِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdccxlvii{وَإِن ما نُرِيَنَّكَ بَعضَ الَّذى نَعِدُهُم أَو نَتَوَفَّيَنَّكَ فَإِنَّما عَلَيكَ البَلٰغُ وَعَلَينَا الحِسابُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdccxlviii{أَوَلَم يَرَوا أَنّا نَأتِى الأَرضَ نَنقُصُها مِن أَطرافِها وَاللَّهُ يَحكُمُ لا مُعَقِّبَ لِحُكمِهِ وَهُوَ سَريعُ الحِسابِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdccxlix{وَقَد مَكَرَ الَّذينَ مِن قَبلِهِم فَلِلَّهِ المَكرُ جَميعًا يَعلَمُ ما تَكسِبُ كُلُّ نَفسٍ وَسَيَعلَمُ الكُفّٰرُ لِمَن عُقبَى الدّارِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdccl{وَيَقولُ الَّذينَ كَفَروا لَستَ مُرسَلًا قُل كَفىٰ بِاللَّهِ شَهيدًا بَينى وَبَينَكُم وَمَن عِندَهُ عِلمُ الكِتٰبِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdccli{\basmalah  الر كِتٰبٌ أَنزَلنٰهُ إِلَيكَ لِتُخرِجَ النّاسَ مِنَ الظُّلُمٰتِ إِلَى النّورِ بِإِذنِ رَبِّهِم إِلىٰ صِرٰطِ العَزيزِ الحَميدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdcclii{اللَّهِ الَّذى لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَوَيلٌ لِلكٰفِرينَ مِن عَذابٍ شَديدٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdccliii{الَّذينَ يَستَحِبّونَ الحَيوٰةَ الدُّنيا عَلَى الءاخِرَةِ وَيَصُدّونَ عَن سَبيلِ اللَّهِ وَيَبغونَها عِوَجًا أُولٰئِكَ فى ضَلٰلٍ بَعيدٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdccliv{وَما أَرسَلنا مِن رَسولٍ إِلّا بِلِسانِ قَومِهِ لِيُبَيِّنَ لَهُم فَيُضِلُّ اللَّهُ مَن يَشاءُ وَيَهدى مَن يَشاءُ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdcclv{وَلَقَد أَرسَلنا موسىٰ بِـٔايٰتِنا أَن أَخرِج قَومَكَ مِنَ الظُّلُمٰتِ إِلَى النّورِ وَذَكِّرهُم بِأَيّىٰمِ اللَّهِ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِكُلِّ صَبّارٍ شَكورٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcclvi{وَإِذ قالَ موسىٰ لِقَومِهِ اذكُروا نِعمَةَ اللَّهِ عَلَيكُم إِذ أَنجىٰكُم مِن ءالِ فِرعَونَ يَسومونَكُم سوءَ العَذابِ وَيُذَبِّحونَ أَبناءَكُم وَيَستَحيونَ نِساءَكُم وَفى ذٰلِكُم بَلاءٌ مِن رَبِّكُم عَظيمٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdcclvii{وَإِذ تَأَذَّنَ رَبُّكُم لَئِن شَكَرتُم لَأَزيدَنَّكُم وَلَئِن كَفَرتُم إِنَّ عَذابى لَشَديدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdcclviii{وَقالَ موسىٰ إِن تَكفُروا أَنتُم وَمَن فِى الأَرضِ جَميعًا فَإِنَّ اللَّهَ لَغَنِىٌّ حَميدٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcclix{أَلَم يَأتِكُم نَبَؤُا۟ الَّذينَ مِن قَبلِكُم قَومِ نوحٍ وَعادٍ وَثَمودَ وَالَّذينَ مِن بَعدِهِم لا يَعلَمُهُم إِلَّا اللَّهُ جاءَتهُم رُسُلُهُم بِالبَيِّنٰتِ فَرَدّوا أَيدِيَهُم فى أَفوٰهِهِم وَقالوا إِنّا كَفَرنا بِما أُرسِلتُم بِهِ وَإِنّا لَفى شَكٍّ مِمّا تَدعونَنا إِلَيهِ مُريبٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcclx{قالَت رُسُلُهُم أَفِى اللَّهِ شَكٌّ فاطِرِ السَّمٰوٰتِ وَالأَرضِ يَدعوكُم لِيَغفِرَ لَكُم مِن ذُنوبِكُم وَيُؤَخِّرَكُم إِلىٰ أَجَلٍ مُسَمًّى قالوا إِن أَنتُم إِلّا بَشَرٌ مِثلُنا تُريدونَ أَن تَصُدّونا عَمّا كانَ يَعبُدُ ءاباؤُنا فَأتونا بِسُلطٰنٍ مُبينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcclxi{قالَت لَهُم رُسُلُهُم إِن نَحنُ إِلّا بَشَرٌ مِثلُكُم وَلٰكِنَّ اللَّهَ يَمُنُّ عَلىٰ مَن يَشاءُ مِن عِبادِهِ وَما كانَ لَنا أَن نَأتِيَكُم بِسُلطٰنٍ إِلّا بِإِذنِ اللَّهِ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcclxii{وَما لَنا أَلّا نَتَوَكَّلَ عَلَى اللَّهِ وَقَد هَدىٰنا سُبُلَنا وَلَنَصبِرَنَّ عَلىٰ ما ءاذَيتُمونا وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُتَوَكِّلونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcclxiii{وَقالَ الَّذينَ كَفَروا لِرُسُلِهِم لَنُخرِجَنَّكُم مِن أَرضِنا أَو لَتَعودُنَّ فى مِلَّتِنا فَأَوحىٰ إِلَيهِم رَبُّهُم لَنُهلِكَنَّ الظّٰلِمينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcclxiv{وَلَنُسكِنَنَّكُمُ الأَرضَ مِن بَعدِهِم ذٰلِكَ لِمَن خافَ مَقامى وَخافَ وَعيدِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcclxv{وَاستَفتَحوا وَخابَ كُلُّ جَبّارٍ عَنيدٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcclxvi{مِن وَرائِهِ جَهَنَّمُ وَيُسقىٰ مِن ماءٍ صَديدٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcclxvii{يَتَجَرَّعُهُ وَلا يَكادُ يُسيغُهُ وَيَأتيهِ المَوتُ مِن كُلِّ مَكانٍ وَما هُوَ بِمَيِّتٍ وَمِن وَرائِهِ عَذابٌ غَليظٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcclxviii{مَثَلُ الَّذينَ كَفَروا بِرَبِّهِم أَعمٰلُهُم كَرَمادٍ اشتَدَّت بِهِ الرّيحُ فى يَومٍ عاصِفٍ لا يَقدِرونَ مِمّا كَسَبوا عَلىٰ شَيءٍ ذٰلِكَ هُوَ الضَّلٰلُ البَعيدُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcclxix{أَلَم تَرَ أَنَّ اللَّهَ خَلَقَ السَّمٰوٰتِ وَالأَرضَ بِالحَقِّ إِن يَشَأ يُذهِبكُم وَيَأتِ بِخَلقٍ جَديدٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcclxx{وَما ذٰلِكَ عَلَى اللَّهِ بِعَزيزٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcclxxi{وَبَرَزوا لِلَّهِ جَميعًا فَقالَ الضُّعَفٰؤُا۟ لِلَّذينَ استَكبَروا إِنّا كُنّا لَكُم تَبَعًا فَهَل أَنتُم مُغنونَ عَنّا مِن عَذابِ اللَّهِ مِن شَيءٍ قالوا لَو هَدىٰنَا اللَّهُ لَهَدَينٰكُم سَواءٌ عَلَينا أَجَزِعنا أَم صَبَرنا ما لَنا مِن مَحيصٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcclxxii{وَقالَ الشَّيطٰنُ لَمّا قُضِىَ الأَمرُ إِنَّ اللَّهَ وَعَدَكُم وَعدَ الحَقِّ وَوَعَدتُكُم فَأَخلَفتُكُم وَما كانَ لِىَ عَلَيكُم مِن سُلطٰنٍ إِلّا أَن دَعَوتُكُم فَاستَجَبتُم لى فَلا تَلومونى وَلوموا أَنفُسَكُم ما أَنا۠ بِمُصرِخِكُم وَما أَنتُم بِمُصرِخِىَّ إِنّى كَفَرتُ بِما أَشرَكتُمونِ مِن قَبلُ إِنَّ الظّٰلِمينَ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcclxxiii{وَأُدخِلَ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها بِإِذنِ رَبِّهِم تَحِيَّتُهُم فيها سَلٰمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcclxxiv{أَلَم تَرَ كَيفَ ضَرَبَ اللَّهُ مَثَلًا كَلِمَةً طَيِّبَةً كَشَجَرَةٍ طَيِّبَةٍ أَصلُها ثابِتٌ وَفَرعُها فِى السَّماءِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcclxxv{تُؤتى أُكُلَها كُلَّ حينٍ بِإِذنِ رَبِّها وَيَضرِبُ اللَّهُ الأَمثالَ لِلنّاسِ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcclxxvi{وَمَثَلُ كَلِمَةٍ خَبيثَةٍ كَشَجَرَةٍ خَبيثَةٍ اجتُثَّت مِن فَوقِ الأَرضِ ما لَها مِن قَرارٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcclxxvii{يُثَبِّتُ اللَّهُ الَّذينَ ءامَنوا بِالقَولِ الثّابِتِ فِى الحَيوٰةِ الدُّنيا وَفِى الءاخِرَةِ وَيُضِلُّ اللَّهُ الظّٰلِمينَ وَيَفعَلُ اللَّهُ ما يَشاءُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcclxxviii{أَلَم تَرَ إِلَى الَّذينَ بَدَّلوا نِعمَتَ اللَّهِ كُفرًا وَأَحَلّوا قَومَهُم دارَ البَوارِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcclxxix{جَهَنَّمَ يَصلَونَها وَبِئسَ القَرارُ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcclxxx{وَجَعَلوا لِلَّهِ أَندادًا لِيُضِلّوا عَن سَبيلِهِ قُل تَمَتَّعوا فَإِنَّ مَصيرَكُم إِلَى النّارِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcclxxxi{قُل لِعِبادِىَ الَّذينَ ءامَنوا يُقيمُوا الصَّلوٰةَ وَيُنفِقوا مِمّا رَزَقنٰهُم سِرًّا وَعَلانِيَةً مِن قَبلِ أَن يَأتِىَ يَومٌ لا بَيعٌ فيهِ وَلا خِلٰلٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcclxxxii{اللَّهُ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ وَأَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجَ بِهِ مِنَ الثَّمَرٰتِ رِزقًا لَكُم وَسَخَّرَ لَكُمُ الفُلكَ لِتَجرِىَ فِى البَحرِ بِأَمرِهِ وَسَخَّرَ لَكُمُ الأَنهٰرَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcclxxxiii{وَسَخَّرَ لَكُمُ الشَّمسَ وَالقَمَرَ دائِبَينِ وَسَخَّرَ لَكُمُ الَّيلَ وَالنَّهارَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcclxxxiv{وَءاتىٰكُم مِن كُلِّ ما سَأَلتُموهُ وَإِن تَعُدّوا نِعمَتَ اللَّهِ لا تُحصوها إِنَّ الإِنسٰنَ لَظَلومٌ كَفّارٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcclxxxv{وَإِذ قالَ إِبرٰهيمُ رَبِّ اجعَل هٰذَا البَلَدَ ءامِنًا وَاجنُبنى وَبَنِىَّ أَن نَعبُدَ الأَصنامَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcclxxxvi{رَبِّ إِنَّهُنَّ أَضلَلنَ كَثيرًا مِنَ النّاسِ فَمَن تَبِعَنى فَإِنَّهُ مِنّى وَمَن عَصانى فَإِنَّكَ غَفورٌ رَحيمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcclxxxvii{رَبَّنا إِنّى أَسكَنتُ مِن ذُرِّيَّتى بِوادٍ غَيرِ ذى زَرعٍ عِندَ بَيتِكَ المُحَرَّمِ رَبَّنا لِيُقيمُوا الصَّلوٰةَ فَاجعَل أَفـِٔدَةً مِنَ النّاسِ تَهوى إِلَيهِم وَارزُقهُم مِنَ الثَّمَرٰتِ لَعَلَّهُم يَشكُرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcclxxxviii{رَبَّنا إِنَّكَ تَعلَمُ ما نُخفى وَما نُعلِنُ وَما يَخفىٰ عَلَى اللَّهِ مِن شَيءٍ فِى الأَرضِ وَلا فِى السَّماءِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcclxxxix{الحَمدُ لِلَّهِ الَّذى وَهَبَ لى عَلَى الكِبَرِ إِسمٰعيلَ وَإِسحٰقَ إِنَّ رَبّى لَسَميعُ الدُّعاءِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdccxc{رَبِّ اجعَلنى مُقيمَ الصَّلوٰةِ وَمِن ذُرِّيَّتى رَبَّنا وَتَقَبَّل دُعاءِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdccxci{رَبَّنَا اغفِر لى وَلِوٰلِدَىَّ وَلِلمُؤمِنينَ يَومَ يَقومُ الحِسابُ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdccxcii{وَلا تَحسَبَنَّ اللَّهَ غٰفِلًا عَمّا يَعمَلُ الظّٰلِمونَ إِنَّما يُؤَخِّرُهُم لِيَومٍ تَشخَصُ فيهِ الأَبصٰرُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdccxciii{مُهطِعينَ مُقنِعى رُءوسِهِم لا يَرتَدُّ إِلَيهِم طَرفُهُم وَأَفـِٔدَتُهُم هَواءٌ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdccxciv{وَأَنذِرِ النّاسَ يَومَ يَأتيهِمُ العَذابُ فَيَقولُ الَّذينَ ظَلَموا رَبَّنا أَخِّرنا إِلىٰ أَجَلٍ قَريبٍ نُجِب دَعوَتَكَ وَنَتَّبِعِ الرُّسُلَ أَوَلَم تَكونوا أَقسَمتُم مِن قَبلُ ما لَكُم مِن زَوالٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdccxcv{وَسَكَنتُم فى مَسٰكِنِ الَّذينَ ظَلَموا أَنفُسَهُم وَتَبَيَّنَ لَكُم كَيفَ فَعَلنا بِهِم وَضَرَبنا لَكُمُ الأَمثالَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdccxcvi{وَقَد مَكَروا مَكرَهُم وَعِندَ اللَّهِ مَكرُهُم وَإِن كانَ مَكرُهُم لِتَزولَ مِنهُ الجِبالُ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdccxcvii{فَلا تَحسَبَنَّ اللَّهَ مُخلِفَ وَعدِهِ رُسُلَهُ إِنَّ اللَّهَ عَزيزٌ ذُو انتِقامٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdccxcviii{يَومَ تُبَدَّلُ الأَرضُ غَيرَ الأَرضِ وَالسَّمٰوٰتُ وَبَرَزوا لِلَّهِ الوٰحِدِ القَهّارِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdccxcix{وَتَرَى المُجرِمينَ يَومَئِذٍ مُقَرَّنينَ فِى الأَصفادِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdccc{سَرابيلُهُم مِن قَطِرانٍ وَتَغشىٰ وُجوهَهُمُ النّارُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdccci{لِيَجزِىَ اللَّهُ كُلَّ نَفسٍ ما كَسَبَت إِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcccii{هٰذا بَلٰغٌ لِلنّاسِ وَلِيُنذَروا بِهِ وَلِيَعلَموا أَنَّما هُوَ إِلٰهٌ وٰحِدٌ وَلِيَذَّكَّرَ أُولُوا الأَلبٰبِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdccciii{\basmalah  الر تِلكَ ءايٰتُ الكِتٰبِ وَقُرءانٍ مُبينٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mdccciv{رُبَما يَوَدُّ الَّذينَ كَفَروا لَو كانوا مُسلِمينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mdcccv{ذَرهُم يَأكُلوا وَيَتَمَتَّعوا وَيُلهِهِمُ الأَمَلُ فَسَوفَ يَعلَمونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mdcccvi{وَما أَهلَكنا مِن قَريَةٍ إِلّا وَلَها كِتابٌ مَعلومٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mdcccvii{ما تَسبِقُ مِن أُمَّةٍ أَجَلَها وَما يَستَـٔخِرونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mdcccviii{وَقالوا يٰأَيُّهَا الَّذى نُزِّلَ عَلَيهِ الذِّكرُ إِنَّكَ لَمَجنونٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mdcccix{لَو ما تَأتينا بِالمَلٰئِكَةِ إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mdcccx{ما نُنَزِّلُ المَلٰئِكَةَ إِلّا بِالحَقِّ وَما كانوا إِذًا مُنظَرينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mdcccxi{إِنّا نَحنُ نَزَّلنَا الذِّكرَ وَإِنّا لَهُ لَحٰفِظونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mdcccxii{وَلَقَد أَرسَلنا مِن قَبلِكَ فى شِيَعِ الأَوَّلينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mdcccxiii{وَما يَأتيهِم مِن رَسولٍ إِلّا كانوا بِهِ يَستَهزِءونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mdcccxiv{كَذٰلِكَ نَسلُكُهُ فى قُلوبِ المُجرِمينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mdcccxv{لا يُؤمِنونَ بِهِ وَقَد خَلَت سُنَّةُ الأَوَّلينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mdcccxvi{وَلَو فَتَحنا عَلَيهِم بابًا مِنَ السَّماءِ فَظَلّوا فيهِ يَعرُجونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mdcccxvii{لَقالوا إِنَّما سُكِّرَت أَبصٰرُنا بَل نَحنُ قَومٌ مَسحورونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mdcccxviii{وَلَقَد جَعَلنا فِى السَّماءِ بُروجًا وَزَيَّنّٰها لِلنّٰظِرينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mdcccxix{وَحَفِظنٰها مِن كُلِّ شَيطٰنٍ رَجيمٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mdcccxx{إِلّا مَنِ استَرَقَ السَّمعَ فَأَتبَعَهُ شِهابٌ مُبينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mdcccxxi{وَالأَرضَ مَدَدنٰها وَأَلقَينا فيها رَوٰسِىَ وَأَنبَتنا فيها مِن كُلِّ شَيءٍ مَوزونٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mdcccxxii{وَجَعَلنا لَكُم فيها مَعٰيِشَ وَمَن لَستُم لَهُ بِرٰزِقينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mdcccxxiii{وَإِن مِن شَيءٍ إِلّا عِندَنا خَزائِنُهُ وَما نُنَزِّلُهُ إِلّا بِقَدَرٍ مَعلومٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mdcccxxiv{وَأَرسَلنَا الرِّيٰحَ لَوٰقِحَ فَأَنزَلنا مِنَ السَّماءِ ماءً فَأَسقَينٰكُموهُ وَما أَنتُم لَهُ بِخٰزِنينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mdcccxxv{وَإِنّا لَنَحنُ نُحيۦ وَنُميتُ وَنَحنُ الوٰرِثونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mdcccxxvi{وَلَقَد عَلِمنَا المُستَقدِمينَ مِنكُم وَلَقَد عَلِمنَا المُستَـٔخِرينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mdcccxxvii{وَإِنَّ رَبَّكَ هُوَ يَحشُرُهُم إِنَّهُ حَكيمٌ عَليمٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mdcccxxviii{وَلَقَد خَلَقنَا الإِنسٰنَ مِن صَلصٰلٍ مِن حَمَإٍ مَسنونٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mdcccxxix{وَالجانَّ خَلَقنٰهُ مِن قَبلُ مِن نارِ السَّمومِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mdcccxxx{وَإِذ قالَ رَبُّكَ لِلمَلٰئِكَةِ إِنّى خٰلِقٌ بَشَرًا مِن صَلصٰلٍ مِن حَمَإٍ مَسنونٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mdcccxxxi{فَإِذا سَوَّيتُهُ وَنَفَختُ فيهِ مِن روحى فَقَعوا لَهُ سٰجِدينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mdcccxxxii{فَسَجَدَ المَلٰئِكَةُ كُلُّهُم أَجمَعونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mdcccxxxiii{إِلّا إِبليسَ أَبىٰ أَن يَكونَ مَعَ السّٰجِدينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mdcccxxxiv{قالَ يٰإِبليسُ ما لَكَ أَلّا تَكونَ مَعَ السّٰجِدينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mdcccxxxv{قالَ لَم أَكُن لِأَسجُدَ لِبَشَرٍ خَلَقتَهُ مِن صَلصٰلٍ مِن حَمَإٍ مَسنونٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mdcccxxxvi{قالَ فَاخرُج مِنها فَإِنَّكَ رَجيمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mdcccxxxvii{وَإِنَّ عَلَيكَ اللَّعنَةَ إِلىٰ يَومِ الدّينِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mdcccxxxviii{قالَ رَبِّ فَأَنظِرنى إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mdcccxxxix{قالَ فَإِنَّكَ مِنَ المُنظَرينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mdcccxl{إِلىٰ يَومِ الوَقتِ المَعلومِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mdcccxli{قالَ رَبِّ بِما أَغوَيتَنى لَأُزَيِّنَنَّ لَهُم فِى الأَرضِ وَلَأُغوِيَنَّهُم أَجمَعينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mdcccxlii{إِلّا عِبادَكَ مِنهُمُ المُخلَصينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mdcccxliii{قالَ هٰذا صِرٰطٌ عَلَىَّ مُستَقيمٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mdcccxliv{إِنَّ عِبادى لَيسَ لَكَ عَلَيهِم سُلطٰنٌ إِلّا مَنِ اتَّبَعَكَ مِنَ الغاوينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mdcccxlv{وَإِنَّ جَهَنَّمَ لَمَوعِدُهُم أَجمَعينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mdcccxlvi{لَها سَبعَةُ أَبوٰبٍ لِكُلِّ بابٍ مِنهُم جُزءٌ مَقسومٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mdcccxlvii{إِنَّ المُتَّقينَ فى جَنّٰتٍ وَعُيونٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mdcccxlviii{ادخُلوها بِسَلٰمٍ ءامِنينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mdcccxlix{وَنَزَعنا ما فى صُدورِهِم مِن غِلٍّ إِخوٰنًا عَلىٰ سُرُرٍ مُتَقٰبِلينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mdcccl{لا يَمَسُّهُم فيها نَصَبٌ وَما هُم مِنها بِمُخرَجينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mdcccli{نَبِّئ عِبادى أَنّى أَنَا الغَفورُ الرَّحيمُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mdccclii{وَأَنَّ عَذابى هُوَ العَذابُ الأَليمُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mdcccliii{وَنَبِّئهُم عَن ضَيفِ إِبرٰهيمَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mdcccliv{إِذ دَخَلوا عَلَيهِ فَقالوا سَلٰمًا قالَ إِنّا مِنكُم وَجِلونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mdccclv{قالوا لا تَوجَل إِنّا نُبَشِّرُكَ بِغُلٰمٍ عَليمٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mdccclvi{قالَ أَبَشَّرتُمونى عَلىٰ أَن مَسَّنِىَ الكِبَرُ فَبِمَ تُبَشِّرونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mdccclvii{قالوا بَشَّرنٰكَ بِالحَقِّ فَلا تَكُن مِنَ القٰنِطينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mdccclviii{قالَ وَمَن يَقنَطُ مِن رَحمَةِ رَبِّهِ إِلَّا الضّالّونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mdccclix{قالَ فَما خَطبُكُم أَيُّهَا المُرسَلونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mdccclx{قالوا إِنّا أُرسِلنا إِلىٰ قَومٍ مُجرِمينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mdccclxi{إِلّا ءالَ لوطٍ إِنّا لَمُنَجّوهُم أَجمَعينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mdccclxii{إِلَّا امرَأَتَهُ قَدَّرنا إِنَّها لَمِنَ الغٰبِرينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mdccclxiii{فَلَمّا جاءَ ءالَ لوطٍ المُرسَلونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mdccclxiv{قالَ إِنَّكُم قَومٌ مُنكَرونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mdccclxv{قالوا بَل جِئنٰكَ بِما كانوا فيهِ يَمتَرونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mdccclxvi{وَأَتَينٰكَ بِالحَقِّ وَإِنّا لَصٰدِقونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mdccclxvii{فَأَسرِ بِأَهلِكَ بِقِطعٍ مِنَ الَّيلِ وَاتَّبِع أَدبٰرَهُم وَلا يَلتَفِت مِنكُم أَحَدٌ وَامضوا حَيثُ تُؤمَرونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mdccclxviii{وَقَضَينا إِلَيهِ ذٰلِكَ الأَمرَ أَنَّ دابِرَ هٰؤُلاءِ مَقطوعٌ مُصبِحينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mdccclxix{وَجاءَ أَهلُ المَدينَةِ يَستَبشِرونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mdccclxx{قالَ إِنَّ هٰؤُلاءِ ضَيفى فَلا تَفضَحونِ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mdccclxxi{وَاتَّقُوا اللَّهَ وَلا تُخزونِ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mdccclxxii{قالوا أَوَلَم نَنهَكَ عَنِ العٰلَمينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mdccclxxiii{قالَ هٰؤُلاءِ بَناتى إِن كُنتُم فٰعِلينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mdccclxxiv{لَعَمرُكَ إِنَّهُم لَفى سَكرَتِهِم يَعمَهونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mdccclxxv{فَأَخَذَتهُمُ الصَّيحَةُ مُشرِقينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mdccclxxvi{فَجَعَلنا عٰلِيَها سافِلَها وَأَمطَرنا عَلَيهِم حِجارَةً مِن سِجّيلٍ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mdccclxxvii{إِنَّ فى ذٰلِكَ لَءايٰتٍ لِلمُتَوَسِّمينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mdccclxxviii{وَإِنَّها لَبِسَبيلٍ مُقيمٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mdccclxxix{إِنَّ فى ذٰلِكَ لَءايَةً لِلمُؤمِنينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mdccclxxx{وَإِن كانَ أَصحٰبُ الأَيكَةِ لَظٰلِمينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mdccclxxxi{فَانتَقَمنا مِنهُم وَإِنَّهُما لَبِإِمامٍ مُبينٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mdccclxxxii{وَلَقَد كَذَّبَ أَصحٰبُ الحِجرِ المُرسَلينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mdccclxxxiii{وَءاتَينٰهُم ءايٰتِنا فَكانوا عَنها مُعرِضينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mdccclxxxiv{وَكانوا يَنحِتونَ مِنَ الجِبالِ بُيوتًا ءامِنينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mdccclxxxv{فَأَخَذَتهُمُ الصَّيحَةُ مُصبِحينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mdccclxxxvi{فَما أَغنىٰ عَنهُم ما كانوا يَكسِبونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mdccclxxxvii{وَما خَلَقنَا السَّمٰوٰتِ وَالأَرضَ وَما بَينَهُما إِلّا بِالحَقِّ وَإِنَّ السّاعَةَ لَءاتِيَةٌ فَاصفَحِ الصَّفحَ الجَميلَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mdccclxxxviii{إِنَّ رَبَّكَ هُوَ الخَلّٰقُ العَليمُ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mdccclxxxix{وَلَقَد ءاتَينٰكَ سَبعًا مِنَ المَثانى وَالقُرءانَ العَظيمَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mdcccxc{لا تَمُدَّنَّ عَينَيكَ إِلىٰ ما مَتَّعنا بِهِ أَزوٰجًا مِنهُم وَلا تَحزَن عَلَيهِم وَاخفِض جَناحَكَ لِلمُؤمِنينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mdcccxci{وَقُل إِنّى أَنَا النَّذيرُ المُبينُ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mdcccxcii{كَما أَنزَلنا عَلَى المُقتَسِمينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mdcccxciii{الَّذينَ جَعَلُوا القُرءانَ عِضينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mdcccxciv{فَوَرَبِّكَ لَنَسـَٔلَنَّهُم أَجمَعينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mdcccxcv{عَمّا كانوا يَعمَلونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mdcccxcvi{فَاصدَع بِما تُؤمَرُ وَأَعرِض عَنِ المُشرِكينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mdcccxcvii{إِنّا كَفَينٰكَ المُستَهزِءينَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mdcccxcviii{الَّذينَ يَجعَلونَ مَعَ اللَّهِ إِلٰهًا ءاخَرَ فَسَوفَ يَعلَمونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mdcccxcix{وَلَقَد نَعلَمُ أَنَّكَ يَضيقُ صَدرُكَ بِما يَقولونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcm{فَسَبِّح بِحَمدِ رَبِّكَ وَكُن مِنَ السّٰجِدينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mcmi{وَاعبُد رَبَّكَ حَتّىٰ يَأتِيَكَ اليَقينُ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mcmii{\basmalah  أَتىٰ أَمرُ اللَّهِ فَلا تَستَعجِلوهُ سُبحٰنَهُ وَتَعٰلىٰ عَمّا يُشرِكونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mcmiii{يُنَزِّلُ المَلٰئِكَةَ بِالرّوحِ مِن أَمرِهِ عَلىٰ مَن يَشاءُ مِن عِبادِهِ أَن أَنذِروا أَنَّهُ لا إِلٰهَ إِلّا أَنا۠ فَاتَّقونِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mcmiv{خَلَقَ السَّمٰوٰتِ وَالأَرضَ بِالحَقِّ تَعٰلىٰ عَمّا يُشرِكونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mcmv{خَلَقَ الإِنسٰنَ مِن نُطفَةٍ فَإِذا هُوَ خَصيمٌ مُبينٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mcmvi{وَالأَنعٰمَ خَلَقَها لَكُم فيها دِفءٌ وَمَنٰفِعُ وَمِنها تَأكُلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mcmvii{وَلَكُم فيها جَمالٌ حينَ تُريحونَ وَحينَ تَسرَحونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mcmviii{وَتَحمِلُ أَثقالَكُم إِلىٰ بَلَدٍ لَم تَكونوا بٰلِغيهِ إِلّا بِشِقِّ الأَنفُسِ إِنَّ رَبَّكُم لَرَءوفٌ رَحيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mcmix{وَالخَيلَ وَالبِغالَ وَالحَميرَ لِتَركَبوها وَزينَةً وَيَخلُقُ ما لا تَعلَمونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mcmx{وَعَلَى اللَّهِ قَصدُ السَّبيلِ وَمِنها جائِرٌ وَلَو شاءَ لَهَدىٰكُم أَجمَعينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mcmxi{هُوَ الَّذى أَنزَلَ مِنَ السَّماءِ ماءً لَكُم مِنهُ شَرابٌ وَمِنهُ شَجَرٌ فيهِ تُسيمونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mcmxii{يُنبِتُ لَكُم بِهِ الزَّرعَ وَالزَّيتونَ وَالنَّخيلَ وَالأَعنٰبَ وَمِن كُلِّ الثَّمَرٰتِ إِنَّ فى ذٰلِكَ لَءايَةً لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mcmxiii{وَسَخَّرَ لَكُمُ الَّيلَ وَالنَّهارَ وَالشَّمسَ وَالقَمَرَ وَالنُّجومُ مُسَخَّرٰتٌ بِأَمرِهِ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَعقِلونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mcmxiv{وَما ذَرَأَ لَكُم فِى الأَرضِ مُختَلِفًا أَلوٰنُهُ إِنَّ فى ذٰلِكَ لَءايَةً لِقَومٍ يَذَّكَّرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mcmxv{وَهُوَ الَّذى سَخَّرَ البَحرَ لِتَأكُلوا مِنهُ لَحمًا طَرِيًّا وَتَستَخرِجوا مِنهُ حِليَةً تَلبَسونَها وَتَرَى الفُلكَ مَواخِرَ فيهِ وَلِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mcmxvi{وَأَلقىٰ فِى الأَرضِ رَوٰسِىَ أَن تَميدَ بِكُم وَأَنهٰرًا وَسُبُلًا لَعَلَّكُم تَهتَدونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mcmxvii{وَعَلٰمٰتٍ وَبِالنَّجمِ هُم يَهتَدونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mcmxviii{أَفَمَن يَخلُقُ كَمَن لا يَخلُقُ أَفَلا تَذَكَّرونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mcmxix{وَإِن تَعُدّوا نِعمَةَ اللَّهِ لا تُحصوها إِنَّ اللَّهَ لَغَفورٌ رَحيمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mcmxx{وَاللَّهُ يَعلَمُ ما تُسِرّونَ وَما تُعلِنونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mcmxxi{وَالَّذينَ يَدعونَ مِن دونِ اللَّهِ لا يَخلُقونَ شَيـًٔا وَهُم يُخلَقونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mcmxxii{أَموٰتٌ غَيرُ أَحياءٍ وَما يَشعُرونَ أَيّانَ يُبعَثونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mcmxxiii{إِلٰهُكُم إِلٰهٌ وٰحِدٌ فَالَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ قُلوبُهُم مُنكِرَةٌ وَهُم مُستَكبِرونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mcmxxiv{لا جَرَمَ أَنَّ اللَّهَ يَعلَمُ ما يُسِرّونَ وَما يُعلِنونَ إِنَّهُ لا يُحِبُّ المُستَكبِرينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mcmxxv{وَإِذا قيلَ لَهُم ماذا أَنزَلَ رَبُّكُم قالوا أَسٰطيرُ الأَوَّلينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mcmxxvi{لِيَحمِلوا أَوزارَهُم كامِلَةً يَومَ القِيٰمَةِ وَمِن أَوزارِ الَّذينَ يُضِلّونَهُم بِغَيرِ عِلمٍ أَلا ساءَ ما يَزِرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mcmxxvii{قَد مَكَرَ الَّذينَ مِن قَبلِهِم فَأَتَى اللَّهُ بُنيٰنَهُم مِنَ القَواعِدِ فَخَرَّ عَلَيهِمُ السَّقفُ مِن فَوقِهِم وَأَتىٰهُمُ العَذابُ مِن حَيثُ لا يَشعُرونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mcmxxviii{ثُمَّ يَومَ القِيٰمَةِ يُخزيهِم وَيَقولُ أَينَ شُرَكاءِىَ الَّذينَ كُنتُم تُشٰقّونَ فيهِم قالَ الَّذينَ أوتُوا العِلمَ إِنَّ الخِزىَ اليَومَ وَالسّوءَ عَلَى الكٰفِرينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mcmxxix{الَّذينَ تَتَوَفّىٰهُمُ المَلٰئِكَةُ ظالِمى أَنفُسِهِم فَأَلقَوُا السَّلَمَ ما كُنّا نَعمَلُ مِن سوءٍ بَلىٰ إِنَّ اللَّهَ عَليمٌ بِما كُنتُم تَعمَلونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mcmxxx{فَادخُلوا أَبوٰبَ جَهَنَّمَ خٰلِدينَ فيها فَلَبِئسَ مَثوَى المُتَكَبِّرينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mcmxxxi{وَقيلَ لِلَّذينَ اتَّقَوا ماذا أَنزَلَ رَبُّكُم قالوا خَيرًا لِلَّذينَ أَحسَنوا فى هٰذِهِ الدُّنيا حَسَنَةٌ وَلَدارُ الءاخِرَةِ خَيرٌ وَلَنِعمَ دارُ المُتَّقينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mcmxxxii{جَنّٰتُ عَدنٍ يَدخُلونَها تَجرى مِن تَحتِهَا الأَنهٰرُ لَهُم فيها ما يَشاءونَ كَذٰلِكَ يَجزِى اللَّهُ المُتَّقينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mcmxxxiii{الَّذينَ تَتَوَفّىٰهُمُ المَلٰئِكَةُ طَيِّبينَ يَقولونَ سَلٰمٌ عَلَيكُمُ ادخُلُوا الجَنَّةَ بِما كُنتُم تَعمَلونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mcmxxxiv{هَل يَنظُرونَ إِلّا أَن تَأتِيَهُمُ المَلٰئِكَةُ أَو يَأتِىَ أَمرُ رَبِّكَ كَذٰلِكَ فَعَلَ الَّذينَ مِن قَبلِهِم وَما ظَلَمَهُمُ اللَّهُ وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mcmxxxv{فَأَصابَهُم سَيِّـٔاتُ ما عَمِلوا وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mcmxxxvi{وَقالَ الَّذينَ أَشرَكوا لَو شاءَ اللَّهُ ما عَبَدنا مِن دونِهِ مِن شَيءٍ نَحنُ وَلا ءاباؤُنا وَلا حَرَّمنا مِن دونِهِ مِن شَيءٍ كَذٰلِكَ فَعَلَ الَّذينَ مِن قَبلِهِم فَهَل عَلَى الرُّسُلِ إِلَّا البَلٰغُ المُبينُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mcmxxxvii{وَلَقَد بَعَثنا فى كُلِّ أُمَّةٍ رَسولًا أَنِ اعبُدُوا اللَّهَ وَاجتَنِبُوا الطّٰغوتَ فَمِنهُم مَن هَدَى اللَّهُ وَمِنهُم مَن حَقَّت عَلَيهِ الضَّلٰلَةُ فَسيروا فِى الأَرضِ فَانظُروا كَيفَ كانَ عٰقِبَةُ المُكَذِّبينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mcmxxxviii{إِن تَحرِص عَلىٰ هُدىٰهُم فَإِنَّ اللَّهَ لا يَهدى مَن يُضِلُّ وَما لَهُم مِن نٰصِرينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mcmxxxix{وَأَقسَموا بِاللَّهِ جَهدَ أَيمٰنِهِم لا يَبعَثُ اللَّهُ مَن يَموتُ بَلىٰ وَعدًا عَلَيهِ حَقًّا وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mcmxl{لِيُبَيِّنَ لَهُمُ الَّذى يَختَلِفونَ فيهِ وَلِيَعلَمَ الَّذينَ كَفَروا أَنَّهُم كانوا كٰذِبينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mcmxli{إِنَّما قَولُنا لِشَيءٍ إِذا أَرَدنٰهُ أَن نَقولَ لَهُ كُن فَيَكونُ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mcmxlii{وَالَّذينَ هاجَروا فِى اللَّهِ مِن بَعدِ ما ظُلِموا لَنُبَوِّئَنَّهُم فِى الدُّنيا حَسَنَةً وَلَأَجرُ الءاخِرَةِ أَكبَرُ لَو كانوا يَعلَمونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mcmxliii{الَّذينَ صَبَروا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mcmxliv{وَما أَرسَلنا مِن قَبلِكَ إِلّا رِجالًا نوحى إِلَيهِم فَسـَٔلوا أَهلَ الذِّكرِ إِن كُنتُم لا تَعلَمونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mcmxlv{بِالبَيِّنٰتِ وَالزُّبُرِ وَأَنزَلنا إِلَيكَ الذِّكرَ لِتُبَيِّنَ لِلنّاسِ ما نُزِّلَ إِلَيهِم وَلَعَلَّهُم يَتَفَكَّرونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mcmxlvi{أَفَأَمِنَ الَّذينَ مَكَرُوا السَّيِّـٔاتِ أَن يَخسِفَ اللَّهُ بِهِمُ الأَرضَ أَو يَأتِيَهُمُ العَذابُ مِن حَيثُ لا يَشعُرونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mcmxlvii{أَو يَأخُذَهُم فى تَقَلُّبِهِم فَما هُم بِمُعجِزينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mcmxlviii{أَو يَأخُذَهُم عَلىٰ تَخَوُّفٍ فَإِنَّ رَبَّكُم لَرَءوفٌ رَحيمٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mcmxlix{أَوَلَم يَرَوا إِلىٰ ما خَلَقَ اللَّهُ مِن شَيءٍ يَتَفَيَّؤُا۟ ظِلٰلُهُ عَنِ اليَمينِ وَالشَّمائِلِ سُجَّدًا لِلَّهِ وَهُم دٰخِرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mcml{وَلِلَّهِ يَسجُدُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ مِن دابَّةٍ وَالمَلٰئِكَةُ وَهُم لا يَستَكبِرونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mcmli{يَخافونَ رَبَّهُم مِن فَوقِهِم وَيَفعَلونَ ما يُؤمَرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mcmlii{وَقالَ اللَّهُ لا تَتَّخِذوا إِلٰهَينِ اثنَينِ إِنَّما هُوَ إِلٰهٌ وٰحِدٌ فَإِيّٰىَ فَارهَبونِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mcmliii{وَلَهُ ما فِى السَّمٰوٰتِ وَالأَرضِ وَلَهُ الدّينُ واصِبًا أَفَغَيرَ اللَّهِ تَتَّقونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mcmliv{وَما بِكُم مِن نِعمَةٍ فَمِنَ اللَّهِ ثُمَّ إِذا مَسَّكُمُ الضُّرُّ فَإِلَيهِ تَجـَٔرونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mcmlv{ثُمَّ إِذا كَشَفَ الضُّرَّ عَنكُم إِذا فَريقٌ مِنكُم بِرَبِّهِم يُشرِكونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mcmlvi{لِيَكفُروا بِما ءاتَينٰهُم فَتَمَتَّعوا فَسَوفَ تَعلَمونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mcmlvii{وَيَجعَلونَ لِما لا يَعلَمونَ نَصيبًا مِمّا رَزَقنٰهُم تَاللَّهِ لَتُسـَٔلُنَّ عَمّا كُنتُم تَفتَرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mcmlviii{وَيَجعَلونَ لِلَّهِ البَنٰتِ سُبحٰنَهُ وَلَهُم ما يَشتَهونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mcmlix{وَإِذا بُشِّرَ أَحَدُهُم بِالأُنثىٰ ظَلَّ وَجهُهُ مُسوَدًّا وَهُوَ كَظيمٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mcmlx{يَتَوٰرىٰ مِنَ القَومِ مِن سوءِ ما بُشِّرَ بِهِ أَيُمسِكُهُ عَلىٰ هونٍ أَم يَدُسُّهُ فِى التُّرابِ أَلا ساءَ ما يَحكُمونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mcmlxi{لِلَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ مَثَلُ السَّوءِ وَلِلَّهِ المَثَلُ الأَعلىٰ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mcmlxii{وَلَو يُؤاخِذُ اللَّهُ النّاسَ بِظُلمِهِم ما تَرَكَ عَلَيها مِن دابَّةٍ وَلٰكِن يُؤَخِّرُهُم إِلىٰ أَجَلٍ مُسَمًّى فَإِذا جاءَ أَجَلُهُم لا يَستَـٔخِرونَ ساعَةً وَلا يَستَقدِمونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mcmlxiii{وَيَجعَلونَ لِلَّهِ ما يَكرَهونَ وَتَصِفُ أَلسِنَتُهُمُ الكَذِبَ أَنَّ لَهُمُ الحُسنىٰ لا جَرَمَ أَنَّ لَهُمُ النّارَ وَأَنَّهُم مُفرَطونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mcmlxiv{تَاللَّهِ لَقَد أَرسَلنا إِلىٰ أُمَمٍ مِن قَبلِكَ فَزَيَّنَ لَهُمُ الشَّيطٰنُ أَعمٰلَهُم فَهُوَ وَلِيُّهُمُ اليَومَ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mcmlxv{وَما أَنزَلنا عَلَيكَ الكِتٰبَ إِلّا لِتُبَيِّنَ لَهُمُ الَّذِى اختَلَفوا فيهِ وَهُدًى وَرَحمَةً لِقَومٍ يُؤمِنونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mcmlxvi{وَاللَّهُ أَنزَلَ مِنَ السَّماءِ ماءً فَأَحيا بِهِ الأَرضَ بَعدَ مَوتِها إِنَّ فى ذٰلِكَ لَءايَةً لِقَومٍ يَسمَعونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mcmlxvii{وَإِنَّ لَكُم فِى الأَنعٰمِ لَعِبرَةً نُسقيكُم مِمّا فى بُطونِهِ مِن بَينِ فَرثٍ وَدَمٍ لَبَنًا خالِصًا سائِغًا لِلشّٰرِبينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mcmlxviii{وَمِن ثَمَرٰتِ النَّخيلِ وَالأَعنٰبِ تَتَّخِذونَ مِنهُ سَكَرًا وَرِزقًا حَسَنًا إِنَّ فى ذٰلِكَ لَءايَةً لِقَومٍ يَعقِلونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mcmlxix{وَأَوحىٰ رَبُّكَ إِلَى النَّحلِ أَنِ اتَّخِذى مِنَ الجِبالِ بُيوتًا وَمِنَ الشَّجَرِ وَمِمّا يَعرِشونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mcmlxx{ثُمَّ كُلى مِن كُلِّ الثَّمَرٰتِ فَاسلُكى سُبُلَ رَبِّكِ ذُلُلًا يَخرُجُ مِن بُطونِها شَرابٌ مُختَلِفٌ أَلوٰنُهُ فيهِ شِفاءٌ لِلنّاسِ إِنَّ فى ذٰلِكَ لَءايَةً لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mcmlxxi{وَاللَّهُ خَلَقَكُم ثُمَّ يَتَوَفّىٰكُم وَمِنكُم مَن يُرَدُّ إِلىٰ أَرذَلِ العُمُرِ لِكَى لا يَعلَمَ بَعدَ عِلمٍ شَيـًٔا إِنَّ اللَّهَ عَليمٌ قَديرٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mcmlxxii{وَاللَّهُ فَضَّلَ بَعضَكُم عَلىٰ بَعضٍ فِى الرِّزقِ فَمَا الَّذينَ فُضِّلوا بِرادّى رِزقِهِم عَلىٰ ما مَلَكَت أَيمٰنُهُم فَهُم فيهِ سَواءٌ أَفَبِنِعمَةِ اللَّهِ يَجحَدونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mcmlxxiii{وَاللَّهُ جَعَلَ لَكُم مِن أَنفُسِكُم أَزوٰجًا وَجَعَلَ لَكُم مِن أَزوٰجِكُم بَنينَ وَحَفَدَةً وَرَزَقَكُم مِنَ الطَّيِّبٰتِ أَفَبِالبٰطِلِ يُؤمِنونَ وَبِنِعمَتِ اللَّهِ هُم يَكفُرونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mcmlxxiv{وَيَعبُدونَ مِن دونِ اللَّهِ ما لا يَملِكُ لَهُم رِزقًا مِنَ السَّمٰوٰتِ وَالأَرضِ شَيـًٔا وَلا يَستَطيعونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mcmlxxv{فَلا تَضرِبوا لِلَّهِ الأَمثالَ إِنَّ اللَّهَ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mcmlxxvi{ضَرَبَ اللَّهُ مَثَلًا عَبدًا مَملوكًا لا يَقدِرُ عَلىٰ شَيءٍ وَمَن رَزَقنٰهُ مِنّا رِزقًا حَسَنًا فَهُوَ يُنفِقُ مِنهُ سِرًّا وَجَهرًا هَل يَستَوۥنَ الحَمدُ لِلَّهِ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mcmlxxvii{وَضَرَبَ اللَّهُ مَثَلًا رَجُلَينِ أَحَدُهُما أَبكَمُ لا يَقدِرُ عَلىٰ شَيءٍ وَهُوَ كَلٌّ عَلىٰ مَولىٰهُ أَينَما يُوَجِّههُ لا يَأتِ بِخَيرٍ هَل يَستَوى هُوَ وَمَن يَأمُرُ بِالعَدلِ وَهُوَ عَلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mcmlxxviii{وَلِلَّهِ غَيبُ السَّمٰوٰتِ وَالأَرضِ وَما أَمرُ السّاعَةِ إِلّا كَلَمحِ البَصَرِ أَو هُوَ أَقرَبُ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mcmlxxix{وَاللَّهُ أَخرَجَكُم مِن بُطونِ أُمَّهٰتِكُم لا تَعلَمونَ شَيـًٔا وَجَعَلَ لَكُمُ السَّمعَ وَالأَبصٰرَ وَالأَفـِٔدَةَ لَعَلَّكُم تَشكُرونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mcmlxxx{أَلَم يَرَوا إِلَى الطَّيرِ مُسَخَّرٰتٍ فى جَوِّ السَّماءِ ما يُمسِكُهُنَّ إِلَّا اللَّهُ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mcmlxxxi{وَاللَّهُ جَعَلَ لَكُم مِن بُيوتِكُم سَكَنًا وَجَعَلَ لَكُم مِن جُلودِ الأَنعٰمِ بُيوتًا تَستَخِفّونَها يَومَ ظَعنِكُم وَيَومَ إِقامَتِكُم وَمِن أَصوافِها وَأَوبارِها وَأَشعارِها أَثٰثًا وَمَتٰعًا إِلىٰ حينٍ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mcmlxxxii{وَاللَّهُ جَعَلَ لَكُم مِمّا خَلَقَ ظِلٰلًا وَجَعَلَ لَكُم مِنَ الجِبالِ أَكنٰنًا وَجَعَلَ لَكُم سَرٰبيلَ تَقيكُمُ الحَرَّ وَسَرٰبيلَ تَقيكُم بَأسَكُم كَذٰلِكَ يُتِمُّ نِعمَتَهُ عَلَيكُم لَعَلَّكُم تُسلِمونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mcmlxxxiii{فَإِن تَوَلَّوا فَإِنَّما عَلَيكَ البَلٰغُ المُبينُ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mcmlxxxiv{يَعرِفونَ نِعمَتَ اللَّهِ ثُمَّ يُنكِرونَها وَأَكثَرُهُمُ الكٰفِرونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mcmlxxxv{وَيَومَ نَبعَثُ مِن كُلِّ أُمَّةٍ شَهيدًا ثُمَّ لا يُؤذَنُ لِلَّذينَ كَفَروا وَلا هُم يُستَعتَبونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mcmlxxxvi{وَإِذا رَءَا الَّذينَ ظَلَمُوا العَذابَ فَلا يُخَفَّفُ عَنهُم وَلا هُم يُنظَرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mcmlxxxvii{وَإِذا رَءَا الَّذينَ أَشرَكوا شُرَكاءَهُم قالوا رَبَّنا هٰؤُلاءِ شُرَكاؤُنَا الَّذينَ كُنّا نَدعوا مِن دونِكَ فَأَلقَوا إِلَيهِمُ القَولَ إِنَّكُم لَكٰذِبونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mcmlxxxviii{وَأَلقَوا إِلَى اللَّهِ يَومَئِذٍ السَّلَمَ وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mcmlxxxix{الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ زِدنٰهُم عَذابًا فَوقَ العَذابِ بِما كانوا يُفسِدونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mcmxc{وَيَومَ نَبعَثُ فى كُلِّ أُمَّةٍ شَهيدًا عَلَيهِم مِن أَنفُسِهِم وَجِئنا بِكَ شَهيدًا عَلىٰ هٰؤُلاءِ وَنَزَّلنا عَلَيكَ الكِتٰبَ تِبيٰنًا لِكُلِّ شَيءٍ وَهُدًى وَرَحمَةً وَبُشرىٰ لِلمُسلِمينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mcmxci{إِنَّ اللَّهَ يَأمُرُ بِالعَدلِ وَالإِحسٰنِ وَإيتائِ ذِى القُربىٰ وَيَنهىٰ عَنِ الفَحشاءِ وَالمُنكَرِ وَالبَغىِ يَعِظُكُم لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mcmxcii{وَأَوفوا بِعَهدِ اللَّهِ إِذا عٰهَدتُم وَلا تَنقُضُوا الأَيمٰنَ بَعدَ تَوكيدِها وَقَد جَعَلتُمُ اللَّهَ عَلَيكُم كَفيلًا إِنَّ اللَّهَ يَعلَمُ ما تَفعَلونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mcmxciii{وَلا تَكونوا كَالَّتى نَقَضَت غَزلَها مِن بَعدِ قُوَّةٍ أَنكٰثًا تَتَّخِذونَ أَيمٰنَكُم دَخَلًا بَينَكُم أَن تَكونَ أُمَّةٌ هِىَ أَربىٰ مِن أُمَّةٍ إِنَّما يَبلوكُمُ اللَّهُ بِهِ وَلَيُبَيِّنَنَّ لَكُم يَومَ القِيٰمَةِ ما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mcmxciv{وَلَو شاءَ اللَّهُ لَجَعَلَكُم أُمَّةً وٰحِدَةً وَلٰكِن يُضِلُّ مَن يَشاءُ وَيَهدى مَن يَشاءُ وَلَتُسـَٔلُنَّ عَمّا كُنتُم تَعمَلونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mcmxcv{وَلا تَتَّخِذوا أَيمٰنَكُم دَخَلًا بَينَكُم فَتَزِلَّ قَدَمٌ بَعدَ ثُبوتِها وَتَذوقُوا السّوءَ بِما صَدَدتُم عَن سَبيلِ اللَّهِ وَلَكُم عَذابٌ عَظيمٌ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mcmxcvi{وَلا تَشتَروا بِعَهدِ اللَّهِ ثَمَنًا قَليلًا إِنَّما عِندَ اللَّهِ هُوَ خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mcmxcvii{ما عِندَكُم يَنفَدُ وَما عِندَ اللَّهِ باقٍ وَلَنَجزِيَنَّ الَّذينَ صَبَروا أَجرَهُم بِأَحسَنِ ما كانوا يَعمَلونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mcmxcviii{مَن عَمِلَ صٰلِحًا مِن ذَكَرٍ أَو أُنثىٰ وَهُوَ مُؤمِنٌ فَلَنُحيِيَنَّهُ حَيوٰةً طَيِّبَةً وَلَنَجزِيَنَّهُم أَجرَهُم بِأَحسَنِ ما كانوا يَعمَلونَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mcmxcix{فَإِذا قَرَأتَ القُرءانَ فَاستَعِذ بِاللَّهِ مِنَ الشَّيطٰنِ الرَّجيمِ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mm{إِنَّهُ لَيسَ لَهُ سُلطٰنٌ عَلَى الَّذينَ ءامَنوا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmi{إِنَّما سُلطٰنُهُ عَلَى الَّذينَ يَتَوَلَّونَهُ وَالَّذينَ هُم بِهِ مُشرِكونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmii{وَإِذا بَدَّلنا ءايَةً مَكانَ ءايَةٍ وَاللَّهُ أَعلَمُ بِما يُنَزِّلُ قالوا إِنَّما أَنتَ مُفتَرٍ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmiii{قُل نَزَّلَهُ روحُ القُدُسِ مِن رَبِّكَ بِالحَقِّ لِيُثَبِّتَ الَّذينَ ءامَنوا وَهُدًى وَبُشرىٰ لِلمُسلِمينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmiv{وَلَقَد نَعلَمُ أَنَّهُم يَقولونَ إِنَّما يُعَلِّمُهُ بَشَرٌ لِسانُ الَّذى يُلحِدونَ إِلَيهِ أَعجَمِىٌّ وَهٰذا لِسانٌ عَرَبِىٌّ مُبينٌ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmv{إِنَّ الَّذينَ لا يُؤمِنونَ بِـٔايٰتِ اللَّهِ لا يَهديهِمُ اللَّهُ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmvi{إِنَّما يَفتَرِى الكَذِبَ الَّذينَ لا يُؤمِنونَ بِـٔايٰتِ اللَّهِ وَأُولٰئِكَ هُمُ الكٰذِبونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmvii{مَن كَفَرَ بِاللَّهِ مِن بَعدِ إيمٰنِهِ إِلّا مَن أُكرِهَ وَقَلبُهُ مُطمَئِنٌّ بِالإيمٰنِ وَلٰكِن مَن شَرَحَ بِالكُفرِ صَدرًا فَعَلَيهِم غَضَبٌ مِنَ اللَّهِ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmviii{ذٰلِكَ بِأَنَّهُمُ استَحَبُّوا الحَيوٰةَ الدُّنيا عَلَى الءاخِرَةِ وَأَنَّ اللَّهَ لا يَهدِى القَومَ الكٰفِرينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmix{أُولٰئِكَ الَّذينَ طَبَعَ اللَّهُ عَلىٰ قُلوبِهِم وَسَمعِهِم وَأَبصٰرِهِم وَأُولٰئِكَ هُمُ الغٰفِلونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmx{لا جَرَمَ أَنَّهُم فِى الءاخِرَةِ هُمُ الخٰسِرونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmxi{ثُمَّ إِنَّ رَبَّكَ لِلَّذينَ هاجَروا مِن بَعدِ ما فُتِنوا ثُمَّ جٰهَدوا وَصَبَروا إِنَّ رَبَّكَ مِن بَعدِها لَغَفورٌ رَحيمٌ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmxii{يَومَ تَأتى كُلُّ نَفسٍ تُجٰدِلُ عَن نَفسِها وَتُوَفّىٰ كُلُّ نَفسٍ ما عَمِلَت وَهُم لا يُظلَمونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmxiii{وَضَرَبَ اللَّهُ مَثَلًا قَريَةً كانَت ءامِنَةً مُطمَئِنَّةً يَأتيها رِزقُها رَغَدًا مِن كُلِّ مَكانٍ فَكَفَرَت بِأَنعُمِ اللَّهِ فَأَذٰقَهَا اللَّهُ لِباسَ الجوعِ وَالخَوفِ بِما كانوا يَصنَعونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmxiv{وَلَقَد جاءَهُم رَسولٌ مِنهُم فَكَذَّبوهُ فَأَخَذَهُمُ العَذابُ وَهُم ظٰلِمونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmxv{فَكُلوا مِمّا رَزَقَكُمُ اللَّهُ حَلٰلًا طَيِّبًا وَاشكُروا نِعمَتَ اللَّهِ إِن كُنتُم إِيّاهُ تَعبُدونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmxvi{إِنَّما حَرَّمَ عَلَيكُمُ المَيتَةَ وَالدَّمَ وَلَحمَ الخِنزيرِ وَما أُهِلَّ لِغَيرِ اللَّهِ بِهِ فَمَنِ اضطُرَّ غَيرَ باغٍ وَلا عادٍ فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmxvii{وَلا تَقولوا لِما تَصِفُ أَلسِنَتُكُمُ الكَذِبَ هٰذا حَلٰلٌ وَهٰذا حَرامٌ لِتَفتَروا عَلَى اللَّهِ الكَذِبَ إِنَّ الَّذينَ يَفتَرونَ عَلَى اللَّهِ الكَذِبَ لا يُفلِحونَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmxviii{مَتٰعٌ قَليلٌ وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmxix{وَعَلَى الَّذينَ هادوا حَرَّمنا ما قَصَصنا عَلَيكَ مِن قَبلُ وَما ظَلَمنٰهُم وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmxx{ثُمَّ إِنَّ رَبَّكَ لِلَّذينَ عَمِلُوا السّوءَ بِجَهٰلَةٍ ثُمَّ تابوا مِن بَعدِ ذٰلِكَ وَأَصلَحوا إِنَّ رَبَّكَ مِن بَعدِها لَغَفورٌ رَحيمٌ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmxxi{إِنَّ إِبرٰهيمَ كانَ أُمَّةً قانِتًا لِلَّهِ حَنيفًا وَلَم يَكُ مِنَ المُشرِكينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmxxii{شاكِرًا لِأَنعُمِهِ اجتَبىٰهُ وَهَدىٰهُ إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmxxiii{وَءاتَينٰهُ فِى الدُّنيا حَسَنَةً وَإِنَّهُ فِى الءاخِرَةِ لَمِنَ الصّٰلِحينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmxxiv{ثُمَّ أَوحَينا إِلَيكَ أَنِ اتَّبِع مِلَّةَ إِبرٰهيمَ حَنيفًا وَما كانَ مِنَ المُشرِكينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmxxv{إِنَّما جُعِلَ السَّبتُ عَلَى الَّذينَ اختَلَفوا فيهِ وَإِنَّ رَبَّكَ لَيَحكُمُ بَينَهُم يَومَ القِيٰمَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmxxvi{ادعُ إِلىٰ سَبيلِ رَبِّكَ بِالحِكمَةِ وَالمَوعِظَةِ الحَسَنَةِ وَجٰدِلهُم بِالَّتى هِىَ أَحسَنُ إِنَّ رَبَّكَ هُوَ أَعلَمُ بِمَن ضَلَّ عَن سَبيلِهِ وَهُوَ أَعلَمُ بِالمُهتَدينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmxxvii{وَإِن عاقَبتُم فَعاقِبوا بِمِثلِ ما عوقِبتُم بِهِ وَلَئِن صَبَرتُم لَهُوَ خَيرٌ لِلصّٰبِرينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmxxviii{وَاصبِر وَما صَبرُكَ إِلّا بِاللَّهِ وَلا تَحزَن عَلَيهِم وَلا تَكُ فى ضَيقٍ مِمّا يَمكُرونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmxxix{إِنَّ اللَّهَ مَعَ الَّذينَ اتَّقَوا وَالَّذينَ هُم مُحسِنونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmxxx{\basmalah  سُبحٰنَ الَّذى أَسرىٰ بِعَبدِهِ لَيلًا مِنَ المَسجِدِ الحَرامِ إِلَى المَسجِدِ الأَقصَا الَّذى بٰرَكنا حَولَهُ لِنُرِيَهُ مِن ءايٰتِنا إِنَّهُ هُوَ السَّميعُ البَصيرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmxxxi{وَءاتَينا موسَى الكِتٰبَ وَجَعَلنٰهُ هُدًى لِبَنى إِسرٰءيلَ أَلّا تَتَّخِذوا مِن دونى وَكيلًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmxxxii{ذُرِّيَّةَ مَن حَمَلنا مَعَ نوحٍ إِنَّهُ كانَ عَبدًا شَكورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmxxxiii{وَقَضَينا إِلىٰ بَنى إِسرٰءيلَ فِى الكِتٰبِ لَتُفسِدُنَّ فِى الأَرضِ مَرَّتَينِ وَلَتَعلُنَّ عُلُوًّا كَبيرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmxxxiv{فَإِذا جاءَ وَعدُ أولىٰهُما بَعَثنا عَلَيكُم عِبادًا لَنا أُولى بَأسٍ شَديدٍ فَجاسوا خِلٰلَ الدِّيارِ وَكانَ وَعدًا مَفعولًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmxxxv{ثُمَّ رَدَدنا لَكُمُ الكَرَّةَ عَلَيهِم وَأَمدَدنٰكُم بِأَموٰلٍ وَبَنينَ وَجَعَلنٰكُم أَكثَرَ نَفيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmxxxvi{إِن أَحسَنتُم أَحسَنتُم لِأَنفُسِكُم وَإِن أَسَأتُم فَلَها فَإِذا جاءَ وَعدُ الءاخِرَةِ لِيَسۥـٔوا وُجوهَكُم وَلِيَدخُلُوا المَسجِدَ كَما دَخَلوهُ أَوَّلَ مَرَّةٍ وَلِيُتَبِّروا ما عَلَوا تَتبيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmxxxvii{عَسىٰ رَبُّكُم أَن يَرحَمَكُم وَإِن عُدتُم عُدنا وَجَعَلنا جَهَنَّمَ لِلكٰفِرينَ حَصيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmxxxviii{إِنَّ هٰذَا القُرءانَ يَهدى لِلَّتى هِىَ أَقوَمُ وَيُبَشِّرُ المُؤمِنينَ الَّذينَ يَعمَلونَ الصّٰلِحٰتِ أَنَّ لَهُم أَجرًا كَبيرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmxxxix{وَأَنَّ الَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ أَعتَدنا لَهُم عَذابًا أَليمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmxl{وَيَدعُ الإِنسٰنُ بِالشَّرِّ دُعاءَهُ بِالخَيرِ وَكانَ الإِنسٰنُ عَجولًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmxli{وَجَعَلنَا الَّيلَ وَالنَّهارَ ءايَتَينِ فَمَحَونا ءايَةَ الَّيلِ وَجَعَلنا ءايَةَ النَّهارِ مُبصِرَةً لِتَبتَغوا فَضلًا مِن رَبِّكُم وَلِتَعلَموا عَدَدَ السِّنينَ وَالحِسابَ وَكُلَّ شَيءٍ فَصَّلنٰهُ تَفصيلًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmxlii{وَكُلَّ إِنسٰنٍ أَلزَمنٰهُ طٰئِرَهُ فى عُنُقِهِ وَنُخرِجُ لَهُ يَومَ القِيٰمَةِ كِتٰبًا يَلقىٰهُ مَنشورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmxliii{اقرَأ كِتٰبَكَ كَفىٰ بِنَفسِكَ اليَومَ عَلَيكَ حَسيبًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmxliv{مَنِ اهتَدىٰ فَإِنَّما يَهتَدى لِنَفسِهِ وَمَن ضَلَّ فَإِنَّما يَضِلُّ عَلَيها وَلا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ وَما كُنّا مُعَذِّبينَ حَتّىٰ نَبعَثَ رَسولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmxlv{وَإِذا أَرَدنا أَن نُهلِكَ قَريَةً أَمَرنا مُترَفيها فَفَسَقوا فيها فَحَقَّ عَلَيهَا القَولُ فَدَمَّرنٰها تَدميرًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmxlvi{وَكَم أَهلَكنا مِنَ القُرونِ مِن بَعدِ نوحٍ وَكَفىٰ بِرَبِّكَ بِذُنوبِ عِبادِهِ خَبيرًا بَصيرًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmxlvii{مَن كانَ يُريدُ العاجِلَةَ عَجَّلنا لَهُ فيها ما نَشاءُ لِمَن نُريدُ ثُمَّ جَعَلنا لَهُ جَهَنَّمَ يَصلىٰها مَذمومًا مَدحورًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmxlviii{وَمَن أَرادَ الءاخِرَةَ وَسَعىٰ لَها سَعيَها وَهُوَ مُؤمِنٌ فَأُولٰئِكَ كانَ سَعيُهُم مَشكورًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmxlix{كُلًّا نُمِدُّ هٰؤُلاءِ وَهٰؤُلاءِ مِن عَطاءِ رَبِّكَ وَما كانَ عَطاءُ رَبِّكَ مَحظورًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mml{انظُر كَيفَ فَضَّلنا بَعضَهُم عَلىٰ بَعضٍ وَلَلءاخِرَةُ أَكبَرُ دَرَجٰتٍ وَأَكبَرُ تَفضيلًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmli{لا تَجعَل مَعَ اللَّهِ إِلٰهًا ءاخَرَ فَتَقعُدَ مَذمومًا مَخذولًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmlii{وَقَضىٰ رَبُّكَ أَلّا تَعبُدوا إِلّا إِيّاهُ وَبِالوٰلِدَينِ إِحسٰنًا إِمّا يَبلُغَنَّ عِندَكَ الكِبَرَ أَحَدُهُما أَو كِلاهُما فَلا تَقُل لَهُما أُفٍّ وَلا تَنهَرهُما وَقُل لَهُما قَولًا كَريمًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmliii{وَاخفِض لَهُما جَناحَ الذُّلِّ مِنَ الرَّحمَةِ وَقُل رَبِّ ارحَمهُما كَما رَبَّيانى صَغيرًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmliv{رَبُّكُم أَعلَمُ بِما فى نُفوسِكُم إِن تَكونوا صٰلِحينَ فَإِنَّهُ كانَ لِلأَوّٰبينَ غَفورًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmlv{وَءاتِ ذَا القُربىٰ حَقَّهُ وَالمِسكينَ وَابنَ السَّبيلِ وَلا تُبَذِّر تَبذيرًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmlvi{إِنَّ المُبَذِّرينَ كانوا إِخوٰنَ الشَّيٰطينِ وَكانَ الشَّيطٰنُ لِرَبِّهِ كَفورًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmlvii{وَإِمّا تُعرِضَنَّ عَنهُمُ ابتِغاءَ رَحمَةٍ مِن رَبِّكَ تَرجوها فَقُل لَهُم قَولًا مَيسورًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmlviii{وَلا تَجعَل يَدَكَ مَغلولَةً إِلىٰ عُنُقِكَ وَلا تَبسُطها كُلَّ البَسطِ فَتَقعُدَ مَلومًا مَحسورًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmlix{إِنَّ رَبَّكَ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ إِنَّهُ كانَ بِعِبادِهِ خَبيرًا بَصيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmlx{وَلا تَقتُلوا أَولٰدَكُم خَشيَةَ إِملٰقٍ نَحنُ نَرزُقُهُم وَإِيّاكُم إِنَّ قَتلَهُم كانَ خِطـًٔا كَبيرًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmlxi{وَلا تَقرَبُوا الزِّنىٰ إِنَّهُ كانَ فٰحِشَةً وَساءَ سَبيلًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmlxii{وَلا تَقتُلُوا النَّفسَ الَّتى حَرَّمَ اللَّهُ إِلّا بِالحَقِّ وَمَن قُتِلَ مَظلومًا فَقَد جَعَلنا لِوَلِيِّهِ سُلطٰنًا فَلا يُسرِف فِى القَتلِ إِنَّهُ كانَ مَنصورًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmlxiii{وَلا تَقرَبوا مالَ اليَتيمِ إِلّا بِالَّتى هِىَ أَحسَنُ حَتّىٰ يَبلُغَ أَشُدَّهُ وَأَوفوا بِالعَهدِ إِنَّ العَهدَ كانَ مَسـٔولًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmlxiv{وَأَوفُوا الكَيلَ إِذا كِلتُم وَزِنوا بِالقِسطاسِ المُستَقيمِ ذٰلِكَ خَيرٌ وَأَحسَنُ تَأويلًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmlxv{وَلا تَقفُ ما لَيسَ لَكَ بِهِ عِلمٌ إِنَّ السَّمعَ وَالبَصَرَ وَالفُؤادَ كُلُّ أُولٰئِكَ كانَ عَنهُ مَسـٔولًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmlxvi{وَلا تَمشِ فِى الأَرضِ مَرَحًا إِنَّكَ لَن تَخرِقَ الأَرضَ وَلَن تَبلُغَ الجِبالَ طولًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmlxvii{كُلُّ ذٰلِكَ كانَ سَيِّئُهُ عِندَ رَبِّكَ مَكروهًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmlxviii{ذٰلِكَ مِمّا أَوحىٰ إِلَيكَ رَبُّكَ مِنَ الحِكمَةِ وَلا تَجعَل مَعَ اللَّهِ إِلٰهًا ءاخَرَ فَتُلقىٰ فى جَهَنَّمَ مَلومًا مَدحورًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmlxix{أَفَأَصفىٰكُم رَبُّكُم بِالبَنينَ وَاتَّخَذَ مِنَ المَلٰئِكَةِ إِنٰثًا إِنَّكُم لَتَقولونَ قَولًا عَظيمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmlxx{وَلَقَد صَرَّفنا فى هٰذَا القُرءانِ لِيَذَّكَّروا وَما يَزيدُهُم إِلّا نُفورًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmlxxi{قُل لَو كانَ مَعَهُ ءالِهَةٌ كَما يَقولونَ إِذًا لَابتَغَوا إِلىٰ ذِى العَرشِ سَبيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmlxxii{سُبحٰنَهُ وَتَعٰلىٰ عَمّا يَقولونَ عُلُوًّا كَبيرًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmlxxiii{تُسَبِّحُ لَهُ السَّمٰوٰتُ السَّبعُ وَالأَرضُ وَمَن فيهِنَّ وَإِن مِن شَيءٍ إِلّا يُسَبِّحُ بِحَمدِهِ وَلٰكِن لا تَفقَهونَ تَسبيحَهُم إِنَّهُ كانَ حَليمًا غَفورًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmlxxiv{وَإِذا قَرَأتَ القُرءانَ جَعَلنا بَينَكَ وَبَينَ الَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ حِجابًا مَستورًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmlxxv{وَجَعَلنا عَلىٰ قُلوبِهِم أَكِنَّةً أَن يَفقَهوهُ وَفى ءاذانِهِم وَقرًا وَإِذا ذَكَرتَ رَبَّكَ فِى القُرءانِ وَحدَهُ وَلَّوا عَلىٰ أَدبٰرِهِم نُفورًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmlxxvi{نَحنُ أَعلَمُ بِما يَستَمِعونَ بِهِ إِذ يَستَمِعونَ إِلَيكَ وَإِذ هُم نَجوىٰ إِذ يَقولُ الظّٰلِمونَ إِن تَتَّبِعونَ إِلّا رَجُلًا مَسحورًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmlxxvii{انظُر كَيفَ ضَرَبوا لَكَ الأَمثالَ فَضَلّوا فَلا يَستَطيعونَ سَبيلًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmlxxviii{وَقالوا أَءِذا كُنّا عِظٰمًا وَرُفٰتًا أَءِنّا لَمَبعوثونَ خَلقًا جَديدًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmlxxix{قُل كونوا حِجارَةً أَو حَديدًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmlxxx{أَو خَلقًا مِمّا يَكبُرُ فى صُدورِكُم فَسَيَقولونَ مَن يُعيدُنا قُلِ الَّذى فَطَرَكُم أَوَّلَ مَرَّةٍ فَسَيُنغِضونَ إِلَيكَ رُءوسَهُم وَيَقولونَ مَتىٰ هُوَ قُل عَسىٰ أَن يَكونَ قَريبًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmlxxxi{يَومَ يَدعوكُم فَتَستَجيبونَ بِحَمدِهِ وَتَظُنّونَ إِن لَبِثتُم إِلّا قَليلًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmlxxxii{وَقُل لِعِبادى يَقولُوا الَّتى هِىَ أَحسَنُ إِنَّ الشَّيطٰنَ يَنزَغُ بَينَهُم إِنَّ الشَّيطٰنَ كانَ لِلإِنسٰنِ عَدُوًّا مُبينًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmlxxxiii{رَبُّكُم أَعلَمُ بِكُم إِن يَشَأ يَرحَمكُم أَو إِن يَشَأ يُعَذِّبكُم وَما أَرسَلنٰكَ عَلَيهِم وَكيلًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmlxxxiv{وَرَبُّكَ أَعلَمُ بِمَن فِى السَّمٰوٰتِ وَالأَرضِ وَلَقَد فَضَّلنا بَعضَ النَّبِيّۦنَ عَلىٰ بَعضٍ وَءاتَينا داوۥدَ زَبورًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmlxxxv{قُلِ ادعُوا الَّذينَ زَعَمتُم مِن دونِهِ فَلا يَملِكونَ كَشفَ الضُّرِّ عَنكُم وَلا تَحويلًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmlxxxvi{أُولٰئِكَ الَّذينَ يَدعونَ يَبتَغونَ إِلىٰ رَبِّهِمُ الوَسيلَةَ أَيُّهُم أَقرَبُ وَيَرجونَ رَحمَتَهُ وَيَخافونَ عَذابَهُ إِنَّ عَذابَ رَبِّكَ كانَ مَحذورًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmlxxxvii{وَإِن مِن قَريَةٍ إِلّا نَحنُ مُهلِكوها قَبلَ يَومِ القِيٰمَةِ أَو مُعَذِّبوها عَذابًا شَديدًا كانَ ذٰلِكَ فِى الكِتٰبِ مَسطورًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmlxxxviii{وَما مَنَعَنا أَن نُرسِلَ بِالءايٰتِ إِلّا أَن كَذَّبَ بِهَا الأَوَّلونَ وَءاتَينا ثَمودَ النّاقَةَ مُبصِرَةً فَظَلَموا بِها وَما نُرسِلُ بِالءايٰتِ إِلّا تَخويفًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmlxxxix{وَإِذ قُلنا لَكَ إِنَّ رَبَّكَ أَحاطَ بِالنّاسِ وَما جَعَلنَا الرُّءيَا الَّتى أَرَينٰكَ إِلّا فِتنَةً لِلنّاسِ وَالشَّجَرَةَ المَلعونَةَ فِى القُرءانِ وَنُخَوِّفُهُم فَما يَزيدُهُم إِلّا طُغيٰنًا كَبيرًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmxc{وَإِذ قُلنا لِلمَلٰئِكَةِ اسجُدوا لِءادَمَ فَسَجَدوا إِلّا إِبليسَ قالَ ءَأَسجُدُ لِمَن خَلَقتَ طينًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmxci{قالَ أَرَءَيتَكَ هٰذَا الَّذى كَرَّمتَ عَلَىَّ لَئِن أَخَّرتَنِ إِلىٰ يَومِ القِيٰمَةِ لَأَحتَنِكَنَّ ذُرِّيَّتَهُ إِلّا قَليلًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmxcii{قالَ اذهَب فَمَن تَبِعَكَ مِنهُم فَإِنَّ جَهَنَّمَ جَزاؤُكُم جَزاءً مَوفورًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmxciii{وَاستَفزِز مَنِ استَطَعتَ مِنهُم بِصَوتِكَ وَأَجلِب عَلَيهِم بِخَيلِكَ وَرَجِلِكَ وَشارِكهُم فِى الأَموٰلِ وَالأَولٰدِ وَعِدهُم وَما يَعِدُهُمُ الشَّيطٰنُ إِلّا غُرورًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmxciv{إِنَّ عِبادى لَيسَ لَكَ عَلَيهِم سُلطٰنٌ وَكَفىٰ بِرَبِّكَ وَكيلًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmxcv{رَبُّكُمُ الَّذى يُزجى لَكُمُ الفُلكَ فِى البَحرِ لِتَبتَغوا مِن فَضلِهِ إِنَّهُ كانَ بِكُم رَحيمًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmxcvi{وَإِذا مَسَّكُمُ الضُّرُّ فِى البَحرِ ضَلَّ مَن تَدعونَ إِلّا إِيّاهُ فَلَمّا نَجّىٰكُم إِلَى البَرِّ أَعرَضتُم وَكانَ الإِنسٰنُ كَفورًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmxcvii{أَفَأَمِنتُم أَن يَخسِفَ بِكُم جانِبَ البَرِّ أَو يُرسِلَ عَلَيكُم حاصِبًا ثُمَّ لا تَجِدوا لَكُم وَكيلًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmxcviii{أَم أَمِنتُم أَن يُعيدَكُم فيهِ تارَةً أُخرىٰ فَيُرسِلَ عَلَيكُم قاصِفًا مِنَ الرّيحِ فَيُغرِقَكُم بِما كَفَرتُم ثُمَّ لا تَجِدوا لَكُم عَلَينا بِهِ تَبيعًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmxcix{وَلَقَد كَرَّمنا بَنى ءادَمَ وَحَمَلنٰهُم فِى البَرِّ وَالبَحرِ وَرَزَقنٰهُم مِنَ الطَّيِّبٰتِ وَفَضَّلنٰهُم عَلىٰ كَثيرٍ مِمَّن خَلَقنا تَفضيلًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmc{يَومَ نَدعوا كُلَّ أُناسٍ بِإِمٰمِهِم فَمَن أوتِىَ كِتٰبَهُ بِيَمينِهِ فَأُولٰئِكَ يَقرَءونَ كِتٰبَهُم وَلا يُظلَمونَ فَتيلًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmci{وَمَن كانَ فى هٰذِهِ أَعمىٰ فَهُوَ فِى الءاخِرَةِ أَعمىٰ وَأَضَلُّ سَبيلًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcii{وَإِن كادوا لَيَفتِنونَكَ عَنِ الَّذى أَوحَينا إِلَيكَ لِتَفتَرِىَ عَلَينا غَيرَهُ وَإِذًا لَاتَّخَذوكَ خَليلًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmciii{وَلَولا أَن ثَبَّتنٰكَ لَقَد كِدتَ تَركَنُ إِلَيهِم شَيـًٔا قَليلًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmciv{إِذًا لَأَذَقنٰكَ ضِعفَ الحَيوٰةِ وَضِعفَ المَماتِ ثُمَّ لا تَجِدُ لَكَ عَلَينا نَصيرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcv{وَإِن كادوا لَيَستَفِزّونَكَ مِنَ الأَرضِ لِيُخرِجوكَ مِنها وَإِذًا لا يَلبَثونَ خِلٰفَكَ إِلّا قَليلًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcvi{سُنَّةَ مَن قَد أَرسَلنا قَبلَكَ مِن رُسُلِنا وَلا تَجِدُ لِسُنَّتِنا تَحويلًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcvii{أَقِمِ الصَّلوٰةَ لِدُلوكِ الشَّمسِ إِلىٰ غَسَقِ الَّيلِ وَقُرءانَ الفَجرِ إِنَّ قُرءانَ الفَجرِ كانَ مَشهودًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcviii{وَمِنَ الَّيلِ فَتَهَجَّد بِهِ نافِلَةً لَكَ عَسىٰ أَن يَبعَثَكَ رَبُّكَ مَقامًا مَحمودًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcix{وَقُل رَبِّ أَدخِلنى مُدخَلَ صِدقٍ وَأَخرِجنى مُخرَجَ صِدقٍ وَاجعَل لى مِن لَدُنكَ سُلطٰنًا نَصيرًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcx{وَقُل جاءَ الحَقُّ وَزَهَقَ البٰطِلُ إِنَّ البٰطِلَ كانَ زَهوقًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcxi{وَنُنَزِّلُ مِنَ القُرءانِ ما هُوَ شِفاءٌ وَرَحمَةٌ لِلمُؤمِنينَ وَلا يَزيدُ الظّٰلِمينَ إِلّا خَسارًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcxii{وَإِذا أَنعَمنا عَلَى الإِنسٰنِ أَعرَضَ وَنَـٔا بِجانِبِهِ وَإِذا مَسَّهُ الشَّرُّ كانَ يَـٔوسًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcxiii{قُل كُلٌّ يَعمَلُ عَلىٰ شاكِلَتِهِ فَرَبُّكُم أَعلَمُ بِمَن هُوَ أَهدىٰ سَبيلًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcxiv{وَيَسـَٔلونَكَ عَنِ الرّوحِ قُلِ الرّوحُ مِن أَمرِ رَبّى وَما أوتيتُم مِنَ العِلمِ إِلّا قَليلًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcxv{وَلَئِن شِئنا لَنَذهَبَنَّ بِالَّذى أَوحَينا إِلَيكَ ثُمَّ لا تَجِدُ لَكَ بِهِ عَلَينا وَكيلًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcxvi{إِلّا رَحمَةً مِن رَبِّكَ إِنَّ فَضلَهُ كانَ عَلَيكَ كَبيرًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcxvii{قُل لَئِنِ اجتَمَعَتِ الإِنسُ وَالجِنُّ عَلىٰ أَن يَأتوا بِمِثلِ هٰذَا القُرءانِ لا يَأتونَ بِمِثلِهِ وَلَو كانَ بَعضُهُم لِبَعضٍ ظَهيرًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcxviii{وَلَقَد صَرَّفنا لِلنّاسِ فى هٰذَا القُرءانِ مِن كُلِّ مَثَلٍ فَأَبىٰ أَكثَرُ النّاسِ إِلّا كُفورًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcxix{وَقالوا لَن نُؤمِنَ لَكَ حَتّىٰ تَفجُرَ لَنا مِنَ الأَرضِ يَنبوعًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcxx{أَو تَكونَ لَكَ جَنَّةٌ مِن نَخيلٍ وَعِنَبٍ فَتُفَجِّرَ الأَنهٰرَ خِلٰلَها تَفجيرًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcxxi{أَو تُسقِطَ السَّماءَ كَما زَعَمتَ عَلَينا كِسَفًا أَو تَأتِىَ بِاللَّهِ وَالمَلٰئِكَةِ قَبيلًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcxxii{أَو يَكونَ لَكَ بَيتٌ مِن زُخرُفٍ أَو تَرقىٰ فِى السَّماءِ وَلَن نُؤمِنَ لِرُقِيِّكَ حَتّىٰ تُنَزِّلَ عَلَينا كِتٰبًا نَقرَؤُهُ قُل سُبحانَ رَبّى هَل كُنتُ إِلّا بَشَرًا رَسولًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcxxiii{وَما مَنَعَ النّاسَ أَن يُؤمِنوا إِذ جاءَهُمُ الهُدىٰ إِلّا أَن قالوا أَبَعَثَ اللَّهُ بَشَرًا رَسولًا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcxxiv{قُل لَو كانَ فِى الأَرضِ مَلٰئِكَةٌ يَمشونَ مُطمَئِنّينَ لَنَزَّلنا عَلَيهِم مِنَ السَّماءِ مَلَكًا رَسولًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcxxv{قُل كَفىٰ بِاللَّهِ شَهيدًا بَينى وَبَينَكُم إِنَّهُ كانَ بِعِبادِهِ خَبيرًا بَصيرًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcxxvi{وَمَن يَهدِ اللَّهُ فَهُوَ المُهتَدِ وَمَن يُضلِل فَلَن تَجِدَ لَهُم أَولِياءَ مِن دونِهِ وَنَحشُرُهُم يَومَ القِيٰمَةِ عَلىٰ وُجوهِهِم عُميًا وَبُكمًا وَصُمًّا مَأوىٰهُم جَهَنَّمُ كُلَّما خَبَت زِدنٰهُم سَعيرًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcxxvii{ذٰلِكَ جَزاؤُهُم بِأَنَّهُم كَفَروا بِـٔايٰتِنا وَقالوا أَءِذا كُنّا عِظٰمًا وَرُفٰتًا أَءِنّا لَمَبعوثونَ خَلقًا جَديدًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcxxviii{أَوَلَم يَرَوا أَنَّ اللَّهَ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ قادِرٌ عَلىٰ أَن يَخلُقَ مِثلَهُم وَجَعَلَ لَهُم أَجَلًا لا رَيبَ فيهِ فَأَبَى الظّٰلِمونَ إِلّا كُفورًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmcxxix{قُل لَو أَنتُم تَملِكونَ خَزائِنَ رَحمَةِ رَبّى إِذًا لَأَمسَكتُم خَشيَةَ الإِنفاقِ وَكانَ الإِنسٰنُ قَتورًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmcxxx{وَلَقَد ءاتَينا موسىٰ تِسعَ ءايٰتٍ بَيِّنٰتٍ فَسـَٔل بَنى إِسرٰءيلَ إِذ جاءَهُم فَقالَ لَهُ فِرعَونُ إِنّى لَأَظُنُّكَ يٰموسىٰ مَسحورًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmcxxxi{قالَ لَقَد عَلِمتَ ما أَنزَلَ هٰؤُلاءِ إِلّا رَبُّ السَّمٰوٰتِ وَالأَرضِ بَصائِرَ وَإِنّى لَأَظُنُّكَ يٰفِرعَونُ مَثبورًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmcxxxii{فَأَرادَ أَن يَستَفِزَّهُم مِنَ الأَرضِ فَأَغرَقنٰهُ وَمَن مَعَهُ جَميعًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmcxxxiii{وَقُلنا مِن بَعدِهِ لِبَنى إِسرٰءيلَ اسكُنُوا الأَرضَ فَإِذا جاءَ وَعدُ الءاخِرَةِ جِئنا بِكُم لَفيفًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmcxxxiv{وَبِالحَقِّ أَنزَلنٰهُ وَبِالحَقِّ نَزَلَ وَما أَرسَلنٰكَ إِلّا مُبَشِّرًا وَنَذيرًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmcxxxv{وَقُرءانًا فَرَقنٰهُ لِتَقرَأَهُ عَلَى النّاسِ عَلىٰ مُكثٍ وَنَزَّلنٰهُ تَنزيلًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmcxxxvi{قُل ءامِنوا بِهِ أَو لا تُؤمِنوا إِنَّ الَّذينَ أوتُوا العِلمَ مِن قَبلِهِ إِذا يُتلىٰ عَلَيهِم يَخِرّونَ لِلأَذقانِ سُجَّدًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmcxxxvii{وَيَقولونَ سُبحٰنَ رَبِّنا إِن كانَ وَعدُ رَبِّنا لَمَفعولًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmcxxxviii{وَيَخِرّونَ لِلأَذقانِ يَبكونَ وَيَزيدُهُم خُشوعًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmcxxxix{قُلِ ادعُوا اللَّهَ أَوِ ادعُوا الرَّحمٰنَ أَيًّا ما تَدعوا فَلَهُ الأَسماءُ الحُسنىٰ وَلا تَجهَر بِصَلاتِكَ وَلا تُخافِت بِها وَابتَغِ بَينَ ذٰلِكَ سَبيلًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmcxl{وَقُلِ الحَمدُ لِلَّهِ الَّذى لَم يَتَّخِذ وَلَدًا وَلَم يَكُن لَهُ شَريكٌ فِى المُلكِ وَلَم يَكُن لَهُ وَلِىٌّ مِنَ الذُّلِّ وَكَبِّرهُ تَكبيرًا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmcxli{\basmalah  الحَمدُ لِلَّهِ الَّذى أَنزَلَ عَلىٰ عَبدِهِ الكِتٰبَ وَلَم يَجعَل لَهُ عِوَجا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcxlii{قَيِّمًا لِيُنذِرَ بَأسًا شَديدًا مِن لَدُنهُ وَيُبَشِّرَ المُؤمِنينَ الَّذينَ يَعمَلونَ الصّٰلِحٰتِ أَنَّ لَهُم أَجرًا حَسَنًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcxliii{مٰكِثينَ فيهِ أَبَدًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcxliv{وَيُنذِرَ الَّذينَ قالُوا اتَّخَذَ اللَّهُ وَلَدًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcxlv{ما لَهُم بِهِ مِن عِلمٍ وَلا لِءابائِهِم كَبُرَت كَلِمَةً تَخرُجُ مِن أَفوٰهِهِم إِن يَقولونَ إِلّا كَذِبًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcxlvi{فَلَعَلَّكَ بٰخِعٌ نَفسَكَ عَلىٰ ءاثٰرِهِم إِن لَم يُؤمِنوا بِهٰذَا الحَديثِ أَسَفًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcxlvii{إِنّا جَعَلنا ما عَلَى الأَرضِ زينَةً لَها لِنَبلُوَهُم أَيُّهُم أَحسَنُ عَمَلًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcxlviii{وَإِنّا لَجٰعِلونَ ما عَلَيها صَعيدًا جُرُزًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcxlix{أَم حَسِبتَ أَنَّ أَصحٰبَ الكَهفِ وَالرَّقيمِ كانوا مِن ءايٰتِنا عَجَبًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcl{إِذ أَوَى الفِتيَةُ إِلَى الكَهفِ فَقالوا رَبَّنا ءاتِنا مِن لَدُنكَ رَحمَةً وَهَيِّئ لَنا مِن أَمرِنا رَشَدًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcli{فَضَرَبنا عَلىٰ ءاذانِهِم فِى الكَهفِ سِنينَ عَدَدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmclii{ثُمَّ بَعَثنٰهُم لِنَعلَمَ أَىُّ الحِزبَينِ أَحصىٰ لِما لَبِثوا أَمَدًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcliii{نَحنُ نَقُصُّ عَلَيكَ نَبَأَهُم بِالحَقِّ إِنَّهُم فِتيَةٌ ءامَنوا بِرَبِّهِم وَزِدنٰهُم هُدًى\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcliv{وَرَبَطنا عَلىٰ قُلوبِهِم إِذ قاموا فَقالوا رَبُّنا رَبُّ السَّمٰوٰتِ وَالأَرضِ لَن نَدعُوَا۟ مِن دونِهِ إِلٰهًا لَقَد قُلنا إِذًا شَطَطًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmclv{هٰؤُلاءِ قَومُنَا اتَّخَذوا مِن دونِهِ ءالِهَةً لَولا يَأتونَ عَلَيهِم بِسُلطٰنٍ بَيِّنٍ فَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmclvi{وَإِذِ اعتَزَلتُموهُم وَما يَعبُدونَ إِلَّا اللَّهَ فَأوۥا إِلَى الكَهفِ يَنشُر لَكُم رَبُّكُم مِن رَحمَتِهِ وَيُهَيِّئ لَكُم مِن أَمرِكُم مِرفَقًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmclvii{وَتَرَى الشَّمسَ إِذا طَلَعَت تَزٰوَرُ عَن كَهفِهِم ذاتَ اليَمينِ وَإِذا غَرَبَت تَقرِضُهُم ذاتَ الشِّمالِ وَهُم فى فَجوَةٍ مِنهُ ذٰلِكَ مِن ءايٰتِ اللَّهِ مَن يَهدِ اللَّهُ فَهُوَ المُهتَدِ وَمَن يُضلِل فَلَن تَجِدَ لَهُ وَلِيًّا مُرشِدًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmclviii{وَتَحسَبُهُم أَيقاظًا وَهُم رُقودٌ وَنُقَلِّبُهُم ذاتَ اليَمينِ وَذاتَ الشِّمالِ وَكَلبُهُم بٰسِطٌ ذِراعَيهِ بِالوَصيدِ لَوِ اطَّلَعتَ عَلَيهِم لَوَلَّيتَ مِنهُم فِرارًا وَلَمُلِئتَ مِنهُم رُعبًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmclix{وَكَذٰلِكَ بَعَثنٰهُم لِيَتَساءَلوا بَينَهُم قالَ قائِلٌ مِنهُم كَم لَبِثتُم قالوا لَبِثنا يَومًا أَو بَعضَ يَومٍ قالوا رَبُّكُم أَعلَمُ بِما لَبِثتُم فَابعَثوا أَحَدَكُم بِوَرِقِكُم هٰذِهِ إِلَى المَدينَةِ فَليَنظُر أَيُّها أَزكىٰ طَعامًا فَليَأتِكُم بِرِزقٍ مِنهُ وَليَتَلَطَّف وَلا يُشعِرَنَّ بِكُم أَحَدًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmclx{إِنَّهُم إِن يَظهَروا عَلَيكُم يَرجُموكُم أَو يُعيدوكُم فى مِلَّتِهِم وَلَن تُفلِحوا إِذًا أَبَدًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmclxi{وَكَذٰلِكَ أَعثَرنا عَلَيهِم لِيَعلَموا أَنَّ وَعدَ اللَّهِ حَقٌّ وَأَنَّ السّاعَةَ لا رَيبَ فيها إِذ يَتَنٰزَعونَ بَينَهُم أَمرَهُم فَقالُوا ابنوا عَلَيهِم بُنيٰنًا رَبُّهُم أَعلَمُ بِهِم قالَ الَّذينَ غَلَبوا عَلىٰ أَمرِهِم لَنَتَّخِذَنَّ عَلَيهِم مَسجِدًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmclxii{سَيَقولونَ ثَلٰثَةٌ رابِعُهُم كَلبُهُم وَيَقولونَ خَمسَةٌ سادِسُهُم كَلبُهُم رَجمًا بِالغَيبِ وَيَقولونَ سَبعَةٌ وَثامِنُهُم كَلبُهُم قُل رَبّى أَعلَمُ بِعِدَّتِهِم ما يَعلَمُهُم إِلّا قَليلٌ فَلا تُمارِ فيهِم إِلّا مِراءً ظٰهِرًا وَلا تَستَفتِ فيهِم مِنهُم أَحَدًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmclxiii{وَلا تَقولَنَّ لِشَا۟يءٍ إِنّى فاعِلٌ ذٰلِكَ غَدًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmclxiv{إِلّا أَن يَشاءَ اللَّهُ وَاذكُر رَبَّكَ إِذا نَسيتَ وَقُل عَسىٰ أَن يَهدِيَنِ رَبّى لِأَقرَبَ مِن هٰذا رَشَدًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmclxv{وَلَبِثوا فى كَهفِهِم ثَلٰثَ مِا۟ئَةٍ سِنينَ وَازدادوا تِسعًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmclxvi{قُلِ اللَّهُ أَعلَمُ بِما لَبِثوا لَهُ غَيبُ السَّمٰوٰتِ وَالأَرضِ أَبصِر بِهِ وَأَسمِع ما لَهُم مِن دونِهِ مِن وَلِىٍّ وَلا يُشرِكُ فى حُكمِهِ أَحَدًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmclxvii{وَاتلُ ما أوحِىَ إِلَيكَ مِن كِتابِ رَبِّكَ لا مُبَدِّلَ لِكَلِمٰتِهِ وَلَن تَجِدَ مِن دونِهِ مُلتَحَدًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmclxviii{وَاصبِر نَفسَكَ مَعَ الَّذينَ يَدعونَ رَبَّهُم بِالغَدوٰةِ وَالعَشِىِّ يُريدونَ وَجهَهُ وَلا تَعدُ عَيناكَ عَنهُم تُريدُ زينَةَ الحَيوٰةِ الدُّنيا وَلا تُطِع مَن أَغفَلنا قَلبَهُ عَن ذِكرِنا وَاتَّبَعَ هَوىٰهُ وَكانَ أَمرُهُ فُرُطًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmclxix{وَقُلِ الحَقُّ مِن رَبِّكُم فَمَن شاءَ فَليُؤمِن وَمَن شاءَ فَليَكفُر إِنّا أَعتَدنا لِلظّٰلِمينَ نارًا أَحاطَ بِهِم سُرادِقُها وَإِن يَستَغيثوا يُغاثوا بِماءٍ كَالمُهلِ يَشوِى الوُجوهَ بِئسَ الشَّرابُ وَساءَت مُرتَفَقًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmclxx{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ إِنّا لا نُضيعُ أَجرَ مَن أَحسَنَ عَمَلًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmclxxi{أُولٰئِكَ لَهُم جَنّٰتُ عَدنٍ تَجرى مِن تَحتِهِمُ الأَنهٰرُ يُحَلَّونَ فيها مِن أَساوِرَ مِن ذَهَبٍ وَيَلبَسونَ ثِيابًا خُضرًا مِن سُندُسٍ وَإِستَبرَقٍ مُتَّكِـٔينَ فيها عَلَى الأَرائِكِ نِعمَ الثَّوابُ وَحَسُنَت مُرتَفَقًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmclxxii{وَاضرِب لَهُم مَثَلًا رَجُلَينِ جَعَلنا لِأَحَدِهِما جَنَّتَينِ مِن أَعنٰبٍ وَحَفَفنٰهُما بِنَخلٍ وَجَعَلنا بَينَهُما زَرعًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmclxxiii{كِلتَا الجَنَّتَينِ ءاتَت أُكُلَها وَلَم تَظلِم مِنهُ شَيـًٔا وَفَجَّرنا خِلٰلَهُما نَهَرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmclxxiv{وَكانَ لَهُ ثَمَرٌ فَقالَ لِصٰحِبِهِ وَهُوَ يُحاوِرُهُ أَنا۠ أَكثَرُ مِنكَ مالًا وَأَعَزُّ نَفَرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmclxxv{وَدَخَلَ جَنَّتَهُ وَهُوَ ظالِمٌ لِنَفسِهِ قالَ ما أَظُنُّ أَن تَبيدَ هٰذِهِ أَبَدًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmclxxvi{وَما أَظُنُّ السّاعَةَ قائِمَةً وَلَئِن رُدِدتُ إِلىٰ رَبّى لَأَجِدَنَّ خَيرًا مِنها مُنقَلَبًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmclxxvii{قالَ لَهُ صاحِبُهُ وَهُوَ يُحاوِرُهُ أَكَفَرتَ بِالَّذى خَلَقَكَ مِن تُرابٍ ثُمَّ مِن نُطفَةٍ ثُمَّ سَوّىٰكَ رَجُلًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmclxxviii{لٰكِنّا۠ هُوَ اللَّهُ رَبّى وَلا أُشرِكُ بِرَبّى أَحَدًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmclxxix{وَلَولا إِذ دَخَلتَ جَنَّتَكَ قُلتَ ما شاءَ اللَّهُ لا قُوَّةَ إِلّا بِاللَّهِ إِن تَرَنِ أَنا۠ أَقَلَّ مِنكَ مالًا وَوَلَدًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmclxxx{فَعَسىٰ رَبّى أَن يُؤتِيَنِ خَيرًا مِن جَنَّتِكَ وَيُرسِلَ عَلَيها حُسبانًا مِنَ السَّماءِ فَتُصبِحَ صَعيدًا زَلَقًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmclxxxi{أَو يُصبِحَ ماؤُها غَورًا فَلَن تَستَطيعَ لَهُ طَلَبًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmclxxxii{وَأُحيطَ بِثَمَرِهِ فَأَصبَحَ يُقَلِّبُ كَفَّيهِ عَلىٰ ما أَنفَقَ فيها وَهِىَ خاوِيَةٌ عَلىٰ عُروشِها وَيَقولُ يٰلَيتَنى لَم أُشرِك بِرَبّى أَحَدًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmclxxxiii{وَلَم تَكُن لَهُ فِئَةٌ يَنصُرونَهُ مِن دونِ اللَّهِ وَما كانَ مُنتَصِرًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmclxxxiv{هُنالِكَ الوَلٰيَةُ لِلَّهِ الحَقِّ هُوَ خَيرٌ ثَوابًا وَخَيرٌ عُقبًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmclxxxv{وَاضرِب لَهُم مَثَلَ الحَيوٰةِ الدُّنيا كَماءٍ أَنزَلنٰهُ مِنَ السَّماءِ فَاختَلَطَ بِهِ نَباتُ الأَرضِ فَأَصبَحَ هَشيمًا تَذروهُ الرِّيٰحُ وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ مُقتَدِرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmclxxxvi{المالُ وَالبَنونَ زينَةُ الحَيوٰةِ الدُّنيا وَالبٰقِيٰتُ الصّٰلِحٰتُ خَيرٌ عِندَ رَبِّكَ ثَوابًا وَخَيرٌ أَمَلًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmclxxxvii{وَيَومَ نُسَيِّرُ الجِبالَ وَتَرَى الأَرضَ بارِزَةً وَحَشَرنٰهُم فَلَم نُغادِر مِنهُم أَحَدًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmclxxxviii{وَعُرِضوا عَلىٰ رَبِّكَ صَفًّا لَقَد جِئتُمونا كَما خَلَقنٰكُم أَوَّلَ مَرَّةٍ بَل زَعَمتُم أَلَّن نَجعَلَ لَكُم مَوعِدًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmclxxxix{وَوُضِعَ الكِتٰبُ فَتَرَى المُجرِمينَ مُشفِقينَ مِمّا فيهِ وَيَقولونَ يٰوَيلَتَنا مالِ هٰذَا الكِتٰبِ لا يُغادِرُ صَغيرَةً وَلا كَبيرَةً إِلّا أَحصىٰها وَوَجَدوا ما عَمِلوا حاضِرًا وَلا يَظلِمُ رَبُّكَ أَحَدًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcxc{وَإِذ قُلنا لِلمَلٰئِكَةِ اسجُدوا لِءادَمَ فَسَجَدوا إِلّا إِبليسَ كانَ مِنَ الجِنِّ فَفَسَقَ عَن أَمرِ رَبِّهِ أَفَتَتَّخِذونَهُ وَذُرِّيَّتَهُ أَولِياءَ مِن دونى وَهُم لَكُم عَدُوٌّ بِئسَ لِلظّٰلِمينَ بَدَلًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcxci{ما أَشهَدتُهُم خَلقَ السَّمٰوٰتِ وَالأَرضِ وَلا خَلقَ أَنفُسِهِم وَما كُنتُ مُتَّخِذَ المُضِلّينَ عَضُدًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcxcii{وَيَومَ يَقولُ نادوا شُرَكاءِىَ الَّذينَ زَعَمتُم فَدَعَوهُم فَلَم يَستَجيبوا لَهُم وَجَعَلنا بَينَهُم مَوبِقًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcxciii{وَرَءَا المُجرِمونَ النّارَ فَظَنّوا أَنَّهُم مُواقِعوها وَلَم يَجِدوا عَنها مَصرِفًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcxciv{وَلَقَد صَرَّفنا فى هٰذَا القُرءانِ لِلنّاسِ مِن كُلِّ مَثَلٍ وَكانَ الإِنسٰنُ أَكثَرَ شَيءٍ جَدَلًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcxcv{وَما مَنَعَ النّاسَ أَن يُؤمِنوا إِذ جاءَهُمُ الهُدىٰ وَيَستَغفِروا رَبَّهُم إِلّا أَن تَأتِيَهُم سُنَّةُ الأَوَّلينَ أَو يَأتِيَهُمُ العَذابُ قُبُلًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcxcvi{وَما نُرسِلُ المُرسَلينَ إِلّا مُبَشِّرينَ وَمُنذِرينَ وَيُجٰدِلُ الَّذينَ كَفَروا بِالبٰطِلِ لِيُدحِضوا بِهِ الحَقَّ وَاتَّخَذوا ءايٰتى وَما أُنذِروا هُزُوًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcxcvii{وَمَن أَظلَمُ مِمَّن ذُكِّرَ بِـٔايٰتِ رَبِّهِ فَأَعرَضَ عَنها وَنَسِىَ ما قَدَّمَت يَداهُ إِنّا جَعَلنا عَلىٰ قُلوبِهِم أَكِنَّةً أَن يَفقَهوهُ وَفى ءاذانِهِم وَقرًا وَإِن تَدعُهُم إِلَى الهُدىٰ فَلَن يَهتَدوا إِذًا أَبَدًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcxcviii{وَرَبُّكَ الغَفورُ ذُو الرَّحمَةِ لَو يُؤاخِذُهُم بِما كَسَبوا لَعَجَّلَ لَهُمُ العَذابَ بَل لَهُم مَوعِدٌ لَن يَجِدوا مِن دونِهِ مَوئِلًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcxcix{وَتِلكَ القُرىٰ أَهلَكنٰهُم لَمّا ظَلَموا وَجَعَلنا لِمَهلِكِهِم مَوعِدًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcc{وَإِذ قالَ موسىٰ لِفَتىٰهُ لا أَبرَحُ حَتّىٰ أَبلُغَ مَجمَعَ البَحرَينِ أَو أَمضِىَ حُقُبًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcci{فَلَمّا بَلَغا مَجمَعَ بَينِهِما نَسِيا حوتَهُما فَاتَّخَذَ سَبيلَهُ فِى البَحرِ سَرَبًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmccii{فَلَمّا جاوَزا قالَ لِفَتىٰهُ ءاتِنا غَداءَنا لَقَد لَقينا مِن سَفَرِنا هٰذا نَصَبًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcciii{قالَ أَرَءَيتَ إِذ أَوَينا إِلَى الصَّخرَةِ فَإِنّى نَسيتُ الحوتَ وَما أَنسىٰنيهُ إِلَّا الشَّيطٰنُ أَن أَذكُرَهُ وَاتَّخَذَ سَبيلَهُ فِى البَحرِ عَجَبًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcciv{قالَ ذٰلِكَ ما كُنّا نَبغِ فَارتَدّا عَلىٰ ءاثارِهِما قَصَصًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmccv{فَوَجَدا عَبدًا مِن عِبادِنا ءاتَينٰهُ رَحمَةً مِن عِندِنا وَعَلَّمنٰهُ مِن لَدُنّا عِلمًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmccvi{قالَ لَهُ موسىٰ هَل أَتَّبِعُكَ عَلىٰ أَن تُعَلِّمَنِ مِمّا عُلِّمتَ رُشدًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmccvii{قالَ إِنَّكَ لَن تَستَطيعَ مَعِىَ صَبرًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmccviii{وَكَيفَ تَصبِرُ عَلىٰ ما لَم تُحِط بِهِ خُبرًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmccix{قالَ سَتَجِدُنى إِن شاءَ اللَّهُ صابِرًا وَلا أَعصى لَكَ أَمرًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmccx{قالَ فَإِنِ اتَّبَعتَنى فَلا تَسـَٔلنى عَن شَيءٍ حَتّىٰ أُحدِثَ لَكَ مِنهُ ذِكرًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmccxi{فَانطَلَقا حَتّىٰ إِذا رَكِبا فِى السَّفينَةِ خَرَقَها قالَ أَخَرَقتَها لِتُغرِقَ أَهلَها لَقَد جِئتَ شَيـًٔا إِمرًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmccxii{قالَ أَلَم أَقُل إِنَّكَ لَن تَستَطيعَ مَعِىَ صَبرًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmccxiii{قالَ لا تُؤاخِذنى بِما نَسيتُ وَلا تُرهِقنى مِن أَمرى عُسرًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmccxiv{فَانطَلَقا حَتّىٰ إِذا لَقِيا غُلٰمًا فَقَتَلَهُ قالَ أَقَتَلتَ نَفسًا زَكِيَّةً بِغَيرِ نَفسٍ لَقَد جِئتَ شَيـًٔا نُكرًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmccxv{قالَ أَلَم أَقُل لَكَ إِنَّكَ لَن تَستَطيعَ مَعِىَ صَبرًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmccxvi{قالَ إِن سَأَلتُكَ عَن شَيءٍ بَعدَها فَلا تُصٰحِبنى قَد بَلَغتَ مِن لَدُنّى عُذرًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmccxvii{فَانطَلَقا حَتّىٰ إِذا أَتَيا أَهلَ قَريَةٍ استَطعَما أَهلَها فَأَبَوا أَن يُضَيِّفوهُما فَوَجَدا فيها جِدارًا يُريدُ أَن يَنقَضَّ فَأَقامَهُ قالَ لَو شِئتَ لَتَّخَذتَ عَلَيهِ أَجرًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmccxviii{قالَ هٰذا فِراقُ بَينى وَبَينِكَ سَأُنَبِّئُكَ بِتَأويلِ ما لَم تَستَطِع عَلَيهِ صَبرًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmccxix{أَمَّا السَّفينَةُ فَكانَت لِمَسٰكينَ يَعمَلونَ فِى البَحرِ فَأَرَدتُ أَن أَعيبَها وَكانَ وَراءَهُم مَلِكٌ يَأخُذُ كُلَّ سَفينَةٍ غَصبًا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmccxx{وَأَمَّا الغُلٰمُ فَكانَ أَبَواهُ مُؤمِنَينِ فَخَشينا أَن يُرهِقَهُما طُغيٰنًا وَكُفرًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmccxxi{فَأَرَدنا أَن يُبدِلَهُما رَبُّهُما خَيرًا مِنهُ زَكوٰةً وَأَقرَبَ رُحمًا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmccxxii{وَأَمَّا الجِدارُ فَكانَ لِغُلٰمَينِ يَتيمَينِ فِى المَدينَةِ وَكانَ تَحتَهُ كَنزٌ لَهُما وَكانَ أَبوهُما صٰلِحًا فَأَرادَ رَبُّكَ أَن يَبلُغا أَشُدَّهُما وَيَستَخرِجا كَنزَهُما رَحمَةً مِن رَبِّكَ وَما فَعَلتُهُ عَن أَمرى ذٰلِكَ تَأويلُ ما لَم تَسطِع عَلَيهِ صَبرًا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmccxxiii{وَيَسـَٔلونَكَ عَن ذِى القَرنَينِ قُل سَأَتلوا عَلَيكُم مِنهُ ذِكرًا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmccxxiv{إِنّا مَكَّنّا لَهُ فِى الأَرضِ وَءاتَينٰهُ مِن كُلِّ شَيءٍ سَبَبًا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmccxxv{فَأَتبَعَ سَبَبًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmccxxvi{حَتّىٰ إِذا بَلَغَ مَغرِبَ الشَّمسِ وَجَدَها تَغرُبُ فى عَينٍ حَمِئَةٍ وَوَجَدَ عِندَها قَومًا قُلنا يٰذَا القَرنَينِ إِمّا أَن تُعَذِّبَ وَإِمّا أَن تَتَّخِذَ فيهِم حُسنًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmccxxvii{قالَ أَمّا مَن ظَلَمَ فَسَوفَ نُعَذِّبُهُ ثُمَّ يُرَدُّ إِلىٰ رَبِّهِ فَيُعَذِّبُهُ عَذابًا نُكرًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmccxxviii{وَأَمّا مَن ءامَنَ وَعَمِلَ صٰلِحًا فَلَهُ جَزاءً الحُسنىٰ وَسَنَقولُ لَهُ مِن أَمرِنا يُسرًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmccxxix{ثُمَّ أَتبَعَ سَبَبًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmccxxx{حَتّىٰ إِذا بَلَغَ مَطلِعَ الشَّمسِ وَجَدَها تَطلُعُ عَلىٰ قَومٍ لَم نَجعَل لَهُم مِن دونِها سِترًا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmccxxxi{كَذٰلِكَ وَقَد أَحَطنا بِما لَدَيهِ خُبرًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmccxxxii{ثُمَّ أَتبَعَ سَبَبًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmccxxxiii{حَتّىٰ إِذا بَلَغَ بَينَ السَّدَّينِ وَجَدَ مِن دونِهِما قَومًا لا يَكادونَ يَفقَهونَ قَولًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmccxxxiv{قالوا يٰذَا القَرنَينِ إِنَّ يَأجوجَ وَمَأجوجَ مُفسِدونَ فِى الأَرضِ فَهَل نَجعَلُ لَكَ خَرجًا عَلىٰ أَن تَجعَلَ بَينَنا وَبَينَهُم سَدًّا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmccxxxv{قالَ ما مَكَّنّى فيهِ رَبّى خَيرٌ فَأَعينونى بِقُوَّةٍ أَجعَل بَينَكُم وَبَينَهُم رَدمًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmccxxxvi{ءاتونى زُبَرَ الحَديدِ حَتّىٰ إِذا ساوىٰ بَينَ الصَّدَفَينِ قالَ انفُخوا حَتّىٰ إِذا جَعَلَهُ نارًا قالَ ءاتونى أُفرِغ عَلَيهِ قِطرًا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmccxxxvii{فَمَا اسطٰعوا أَن يَظهَروهُ وَمَا استَطٰعوا لَهُ نَقبًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmccxxxviii{قالَ هٰذا رَحمَةٌ مِن رَبّى فَإِذا جاءَ وَعدُ رَبّى جَعَلَهُ دَكّاءَ وَكانَ وَعدُ رَبّى حَقًّا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmccxxxix{وَتَرَكنا بَعضَهُم يَومَئِذٍ يَموجُ فى بَعضٍ وَنُفِخَ فِى الصّورِ فَجَمَعنٰهُم جَمعًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmccxl{وَعَرَضنا جَهَنَّمَ يَومَئِذٍ لِلكٰفِرينَ عَرضًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmccxli{الَّذينَ كانَت أَعيُنُهُم فى غِطاءٍ عَن ذِكرى وَكانوا لا يَستَطيعونَ سَمعًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmccxlii{أَفَحَسِبَ الَّذينَ كَفَروا أَن يَتَّخِذوا عِبادى مِن دونى أَولِياءَ إِنّا أَعتَدنا جَهَنَّمَ لِلكٰفِرينَ نُزُلًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmccxliii{قُل هَل نُنَبِّئُكُم بِالأَخسَرينَ أَعمٰلًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmccxliv{الَّذينَ ضَلَّ سَعيُهُم فِى الحَيوٰةِ الدُّنيا وَهُم يَحسَبونَ أَنَّهُم يُحسِنونَ صُنعًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmccxlv{أُولٰئِكَ الَّذينَ كَفَروا بِـٔايٰتِ رَبِّهِم وَلِقائِهِ فَحَبِطَت أَعمٰلُهُم فَلا نُقيمُ لَهُم يَومَ القِيٰمَةِ وَزنًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmccxlvi{ذٰلِكَ جَزاؤُهُم جَهَنَّمُ بِما كَفَروا وَاتَّخَذوا ءايٰتى وَرُسُلى هُزُوًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmccxlvii{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ كانَت لَهُم جَنّٰتُ الفِردَوسِ نُزُلًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmccxlviii{خٰلِدينَ فيها لا يَبغونَ عَنها حِوَلًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmccxlix{قُل لَو كانَ البَحرُ مِدادًا لِكَلِمٰتِ رَبّى لَنَفِدَ البَحرُ قَبلَ أَن تَنفَدَ كَلِمٰتُ رَبّى وَلَو جِئنا بِمِثلِهِ مَدَدًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmccl{قُل إِنَّما أَنا۠ بَشَرٌ مِثلُكُم يوحىٰ إِلَىَّ أَنَّما إِلٰهُكُم إِلٰهٌ وٰحِدٌ فَمَن كانَ يَرجوا لِقاءَ رَبِّهِ فَليَعمَل عَمَلًا صٰلِحًا وَلا يُشرِك بِعِبادَةِ رَبِّهِ أَحَدًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmccli{\basmalah  كهيعص\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcclii{ذِكرُ رَحمَتِ رَبِّكَ عَبدَهُ زَكَرِيّا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmccliii{إِذ نادىٰ رَبَّهُ نِداءً خَفِيًّا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmccliv{قالَ رَبِّ إِنّى وَهَنَ العَظمُ مِنّى وَاشتَعَلَ الرَّأسُ شَيبًا وَلَم أَكُن بِدُعائِكَ رَبِّ شَقِيًّا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcclv{وَإِنّى خِفتُ المَوٰلِىَ مِن وَراءى وَكانَتِ امرَأَتى عاقِرًا فَهَب لى مِن لَدُنكَ وَلِيًّا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcclvi{يَرِثُنى وَيَرِثُ مِن ءالِ يَعقوبَ وَاجعَلهُ رَبِّ رَضِيًّا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcclvii{يٰزَكَرِيّا إِنّا نُبَشِّرُكَ بِغُلٰمٍ اسمُهُ يَحيىٰ لَم نَجعَل لَهُ مِن قَبلُ سَمِيًّا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcclviii{قالَ رَبِّ أَنّىٰ يَكونُ لى غُلٰمٌ وَكانَتِ امرَأَتى عاقِرًا وَقَد بَلَغتُ مِنَ الكِبَرِ عِتِيًّا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcclix{قالَ كَذٰلِكَ قالَ رَبُّكَ هُوَ عَلَىَّ هَيِّنٌ وَقَد خَلَقتُكَ مِن قَبلُ وَلَم تَكُ شَيـًٔا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcclx{قالَ رَبِّ اجعَل لى ءايَةً قالَ ءايَتُكَ أَلّا تُكَلِّمَ النّاسَ ثَلٰثَ لَيالٍ سَوِيًّا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcclxi{فَخَرَجَ عَلىٰ قَومِهِ مِنَ المِحرابِ فَأَوحىٰ إِلَيهِم أَن سَبِّحوا بُكرَةً وَعَشِيًّا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcclxii{يٰيَحيىٰ خُذِ الكِتٰبَ بِقُوَّةٍ وَءاتَينٰهُ الحُكمَ صَبِيًّا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcclxiii{وَحَنانًا مِن لَدُنّا وَزَكوٰةً وَكانَ تَقِيًّا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcclxiv{وَبَرًّا بِوٰلِدَيهِ وَلَم يَكُن جَبّارًا عَصِيًّا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcclxv{وَسَلٰمٌ عَلَيهِ يَومَ وُلِدَ وَيَومَ يَموتُ وَيَومَ يُبعَثُ حَيًّا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcclxvi{وَاذكُر فِى الكِتٰبِ مَريَمَ إِذِ انتَبَذَت مِن أَهلِها مَكانًا شَرقِيًّا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmcclxvii{فَاتَّخَذَت مِن دونِهِم حِجابًا فَأَرسَلنا إِلَيها روحَنا فَتَمَثَّلَ لَها بَشَرًا سَوِيًّا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmcclxviii{قالَت إِنّى أَعوذُ بِالرَّحمٰنِ مِنكَ إِن كُنتَ تَقِيًّا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmcclxix{قالَ إِنَّما أَنا۠ رَسولُ رَبِّكِ لِأَهَبَ لَكِ غُلٰمًا زَكِيًّا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmcclxx{قالَت أَنّىٰ يَكونُ لى غُلٰمٌ وَلَم يَمسَسنى بَشَرٌ وَلَم أَكُ بَغِيًّا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmcclxxi{قالَ كَذٰلِكِ قالَ رَبُّكِ هُوَ عَلَىَّ هَيِّنٌ وَلِنَجعَلَهُ ءايَةً لِلنّاسِ وَرَحمَةً مِنّا وَكانَ أَمرًا مَقضِيًّا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmcclxxii{فَحَمَلَتهُ فَانتَبَذَت بِهِ مَكانًا قَصِيًّا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmcclxxiii{فَأَجاءَهَا المَخاضُ إِلىٰ جِذعِ النَّخلَةِ قالَت يٰلَيتَنى مِتُّ قَبلَ هٰذا وَكُنتُ نَسيًا مَنسِيًّا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmcclxxiv{فَنادىٰها مِن تَحتِها أَلّا تَحزَنى قَد جَعَلَ رَبُّكِ تَحتَكِ سَرِيًّا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmcclxxv{وَهُزّى إِلَيكِ بِجِذعِ النَّخلَةِ تُسٰقِط عَلَيكِ رُطَبًا جَنِيًّا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmcclxxvi{فَكُلى وَاشرَبى وَقَرّى عَينًا فَإِمّا تَرَيِنَّ مِنَ البَشَرِ أَحَدًا فَقولى إِنّى نَذَرتُ لِلرَّحمٰنِ صَومًا فَلَن أُكَلِّمَ اليَومَ إِنسِيًّا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmcclxxvii{فَأَتَت بِهِ قَومَها تَحمِلُهُ قالوا يٰمَريَمُ لَقَد جِئتِ شَيـًٔا فَرِيًّا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmcclxxviii{يٰأُختَ هٰرونَ ما كانَ أَبوكِ امرَأَ سَوءٍ وَما كانَت أُمُّكِ بَغِيًّا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmcclxxix{فَأَشارَت إِلَيهِ قالوا كَيفَ نُكَلِّمُ مَن كانَ فِى المَهدِ صَبِيًّا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmcclxxx{قالَ إِنّى عَبدُ اللَّهِ ءاتىٰنِىَ الكِتٰبَ وَجَعَلَنى نَبِيًّا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmcclxxxi{وَجَعَلَنى مُبارَكًا أَينَ ما كُنتُ وَأَوصٰنى بِالصَّلوٰةِ وَالزَّكوٰةِ ما دُمتُ حَيًّا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmcclxxxii{وَبَرًّا بِوٰلِدَتى وَلَم يَجعَلنى جَبّارًا شَقِيًّا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmcclxxxiii{وَالسَّلٰمُ عَلَىَّ يَومَ وُلِدتُ وَيَومَ أَموتُ وَيَومَ أُبعَثُ حَيًّا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmcclxxxiv{ذٰلِكَ عيسَى ابنُ مَريَمَ قَولَ الحَقِّ الَّذى فيهِ يَمتَرونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmcclxxxv{ما كانَ لِلَّهِ أَن يَتَّخِذَ مِن وَلَدٍ سُبحٰنَهُ إِذا قَضىٰ أَمرًا فَإِنَّما يَقولُ لَهُ كُن فَيَكونُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmcclxxxvi{وَإِنَّ اللَّهَ رَبّى وَرَبُّكُم فَاعبُدوهُ هٰذا صِرٰطٌ مُستَقيمٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmcclxxxvii{فَاختَلَفَ الأَحزابُ مِن بَينِهِم فَوَيلٌ لِلَّذينَ كَفَروا مِن مَشهَدِ يَومٍ عَظيمٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmcclxxxviii{أَسمِع بِهِم وَأَبصِر يَومَ يَأتونَنا لٰكِنِ الظّٰلِمونَ اليَومَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmcclxxxix{وَأَنذِرهُم يَومَ الحَسرَةِ إِذ قُضِىَ الأَمرُ وَهُم فى غَفلَةٍ وَهُم لا يُؤمِنونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmccxc{إِنّا نَحنُ نَرِثُ الأَرضَ وَمَن عَلَيها وَإِلَينا يُرجَعونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmccxci{وَاذكُر فِى الكِتٰبِ إِبرٰهيمَ إِنَّهُ كانَ صِدّيقًا نَبِيًّا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmccxcii{إِذ قالَ لِأَبيهِ يٰأَبَتِ لِمَ تَعبُدُ ما لا يَسمَعُ وَلا يُبصِرُ وَلا يُغنى عَنكَ شَيـًٔا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmccxciii{يٰأَبَتِ إِنّى قَد جاءَنى مِنَ العِلمِ ما لَم يَأتِكَ فَاتَّبِعنى أَهدِكَ صِرٰطًا سَوِيًّا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmccxciv{يٰأَبَتِ لا تَعبُدِ الشَّيطٰنَ إِنَّ الشَّيطٰنَ كانَ لِلرَّحمٰنِ عَصِيًّا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmccxcv{يٰأَبَتِ إِنّى أَخافُ أَن يَمَسَّكَ عَذابٌ مِنَ الرَّحمٰنِ فَتَكونَ لِلشَّيطٰنِ وَلِيًّا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmccxcvi{قالَ أَراغِبٌ أَنتَ عَن ءالِهَتى يٰإِبرٰهيمُ لَئِن لَم تَنتَهِ لَأَرجُمَنَّكَ وَاهجُرنى مَلِيًّا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmccxcvii{قالَ سَلٰمٌ عَلَيكَ سَأَستَغفِرُ لَكَ رَبّى إِنَّهُ كانَ بى حَفِيًّا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmccxcviii{وَأَعتَزِلُكُم وَما تَدعونَ مِن دونِ اللَّهِ وَأَدعوا رَبّى عَسىٰ أَلّا أَكونَ بِدُعاءِ رَبّى شَقِيًّا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmccxcix{فَلَمَّا اعتَزَلَهُم وَما يَعبُدونَ مِن دونِ اللَّهِ وَهَبنا لَهُ إِسحٰقَ وَيَعقوبَ وَكُلًّا جَعَلنا نَبِيًّا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmccc{وَوَهَبنا لَهُم مِن رَحمَتِنا وَجَعَلنا لَهُم لِسانَ صِدقٍ عَلِيًّا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmccci{وَاذكُر فِى الكِتٰبِ موسىٰ إِنَّهُ كانَ مُخلَصًا وَكانَ رَسولًا نَبِيًّا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcccii{وَنٰدَينٰهُ مِن جانِبِ الطّورِ الأَيمَنِ وَقَرَّبنٰهُ نَجِيًّا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmccciii{وَوَهَبنا لَهُ مِن رَحمَتِنا أَخاهُ هٰرونَ نَبِيًّا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmccciv{وَاذكُر فِى الكِتٰبِ إِسمٰعيلَ إِنَّهُ كانَ صادِقَ الوَعدِ وَكانَ رَسولًا نَبِيًّا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcccv{وَكانَ يَأمُرُ أَهلَهُ بِالصَّلوٰةِ وَالزَّكوٰةِ وَكانَ عِندَ رَبِّهِ مَرضِيًّا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcccvi{وَاذكُر فِى الكِتٰبِ إِدريسَ إِنَّهُ كانَ صِدّيقًا نَبِيًّا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcccvii{وَرَفَعنٰهُ مَكانًا عَلِيًّا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcccviii{أُولٰئِكَ الَّذينَ أَنعَمَ اللَّهُ عَلَيهِم مِنَ النَّبِيّۦنَ مِن ذُرِّيَّةِ ءادَمَ وَمِمَّن حَمَلنا مَعَ نوحٍ وَمِن ذُرِّيَّةِ إِبرٰهيمَ وَإِسرٰءيلَ وَمِمَّن هَدَينا وَاجتَبَينا إِذا تُتلىٰ عَلَيهِم ءايٰتُ الرَّحمٰنِ خَرّوا سُجَّدًا وَبُكِيًّا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcccix{فَخَلَفَ مِن بَعدِهِم خَلفٌ أَضاعُوا الصَّلوٰةَ وَاتَّبَعُوا الشَّهَوٰتِ فَسَوفَ يَلقَونَ غَيًّا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcccx{إِلّا مَن تابَ وَءامَنَ وَعَمِلَ صٰلِحًا فَأُولٰئِكَ يَدخُلونَ الجَنَّةَ وَلا يُظلَمونَ شَيـًٔا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcccxi{جَنّٰتِ عَدنٍ الَّتى وَعَدَ الرَّحمٰنُ عِبادَهُ بِالغَيبِ إِنَّهُ كانَ وَعدُهُ مَأتِيًّا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcccxii{لا يَسمَعونَ فيها لَغوًا إِلّا سَلٰمًا وَلَهُم رِزقُهُم فيها بُكرَةً وَعَشِيًّا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcccxiii{تِلكَ الجَنَّةُ الَّتى نورِثُ مِن عِبادِنا مَن كانَ تَقِيًّا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcccxiv{وَما نَتَنَزَّلُ إِلّا بِأَمرِ رَبِّكَ لَهُ ما بَينَ أَيدينا وَما خَلفَنا وَما بَينَ ذٰلِكَ وَما كانَ رَبُّكَ نَسِيًّا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcccxv{رَبُّ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُما فَاعبُدهُ وَاصطَبِر لِعِبٰدَتِهِ هَل تَعلَمُ لَهُ سَمِيًّا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcccxvi{وَيَقولُ الإِنسٰنُ أَءِذا ما مِتُّ لَسَوفَ أُخرَجُ حَيًّا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcccxvii{أَوَلا يَذكُرُ الإِنسٰنُ أَنّا خَلَقنٰهُ مِن قَبلُ وَلَم يَكُ شَيـًٔا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcccxviii{فَوَرَبِّكَ لَنَحشُرَنَّهُم وَالشَّيٰطينَ ثُمَّ لَنُحضِرَنَّهُم حَولَ جَهَنَّمَ جِثِيًّا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcccxix{ثُمَّ لَنَنزِعَنَّ مِن كُلِّ شيعَةٍ أَيُّهُم أَشَدُّ عَلَى الرَّحمٰنِ عِتِيًّا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcccxx{ثُمَّ لَنَحنُ أَعلَمُ بِالَّذينَ هُم أَولىٰ بِها صِلِيًّا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcccxxi{وَإِن مِنكُم إِلّا وارِدُها كانَ عَلىٰ رَبِّكَ حَتمًا مَقضِيًّا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcccxxii{ثُمَّ نُنَجِّى الَّذينَ اتَّقَوا وَنَذَرُ الظّٰلِمينَ فيها جِثِيًّا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcccxxiii{وَإِذا تُتلىٰ عَلَيهِم ءايٰتُنا بَيِّنٰتٍ قالَ الَّذينَ كَفَروا لِلَّذينَ ءامَنوا أَىُّ الفَريقَينِ خَيرٌ مَقامًا وَأَحسَنُ نَدِيًّا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcccxxiv{وَكَم أَهلَكنا قَبلَهُم مِن قَرنٍ هُم أَحسَنُ أَثٰثًا وَرِءيًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcccxxv{قُل مَن كانَ فِى الضَّلٰلَةِ فَليَمدُد لَهُ الرَّحمٰنُ مَدًّا حَتّىٰ إِذا رَأَوا ما يوعَدونَ إِمَّا العَذابَ وَإِمَّا السّاعَةَ فَسَيَعلَمونَ مَن هُوَ شَرٌّ مَكانًا وَأَضعَفُ جُندًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcccxxvi{وَيَزيدُ اللَّهُ الَّذينَ اهتَدَوا هُدًى وَالبٰقِيٰتُ الصّٰلِحٰتُ خَيرٌ عِندَ رَبِّكَ ثَوابًا وَخَيرٌ مَرَدًّا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcccxxvii{أَفَرَءَيتَ الَّذى كَفَرَ بِـٔايٰتِنا وَقالَ لَأوتَيَنَّ مالًا وَوَلَدًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcccxxviii{أَطَّلَعَ الغَيبَ أَمِ اتَّخَذَ عِندَ الرَّحمٰنِ عَهدًا\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcccxxix{كَلّا سَنَكتُبُ ما يَقولُ وَنَمُدُّ لَهُ مِنَ العَذابِ مَدًّا\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcccxxx{وَنَرِثُهُ ما يَقولُ وَيَأتينا فَردًا\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcccxxxi{وَاتَّخَذوا مِن دونِ اللَّهِ ءالِهَةً لِيَكونوا لَهُم عِزًّا\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcccxxxii{كَلّا سَيَكفُرونَ بِعِبادَتِهِم وَيَكونونَ عَلَيهِم ضِدًّا\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcccxxxiii{أَلَم تَرَ أَنّا أَرسَلنَا الشَّيٰطينَ عَلَى الكٰفِرينَ تَؤُزُّهُم أَزًّا\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcccxxxiv{فَلا تَعجَل عَلَيهِم إِنَّما نَعُدُّ لَهُم عَدًّا\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcccxxxv{يَومَ نَحشُرُ المُتَّقينَ إِلَى الرَّحمٰنِ وَفدًا\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcccxxxvi{وَنَسوقُ المُجرِمينَ إِلىٰ جَهَنَّمَ وِردًا\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcccxxxvii{لا يَملِكونَ الشَّفٰعَةَ إِلّا مَنِ اتَّخَذَ عِندَ الرَّحمٰنِ عَهدًا\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcccxxxviii{وَقالُوا اتَّخَذَ الرَّحمٰنُ وَلَدًا\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcccxxxix{لَقَد جِئتُم شَيـًٔا إِدًّا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcccxl{تَكادُ السَّمٰوٰتُ يَتَفَطَّرنَ مِنهُ وَتَنشَقُّ الأَرضُ وَتَخِرُّ الجِبالُ هَدًّا\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcccxli{أَن دَعَوا لِلرَّحمٰنِ وَلَدًا\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcccxlii{وَما يَنبَغى لِلرَّحمٰنِ أَن يَتَّخِذَ وَلَدًا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcccxliii{إِن كُلُّ مَن فِى السَّمٰوٰتِ وَالأَرضِ إِلّا ءاتِى الرَّحمٰنِ عَبدًا\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcccxliv{لَقَد أَحصىٰهُم وَعَدَّهُم عَدًّا\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcccxlv{وَكُلُّهُم ءاتيهِ يَومَ القِيٰمَةِ فَردًا\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcccxlvi{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ سَيَجعَلُ لَهُمُ الرَّحمٰنُ وُدًّا\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcccxlvii{فَإِنَّما يَسَّرنٰهُ بِلِسانِكَ لِتُبَشِّرَ بِهِ المُتَّقينَ وَتُنذِرَ بِهِ قَومًا لُدًّا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcccxlviii{وَكَم أَهلَكنا قَبلَهُم مِن قَرنٍ هَل تُحِسُّ مِنهُم مِن أَحَدٍ أَو تَسمَعُ لَهُم رِكزًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcccxlix{\basmalah  طه\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcccl{ما أَنزَلنا عَلَيكَ القُرءانَ لِتَشقىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcccli{إِلّا تَذكِرَةً لِمَن يَخشىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmccclii{تَنزيلًا مِمَّن خَلَقَ الأَرضَ وَالسَّمٰوٰتِ العُلَى\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcccliii{الرَّحمٰنُ عَلَى العَرشِ استَوىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcccliv{لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَما بَينَهُما وَما تَحتَ الثَّرىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmccclv{وَإِن تَجهَر بِالقَولِ فَإِنَّهُ يَعلَمُ السِّرَّ وَأَخفَى\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmccclvi{اللَّهُ لا إِلٰهَ إِلّا هُوَ لَهُ الأَسماءُ الحُسنىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmccclvii{وَهَل أَتىٰكَ حَديثُ موسىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmccclviii{إِذ رَءا نارًا فَقالَ لِأَهلِهِ امكُثوا إِنّى ءانَستُ نارًا لَعَلّى ءاتيكُم مِنها بِقَبَسٍ أَو أَجِدُ عَلَى النّارِ هُدًى\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmccclix{فَلَمّا أَتىٰها نودِىَ يٰموسىٰ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmccclx{إِنّى أَنا۠ رَبُّكَ فَاخلَع نَعلَيكَ إِنَّكَ بِالوادِ المُقَدَّسِ طُوًى\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmccclxi{وَأَنَا اختَرتُكَ فَاستَمِع لِما يوحىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmccclxii{إِنَّنى أَنَا اللَّهُ لا إِلٰهَ إِلّا أَنا۠ فَاعبُدنى وَأَقِمِ الصَّلوٰةَ لِذِكرى\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmccclxiii{إِنَّ السّاعَةَ ءاتِيَةٌ أَكادُ أُخفيها لِتُجزىٰ كُلُّ نَفسٍ بِما تَسعىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmccclxiv{فَلا يَصُدَّنَّكَ عَنها مَن لا يُؤمِنُ بِها وَاتَّبَعَ هَوىٰهُ فَتَردىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmccclxv{وَما تِلكَ بِيَمينِكَ يٰموسىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmccclxvi{قالَ هِىَ عَصاىَ أَتَوَكَّؤُا۟ عَلَيها وَأَهُشُّ بِها عَلىٰ غَنَمى وَلِىَ فيها مَـٔارِبُ أُخرىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmccclxvii{قالَ أَلقِها يٰموسىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmccclxviii{فَأَلقىٰها فَإِذا هِىَ حَيَّةٌ تَسعىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmccclxix{قالَ خُذها وَلا تَخَف سَنُعيدُها سيرَتَهَا الأولىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmccclxx{وَاضمُم يَدَكَ إِلىٰ جَناحِكَ تَخرُج بَيضاءَ مِن غَيرِ سوءٍ ءايَةً أُخرىٰ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmccclxxi{لِنُرِيَكَ مِن ءايٰتِنَا الكُبرَى\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmccclxxii{اذهَب إِلىٰ فِرعَونَ إِنَّهُ طَغىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmccclxxiii{قالَ رَبِّ اشرَح لى صَدرى\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmccclxxiv{وَيَسِّر لى أَمرى\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmccclxxv{وَاحلُل عُقدَةً مِن لِسانى\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmccclxxvi{يَفقَهوا قَولى\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmccclxxvii{وَاجعَل لى وَزيرًا مِن أَهلى\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmccclxxviii{هٰرونَ أَخِى\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmccclxxix{اشدُد بِهِ أَزرى\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmccclxxx{وَأَشرِكهُ فى أَمرى\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmccclxxxi{كَى نُسَبِّحَكَ كَثيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmccclxxxii{وَنَذكُرَكَ كَثيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmccclxxxiii{إِنَّكَ كُنتَ بِنا بَصيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmccclxxxiv{قالَ قَد أوتيتَ سُؤلَكَ يٰموسىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmccclxxxv{وَلَقَد مَنَنّا عَلَيكَ مَرَّةً أُخرىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmccclxxxvi{إِذ أَوحَينا إِلىٰ أُمِّكَ ما يوحىٰ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmccclxxxvii{أَنِ اقذِفيهِ فِى التّابوتِ فَاقذِفيهِ فِى اليَمِّ فَليُلقِهِ اليَمُّ بِالسّاحِلِ يَأخُذهُ عَدُوٌّ لى وَعَدُوٌّ لَهُ وَأَلقَيتُ عَلَيكَ مَحَبَّةً مِنّى وَلِتُصنَعَ عَلىٰ عَينى\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmccclxxxviii{إِذ تَمشى أُختُكَ فَتَقولُ هَل أَدُلُّكُم عَلىٰ مَن يَكفُلُهُ فَرَجَعنٰكَ إِلىٰ أُمِّكَ كَى تَقَرَّ عَينُها وَلا تَحزَنَ وَقَتَلتَ نَفسًا فَنَجَّينٰكَ مِنَ الغَمِّ وَفَتَنّٰكَ فُتونًا فَلَبِثتَ سِنينَ فى أَهلِ مَديَنَ ثُمَّ جِئتَ عَلىٰ قَدَرٍ يٰموسىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmccclxxxix{وَاصطَنَعتُكَ لِنَفسِى\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmcccxc{اذهَب أَنتَ وَأَخوكَ بِـٔايٰتى وَلا تَنِيا فى ذِكرِى\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmcccxci{اذهَبا إِلىٰ فِرعَونَ إِنَّهُ طَغىٰ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmcccxcii{فَقولا لَهُ قَولًا لَيِّنًا لَعَلَّهُ يَتَذَكَّرُ أَو يَخشىٰ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcccxciii{قالا رَبَّنا إِنَّنا نَخافُ أَن يَفرُطَ عَلَينا أَو أَن يَطغىٰ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcccxciv{قالَ لا تَخافا إِنَّنى مَعَكُما أَسمَعُ وَأَرىٰ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcccxcv{فَأتِياهُ فَقولا إِنّا رَسولا رَبِّكَ فَأَرسِل مَعَنا بَنى إِسرٰءيلَ وَلا تُعَذِّبهُم قَد جِئنٰكَ بِـٔايَةٍ مِن رَبِّكَ وَالسَّلٰمُ عَلىٰ مَنِ اتَّبَعَ الهُدىٰ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcccxcvi{إِنّا قَد أوحِىَ إِلَينا أَنَّ العَذابَ عَلىٰ مَن كَذَّبَ وَتَوَلّىٰ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcccxcvii{قالَ فَمَن رَبُّكُما يٰموسىٰ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcccxcviii{قالَ رَبُّنَا الَّذى أَعطىٰ كُلَّ شَيءٍ خَلقَهُ ثُمَّ هَدىٰ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcccxcix{قالَ فَما بالُ القُرونِ الأولىٰ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcd{قالَ عِلمُها عِندَ رَبّى فى كِتٰبٍ لا يَضِلُّ رَبّى وَلا يَنسَى\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcdi{الَّذى جَعَلَ لَكُمُ الأَرضَ مَهدًا وَسَلَكَ لَكُم فيها سُبُلًا وَأَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجنا بِهِ أَزوٰجًا مِن نَباتٍ شَتّىٰ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcdii{كُلوا وَارعَوا أَنعٰمَكُم إِنَّ فى ذٰلِكَ لَءايٰتٍ لِأُولِى النُّهىٰ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcdiii{مِنها خَلَقنٰكُم وَفيها نُعيدُكُم وَمِنها نُخرِجُكُم تارَةً أُخرىٰ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcdiv{وَلَقَد أَرَينٰهُ ءايٰتِنا كُلَّها فَكَذَّبَ وَأَبىٰ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcdv{قالَ أَجِئتَنا لِتُخرِجَنا مِن أَرضِنا بِسِحرِكَ يٰموسىٰ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcdvi{فَلَنَأتِيَنَّكَ بِسِحرٍ مِثلِهِ فَاجعَل بَينَنا وَبَينَكَ مَوعِدًا لا نُخلِفُهُ نَحنُ وَلا أَنتَ مَكانًا سُوًى\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcdvii{قالَ مَوعِدُكُم يَومُ الزّينَةِ وَأَن يُحشَرَ النّاسُ ضُحًى\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcdviii{فَتَوَلّىٰ فِرعَونُ فَجَمَعَ كَيدَهُ ثُمَّ أَتىٰ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcdix{قالَ لَهُم موسىٰ وَيلَكُم لا تَفتَروا عَلَى اللَّهِ كَذِبًا فَيُسحِتَكُم بِعَذابٍ وَقَد خابَ مَنِ افتَرىٰ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcdx{فَتَنٰزَعوا أَمرَهُم بَينَهُم وَأَسَرُّوا النَّجوىٰ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcdxi{قالوا إِن هٰذٰنِ لَسٰحِرٰنِ يُريدانِ أَن يُخرِجاكُم مِن أَرضِكُم بِسِحرِهِما وَيَذهَبا بِطَريقَتِكُمُ المُثلىٰ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcdxii{فَأَجمِعوا كَيدَكُم ثُمَّ ائتوا صَفًّا وَقَد أَفلَحَ اليَومَ مَنِ استَعلىٰ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcdxiii{قالوا يٰموسىٰ إِمّا أَن تُلقِىَ وَإِمّا أَن نَكونَ أَوَّلَ مَن أَلقىٰ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcdxiv{قالَ بَل أَلقوا فَإِذا حِبالُهُم وَعِصِيُّهُم يُخَيَّلُ إِلَيهِ مِن سِحرِهِم أَنَّها تَسعىٰ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcdxv{فَأَوجَسَ فى نَفسِهِ خيفَةً موسىٰ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcdxvi{قُلنا لا تَخَف إِنَّكَ أَنتَ الأَعلىٰ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcdxvii{وَأَلقِ ما فى يَمينِكَ تَلقَف ما صَنَعوا إِنَّما صَنَعوا كَيدُ سٰحِرٍ وَلا يُفلِحُ السّاحِرُ حَيثُ أَتىٰ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcdxviii{فَأُلقِىَ السَّحَرَةُ سُجَّدًا قالوا ءامَنّا بِرَبِّ هٰرونَ وَموسىٰ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcdxix{قالَ ءامَنتُم لَهُ قَبلَ أَن ءاذَنَ لَكُم إِنَّهُ لَكَبيرُكُمُ الَّذى عَلَّمَكُمُ السِّحرَ فَلَأُقَطِّعَنَّ أَيدِيَكُم وَأَرجُلَكُم مِن خِلٰفٍ وَلَأُصَلِّبَنَّكُم فى جُذوعِ النَّخلِ وَلَتَعلَمُنَّ أَيُّنا أَشَدُّ عَذابًا وَأَبقىٰ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcdxx{قالوا لَن نُؤثِرَكَ عَلىٰ ما جاءَنا مِنَ البَيِّنٰتِ وَالَّذى فَطَرَنا فَاقضِ ما أَنتَ قاضٍ إِنَّما تَقضى هٰذِهِ الحَيوٰةَ الدُّنيا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcdxxi{إِنّا ءامَنّا بِرَبِّنا لِيَغفِرَ لَنا خَطٰيٰنا وَما أَكرَهتَنا عَلَيهِ مِنَ السِّحرِ وَاللَّهُ خَيرٌ وَأَبقىٰ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcdxxii{إِنَّهُ مَن يَأتِ رَبَّهُ مُجرِمًا فَإِنَّ لَهُ جَهَنَّمَ لا يَموتُ فيها وَلا يَحيىٰ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcdxxiii{وَمَن يَأتِهِ مُؤمِنًا قَد عَمِلَ الصّٰلِحٰتِ فَأُولٰئِكَ لَهُمُ الدَّرَجٰتُ العُلىٰ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcdxxiv{جَنّٰتُ عَدنٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها وَذٰلِكَ جَزاءُ مَن تَزَكّىٰ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcdxxv{وَلَقَد أَوحَينا إِلىٰ موسىٰ أَن أَسرِ بِعِبادى فَاضرِب لَهُم طَريقًا فِى البَحرِ يَبَسًا لا تَخٰفُ دَرَكًا وَلا تَخشىٰ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcdxxvi{فَأَتبَعَهُم فِرعَونُ بِجُنودِهِ فَغَشِيَهُم مِنَ اليَمِّ ما غَشِيَهُم\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmcdxxvii{وَأَضَلَّ فِرعَونُ قَومَهُ وَما هَدىٰ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmcdxxviii{يٰبَنى إِسرٰءيلَ قَد أَنجَينٰكُم مِن عَدُوِّكُم وَوٰعَدنٰكُم جانِبَ الطّورِ الأَيمَنَ وَنَزَّلنا عَلَيكُمُ المَنَّ وَالسَّلوىٰ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmcdxxix{كُلوا مِن طَيِّبٰتِ ما رَزَقنٰكُم وَلا تَطغَوا فيهِ فَيَحِلَّ عَلَيكُم غَضَبى وَمَن يَحلِل عَلَيهِ غَضَبى فَقَد هَوىٰ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmcdxxx{وَإِنّى لَغَفّارٌ لِمَن تابَ وَءامَنَ وَعَمِلَ صٰلِحًا ثُمَّ اهتَدىٰ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmcdxxxi{وَما أَعجَلَكَ عَن قَومِكَ يٰموسىٰ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmcdxxxii{قالَ هُم أُولاءِ عَلىٰ أَثَرى وَعَجِلتُ إِلَيكَ رَبِّ لِتَرضىٰ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmcdxxxiii{قالَ فَإِنّا قَد فَتَنّا قَومَكَ مِن بَعدِكَ وَأَضَلَّهُمُ السّامِرِىُّ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmcdxxxiv{فَرَجَعَ موسىٰ إِلىٰ قَومِهِ غَضبٰنَ أَسِفًا قالَ يٰقَومِ أَلَم يَعِدكُم رَبُّكُم وَعدًا حَسَنًا أَفَطالَ عَلَيكُمُ العَهدُ أَم أَرَدتُم أَن يَحِلَّ عَلَيكُم غَضَبٌ مِن رَبِّكُم فَأَخلَفتُم مَوعِدى\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmcdxxxv{قالوا ما أَخلَفنا مَوعِدَكَ بِمَلكِنا وَلٰكِنّا حُمِّلنا أَوزارًا مِن زينَةِ القَومِ فَقَذَفنٰها فَكَذٰلِكَ أَلقَى السّامِرِىُّ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmcdxxxvi{فَأَخرَجَ لَهُم عِجلًا جَسَدًا لَهُ خُوارٌ فَقالوا هٰذا إِلٰهُكُم وَإِلٰهُ موسىٰ فَنَسِىَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmcdxxxvii{أَفَلا يَرَونَ أَلّا يَرجِعُ إِلَيهِم قَولًا وَلا يَملِكُ لَهُم ضَرًّا وَلا نَفعًا\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmcdxxxviii{وَلَقَد قالَ لَهُم هٰرونُ مِن قَبلُ يٰقَومِ إِنَّما فُتِنتُم بِهِ وَإِنَّ رَبَّكُمُ الرَّحمٰنُ فَاتَّبِعونى وَأَطيعوا أَمرى\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmcdxxxix{قالوا لَن نَبرَحَ عَلَيهِ عٰكِفينَ حَتّىٰ يَرجِعَ إِلَينا موسىٰ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmcdxl{قالَ يٰهٰرونُ ما مَنَعَكَ إِذ رَأَيتَهُم ضَلّوا\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmcdxli{أَلّا تَتَّبِعَنِ أَفَعَصَيتَ أَمرى\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmcdxlii{قالَ يَبنَؤُمَّ لا تَأخُذ بِلِحيَتى وَلا بِرَأسى إِنّى خَشيتُ أَن تَقولَ فَرَّقتَ بَينَ بَنى إِسرٰءيلَ وَلَم تَرقُب قَولى\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmcdxliii{قالَ فَما خَطبُكَ يٰسٰمِرِىُّ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmcdxliv{قالَ بَصُرتُ بِما لَم يَبصُروا بِهِ فَقَبَضتُ قَبضَةً مِن أَثَرِ الرَّسولِ فَنَبَذتُها وَكَذٰلِكَ سَوَّلَت لى نَفسى\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmcdxlv{قالَ فَاذهَب فَإِنَّ لَكَ فِى الحَيوٰةِ أَن تَقولَ لا مِساسَ وَإِنَّ لَكَ مَوعِدًا لَن تُخلَفَهُ وَانظُر إِلىٰ إِلٰهِكَ الَّذى ظَلتَ عَلَيهِ عاكِفًا لَنُحَرِّقَنَّهُ ثُمَّ لَنَنسِفَنَّهُ فِى اليَمِّ نَسفًا\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmcdxlvi{إِنَّما إِلٰهُكُمُ اللَّهُ الَّذى لا إِلٰهَ إِلّا هُوَ وَسِعَ كُلَّ شَيءٍ عِلمًا\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmcdxlvii{كَذٰلِكَ نَقُصُّ عَلَيكَ مِن أَنباءِ ما قَد سَبَقَ وَقَد ءاتَينٰكَ مِن لَدُنّا ذِكرًا\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmcdxlviii{مَن أَعرَضَ عَنهُ فَإِنَّهُ يَحمِلُ يَومَ القِيٰمَةِ وِزرًا\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmcdxlix{خٰلِدينَ فيهِ وَساءَ لَهُم يَومَ القِيٰمَةِ حِملًا\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmcdl{يَومَ يُنفَخُ فِى الصّورِ وَنَحشُرُ المُجرِمينَ يَومَئِذٍ زُرقًا\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmcdli{يَتَخٰفَتونَ بَينَهُم إِن لَبِثتُم إِلّا عَشرًا\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmcdlii{نَحنُ أَعلَمُ بِما يَقولونَ إِذ يَقولُ أَمثَلُهُم طَريقَةً إِن لَبِثتُم إِلّا يَومًا\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmcdliii{وَيَسـَٔلونَكَ عَنِ الجِبالِ فَقُل يَنسِفُها رَبّى نَسفًا\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmcdliv{فَيَذَرُها قاعًا صَفصَفًا\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmcdlv{لا تَرىٰ فيها عِوَجًا وَلا أَمتًا\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmcdlvi{يَومَئِذٍ يَتَّبِعونَ الدّاعِىَ لا عِوَجَ لَهُ وَخَشَعَتِ الأَصواتُ لِلرَّحمٰنِ فَلا تَسمَعُ إِلّا هَمسًا\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmcdlvii{يَومَئِذٍ لا تَنفَعُ الشَّفٰعَةُ إِلّا مَن أَذِنَ لَهُ الرَّحمٰنُ وَرَضِىَ لَهُ قَولًا\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmcdlviii{يَعلَمُ ما بَينَ أَيديهِم وَما خَلفَهُم وَلا يُحيطونَ بِهِ عِلمًا\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmcdlix{وَعَنَتِ الوُجوهُ لِلحَىِّ القَيّومِ وَقَد خابَ مَن حَمَلَ ظُلمًا\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmcdlx{وَمَن يَعمَل مِنَ الصّٰلِحٰتِ وَهُوَ مُؤمِنٌ فَلا يَخافُ ظُلمًا وَلا هَضمًا\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmcdlxi{وَكَذٰلِكَ أَنزَلنٰهُ قُرءانًا عَرَبِيًّا وَصَرَّفنا فيهِ مِنَ الوَعيدِ لَعَلَّهُم يَتَّقونَ أَو يُحدِثُ لَهُم ذِكرًا\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmcdlxii{فَتَعٰلَى اللَّهُ المَلِكُ الحَقُّ وَلا تَعجَل بِالقُرءانِ مِن قَبلِ أَن يُقضىٰ إِلَيكَ وَحيُهُ وَقُل رَبِّ زِدنى عِلمًا\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmcdlxiii{وَلَقَد عَهِدنا إِلىٰ ءادَمَ مِن قَبلُ فَنَسِىَ وَلَم نَجِد لَهُ عَزمًا\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmcdlxiv{وَإِذ قُلنا لِلمَلٰئِكَةِ اسجُدوا لِءادَمَ فَسَجَدوا إِلّا إِبليسَ أَبىٰ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmcdlxv{فَقُلنا يٰـٔادَمُ إِنَّ هٰذا عَدُوٌّ لَكَ وَلِزَوجِكَ فَلا يُخرِجَنَّكُما مِنَ الجَنَّةِ فَتَشقىٰ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmcdlxvi{إِنَّ لَكَ أَلّا تَجوعَ فيها وَلا تَعرىٰ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmcdlxvii{وَأَنَّكَ لا تَظمَؤُا۟ فيها وَلا تَضحىٰ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmcdlxviii{فَوَسوَسَ إِلَيهِ الشَّيطٰنُ قالَ يٰـٔادَمُ هَل أَدُلُّكَ عَلىٰ شَجَرَةِ الخُلدِ وَمُلكٍ لا يَبلىٰ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmcdlxix{فَأَكَلا مِنها فَبَدَت لَهُما سَوءٰتُهُما وَطَفِقا يَخصِفانِ عَلَيهِما مِن وَرَقِ الجَنَّةِ وَعَصىٰ ءادَمُ رَبَّهُ فَغَوىٰ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmcdlxx{ثُمَّ اجتَبٰهُ رَبُّهُ فَتابَ عَلَيهِ وَهَدىٰ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmcdlxxi{قالَ اهبِطا مِنها جَميعًا بَعضُكُم لِبَعضٍ عَدُوٌّ فَإِمّا يَأتِيَنَّكُم مِنّى هُدًى فَمَنِ اتَّبَعَ هُداىَ فَلا يَضِلُّ وَلا يَشقىٰ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmcdlxxii{وَمَن أَعرَضَ عَن ذِكرى فَإِنَّ لَهُ مَعيشَةً ضَنكًا وَنَحشُرُهُ يَومَ القِيٰمَةِ أَعمىٰ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmcdlxxiii{قالَ رَبِّ لِمَ حَشَرتَنى أَعمىٰ وَقَد كُنتُ بَصيرًا\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmcdlxxiv{قالَ كَذٰلِكَ أَتَتكَ ءايٰتُنا فَنَسيتَها وَكَذٰلِكَ اليَومَ تُنسىٰ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmcdlxxv{وَكَذٰلِكَ نَجزى مَن أَسرَفَ وَلَم يُؤمِن بِـٔايٰتِ رَبِّهِ وَلَعَذابُ الءاخِرَةِ أَشَدُّ وَأَبقىٰ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmcdlxxvi{أَفَلَم يَهدِ لَهُم كَم أَهلَكنا قَبلَهُم مِنَ القُرونِ يَمشونَ فى مَسٰكِنِهِم إِنَّ فى ذٰلِكَ لَءايٰتٍ لِأُولِى النُّهىٰ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmcdlxxvii{وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ لَكانَ لِزامًا وَأَجَلٌ مُسَمًّى\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmcdlxxviii{فَاصبِر عَلىٰ ما يَقولونَ وَسَبِّح بِحَمدِ رَبِّكَ قَبلَ طُلوعِ الشَّمسِ وَقَبلَ غُروبِها وَمِن ءانائِ الَّيلِ فَسَبِّح وَأَطرافَ النَّهارِ لَعَلَّكَ تَرضىٰ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmcdlxxix{وَلا تَمُدَّنَّ عَينَيكَ إِلىٰ ما مَتَّعنا بِهِ أَزوٰجًا مِنهُم زَهرَةَ الحَيوٰةِ الدُّنيا لِنَفتِنَهُم فيهِ وَرِزقُ رَبِّكَ خَيرٌ وَأَبقىٰ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmcdlxxx{وَأمُر أَهلَكَ بِالصَّلوٰةِ وَاصطَبِر عَلَيها لا نَسـَٔلُكَ رِزقًا نَحنُ نَرزُقُكَ وَالعٰقِبَةُ لِلتَّقوىٰ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmcdlxxxi{وَقالوا لَولا يَأتينا بِـٔايَةٍ مِن رَبِّهِ أَوَلَم تَأتِهِم بَيِّنَةُ ما فِى الصُّحُفِ الأولىٰ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmcdlxxxii{وَلَو أَنّا أَهلَكنٰهُم بِعَذابٍ مِن قَبلِهِ لَقالوا رَبَّنا لَولا أَرسَلتَ إِلَينا رَسولًا فَنَتَّبِعَ ءايٰتِكَ مِن قَبلِ أَن نَذِلَّ وَنَخزىٰ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmcdlxxxiii{قُل كُلٌّ مُتَرَبِّصٌ فَتَرَبَّصوا فَسَتَعلَمونَ مَن أَصحٰبُ الصِّرٰطِ السَّوِىِّ وَمَنِ اهتَدىٰ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmcdlxxxiv{\basmalah  اقتَرَبَ لِلنّاسِ حِسابُهُم وَهُم فى غَفلَةٍ مُعرِضونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcdlxxxv{ما يَأتيهِم مِن ذِكرٍ مِن رَبِّهِم مُحدَثٍ إِلَّا استَمَعوهُ وَهُم يَلعَبونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcdlxxxvi{لاهِيَةً قُلوبُهُم وَأَسَرُّوا النَّجوَى الَّذينَ ظَلَموا هَل هٰذا إِلّا بَشَرٌ مِثلُكُم أَفَتَأتونَ السِّحرَ وَأَنتُم تُبصِرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcdlxxxvii{قالَ رَبّى يَعلَمُ القَولَ فِى السَّماءِ وَالأَرضِ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcdlxxxviii{بَل قالوا أَضغٰثُ أَحلٰمٍ بَلِ افتَرىٰهُ بَل هُوَ شاعِرٌ فَليَأتِنا بِـٔايَةٍ كَما أُرسِلَ الأَوَّلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcdlxxxix{ما ءامَنَت قَبلَهُم مِن قَريَةٍ أَهلَكنٰها أَفَهُم يُؤمِنونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcdxc{وَما أَرسَلنا قَبلَكَ إِلّا رِجالًا نوحى إِلَيهِم فَسـَٔلوا أَهلَ الذِّكرِ إِن كُنتُم لا تَعلَمونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcdxci{وَما جَعَلنٰهُم جَسَدًا لا يَأكُلونَ الطَّعامَ وَما كانوا خٰلِدينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcdxcii{ثُمَّ صَدَقنٰهُمُ الوَعدَ فَأَنجَينٰهُم وَمَن نَشاءُ وَأَهلَكنَا المُسرِفينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcdxciii{لَقَد أَنزَلنا إِلَيكُم كِتٰبًا فيهِ ذِكرُكُم أَفَلا تَعقِلونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcdxciv{وَكَم قَصَمنا مِن قَريَةٍ كانَت ظالِمَةً وَأَنشَأنا بَعدَها قَومًا ءاخَرينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcdxcv{فَلَمّا أَحَسّوا بَأسَنا إِذا هُم مِنها يَركُضونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcdxcvi{لا تَركُضوا وَارجِعوا إِلىٰ ما أُترِفتُم فيهِ وَمَسٰكِنِكُم لَعَلَّكُم تُسـَٔلونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcdxcvii{قالوا يٰوَيلَنا إِنّا كُنّا ظٰلِمينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcdxcviii{فَما زالَت تِلكَ دَعوىٰهُم حَتّىٰ جَعَلنٰهُم حَصيدًا خٰمِدينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcdxcix{وَما خَلَقنَا السَّماءَ وَالأَرضَ وَما بَينَهُما لٰعِبينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmd{لَو أَرَدنا أَن نَتَّخِذَ لَهوًا لَاتَّخَذنٰهُ مِن لَدُنّا إِن كُنّا فٰعِلينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdi{بَل نَقذِفُ بِالحَقِّ عَلَى البٰطِلِ فَيَدمَغُهُ فَإِذا هُوَ زاهِقٌ وَلَكُمُ الوَيلُ مِمّا تَصِفونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdii{وَلَهُ مَن فِى السَّمٰوٰتِ وَالأَرضِ وَمَن عِندَهُ لا يَستَكبِرونَ عَن عِبادَتِهِ وَلا يَستَحسِرونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdiii{يُسَبِّحونَ الَّيلَ وَالنَّهارَ لا يَفتُرونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdiv{أَمِ اتَّخَذوا ءالِهَةً مِنَ الأَرضِ هُم يُنشِرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdv{لَو كانَ فيهِما ءالِهَةٌ إِلَّا اللَّهُ لَفَسَدَتا فَسُبحٰنَ اللَّهِ رَبِّ العَرشِ عَمّا يَصِفونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdvi{لا يُسـَٔلُ عَمّا يَفعَلُ وَهُم يُسـَٔلونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdvii{أَمِ اتَّخَذوا مِن دونِهِ ءالِهَةً قُل هاتوا بُرهٰنَكُم هٰذا ذِكرُ مَن مَعِىَ وَذِكرُ مَن قَبلى بَل أَكثَرُهُم لا يَعلَمونَ الحَقَّ فَهُم مُعرِضونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdviii{وَما أَرسَلنا مِن قَبلِكَ مِن رَسولٍ إِلّا نوحى إِلَيهِ أَنَّهُ لا إِلٰهَ إِلّا أَنا۠ فَاعبُدونِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdix{وَقالُوا اتَّخَذَ الرَّحمٰنُ وَلَدًا سُبحٰنَهُ بَل عِبادٌ مُكرَمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdx{لا يَسبِقونَهُ بِالقَولِ وَهُم بِأَمرِهِ يَعمَلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdxi{يَعلَمُ ما بَينَ أَيديهِم وَما خَلفَهُم وَلا يَشفَعونَ إِلّا لِمَنِ ارتَضىٰ وَهُم مِن خَشيَتِهِ مُشفِقونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdxii{وَمَن يَقُل مِنهُم إِنّى إِلٰهٌ مِن دونِهِ فَذٰلِكَ نَجزيهِ جَهَنَّمَ كَذٰلِكَ نَجزِى الظّٰلِمينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdxiii{أَوَلَم يَرَ الَّذينَ كَفَروا أَنَّ السَّمٰوٰتِ وَالأَرضَ كانَتا رَتقًا فَفَتَقنٰهُما وَجَعَلنا مِنَ الماءِ كُلَّ شَيءٍ حَىٍّ أَفَلا يُؤمِنونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdxiv{وَجَعَلنا فِى الأَرضِ رَوٰسِىَ أَن تَميدَ بِهِم وَجَعَلنا فيها فِجاجًا سُبُلًا لَعَلَّهُم يَهتَدونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdxv{وَجَعَلنَا السَّماءَ سَقفًا مَحفوظًا وَهُم عَن ءايٰتِها مُعرِضونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdxvi{وَهُوَ الَّذى خَلَقَ الَّيلَ وَالنَّهارَ وَالشَّمسَ وَالقَمَرَ كُلٌّ فى فَلَكٍ يَسبَحونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdxvii{وَما جَعَلنا لِبَشَرٍ مِن قَبلِكَ الخُلدَ أَفَإِي۟ن مِتَّ فَهُمُ الخٰلِدونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdxviii{كُلُّ نَفسٍ ذائِقَةُ المَوتِ وَنَبلوكُم بِالشَّرِّ وَالخَيرِ فِتنَةً وَإِلَينا تُرجَعونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdxix{وَإِذا رَءاكَ الَّذينَ كَفَروا إِن يَتَّخِذونَكَ إِلّا هُزُوًا أَهٰذَا الَّذى يَذكُرُ ءالِهَتَكُم وَهُم بِذِكرِ الرَّحمٰنِ هُم كٰفِرونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdxx{خُلِقَ الإِنسٰنُ مِن عَجَلٍ سَأُو۟ريكُم ءايٰتى فَلا تَستَعجِلونِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdxxi{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صٰدِقينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdxxii{لَو يَعلَمُ الَّذينَ كَفَروا حينَ لا يَكُفّونَ عَن وُجوهِهِمُ النّارَ وَلا عَن ظُهورِهِم وَلا هُم يُنصَرونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdxxiii{بَل تَأتيهِم بَغتَةً فَتَبهَتُهُم فَلا يَستَطيعونَ رَدَّها وَلا هُم يُنظَرونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdxxiv{وَلَقَدِ استُهزِئَ بِرُسُلٍ مِن قَبلِكَ فَحاقَ بِالَّذينَ سَخِروا مِنهُم ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdxxv{قُل مَن يَكلَؤُكُم بِالَّيلِ وَالنَّهارِ مِنَ الرَّحمٰنِ بَل هُم عَن ذِكرِ رَبِّهِم مُعرِضونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdxxvi{أَم لَهُم ءالِهَةٌ تَمنَعُهُم مِن دونِنا لا يَستَطيعونَ نَصرَ أَنفُسِهِم وَلا هُم مِنّا يُصحَبونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdxxvii{بَل مَتَّعنا هٰؤُلاءِ وَءاباءَهُم حَتّىٰ طالَ عَلَيهِمُ العُمُرُ أَفَلا يَرَونَ أَنّا نَأتِى الأَرضَ نَنقُصُها مِن أَطرافِها أَفَهُمُ الغٰلِبونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdxxviii{قُل إِنَّما أُنذِرُكُم بِالوَحىِ وَلا يَسمَعُ الصُّمُّ الدُّعاءَ إِذا ما يُنذَرونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdxxix{وَلَئِن مَسَّتهُم نَفحَةٌ مِن عَذابِ رَبِّكَ لَيَقولُنَّ يٰوَيلَنا إِنّا كُنّا ظٰلِمينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdxxx{وَنَضَعُ المَوٰزينَ القِسطَ لِيَومِ القِيٰمَةِ فَلا تُظلَمُ نَفسٌ شَيـًٔا وَإِن كانَ مِثقالَ حَبَّةٍ مِن خَردَلٍ أَتَينا بِها وَكَفىٰ بِنا حٰسِبينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdxxxi{وَلَقَد ءاتَينا موسىٰ وَهٰرونَ الفُرقانَ وَضِياءً وَذِكرًا لِلمُتَّقينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdxxxii{الَّذينَ يَخشَونَ رَبَّهُم بِالغَيبِ وَهُم مِنَ السّاعَةِ مُشفِقونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdxxxiii{وَهٰذا ذِكرٌ مُبارَكٌ أَنزَلنٰهُ أَفَأَنتُم لَهُ مُنكِرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdxxxiv{وَلَقَد ءاتَينا إِبرٰهيمَ رُشدَهُ مِن قَبلُ وَكُنّا بِهِ عٰلِمينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdxxxv{إِذ قالَ لِأَبيهِ وَقَومِهِ ما هٰذِهِ التَّماثيلُ الَّتى أَنتُم لَها عٰكِفونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdxxxvi{قالوا وَجَدنا ءاباءَنا لَها عٰبِدينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdxxxvii{قالَ لَقَد كُنتُم أَنتُم وَءاباؤُكُم فى ضَلٰلٍ مُبينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdxxxviii{قالوا أَجِئتَنا بِالحَقِّ أَم أَنتَ مِنَ اللّٰعِبينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdxxxix{قالَ بَل رَبُّكُم رَبُّ السَّمٰوٰتِ وَالأَرضِ الَّذى فَطَرَهُنَّ وَأَنا۠ عَلىٰ ذٰلِكُم مِنَ الشّٰهِدينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdxl{وَتَاللَّهِ لَأَكيدَنَّ أَصنٰمَكُم بَعدَ أَن تُوَلّوا مُدبِرينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdxli{فَجَعَلَهُم جُذٰذًا إِلّا كَبيرًا لَهُم لَعَلَّهُم إِلَيهِ يَرجِعونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdxlii{قالوا مَن فَعَلَ هٰذا بِـٔالِهَتِنا إِنَّهُ لَمِنَ الظّٰلِمينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdxliii{قالوا سَمِعنا فَتًى يَذكُرُهُم يُقالُ لَهُ إِبرٰهيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdxliv{قالوا فَأتوا بِهِ عَلىٰ أَعيُنِ النّاسِ لَعَلَّهُم يَشهَدونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdxlv{قالوا ءَأَنتَ فَعَلتَ هٰذا بِـٔالِهَتِنا يٰإِبرٰهيمُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdxlvi{قالَ بَل فَعَلَهُ كَبيرُهُم هٰذا فَسـَٔلوهُم إِن كانوا يَنطِقونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdxlvii{فَرَجَعوا إِلىٰ أَنفُسِهِم فَقالوا إِنَّكُم أَنتُمُ الظّٰلِمونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdxlviii{ثُمَّ نُكِسوا عَلىٰ رُءوسِهِم لَقَد عَلِمتَ ما هٰؤُلاءِ يَنطِقونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdxlix{قالَ أَفَتَعبُدونَ مِن دونِ اللَّهِ ما لا يَنفَعُكُم شَيـًٔا وَلا يَضُرُّكُم\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdl{أُفٍّ لَكُم وَلِما تَعبُدونَ مِن دونِ اللَّهِ أَفَلا تَعقِلونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdli{قالوا حَرِّقوهُ وَانصُروا ءالِهَتَكُم إِن كُنتُم فٰعِلينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdlii{قُلنا يٰنارُ كونى بَردًا وَسَلٰمًا عَلىٰ إِبرٰهيمَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdliii{وَأَرادوا بِهِ كَيدًا فَجَعَلنٰهُمُ الأَخسَرينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdliv{وَنَجَّينٰهُ وَلوطًا إِلَى الأَرضِ الَّتى بٰرَكنا فيها لِلعٰلَمينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdlv{وَوَهَبنا لَهُ إِسحٰقَ وَيَعقوبَ نافِلَةً وَكُلًّا جَعَلنا صٰلِحينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdlvi{وَجَعَلنٰهُم أَئِمَّةً يَهدونَ بِأَمرِنا وَأَوحَينا إِلَيهِم فِعلَ الخَيرٰتِ وَإِقامَ الصَّلوٰةِ وَإيتاءَ الزَّكوٰةِ وَكانوا لَنا عٰبِدينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdlvii{وَلوطًا ءاتَينٰهُ حُكمًا وَعِلمًا وَنَجَّينٰهُ مِنَ القَريَةِ الَّتى كانَت تَعمَلُ الخَبٰئِثَ إِنَّهُم كانوا قَومَ سَوءٍ فٰسِقينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdlviii{وَأَدخَلنٰهُ فى رَحمَتِنا إِنَّهُ مِنَ الصّٰلِحينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdlix{وَنوحًا إِذ نادىٰ مِن قَبلُ فَاستَجَبنا لَهُ فَنَجَّينٰهُ وَأَهلَهُ مِنَ الكَربِ العَظيمِ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdlx{وَنَصَرنٰهُ مِنَ القَومِ الَّذينَ كَذَّبوا بِـٔايٰتِنا إِنَّهُم كانوا قَومَ سَوءٍ فَأَغرَقنٰهُم أَجمَعينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdlxi{وَداوۥدَ وَسُلَيمٰنَ إِذ يَحكُمانِ فِى الحَرثِ إِذ نَفَشَت فيهِ غَنَمُ القَومِ وَكُنّا لِحُكمِهِم شٰهِدينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdlxii{فَفَهَّمنٰها سُلَيمٰنَ وَكُلًّا ءاتَينا حُكمًا وَعِلمًا وَسَخَّرنا مَعَ داوۥدَ الجِبالَ يُسَبِّحنَ وَالطَّيرَ وَكُنّا فٰعِلينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmdlxiii{وَعَلَّمنٰهُ صَنعَةَ لَبوسٍ لَكُم لِتُحصِنَكُم مِن بَأسِكُم فَهَل أَنتُم شٰكِرونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmdlxiv{وَلِسُلَيمٰنَ الرّيحَ عاصِفَةً تَجرى بِأَمرِهِ إِلَى الأَرضِ الَّتى بٰرَكنا فيها وَكُنّا بِكُلِّ شَيءٍ عٰلِمينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmdlxv{وَمِنَ الشَّيٰطينِ مَن يَغوصونَ لَهُ وَيَعمَلونَ عَمَلًا دونَ ذٰلِكَ وَكُنّا لَهُم حٰفِظينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmdlxvi{وَأَيّوبَ إِذ نادىٰ رَبَّهُ أَنّى مَسَّنِىَ الضُّرُّ وَأَنتَ أَرحَمُ الرّٰحِمينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmdlxvii{فَاستَجَبنا لَهُ فَكَشَفنا ما بِهِ مِن ضُرٍّ وَءاتَينٰهُ أَهلَهُ وَمِثلَهُم مَعَهُم رَحمَةً مِن عِندِنا وَذِكرىٰ لِلعٰبِدينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmdlxviii{وَإِسمٰعيلَ وَإِدريسَ وَذَا الكِفلِ كُلٌّ مِنَ الصّٰبِرينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmdlxix{وَأَدخَلنٰهُم فى رَحمَتِنا إِنَّهُم مِنَ الصّٰلِحينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmdlxx{وَذَا النّونِ إِذ ذَهَبَ مُغٰضِبًا فَظَنَّ أَن لَن نَقدِرَ عَلَيهِ فَنادىٰ فِى الظُّلُمٰتِ أَن لا إِلٰهَ إِلّا أَنتَ سُبحٰنَكَ إِنّى كُنتُ مِنَ الظّٰلِمينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmdlxxi{فَاستَجَبنا لَهُ وَنَجَّينٰهُ مِنَ الغَمِّ وَكَذٰلِكَ نُۨجِى المُؤمِنينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmdlxxii{وَزَكَرِيّا إِذ نادىٰ رَبَّهُ رَبِّ لا تَذَرنى فَردًا وَأَنتَ خَيرُ الوٰرِثينَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmdlxxiii{فَاستَجَبنا لَهُ وَوَهَبنا لَهُ يَحيىٰ وَأَصلَحنا لَهُ زَوجَهُ إِنَّهُم كانوا يُسٰرِعونَ فِى الخَيرٰتِ وَيَدعونَنا رَغَبًا وَرَهَبًا وَكانوا لَنا خٰشِعينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmdlxxiv{وَالَّتى أَحصَنَت فَرجَها فَنَفَخنا فيها مِن روحِنا وَجَعَلنٰها وَابنَها ءايَةً لِلعٰلَمينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmdlxxv{إِنَّ هٰذِهِ أُمَّتُكُم أُمَّةً وٰحِدَةً وَأَنا۠ رَبُّكُم فَاعبُدونِ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmdlxxvi{وَتَقَطَّعوا أَمرَهُم بَينَهُم كُلٌّ إِلَينا رٰجِعونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmdlxxvii{فَمَن يَعمَل مِنَ الصّٰلِحٰتِ وَهُوَ مُؤمِنٌ فَلا كُفرانَ لِسَعيِهِ وَإِنّا لَهُ كٰتِبونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmdlxxviii{وَحَرٰمٌ عَلىٰ قَريَةٍ أَهلَكنٰها أَنَّهُم لا يَرجِعونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmdlxxix{حَتّىٰ إِذا فُتِحَت يَأجوجُ وَمَأجوجُ وَهُم مِن كُلِّ حَدَبٍ يَنسِلونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmdlxxx{وَاقتَرَبَ الوَعدُ الحَقُّ فَإِذا هِىَ شٰخِصَةٌ أَبصٰرُ الَّذينَ كَفَروا يٰوَيلَنا قَد كُنّا فى غَفلَةٍ مِن هٰذا بَل كُنّا ظٰلِمينَ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmdlxxxi{إِنَّكُم وَما تَعبُدونَ مِن دونِ اللَّهِ حَصَبُ جَهَنَّمَ أَنتُم لَها وٰرِدونَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmdlxxxii{لَو كانَ هٰؤُلاءِ ءالِهَةً ما وَرَدوها وَكُلٌّ فيها خٰلِدونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmdlxxxiii{لَهُم فيها زَفيرٌ وَهُم فيها لا يَسمَعونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmdlxxxiv{إِنَّ الَّذينَ سَبَقَت لَهُم مِنَّا الحُسنىٰ أُولٰئِكَ عَنها مُبعَدونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmdlxxxv{لا يَسمَعونَ حَسيسَها وَهُم فى مَا اشتَهَت أَنفُسُهُم خٰلِدونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmdlxxxvi{لا يَحزُنُهُمُ الفَزَعُ الأَكبَرُ وَتَتَلَقّىٰهُمُ المَلٰئِكَةُ هٰذا يَومُكُمُ الَّذى كُنتُم توعَدونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmdlxxxvii{يَومَ نَطوِى السَّماءَ كَطَىِّ السِّجِلِّ لِلكُتُبِ كَما بَدَأنا أَوَّلَ خَلقٍ نُعيدُهُ وَعدًا عَلَينا إِنّا كُنّا فٰعِلينَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmdlxxxviii{وَلَقَد كَتَبنا فِى الزَّبورِ مِن بَعدِ الذِّكرِ أَنَّ الأَرضَ يَرِثُها عِبادِىَ الصّٰلِحونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmdlxxxix{إِنَّ فى هٰذا لَبَلٰغًا لِقَومٍ عٰبِدينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmdxc{وَما أَرسَلنٰكَ إِلّا رَحمَةً لِلعٰلَمينَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmdxci{قُل إِنَّما يوحىٰ إِلَىَّ أَنَّما إِلٰهُكُم إِلٰهٌ وٰحِدٌ فَهَل أَنتُم مُسلِمونَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmdxcii{فَإِن تَوَلَّوا فَقُل ءاذَنتُكُم عَلىٰ سَواءٍ وَإِن أَدرى أَقَريبٌ أَم بَعيدٌ ما توعَدونَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmdxciii{إِنَّهُ يَعلَمُ الجَهرَ مِنَ القَولِ وَيَعلَمُ ما تَكتُمونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmdxciv{وَإِن أَدرى لَعَلَّهُ فِتنَةٌ لَكُم وَمَتٰعٌ إِلىٰ حينٍ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmdxcv{قٰلَ رَبِّ احكُم بِالحَقِّ وَرَبُّنَا الرَّحمٰنُ المُستَعانُ عَلىٰ ما تَصِفونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmdxcvi{\basmalah  يٰأَيُّهَا النّاسُ اتَّقوا رَبَّكُم إِنَّ زَلزَلَةَ السّاعَةِ شَيءٌ عَظيمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdxcvii{يَومَ تَرَونَها تَذهَلُ كُلُّ مُرضِعَةٍ عَمّا أَرضَعَت وَتَضَعُ كُلُّ ذاتِ حَملٍ حَملَها وَتَرَى النّاسَ سُكٰرىٰ وَما هُم بِسُكٰرىٰ وَلٰكِنَّ عَذابَ اللَّهِ شَديدٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdxcviii{وَمِنَ النّاسِ مَن يُجٰدِلُ فِى اللَّهِ بِغَيرِ عِلمٍ وَيَتَّبِعُ كُلَّ شَيطٰنٍ مَريدٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdxcix{كُتِبَ عَلَيهِ أَنَّهُ مَن تَوَلّاهُ فَأَنَّهُ يُضِلُّهُ وَيَهديهِ إِلىٰ عَذابِ السَّعيرِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdc{يٰأَيُّهَا النّاسُ إِن كُنتُم فى رَيبٍ مِنَ البَعثِ فَإِنّا خَلَقنٰكُم مِن تُرابٍ ثُمَّ مِن نُطفَةٍ ثُمَّ مِن عَلَقَةٍ ثُمَّ مِن مُضغَةٍ مُخَلَّقَةٍ وَغَيرِ مُخَلَّقَةٍ لِنُبَيِّنَ لَكُم وَنُقِرُّ فِى الأَرحامِ ما نَشاءُ إِلىٰ أَجَلٍ مُسَمًّى ثُمَّ نُخرِجُكُم طِفلًا ثُمَّ لِتَبلُغوا أَشُدَّكُم وَمِنكُم مَن يُتَوَفّىٰ وَمِنكُم مَن يُرَدُّ إِلىٰ أَرذَلِ العُمُرِ لِكَيلا يَعلَمَ مِن بَعدِ عِلمٍ شَيـًٔا وَتَرَى الأَرضَ هامِدَةً فَإِذا أَنزَلنا عَلَيهَا الماءَ اهتَزَّت وَرَبَت وَأَنبَتَت مِن كُلِّ زَوجٍ بَهيجٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdci{ذٰلِكَ بِأَنَّ اللَّهَ هُوَ الحَقُّ وَأَنَّهُ يُحىِ المَوتىٰ وَأَنَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdcii{وَأَنَّ السّاعَةَ ءاتِيَةٌ لا رَيبَ فيها وَأَنَّ اللَّهَ يَبعَثُ مَن فِى القُبورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdciii{وَمِنَ النّاسِ مَن يُجٰدِلُ فِى اللَّهِ بِغَيرِ عِلمٍ وَلا هُدًى وَلا كِتٰبٍ مُنيرٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdciv{ثانِىَ عِطفِهِ لِيُضِلَّ عَن سَبيلِ اللَّهِ لَهُ فِى الدُّنيا خِزىٌ وَنُذيقُهُ يَومَ القِيٰمَةِ عَذابَ الحَريقِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdcv{ذٰلِكَ بِما قَدَّمَت يَداكَ وَأَنَّ اللَّهَ لَيسَ بِظَلّٰمٍ لِلعَبيدِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdcvi{وَمِنَ النّاسِ مَن يَعبُدُ اللَّهَ عَلىٰ حَرفٍ فَإِن أَصابَهُ خَيرٌ اطمَأَنَّ بِهِ وَإِن أَصابَتهُ فِتنَةٌ انقَلَبَ عَلىٰ وَجهِهِ خَسِرَ الدُّنيا وَالءاخِرَةَ ذٰلِكَ هُوَ الخُسرانُ المُبينُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdcvii{يَدعوا مِن دونِ اللَّهِ ما لا يَضُرُّهُ وَما لا يَنفَعُهُ ذٰلِكَ هُوَ الضَّلٰلُ البَعيدُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdcviii{يَدعوا لَمَن ضَرُّهُ أَقرَبُ مِن نَفعِهِ لَبِئسَ المَولىٰ وَلَبِئسَ العَشيرُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdcix{إِنَّ اللَّهَ يُدخِلُ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ إِنَّ اللَّهَ يَفعَلُ ما يُريدُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdcx{مَن كانَ يَظُنُّ أَن لَن يَنصُرَهُ اللَّهُ فِى الدُّنيا وَالءاخِرَةِ فَليَمدُد بِسَبَبٍ إِلَى السَّماءِ ثُمَّ ليَقطَع فَليَنظُر هَل يُذهِبَنَّ كَيدُهُ ما يَغيظُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdcxi{وَكَذٰلِكَ أَنزَلنٰهُ ءايٰتٍ بَيِّنٰتٍ وَأَنَّ اللَّهَ يَهدى مَن يُريدُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcxii{إِنَّ الَّذينَ ءامَنوا وَالَّذينَ هادوا وَالصّٰبِـٔينَ وَالنَّصٰرىٰ وَالمَجوسَ وَالَّذينَ أَشرَكوا إِنَّ اللَّهَ يَفصِلُ بَينَهُم يَومَ القِيٰمَةِ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcxiii{أَلَم تَرَ أَنَّ اللَّهَ يَسجُدُ لَهُ مَن فِى السَّمٰوٰتِ وَمَن فِى الأَرضِ وَالشَّمسُ وَالقَمَرُ وَالنُّجومُ وَالجِبالُ وَالشَّجَرُ وَالدَّوابُّ وَكَثيرٌ مِنَ النّاسِ وَكَثيرٌ حَقَّ عَلَيهِ العَذابُ وَمَن يُهِنِ اللَّهُ فَما لَهُ مِن مُكرِمٍ إِنَّ اللَّهَ يَفعَلُ ما يَشاءُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcxiv{هٰذانِ خَصمانِ اختَصَموا فى رَبِّهِم فَالَّذينَ كَفَروا قُطِّعَت لَهُم ثِيابٌ مِن نارٍ يُصَبُّ مِن فَوقِ رُءوسِهِمُ الحَميمُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcxv{يُصهَرُ بِهِ ما فى بُطونِهِم وَالجُلودُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcxvi{وَلَهُم مَقٰمِعُ مِن حَديدٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcxvii{كُلَّما أَرادوا أَن يَخرُجوا مِنها مِن غَمٍّ أُعيدوا فيها وَذوقوا عَذابَ الحَريقِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcxviii{إِنَّ اللَّهَ يُدخِلُ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ يُحَلَّونَ فيها مِن أَساوِرَ مِن ذَهَبٍ وَلُؤلُؤًا وَلِباسُهُم فيها حَريرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcxix{وَهُدوا إِلَى الطَّيِّبِ مِنَ القَولِ وَهُدوا إِلىٰ صِرٰطِ الحَميدِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcxx{إِنَّ الَّذينَ كَفَروا وَيَصُدّونَ عَن سَبيلِ اللَّهِ وَالمَسجِدِ الحَرامِ الَّذى جَعَلنٰهُ لِلنّاسِ سَواءً العٰكِفُ فيهِ وَالبادِ وَمَن يُرِد فيهِ بِإِلحادٍ بِظُلمٍ نُذِقهُ مِن عَذابٍ أَليمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcxxi{وَإِذ بَوَّأنا لِإِبرٰهيمَ مَكانَ البَيتِ أَن لا تُشرِك بى شَيـًٔا وَطَهِّر بَيتِىَ لِلطّائِفينَ وَالقائِمينَ وَالرُّكَّعِ السُّجودِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcxxii{وَأَذِّن فِى النّاسِ بِالحَجِّ يَأتوكَ رِجالًا وَعَلىٰ كُلِّ ضامِرٍ يَأتينَ مِن كُلِّ فَجٍّ عَميقٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcxxiii{لِيَشهَدوا مَنٰفِعَ لَهُم وَيَذكُرُوا اسمَ اللَّهِ فى أَيّامٍ مَعلومٰتٍ عَلىٰ ما رَزَقَهُم مِن بَهيمَةِ الأَنعٰمِ فَكُلوا مِنها وَأَطعِمُوا البائِسَ الفَقيرَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdcxxiv{ثُمَّ ليَقضوا تَفَثَهُم وَليوفوا نُذورَهُم وَليَطَّوَّفوا بِالبَيتِ العَتيقِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcxxv{ذٰلِكَ وَمَن يُعَظِّم حُرُمٰتِ اللَّهِ فَهُوَ خَيرٌ لَهُ عِندَ رَبِّهِ وَأُحِلَّت لَكُمُ الأَنعٰمُ إِلّا ما يُتلىٰ عَلَيكُم فَاجتَنِبُوا الرِّجسَ مِنَ الأَوثٰنِ وَاجتَنِبوا قَولَ الزّورِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcxxvi{حُنَفاءَ لِلَّهِ غَيرَ مُشرِكينَ بِهِ وَمَن يُشرِك بِاللَّهِ فَكَأَنَّما خَرَّ مِنَ السَّماءِ فَتَخطَفُهُ الطَّيرُ أَو تَهوى بِهِ الرّيحُ فى مَكانٍ سَحيقٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdcxxvii{ذٰلِكَ وَمَن يُعَظِّم شَعٰئِرَ اللَّهِ فَإِنَّها مِن تَقوَى القُلوبِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdcxxviii{لَكُم فيها مَنٰفِعُ إِلىٰ أَجَلٍ مُسَمًّى ثُمَّ مَحِلُّها إِلَى البَيتِ العَتيقِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdcxxix{وَلِكُلِّ أُمَّةٍ جَعَلنا مَنسَكًا لِيَذكُرُوا اسمَ اللَّهِ عَلىٰ ما رَزَقَهُم مِن بَهيمَةِ الأَنعٰمِ فَإِلٰهُكُم إِلٰهٌ وٰحِدٌ فَلَهُ أَسلِموا وَبَشِّرِ المُخبِتينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcxxx{الَّذينَ إِذا ذُكِرَ اللَّهُ وَجِلَت قُلوبُهُم وَالصّٰبِرينَ عَلىٰ ما أَصابَهُم وَالمُقيمِى الصَّلوٰةِ وَمِمّا رَزَقنٰهُم يُنفِقونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcxxxi{وَالبُدنَ جَعَلنٰها لَكُم مِن شَعٰئِرِ اللَّهِ لَكُم فيها خَيرٌ فَاذكُرُوا اسمَ اللَّهِ عَلَيها صَوافَّ فَإِذا وَجَبَت جُنوبُها فَكُلوا مِنها وَأَطعِمُوا القانِعَ وَالمُعتَرَّ كَذٰلِكَ سَخَّرنٰها لَكُم لَعَلَّكُم تَشكُرونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcxxxii{لَن يَنالَ اللَّهَ لُحومُها وَلا دِماؤُها وَلٰكِن يَنالُهُ التَّقوىٰ مِنكُم كَذٰلِكَ سَخَّرَها لَكُم لِتُكَبِّرُوا اللَّهَ عَلىٰ ما هَدىٰكُم وَبَشِّرِ المُحسِنينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcxxxiii{إِنَّ اللَّهَ يُدٰفِعُ عَنِ الَّذينَ ءامَنوا إِنَّ اللَّهَ لا يُحِبُّ كُلَّ خَوّانٍ كَفورٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcxxxiv{أُذِنَ لِلَّذينَ يُقٰتَلونَ بِأَنَّهُم ظُلِموا وَإِنَّ اللَّهَ عَلىٰ نَصرِهِم لَقَديرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcxxxv{الَّذينَ أُخرِجوا مِن دِيٰرِهِم بِغَيرِ حَقٍّ إِلّا أَن يَقولوا رَبُّنَا اللَّهُ وَلَولا دَفعُ اللَّهِ النّاسَ بَعضَهُم بِبَعضٍ لَهُدِّمَت صَوٰمِعُ وَبِيَعٌ وَصَلَوٰتٌ وَمَسٰجِدُ يُذكَرُ فيهَا اسمُ اللَّهِ كَثيرًا وَلَيَنصُرَنَّ اللَّهُ مَن يَنصُرُهُ إِنَّ اللَّهَ لَقَوِىٌّ عَزيزٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcxxxvi{الَّذينَ إِن مَكَّنّٰهُم فِى الأَرضِ أَقامُوا الصَّلوٰةَ وَءاتَوُا الزَّكوٰةَ وَأَمَروا بِالمَعروفِ وَنَهَوا عَنِ المُنكَرِ وَلِلَّهِ عٰقِبَةُ الأُمورِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcxxxvii{وَإِن يُكَذِّبوكَ فَقَد كَذَّبَت قَبلَهُم قَومُ نوحٍ وَعادٌ وَثَمودُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcxxxviii{وَقَومُ إِبرٰهيمَ وَقَومُ لوطٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcxxxix{وَأَصحٰبُ مَديَنَ وَكُذِّبَ موسىٰ فَأَملَيتُ لِلكٰفِرينَ ثُمَّ أَخَذتُهُم فَكَيفَ كانَ نَكيرِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdcxl{فَكَأَيِّن مِن قَريَةٍ أَهلَكنٰها وَهِىَ ظالِمَةٌ فَهِىَ خاوِيَةٌ عَلىٰ عُروشِها وَبِئرٍ مُعَطَّلَةٍ وَقَصرٍ مَشيدٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdcxli{أَفَلَم يَسيروا فِى الأَرضِ فَتَكونَ لَهُم قُلوبٌ يَعقِلونَ بِها أَو ءاذانٌ يَسمَعونَ بِها فَإِنَّها لا تَعمَى الأَبصٰرُ وَلٰكِن تَعمَى القُلوبُ الَّتى فِى الصُّدورِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdcxlii{وَيَستَعجِلونَكَ بِالعَذابِ وَلَن يُخلِفَ اللَّهُ وَعدَهُ وَإِنَّ يَومًا عِندَ رَبِّكَ كَأَلفِ سَنَةٍ مِمّا تَعُدّونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdcxliii{وَكَأَيِّن مِن قَريَةٍ أَملَيتُ لَها وَهِىَ ظالِمَةٌ ثُمَّ أَخَذتُها وَإِلَىَّ المَصيرُ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdcxliv{قُل يٰأَيُّهَا النّاسُ إِنَّما أَنا۠ لَكُم نَذيرٌ مُبينٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdcxlv{فَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَهُم مَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdcxlvi{وَالَّذينَ سَعَوا فى ءايٰتِنا مُعٰجِزينَ أُولٰئِكَ أَصحٰبُ الجَحيمِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdcxlvii{وَما أَرسَلنا مِن قَبلِكَ مِن رَسولٍ وَلا نَبِىٍّ إِلّا إِذا تَمَنّىٰ أَلقَى الشَّيطٰنُ فى أُمنِيَّتِهِ فَيَنسَخُ اللَّهُ ما يُلقِى الشَّيطٰنُ ثُمَّ يُحكِمُ اللَّهُ ءايٰتِهِ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdcxlviii{لِيَجعَلَ ما يُلقِى الشَّيطٰنُ فِتنَةً لِلَّذينَ فى قُلوبِهِم مَرَضٌ وَالقاسِيَةِ قُلوبُهُم وَإِنَّ الظّٰلِمينَ لَفى شِقاقٍ بَعيدٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdcxlix{وَلِيَعلَمَ الَّذينَ أوتُوا العِلمَ أَنَّهُ الحَقُّ مِن رَبِّكَ فَيُؤمِنوا بِهِ فَتُخبِتَ لَهُ قُلوبُهُم وَإِنَّ اللَّهَ لَهادِ الَّذينَ ءامَنوا إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdcl{وَلا يَزالُ الَّذينَ كَفَروا فى مِريَةٍ مِنهُ حَتّىٰ تَأتِيَهُمُ السّاعَةُ بَغتَةً أَو يَأتِيَهُم عَذابُ يَومٍ عَقيمٍ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdcli{المُلكُ يَومَئِذٍ لِلَّهِ يَحكُمُ بَينَهُم فَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ فى جَنّٰتِ النَّعيمِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdclii{وَالَّذينَ كَفَروا وَكَذَّبوا بِـٔايٰتِنا فَأُولٰئِكَ لَهُم عَذابٌ مُهينٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdcliii{وَالَّذينَ هاجَروا فى سَبيلِ اللَّهِ ثُمَّ قُتِلوا أَو ماتوا لَيَرزُقَنَّهُمُ اللَّهُ رِزقًا حَسَنًا وَإِنَّ اللَّهَ لَهُوَ خَيرُ الرّٰزِقينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdcliv{لَيُدخِلَنَّهُم مُدخَلًا يَرضَونَهُ وَإِنَّ اللَّهَ لَعَليمٌ حَليمٌ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdclv{ذٰلِكَ وَمَن عاقَبَ بِمِثلِ ما عوقِبَ بِهِ ثُمَّ بُغِىَ عَلَيهِ لَيَنصُرَنَّهُ اللَّهُ إِنَّ اللَّهَ لَعَفُوٌّ غَفورٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdclvi{ذٰلِكَ بِأَنَّ اللَّهَ يولِجُ الَّيلَ فِى النَّهارِ وَيولِجُ النَّهارَ فِى الَّيلِ وَأَنَّ اللَّهَ سَميعٌ بَصيرٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdclvii{ذٰلِكَ بِأَنَّ اللَّهَ هُوَ الحَقُّ وَأَنَّ ما يَدعونَ مِن دونِهِ هُوَ البٰطِلُ وَأَنَّ اللَّهَ هُوَ العَلِىُّ الكَبيرُ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdclviii{أَلَم تَرَ أَنَّ اللَّهَ أَنزَلَ مِنَ السَّماءِ ماءً فَتُصبِحُ الأَرضُ مُخضَرَّةً إِنَّ اللَّهَ لَطيفٌ خَبيرٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdclix{لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَإِنَّ اللَّهَ لَهُوَ الغَنِىُّ الحَميدُ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdclx{أَلَم تَرَ أَنَّ اللَّهَ سَخَّرَ لَكُم ما فِى الأَرضِ وَالفُلكَ تَجرى فِى البَحرِ بِأَمرِهِ وَيُمسِكُ السَّماءَ أَن تَقَعَ عَلَى الأَرضِ إِلّا بِإِذنِهِ إِنَّ اللَّهَ بِالنّاسِ لَرَءوفٌ رَحيمٌ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdclxi{وَهُوَ الَّذى أَحياكُم ثُمَّ يُميتُكُم ثُمَّ يُحييكُم إِنَّ الإِنسٰنَ لَكَفورٌ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdclxii{لِكُلِّ أُمَّةٍ جَعَلنا مَنسَكًا هُم ناسِكوهُ فَلا يُنٰزِعُنَّكَ فِى الأَمرِ وَادعُ إِلىٰ رَبِّكَ إِنَّكَ لَعَلىٰ هُدًى مُستَقيمٍ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdclxiii{وَإِن جٰدَلوكَ فَقُلِ اللَّهُ أَعلَمُ بِما تَعمَلونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdclxiv{اللَّهُ يَحكُمُ بَينَكُم يَومَ القِيٰمَةِ فيما كُنتُم فيهِ تَختَلِفونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdclxv{أَلَم تَعلَم أَنَّ اللَّهَ يَعلَمُ ما فِى السَّماءِ وَالأَرضِ إِنَّ ذٰلِكَ فى كِتٰبٍ إِنَّ ذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdclxvi{وَيَعبُدونَ مِن دونِ اللَّهِ ما لَم يُنَزِّل بِهِ سُلطٰنًا وَما لَيسَ لَهُم بِهِ عِلمٌ وَما لِلظّٰلِمينَ مِن نَصيرٍ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdclxvii{وَإِذا تُتلىٰ عَلَيهِم ءايٰتُنا بَيِّنٰتٍ تَعرِفُ فى وُجوهِ الَّذينَ كَفَرُوا المُنكَرَ يَكادونَ يَسطونَ بِالَّذينَ يَتلونَ عَلَيهِم ءايٰتِنا قُل أَفَأُنَبِّئُكُم بِشَرٍّ مِن ذٰلِكُمُ النّارُ وَعَدَهَا اللَّهُ الَّذينَ كَفَروا وَبِئسَ المَصيرُ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdclxviii{يٰأَيُّهَا النّاسُ ضُرِبَ مَثَلٌ فَاستَمِعوا لَهُ إِنَّ الَّذينَ تَدعونَ مِن دونِ اللَّهِ لَن يَخلُقوا ذُبابًا وَلَوِ اجتَمَعوا لَهُ وَإِن يَسلُبهُمُ الذُّبابُ شَيـًٔا لا يَستَنقِذوهُ مِنهُ ضَعُفَ الطّالِبُ وَالمَطلوبُ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdclxix{ما قَدَرُوا اللَّهَ حَقَّ قَدرِهِ إِنَّ اللَّهَ لَقَوِىٌّ عَزيزٌ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdclxx{اللَّهُ يَصطَفى مِنَ المَلٰئِكَةِ رُسُلًا وَمِنَ النّاسِ إِنَّ اللَّهَ سَميعٌ بَصيرٌ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdclxxi{يَعلَمُ ما بَينَ أَيديهِم وَما خَلفَهُم وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdclxxii{يٰأَيُّهَا الَّذينَ ءامَنُوا اركَعوا وَاسجُدوا وَاعبُدوا رَبَّكُم وَافعَلُوا الخَيرَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdclxxiii{وَجٰهِدوا فِى اللَّهِ حَقَّ جِهادِهِ هُوَ اجتَبىٰكُم وَما جَعَلَ عَلَيكُم فِى الدّينِ مِن حَرَجٍ مِلَّةَ أَبيكُم إِبرٰهيمَ هُوَ سَمّىٰكُمُ المُسلِمينَ مِن قَبلُ وَفى هٰذا لِيَكونَ الرَّسولُ شَهيدًا عَلَيكُم وَتَكونوا شُهَداءَ عَلَى النّاسِ فَأَقيمُوا الصَّلوٰةَ وَءاتُوا الزَّكوٰةَ وَاعتَصِموا بِاللَّهِ هُوَ مَولىٰكُم فَنِعمَ المَولىٰ وَنِعمَ النَّصيرُ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdclxxiv{\basmalah  قَد أَفلَحَ المُؤمِنونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdclxxv{الَّذينَ هُم فى صَلاتِهِم خٰشِعونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdclxxvi{وَالَّذينَ هُم عَنِ اللَّغوِ مُعرِضونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdclxxvii{وَالَّذينَ هُم لِلزَّكوٰةِ فٰعِلونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdclxxviii{وَالَّذينَ هُم لِفُروجِهِم حٰفِظونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdclxxix{إِلّا عَلىٰ أَزوٰجِهِم أَو ما مَلَكَت أَيمٰنُهُم فَإِنَّهُم غَيرُ مَلومينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdclxxx{فَمَنِ ابتَغىٰ وَراءَ ذٰلِكَ فَأُولٰئِكَ هُمُ العادونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdclxxxi{وَالَّذينَ هُم لِأَمٰنٰتِهِم وَعَهدِهِم رٰعونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdclxxxii{وَالَّذينَ هُم عَلىٰ صَلَوٰتِهِم يُحافِظونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdclxxxiii{أُولٰئِكَ هُمُ الوٰرِثونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdclxxxiv{الَّذينَ يَرِثونَ الفِردَوسَ هُم فيها خٰلِدونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdclxxxv{وَلَقَد خَلَقنَا الإِنسٰنَ مِن سُلٰلَةٍ مِن طينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdclxxxvi{ثُمَّ جَعَلنٰهُ نُطفَةً فى قَرارٍ مَكينٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdclxxxvii{ثُمَّ خَلَقنَا النُّطفَةَ عَلَقَةً فَخَلَقنَا العَلَقَةَ مُضغَةً فَخَلَقنَا المُضغَةَ عِظٰمًا فَكَسَونَا العِظٰمَ لَحمًا ثُمَّ أَنشَأنٰهُ خَلقًا ءاخَرَ فَتَبارَكَ اللَّهُ أَحسَنُ الخٰلِقينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdclxxxviii{ثُمَّ إِنَّكُم بَعدَ ذٰلِكَ لَمَيِّتونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdclxxxix{ثُمَّ إِنَّكُم يَومَ القِيٰمَةِ تُبعَثونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcxc{وَلَقَد خَلَقنا فَوقَكُم سَبعَ طَرائِقَ وَما كُنّا عَنِ الخَلقِ غٰفِلينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcxci{وَأَنزَلنا مِنَ السَّماءِ ماءً بِقَدَرٍ فَأَسكَنّٰهُ فِى الأَرضِ وَإِنّا عَلىٰ ذَهابٍ بِهِ لَقٰدِرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcxcii{فَأَنشَأنا لَكُم بِهِ جَنّٰتٍ مِن نَخيلٍ وَأَعنٰبٍ لَكُم فيها فَوٰكِهُ كَثيرَةٌ وَمِنها تَأكُلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcxciii{وَشَجَرَةً تَخرُجُ مِن طورِ سَيناءَ تَنبُتُ بِالدُّهنِ وَصِبغٍ لِلءاكِلينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcxciv{وَإِنَّ لَكُم فِى الأَنعٰمِ لَعِبرَةً نُسقيكُم مِمّا فى بُطونِها وَلَكُم فيها مَنٰفِعُ كَثيرَةٌ وَمِنها تَأكُلونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcxcv{وَعَلَيها وَعَلَى الفُلكِ تُحمَلونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcxcvi{وَلَقَد أَرسَلنا نوحًا إِلىٰ قَومِهِ فَقالَ يٰقَومِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ أَفَلا تَتَّقونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcxcvii{فَقالَ المَلَؤُا۟ الَّذينَ كَفَروا مِن قَومِهِ ما هٰذا إِلّا بَشَرٌ مِثلُكُم يُريدُ أَن يَتَفَضَّلَ عَلَيكُم وَلَو شاءَ اللَّهُ لَأَنزَلَ مَلٰئِكَةً ما سَمِعنا بِهٰذا فى ءابائِنَا الأَوَّلينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcxcviii{إِن هُوَ إِلّا رَجُلٌ بِهِ جِنَّةٌ فَتَرَبَّصوا بِهِ حَتّىٰ حينٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcxcix{قالَ رَبِّ انصُرنى بِما كَذَّبونِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcc{فَأَوحَينا إِلَيهِ أَنِ اصنَعِ الفُلكَ بِأَعيُنِنا وَوَحيِنا فَإِذا جاءَ أَمرُنا وَفارَ التَّنّورُ فَاسلُك فيها مِن كُلٍّ زَوجَينِ اثنَينِ وَأَهلَكَ إِلّا مَن سَبَقَ عَلَيهِ القَولُ مِنهُم وَلا تُخٰطِبنى فِى الَّذينَ ظَلَموا إِنَّهُم مُغرَقونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcci{فَإِذَا استَوَيتَ أَنتَ وَمَن مَعَكَ عَلَى الفُلكِ فَقُلِ الحَمدُ لِلَّهِ الَّذى نَجّىٰنا مِنَ القَومِ الظّٰلِمينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdccii{وَقُل رَبِّ أَنزِلنى مُنزَلًا مُبارَكًا وَأَنتَ خَيرُ المُنزِلينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcciii{إِنَّ فى ذٰلِكَ لَءايٰتٍ وَإِن كُنّا لَمُبتَلينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcciv{ثُمَّ أَنشَأنا مِن بَعدِهِم قَرنًا ءاخَرينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdccv{فَأَرسَلنا فيهِم رَسولًا مِنهُم أَنِ اعبُدُوا اللَّهَ ما لَكُم مِن إِلٰهٍ غَيرُهُ أَفَلا تَتَّقونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdccvi{وَقالَ المَلَأُ مِن قَومِهِ الَّذينَ كَفَروا وَكَذَّبوا بِلِقاءِ الءاخِرَةِ وَأَترَفنٰهُم فِى الحَيوٰةِ الدُّنيا ما هٰذا إِلّا بَشَرٌ مِثلُكُم يَأكُلُ مِمّا تَأكُلونَ مِنهُ وَيَشرَبُ مِمّا تَشرَبونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdccvii{وَلَئِن أَطَعتُم بَشَرًا مِثلَكُم إِنَّكُم إِذًا لَخٰسِرونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdccviii{أَيَعِدُكُم أَنَّكُم إِذا مِتُّم وَكُنتُم تُرابًا وَعِظٰمًا أَنَّكُم مُخرَجونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdccix{هَيهاتَ هَيهاتَ لِما توعَدونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdccx{إِن هِىَ إِلّا حَياتُنَا الدُّنيا نَموتُ وَنَحيا وَما نَحنُ بِمَبعوثينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdccxi{إِن هُوَ إِلّا رَجُلٌ افتَرىٰ عَلَى اللَّهِ كَذِبًا وَما نَحنُ لَهُ بِمُؤمِنينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdccxii{قالَ رَبِّ انصُرنى بِما كَذَّبونِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdccxiii{قالَ عَمّا قَليلٍ لَيُصبِحُنَّ نٰدِمينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdccxiv{فَأَخَذَتهُمُ الصَّيحَةُ بِالحَقِّ فَجَعَلنٰهُم غُثاءً فَبُعدًا لِلقَومِ الظّٰلِمينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdccxv{ثُمَّ أَنشَأنا مِن بَعدِهِم قُرونًا ءاخَرينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdccxvi{ما تَسبِقُ مِن أُمَّةٍ أَجَلَها وَما يَستَـٔخِرونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdccxvii{ثُمَّ أَرسَلنا رُسُلَنا تَترا كُلَّ ما جاءَ أُمَّةً رَسولُها كَذَّبوهُ فَأَتبَعنا بَعضَهُم بَعضًا وَجَعَلنٰهُم أَحاديثَ فَبُعدًا لِقَومٍ لا يُؤمِنونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdccxviii{ثُمَّ أَرسَلنا موسىٰ وَأَخاهُ هٰرونَ بِـٔايٰتِنا وَسُلطٰنٍ مُبينٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdccxix{إِلىٰ فِرعَونَ وَمَلَإِي۟هِ فَاستَكبَروا وَكانوا قَومًا عالينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdccxx{فَقالوا أَنُؤمِنُ لِبَشَرَينِ مِثلِنا وَقَومُهُما لَنا عٰبِدونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdccxxi{فَكَذَّبوهُما فَكانوا مِنَ المُهلَكينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdccxxii{وَلَقَد ءاتَينا موسَى الكِتٰبَ لَعَلَّهُم يَهتَدونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdccxxiii{وَجَعَلنَا ابنَ مَريَمَ وَأُمَّهُ ءايَةً وَءاوَينٰهُما إِلىٰ رَبوَةٍ ذاتِ قَرارٍ وَمَعينٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdccxxiv{يٰأَيُّهَا الرُّسُلُ كُلوا مِنَ الطَّيِّبٰتِ وَاعمَلوا صٰلِحًا إِنّى بِما تَعمَلونَ عَليمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdccxxv{وَإِنَّ هٰذِهِ أُمَّتُكُم أُمَّةً وٰحِدَةً وَأَنا۠ رَبُّكُم فَاتَّقونِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdccxxvi{فَتَقَطَّعوا أَمرَهُم بَينَهُم زُبُرًا كُلُّ حِزبٍ بِما لَدَيهِم فَرِحونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdccxxvii{فَذَرهُم فى غَمرَتِهِم حَتّىٰ حينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdccxxviii{أَيَحسَبونَ أَنَّما نُمِدُّهُم بِهِ مِن مالٍ وَبَنينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdccxxix{نُسارِعُ لَهُم فِى الخَيرٰتِ بَل لا يَشعُرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdccxxx{إِنَّ الَّذينَ هُم مِن خَشيَةِ رَبِّهِم مُشفِقونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdccxxxi{وَالَّذينَ هُم بِـٔايٰتِ رَبِّهِم يُؤمِنونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdccxxxii{وَالَّذينَ هُم بِرَبِّهِم لا يُشرِكونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdccxxxiii{وَالَّذينَ يُؤتونَ ما ءاتَوا وَقُلوبُهُم وَجِلَةٌ أَنَّهُم إِلىٰ رَبِّهِم رٰجِعونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdccxxxiv{أُولٰئِكَ يُسٰرِعونَ فِى الخَيرٰتِ وَهُم لَها سٰبِقونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdccxxxv{وَلا نُكَلِّفُ نَفسًا إِلّا وُسعَها وَلَدَينا كِتٰبٌ يَنطِقُ بِالحَقِّ وَهُم لا يُظلَمونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdccxxxvi{بَل قُلوبُهُم فى غَمرَةٍ مِن هٰذا وَلَهُم أَعمٰلٌ مِن دونِ ذٰلِكَ هُم لَها عٰمِلونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdccxxxvii{حَتّىٰ إِذا أَخَذنا مُترَفيهِم بِالعَذابِ إِذا هُم يَجـَٔرونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdccxxxviii{لا تَجـَٔرُوا اليَومَ إِنَّكُم مِنّا لا تُنصَرونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmdccxxxix{قَد كانَت ءايٰتى تُتلىٰ عَلَيكُم فَكُنتُم عَلىٰ أَعقٰبِكُم تَنكِصونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmdccxl{مُستَكبِرينَ بِهِ سٰمِرًا تَهجُرونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmdccxli{أَفَلَم يَدَّبَّرُوا القَولَ أَم جاءَهُم ما لَم يَأتِ ءاباءَهُمُ الأَوَّلينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmdccxlii{أَم لَم يَعرِفوا رَسولَهُم فَهُم لَهُ مُنكِرونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmdccxliii{أَم يَقولونَ بِهِ جِنَّةٌ بَل جاءَهُم بِالحَقِّ وَأَكثَرُهُم لِلحَقِّ كٰرِهونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmdccxliv{وَلَوِ اتَّبَعَ الحَقُّ أَهواءَهُم لَفَسَدَتِ السَّمٰوٰتُ وَالأَرضُ وَمَن فيهِنَّ بَل أَتَينٰهُم بِذِكرِهِم فَهُم عَن ذِكرِهِم مُعرِضونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmdccxlv{أَم تَسـَٔلُهُم خَرجًا فَخَراجُ رَبِّكَ خَيرٌ وَهُوَ خَيرُ الرّٰزِقينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmdccxlvi{وَإِنَّكَ لَتَدعوهُم إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmdccxlvii{وَإِنَّ الَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ عَنِ الصِّرٰطِ لَنٰكِبونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmdccxlviii{وَلَو رَحِمنٰهُم وَكَشَفنا ما بِهِم مِن ضُرٍّ لَلَجّوا فى طُغيٰنِهِم يَعمَهونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmdccxlix{وَلَقَد أَخَذنٰهُم بِالعَذابِ فَمَا استَكانوا لِرَبِّهِم وَما يَتَضَرَّعونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmdccl{حَتّىٰ إِذا فَتَحنا عَلَيهِم بابًا ذا عَذابٍ شَديدٍ إِذا هُم فيهِ مُبلِسونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmdccli{وَهُوَ الَّذى أَنشَأَ لَكُمُ السَّمعَ وَالأَبصٰرَ وَالأَفـِٔدَةَ قَليلًا ما تَشكُرونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmdcclii{وَهُوَ الَّذى ذَرَأَكُم فِى الأَرضِ وَإِلَيهِ تُحشَرونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmdccliii{وَهُوَ الَّذى يُحيۦ وَيُميتُ وَلَهُ اختِلٰفُ الَّيلِ وَالنَّهارِ أَفَلا تَعقِلونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmdccliv{بَل قالوا مِثلَ ما قالَ الأَوَّلونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmdcclv{قالوا أَءِذا مِتنا وَكُنّا تُرابًا وَعِظٰمًا أَءِنّا لَمَبعوثونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmdcclvi{لَقَد وُعِدنا نَحنُ وَءاباؤُنا هٰذا مِن قَبلُ إِن هٰذا إِلّا أَسٰطيرُ الأَوَّلينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmdcclvii{قُل لِمَنِ الأَرضُ وَمَن فيها إِن كُنتُم تَعلَمونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmdcclviii{سَيَقولونَ لِلَّهِ قُل أَفَلا تَذَكَّرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmdcclix{قُل مَن رَبُّ السَّمٰوٰتِ السَّبعِ وَرَبُّ العَرشِ العَظيمِ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmdcclx{سَيَقولونَ لِلَّهِ قُل أَفَلا تَتَّقونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmdcclxi{قُل مَن بِيَدِهِ مَلَكوتُ كُلِّ شَيءٍ وَهُوَ يُجيرُ وَلا يُجارُ عَلَيهِ إِن كُنتُم تَعلَمونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmdcclxii{سَيَقولونَ لِلَّهِ قُل فَأَنّىٰ تُسحَرونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmdcclxiii{بَل أَتَينٰهُم بِالحَقِّ وَإِنَّهُم لَكٰذِبونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmdcclxiv{مَا اتَّخَذَ اللَّهُ مِن وَلَدٍ وَما كانَ مَعَهُ مِن إِلٰهٍ إِذًا لَذَهَبَ كُلُّ إِلٰهٍ بِما خَلَقَ وَلَعَلا بَعضُهُم عَلىٰ بَعضٍ سُبحٰنَ اللَّهِ عَمّا يَصِفونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmdcclxv{عٰلِمِ الغَيبِ وَالشَّهٰدَةِ فَتَعٰلىٰ عَمّا يُشرِكونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmdcclxvi{قُل رَبِّ إِمّا تُرِيَنّى ما يوعَدونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmdcclxvii{رَبِّ فَلا تَجعَلنى فِى القَومِ الظّٰلِمينَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmdcclxviii{وَإِنّا عَلىٰ أَن نُرِيَكَ ما نَعِدُهُم لَقٰدِرونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmdcclxix{ادفَع بِالَّتى هِىَ أَحسَنُ السَّيِّئَةَ نَحنُ أَعلَمُ بِما يَصِفونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmdcclxx{وَقُل رَبِّ أَعوذُ بِكَ مِن هَمَزٰتِ الشَّيٰطينِ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmdcclxxi{وَأَعوذُ بِكَ رَبِّ أَن يَحضُرونِ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmdcclxxii{حَتّىٰ إِذا جاءَ أَحَدَهُمُ المَوتُ قالَ رَبِّ ارجِعونِ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmdcclxxiii{لَعَلّى أَعمَلُ صٰلِحًا فيما تَرَكتُ كَلّا إِنَّها كَلِمَةٌ هُوَ قائِلُها وَمِن وَرائِهِم بَرزَخٌ إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmdcclxxiv{فَإِذا نُفِخَ فِى الصّورِ فَلا أَنسابَ بَينَهُم يَومَئِذٍ وَلا يَتَساءَلونَ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmdcclxxv{فَمَن ثَقُلَت مَوٰزينُهُ فَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmdcclxxvi{وَمَن خَفَّت مَوٰزينُهُ فَأُولٰئِكَ الَّذينَ خَسِروا أَنفُسَهُم فى جَهَنَّمَ خٰلِدونَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmdcclxxvii{تَلفَحُ وُجوهَهُمُ النّارُ وَهُم فيها كٰلِحونَ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmdcclxxviii{أَلَم تَكُن ءايٰتى تُتلىٰ عَلَيكُم فَكُنتُم بِها تُكَذِّبونَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmdcclxxix{قالوا رَبَّنا غَلَبَت عَلَينا شِقوَتُنا وَكُنّا قَومًا ضالّينَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmdcclxxx{رَبَّنا أَخرِجنا مِنها فَإِن عُدنا فَإِنّا ظٰلِمونَ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmdcclxxxi{قالَ اخسَـٔوا فيها وَلا تُكَلِّمونِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmdcclxxxii{إِنَّهُ كانَ فَريقٌ مِن عِبادى يَقولونَ رَبَّنا ءامَنّا فَاغفِر لَنا وَارحَمنا وَأَنتَ خَيرُ الرّٰحِمينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmdcclxxxiii{فَاتَّخَذتُموهُم سِخرِيًّا حَتّىٰ أَنسَوكُم ذِكرى وَكُنتُم مِنهُم تَضحَكونَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmdcclxxxiv{إِنّى جَزَيتُهُمُ اليَومَ بِما صَبَروا أَنَّهُم هُمُ الفائِزونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmdcclxxxv{قٰلَ كَم لَبِثتُم فِى الأَرضِ عَدَدَ سِنينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmdcclxxxvi{قالوا لَبِثنا يَومًا أَو بَعضَ يَومٍ فَسـَٔلِ العادّينَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmdcclxxxvii{قٰلَ إِن لَبِثتُم إِلّا قَليلًا لَو أَنَّكُم كُنتُم تَعلَمونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmdcclxxxviii{أَفَحَسِبتُم أَنَّما خَلَقنٰكُم عَبَثًا وَأَنَّكُم إِلَينا لا تُرجَعونَ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmdcclxxxix{فَتَعٰلَى اللَّهُ المَلِكُ الحَقُّ لا إِلٰهَ إِلّا هُوَ رَبُّ العَرشِ الكَريمِ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmdccxc{وَمَن يَدعُ مَعَ اللَّهِ إِلٰهًا ءاخَرَ لا بُرهٰنَ لَهُ بِهِ فَإِنَّما حِسابُهُ عِندَ رَبِّهِ إِنَّهُ لا يُفلِحُ الكٰفِرونَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmdccxci{وَقُل رَبِّ اغفِر وَارحَم وَأَنتَ خَيرُ الرّٰحِمينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmdccxcii{\basmalah  سورَةٌ أَنزَلنٰها وَفَرَضنٰها وَأَنزَلنا فيها ءايٰتٍ بَيِّنٰتٍ لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdccxciii{الزّانِيَةُ وَالزّانى فَاجلِدوا كُلَّ وٰحِدٍ مِنهُما مِا۟ئَةَ جَلدَةٍ وَلا تَأخُذكُم بِهِما رَأفَةٌ فى دينِ اللَّهِ إِن كُنتُم تُؤمِنونَ بِاللَّهِ وَاليَومِ الءاخِرِ وَليَشهَد عَذابَهُما طائِفَةٌ مِنَ المُؤمِنينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdccxciv{الزّانى لا يَنكِحُ إِلّا زانِيَةً أَو مُشرِكَةً وَالزّانِيَةُ لا يَنكِحُها إِلّا زانٍ أَو مُشرِكٌ وَحُرِّمَ ذٰلِكَ عَلَى المُؤمِنينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdccxcv{وَالَّذينَ يَرمونَ المُحصَنٰتِ ثُمَّ لَم يَأتوا بِأَربَعَةِ شُهَداءَ فَاجلِدوهُم ثَمٰنينَ جَلدَةً وَلا تَقبَلوا لَهُم شَهٰدَةً أَبَدًا وَأُولٰئِكَ هُمُ الفٰسِقونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdccxcvi{إِلَّا الَّذينَ تابوا مِن بَعدِ ذٰلِكَ وَأَصلَحوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdccxcvii{وَالَّذينَ يَرمونَ أَزوٰجَهُم وَلَم يَكُن لَهُم شُهَداءُ إِلّا أَنفُسُهُم فَشَهٰدَةُ أَحَدِهِم أَربَعُ شَهٰدٰتٍ بِاللَّهِ إِنَّهُ لَمِنَ الصّٰدِقينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdccxcviii{وَالخٰمِسَةُ أَنَّ لَعنَتَ اللَّهِ عَلَيهِ إِن كانَ مِنَ الكٰذِبينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdccxcix{وَيَدرَؤُا۟ عَنهَا العَذابَ أَن تَشهَدَ أَربَعَ شَهٰدٰتٍ بِاللَّهِ إِنَّهُ لَمِنَ الكٰذِبينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdccc{وَالخٰمِسَةَ أَنَّ غَضَبَ اللَّهِ عَلَيها إِن كانَ مِنَ الصّٰدِقينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdccci{وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ وَأَنَّ اللَّهَ تَوّابٌ حَكيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdcccii{إِنَّ الَّذينَ جاءو بِالإِفكِ عُصبَةٌ مِنكُم لا تَحسَبوهُ شَرًّا لَكُم بَل هُوَ خَيرٌ لَكُم لِكُلِّ امرِئٍ مِنهُم مَا اكتَسَبَ مِنَ الإِثمِ وَالَّذى تَوَلّىٰ كِبرَهُ مِنهُم لَهُ عَذابٌ عَظيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdccciii{لَولا إِذ سَمِعتُموهُ ظَنَّ المُؤمِنونَ وَالمُؤمِنٰتُ بِأَنفُسِهِم خَيرًا وَقالوا هٰذا إِفكٌ مُبينٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdccciv{لَولا جاءو عَلَيهِ بِأَربَعَةِ شُهَداءَ فَإِذ لَم يَأتوا بِالشُّهَداءِ فَأُولٰئِكَ عِندَ اللَّهِ هُمُ الكٰذِبونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdcccv{وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ فِى الدُّنيا وَالءاخِرَةِ لَمَسَّكُم فى ما أَفَضتُم فيهِ عَذابٌ عَظيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdcccvi{إِذ تَلَقَّونَهُ بِأَلسِنَتِكُم وَتَقولونَ بِأَفواهِكُم ما لَيسَ لَكُم بِهِ عِلمٌ وَتَحسَبونَهُ هَيِّنًا وَهُوَ عِندَ اللَّهِ عَظيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdcccvii{وَلَولا إِذ سَمِعتُموهُ قُلتُم ما يَكونُ لَنا أَن نَتَكَلَّمَ بِهٰذا سُبحٰنَكَ هٰذا بُهتٰنٌ عَظيمٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdcccviii{يَعِظُكُمُ اللَّهُ أَن تَعودوا لِمِثلِهِ أَبَدًا إِن كُنتُم مُؤمِنينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdcccix{وَيُبَيِّنُ اللَّهُ لَكُمُ الءايٰتِ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdcccx{إِنَّ الَّذينَ يُحِبّونَ أَن تَشيعَ الفٰحِشَةُ فِى الَّذينَ ءامَنوا لَهُم عَذابٌ أَليمٌ فِى الدُّنيا وَالءاخِرَةِ وَاللَّهُ يَعلَمُ وَأَنتُم لا تَعلَمونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdcccxi{وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ وَأَنَّ اللَّهَ رَءوفٌ رَحيمٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdcccxii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَتَّبِعوا خُطُوٰتِ الشَّيطٰنِ وَمَن يَتَّبِع خُطُوٰتِ الشَّيطٰنِ فَإِنَّهُ يَأمُرُ بِالفَحشاءِ وَالمُنكَرِ وَلَولا فَضلُ اللَّهِ عَلَيكُم وَرَحمَتُهُ ما زَكىٰ مِنكُم مِن أَحَدٍ أَبَدًا وَلٰكِنَّ اللَّهَ يُزَكّى مَن يَشاءُ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdcccxiii{وَلا يَأتَلِ أُولُوا الفَضلِ مِنكُم وَالسَّعَةِ أَن يُؤتوا أُولِى القُربىٰ وَالمَسٰكينَ وَالمُهٰجِرينَ فى سَبيلِ اللَّهِ وَليَعفوا وَليَصفَحوا أَلا تُحِبّونَ أَن يَغفِرَ اللَّهُ لَكُم وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdcccxiv{إِنَّ الَّذينَ يَرمونَ المُحصَنٰتِ الغٰفِلٰتِ المُؤمِنٰتِ لُعِنوا فِى الدُّنيا وَالءاخِرَةِ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdcccxv{يَومَ تَشهَدُ عَلَيهِم أَلسِنَتُهُم وَأَيديهِم وَأَرجُلُهُم بِما كانوا يَعمَلونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdcccxvi{يَومَئِذٍ يُوَفّيهِمُ اللَّهُ دينَهُمُ الحَقَّ وَيَعلَمونَ أَنَّ اللَّهَ هُوَ الحَقُّ المُبينُ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdcccxvii{الخَبيثٰتُ لِلخَبيثينَ وَالخَبيثونَ لِلخَبيثٰتِ وَالطَّيِّبٰتُ لِلطَّيِّبينَ وَالطَّيِّبونَ لِلطَّيِّبٰتِ أُولٰئِكَ مُبَرَّءونَ مِمّا يَقولونَ لَهُم مَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdcccxviii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَدخُلوا بُيوتًا غَيرَ بُيوتِكُم حَتّىٰ تَستَأنِسوا وَتُسَلِّموا عَلىٰ أَهلِها ذٰلِكُم خَيرٌ لَكُم لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdcccxix{فَإِن لَم تَجِدوا فيها أَحَدًا فَلا تَدخُلوها حَتّىٰ يُؤذَنَ لَكُم وَإِن قيلَ لَكُمُ ارجِعوا فَارجِعوا هُوَ أَزكىٰ لَكُم وَاللَّهُ بِما تَعمَلونَ عَليمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdcccxx{لَيسَ عَلَيكُم جُناحٌ أَن تَدخُلوا بُيوتًا غَيرَ مَسكونَةٍ فيها مَتٰعٌ لَكُم وَاللَّهُ يَعلَمُ ما تُبدونَ وَما تَكتُمونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdcccxxi{قُل لِلمُؤمِنينَ يَغُضّوا مِن أَبصٰرِهِم وَيَحفَظوا فُروجَهُم ذٰلِكَ أَزكىٰ لَهُم إِنَّ اللَّهَ خَبيرٌ بِما يَصنَعونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdcccxxii{وَقُل لِلمُؤمِنٰتِ يَغضُضنَ مِن أَبصٰرِهِنَّ وَيَحفَظنَ فُروجَهُنَّ وَلا يُبدينَ زينَتَهُنَّ إِلّا ما ظَهَرَ مِنها وَليَضرِبنَ بِخُمُرِهِنَّ عَلىٰ جُيوبِهِنَّ وَلا يُبدينَ زينَتَهُنَّ إِلّا لِبُعولَتِهِنَّ أَو ءابائِهِنَّ أَو ءاباءِ بُعولَتِهِنَّ أَو أَبنائِهِنَّ أَو أَبناءِ بُعولَتِهِنَّ أَو إِخوٰنِهِنَّ أَو بَنى إِخوٰنِهِنَّ أَو بَنى أَخَوٰتِهِنَّ أَو نِسائِهِنَّ أَو ما مَلَكَت أَيمٰنُهُنَّ أَوِ التّٰبِعينَ غَيرِ أُولِى الإِربَةِ مِنَ الرِّجالِ أَوِ الطِّفلِ الَّذينَ لَم يَظهَروا عَلىٰ عَورٰتِ النِّساءِ وَلا يَضرِبنَ بِأَرجُلِهِنَّ لِيُعلَمَ ما يُخفينَ مِن زينَتِهِنَّ وَتوبوا إِلَى اللَّهِ جَميعًا أَيُّهَ المُؤمِنونَ لَعَلَّكُم تُفلِحونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdcccxxiii{وَأَنكِحُوا الأَيٰمىٰ مِنكُم وَالصّٰلِحينَ مِن عِبادِكُم وَإِمائِكُم إِن يَكونوا فُقَراءَ يُغنِهِمُ اللَّهُ مِن فَضلِهِ وَاللَّهُ وٰسِعٌ عَليمٌ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdcccxxiv{وَليَستَعفِفِ الَّذينَ لا يَجِدونَ نِكاحًا حَتّىٰ يُغنِيَهُمُ اللَّهُ مِن فَضلِهِ وَالَّذينَ يَبتَغونَ الكِتٰبَ مِمّا مَلَكَت أَيمٰنُكُم فَكاتِبوهُم إِن عَلِمتُم فيهِم خَيرًا وَءاتوهُم مِن مالِ اللَّهِ الَّذى ءاتىٰكُم وَلا تُكرِهوا فَتَيٰتِكُم عَلَى البِغاءِ إِن أَرَدنَ تَحَصُّنًا لِتَبتَغوا عَرَضَ الحَيوٰةِ الدُّنيا وَمَن يُكرِههُنَّ فَإِنَّ اللَّهَ مِن بَعدِ إِكرٰهِهِنَّ غَفورٌ رَحيمٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdcccxxv{وَلَقَد أَنزَلنا إِلَيكُم ءايٰتٍ مُبَيِّنٰتٍ وَمَثَلًا مِنَ الَّذينَ خَلَوا مِن قَبلِكُم وَمَوعِظَةً لِلمُتَّقينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcccxxvi{اللَّهُ نورُ السَّمٰوٰتِ وَالأَرضِ مَثَلُ نورِهِ كَمِشكوٰةٍ فيها مِصباحٌ المِصباحُ فى زُجاجَةٍ الزُّجاجَةُ كَأَنَّها كَوكَبٌ دُرِّىٌّ يوقَدُ مِن شَجَرَةٍ مُبٰرَكَةٍ زَيتونَةٍ لا شَرقِيَّةٍ وَلا غَربِيَّةٍ يَكادُ زَيتُها يُضيءُ وَلَو لَم تَمسَسهُ نارٌ نورٌ عَلىٰ نورٍ يَهدِى اللَّهُ لِنورِهِ مَن يَشاءُ وَيَضرِبُ اللَّهُ الأَمثٰلَ لِلنّاسِ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcccxxvii{فى بُيوتٍ أَذِنَ اللَّهُ أَن تُرفَعَ وَيُذكَرَ فيهَا اسمُهُ يُسَبِّحُ لَهُ فيها بِالغُدُوِّ وَالءاصالِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcccxxviii{رِجالٌ لا تُلهيهِم تِجٰرَةٌ وَلا بَيعٌ عَن ذِكرِ اللَّهِ وَإِقامِ الصَّلوٰةِ وَإيتاءِ الزَّكوٰةِ يَخافونَ يَومًا تَتَقَلَّبُ فيهِ القُلوبُ وَالأَبصٰرُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcccxxix{لِيَجزِيَهُمُ اللَّهُ أَحسَنَ ما عَمِلوا وَيَزيدَهُم مِن فَضلِهِ وَاللَّهُ يَرزُقُ مَن يَشاءُ بِغَيرِ حِسابٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcccxxx{وَالَّذينَ كَفَروا أَعمٰلُهُم كَسَرابٍ بِقيعَةٍ يَحسَبُهُ الظَّمـٔانُ ماءً حَتّىٰ إِذا جاءَهُ لَم يَجِدهُ شَيـًٔا وَوَجَدَ اللَّهَ عِندَهُ فَوَفّىٰهُ حِسابَهُ وَاللَّهُ سَريعُ الحِسابِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcccxxxi{أَو كَظُلُمٰتٍ فى بَحرٍ لُجِّىٍّ يَغشىٰهُ مَوجٌ مِن فَوقِهِ مَوجٌ مِن فَوقِهِ سَحابٌ ظُلُمٰتٌ بَعضُها فَوقَ بَعضٍ إِذا أَخرَجَ يَدَهُ لَم يَكَد يَرىٰها وَمَن لَم يَجعَلِ اللَّهُ لَهُ نورًا فَما لَهُ مِن نورٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcccxxxii{أَلَم تَرَ أَنَّ اللَّهَ يُسَبِّحُ لَهُ مَن فِى السَّمٰوٰتِ وَالأَرضِ وَالطَّيرُ صٰفّٰتٍ كُلٌّ قَد عَلِمَ صَلاتَهُ وَتَسبيحَهُ وَاللَّهُ عَليمٌ بِما يَفعَلونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcccxxxiii{وَلِلَّهِ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَإِلَى اللَّهِ المَصيرُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcccxxxiv{أَلَم تَرَ أَنَّ اللَّهَ يُزجى سَحابًا ثُمَّ يُؤَلِّفُ بَينَهُ ثُمَّ يَجعَلُهُ رُكامًا فَتَرَى الوَدقَ يَخرُجُ مِن خِلٰلِهِ وَيُنَزِّلُ مِنَ السَّماءِ مِن جِبالٍ فيها مِن بَرَدٍ فَيُصيبُ بِهِ مَن يَشاءُ وَيَصرِفُهُ عَن مَن يَشاءُ يَكادُ سَنا بَرقِهِ يَذهَبُ بِالأَبصٰرِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcccxxxv{يُقَلِّبُ اللَّهُ الَّيلَ وَالنَّهارَ إِنَّ فى ذٰلِكَ لَعِبرَةً لِأُولِى الأَبصٰرِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmdcccxxxvi{وَاللَّهُ خَلَقَ كُلَّ دابَّةٍ مِن ماءٍ فَمِنهُم مَن يَمشى عَلىٰ بَطنِهِ وَمِنهُم مَن يَمشى عَلىٰ رِجلَينِ وَمِنهُم مَن يَمشى عَلىٰ أَربَعٍ يَخلُقُ اللَّهُ ما يَشاءُ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmdcccxxxvii{لَقَد أَنزَلنا ءايٰتٍ مُبَيِّنٰتٍ وَاللَّهُ يَهدى مَن يَشاءُ إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmdcccxxxviii{وَيَقولونَ ءامَنّا بِاللَّهِ وَبِالرَّسولِ وَأَطَعنا ثُمَّ يَتَوَلّىٰ فَريقٌ مِنهُم مِن بَعدِ ذٰلِكَ وَما أُولٰئِكَ بِالمُؤمِنينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmdcccxxxix{وَإِذا دُعوا إِلَى اللَّهِ وَرَسولِهِ لِيَحكُمَ بَينَهُم إِذا فَريقٌ مِنهُم مُعرِضونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmdcccxl{وَإِن يَكُن لَهُمُ الحَقُّ يَأتوا إِلَيهِ مُذعِنينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmdcccxli{أَفى قُلوبِهِم مَرَضٌ أَمِ ارتابوا أَم يَخافونَ أَن يَحيفَ اللَّهُ عَلَيهِم وَرَسولُهُ بَل أُولٰئِكَ هُمُ الظّٰلِمونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmdcccxlii{إِنَّما كانَ قَولَ المُؤمِنينَ إِذا دُعوا إِلَى اللَّهِ وَرَسولِهِ لِيَحكُمَ بَينَهُم أَن يَقولوا سَمِعنا وَأَطَعنا وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmdcccxliii{وَمَن يُطِعِ اللَّهَ وَرَسولَهُ وَيَخشَ اللَّهَ وَيَتَّقهِ فَأُولٰئِكَ هُمُ الفائِزونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmdcccxliv{وَأَقسَموا بِاللَّهِ جَهدَ أَيمٰنِهِم لَئِن أَمَرتَهُم لَيَخرُجُنَّ قُل لا تُقسِموا طاعَةٌ مَعروفَةٌ إِنَّ اللَّهَ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmdcccxlv{قُل أَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ فَإِن تَوَلَّوا فَإِنَّما عَلَيهِ ما حُمِّلَ وَعَلَيكُم ما حُمِّلتُم وَإِن تُطيعوهُ تَهتَدوا وَما عَلَى الرَّسولِ إِلَّا البَلٰغُ المُبينُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmdcccxlvi{وَعَدَ اللَّهُ الَّذينَ ءامَنوا مِنكُم وَعَمِلُوا الصّٰلِحٰتِ لَيَستَخلِفَنَّهُم فِى الأَرضِ كَمَا استَخلَفَ الَّذينَ مِن قَبلِهِم وَلَيُمَكِّنَنَّ لَهُم دينَهُمُ الَّذِى ارتَضىٰ لَهُم وَلَيُبَدِّلَنَّهُم مِن بَعدِ خَوفِهِم أَمنًا يَعبُدونَنى لا يُشرِكونَ بى شَيـًٔا وَمَن كَفَرَ بَعدَ ذٰلِكَ فَأُولٰئِكَ هُمُ الفٰسِقونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmdcccxlvii{وَأَقيمُوا الصَّلوٰةَ وَءاتُوا الزَّكوٰةَ وَأَطيعُوا الرَّسولَ لَعَلَّكُم تُرحَمونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmdcccxlviii{لا تَحسَبَنَّ الَّذينَ كَفَروا مُعجِزينَ فِى الأَرضِ وَمَأوىٰهُمُ النّارُ وَلَبِئسَ المَصيرُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmdcccxlix{يٰأَيُّهَا الَّذينَ ءامَنوا لِيَستَـٔذِنكُمُ الَّذينَ مَلَكَت أَيمٰنُكُم وَالَّذينَ لَم يَبلُغُوا الحُلُمَ مِنكُم ثَلٰثَ مَرّٰتٍ مِن قَبلِ صَلوٰةِ الفَجرِ وَحينَ تَضَعونَ ثِيابَكُم مِنَ الظَّهيرَةِ وَمِن بَعدِ صَلوٰةِ العِشاءِ ثَلٰثُ عَورٰتٍ لَكُم لَيسَ عَلَيكُم وَلا عَلَيهِم جُناحٌ بَعدَهُنَّ طَوّٰفونَ عَلَيكُم بَعضُكُم عَلىٰ بَعضٍ كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُمُ الءايٰتِ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmdcccl{وَإِذا بَلَغَ الأَطفٰلُ مِنكُمُ الحُلُمَ فَليَستَـٔذِنوا كَمَا استَـٔذَنَ الَّذينَ مِن قَبلِهِم كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُم ءايٰتِهِ وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmdcccli{وَالقَوٰعِدُ مِنَ النِّساءِ الّٰتى لا يَرجونَ نِكاحًا فَلَيسَ عَلَيهِنَّ جُناحٌ أَن يَضَعنَ ثِيابَهُنَّ غَيرَ مُتَبَرِّجٰتٍ بِزينَةٍ وَأَن يَستَعفِفنَ خَيرٌ لَهُنَّ وَاللَّهُ سَميعٌ عَليمٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmdccclii{لَيسَ عَلَى الأَعمىٰ حَرَجٌ وَلا عَلَى الأَعرَجِ حَرَجٌ وَلا عَلَى المَريضِ حَرَجٌ وَلا عَلىٰ أَنفُسِكُم أَن تَأكُلوا مِن بُيوتِكُم أَو بُيوتِ ءابائِكُم أَو بُيوتِ أُمَّهٰتِكُم أَو بُيوتِ إِخوٰنِكُم أَو بُيوتِ أَخَوٰتِكُم أَو بُيوتِ أَعمٰمِكُم أَو بُيوتِ عَمّٰتِكُم أَو بُيوتِ أَخوٰلِكُم أَو بُيوتِ خٰلٰتِكُم أَو ما مَلَكتُم مَفاتِحَهُ أَو صَديقِكُم لَيسَ عَلَيكُم جُناحٌ أَن تَأكُلوا جَميعًا أَو أَشتاتًا فَإِذا دَخَلتُم بُيوتًا فَسَلِّموا عَلىٰ أَنفُسِكُم تَحِيَّةً مِن عِندِ اللَّهِ مُبٰرَكَةً طَيِّبَةً كَذٰلِكَ يُبَيِّنُ اللَّهُ لَكُمُ الءايٰتِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmdcccliii{إِنَّمَا المُؤمِنونَ الَّذينَ ءامَنوا بِاللَّهِ وَرَسولِهِ وَإِذا كانوا مَعَهُ عَلىٰ أَمرٍ جامِعٍ لَم يَذهَبوا حَتّىٰ يَستَـٔذِنوهُ إِنَّ الَّذينَ يَستَـٔذِنونَكَ أُولٰئِكَ الَّذينَ يُؤمِنونَ بِاللَّهِ وَرَسولِهِ فَإِذَا استَـٔذَنوكَ لِبَعضِ شَأنِهِم فَأذَن لِمَن شِئتَ مِنهُم وَاستَغفِر لَهُمُ اللَّهَ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmdcccliv{لا تَجعَلوا دُعاءَ الرَّسولِ بَينَكُم كَدُعاءِ بَعضِكُم بَعضًا قَد يَعلَمُ اللَّهُ الَّذينَ يَتَسَلَّلونَ مِنكُم لِواذًا فَليَحذَرِ الَّذينَ يُخالِفونَ عَن أَمرِهِ أَن تُصيبَهُم فِتنَةٌ أَو يُصيبَهُم عَذابٌ أَليمٌ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmdccclv{أَلا إِنَّ لِلَّهِ ما فِى السَّمٰوٰتِ وَالأَرضِ قَد يَعلَمُ ما أَنتُم عَلَيهِ وَيَومَ يُرجَعونَ إِلَيهِ فَيُنَبِّئُهُم بِما عَمِلوا وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmdccclvi{\basmalah  تَبارَكَ الَّذى نَزَّلَ الفُرقانَ عَلىٰ عَبدِهِ لِيَكونَ لِلعٰلَمينَ نَذيرًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmdccclvii{الَّذى لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَلَم يَتَّخِذ وَلَدًا وَلَم يَكُن لَهُ شَريكٌ فِى المُلكِ وَخَلَقَ كُلَّ شَيءٍ فَقَدَّرَهُ تَقديرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmdccclviii{وَاتَّخَذوا مِن دونِهِ ءالِهَةً لا يَخلُقونَ شَيـًٔا وَهُم يُخلَقونَ وَلا يَملِكونَ لِأَنفُسِهِم ضَرًّا وَلا نَفعًا وَلا يَملِكونَ مَوتًا وَلا حَيوٰةً وَلا نُشورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmdccclix{وَقالَ الَّذينَ كَفَروا إِن هٰذا إِلّا إِفكٌ افتَرىٰهُ وَأَعانَهُ عَلَيهِ قَومٌ ءاخَرونَ فَقَد جاءو ظُلمًا وَزورًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmdccclx{وَقالوا أَسٰطيرُ الأَوَّلينَ اكتَتَبَها فَهِىَ تُملىٰ عَلَيهِ بُكرَةً وَأَصيلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmdccclxi{قُل أَنزَلَهُ الَّذى يَعلَمُ السِّرَّ فِى السَّمٰوٰتِ وَالأَرضِ إِنَّهُ كانَ غَفورًا رَحيمًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmdccclxii{وَقالوا مالِ هٰذَا الرَّسولِ يَأكُلُ الطَّعامَ وَيَمشى فِى الأَسواقِ لَولا أُنزِلَ إِلَيهِ مَلَكٌ فَيَكونَ مَعَهُ نَذيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmdccclxiii{أَو يُلقىٰ إِلَيهِ كَنزٌ أَو تَكونُ لَهُ جَنَّةٌ يَأكُلُ مِنها وَقالَ الظّٰلِمونَ إِن تَتَّبِعونَ إِلّا رَجُلًا مَسحورًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmdccclxiv{انظُر كَيفَ ضَرَبوا لَكَ الأَمثٰلَ فَضَلّوا فَلا يَستَطيعونَ سَبيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmdccclxv{تَبارَكَ الَّذى إِن شاءَ جَعَلَ لَكَ خَيرًا مِن ذٰلِكَ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ وَيَجعَل لَكَ قُصورًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmdccclxvi{بَل كَذَّبوا بِالسّاعَةِ وَأَعتَدنا لِمَن كَذَّبَ بِالسّاعَةِ سَعيرًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmdccclxvii{إِذا رَأَتهُم مِن مَكانٍ بَعيدٍ سَمِعوا لَها تَغَيُّظًا وَزَفيرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmdccclxviii{وَإِذا أُلقوا مِنها مَكانًا ضَيِّقًا مُقَرَّنينَ دَعَوا هُنالِكَ ثُبورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmdccclxix{لا تَدعُوا اليَومَ ثُبورًا وٰحِدًا وَادعوا ثُبورًا كَثيرًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmdccclxx{قُل أَذٰلِكَ خَيرٌ أَم جَنَّةُ الخُلدِ الَّتى وُعِدَ المُتَّقونَ كانَت لَهُم جَزاءً وَمَصيرًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmdccclxxi{لَهُم فيها ما يَشاءونَ خٰلِدينَ كانَ عَلىٰ رَبِّكَ وَعدًا مَسـٔولًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmdccclxxii{وَيَومَ يَحشُرُهُم وَما يَعبُدونَ مِن دونِ اللَّهِ فَيَقولُ ءَأَنتُم أَضلَلتُم عِبادى هٰؤُلاءِ أَم هُم ضَلُّوا السَّبيلَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmdccclxxiii{قالوا سُبحٰنَكَ ما كانَ يَنبَغى لَنا أَن نَتَّخِذَ مِن دونِكَ مِن أَولِياءَ وَلٰكِن مَتَّعتَهُم وَءاباءَهُم حَتّىٰ نَسُوا الذِّكرَ وَكانوا قَومًا بورًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmdccclxxiv{فَقَد كَذَّبوكُم بِما تَقولونَ فَما تَستَطيعونَ صَرفًا وَلا نَصرًا وَمَن يَظلِم مِنكُم نُذِقهُ عَذابًا كَبيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmdccclxxv{وَما أَرسَلنا قَبلَكَ مِنَ المُرسَلينَ إِلّا إِنَّهُم لَيَأكُلونَ الطَّعامَ وَيَمشونَ فِى الأَسواقِ وَجَعَلنا بَعضَكُم لِبَعضٍ فِتنَةً أَتَصبِرونَ وَكانَ رَبُّكَ بَصيرًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmdccclxxvi{وَقالَ الَّذينَ لا يَرجونَ لِقاءَنا لَولا أُنزِلَ عَلَينَا المَلٰئِكَةُ أَو نَرىٰ رَبَّنا لَقَدِ استَكبَروا فى أَنفُسِهِم وَعَتَو عُتُوًّا كَبيرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmdccclxxvii{يَومَ يَرَونَ المَلٰئِكَةَ لا بُشرىٰ يَومَئِذٍ لِلمُجرِمينَ وَيَقولونَ حِجرًا مَحجورًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmdccclxxviii{وَقَدِمنا إِلىٰ ما عَمِلوا مِن عَمَلٍ فَجَعَلنٰهُ هَباءً مَنثورًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmdccclxxix{أَصحٰبُ الجَنَّةِ يَومَئِذٍ خَيرٌ مُستَقَرًّا وَأَحسَنُ مَقيلًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmdccclxxx{وَيَومَ تَشَقَّقُ السَّماءُ بِالغَمٰمِ وَنُزِّلَ المَلٰئِكَةُ تَنزيلًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmdccclxxxi{المُلكُ يَومَئِذٍ الحَقُّ لِلرَّحمٰنِ وَكانَ يَومًا عَلَى الكٰفِرينَ عَسيرًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmdccclxxxii{وَيَومَ يَعَضُّ الظّالِمُ عَلىٰ يَدَيهِ يَقولُ يٰلَيتَنِى اتَّخَذتُ مَعَ الرَّسولِ سَبيلًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmdccclxxxiii{يٰوَيلَتىٰ لَيتَنى لَم أَتَّخِذ فُلانًا خَليلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmdccclxxxiv{لَقَد أَضَلَّنى عَنِ الذِّكرِ بَعدَ إِذ جاءَنى وَكانَ الشَّيطٰنُ لِلإِنسٰنِ خَذولًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmdccclxxxv{وَقالَ الرَّسولُ يٰرَبِّ إِنَّ قَومِى اتَّخَذوا هٰذَا القُرءانَ مَهجورًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmdccclxxxvi{وَكَذٰلِكَ جَعَلنا لِكُلِّ نَبِىٍّ عَدُوًّا مِنَ المُجرِمينَ وَكَفىٰ بِرَبِّكَ هادِيًا وَنَصيرًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmdccclxxxvii{وَقالَ الَّذينَ كَفَروا لَولا نُزِّلَ عَلَيهِ القُرءانُ جُملَةً وٰحِدَةً كَذٰلِكَ لِنُثَبِّتَ بِهِ فُؤادَكَ وَرَتَّلنٰهُ تَرتيلًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmdccclxxxviii{وَلا يَأتونَكَ بِمَثَلٍ إِلّا جِئنٰكَ بِالحَقِّ وَأَحسَنَ تَفسيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmdccclxxxix{الَّذينَ يُحشَرونَ عَلىٰ وُجوهِهِم إِلىٰ جَهَنَّمَ أُولٰئِكَ شَرٌّ مَكانًا وَأَضَلُّ سَبيلًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmdcccxc{وَلَقَد ءاتَينا موسَى الكِتٰبَ وَجَعَلنا مَعَهُ أَخاهُ هٰرونَ وَزيرًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmdcccxci{فَقُلنَا اذهَبا إِلَى القَومِ الَّذينَ كَذَّبوا بِـٔايٰتِنا فَدَمَّرنٰهُم تَدميرًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmdcccxcii{وَقَومَ نوحٍ لَمّا كَذَّبُوا الرُّسُلَ أَغرَقنٰهُم وَجَعَلنٰهُم لِلنّاسِ ءايَةً وَأَعتَدنا لِلظّٰلِمينَ عَذابًا أَليمًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmdcccxciii{وَعادًا وَثَمودَا۟ وَأَصحٰبَ الرَّسِّ وَقُرونًا بَينَ ذٰلِكَ كَثيرًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmdcccxciv{وَكُلًّا ضَرَبنا لَهُ الأَمثٰلَ وَكُلًّا تَبَّرنا تَتبيرًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmdcccxcv{وَلَقَد أَتَوا عَلَى القَريَةِ الَّتى أُمطِرَت مَطَرَ السَّوءِ أَفَلَم يَكونوا يَرَونَها بَل كانوا لا يَرجونَ نُشورًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmdcccxcvi{وَإِذا رَأَوكَ إِن يَتَّخِذونَكَ إِلّا هُزُوًا أَهٰذَا الَّذى بَعَثَ اللَّهُ رَسولًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmdcccxcvii{إِن كادَ لَيُضِلُّنا عَن ءالِهَتِنا لَولا أَن صَبَرنا عَلَيها وَسَوفَ يَعلَمونَ حينَ يَرَونَ العَذابَ مَن أَضَلُّ سَبيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmdcccxcviii{أَرَءَيتَ مَنِ اتَّخَذَ إِلٰهَهُ هَوىٰهُ أَفَأَنتَ تَكونُ عَلَيهِ وَكيلًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmdcccxcix{أَم تَحسَبُ أَنَّ أَكثَرَهُم يَسمَعونَ أَو يَعقِلونَ إِن هُم إِلّا كَالأَنعٰمِ بَل هُم أَضَلُّ سَبيلًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcm{أَلَم تَرَ إِلىٰ رَبِّكَ كَيفَ مَدَّ الظِّلَّ وَلَو شاءَ لَجَعَلَهُ ساكِنًا ثُمَّ جَعَلنَا الشَّمسَ عَلَيهِ دَليلًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcmi{ثُمَّ قَبَضنٰهُ إِلَينا قَبضًا يَسيرًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcmii{وَهُوَ الَّذى جَعَلَ لَكُمُ الَّيلَ لِباسًا وَالنَّومَ سُباتًا وَجَعَلَ النَّهارَ نُشورًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcmiii{وَهُوَ الَّذى أَرسَلَ الرِّيٰحَ بُشرًا بَينَ يَدَى رَحمَتِهِ وَأَنزَلنا مِنَ السَّماءِ ماءً طَهورًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcmiv{لِنُحۦِىَ بِهِ بَلدَةً مَيتًا وَنُسقِيَهُ مِمّا خَلَقنا أَنعٰمًا وَأَناسِىَّ كَثيرًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcmv{وَلَقَد صَرَّفنٰهُ بَينَهُم لِيَذَّكَّروا فَأَبىٰ أَكثَرُ النّاسِ إِلّا كُفورًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcmvi{وَلَو شِئنا لَبَعَثنا فى كُلِّ قَريَةٍ نَذيرًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcmvii{فَلا تُطِعِ الكٰفِرينَ وَجٰهِدهُم بِهِ جِهادًا كَبيرًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcmviii{وَهُوَ الَّذى مَرَجَ البَحرَينِ هٰذا عَذبٌ فُراتٌ وَهٰذا مِلحٌ أُجاجٌ وَجَعَلَ بَينَهُما بَرزَخًا وَحِجرًا مَحجورًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcmix{وَهُوَ الَّذى خَلَقَ مِنَ الماءِ بَشَرًا فَجَعَلَهُ نَسَبًا وَصِهرًا وَكانَ رَبُّكَ قَديرًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcmx{وَيَعبُدونَ مِن دونِ اللَّهِ ما لا يَنفَعُهُم وَلا يَضُرُّهُم وَكانَ الكافِرُ عَلىٰ رَبِّهِ ظَهيرًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcmxi{وَما أَرسَلنٰكَ إِلّا مُبَشِّرًا وَنَذيرًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcmxii{قُل ما أَسـَٔلُكُم عَلَيهِ مِن أَجرٍ إِلّا مَن شاءَ أَن يَتَّخِذَ إِلىٰ رَبِّهِ سَبيلًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcmxiii{وَتَوَكَّل عَلَى الحَىِّ الَّذى لا يَموتُ وَسَبِّح بِحَمدِهِ وَكَفىٰ بِهِ بِذُنوبِ عِبادِهِ خَبيرًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcmxiv{الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ وَما بَينَهُما فى سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ الرَّحمٰنُ فَسـَٔل بِهِ خَبيرًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcmxv{وَإِذا قيلَ لَهُمُ اسجُدوا لِلرَّحمٰنِ قالوا وَمَا الرَّحمٰنُ أَنَسجُدُ لِما تَأمُرُنا وَزادَهُم نُفورًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcmxvi{تَبارَكَ الَّذى جَعَلَ فِى السَّماءِ بُروجًا وَجَعَلَ فيها سِرٰجًا وَقَمَرًا مُنيرًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcmxvii{وَهُوَ الَّذى جَعَلَ الَّيلَ وَالنَّهارَ خِلفَةً لِمَن أَرادَ أَن يَذَّكَّرَ أَو أَرادَ شُكورًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcmxviii{وَعِبادُ الرَّحمٰنِ الَّذينَ يَمشونَ عَلَى الأَرضِ هَونًا وَإِذا خاطَبَهُمُ الجٰهِلونَ قالوا سَلٰمًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcmxix{وَالَّذينَ يَبيتونَ لِرَبِّهِم سُجَّدًا وَقِيٰمًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcmxx{وَالَّذينَ يَقولونَ رَبَّنَا اصرِف عَنّا عَذابَ جَهَنَّمَ إِنَّ عَذابَها كانَ غَرامًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcmxxi{إِنَّها ساءَت مُستَقَرًّا وَمُقامًا\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcmxxii{وَالَّذينَ إِذا أَنفَقوا لَم يُسرِفوا وَلَم يَقتُروا وَكانَ بَينَ ذٰلِكَ قَوامًا\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmcmxxiii{وَالَّذينَ لا يَدعونَ مَعَ اللَّهِ إِلٰهًا ءاخَرَ وَلا يَقتُلونَ النَّفسَ الَّتى حَرَّمَ اللَّهُ إِلّا بِالحَقِّ وَلا يَزنونَ وَمَن يَفعَل ذٰلِكَ يَلقَ أَثامًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmcmxxiv{يُضٰعَف لَهُ العَذابُ يَومَ القِيٰمَةِ وَيَخلُد فيهِ مُهانًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmcmxxv{إِلّا مَن تابَ وَءامَنَ وَعَمِلَ عَمَلًا صٰلِحًا فَأُولٰئِكَ يُبَدِّلُ اللَّهُ سَيِّـٔاتِهِم حَسَنٰتٍ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmcmxxvi{وَمَن تابَ وَعَمِلَ صٰلِحًا فَإِنَّهُ يَتوبُ إِلَى اللَّهِ مَتابًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmcmxxvii{وَالَّذينَ لا يَشهَدونَ الزّورَ وَإِذا مَرّوا بِاللَّغوِ مَرّوا كِرامًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmcmxxviii{وَالَّذينَ إِذا ذُكِّروا بِـٔايٰتِ رَبِّهِم لَم يَخِرّوا عَلَيها صُمًّا وَعُميانًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmcmxxix{وَالَّذينَ يَقولونَ رَبَّنا هَب لَنا مِن أَزوٰجِنا وَذُرِّيّٰتِنا قُرَّةَ أَعيُنٍ وَاجعَلنا لِلمُتَّقينَ إِمامًا\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmcmxxx{أُولٰئِكَ يُجزَونَ الغُرفَةَ بِما صَبَروا وَيُلَقَّونَ فيها تَحِيَّةً وَسَلٰمًا\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmcmxxxi{خٰلِدينَ فيها حَسُنَت مُستَقَرًّا وَمُقامًا\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmcmxxxii{قُل ما يَعبَؤُا۟ بِكُم رَبّى لَولا دُعاؤُكُم فَقَد كَذَّبتُم فَسَوفَ يَكونُ لِزامًا\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmcmxxxiii{\basmalah  طسم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmcmxxxiv{تِلكَ ءايٰتُ الكِتٰبِ المُبينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmcmxxxv{لَعَلَّكَ بٰخِعٌ نَفسَكَ أَلّا يَكونوا مُؤمِنينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmcmxxxvi{إِن نَشَأ نُنَزِّل عَلَيهِم مِنَ السَّماءِ ءايَةً فَظَلَّت أَعنٰقُهُم لَها خٰضِعينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmcmxxxvii{وَما يَأتيهِم مِن ذِكرٍ مِنَ الرَّحمٰنِ مُحدَثٍ إِلّا كانوا عَنهُ مُعرِضينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmcmxxxviii{فَقَد كَذَّبوا فَسَيَأتيهِم أَنبٰؤُا۟ ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmcmxxxix{أَوَلَم يَرَوا إِلَى الأَرضِ كَم أَنبَتنا فيها مِن كُلِّ زَوجٍ كَريمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmcmxl{إِنَّ فى ذٰلِكَ لَءايَةً وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmcmxli{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmcmxlii{وَإِذ نادىٰ رَبُّكَ موسىٰ أَنِ ائتِ القَومَ الظّٰلِمينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmcmxliii{قَومَ فِرعَونَ أَلا يَتَّقونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmcmxliv{قالَ رَبِّ إِنّى أَخافُ أَن يُكَذِّبونِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmcmxlv{وَيَضيقُ صَدرى وَلا يَنطَلِقُ لِسانى فَأَرسِل إِلىٰ هٰرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmcmxlvi{وَلَهُم عَلَىَّ ذَنبٌ فَأَخافُ أَن يَقتُلونِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmcmxlvii{قالَ كَلّا فَاذهَبا بِـٔايٰتِنا إِنّا مَعَكُم مُستَمِعونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmcmxlviii{فَأتِيا فِرعَونَ فَقولا إِنّا رَسولُ رَبِّ العٰلَمينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmcmxlix{أَن أَرسِل مَعَنا بَنى إِسرٰءيلَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmcml{قالَ أَلَم نُرَبِّكَ فينا وَليدًا وَلَبِثتَ فينا مِن عُمُرِكَ سِنينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmcmli{وَفَعَلتَ فَعلَتَكَ الَّتى فَعَلتَ وَأَنتَ مِنَ الكٰفِرينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmcmlii{قالَ فَعَلتُها إِذًا وَأَنا۠ مِنَ الضّالّينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmcmliii{فَفَرَرتُ مِنكُم لَمّا خِفتُكُم فَوَهَبَ لى رَبّى حُكمًا وَجَعَلَنى مِنَ المُرسَلينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmcmliv{وَتِلكَ نِعمَةٌ تَمُنُّها عَلَىَّ أَن عَبَّدتَ بَنى إِسرٰءيلَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmcmlv{قالَ فِرعَونُ وَما رَبُّ العٰلَمينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmcmlvi{قالَ رَبُّ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُما إِن كُنتُم موقِنينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmcmlvii{قالَ لِمَن حَولَهُ أَلا تَستَمِعونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmcmlviii{قالَ رَبُّكُم وَرَبُّ ءابائِكُمُ الأَوَّلينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmcmlix{قالَ إِنَّ رَسولَكُمُ الَّذى أُرسِلَ إِلَيكُم لَمَجنونٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmcmlx{قالَ رَبُّ المَشرِقِ وَالمَغرِبِ وَما بَينَهُما إِن كُنتُم تَعقِلونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmcmlxi{قالَ لَئِنِ اتَّخَذتَ إِلٰهًا غَيرى لَأَجعَلَنَّكَ مِنَ المَسجونينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmcmlxii{قالَ أَوَلَو جِئتُكَ بِشَيءٍ مُبينٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmcmlxiii{قالَ فَأتِ بِهِ إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmcmlxiv{فَأَلقىٰ عَصاهُ فَإِذا هِىَ ثُعبانٌ مُبينٌ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmcmlxv{وَنَزَعَ يَدَهُ فَإِذا هِىَ بَيضاءُ لِلنّٰظِرينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmcmlxvi{قالَ لِلمَلَإِ حَولَهُ إِنَّ هٰذا لَسٰحِرٌ عَليمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmcmlxvii{يُريدُ أَن يُخرِجَكُم مِن أَرضِكُم بِسِحرِهِ فَماذا تَأمُرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmcmlxviii{قالوا أَرجِه وَأَخاهُ وَابعَث فِى المَدائِنِ حٰشِرينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmcmlxix{يَأتوكَ بِكُلِّ سَحّارٍ عَليمٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmcmlxx{فَجُمِعَ السَّحَرَةُ لِميقٰتِ يَومٍ مَعلومٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmcmlxxi{وَقيلَ لِلنّاسِ هَل أَنتُم مُجتَمِعونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmcmlxxii{لَعَلَّنا نَتَّبِعُ السَّحَرَةَ إِن كانوا هُمُ الغٰلِبينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmcmlxxiii{فَلَمّا جاءَ السَّحَرَةُ قالوا لِفِرعَونَ أَئِنَّ لَنا لَأَجرًا إِن كُنّا نَحنُ الغٰلِبينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmcmlxxiv{قالَ نَعَم وَإِنَّكُم إِذًا لَمِنَ المُقَرَّبينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmcmlxxv{قالَ لَهُم موسىٰ أَلقوا ما أَنتُم مُلقونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmcmlxxvi{فَأَلقَوا حِبالَهُم وَعِصِيَّهُم وَقالوا بِعِزَّةِ فِرعَونَ إِنّا لَنَحنُ الغٰلِبونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmcmlxxvii{فَأَلقىٰ موسىٰ عَصاهُ فَإِذا هِىَ تَلقَفُ ما يَأفِكونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmcmlxxviii{فَأُلقِىَ السَّحَرَةُ سٰجِدينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmcmlxxix{قالوا ءامَنّا بِرَبِّ العٰلَمينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmcmlxxx{رَبِّ موسىٰ وَهٰرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmcmlxxxi{قالَ ءامَنتُم لَهُ قَبلَ أَن ءاذَنَ لَكُم إِنَّهُ لَكَبيرُكُمُ الَّذى عَلَّمَكُمُ السِّحرَ فَلَسَوفَ تَعلَمونَ لَأُقَطِّعَنَّ أَيدِيَكُم وَأَرجُلَكُم مِن خِلٰفٍ وَلَأُصَلِّبَنَّكُم أَجمَعينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmcmlxxxii{قالوا لا ضَيرَ إِنّا إِلىٰ رَبِّنا مُنقَلِبونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmcmlxxxiii{إِنّا نَطمَعُ أَن يَغفِرَ لَنا رَبُّنا خَطٰيٰنا أَن كُنّا أَوَّلَ المُؤمِنينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmcmlxxxiv{وَأَوحَينا إِلىٰ موسىٰ أَن أَسرِ بِعِبادى إِنَّكُم مُتَّبَعونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmcmlxxxv{فَأَرسَلَ فِرعَونُ فِى المَدائِنِ حٰشِرينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmcmlxxxvi{إِنَّ هٰؤُلاءِ لَشِرذِمَةٌ قَليلونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmcmlxxxvii{وَإِنَّهُم لَنا لَغائِظونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmcmlxxxviii{وَإِنّا لَجَميعٌ حٰذِرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmcmlxxxix{فَأَخرَجنٰهُم مِن جَنّٰتٍ وَعُيونٍ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmcmxc{وَكُنوزٍ وَمَقامٍ كَريمٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmcmxci{كَذٰلِكَ وَأَورَثنٰها بَنى إِسرٰءيلَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmcmxcii{فَأَتبَعوهُم مُشرِقينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmcmxciii{فَلَمّا تَرٰءَا الجَمعانِ قالَ أَصحٰبُ موسىٰ إِنّا لَمُدرَكونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmcmxciv{قالَ كَلّا إِنَّ مَعِىَ رَبّى سَيَهدينِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmcmxcv{فَأَوحَينا إِلىٰ موسىٰ أَنِ اضرِب بِعَصاكَ البَحرَ فَانفَلَقَ فَكانَ كُلُّ فِرقٍ كَالطَّودِ العَظيمِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmcmxcvi{وَأَزلَفنا ثَمَّ الءاخَرينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmcmxcvii{وَأَنجَينا موسىٰ وَمَن مَعَهُ أَجمَعينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmcmxcviii{ثُمَّ أَغرَقنَا الءاخَرينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmcmxcix{إِنَّ فى ذٰلِكَ لَءايَةً وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmm{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmi{وَاتلُ عَلَيهِم نَبَأَ إِبرٰهيمَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmii{إِذ قالَ لِأَبيهِ وَقَومِهِ ما تَعبُدونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmiii{قالوا نَعبُدُ أَصنامًا فَنَظَلُّ لَها عٰكِفينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmiv{قالَ هَل يَسمَعونَكُم إِذ تَدعونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmv{أَو يَنفَعونَكُم أَو يَضُرّونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmvi{قالوا بَل وَجَدنا ءاباءَنا كَذٰلِكَ يَفعَلونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmvii{قالَ أَفَرَءَيتُم ما كُنتُم تَعبُدونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmviii{أَنتُم وَءاباؤُكُمُ الأَقدَمونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmix{فَإِنَّهُم عَدُوٌّ لى إِلّا رَبَّ العٰلَمينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmx{الَّذى خَلَقَنى فَهُوَ يَهدينِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmxi{وَالَّذى هُوَ يُطعِمُنى وَيَسقينِ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmxii{وَإِذا مَرِضتُ فَهُوَ يَشفينِ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmxiii{وَالَّذى يُميتُنى ثُمَّ يُحيينِ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmxiv{وَالَّذى أَطمَعُ أَن يَغفِرَ لى خَطيـَٔتى يَومَ الدّينِ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmxv{رَبِّ هَب لى حُكمًا وَأَلحِقنى بِالصّٰلِحينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmxvi{وَاجعَل لى لِسانَ صِدقٍ فِى الءاخِرينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmxvii{وَاجعَلنى مِن وَرَثَةِ جَنَّةِ النَّعيمِ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmxviii{وَاغفِر لِأَبى إِنَّهُ كانَ مِنَ الضّالّينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmxix{وَلا تُخزِنى يَومَ يُبعَثونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmxx{يَومَ لا يَنفَعُ مالٌ وَلا بَنونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmxxi{إِلّا مَن أَتَى اللَّهَ بِقَلبٍ سَليمٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmxxii{وَأُزلِفَتِ الجَنَّةُ لِلمُتَّقينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmxxiii{وَبُرِّزَتِ الجَحيمُ لِلغاوينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmxxiv{وَقيلَ لَهُم أَينَ ما كُنتُم تَعبُدونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmxxv{مِن دونِ اللَّهِ هَل يَنصُرونَكُم أَو يَنتَصِرونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmxxvi{فَكُبكِبوا فيها هُم وَالغاوۥنَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmxxvii{وَجُنودُ إِبليسَ أَجمَعونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmxxviii{قالوا وَهُم فيها يَختَصِمونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmxxix{تَاللَّهِ إِن كُنّا لَفى ضَلٰلٍ مُبينٍ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmmxxx{إِذ نُسَوّيكُم بِرَبِّ العٰلَمينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmmxxxi{وَما أَضَلَّنا إِلَّا المُجرِمونَ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmmxxxii{فَما لَنا مِن شٰفِعينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmmxxxiii{وَلا صَديقٍ حَميمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmmxxxiv{فَلَو أَنَّ لَنا كَرَّةً فَنَكونَ مِنَ المُؤمِنينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmmxxxv{إِنَّ فى ذٰلِكَ لَءايَةً وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmmxxxvi{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmmxxxvii{كَذَّبَت قَومُ نوحٍ المُرسَلينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmmxxxviii{إِذ قالَ لَهُم أَخوهُم نوحٌ أَلا تَتَّقونَ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmmxxxix{إِنّى لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmmxl{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmmxli{وَما أَسـَٔلُكُم عَلَيهِ مِن أَجرٍ إِن أَجرِىَ إِلّا عَلىٰ رَبِّ العٰلَمينَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmmxlii{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmmxliii{قالوا أَنُؤمِنُ لَكَ وَاتَّبَعَكَ الأَرذَلونَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmmxliv{قالَ وَما عِلمى بِما كانوا يَعمَلونَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmmxlv{إِن حِسابُهُم إِلّا عَلىٰ رَبّى لَو تَشعُرونَ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmmxlvi{وَما أَنا۠ بِطارِدِ المُؤمِنينَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmmxlvii{إِن أَنا۠ إِلّا نَذيرٌ مُبينٌ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmmxlviii{قالوا لَئِن لَم تَنتَهِ يٰنوحُ لَتَكونَنَّ مِنَ المَرجومينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmmxlix{قالَ رَبِّ إِنَّ قَومى كَذَّبونِ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmml{فَافتَح بَينى وَبَينَهُم فَتحًا وَنَجِّنى وَمَن مَعِىَ مِنَ المُؤمِنينَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmmli{فَأَنجَينٰهُ وَمَن مَعَهُ فِى الفُلكِ المَشحونِ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmmlii{ثُمَّ أَغرَقنا بَعدُ الباقينَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmmliii{إِنَّ فى ذٰلِكَ لَءايَةً وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmmliv{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmmlv{كَذَّبَت عادٌ المُرسَلينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmmlvi{إِذ قالَ لَهُم أَخوهُم هودٌ أَلا تَتَّقونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmmlvii{إِنّى لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmmlviii{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmmlix{وَما أَسـَٔلُكُم عَلَيهِ مِن أَجرٍ إِن أَجرِىَ إِلّا عَلىٰ رَبِّ العٰلَمينَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmmlx{أَتَبنونَ بِكُلِّ ريعٍ ءايَةً تَعبَثونَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmmlxi{وَتَتَّخِذونَ مَصانِعَ لَعَلَّكُم تَخلُدونَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmmlxii{وَإِذا بَطَشتُم بَطَشتُم جَبّارينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmmlxiii{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmmlxiv{وَاتَّقُوا الَّذى أَمَدَّكُم بِما تَعلَمونَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmmlxv{أَمَدَّكُم بِأَنعٰمٍ وَبَنينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmmlxvi{وَجَنّٰتٍ وَعُيونٍ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmmlxvii{إِنّى أَخافُ عَلَيكُم عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmmlxviii{قالوا سَواءٌ عَلَينا أَوَعَظتَ أَم لَم تَكُن مِنَ الوٰعِظينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mmmlxix{إِن هٰذا إِلّا خُلُقُ الأَوَّلينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mmmlxx{وَما نَحنُ بِمُعَذَّبينَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mmmlxxi{فَكَذَّبوهُ فَأَهلَكنٰهُم إِنَّ فى ذٰلِكَ لَءايَةً وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mmmlxxii{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mmmlxxiii{كَذَّبَت ثَمودُ المُرسَلينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mmmlxxiv{إِذ قالَ لَهُم أَخوهُم صٰلِحٌ أَلا تَتَّقونَ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mmmlxxv{إِنّى لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mmmlxxvi{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mmmlxxvii{وَما أَسـَٔلُكُم عَلَيهِ مِن أَجرٍ إِن أَجرِىَ إِلّا عَلىٰ رَبِّ العٰلَمينَ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mmmlxxviii{أَتُترَكونَ فى ما هٰهُنا ءامِنينَ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mmmlxxix{فى جَنّٰتٍ وَعُيونٍ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mmmlxxx{وَزُروعٍ وَنَخلٍ طَلعُها هَضيمٌ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mmmlxxxi{وَتَنحِتونَ مِنَ الجِبالِ بُيوتًا فٰرِهينَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mmmlxxxii{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mmmlxxxiii{وَلا تُطيعوا أَمرَ المُسرِفينَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mmmlxxxiv{الَّذينَ يُفسِدونَ فِى الأَرضِ وَلا يُصلِحونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mmmlxxxv{قالوا إِنَّما أَنتَ مِنَ المُسَحَّرينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mmmlxxxvi{ما أَنتَ إِلّا بَشَرٌ مِثلُنا فَأتِ بِـٔايَةٍ إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mmmlxxxvii{قالَ هٰذِهِ ناقَةٌ لَها شِربٌ وَلَكُم شِربُ يَومٍ مَعلومٍ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mmmlxxxviii{وَلا تَمَسّوها بِسوءٍ فَيَأخُذَكُم عَذابُ يَومٍ عَظيمٍ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mmmlxxxix{فَعَقَروها فَأَصبَحوا نٰدِمينَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mmmxc{فَأَخَذَهُمُ العَذابُ إِنَّ فى ذٰلِكَ لَءايَةً وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mmmxci{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mmmxcii{كَذَّبَت قَومُ لوطٍ المُرسَلينَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mmmxciii{إِذ قالَ لَهُم أَخوهُم لوطٌ أَلا تَتَّقونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mmmxciv{إِنّى لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mmmxcv{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mmmxcvi{وَما أَسـَٔلُكُم عَلَيهِ مِن أَجرٍ إِن أَجرِىَ إِلّا عَلىٰ رَبِّ العٰلَمينَ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mmmxcvii{أَتَأتونَ الذُّكرانَ مِنَ العٰلَمينَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mmmxcviii{وَتَذَرونَ ما خَلَقَ لَكُم رَبُّكُم مِن أَزوٰجِكُم بَل أَنتُم قَومٌ عادونَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mmmxcix{قالوا لَئِن لَم تَنتَهِ يٰلوطُ لَتَكونَنَّ مِنَ المُخرَجينَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mmmc{قالَ إِنّى لِعَمَلِكُم مِنَ القالينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mmmci{رَبِّ نَجِّنى وَأَهلى مِمّا يَعمَلونَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mmmcii{فَنَجَّينٰهُ وَأَهلَهُ أَجمَعينَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mmmciii{إِلّا عَجوزًا فِى الغٰبِرينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mmmciv{ثُمَّ دَمَّرنَا الءاخَرينَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mmmcv{وَأَمطَرنا عَلَيهِم مَطَرًا فَساءَ مَطَرُ المُنذَرينَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mmmcvi{إِنَّ فى ذٰلِكَ لَءايَةً وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mmmcvii{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mmmcviii{كَذَّبَ أَصحٰبُ لـَٔيكَةِ المُرسَلينَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mmmcix{إِذ قالَ لَهُم شُعَيبٌ أَلا تَتَّقونَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mmmcx{إِنّى لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mmmcxi{فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mmmcxii{وَما أَسـَٔلُكُم عَلَيهِ مِن أَجرٍ إِن أَجرِىَ إِلّا عَلىٰ رَبِّ العٰلَمينَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mmmcxiii{أَوفُوا الكَيلَ وَلا تَكونوا مِنَ المُخسِرينَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mmmcxiv{وَزِنوا بِالقِسطاسِ المُستَقيمِ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mmmcxv{وَلا تَبخَسُوا النّاسَ أَشياءَهُم وَلا تَعثَوا فِى الأَرضِ مُفسِدينَ\qt@no{﴿١٨٣﴾}}
\qt@newcmd\qurantext@mmmcxvi{وَاتَّقُوا الَّذى خَلَقَكُم وَالجِبِلَّةَ الأَوَّلينَ\qt@no{﴿١٨٤﴾}}
\qt@newcmd\qurantext@mmmcxvii{قالوا إِنَّما أَنتَ مِنَ المُسَحَّرينَ\qt@no{﴿١٨٥﴾}}
\qt@newcmd\qurantext@mmmcxviii{وَما أَنتَ إِلّا بَشَرٌ مِثلُنا وَإِن نَظُنُّكَ لَمِنَ الكٰذِبينَ\qt@no{﴿١٨٦﴾}}
\qt@newcmd\qurantext@mmmcxix{فَأَسقِط عَلَينا كِسَفًا مِنَ السَّماءِ إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿١٨٧﴾}}
\qt@newcmd\qurantext@mmmcxx{قالَ رَبّى أَعلَمُ بِما تَعمَلونَ\qt@no{﴿١٨٨﴾}}
\qt@newcmd\qurantext@mmmcxxi{فَكَذَّبوهُ فَأَخَذَهُم عَذابُ يَومِ الظُّلَّةِ إِنَّهُ كانَ عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٨٩﴾}}
\qt@newcmd\qurantext@mmmcxxii{إِنَّ فى ذٰلِكَ لَءايَةً وَما كانَ أَكثَرُهُم مُؤمِنينَ\qt@no{﴿١٩٠﴾}}
\qt@newcmd\qurantext@mmmcxxiii{وَإِنَّ رَبَّكَ لَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿١٩١﴾}}
\qt@newcmd\qurantext@mmmcxxiv{وَإِنَّهُ لَتَنزيلُ رَبِّ العٰلَمينَ\qt@no{﴿١٩٢﴾}}
\qt@newcmd\qurantext@mmmcxxv{نَزَلَ بِهِ الرّوحُ الأَمينُ\qt@no{﴿١٩٣﴾}}
\qt@newcmd\qurantext@mmmcxxvi{عَلىٰ قَلبِكَ لِتَكونَ مِنَ المُنذِرينَ\qt@no{﴿١٩٤﴾}}
\qt@newcmd\qurantext@mmmcxxvii{بِلِسانٍ عَرَبِىٍّ مُبينٍ\qt@no{﴿١٩٥﴾}}
\qt@newcmd\qurantext@mmmcxxviii{وَإِنَّهُ لَفى زُبُرِ الأَوَّلينَ\qt@no{﴿١٩٦﴾}}
\qt@newcmd\qurantext@mmmcxxix{أَوَلَم يَكُن لَهُم ءايَةً أَن يَعلَمَهُ عُلَمٰؤُا۟ بَنى إِسرٰءيلَ\qt@no{﴿١٩٧﴾}}
\qt@newcmd\qurantext@mmmcxxx{وَلَو نَزَّلنٰهُ عَلىٰ بَعضِ الأَعجَمينَ\qt@no{﴿١٩٨﴾}}
\qt@newcmd\qurantext@mmmcxxxi{فَقَرَأَهُ عَلَيهِم ما كانوا بِهِ مُؤمِنينَ\qt@no{﴿١٩٩﴾}}
\qt@newcmd\qurantext@mmmcxxxii{كَذٰلِكَ سَلَكنٰهُ فى قُلوبِ المُجرِمينَ\qt@no{﴿٢٠٠﴾}}
\qt@newcmd\qurantext@mmmcxxxiii{لا يُؤمِنونَ بِهِ حَتّىٰ يَرَوُا العَذابَ الأَليمَ\qt@no{﴿٢٠١﴾}}
\qt@newcmd\qurantext@mmmcxxxiv{فَيَأتِيَهُم بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿٢٠٢﴾}}
\qt@newcmd\qurantext@mmmcxxxv{فَيَقولوا هَل نَحنُ مُنظَرونَ\qt@no{﴿٢٠٣﴾}}
\qt@newcmd\qurantext@mmmcxxxvi{أَفَبِعَذابِنا يَستَعجِلونَ\qt@no{﴿٢٠٤﴾}}
\qt@newcmd\qurantext@mmmcxxxvii{أَفَرَءَيتَ إِن مَتَّعنٰهُم سِنينَ\qt@no{﴿٢٠٥﴾}}
\qt@newcmd\qurantext@mmmcxxxviii{ثُمَّ جاءَهُم ما كانوا يوعَدونَ\qt@no{﴿٢٠٦﴾}}
\qt@newcmd\qurantext@mmmcxxxix{ما أَغنىٰ عَنهُم ما كانوا يُمَتَّعونَ\qt@no{﴿٢٠٧﴾}}
\qt@newcmd\qurantext@mmmcxl{وَما أَهلَكنا مِن قَريَةٍ إِلّا لَها مُنذِرونَ\qt@no{﴿٢٠٨﴾}}
\qt@newcmd\qurantext@mmmcxli{ذِكرىٰ وَما كُنّا ظٰلِمينَ\qt@no{﴿٢٠٩﴾}}
\qt@newcmd\qurantext@mmmcxlii{وَما تَنَزَّلَت بِهِ الشَّيٰطينُ\qt@no{﴿٢١٠﴾}}
\qt@newcmd\qurantext@mmmcxliii{وَما يَنبَغى لَهُم وَما يَستَطيعونَ\qt@no{﴿٢١١﴾}}
\qt@newcmd\qurantext@mmmcxliv{إِنَّهُم عَنِ السَّمعِ لَمَعزولونَ\qt@no{﴿٢١٢﴾}}
\qt@newcmd\qurantext@mmmcxlv{فَلا تَدعُ مَعَ اللَّهِ إِلٰهًا ءاخَرَ فَتَكونَ مِنَ المُعَذَّبينَ\qt@no{﴿٢١٣﴾}}
\qt@newcmd\qurantext@mmmcxlvi{وَأَنذِر عَشيرَتَكَ الأَقرَبينَ\qt@no{﴿٢١٤﴾}}
\qt@newcmd\qurantext@mmmcxlvii{وَاخفِض جَناحَكَ لِمَنِ اتَّبَعَكَ مِنَ المُؤمِنينَ\qt@no{﴿٢١٥﴾}}
\qt@newcmd\qurantext@mmmcxlviii{فَإِن عَصَوكَ فَقُل إِنّى بَريءٌ مِمّا تَعمَلونَ\qt@no{﴿٢١٦﴾}}
\qt@newcmd\qurantext@mmmcxlix{وَتَوَكَّل عَلَى العَزيزِ الرَّحيمِ\qt@no{﴿٢١٧﴾}}
\qt@newcmd\qurantext@mmmcl{الَّذى يَرىٰكَ حينَ تَقومُ\qt@no{﴿٢١٨﴾}}
\qt@newcmd\qurantext@mmmcli{وَتَقَلُّبَكَ فِى السّٰجِدينَ\qt@no{﴿٢١٩﴾}}
\qt@newcmd\qurantext@mmmclii{إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٢٢٠﴾}}
\qt@newcmd\qurantext@mmmcliii{هَل أُنَبِّئُكُم عَلىٰ مَن تَنَزَّلُ الشَّيٰطينُ\qt@no{﴿٢٢١﴾}}
\qt@newcmd\qurantext@mmmcliv{تَنَزَّلُ عَلىٰ كُلِّ أَفّاكٍ أَثيمٍ\qt@no{﴿٢٢٢﴾}}
\qt@newcmd\qurantext@mmmclv{يُلقونَ السَّمعَ وَأَكثَرُهُم كٰذِبونَ\qt@no{﴿٢٢٣﴾}}
\qt@newcmd\qurantext@mmmclvi{وَالشُّعَراءُ يَتَّبِعُهُمُ الغاوۥنَ\qt@no{﴿٢٢٤﴾}}
\qt@newcmd\qurantext@mmmclvii{أَلَم تَرَ أَنَّهُم فى كُلِّ وادٍ يَهيمونَ\qt@no{﴿٢٢٥﴾}}
\qt@newcmd\qurantext@mmmclviii{وَأَنَّهُم يَقولونَ ما لا يَفعَلونَ\qt@no{﴿٢٢٦﴾}}
\qt@newcmd\qurantext@mmmclix{إِلَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ وَذَكَرُوا اللَّهَ كَثيرًا وَانتَصَروا مِن بَعدِ ما ظُلِموا وَسَيَعلَمُ الَّذينَ ظَلَموا أَىَّ مُنقَلَبٍ يَنقَلِبونَ\qt@no{﴿٢٢٧﴾}}
\qt@newcmd\qurantext@mmmclx{\basmalah  طس تِلكَ ءايٰتُ القُرءانِ وَكِتابٍ مُبينٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmclxi{هُدًى وَبُشرىٰ لِلمُؤمِنينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmclxii{الَّذينَ يُقيمونَ الصَّلوٰةَ وَيُؤتونَ الزَّكوٰةَ وَهُم بِالءاخِرَةِ هُم يوقِنونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmclxiii{إِنَّ الَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ زَيَّنّا لَهُم أَعمٰلَهُم فَهُم يَعمَهونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmclxiv{أُولٰئِكَ الَّذينَ لَهُم سوءُ العَذابِ وَهُم فِى الءاخِرَةِ هُمُ الأَخسَرونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmclxv{وَإِنَّكَ لَتُلَقَّى القُرءانَ مِن لَدُن حَكيمٍ عَليمٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmclxvi{إِذ قالَ موسىٰ لِأَهلِهِ إِنّى ءانَستُ نارًا سَـٔاتيكُم مِنها بِخَبَرٍ أَو ءاتيكُم بِشِهابٍ قَبَسٍ لَعَلَّكُم تَصطَلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmclxvii{فَلَمّا جاءَها نودِىَ أَن بورِكَ مَن فِى النّارِ وَمَن حَولَها وَسُبحٰنَ اللَّهِ رَبِّ العٰلَمينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmclxviii{يٰموسىٰ إِنَّهُ أَنَا اللَّهُ العَزيزُ الحَكيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmclxix{وَأَلقِ عَصاكَ فَلَمّا رَءاها تَهتَزُّ كَأَنَّها جانٌّ وَلّىٰ مُدبِرًا وَلَم يُعَقِّب يٰموسىٰ لا تَخَف إِنّى لا يَخافُ لَدَىَّ المُرسَلونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmclxx{إِلّا مَن ظَلَمَ ثُمَّ بَدَّلَ حُسنًا بَعدَ سوءٍ فَإِنّى غَفورٌ رَحيمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmclxxi{وَأَدخِل يَدَكَ فى جَيبِكَ تَخرُج بَيضاءَ مِن غَيرِ سوءٍ فى تِسعِ ءايٰتٍ إِلىٰ فِرعَونَ وَقَومِهِ إِنَّهُم كانوا قَومًا فٰسِقينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmclxxii{فَلَمّا جاءَتهُم ءايٰتُنا مُبصِرَةً قالوا هٰذا سِحرٌ مُبينٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmclxxiii{وَجَحَدوا بِها وَاستَيقَنَتها أَنفُسُهُم ظُلمًا وَعُلُوًّا فَانظُر كَيفَ كانَ عٰقِبَةُ المُفسِدينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmclxxiv{وَلَقَد ءاتَينا داوۥدَ وَسُلَيمٰنَ عِلمًا وَقالَا الحَمدُ لِلَّهِ الَّذى فَضَّلَنا عَلىٰ كَثيرٍ مِن عِبادِهِ المُؤمِنينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmclxxv{وَوَرِثَ سُلَيمٰنُ داوۥدَ وَقالَ يٰأَيُّهَا النّاسُ عُلِّمنا مَنطِقَ الطَّيرِ وَأوتينا مِن كُلِّ شَيءٍ إِنَّ هٰذا لَهُوَ الفَضلُ المُبينُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmclxxvi{وَحُشِرَ لِسُلَيمٰنَ جُنودُهُ مِنَ الجِنِّ وَالإِنسِ وَالطَّيرِ فَهُم يوزَعونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmclxxvii{حَتّىٰ إِذا أَتَوا عَلىٰ وادِ النَّملِ قالَت نَملَةٌ يٰأَيُّهَا النَّملُ ادخُلوا مَسٰكِنَكُم لا يَحطِمَنَّكُم سُلَيمٰنُ وَجُنودُهُ وَهُم لا يَشعُرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmclxxviii{فَتَبَسَّمَ ضاحِكًا مِن قَولِها وَقالَ رَبِّ أَوزِعنى أَن أَشكُرَ نِعمَتَكَ الَّتى أَنعَمتَ عَلَىَّ وَعَلىٰ وٰلِدَىَّ وَأَن أَعمَلَ صٰلِحًا تَرضىٰهُ وَأَدخِلنى بِرَحمَتِكَ فى عِبادِكَ الصّٰلِحينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmclxxix{وَتَفَقَّدَ الطَّيرَ فَقالَ ما لِىَ لا أَرَى الهُدهُدَ أَم كانَ مِنَ الغائِبينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmclxxx{لَأُعَذِّبَنَّهُ عَذابًا شَديدًا أَو لَأَا۟ذبَحَنَّهُ أَو لَيَأتِيَنّى بِسُلطٰنٍ مُبينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmclxxxi{فَمَكَثَ غَيرَ بَعيدٍ فَقالَ أَحَطتُ بِما لَم تُحِط بِهِ وَجِئتُكَ مِن سَبَإٍ بِنَبَإٍ يَقينٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmclxxxii{إِنّى وَجَدتُ امرَأَةً تَملِكُهُم وَأوتِيَت مِن كُلِّ شَيءٍ وَلَها عَرشٌ عَظيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmclxxxiii{وَجَدتُها وَقَومَها يَسجُدونَ لِلشَّمسِ مِن دونِ اللَّهِ وَزَيَّنَ لَهُمُ الشَّيطٰنُ أَعمٰلَهُم فَصَدَّهُم عَنِ السَّبيلِ فَهُم لا يَهتَدونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmclxxxiv{أَلّا يَسجُدوا لِلَّهِ الَّذى يُخرِجُ الخَبءَ فِى السَّمٰوٰتِ وَالأَرضِ وَيَعلَمُ ما تُخفونَ وَما تُعلِنونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmclxxxv{اللَّهُ لا إِلٰهَ إِلّا هُوَ رَبُّ العَرشِ العَظيمِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmclxxxvi{قالَ سَنَنظُرُ أَصَدَقتَ أَم كُنتَ مِنَ الكٰذِبينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmclxxxvii{اذهَب بِكِتٰبى هٰذا فَأَلقِه إِلَيهِم ثُمَّ تَوَلَّ عَنهُم فَانظُر ماذا يَرجِعونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmclxxxviii{قالَت يٰأَيُّهَا المَلَؤُا۟ إِنّى أُلقِىَ إِلَىَّ كِتٰبٌ كَريمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmclxxxix{إِنَّهُ مِن سُلَيمٰنَ وَإِنَّهُ بِسمِ اللَّهِ الرَّحمٰنِ الرَّحيمِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcxc{أَلّا تَعلوا عَلَىَّ وَأتونى مُسلِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcxci{قالَت يٰأَيُّهَا المَلَؤُا۟ أَفتونى فى أَمرى ما كُنتُ قاطِعَةً أَمرًا حَتّىٰ تَشهَدونِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcxcii{قالوا نَحنُ أُولوا قُوَّةٍ وَأُولوا بَأسٍ شَديدٍ وَالأَمرُ إِلَيكِ فَانظُرى ماذا تَأمُرينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcxciii{قالَت إِنَّ المُلوكَ إِذا دَخَلوا قَريَةً أَفسَدوها وَجَعَلوا أَعِزَّةَ أَهلِها أَذِلَّةً وَكَذٰلِكَ يَفعَلونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcxciv{وَإِنّى مُرسِلَةٌ إِلَيهِم بِهَدِيَّةٍ فَناظِرَةٌ بِمَ يَرجِعُ المُرسَلونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcxcv{فَلَمّا جاءَ سُلَيمٰنَ قالَ أَتُمِدّونَنِ بِمالٍ فَما ءاتىٰنِۦَ اللَّهُ خَيرٌ مِمّا ءاتىٰكُم بَل أَنتُم بِهَدِيَّتِكُم تَفرَحونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcxcvi{ارجِع إِلَيهِم فَلَنَأتِيَنَّهُم بِجُنودٍ لا قِبَلَ لَهُم بِها وَلَنُخرِجَنَّهُم مِنها أَذِلَّةً وَهُم صٰغِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmcxcvii{قالَ يٰأَيُّهَا المَلَؤُا۟ أَيُّكُم يَأتينى بِعَرشِها قَبلَ أَن يَأتونى مُسلِمينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmcxcviii{قالَ عِفريتٌ مِنَ الجِنِّ أَنا۠ ءاتيكَ بِهِ قَبلَ أَن تَقومَ مِن مَقامِكَ وَإِنّى عَلَيهِ لَقَوِىٌّ أَمينٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmcxcix{قالَ الَّذى عِندَهُ عِلمٌ مِنَ الكِتٰبِ أَنا۠ ءاتيكَ بِهِ قَبلَ أَن يَرتَدَّ إِلَيكَ طَرفُكَ فَلَمّا رَءاهُ مُستَقِرًّا عِندَهُ قالَ هٰذا مِن فَضلِ رَبّى لِيَبلُوَنى ءَأَشكُرُ أَم أَكفُرُ وَمَن شَكَرَ فَإِنَّما يَشكُرُ لِنَفسِهِ وَمَن كَفَرَ فَإِنَّ رَبّى غَنِىٌّ كَريمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmcc{قالَ نَكِّروا لَها عَرشَها نَنظُر أَتَهتَدى أَم تَكونُ مِنَ الَّذينَ لا يَهتَدونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmcci{فَلَمّا جاءَت قيلَ أَهٰكَذا عَرشُكِ قالَت كَأَنَّهُ هُوَ وَأوتينَا العِلمَ مِن قَبلِها وَكُنّا مُسلِمينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccii{وَصَدَّها ما كانَت تَعبُدُ مِن دونِ اللَّهِ إِنَّها كانَت مِن قَومٍ كٰفِرينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmcciii{قيلَ لَهَا ادخُلِى الصَّرحَ فَلَمّا رَأَتهُ حَسِبَتهُ لُجَّةً وَكَشَفَت عَن ساقَيها قالَ إِنَّهُ صَرحٌ مُمَرَّدٌ مِن قَواريرَ قالَت رَبِّ إِنّى ظَلَمتُ نَفسى وَأَسلَمتُ مَعَ سُلَيمٰنَ لِلَّهِ رَبِّ العٰلَمينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmcciv{وَلَقَد أَرسَلنا إِلىٰ ثَمودَ أَخاهُم صٰلِحًا أَنِ اعبُدُوا اللَّهَ فَإِذا هُم فَريقانِ يَختَصِمونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccv{قالَ يٰقَومِ لِمَ تَستَعجِلونَ بِالسَّيِّئَةِ قَبلَ الحَسَنَةِ لَولا تَستَغفِرونَ اللَّهَ لَعَلَّكُم تُرحَمونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccvi{قالُوا اطَّيَّرنا بِكَ وَبِمَن مَعَكَ قالَ طٰئِرُكُم عِندَ اللَّهِ بَل أَنتُم قَومٌ تُفتَنونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccvii{وَكانَ فِى المَدينَةِ تِسعَةُ رَهطٍ يُفسِدونَ فِى الأَرضِ وَلا يُصلِحونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccviii{قالوا تَقاسَموا بِاللَّهِ لَنُبَيِّتَنَّهُ وَأَهلَهُ ثُمَّ لَنَقولَنَّ لِوَلِيِّهِ ما شَهِدنا مَهلِكَ أَهلِهِ وَإِنّا لَصٰدِقونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmccix{وَمَكَروا مَكرًا وَمَكَرنا مَكرًا وَهُم لا يَشعُرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmccx{فَانظُر كَيفَ كانَ عٰقِبَةُ مَكرِهِم أَنّا دَمَّرنٰهُم وَقَومَهُم أَجمَعينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmccxi{فَتِلكَ بُيوتُهُم خاوِيَةً بِما ظَلَموا إِنَّ فى ذٰلِكَ لَءايَةً لِقَومٍ يَعلَمونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmccxii{وَأَنجَينَا الَّذينَ ءامَنوا وَكانوا يَتَّقونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmccxiii{وَلوطًا إِذ قالَ لِقَومِهِ أَتَأتونَ الفٰحِشَةَ وَأَنتُم تُبصِرونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmccxiv{أَئِنَّكُم لَتَأتونَ الرِّجالَ شَهوَةً مِن دونِ النِّساءِ بَل أَنتُم قَومٌ تَجهَلونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmccxv{فَما كانَ جَوابَ قَومِهِ إِلّا أَن قالوا أَخرِجوا ءالَ لوطٍ مِن قَريَتِكُم إِنَّهُم أُناسٌ يَتَطَهَّرونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmccxvi{فَأَنجَينٰهُ وَأَهلَهُ إِلَّا امرَأَتَهُ قَدَّرنٰها مِنَ الغٰبِرينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmccxvii{وَأَمطَرنا عَلَيهِم مَطَرًا فَساءَ مَطَرُ المُنذَرينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmccxviii{قُلِ الحَمدُ لِلَّهِ وَسَلٰمٌ عَلىٰ عِبادِهِ الَّذينَ اصطَفىٰ ءاللَّهُ خَيرٌ أَمّا يُشرِكونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmccxix{أَمَّن خَلَقَ السَّمٰوٰتِ وَالأَرضَ وَأَنزَلَ لَكُم مِنَ السَّماءِ ماءً فَأَنبَتنا بِهِ حَدائِقَ ذاتَ بَهجَةٍ ما كانَ لَكُم أَن تُنبِتوا شَجَرَها أَءِلٰهٌ مَعَ اللَّهِ بَل هُم قَومٌ يَعدِلونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmccxx{أَمَّن جَعَلَ الأَرضَ قَرارًا وَجَعَلَ خِلٰلَها أَنهٰرًا وَجَعَلَ لَها رَوٰسِىَ وَجَعَلَ بَينَ البَحرَينِ حاجِزًا أَءِلٰهٌ مَعَ اللَّهِ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmccxxi{أَمَّن يُجيبُ المُضطَرَّ إِذا دَعاهُ وَيَكشِفُ السّوءَ وَيَجعَلُكُم خُلَفاءَ الأَرضِ أَءِلٰهٌ مَعَ اللَّهِ قَليلًا ما تَذَكَّرونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmccxxii{أَمَّن يَهديكُم فى ظُلُمٰتِ البَرِّ وَالبَحرِ وَمَن يُرسِلُ الرِّيٰحَ بُشرًا بَينَ يَدَى رَحمَتِهِ أَءِلٰهٌ مَعَ اللَّهِ تَعٰلَى اللَّهُ عَمّا يُشرِكونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmccxxiii{أَمَّن يَبدَؤُا۟ الخَلقَ ثُمَّ يُعيدُهُ وَمَن يَرزُقُكُم مِنَ السَّماءِ وَالأَرضِ أَءِلٰهٌ مَعَ اللَّهِ قُل هاتوا بُرهٰنَكُم إِن كُنتُم صٰدِقينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmccxxiv{قُل لا يَعلَمُ مَن فِى السَّمٰوٰتِ وَالأَرضِ الغَيبَ إِلَّا اللَّهُ وَما يَشعُرونَ أَيّانَ يُبعَثونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmccxxv{بَلِ ادّٰرَكَ عِلمُهُم فِى الءاخِرَةِ بَل هُم فى شَكٍّ مِنها بَل هُم مِنها عَمونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmccxxvi{وَقالَ الَّذينَ كَفَروا أَءِذا كُنّا تُرٰبًا وَءاباؤُنا أَئِنّا لَمُخرَجونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmccxxvii{لَقَد وُعِدنا هٰذا نَحنُ وَءاباؤُنا مِن قَبلُ إِن هٰذا إِلّا أَسٰطيرُ الأَوَّلينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmccxxviii{قُل سيروا فِى الأَرضِ فَانظُروا كَيفَ كانَ عٰقِبَةُ المُجرِمينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmccxxix{وَلا تَحزَن عَلَيهِم وَلا تَكُن فى ضَيقٍ مِمّا يَمكُرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmccxxx{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صٰدِقينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmccxxxi{قُل عَسىٰ أَن يَكونَ رَدِفَ لَكُم بَعضُ الَّذى تَستَعجِلونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmccxxxii{وَإِنَّ رَبَّكَ لَذو فَضلٍ عَلَى النّاسِ وَلٰكِنَّ أَكثَرَهُم لا يَشكُرونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmccxxxiii{وَإِنَّ رَبَّكَ لَيَعلَمُ ما تُكِنُّ صُدورُهُم وَما يُعلِنونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmccxxxiv{وَما مِن غائِبَةٍ فِى السَّماءِ وَالأَرضِ إِلّا فى كِتٰبٍ مُبينٍ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmccxxxv{إِنَّ هٰذَا القُرءانَ يَقُصُّ عَلىٰ بَنى إِسرٰءيلَ أَكثَرَ الَّذى هُم فيهِ يَختَلِفونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmccxxxvi{وَإِنَّهُ لَهُدًى وَرَحمَةٌ لِلمُؤمِنينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmccxxxvii{إِنَّ رَبَّكَ يَقضى بَينَهُم بِحُكمِهِ وَهُوَ العَزيزُ العَليمُ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmccxxxviii{فَتَوَكَّل عَلَى اللَّهِ إِنَّكَ عَلَى الحَقِّ المُبينِ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmccxxxix{إِنَّكَ لا تُسمِعُ المَوتىٰ وَلا تُسمِعُ الصُّمَّ الدُّعاءَ إِذا وَلَّوا مُدبِرينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmccxl{وَما أَنتَ بِهٰدِى العُمىِ عَن ضَلٰلَتِهِم إِن تُسمِعُ إِلّا مَن يُؤمِنُ بِـٔايٰتِنا فَهُم مُسلِمونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmccxli{وَإِذا وَقَعَ القَولُ عَلَيهِم أَخرَجنا لَهُم دابَّةً مِنَ الأَرضِ تُكَلِّمُهُم أَنَّ النّاسَ كانوا بِـٔايٰتِنا لا يوقِنونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmccxlii{وَيَومَ نَحشُرُ مِن كُلِّ أُمَّةٍ فَوجًا مِمَّن يُكَذِّبُ بِـٔايٰتِنا فَهُم يوزَعونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmccxliii{حَتّىٰ إِذا جاءو قالَ أَكَذَّبتُم بِـٔايٰتى وَلَم تُحيطوا بِها عِلمًا أَمّاذا كُنتُم تَعمَلونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmccxliv{وَوَقَعَ القَولُ عَلَيهِم بِما ظَلَموا فَهُم لا يَنطِقونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmccxlv{أَلَم يَرَوا أَنّا جَعَلنَا الَّيلَ لِيَسكُنوا فيهِ وَالنَّهارَ مُبصِرًا إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmccxlvi{وَيَومَ يُنفَخُ فِى الصّورِ فَفَزِعَ مَن فِى السَّمٰوٰتِ وَمَن فِى الأَرضِ إِلّا مَن شاءَ اللَّهُ وَكُلٌّ أَتَوهُ دٰخِرينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmccxlvii{وَتَرَى الجِبالَ تَحسَبُها جامِدَةً وَهِىَ تَمُرُّ مَرَّ السَّحابِ صُنعَ اللَّهِ الَّذى أَتقَنَ كُلَّ شَيءٍ إِنَّهُ خَبيرٌ بِما تَفعَلونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmccxlviii{مَن جاءَ بِالحَسَنَةِ فَلَهُ خَيرٌ مِنها وَهُم مِن فَزَعٍ يَومَئِذٍ ءامِنونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmccxlix{وَمَن جاءَ بِالسَّيِّئَةِ فَكُبَّت وُجوهُهُم فِى النّارِ هَل تُجزَونَ إِلّا ما كُنتُم تَعمَلونَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmccl{إِنَّما أُمِرتُ أَن أَعبُدَ رَبَّ هٰذِهِ البَلدَةِ الَّذى حَرَّمَها وَلَهُ كُلُّ شَيءٍ وَأُمِرتُ أَن أَكونَ مِنَ المُسلِمينَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmccli{وَأَن أَتلُوَا۟ القُرءانَ فَمَنِ اهتَدىٰ فَإِنَّما يَهتَدى لِنَفسِهِ وَمَن ضَلَّ فَقُل إِنَّما أَنا۠ مِنَ المُنذِرينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmcclii{وَقُلِ الحَمدُ لِلَّهِ سَيُريكُم ءايٰتِهِ فَتَعرِفونَها وَما رَبُّكَ بِغٰفِلٍ عَمّا تَعمَلونَ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmccliii{\basmalah  طسم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmccliv{تِلكَ ءايٰتُ الكِتٰبِ المُبينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcclv{نَتلوا عَلَيكَ مِن نَبَإِ موسىٰ وَفِرعَونَ بِالحَقِّ لِقَومٍ يُؤمِنونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcclvi{إِنَّ فِرعَونَ عَلا فِى الأَرضِ وَجَعَلَ أَهلَها شِيَعًا يَستَضعِفُ طائِفَةً مِنهُم يُذَبِّحُ أَبناءَهُم وَيَستَحيۦ نِساءَهُم إِنَّهُ كانَ مِنَ المُفسِدينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcclvii{وَنُريدُ أَن نَمُنَّ عَلَى الَّذينَ استُضعِفوا فِى الأَرضِ وَنَجعَلَهُم أَئِمَّةً وَنَجعَلَهُمُ الوٰرِثينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcclviii{وَنُمَكِّنَ لَهُم فِى الأَرضِ وَنُرِىَ فِرعَونَ وَهٰمٰنَ وَجُنودَهُما مِنهُم ما كانوا يَحذَرونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcclix{وَأَوحَينا إِلىٰ أُمِّ موسىٰ أَن أَرضِعيهِ فَإِذا خِفتِ عَلَيهِ فَأَلقيهِ فِى اليَمِّ وَلا تَخافى وَلا تَحزَنى إِنّا رادّوهُ إِلَيكِ وَجاعِلوهُ مِنَ المُرسَلينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcclx{فَالتَقَطَهُ ءالُ فِرعَونَ لِيَكونَ لَهُم عَدُوًّا وَحَزَنًا إِنَّ فِرعَونَ وَهٰمٰنَ وَجُنودَهُما كانوا خٰطِـٔينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcclxi{وَقالَتِ امرَأَتُ فِرعَونَ قُرَّتُ عَينٍ لى وَلَكَ لا تَقتُلوهُ عَسىٰ أَن يَنفَعَنا أَو نَتَّخِذَهُ وَلَدًا وَهُم لا يَشعُرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcclxii{وَأَصبَحَ فُؤادُ أُمِّ موسىٰ فٰرِغًا إِن كادَت لَتُبدى بِهِ لَولا أَن رَبَطنا عَلىٰ قَلبِها لِتَكونَ مِنَ المُؤمِنينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcclxiii{وَقالَت لِأُختِهِ قُصّيهِ فَبَصُرَت بِهِ عَن جُنُبٍ وَهُم لا يَشعُرونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcclxiv{وَحَرَّمنا عَلَيهِ المَراضِعَ مِن قَبلُ فَقالَت هَل أَدُلُّكُم عَلىٰ أَهلِ بَيتٍ يَكفُلونَهُ لَكُم وَهُم لَهُ نٰصِحونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcclxv{فَرَدَدنٰهُ إِلىٰ أُمِّهِ كَى تَقَرَّ عَينُها وَلا تَحزَنَ وَلِتَعلَمَ أَنَّ وَعدَ اللَّهِ حَقٌّ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcclxvi{وَلَمّا بَلَغَ أَشُدَّهُ وَاستَوىٰ ءاتَينٰهُ حُكمًا وَعِلمًا وَكَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcclxvii{وَدَخَلَ المَدينَةَ عَلىٰ حينِ غَفلَةٍ مِن أَهلِها فَوَجَدَ فيها رَجُلَينِ يَقتَتِلانِ هٰذا مِن شيعَتِهِ وَهٰذا مِن عَدُوِّهِ فَاستَغٰثَهُ الَّذى مِن شيعَتِهِ عَلَى الَّذى مِن عَدُوِّهِ فَوَكَزَهُ موسىٰ فَقَضىٰ عَلَيهِ قالَ هٰذا مِن عَمَلِ الشَّيطٰنِ إِنَّهُ عَدُوٌّ مُضِلٌّ مُبينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcclxviii{قالَ رَبِّ إِنّى ظَلَمتُ نَفسى فَاغفِر لى فَغَفَرَ لَهُ إِنَّهُ هُوَ الغَفورُ الرَّحيمُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcclxix{قالَ رَبِّ بِما أَنعَمتَ عَلَىَّ فَلَن أَكونَ ظَهيرًا لِلمُجرِمينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcclxx{فَأَصبَحَ فِى المَدينَةِ خائِفًا يَتَرَقَّبُ فَإِذَا الَّذِى استَنصَرَهُ بِالأَمسِ يَستَصرِخُهُ قالَ لَهُ موسىٰ إِنَّكَ لَغَوِىٌّ مُبينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcclxxi{فَلَمّا أَن أَرادَ أَن يَبطِشَ بِالَّذى هُوَ عَدُوٌّ لَهُما قالَ يٰموسىٰ أَتُريدُ أَن تَقتُلَنى كَما قَتَلتَ نَفسًا بِالأَمسِ إِن تُريدُ إِلّا أَن تَكونَ جَبّارًا فِى الأَرضِ وَما تُريدُ أَن تَكونَ مِنَ المُصلِحينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcclxxii{وَجاءَ رَجُلٌ مِن أَقصَا المَدينَةِ يَسعىٰ قالَ يٰموسىٰ إِنَّ المَلَأَ يَأتَمِرونَ بِكَ لِيَقتُلوكَ فَاخرُج إِنّى لَكَ مِنَ النّٰصِحينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcclxxiii{فَخَرَجَ مِنها خائِفًا يَتَرَقَّبُ قالَ رَبِّ نَجِّنى مِنَ القَومِ الظّٰلِمينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcclxxiv{وَلَمّا تَوَجَّهَ تِلقاءَ مَديَنَ قالَ عَسىٰ رَبّى أَن يَهدِيَنى سَواءَ السَّبيلِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcclxxv{وَلَمّا وَرَدَ ماءَ مَديَنَ وَجَدَ عَلَيهِ أُمَّةً مِنَ النّاسِ يَسقونَ وَوَجَدَ مِن دونِهِمُ امرَأَتَينِ تَذودانِ قالَ ما خَطبُكُما قالَتا لا نَسقى حَتّىٰ يُصدِرَ الرِّعاءُ وَأَبونا شَيخٌ كَبيرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcclxxvi{فَسَقىٰ لَهُما ثُمَّ تَوَلّىٰ إِلَى الظِّلِّ فَقالَ رَبِّ إِنّى لِما أَنزَلتَ إِلَىَّ مِن خَيرٍ فَقيرٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcclxxvii{فَجاءَتهُ إِحدىٰهُما تَمشى عَلَى استِحياءٍ قالَت إِنَّ أَبى يَدعوكَ لِيَجزِيَكَ أَجرَ ما سَقَيتَ لَنا فَلَمّا جاءَهُ وَقَصَّ عَلَيهِ القَصَصَ قالَ لا تَخَف نَجَوتَ مِنَ القَومِ الظّٰلِمينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcclxxviii{قالَت إِحدىٰهُما يٰأَبَتِ استَـٔجِرهُ إِنَّ خَيرَ مَنِ استَـٔجَرتَ القَوِىُّ الأَمينُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcclxxix{قالَ إِنّى أُريدُ أَن أُنكِحَكَ إِحدَى ابنَتَىَّ هٰتَينِ عَلىٰ أَن تَأجُرَنى ثَمٰنِىَ حِجَجٍ فَإِن أَتمَمتَ عَشرًا فَمِن عِندِكَ وَما أُريدُ أَن أَشُقَّ عَلَيكَ سَتَجِدُنى إِن شاءَ اللَّهُ مِنَ الصّٰلِحينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcclxxx{قالَ ذٰلِكَ بَينى وَبَينَكَ أَيَّمَا الأَجَلَينِ قَضَيتُ فَلا عُدوٰنَ عَلَىَّ وَاللَّهُ عَلىٰ ما نَقولُ وَكيلٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcclxxxi{فَلَمّا قَضىٰ موسَى الأَجَلَ وَسارَ بِأَهلِهِ ءانَسَ مِن جانِبِ الطّورِ نارًا قالَ لِأَهلِهِ امكُثوا إِنّى ءانَستُ نارًا لَعَلّى ءاتيكُم مِنها بِخَبَرٍ أَو جَذوَةٍ مِنَ النّارِ لَعَلَّكُم تَصطَلونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcclxxxii{فَلَمّا أَتىٰها نودِىَ مِن شٰطِئِ الوادِ الأَيمَنِ فِى البُقعَةِ المُبٰرَكَةِ مِنَ الشَّجَرَةِ أَن يٰموسىٰ إِنّى أَنَا اللَّهُ رَبُّ العٰلَمينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcclxxxiii{وَأَن أَلقِ عَصاكَ فَلَمّا رَءاها تَهتَزُّ كَأَنَّها جانٌّ وَلّىٰ مُدبِرًا وَلَم يُعَقِّب يٰموسىٰ أَقبِل وَلا تَخَف إِنَّكَ مِنَ الءامِنينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcclxxxiv{اسلُك يَدَكَ فى جَيبِكَ تَخرُج بَيضاءَ مِن غَيرِ سوءٍ وَاضمُم إِلَيكَ جَناحَكَ مِنَ الرَّهبِ فَذٰنِكَ بُرهٰنانِ مِن رَبِّكَ إِلىٰ فِرعَونَ وَمَلَإِي۟هِ إِنَّهُم كانوا قَومًا فٰسِقينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcclxxxv{قالَ رَبِّ إِنّى قَتَلتُ مِنهُم نَفسًا فَأَخافُ أَن يَقتُلونِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcclxxxvi{وَأَخى هٰرونُ هُوَ أَفصَحُ مِنّى لِسانًا فَأَرسِلهُ مَعِىَ رِدءًا يُصَدِّقُنى إِنّى أَخافُ أَن يُكَذِّبونِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcclxxxvii{قالَ سَنَشُدُّ عَضُدَكَ بِأَخيكَ وَنَجعَلُ لَكُما سُلطٰنًا فَلا يَصِلونَ إِلَيكُما بِـٔايٰتِنا أَنتُما وَمَنِ اتَّبَعَكُمَا الغٰلِبونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcclxxxviii{فَلَمّا جاءَهُم موسىٰ بِـٔايٰتِنا بَيِّنٰتٍ قالوا ما هٰذا إِلّا سِحرٌ مُفتَرًى وَما سَمِعنا بِهٰذا فى ءابائِنَا الأَوَّلينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcclxxxix{وَقالَ موسىٰ رَبّى أَعلَمُ بِمَن جاءَ بِالهُدىٰ مِن عِندِهِ وَمَن تَكونُ لَهُ عٰقِبَةُ الدّارِ إِنَّهُ لا يُفلِحُ الظّٰلِمونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmccxc{وَقالَ فِرعَونُ يٰأَيُّهَا المَلَأُ ما عَلِمتُ لَكُم مِن إِلٰهٍ غَيرى فَأَوقِد لى يٰهٰمٰنُ عَلَى الطّينِ فَاجعَل لى صَرحًا لَعَلّى أَطَّلِعُ إِلىٰ إِلٰهِ موسىٰ وَإِنّى لَأَظُنُّهُ مِنَ الكٰذِبينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmccxci{وَاستَكبَرَ هُوَ وَجُنودُهُ فِى الأَرضِ بِغَيرِ الحَقِّ وَظَنّوا أَنَّهُم إِلَينا لا يُرجَعونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmccxcii{فَأَخَذنٰهُ وَجُنودَهُ فَنَبَذنٰهُم فِى اليَمِّ فَانظُر كَيفَ كانَ عٰقِبَةُ الظّٰلِمينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmccxciii{وَجَعَلنٰهُم أَئِمَّةً يَدعونَ إِلَى النّارِ وَيَومَ القِيٰمَةِ لا يُنصَرونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmccxciv{وَأَتبَعنٰهُم فى هٰذِهِ الدُّنيا لَعنَةً وَيَومَ القِيٰمَةِ هُم مِنَ المَقبوحينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccxcv{وَلَقَد ءاتَينا موسَى الكِتٰبَ مِن بَعدِ ما أَهلَكنَا القُرونَ الأولىٰ بَصائِرَ لِلنّاسِ وَهُدًى وَرَحمَةً لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmccxcvi{وَما كُنتَ بِجانِبِ الغَربِىِّ إِذ قَضَينا إِلىٰ موسَى الأَمرَ وَما كُنتَ مِنَ الشّٰهِدينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmccxcvii{وَلٰكِنّا أَنشَأنا قُرونًا فَتَطاوَلَ عَلَيهِمُ العُمُرُ وَما كُنتَ ثاوِيًا فى أَهلِ مَديَنَ تَتلوا عَلَيهِم ءايٰتِنا وَلٰكِنّا كُنّا مُرسِلينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccxcviii{وَما كُنتَ بِجانِبِ الطّورِ إِذ نادَينا وَلٰكِن رَحمَةً مِن رَبِّكَ لِتُنذِرَ قَومًا ما أَتىٰهُم مِن نَذيرٍ مِن قَبلِكَ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccxcix{وَلَولا أَن تُصيبَهُم مُصيبَةٌ بِما قَدَّمَت أَيديهِم فَيَقولوا رَبَّنا لَولا أَرسَلتَ إِلَينا رَسولًا فَنَتَّبِعَ ءايٰتِكَ وَنَكونَ مِنَ المُؤمِنينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccc{فَلَمّا جاءَهُمُ الحَقُّ مِن عِندِنا قالوا لَولا أوتِىَ مِثلَ ما أوتِىَ موسىٰ أَوَلَم يَكفُروا بِما أوتِىَ موسىٰ مِن قَبلُ قالوا سِحرانِ تَظٰهَرا وَقالوا إِنّا بِكُلٍّ كٰفِرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccci{قُل فَأتوا بِكِتٰبٍ مِن عِندِ اللَّهِ هُوَ أَهدىٰ مِنهُما أَتَّبِعهُ إِن كُنتُم صٰدِقينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcccii{فَإِن لَم يَستَجيبوا لَكَ فَاعلَم أَنَّما يَتَّبِعونَ أَهواءَهُم وَمَن أَضَلُّ مِمَّنِ اتَّبَعَ هَوىٰهُ بِغَيرِ هُدًى مِنَ اللَّهِ إِنَّ اللَّهَ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmccciii{وَلَقَد وَصَّلنا لَهُمُ القَولَ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmccciv{الَّذينَ ءاتَينٰهُمُ الكِتٰبَ مِن قَبلِهِ هُم بِهِ يُؤمِنونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcccv{وَإِذا يُتلىٰ عَلَيهِم قالوا ءامَنّا بِهِ إِنَّهُ الحَقُّ مِن رَبِّنا إِنّا كُنّا مِن قَبلِهِ مُسلِمينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcccvi{أُولٰئِكَ يُؤتَونَ أَجرَهُم مَرَّتَينِ بِما صَبَروا وَيَدرَءونَ بِالحَسَنَةِ السَّيِّئَةَ وَمِمّا رَزَقنٰهُم يُنفِقونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcccvii{وَإِذا سَمِعُوا اللَّغوَ أَعرَضوا عَنهُ وَقالوا لَنا أَعمٰلُنا وَلَكُم أَعمٰلُكُم سَلٰمٌ عَلَيكُم لا نَبتَغِى الجٰهِلينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcccviii{إِنَّكَ لا تَهدى مَن أَحبَبتَ وَلٰكِنَّ اللَّهَ يَهدى مَن يَشاءُ وَهُوَ أَعلَمُ بِالمُهتَدينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcccix{وَقالوا إِن نَتَّبِعِ الهُدىٰ مَعَكَ نُتَخَطَّف مِن أَرضِنا أَوَلَم نُمَكِّن لَهُم حَرَمًا ءامِنًا يُجبىٰ إِلَيهِ ثَمَرٰتُ كُلِّ شَيءٍ رِزقًا مِن لَدُنّا وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcccx{وَكَم أَهلَكنا مِن قَريَةٍ بَطِرَت مَعيشَتَها فَتِلكَ مَسٰكِنُهُم لَم تُسكَن مِن بَعدِهِم إِلّا قَليلًا وَكُنّا نَحنُ الوٰرِثينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcccxi{وَما كانَ رَبُّكَ مُهلِكَ القُرىٰ حَتّىٰ يَبعَثَ فى أُمِّها رَسولًا يَتلوا عَلَيهِم ءايٰتِنا وَما كُنّا مُهلِكِى القُرىٰ إِلّا وَأَهلُها ظٰلِمونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcccxii{وَما أوتيتُم مِن شَيءٍ فَمَتٰعُ الحَيوٰةِ الدُّنيا وَزينَتُها وَما عِندَ اللَّهِ خَيرٌ وَأَبقىٰ أَفَلا تَعقِلونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcccxiii{أَفَمَن وَعَدنٰهُ وَعدًا حَسَنًا فَهُوَ لٰقيهِ كَمَن مَتَّعنٰهُ مَتٰعَ الحَيوٰةِ الدُّنيا ثُمَّ هُوَ يَومَ القِيٰمَةِ مِنَ المُحضَرينَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmcccxiv{وَيَومَ يُناديهِم فَيَقولُ أَينَ شُرَكاءِىَ الَّذينَ كُنتُم تَزعُمونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmcccxv{قالَ الَّذينَ حَقَّ عَلَيهِمُ القَولُ رَبَّنا هٰؤُلاءِ الَّذينَ أَغوَينا أَغوَينٰهُم كَما غَوَينا تَبَرَّأنا إِلَيكَ ما كانوا إِيّانا يَعبُدونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmcccxvi{وَقيلَ ادعوا شُرَكاءَكُم فَدَعَوهُم فَلَم يَستَجيبوا لَهُم وَرَأَوُا العَذابَ لَو أَنَّهُم كانوا يَهتَدونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmcccxvii{وَيَومَ يُناديهِم فَيَقولُ ماذا أَجَبتُمُ المُرسَلينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmcccxviii{فَعَمِيَت عَلَيهِمُ الأَنباءُ يَومَئِذٍ فَهُم لا يَتَساءَلونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmcccxix{فَأَمّا مَن تابَ وَءامَنَ وَعَمِلَ صٰلِحًا فَعَسىٰ أَن يَكونَ مِنَ المُفلِحينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmcccxx{وَرَبُّكَ يَخلُقُ ما يَشاءُ وَيَختارُ ما كانَ لَهُمُ الخِيَرَةُ سُبحٰنَ اللَّهِ وَتَعٰلىٰ عَمّا يُشرِكونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmcccxxi{وَرَبُّكَ يَعلَمُ ما تُكِنُّ صُدورُهُم وَما يُعلِنونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmcccxxii{وَهُوَ اللَّهُ لا إِلٰهَ إِلّا هُوَ لَهُ الحَمدُ فِى الأولىٰ وَالءاخِرَةِ وَلَهُ الحُكمُ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmcccxxiii{قُل أَرَءَيتُم إِن جَعَلَ اللَّهُ عَلَيكُمُ الَّيلَ سَرمَدًا إِلىٰ يَومِ القِيٰمَةِ مَن إِلٰهٌ غَيرُ اللَّهِ يَأتيكُم بِضِياءٍ أَفَلا تَسمَعونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmcccxxiv{قُل أَرَءَيتُم إِن جَعَلَ اللَّهُ عَلَيكُمُ النَّهارَ سَرمَدًا إِلىٰ يَومِ القِيٰمَةِ مَن إِلٰهٌ غَيرُ اللَّهِ يَأتيكُم بِلَيلٍ تَسكُنونَ فيهِ أَفَلا تُبصِرونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmcccxxv{وَمِن رَحمَتِهِ جَعَلَ لَكُمُ الَّيلَ وَالنَّهارَ لِتَسكُنوا فيهِ وَلِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmcccxxvi{وَيَومَ يُناديهِم فَيَقولُ أَينَ شُرَكاءِىَ الَّذينَ كُنتُم تَزعُمونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmcccxxvii{وَنَزَعنا مِن كُلِّ أُمَّةٍ شَهيدًا فَقُلنا هاتوا بُرهٰنَكُم فَعَلِموا أَنَّ الحَقَّ لِلَّهِ وَضَلَّ عَنهُم ما كانوا يَفتَرونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmcccxxviii{إِنَّ قٰرونَ كانَ مِن قَومِ موسىٰ فَبَغىٰ عَلَيهِم وَءاتَينٰهُ مِنَ الكُنوزِ ما إِنَّ مَفاتِحَهُ لَتَنوأُ بِالعُصبَةِ أُولِى القُوَّةِ إِذ قالَ لَهُ قَومُهُ لا تَفرَح إِنَّ اللَّهَ لا يُحِبُّ الفَرِحينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmcccxxix{وَابتَغِ فيما ءاتىٰكَ اللَّهُ الدّارَ الءاخِرَةَ وَلا تَنسَ نَصيبَكَ مِنَ الدُّنيا وَأَحسِن كَما أَحسَنَ اللَّهُ إِلَيكَ وَلا تَبغِ الفَسادَ فِى الأَرضِ إِنَّ اللَّهَ لا يُحِبُّ المُفسِدينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmcccxxx{قالَ إِنَّما أوتيتُهُ عَلىٰ عِلمٍ عِندى أَوَلَم يَعلَم أَنَّ اللَّهَ قَد أَهلَكَ مِن قَبلِهِ مِنَ القُرونِ مَن هُوَ أَشَدُّ مِنهُ قُوَّةً وَأَكثَرُ جَمعًا وَلا يُسـَٔلُ عَن ذُنوبِهِمُ المُجرِمونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmcccxxxi{فَخَرَجَ عَلىٰ قَومِهِ فى زينَتِهِ قالَ الَّذينَ يُريدونَ الحَيوٰةَ الدُّنيا يٰلَيتَ لَنا مِثلَ ما أوتِىَ قٰرونُ إِنَّهُ لَذو حَظٍّ عَظيمٍ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmcccxxxii{وَقالَ الَّذينَ أوتُوا العِلمَ وَيلَكُم ثَوابُ اللَّهِ خَيرٌ لِمَن ءامَنَ وَعَمِلَ صٰلِحًا وَلا يُلَقّىٰها إِلَّا الصّٰبِرونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmcccxxxiii{فَخَسَفنا بِهِ وَبِدارِهِ الأَرضَ فَما كانَ لَهُ مِن فِئَةٍ يَنصُرونَهُ مِن دونِ اللَّهِ وَما كانَ مِنَ المُنتَصِرينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmcccxxxiv{وَأَصبَحَ الَّذينَ تَمَنَّوا مَكانَهُ بِالأَمسِ يَقولونَ وَيكَأَنَّ اللَّهَ يَبسُطُ الرِّزقَ لِمَن يَشاءُ مِن عِبادِهِ وَيَقدِرُ لَولا أَن مَنَّ اللَّهُ عَلَينا لَخَسَفَ بِنا وَيكَأَنَّهُ لا يُفلِحُ الكٰفِرونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmcccxxxv{تِلكَ الدّارُ الءاخِرَةُ نَجعَلُها لِلَّذينَ لا يُريدونَ عُلُوًّا فِى الأَرضِ وَلا فَسادًا وَالعٰقِبَةُ لِلمُتَّقينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmcccxxxvi{مَن جاءَ بِالحَسَنَةِ فَلَهُ خَيرٌ مِنها وَمَن جاءَ بِالسَّيِّئَةِ فَلا يُجزَى الَّذينَ عَمِلُوا السَّيِّـٔاتِ إِلّا ما كانوا يَعمَلونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmcccxxxvii{إِنَّ الَّذى فَرَضَ عَلَيكَ القُرءانَ لَرادُّكَ إِلىٰ مَعادٍ قُل رَبّى أَعلَمُ مَن جاءَ بِالهُدىٰ وَمَن هُوَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmcccxxxviii{وَما كُنتَ تَرجوا أَن يُلقىٰ إِلَيكَ الكِتٰبُ إِلّا رَحمَةً مِن رَبِّكَ فَلا تَكونَنَّ ظَهيرًا لِلكٰفِرينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmcccxxxix{وَلا يَصُدُّنَّكَ عَن ءايٰتِ اللَّهِ بَعدَ إِذ أُنزِلَت إِلَيكَ وَادعُ إِلىٰ رَبِّكَ وَلا تَكونَنَّ مِنَ المُشرِكينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmcccxl{وَلا تَدعُ مَعَ اللَّهِ إِلٰهًا ءاخَرَ لا إِلٰهَ إِلّا هُوَ كُلُّ شَيءٍ هالِكٌ إِلّا وَجهَهُ لَهُ الحُكمُ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmcccxli{\basmalah  الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcccxlii{أَحَسِبَ النّاسُ أَن يُترَكوا أَن يَقولوا ءامَنّا وَهُم لا يُفتَنونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcccxliii{وَلَقَد فَتَنَّا الَّذينَ مِن قَبلِهِم فَلَيَعلَمَنَّ اللَّهُ الَّذينَ صَدَقوا وَلَيَعلَمَنَّ الكٰذِبينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcccxliv{أَم حَسِبَ الَّذينَ يَعمَلونَ السَّيِّـٔاتِ أَن يَسبِقونا ساءَ ما يَحكُمونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcccxlv{مَن كانَ يَرجوا لِقاءَ اللَّهِ فَإِنَّ أَجَلَ اللَّهِ لَءاتٍ وَهُوَ السَّميعُ العَليمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcccxlvi{وَمَن جٰهَدَ فَإِنَّما يُجٰهِدُ لِنَفسِهِ إِنَّ اللَّهَ لَغَنِىٌّ عَنِ العٰلَمينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcccxlvii{وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَنُكَفِّرَنَّ عَنهُم سَيِّـٔاتِهِم وَلَنَجزِيَنَّهُم أَحسَنَ الَّذى كانوا يَعمَلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcccxlviii{وَوَصَّينَا الإِنسٰنَ بِوٰلِدَيهِ حُسنًا وَإِن جٰهَداكَ لِتُشرِكَ بى ما لَيسَ لَكَ بِهِ عِلمٌ فَلا تُطِعهُما إِلَىَّ مَرجِعُكُم فَأُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcccxlix{وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَنُدخِلَنَّهُم فِى الصّٰلِحينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcccl{وَمِنَ النّاسِ مَن يَقولُ ءامَنّا بِاللَّهِ فَإِذا أوذِىَ فِى اللَّهِ جَعَلَ فِتنَةَ النّاسِ كَعَذابِ اللَّهِ وَلَئِن جاءَ نَصرٌ مِن رَبِّكَ لَيَقولُنَّ إِنّا كُنّا مَعَكُم أَوَلَيسَ اللَّهُ بِأَعلَمَ بِما فى صُدورِ العٰلَمينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcccli{وَلَيَعلَمَنَّ اللَّهُ الَّذينَ ءامَنوا وَلَيَعلَمَنَّ المُنٰفِقينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmccclii{وَقالَ الَّذينَ كَفَروا لِلَّذينَ ءامَنُوا اتَّبِعوا سَبيلَنا وَلنَحمِل خَطٰيٰكُم وَما هُم بِحٰمِلينَ مِن خَطٰيٰهُم مِن شَيءٍ إِنَّهُم لَكٰذِبونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcccliii{وَلَيَحمِلُنَّ أَثقالَهُم وَأَثقالًا مَعَ أَثقالِهِم وَلَيُسـَٔلُنَّ يَومَ القِيٰمَةِ عَمّا كانوا يَفتَرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcccliv{وَلَقَد أَرسَلنا نوحًا إِلىٰ قَومِهِ فَلَبِثَ فيهِم أَلفَ سَنَةٍ إِلّا خَمسينَ عامًا فَأَخَذَهُمُ الطّوفانُ وَهُم ظٰلِمونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmccclv{فَأَنجَينٰهُ وَأَصحٰبَ السَّفينَةِ وَجَعَلنٰها ءايَةً لِلعٰلَمينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmccclvi{وَإِبرٰهيمَ إِذ قالَ لِقَومِهِ اعبُدُوا اللَّهَ وَاتَّقوهُ ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmccclvii{إِنَّما تَعبُدونَ مِن دونِ اللَّهِ أَوثٰنًا وَتَخلُقونَ إِفكًا إِنَّ الَّذينَ تَعبُدونَ مِن دونِ اللَّهِ لا يَملِكونَ لَكُم رِزقًا فَابتَغوا عِندَ اللَّهِ الرِّزقَ وَاعبُدوهُ وَاشكُروا لَهُ إِلَيهِ تُرجَعونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmccclviii{وَإِن تُكَذِّبوا فَقَد كَذَّبَ أُمَمٌ مِن قَبلِكُم وَما عَلَى الرَّسولِ إِلَّا البَلٰغُ المُبينُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmccclix{أَوَلَم يَرَوا كَيفَ يُبدِئُ اللَّهُ الخَلقَ ثُمَّ يُعيدُهُ إِنَّ ذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmccclx{قُل سيروا فِى الأَرضِ فَانظُروا كَيفَ بَدَأَ الخَلقَ ثُمَّ اللَّهُ يُنشِئُ النَّشأَةَ الءاخِرَةَ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmccclxi{يُعَذِّبُ مَن يَشاءُ وَيَرحَمُ مَن يَشاءُ وَإِلَيهِ تُقلَبونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmccclxii{وَما أَنتُم بِمُعجِزينَ فِى الأَرضِ وَلا فِى السَّماءِ وَما لَكُم مِن دونِ اللَّهِ مِن وَلِىٍّ وَلا نَصيرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmccclxiii{وَالَّذينَ كَفَروا بِـٔايٰتِ اللَّهِ وَلِقائِهِ أُولٰئِكَ يَئِسوا مِن رَحمَتى وَأُولٰئِكَ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmccclxiv{فَما كانَ جَوابَ قَومِهِ إِلّا أَن قالُوا اقتُلوهُ أَو حَرِّقوهُ فَأَنجىٰهُ اللَّهُ مِنَ النّارِ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmccclxv{وَقالَ إِنَّمَا اتَّخَذتُم مِن دونِ اللَّهِ أَوثٰنًا مَوَدَّةَ بَينِكُم فِى الحَيوٰةِ الدُّنيا ثُمَّ يَومَ القِيٰمَةِ يَكفُرُ بَعضُكُم بِبَعضٍ وَيَلعَنُ بَعضُكُم بَعضًا وَمَأوىٰكُمُ النّارُ وَما لَكُم مِن نٰصِرينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmccclxvi{فَـٔامَنَ لَهُ لوطٌ وَقالَ إِنّى مُهاجِرٌ إِلىٰ رَبّى إِنَّهُ هُوَ العَزيزُ الحَكيمُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmccclxvii{وَوَهَبنا لَهُ إِسحٰقَ وَيَعقوبَ وَجَعَلنا فى ذُرِّيَّتِهِ النُّبُوَّةَ وَالكِتٰبَ وَءاتَينٰهُ أَجرَهُ فِى الدُّنيا وَإِنَّهُ فِى الءاخِرَةِ لَمِنَ الصّٰلِحينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmccclxviii{وَلوطًا إِذ قالَ لِقَومِهِ إِنَّكُم لَتَأتونَ الفٰحِشَةَ ما سَبَقَكُم بِها مِن أَحَدٍ مِنَ العٰلَمينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmccclxix{أَئِنَّكُم لَتَأتونَ الرِّجالَ وَتَقطَعونَ السَّبيلَ وَتَأتونَ فى ناديكُمُ المُنكَرَ فَما كانَ جَوابَ قَومِهِ إِلّا أَن قالُوا ائتِنا بِعَذابِ اللَّهِ إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmccclxx{قالَ رَبِّ انصُرنى عَلَى القَومِ المُفسِدينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmccclxxi{وَلَمّا جاءَت رُسُلُنا إِبرٰهيمَ بِالبُشرىٰ قالوا إِنّا مُهلِكوا أَهلِ هٰذِهِ القَريَةِ إِنَّ أَهلَها كانوا ظٰلِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmccclxxii{قالَ إِنَّ فيها لوطًا قالوا نَحنُ أَعلَمُ بِمَن فيها لَنُنَجِّيَنَّهُ وَأَهلَهُ إِلَّا امرَأَتَهُ كانَت مِنَ الغٰبِرينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmccclxxiii{وَلَمّا أَن جاءَت رُسُلُنا لوطًا سيءَ بِهِم وَضاقَ بِهِم ذَرعًا وَقالوا لا تَخَف وَلا تَحزَن إِنّا مُنَجّوكَ وَأَهلَكَ إِلَّا امرَأَتَكَ كانَت مِنَ الغٰبِرينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmccclxxiv{إِنّا مُنزِلونَ عَلىٰ أَهلِ هٰذِهِ القَريَةِ رِجزًا مِنَ السَّماءِ بِما كانوا يَفسُقونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmccclxxv{وَلَقَد تَرَكنا مِنها ءايَةً بَيِّنَةً لِقَومٍ يَعقِلونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmccclxxvi{وَإِلىٰ مَديَنَ أَخاهُم شُعَيبًا فَقالَ يٰقَومِ اعبُدُوا اللَّهَ وَارجُوا اليَومَ الءاخِرَ وَلا تَعثَوا فِى الأَرضِ مُفسِدينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmccclxxvii{فَكَذَّبوهُ فَأَخَذَتهُمُ الرَّجفَةُ فَأَصبَحوا فى دارِهِم جٰثِمينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmccclxxviii{وَعادًا وَثَمودَا۟ وَقَد تَبَيَّنَ لَكُم مِن مَسٰكِنِهِم وَزَيَّنَ لَهُمُ الشَّيطٰنُ أَعمٰلَهُم فَصَدَّهُم عَنِ السَّبيلِ وَكانوا مُستَبصِرينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmccclxxix{وَقٰرونَ وَفِرعَونَ وَهٰمٰنَ وَلَقَد جاءَهُم موسىٰ بِالبَيِّنٰتِ فَاستَكبَروا فِى الأَرضِ وَما كانوا سٰبِقينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmccclxxx{فَكُلًّا أَخَذنا بِذَنبِهِ فَمِنهُم مَن أَرسَلنا عَلَيهِ حاصِبًا وَمِنهُم مَن أَخَذَتهُ الصَّيحَةُ وَمِنهُم مَن خَسَفنا بِهِ الأَرضَ وَمِنهُم مَن أَغرَقنا وَما كانَ اللَّهُ لِيَظلِمَهُم وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmccclxxxi{مَثَلُ الَّذينَ اتَّخَذوا مِن دونِ اللَّهِ أَولِياءَ كَمَثَلِ العَنكَبوتِ اتَّخَذَت بَيتًا وَإِنَّ أَوهَنَ البُيوتِ لَبَيتُ العَنكَبوتِ لَو كانوا يَعلَمونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmccclxxxii{إِنَّ اللَّهَ يَعلَمُ ما يَدعونَ مِن دونِهِ مِن شَيءٍ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmccclxxxiii{وَتِلكَ الأَمثٰلُ نَضرِبُها لِلنّاسِ وَما يَعقِلُها إِلَّا العٰلِمونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmccclxxxiv{خَلَقَ اللَّهُ السَّمٰوٰتِ وَالأَرضَ بِالحَقِّ إِنَّ فى ذٰلِكَ لَءايَةً لِلمُؤمِنينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmccclxxxv{اتلُ ما أوحِىَ إِلَيكَ مِنَ الكِتٰبِ وَأَقِمِ الصَّلوٰةَ إِنَّ الصَّلوٰةَ تَنهىٰ عَنِ الفَحشاءِ وَالمُنكَرِ وَلَذِكرُ اللَّهِ أَكبَرُ وَاللَّهُ يَعلَمُ ما تَصنَعونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmccclxxxvi{وَلا تُجٰدِلوا أَهلَ الكِتٰبِ إِلّا بِالَّتى هِىَ أَحسَنُ إِلَّا الَّذينَ ظَلَموا مِنهُم وَقولوا ءامَنّا بِالَّذى أُنزِلَ إِلَينا وَأُنزِلَ إِلَيكُم وَإِلٰهُنا وَإِلٰهُكُم وٰحِدٌ وَنَحنُ لَهُ مُسلِمونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmccclxxxvii{وَكَذٰلِكَ أَنزَلنا إِلَيكَ الكِتٰبَ فَالَّذينَ ءاتَينٰهُمُ الكِتٰبَ يُؤمِنونَ بِهِ وَمِن هٰؤُلاءِ مَن يُؤمِنُ بِهِ وَما يَجحَدُ بِـٔايٰتِنا إِلَّا الكٰفِرونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmccclxxxviii{وَما كُنتَ تَتلوا مِن قَبلِهِ مِن كِتٰبٍ وَلا تَخُطُّهُ بِيَمينِكَ إِذًا لَارتابَ المُبطِلونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmccclxxxix{بَل هُوَ ءايٰتٌ بَيِّنٰتٌ فى صُدورِ الَّذينَ أوتُوا العِلمَ وَما يَجحَدُ بِـٔايٰتِنا إِلَّا الظّٰلِمونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcccxc{وَقالوا لَولا أُنزِلَ عَلَيهِ ءايٰتٌ مِن رَبِّهِ قُل إِنَّمَا الءايٰتُ عِندَ اللَّهِ وَإِنَّما أَنا۠ نَذيرٌ مُبينٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmcccxci{أَوَلَم يَكفِهِم أَنّا أَنزَلنا عَلَيكَ الكِتٰبَ يُتلىٰ عَلَيهِم إِنَّ فى ذٰلِكَ لَرَحمَةً وَذِكرىٰ لِقَومٍ يُؤمِنونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmcccxcii{قُل كَفىٰ بِاللَّهِ بَينى وَبَينَكُم شَهيدًا يَعلَمُ ما فِى السَّمٰوٰتِ وَالأَرضِ وَالَّذينَ ءامَنوا بِالبٰطِلِ وَكَفَروا بِاللَّهِ أُولٰئِكَ هُمُ الخٰسِرونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcccxciii{وَيَستَعجِلونَكَ بِالعَذابِ وَلَولا أَجَلٌ مُسَمًّى لَجاءَهُمُ العَذابُ وَلَيَأتِيَنَّهُم بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcccxciv{يَستَعجِلونَكَ بِالعَذابِ وَإِنَّ جَهَنَّمَ لَمُحيطَةٌ بِالكٰفِرينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcccxcv{يَومَ يَغشىٰهُمُ العَذابُ مِن فَوقِهِم وَمِن تَحتِ أَرجُلِهِم وَيَقولُ ذوقوا ما كُنتُم تَعمَلونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcccxcvi{يٰعِبادِىَ الَّذينَ ءامَنوا إِنَّ أَرضى وٰسِعَةٌ فَإِيّٰىَ فَاعبُدونِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcccxcvii{كُلُّ نَفسٍ ذائِقَةُ المَوتِ ثُمَّ إِلَينا تُرجَعونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcccxcviii{وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَنُبَوِّئَنَّهُم مِنَ الجَنَّةِ غُرَفًا تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها نِعمَ أَجرُ العٰمِلينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcccxcix{الَّذينَ صَبَروا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcd{وَكَأَيِّن مِن دابَّةٍ لا تَحمِلُ رِزقَهَا اللَّهُ يَرزُقُها وَإِيّاكُم وَهُوَ السَّميعُ العَليمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcdi{وَلَئِن سَأَلتَهُم مَن خَلَقَ السَّمٰوٰتِ وَالأَرضَ وَسَخَّرَ الشَّمسَ وَالقَمَرَ لَيَقولُنَّ اللَّهُ فَأَنّىٰ يُؤفَكونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmcdii{اللَّهُ يَبسُطُ الرِّزقَ لِمَن يَشاءُ مِن عِبادِهِ وَيَقدِرُ لَهُ إِنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmcdiii{وَلَئِن سَأَلتَهُم مَن نَزَّلَ مِنَ السَّماءِ ماءً فَأَحيا بِهِ الأَرضَ مِن بَعدِ مَوتِها لَيَقولُنَّ اللَّهُ قُلِ الحَمدُ لِلَّهِ بَل أَكثَرُهُم لا يَعقِلونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmcdiv{وَما هٰذِهِ الحَيوٰةُ الدُّنيا إِلّا لَهوٌ وَلَعِبٌ وَإِنَّ الدّارَ الءاخِرَةَ لَهِىَ الحَيَوانُ لَو كانوا يَعلَمونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmcdv{فَإِذا رَكِبوا فِى الفُلكِ دَعَوُا اللَّهَ مُخلِصينَ لَهُ الدّينَ فَلَمّا نَجّىٰهُم إِلَى البَرِّ إِذا هُم يُشرِكونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmcdvi{لِيَكفُروا بِما ءاتَينٰهُم وَلِيَتَمَتَّعوا فَسَوفَ يَعلَمونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmcdvii{أَوَلَم يَرَوا أَنّا جَعَلنا حَرَمًا ءامِنًا وَيُتَخَطَّفُ النّاسُ مِن حَولِهِم أَفَبِالبٰطِلِ يُؤمِنونَ وَبِنِعمَةِ اللَّهِ يَكفُرونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmcdviii{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ كَذِبًا أَو كَذَّبَ بِالحَقِّ لَمّا جاءَهُ أَلَيسَ فى جَهَنَّمَ مَثوًى لِلكٰفِرينَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmcdix{وَالَّذينَ جٰهَدوا فينا لَنَهدِيَنَّهُم سُبُلَنا وَإِنَّ اللَّهَ لَمَعَ المُحسِنينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmcdx{\basmalah  الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcdxi{غُلِبَتِ الرّومُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcdxii{فى أَدنَى الأَرضِ وَهُم مِن بَعدِ غَلَبِهِم سَيَغلِبونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcdxiii{فى بِضعِ سِنينَ لِلَّهِ الأَمرُ مِن قَبلُ وَمِن بَعدُ وَيَومَئِذٍ يَفرَحُ المُؤمِنونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcdxiv{بِنَصرِ اللَّهِ يَنصُرُ مَن يَشاءُ وَهُوَ العَزيزُ الرَّحيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcdxv{وَعدَ اللَّهِ لا يُخلِفُ اللَّهُ وَعدَهُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcdxvi{يَعلَمونَ ظٰهِرًا مِنَ الحَيوٰةِ الدُّنيا وَهُم عَنِ الءاخِرَةِ هُم غٰفِلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcdxvii{أَوَلَم يَتَفَكَّروا فى أَنفُسِهِم ما خَلَقَ اللَّهُ السَّمٰوٰتِ وَالأَرضَ وَما بَينَهُما إِلّا بِالحَقِّ وَأَجَلٍ مُسَمًّى وَإِنَّ كَثيرًا مِنَ النّاسِ بِلِقائِ رَبِّهِم لَكٰفِرونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcdxviii{أَوَلَم يَسيروا فِى الأَرضِ فَيَنظُروا كَيفَ كانَ عٰقِبَةُ الَّذينَ مِن قَبلِهِم كانوا أَشَدَّ مِنهُم قُوَّةً وَأَثارُوا الأَرضَ وَعَمَروها أَكثَرَ مِمّا عَمَروها وَجاءَتهُم رُسُلُهُم بِالبَيِّنٰتِ فَما كانَ اللَّهُ لِيَظلِمَهُم وَلٰكِن كانوا أَنفُسَهُم يَظلِمونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcdxix{ثُمَّ كانَ عٰقِبَةَ الَّذينَ أَسٰـُٔوا السّوأىٰ أَن كَذَّبوا بِـٔايٰتِ اللَّهِ وَكانوا بِها يَستَهزِءونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcdxx{اللَّهُ يَبدَؤُا۟ الخَلقَ ثُمَّ يُعيدُهُ ثُمَّ إِلَيهِ تُرجَعونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcdxxi{وَيَومَ تَقومُ السّاعَةُ يُبلِسُ المُجرِمونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcdxxii{وَلَم يَكُن لَهُم مِن شُرَكائِهِم شُفَعٰؤُا۟ وَكانوا بِشُرَكائِهِم كٰفِرينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcdxxiii{وَيَومَ تَقومُ السّاعَةُ يَومَئِذٍ يَتَفَرَّقونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcdxxiv{فَأَمَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ فَهُم فى رَوضَةٍ يُحبَرونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcdxxv{وَأَمَّا الَّذينَ كَفَروا وَكَذَّبوا بِـٔايٰتِنا وَلِقائِ الءاخِرَةِ فَأُولٰئِكَ فِى العَذابِ مُحضَرونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcdxxvi{فَسُبحٰنَ اللَّهِ حينَ تُمسونَ وَحينَ تُصبِحونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcdxxvii{وَلَهُ الحَمدُ فِى السَّمٰوٰتِ وَالأَرضِ وَعَشِيًّا وَحينَ تُظهِرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcdxxviii{يُخرِجُ الحَىَّ مِنَ المَيِّتِ وَيُخرِجُ المَيِّتَ مِنَ الحَىِّ وَيُحىِ الأَرضَ بَعدَ مَوتِها وَكَذٰلِكَ تُخرَجونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcdxxix{وَمِن ءايٰتِهِ أَن خَلَقَكُم مِن تُرابٍ ثُمَّ إِذا أَنتُم بَشَرٌ تَنتَشِرونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcdxxx{وَمِن ءايٰتِهِ أَن خَلَقَ لَكُم مِن أَنفُسِكُم أَزوٰجًا لِتَسكُنوا إِلَيها وَجَعَلَ بَينَكُم مَوَدَّةً وَرَحمَةً إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcdxxxi{وَمِن ءايٰتِهِ خَلقُ السَّمٰوٰتِ وَالأَرضِ وَاختِلٰفُ أَلسِنَتِكُم وَأَلوٰنِكُم إِنَّ فى ذٰلِكَ لَءايٰتٍ لِلعٰلِمينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcdxxxii{وَمِن ءايٰتِهِ مَنامُكُم بِالَّيلِ وَالنَّهارِ وَابتِغاؤُكُم مِن فَضلِهِ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَسمَعونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcdxxxiii{وَمِن ءايٰتِهِ يُريكُمُ البَرقَ خَوفًا وَطَمَعًا وَيُنَزِّلُ مِنَ السَّماءِ ماءً فَيُحيۦ بِهِ الأَرضَ بَعدَ مَوتِها إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَعقِلونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcdxxxiv{وَمِن ءايٰتِهِ أَن تَقومَ السَّماءُ وَالأَرضُ بِأَمرِهِ ثُمَّ إِذا دَعاكُم دَعوَةً مِنَ الأَرضِ إِذا أَنتُم تَخرُجونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcdxxxv{وَلَهُ مَن فِى السَّمٰوٰتِ وَالأَرضِ كُلٌّ لَهُ قٰنِتونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcdxxxvi{وَهُوَ الَّذى يَبدَؤُا۟ الخَلقَ ثُمَّ يُعيدُهُ وَهُوَ أَهوَنُ عَلَيهِ وَلَهُ المَثَلُ الأَعلىٰ فِى السَّمٰوٰتِ وَالأَرضِ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcdxxxvii{ضَرَبَ لَكُم مَثَلًا مِن أَنفُسِكُم هَل لَكُم مِن ما مَلَكَت أَيمٰنُكُم مِن شُرَكاءَ فى ما رَزَقنٰكُم فَأَنتُم فيهِ سَواءٌ تَخافونَهُم كَخيفَتِكُم أَنفُسَكُم كَذٰلِكَ نُفَصِّلُ الءايٰتِ لِقَومٍ يَعقِلونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcdxxxviii{بَلِ اتَّبَعَ الَّذينَ ظَلَموا أَهواءَهُم بِغَيرِ عِلمٍ فَمَن يَهدى مَن أَضَلَّ اللَّهُ وَما لَهُم مِن نٰصِرينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcdxxxix{فَأَقِم وَجهَكَ لِلدّينِ حَنيفًا فِطرَتَ اللَّهِ الَّتى فَطَرَ النّاسَ عَلَيها لا تَبديلَ لِخَلقِ اللَّهِ ذٰلِكَ الدّينُ القَيِّمُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmcdxl{مُنيبينَ إِلَيهِ وَاتَّقوهُ وَأَقيمُوا الصَّلوٰةَ وَلا تَكونوا مِنَ المُشرِكينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmcdxli{مِنَ الَّذينَ فَرَّقوا دينَهُم وَكانوا شِيَعًا كُلُّ حِزبٍ بِما لَدَيهِم فَرِحونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmcdxlii{وَإِذا مَسَّ النّاسَ ضُرٌّ دَعَوا رَبَّهُم مُنيبينَ إِلَيهِ ثُمَّ إِذا أَذاقَهُم مِنهُ رَحمَةً إِذا فَريقٌ مِنهُم بِرَبِّهِم يُشرِكونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmcdxliii{لِيَكفُروا بِما ءاتَينٰهُم فَتَمَتَّعوا فَسَوفَ تَعلَمونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmcdxliv{أَم أَنزَلنا عَلَيهِم سُلطٰنًا فَهُوَ يَتَكَلَّمُ بِما كانوا بِهِ يُشرِكونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmcdxlv{وَإِذا أَذَقنَا النّاسَ رَحمَةً فَرِحوا بِها وَإِن تُصِبهُم سَيِّئَةٌ بِما قَدَّمَت أَيديهِم إِذا هُم يَقنَطونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmcdxlvi{أَوَلَم يَرَوا أَنَّ اللَّهَ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmcdxlvii{فَـٔاتِ ذَا القُربىٰ حَقَّهُ وَالمِسكينَ وَابنَ السَّبيلِ ذٰلِكَ خَيرٌ لِلَّذينَ يُريدونَ وَجهَ اللَّهِ وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmcdxlviii{وَما ءاتَيتُم مِن رِبًا لِيَربُوَا۟ فى أَموٰلِ النّاسِ فَلا يَربوا عِندَ اللَّهِ وَما ءاتَيتُم مِن زَكوٰةٍ تُريدونَ وَجهَ اللَّهِ فَأُولٰئِكَ هُمُ المُضعِفونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmcdxlix{اللَّهُ الَّذى خَلَقَكُم ثُمَّ رَزَقَكُم ثُمَّ يُميتُكُم ثُمَّ يُحييكُم هَل مِن شُرَكائِكُم مَن يَفعَلُ مِن ذٰلِكُم مِن شَيءٍ سُبحٰنَهُ وَتَعٰلىٰ عَمّا يُشرِكونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmcdl{ظَهَرَ الفَسادُ فِى البَرِّ وَالبَحرِ بِما كَسَبَت أَيدِى النّاسِ لِيُذيقَهُم بَعضَ الَّذى عَمِلوا لَعَلَّهُم يَرجِعونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmcdli{قُل سيروا فِى الأَرضِ فَانظُروا كَيفَ كانَ عٰقِبَةُ الَّذينَ مِن قَبلُ كانَ أَكثَرُهُم مُشرِكينَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmcdlii{فَأَقِم وَجهَكَ لِلدّينِ القَيِّمِ مِن قَبلِ أَن يَأتِىَ يَومٌ لا مَرَدَّ لَهُ مِنَ اللَّهِ يَومَئِذٍ يَصَّدَّعونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmcdliii{مَن كَفَرَ فَعَلَيهِ كُفرُهُ وَمَن عَمِلَ صٰلِحًا فَلِأَنفُسِهِم يَمهَدونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmcdliv{لِيَجزِىَ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ مِن فَضلِهِ إِنَّهُ لا يُحِبُّ الكٰفِرينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmcdlv{وَمِن ءايٰتِهِ أَن يُرسِلَ الرِّياحَ مُبَشِّرٰتٍ وَلِيُذيقَكُم مِن رَحمَتِهِ وَلِتَجرِىَ الفُلكُ بِأَمرِهِ وَلِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmcdlvi{وَلَقَد أَرسَلنا مِن قَبلِكَ رُسُلًا إِلىٰ قَومِهِم فَجاءوهُم بِالبَيِّنٰتِ فَانتَقَمنا مِنَ الَّذينَ أَجرَموا وَكانَ حَقًّا عَلَينا نَصرُ المُؤمِنينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmcdlvii{اللَّهُ الَّذى يُرسِلُ الرِّيٰحَ فَتُثيرُ سَحابًا فَيَبسُطُهُ فِى السَّماءِ كَيفَ يَشاءُ وَيَجعَلُهُ كِسَفًا فَتَرَى الوَدقَ يَخرُجُ مِن خِلٰلِهِ فَإِذا أَصابَ بِهِ مَن يَشاءُ مِن عِبادِهِ إِذا هُم يَستَبشِرونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmcdlviii{وَإِن كانوا مِن قَبلِ أَن يُنَزَّلَ عَلَيهِم مِن قَبلِهِ لَمُبلِسينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmcdlix{فَانظُر إِلىٰ ءاثٰرِ رَحمَتِ اللَّهِ كَيفَ يُحىِ الأَرضَ بَعدَ مَوتِها إِنَّ ذٰلِكَ لَمُحىِ المَوتىٰ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmcdlx{وَلَئِن أَرسَلنا ريحًا فَرَأَوهُ مُصفَرًّا لَظَلّوا مِن بَعدِهِ يَكفُرونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmcdlxi{فَإِنَّكَ لا تُسمِعُ المَوتىٰ وَلا تُسمِعُ الصُّمَّ الدُّعاءَ إِذا وَلَّوا مُدبِرينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmcdlxii{وَما أَنتَ بِهٰدِ العُمىِ عَن ضَلٰلَتِهِم إِن تُسمِعُ إِلّا مَن يُؤمِنُ بِـٔايٰتِنا فَهُم مُسلِمونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmcdlxiii{اللَّهُ الَّذى خَلَقَكُم مِن ضَعفٍ ثُمَّ جَعَلَ مِن بَعدِ ضَعفٍ قُوَّةً ثُمَّ جَعَلَ مِن بَعدِ قُوَّةٍ ضَعفًا وَشَيبَةً يَخلُقُ ما يَشاءُ وَهُوَ العَليمُ القَديرُ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmcdlxiv{وَيَومَ تَقومُ السّاعَةُ يُقسِمُ المُجرِمونَ ما لَبِثوا غَيرَ ساعَةٍ كَذٰلِكَ كانوا يُؤفَكونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmcdlxv{وَقالَ الَّذينَ أوتُوا العِلمَ وَالإيمٰنَ لَقَد لَبِثتُم فى كِتٰبِ اللَّهِ إِلىٰ يَومِ البَعثِ فَهٰذا يَومُ البَعثِ وَلٰكِنَّكُم كُنتُم لا تَعلَمونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmcdlxvi{فَيَومَئِذٍ لا يَنفَعُ الَّذينَ ظَلَموا مَعذِرَتُهُم وَلا هُم يُستَعتَبونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmcdlxvii{وَلَقَد ضَرَبنا لِلنّاسِ فى هٰذَا القُرءانِ مِن كُلِّ مَثَلٍ وَلَئِن جِئتَهُم بِـٔايَةٍ لَيَقولَنَّ الَّذينَ كَفَروا إِن أَنتُم إِلّا مُبطِلونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmcdlxviii{كَذٰلِكَ يَطبَعُ اللَّهُ عَلىٰ قُلوبِ الَّذينَ لا يَعلَمونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmcdlxix{فَاصبِر إِنَّ وَعدَ اللَّهِ حَقٌّ وَلا يَستَخِفَّنَّكَ الَّذينَ لا يوقِنونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmcdlxx{\basmalah  الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcdlxxi{تِلكَ ءايٰتُ الكِتٰبِ الحَكيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcdlxxii{هُدًى وَرَحمَةً لِلمُحسِنينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcdlxxiii{الَّذينَ يُقيمونَ الصَّلوٰةَ وَيُؤتونَ الزَّكوٰةَ وَهُم بِالءاخِرَةِ هُم يوقِنونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcdlxxiv{أُولٰئِكَ عَلىٰ هُدًى مِن رَبِّهِم وَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcdlxxv{وَمِنَ النّاسِ مَن يَشتَرى لَهوَ الحَديثِ لِيُضِلَّ عَن سَبيلِ اللَّهِ بِغَيرِ عِلمٍ وَيَتَّخِذَها هُزُوًا أُولٰئِكَ لَهُم عَذابٌ مُهينٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcdlxxvi{وَإِذا تُتلىٰ عَلَيهِ ءايٰتُنا وَلّىٰ مُستَكبِرًا كَأَن لَم يَسمَعها كَأَنَّ فى أُذُنَيهِ وَقرًا فَبَشِّرهُ بِعَذابٍ أَليمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcdlxxvii{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَهُم جَنّٰتُ النَّعيمِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcdlxxviii{خٰلِدينَ فيها وَعدَ اللَّهِ حَقًّا وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcdlxxix{خَلَقَ السَّمٰوٰتِ بِغَيرِ عَمَدٍ تَرَونَها وَأَلقىٰ فِى الأَرضِ رَوٰسِىَ أَن تَميدَ بِكُم وَبَثَّ فيها مِن كُلِّ دابَّةٍ وَأَنزَلنا مِنَ السَّماءِ ماءً فَأَنبَتنا فيها مِن كُلِّ زَوجٍ كَريمٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcdlxxx{هٰذا خَلقُ اللَّهِ فَأَرونى ماذا خَلَقَ الَّذينَ مِن دونِهِ بَلِ الظّٰلِمونَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcdlxxxi{وَلَقَد ءاتَينا لُقمٰنَ الحِكمَةَ أَنِ اشكُر لِلَّهِ وَمَن يَشكُر فَإِنَّما يَشكُرُ لِنَفسِهِ وَمَن كَفَرَ فَإِنَّ اللَّهَ غَنِىٌّ حَميدٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcdlxxxii{وَإِذ قالَ لُقمٰنُ لِابنِهِ وَهُوَ يَعِظُهُ يٰبُنَىَّ لا تُشرِك بِاللَّهِ إِنَّ الشِّركَ لَظُلمٌ عَظيمٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcdlxxxiii{وَوَصَّينَا الإِنسٰنَ بِوٰلِدَيهِ حَمَلَتهُ أُمُّهُ وَهنًا عَلىٰ وَهنٍ وَفِصٰلُهُ فى عامَينِ أَنِ اشكُر لى وَلِوٰلِدَيكَ إِلَىَّ المَصيرُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcdlxxxiv{وَإِن جٰهَداكَ عَلىٰ أَن تُشرِكَ بى ما لَيسَ لَكَ بِهِ عِلمٌ فَلا تُطِعهُما وَصاحِبهُما فِى الدُّنيا مَعروفًا وَاتَّبِع سَبيلَ مَن أَنابَ إِلَىَّ ثُمَّ إِلَىَّ مَرجِعُكُم فَأُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcdlxxxv{يٰبُنَىَّ إِنَّها إِن تَكُ مِثقالَ حَبَّةٍ مِن خَردَلٍ فَتَكُن فى صَخرَةٍ أَو فِى السَّمٰوٰتِ أَو فِى الأَرضِ يَأتِ بِهَا اللَّهُ إِنَّ اللَّهَ لَطيفٌ خَبيرٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcdlxxxvi{يٰبُنَىَّ أَقِمِ الصَّلوٰةَ وَأمُر بِالمَعروفِ وَانهَ عَنِ المُنكَرِ وَاصبِر عَلىٰ ما أَصابَكَ إِنَّ ذٰلِكَ مِن عَزمِ الأُمورِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcdlxxxvii{وَلا تُصَعِّر خَدَّكَ لِلنّاسِ وَلا تَمشِ فِى الأَرضِ مَرَحًا إِنَّ اللَّهَ لا يُحِبُّ كُلَّ مُختالٍ فَخورٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcdlxxxviii{وَاقصِد فى مَشيِكَ وَاغضُض مِن صَوتِكَ إِنَّ أَنكَرَ الأَصوٰتِ لَصَوتُ الحَميرِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcdlxxxix{أَلَم تَرَوا أَنَّ اللَّهَ سَخَّرَ لَكُم ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَأَسبَغَ عَلَيكُم نِعَمَهُ ظٰهِرَةً وَباطِنَةً وَمِنَ النّاسِ مَن يُجٰدِلُ فِى اللَّهِ بِغَيرِ عِلمٍ وَلا هُدًى وَلا كِتٰبٍ مُنيرٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcdxc{وَإِذا قيلَ لَهُمُ اتَّبِعوا ما أَنزَلَ اللَّهُ قالوا بَل نَتَّبِعُ ما وَجَدنا عَلَيهِ ءاباءَنا أَوَلَو كانَ الشَّيطٰنُ يَدعوهُم إِلىٰ عَذابِ السَّعيرِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcdxci{وَمَن يُسلِم وَجهَهُ إِلَى اللَّهِ وَهُوَ مُحسِنٌ فَقَدِ استَمسَكَ بِالعُروَةِ الوُثقىٰ وَإِلَى اللَّهِ عٰقِبَةُ الأُمورِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcdxcii{وَمَن كَفَرَ فَلا يَحزُنكَ كُفرُهُ إِلَينا مَرجِعُهُم فَنُنَبِّئُهُم بِما عَمِلوا إِنَّ اللَّهَ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcdxciii{نُمَتِّعُهُم قَليلًا ثُمَّ نَضطَرُّهُم إِلىٰ عَذابٍ غَليظٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcdxciv{وَلَئِن سَأَلتَهُم مَن خَلَقَ السَّمٰوٰتِ وَالأَرضَ لَيَقولُنَّ اللَّهُ قُلِ الحَمدُ لِلَّهِ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcdxcv{لِلَّهِ ما فِى السَّمٰوٰتِ وَالأَرضِ إِنَّ اللَّهَ هُوَ الغَنِىُّ الحَميدُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcdxcvi{وَلَو أَنَّما فِى الأَرضِ مِن شَجَرَةٍ أَقلٰمٌ وَالبَحرُ يَمُدُّهُ مِن بَعدِهِ سَبعَةُ أَبحُرٍ ما نَفِدَت كَلِمٰتُ اللَّهِ إِنَّ اللَّهَ عَزيزٌ حَكيمٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcdxcvii{ما خَلقُكُم وَلا بَعثُكُم إِلّا كَنَفسٍ وٰحِدَةٍ إِنَّ اللَّهَ سَميعٌ بَصيرٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcdxcviii{أَلَم تَرَ أَنَّ اللَّهَ يولِجُ الَّيلَ فِى النَّهارِ وَيولِجُ النَّهارَ فِى الَّيلِ وَسَخَّرَ الشَّمسَ وَالقَمَرَ كُلٌّ يَجرى إِلىٰ أَجَلٍ مُسَمًّى وَأَنَّ اللَّهَ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmcdxcix{ذٰلِكَ بِأَنَّ اللَّهَ هُوَ الحَقُّ وَأَنَّ ما يَدعونَ مِن دونِهِ البٰطِلُ وَأَنَّ اللَّهَ هُوَ العَلِىُّ الكَبيرُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmd{أَلَم تَرَ أَنَّ الفُلكَ تَجرى فِى البَحرِ بِنِعمَتِ اللَّهِ لِيُرِيَكُم مِن ءايٰتِهِ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِكُلِّ صَبّارٍ شَكورٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdi{وَإِذا غَشِيَهُم مَوجٌ كَالظُّلَلِ دَعَوُا اللَّهَ مُخلِصينَ لَهُ الدّينَ فَلَمّا نَجّىٰهُم إِلَى البَرِّ فَمِنهُم مُقتَصِدٌ وَما يَجحَدُ بِـٔايٰتِنا إِلّا كُلُّ خَتّارٍ كَفورٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdii{يٰأَيُّهَا النّاسُ اتَّقوا رَبَّكُم وَاخشَوا يَومًا لا يَجزى والِدٌ عَن وَلَدِهِ وَلا مَولودٌ هُوَ جازٍ عَن والِدِهِ شَيـًٔا إِنَّ وَعدَ اللَّهِ حَقٌّ فَلا تَغُرَّنَّكُمُ الحَيوٰةُ الدُّنيا وَلا يَغُرَّنَّكُم بِاللَّهِ الغَرورُ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdiii{إِنَّ اللَّهَ عِندَهُ عِلمُ السّاعَةِ وَيُنَزِّلُ الغَيثَ وَيَعلَمُ ما فِى الأَرحامِ وَما تَدرى نَفسٌ ماذا تَكسِبُ غَدًا وَما تَدرى نَفسٌ بِأَىِّ أَرضٍ تَموتُ إِنَّ اللَّهَ عَليمٌ خَبيرٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdiv{\basmalah  الم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdv{تَنزيلُ الكِتٰبِ لا رَيبَ فيهِ مِن رَبِّ العٰلَمينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdvi{أَم يَقولونَ افتَرىٰهُ بَل هُوَ الحَقُّ مِن رَبِّكَ لِتُنذِرَ قَومًا ما أَتىٰهُم مِن نَذيرٍ مِن قَبلِكَ لَعَلَّهُم يَهتَدونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdvii{اللَّهُ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ وَما بَينَهُما فى سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ ما لَكُم مِن دونِهِ مِن وَلِىٍّ وَلا شَفيعٍ أَفَلا تَتَذَكَّرونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdviii{يُدَبِّرُ الأَمرَ مِنَ السَّماءِ إِلَى الأَرضِ ثُمَّ يَعرُجُ إِلَيهِ فى يَومٍ كانَ مِقدارُهُ أَلفَ سَنَةٍ مِمّا تَعُدّونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdix{ذٰلِكَ عٰلِمُ الغَيبِ وَالشَّهٰدَةِ العَزيزُ الرَّحيمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdx{الَّذى أَحسَنَ كُلَّ شَيءٍ خَلَقَهُ وَبَدَأَ خَلقَ الإِنسٰنِ مِن طينٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdxi{ثُمَّ جَعَلَ نَسلَهُ مِن سُلٰلَةٍ مِن ماءٍ مَهينٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdxii{ثُمَّ سَوّىٰهُ وَنَفَخَ فيهِ مِن روحِهِ وَجَعَلَ لَكُمُ السَّمعَ وَالأَبصٰرَ وَالأَفـِٔدَةَ قَليلًا ما تَشكُرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdxiii{وَقالوا أَءِذا ضَلَلنا فِى الأَرضِ أَءِنّا لَفى خَلقٍ جَديدٍ بَل هُم بِلِقاءِ رَبِّهِم كٰفِرونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdxiv{قُل يَتَوَفّىٰكُم مَلَكُ المَوتِ الَّذى وُكِّلَ بِكُم ثُمَّ إِلىٰ رَبِّكُم تُرجَعونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdxv{وَلَو تَرىٰ إِذِ المُجرِمونَ ناكِسوا رُءوسِهِم عِندَ رَبِّهِم رَبَّنا أَبصَرنا وَسَمِعنا فَارجِعنا نَعمَل صٰلِحًا إِنّا موقِنونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdxvi{وَلَو شِئنا لَءاتَينا كُلَّ نَفسٍ هُدىٰها وَلٰكِن حَقَّ القَولُ مِنّى لَأَملَأَنَّ جَهَنَّمَ مِنَ الجِنَّةِ وَالنّاسِ أَجمَعينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdxvii{فَذوقوا بِما نَسيتُم لِقاءَ يَومِكُم هٰذا إِنّا نَسينٰكُم وَذوقوا عَذابَ الخُلدِ بِما كُنتُم تَعمَلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdxviii{إِنَّما يُؤمِنُ بِـٔايٰتِنَا الَّذينَ إِذا ذُكِّروا بِها خَرّوا سُجَّدًا وَسَبَّحوا بِحَمدِ رَبِّهِم وَهُم لا يَستَكبِرونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdxix{تَتَجافىٰ جُنوبُهُم عَنِ المَضاجِعِ يَدعونَ رَبَّهُم خَوفًا وَطَمَعًا وَمِمّا رَزَقنٰهُم يُنفِقونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdxx{فَلا تَعلَمُ نَفسٌ ما أُخفِىَ لَهُم مِن قُرَّةِ أَعيُنٍ جَزاءً بِما كانوا يَعمَلونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdxxi{أَفَمَن كانَ مُؤمِنًا كَمَن كانَ فاسِقًا لا يَستَوۥنَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdxxii{أَمَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ فَلَهُم جَنّٰتُ المَأوىٰ نُزُلًا بِما كانوا يَعمَلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdxxiii{وَأَمَّا الَّذينَ فَسَقوا فَمَأوىٰهُمُ النّارُ كُلَّما أَرادوا أَن يَخرُجوا مِنها أُعيدوا فيها وَقيلَ لَهُم ذوقوا عَذابَ النّارِ الَّذى كُنتُم بِهِ تُكَذِّبونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdxxiv{وَلَنُذيقَنَّهُم مِنَ العَذابِ الأَدنىٰ دونَ العَذابِ الأَكبَرِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdxxv{وَمَن أَظلَمُ مِمَّن ذُكِّرَ بِـٔايٰتِ رَبِّهِ ثُمَّ أَعرَضَ عَنها إِنّا مِنَ المُجرِمينَ مُنتَقِمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdxxvi{وَلَقَد ءاتَينا موسَى الكِتٰبَ فَلا تَكُن فى مِريَةٍ مِن لِقائِهِ وَجَعَلنٰهُ هُدًى لِبَنى إِسرٰءيلَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdxxvii{وَجَعَلنا مِنهُم أَئِمَّةً يَهدونَ بِأَمرِنا لَمّا صَبَروا وَكانوا بِـٔايٰتِنا يوقِنونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdxxviii{إِنَّ رَبَّكَ هُوَ يَفصِلُ بَينَهُم يَومَ القِيٰمَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdxxix{أَوَلَم يَهدِ لَهُم كَم أَهلَكنا مِن قَبلِهِم مِنَ القُرونِ يَمشونَ فى مَسٰكِنِهِم إِنَّ فى ذٰلِكَ لَءايٰتٍ أَفَلا يَسمَعونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdxxx{أَوَلَم يَرَوا أَنّا نَسوقُ الماءَ إِلَى الأَرضِ الجُرُزِ فَنُخرِجُ بِهِ زَرعًا تَأكُلُ مِنهُ أَنعٰمُهُم وَأَنفُسُهُم أَفَلا يُبصِرونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdxxxi{وَيَقولونَ مَتىٰ هٰذَا الفَتحُ إِن كُنتُم صٰدِقينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdxxxii{قُل يَومَ الفَتحِ لا يَنفَعُ الَّذينَ كَفَروا إيمٰنُهُم وَلا هُم يُنظَرونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdxxxiii{فَأَعرِض عَنهُم وَانتَظِر إِنَّهُم مُنتَظِرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdxxxiv{\basmalah  يٰأَيُّهَا النَّبِىُّ اتَّقِ اللَّهَ وَلا تُطِعِ الكٰفِرينَ وَالمُنٰفِقينَ إِنَّ اللَّهَ كانَ عَليمًا حَكيمًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdxxxv{وَاتَّبِع ما يوحىٰ إِلَيكَ مِن رَبِّكَ إِنَّ اللَّهَ كانَ بِما تَعمَلونَ خَبيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdxxxvi{وَتَوَكَّل عَلَى اللَّهِ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdxxxvii{ما جَعَلَ اللَّهُ لِرَجُلٍ مِن قَلبَينِ فى جَوفِهِ وَما جَعَلَ أَزوٰجَكُمُ الّٰـٔى تُظٰهِرونَ مِنهُنَّ أُمَّهٰتِكُم وَما جَعَلَ أَدعِياءَكُم أَبناءَكُم ذٰلِكُم قَولُكُم بِأَفوٰهِكُم وَاللَّهُ يَقولُ الحَقَّ وَهُوَ يَهدِى السَّبيلَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdxxxviii{ادعوهُم لِءابائِهِم هُوَ أَقسَطُ عِندَ اللَّهِ فَإِن لَم تَعلَموا ءاباءَهُم فَإِخوٰنُكُم فِى الدّينِ وَمَوٰليكُم وَلَيسَ عَلَيكُم جُناحٌ فيما أَخطَأتُم بِهِ وَلٰكِن ما تَعَمَّدَت قُلوبُكُم وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdxxxix{النَّبِىُّ أَولىٰ بِالمُؤمِنينَ مِن أَنفُسِهِم وَأَزوٰجُهُ أُمَّهٰتُهُم وَأُولُوا الأَرحامِ بَعضُهُم أَولىٰ بِبَعضٍ فى كِتٰبِ اللَّهِ مِنَ المُؤمِنينَ وَالمُهٰجِرينَ إِلّا أَن تَفعَلوا إِلىٰ أَولِيائِكُم مَعروفًا كانَ ذٰلِكَ فِى الكِتٰبِ مَسطورًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdxl{وَإِذ أَخَذنا مِنَ النَّبِيّۦنَ ميثٰقَهُم وَمِنكَ وَمِن نوحٍ وَإِبرٰهيمَ وَموسىٰ وَعيسَى ابنِ مَريَمَ وَأَخَذنا مِنهُم ميثٰقًا غَليظًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdxli{لِيَسـَٔلَ الصّٰدِقينَ عَن صِدقِهِم وَأَعَدَّ لِلكٰفِرينَ عَذابًا أَليمًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdxlii{يٰأَيُّهَا الَّذينَ ءامَنُوا اذكُروا نِعمَةَ اللَّهِ عَلَيكُم إِذ جاءَتكُم جُنودٌ فَأَرسَلنا عَلَيهِم ريحًا وَجُنودًا لَم تَرَوها وَكانَ اللَّهُ بِما تَعمَلونَ بَصيرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdxliii{إِذ جاءوكُم مِن فَوقِكُم وَمِن أَسفَلَ مِنكُم وَإِذ زاغَتِ الأَبصٰرُ وَبَلَغَتِ القُلوبُ الحَناجِرَ وَتَظُنّونَ بِاللَّهِ الظُّنونا۠\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdxliv{هُنالِكَ ابتُلِىَ المُؤمِنونَ وَزُلزِلوا زِلزالًا شَديدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdxlv{وَإِذ يَقولُ المُنٰفِقونَ وَالَّذينَ فى قُلوبِهِم مَرَضٌ ما وَعَدَنَا اللَّهُ وَرَسولُهُ إِلّا غُرورًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdxlvi{وَإِذ قالَت طائِفَةٌ مِنهُم يٰأَهلَ يَثرِبَ لا مُقامَ لَكُم فَارجِعوا وَيَستَـٔذِنُ فَريقٌ مِنهُمُ النَّبِىَّ يَقولونَ إِنَّ بُيوتَنا عَورَةٌ وَما هِىَ بِعَورَةٍ إِن يُريدونَ إِلّا فِرارًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdxlvii{وَلَو دُخِلَت عَلَيهِم مِن أَقطارِها ثُمَّ سُئِلُوا الفِتنَةَ لَءاتَوها وَما تَلَبَّثوا بِها إِلّا يَسيرًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdxlviii{وَلَقَد كانوا عٰهَدُوا اللَّهَ مِن قَبلُ لا يُوَلّونَ الأَدبٰرَ وَكانَ عَهدُ اللَّهِ مَسـٔولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdxlix{قُل لَن يَنفَعَكُمُ الفِرارُ إِن فَرَرتُم مِنَ المَوتِ أَوِ القَتلِ وَإِذًا لا تُمَتَّعونَ إِلّا قَليلًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdl{قُل مَن ذَا الَّذى يَعصِمُكُم مِنَ اللَّهِ إِن أَرادَ بِكُم سوءًا أَو أَرادَ بِكُم رَحمَةً وَلا يَجِدونَ لَهُم مِن دونِ اللَّهِ وَلِيًّا وَلا نَصيرًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdli{قَد يَعلَمُ اللَّهُ المُعَوِّقينَ مِنكُم وَالقائِلينَ لِإِخوٰنِهِم هَلُمَّ إِلَينا وَلا يَأتونَ البَأسَ إِلّا قَليلًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdlii{أَشِحَّةً عَلَيكُم فَإِذا جاءَ الخَوفُ رَأَيتَهُم يَنظُرونَ إِلَيكَ تَدورُ أَعيُنُهُم كَالَّذى يُغشىٰ عَلَيهِ مِنَ المَوتِ فَإِذا ذَهَبَ الخَوفُ سَلَقوكُم بِأَلسِنَةٍ حِدادٍ أَشِحَّةً عَلَى الخَيرِ أُولٰئِكَ لَم يُؤمِنوا فَأَحبَطَ اللَّهُ أَعمٰلَهُم وَكانَ ذٰلِكَ عَلَى اللَّهِ يَسيرًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdliii{يَحسَبونَ الأَحزابَ لَم يَذهَبوا وَإِن يَأتِ الأَحزابُ يَوَدّوا لَو أَنَّهُم بادونَ فِى الأَعرابِ يَسـَٔلونَ عَن أَنبائِكُم وَلَو كانوا فيكُم ما قٰتَلوا إِلّا قَليلًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdliv{لَقَد كانَ لَكُم فى رَسولِ اللَّهِ أُسوَةٌ حَسَنَةٌ لِمَن كانَ يَرجُوا اللَّهَ وَاليَومَ الءاخِرَ وَذَكَرَ اللَّهَ كَثيرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdlv{وَلَمّا رَءَا المُؤمِنونَ الأَحزابَ قالوا هٰذا ما وَعَدَنَا اللَّهُ وَرَسولُهُ وَصَدَقَ اللَّهُ وَرَسولُهُ وَما زادَهُم إِلّا إيمٰنًا وَتَسليمًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdlvi{مِنَ المُؤمِنينَ رِجالٌ صَدَقوا ما عٰهَدُوا اللَّهَ عَلَيهِ فَمِنهُم مَن قَضىٰ نَحبَهُ وَمِنهُم مَن يَنتَظِرُ وَما بَدَّلوا تَبديلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdlvii{لِيَجزِىَ اللَّهُ الصّٰدِقينَ بِصِدقِهِم وَيُعَذِّبَ المُنٰفِقينَ إِن شاءَ أَو يَتوبَ عَلَيهِم إِنَّ اللَّهَ كانَ غَفورًا رَحيمًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdlviii{وَرَدَّ اللَّهُ الَّذينَ كَفَروا بِغَيظِهِم لَم يَنالوا خَيرًا وَكَفَى اللَّهُ المُؤمِنينَ القِتالَ وَكانَ اللَّهُ قَوِيًّا عَزيزًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdlix{وَأَنزَلَ الَّذينَ ظٰهَروهُم مِن أَهلِ الكِتٰبِ مِن صَياصيهِم وَقَذَفَ فى قُلوبِهِمُ الرُّعبَ فَريقًا تَقتُلونَ وَتَأسِرونَ فَريقًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdlx{وَأَورَثَكُم أَرضَهُم وَدِيٰرَهُم وَأَموٰلَهُم وَأَرضًا لَم تَطَـٔوها وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdlxi{يٰأَيُّهَا النَّبِىُّ قُل لِأَزوٰجِكَ إِن كُنتُنَّ تُرِدنَ الحَيوٰةَ الدُّنيا وَزينَتَها فَتَعالَينَ أُمَتِّعكُنَّ وَأُسَرِّحكُنَّ سَراحًا جَميلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdlxii{وَإِن كُنتُنَّ تُرِدنَ اللَّهَ وَرَسولَهُ وَالدّارَ الءاخِرَةَ فَإِنَّ اللَّهَ أَعَدَّ لِلمُحسِنٰتِ مِنكُنَّ أَجرًا عَظيمًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdlxiii{يٰنِساءَ النَّبِىِّ مَن يَأتِ مِنكُنَّ بِفٰحِشَةٍ مُبَيِّنَةٍ يُضٰعَف لَهَا العَذابُ ضِعفَينِ وَكانَ ذٰلِكَ عَلَى اللَّهِ يَسيرًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdlxiv{وَمَن يَقنُت مِنكُنَّ لِلَّهِ وَرَسولِهِ وَتَعمَل صٰلِحًا نُؤتِها أَجرَها مَرَّتَينِ وَأَعتَدنا لَها رِزقًا كَريمًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdlxv{يٰنِساءَ النَّبِىِّ لَستُنَّ كَأَحَدٍ مِنَ النِّساءِ إِنِ اتَّقَيتُنَّ فَلا تَخضَعنَ بِالقَولِ فَيَطمَعَ الَّذى فى قَلبِهِ مَرَضٌ وَقُلنَ قَولًا مَعروفًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdlxvi{وَقَرنَ فى بُيوتِكُنَّ وَلا تَبَرَّجنَ تَبَرُّجَ الجٰهِلِيَّةِ الأولىٰ وَأَقِمنَ الصَّلوٰةَ وَءاتينَ الزَّكوٰةَ وَأَطِعنَ اللَّهَ وَرَسولَهُ إِنَّما يُريدُ اللَّهُ لِيُذهِبَ عَنكُمُ الرِّجسَ أَهلَ البَيتِ وَيُطَهِّرَكُم تَطهيرًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdlxvii{وَاذكُرنَ ما يُتلىٰ فى بُيوتِكُنَّ مِن ءايٰتِ اللَّهِ وَالحِكمَةِ إِنَّ اللَّهَ كانَ لَطيفًا خَبيرًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdlxviii{إِنَّ المُسلِمينَ وَالمُسلِمٰتِ وَالمُؤمِنينَ وَالمُؤمِنٰتِ وَالقٰنِتينَ وَالقٰنِتٰتِ وَالصّٰدِقينَ وَالصّٰدِقٰتِ وَالصّٰبِرينَ وَالصّٰبِرٰتِ وَالخٰشِعينَ وَالخٰشِعٰتِ وَالمُتَصَدِّقينَ وَالمُتَصَدِّقٰتِ وَالصّٰئِمينَ وَالصّٰئِمٰتِ وَالحٰفِظينَ فُروجَهُم وَالحٰفِظٰتِ وَالذّٰكِرينَ اللَّهَ كَثيرًا وَالذّٰكِرٰتِ أَعَدَّ اللَّهُ لَهُم مَغفِرَةً وَأَجرًا عَظيمًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdlxix{وَما كانَ لِمُؤمِنٍ وَلا مُؤمِنَةٍ إِذا قَضَى اللَّهُ وَرَسولُهُ أَمرًا أَن يَكونَ لَهُمُ الخِيَرَةُ مِن أَمرِهِم وَمَن يَعصِ اللَّهَ وَرَسولَهُ فَقَد ضَلَّ ضَلٰلًا مُبينًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdlxx{وَإِذ تَقولُ لِلَّذى أَنعَمَ اللَّهُ عَلَيهِ وَأَنعَمتَ عَلَيهِ أَمسِك عَلَيكَ زَوجَكَ وَاتَّقِ اللَّهَ وَتُخفى فى نَفسِكَ مَا اللَّهُ مُبديهِ وَتَخشَى النّاسَ وَاللَّهُ أَحَقُّ أَن تَخشىٰهُ فَلَمّا قَضىٰ زَيدٌ مِنها وَطَرًا زَوَّجنٰكَها لِكَى لا يَكونَ عَلَى المُؤمِنينَ حَرَجٌ فى أَزوٰجِ أَدعِيائِهِم إِذا قَضَوا مِنهُنَّ وَطَرًا وَكانَ أَمرُ اللَّهِ مَفعولًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdlxxi{ما كانَ عَلَى النَّبِىِّ مِن حَرَجٍ فيما فَرَضَ اللَّهُ لَهُ سُنَّةَ اللَّهِ فِى الَّذينَ خَلَوا مِن قَبلُ وَكانَ أَمرُ اللَّهِ قَدَرًا مَقدورًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdlxxii{الَّذينَ يُبَلِّغونَ رِسٰلٰتِ اللَّهِ وَيَخشَونَهُ وَلا يَخشَونَ أَحَدًا إِلَّا اللَّهَ وَكَفىٰ بِاللَّهِ حَسيبًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdlxxiii{ما كانَ مُحَمَّدٌ أَبا أَحَدٍ مِن رِجالِكُم وَلٰكِن رَسولَ اللَّهِ وَخاتَمَ النَّبِيّۦنَ وَكانَ اللَّهُ بِكُلِّ شَيءٍ عَليمًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdlxxiv{يٰأَيُّهَا الَّذينَ ءامَنُوا اذكُرُوا اللَّهَ ذِكرًا كَثيرًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdlxxv{وَسَبِّحوهُ بُكرَةً وَأَصيلًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdlxxvi{هُوَ الَّذى يُصَلّى عَلَيكُم وَمَلٰئِكَتُهُ لِيُخرِجَكُم مِنَ الظُّلُمٰتِ إِلَى النّورِ وَكانَ بِالمُؤمِنينَ رَحيمًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdlxxvii{تَحِيَّتُهُم يَومَ يَلقَونَهُ سَلٰمٌ وَأَعَدَّ لَهُم أَجرًا كَريمًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdlxxviii{يٰأَيُّهَا النَّبِىُّ إِنّا أَرسَلنٰكَ شٰهِدًا وَمُبَشِّرًا وَنَذيرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdlxxix{وَداعِيًا إِلَى اللَّهِ بِإِذنِهِ وَسِراجًا مُنيرًا\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdlxxx{وَبَشِّرِ المُؤمِنينَ بِأَنَّ لَهُم مِنَ اللَّهِ فَضلًا كَبيرًا\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdlxxxi{وَلا تُطِعِ الكٰفِرينَ وَالمُنٰفِقينَ وَدَع أَذىٰهُم وَتَوَكَّل عَلَى اللَّهِ وَكَفىٰ بِاللَّهِ وَكيلًا\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdlxxxii{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا نَكَحتُمُ المُؤمِنٰتِ ثُمَّ طَلَّقتُموهُنَّ مِن قَبلِ أَن تَمَسّوهُنَّ فَما لَكُم عَلَيهِنَّ مِن عِدَّةٍ تَعتَدّونَها فَمَتِّعوهُنَّ وَسَرِّحوهُنَّ سَراحًا جَميلًا\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdlxxxiii{يٰأَيُّهَا النَّبِىُّ إِنّا أَحلَلنا لَكَ أَزوٰجَكَ الّٰتى ءاتَيتَ أُجورَهُنَّ وَما مَلَكَت يَمينُكَ مِمّا أَفاءَ اللَّهُ عَلَيكَ وَبَناتِ عَمِّكَ وَبَناتِ عَمّٰتِكَ وَبَناتِ خالِكَ وَبَناتِ خٰلٰتِكَ الّٰتى هاجَرنَ مَعَكَ وَامرَأَةً مُؤمِنَةً إِن وَهَبَت نَفسَها لِلنَّبِىِّ إِن أَرادَ النَّبِىُّ أَن يَستَنكِحَها خالِصَةً لَكَ مِن دونِ المُؤمِنينَ قَد عَلِمنا ما فَرَضنا عَلَيهِم فى أَزوٰجِهِم وَما مَلَكَت أَيمٰنُهُم لِكَيلا يَكونَ عَلَيكَ حَرَجٌ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdlxxxiv{تُرجى مَن تَشاءُ مِنهُنَّ وَتُـٔوى إِلَيكَ مَن تَشاءُ وَمَنِ ابتَغَيتَ مِمَّن عَزَلتَ فَلا جُناحَ عَلَيكَ ذٰلِكَ أَدنىٰ أَن تَقَرَّ أَعيُنُهُنَّ وَلا يَحزَنَّ وَيَرضَينَ بِما ءاتَيتَهُنَّ كُلُّهُنَّ وَاللَّهُ يَعلَمُ ما فى قُلوبِكُم وَكانَ اللَّهُ عَليمًا حَليمًا\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdlxxxv{لا يَحِلُّ لَكَ النِّساءُ مِن بَعدُ وَلا أَن تَبَدَّلَ بِهِنَّ مِن أَزوٰجٍ وَلَو أَعجَبَكَ حُسنُهُنَّ إِلّا ما مَلَكَت يَمينُكَ وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ رَقيبًا\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdlxxxvi{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَدخُلوا بُيوتَ النَّبِىِّ إِلّا أَن يُؤذَنَ لَكُم إِلىٰ طَعامٍ غَيرَ نٰظِرينَ إِنىٰهُ وَلٰكِن إِذا دُعيتُم فَادخُلوا فَإِذا طَعِمتُم فَانتَشِروا وَلا مُستَـٔنِسينَ لِحَديثٍ إِنَّ ذٰلِكُم كانَ يُؤذِى النَّبِىَّ فَيَستَحيۦ مِنكُم وَاللَّهُ لا يَستَحيۦ مِنَ الحَقِّ وَإِذا سَأَلتُموهُنَّ مَتٰعًا فَسـَٔلوهُنَّ مِن وَراءِ حِجابٍ ذٰلِكُم أَطهَرُ لِقُلوبِكُم وَقُلوبِهِنَّ وَما كانَ لَكُم أَن تُؤذوا رَسولَ اللَّهِ وَلا أَن تَنكِحوا أَزوٰجَهُ مِن بَعدِهِ أَبَدًا إِنَّ ذٰلِكُم كانَ عِندَ اللَّهِ عَظيمًا\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdlxxxvii{إِن تُبدوا شَيـًٔا أَو تُخفوهُ فَإِنَّ اللَّهَ كانَ بِكُلِّ شَيءٍ عَليمًا\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdlxxxviii{لا جُناحَ عَلَيهِنَّ فى ءابائِهِنَّ وَلا أَبنائِهِنَّ وَلا إِخوٰنِهِنَّ وَلا أَبناءِ إِخوٰنِهِنَّ وَلا أَبناءِ أَخَوٰتِهِنَّ وَلا نِسائِهِنَّ وَلا ما مَلَكَت أَيمٰنُهُنَّ وَاتَّقينَ اللَّهَ إِنَّ اللَّهَ كانَ عَلىٰ كُلِّ شَيءٍ شَهيدًا\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdlxxxix{إِنَّ اللَّهَ وَمَلٰئِكَتَهُ يُصَلّونَ عَلَى النَّبِىِّ يٰأَيُّهَا الَّذينَ ءامَنوا صَلّوا عَلَيهِ وَسَلِّموا تَسليمًا\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdxc{إِنَّ الَّذينَ يُؤذونَ اللَّهَ وَرَسولَهُ لَعَنَهُمُ اللَّهُ فِى الدُّنيا وَالءاخِرَةِ وَأَعَدَّ لَهُم عَذابًا مُهينًا\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdxci{وَالَّذينَ يُؤذونَ المُؤمِنينَ وَالمُؤمِنٰتِ بِغَيرِ مَا اكتَسَبوا فَقَدِ احتَمَلوا بُهتٰنًا وَإِثمًا مُبينًا\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdxcii{يٰأَيُّهَا النَّبِىُّ قُل لِأَزوٰجِكَ وَبَناتِكَ وَنِساءِ المُؤمِنينَ يُدنينَ عَلَيهِنَّ مِن جَلٰبيبِهِنَّ ذٰلِكَ أَدنىٰ أَن يُعرَفنَ فَلا يُؤذَينَ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdxciii{لَئِن لَم يَنتَهِ المُنٰفِقونَ وَالَّذينَ فى قُلوبِهِم مَرَضٌ وَالمُرجِفونَ فِى المَدينَةِ لَنُغرِيَنَّكَ بِهِم ثُمَّ لا يُجاوِرونَكَ فيها إِلّا قَليلًا\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdxciv{مَلعونينَ أَينَما ثُقِفوا أُخِذوا وَقُتِّلوا تَقتيلًا\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdxcv{سُنَّةَ اللَّهِ فِى الَّذينَ خَلَوا مِن قَبلُ وَلَن تَجِدَ لِسُنَّةِ اللَّهِ تَبديلًا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdxcvi{يَسـَٔلُكَ النّاسُ عَنِ السّاعَةِ قُل إِنَّما عِلمُها عِندَ اللَّهِ وَما يُدريكَ لَعَلَّ السّاعَةَ تَكونُ قَريبًا\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdxcvii{إِنَّ اللَّهَ لَعَنَ الكٰفِرينَ وَأَعَدَّ لَهُم سَعيرًا\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdxcviii{خٰلِدينَ فيها أَبَدًا لا يَجِدونَ وَلِيًّا وَلا نَصيرًا\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdxcix{يَومَ تُقَلَّبُ وُجوهُهُم فِى النّارِ يَقولونَ يٰلَيتَنا أَطَعنَا اللَّهَ وَأَطَعنَا الرَّسولا۠\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdc{وَقالوا رَبَّنا إِنّا أَطَعنا سادَتَنا وَكُبَراءَنا فَأَضَلّونَا السَّبيلا۠\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdci{رَبَّنا ءاتِهِم ضِعفَينِ مِنَ العَذابِ وَالعَنهُم لَعنًا كَبيرًا\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdcii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَكونوا كَالَّذينَ ءاذَوا موسىٰ فَبَرَّأَهُ اللَّهُ مِمّا قالوا وَكانَ عِندَ اللَّهِ وَجيهًا\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdciii{يٰأَيُّهَا الَّذينَ ءامَنُوا اتَّقُوا اللَّهَ وَقولوا قَولًا سَديدًا\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdciv{يُصلِح لَكُم أَعمٰلَكُم وَيَغفِر لَكُم ذُنوبَكُم وَمَن يُطِعِ اللَّهَ وَرَسولَهُ فَقَد فازَ فَوزًا عَظيمًا\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdcv{إِنّا عَرَضنَا الأَمانَةَ عَلَى السَّمٰوٰتِ وَالأَرضِ وَالجِبالِ فَأَبَينَ أَن يَحمِلنَها وَأَشفَقنَ مِنها وَحَمَلَهَا الإِنسٰنُ إِنَّهُ كانَ ظَلومًا جَهولًا\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdcvi{لِيُعَذِّبَ اللَّهُ المُنٰفِقينَ وَالمُنٰفِقٰتِ وَالمُشرِكينَ وَالمُشرِكٰتِ وَيَتوبَ اللَّهُ عَلَى المُؤمِنينَ وَالمُؤمِنٰتِ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdcvii{\basmalah  الحَمدُ لِلَّهِ الَّذى لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَلَهُ الحَمدُ فِى الءاخِرَةِ وَهُوَ الحَكيمُ الخَبيرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdcviii{يَعلَمُ ما يَلِجُ فِى الأَرضِ وَما يَخرُجُ مِنها وَما يَنزِلُ مِنَ السَّماءِ وَما يَعرُجُ فيها وَهُوَ الرَّحيمُ الغَفورُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdcix{وَقالَ الَّذينَ كَفَروا لا تَأتينَا السّاعَةُ قُل بَلىٰ وَرَبّى لَتَأتِيَنَّكُم عٰلِمِ الغَيبِ لا يَعزُبُ عَنهُ مِثقالُ ذَرَّةٍ فِى السَّمٰوٰتِ وَلا فِى الأَرضِ وَلا أَصغَرُ مِن ذٰلِكَ وَلا أَكبَرُ إِلّا فى كِتٰبٍ مُبينٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdcx{لِيَجزِىَ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ أُولٰئِكَ لَهُم مَغفِرَةٌ وَرِزقٌ كَريمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdcxi{وَالَّذينَ سَعَو فى ءايٰتِنا مُعٰجِزينَ أُولٰئِكَ لَهُم عَذابٌ مِن رِجزٍ أَليمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdcxii{وَيَرَى الَّذينَ أوتُوا العِلمَ الَّذى أُنزِلَ إِلَيكَ مِن رَبِّكَ هُوَ الحَقَّ وَيَهدى إِلىٰ صِرٰطِ العَزيزِ الحَميدِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdcxiii{وَقالَ الَّذينَ كَفَروا هَل نَدُلُّكُم عَلىٰ رَجُلٍ يُنَبِّئُكُم إِذا مُزِّقتُم كُلَّ مُمَزَّقٍ إِنَّكُم لَفى خَلقٍ جَديدٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdcxiv{أَفتَرىٰ عَلَى اللَّهِ كَذِبًا أَم بِهِ جِنَّةٌ بَلِ الَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ فِى العَذابِ وَالضَّلٰلِ البَعيدِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdcxv{أَفَلَم يَرَوا إِلىٰ ما بَينَ أَيديهِم وَما خَلفَهُم مِنَ السَّماءِ وَالأَرضِ إِن نَشَأ نَخسِف بِهِمُ الأَرضَ أَو نُسقِط عَلَيهِم كِسَفًا مِنَ السَّماءِ إِنَّ فى ذٰلِكَ لَءايَةً لِكُلِّ عَبدٍ مُنيبٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdcxvi{وَلَقَد ءاتَينا داوۥدَ مِنّا فَضلًا يٰجِبالُ أَوِّبى مَعَهُ وَالطَّيرَ وَأَلَنّا لَهُ الحَديدَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdcxvii{أَنِ اعمَل سٰبِغٰتٍ وَقَدِّر فِى السَّردِ وَاعمَلوا صٰلِحًا إِنّى بِما تَعمَلونَ بَصيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdcxviii{وَلِسُلَيمٰنَ الرّيحَ غُدُوُّها شَهرٌ وَرَواحُها شَهرٌ وَأَسَلنا لَهُ عَينَ القِطرِ وَمِنَ الجِنِّ مَن يَعمَلُ بَينَ يَدَيهِ بِإِذنِ رَبِّهِ وَمَن يَزِغ مِنهُم عَن أَمرِنا نُذِقهُ مِن عَذابِ السَّعيرِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdcxix{يَعمَلونَ لَهُ ما يَشاءُ مِن مَحٰريبَ وَتَمٰثيلَ وَجِفانٍ كَالجَوابِ وَقُدورٍ راسِيٰتٍ اعمَلوا ءالَ داوۥدَ شُكرًا وَقَليلٌ مِن عِبادِىَ الشَّكورُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdcxx{فَلَمّا قَضَينا عَلَيهِ المَوتَ ما دَلَّهُم عَلىٰ مَوتِهِ إِلّا دابَّةُ الأَرضِ تَأكُلُ مِنسَأَتَهُ فَلَمّا خَرَّ تَبَيَّنَتِ الجِنُّ أَن لَو كانوا يَعلَمونَ الغَيبَ ما لَبِثوا فِى العَذابِ المُهينِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdcxxi{لَقَد كانَ لِسَبَإٍ فى مَسكَنِهِم ءايَةٌ جَنَّتانِ عَن يَمينٍ وَشِمالٍ كُلوا مِن رِزقِ رَبِّكُم وَاشكُروا لَهُ بَلدَةٌ طَيِّبَةٌ وَرَبٌّ غَفورٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdcxxii{فَأَعرَضوا فَأَرسَلنا عَلَيهِم سَيلَ العَرِمِ وَبَدَّلنٰهُم بِجَنَّتَيهِم جَنَّتَينِ ذَواتَى أُكُلٍ خَمطٍ وَأَثلٍ وَشَيءٍ مِن سِدرٍ قَليلٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdcxxiii{ذٰلِكَ جَزَينٰهُم بِما كَفَروا وَهَل نُجٰزى إِلَّا الكَفورَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdcxxiv{وَجَعَلنا بَينَهُم وَبَينَ القُرَى الَّتى بٰرَكنا فيها قُرًى ظٰهِرَةً وَقَدَّرنا فيهَا السَّيرَ سيروا فيها لَيالِىَ وَأَيّامًا ءامِنينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdcxxv{فَقالوا رَبَّنا بٰعِد بَينَ أَسفارِنا وَظَلَموا أَنفُسَهُم فَجَعَلنٰهُم أَحاديثَ وَمَزَّقنٰهُم كُلَّ مُمَزَّقٍ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِكُلِّ صَبّارٍ شَكورٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdcxxvi{وَلَقَد صَدَّقَ عَلَيهِم إِبليسُ ظَنَّهُ فَاتَّبَعوهُ إِلّا فَريقًا مِنَ المُؤمِنينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdcxxvii{وَما كانَ لَهُ عَلَيهِم مِن سُلطٰنٍ إِلّا لِنَعلَمَ مَن يُؤمِنُ بِالءاخِرَةِ مِمَّن هُوَ مِنها فى شَكٍّ وَرَبُّكَ عَلىٰ كُلِّ شَيءٍ حَفيظٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdcxxviii{قُلِ ادعُوا الَّذينَ زَعَمتُم مِن دونِ اللَّهِ لا يَملِكونَ مِثقالَ ذَرَّةٍ فِى السَّمٰوٰتِ وَلا فِى الأَرضِ وَما لَهُم فيهِما مِن شِركٍ وَما لَهُ مِنهُم مِن ظَهيرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdcxxix{وَلا تَنفَعُ الشَّفٰعَةُ عِندَهُ إِلّا لِمَن أَذِنَ لَهُ حَتّىٰ إِذا فُزِّعَ عَن قُلوبِهِم قالوا ماذا قالَ رَبُّكُم قالُوا الحَقَّ وَهُوَ العَلِىُّ الكَبيرُ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdcxxx{قُل مَن يَرزُقُكُم مِنَ السَّمٰوٰتِ وَالأَرضِ قُلِ اللَّهُ وَإِنّا أَو إِيّاكُم لَعَلىٰ هُدًى أَو فى ضَلٰلٍ مُبينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdcxxxi{قُل لا تُسـَٔلونَ عَمّا أَجرَمنا وَلا نُسـَٔلُ عَمّا تَعمَلونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdcxxxii{قُل يَجمَعُ بَينَنا رَبُّنا ثُمَّ يَفتَحُ بَينَنا بِالحَقِّ وَهُوَ الفَتّاحُ العَليمُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdcxxxiii{قُل أَرونِىَ الَّذينَ أَلحَقتُم بِهِ شُرَكاءَ كَلّا بَل هُوَ اللَّهُ العَزيزُ الحَكيمُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdcxxxiv{وَما أَرسَلنٰكَ إِلّا كافَّةً لِلنّاسِ بَشيرًا وَنَذيرًا وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdcxxxv{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صٰدِقينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcxxxvi{قُل لَكُم ميعادُ يَومٍ لا تَستَـٔخِرونَ عَنهُ ساعَةً وَلا تَستَقدِمونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcxxxvii{وَقالَ الَّذينَ كَفَروا لَن نُؤمِنَ بِهٰذَا القُرءانِ وَلا بِالَّذى بَينَ يَدَيهِ وَلَو تَرىٰ إِذِ الظّٰلِمونَ مَوقوفونَ عِندَ رَبِّهِم يَرجِعُ بَعضُهُم إِلىٰ بَعضٍ القَولَ يَقولُ الَّذينَ استُضعِفوا لِلَّذينَ استَكبَروا لَولا أَنتُم لَكُنّا مُؤمِنينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcxxxviii{قالَ الَّذينَ استَكبَروا لِلَّذينَ استُضعِفوا أَنَحنُ صَدَدنٰكُم عَنِ الهُدىٰ بَعدَ إِذ جاءَكُم بَل كُنتُم مُجرِمينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcxxxix{وَقالَ الَّذينَ استُضعِفوا لِلَّذينَ استَكبَروا بَل مَكرُ الَّيلِ وَالنَّهارِ إِذ تَأمُرونَنا أَن نَكفُرَ بِاللَّهِ وَنَجعَلَ لَهُ أَندادًا وَأَسَرُّوا النَّدامَةَ لَمّا رَأَوُا العَذابَ وَجَعَلنَا الأَغلٰلَ فى أَعناقِ الَّذينَ كَفَروا هَل يُجزَونَ إِلّا ما كانوا يَعمَلونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcxl{وَما أَرسَلنا فى قَريَةٍ مِن نَذيرٍ إِلّا قالَ مُترَفوها إِنّا بِما أُرسِلتُم بِهِ كٰفِرونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcxli{وَقالوا نَحنُ أَكثَرُ أَموٰلًا وَأَولٰدًا وَما نَحنُ بِمُعَذَّبينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcxlii{قُل إِنَّ رَبّى يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcxliii{وَما أَموٰلُكُم وَلا أَولٰدُكُم بِالَّتى تُقَرِّبُكُم عِندَنا زُلفىٰ إِلّا مَن ءامَنَ وَعَمِلَ صٰلِحًا فَأُولٰئِكَ لَهُم جَزاءُ الضِّعفِ بِما عَمِلوا وَهُم فِى الغُرُفٰتِ ءامِنونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcxliv{وَالَّذينَ يَسعَونَ فى ءايٰتِنا مُعٰجِزينَ أُولٰئِكَ فِى العَذابِ مُحضَرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcxlv{قُل إِنَّ رَبّى يَبسُطُ الرِّزقَ لِمَن يَشاءُ مِن عِبادِهِ وَيَقدِرُ لَهُ وَما أَنفَقتُم مِن شَيءٍ فَهُوَ يُخلِفُهُ وَهُوَ خَيرُ الرّٰزِقينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcxlvi{وَيَومَ يَحشُرُهُم جَميعًا ثُمَّ يَقولُ لِلمَلٰئِكَةِ أَهٰؤُلاءِ إِيّاكُم كانوا يَعبُدونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcxlvii{قالوا سُبحٰنَكَ أَنتَ وَلِيُّنا مِن دونِهِم بَل كانوا يَعبُدونَ الجِنَّ أَكثَرُهُم بِهِم مُؤمِنونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdcxlviii{فَاليَومَ لا يَملِكُ بَعضُكُم لِبَعضٍ نَفعًا وَلا ضَرًّا وَنَقولُ لِلَّذينَ ظَلَموا ذوقوا عَذابَ النّارِ الَّتى كُنتُم بِها تُكَذِّبونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcxlix{وَإِذا تُتلىٰ عَلَيهِم ءايٰتُنا بَيِّنٰتٍ قالوا ما هٰذا إِلّا رَجُلٌ يُريدُ أَن يَصُدَّكُم عَمّا كانَ يَعبُدُ ءاباؤُكُم وَقالوا ما هٰذا إِلّا إِفكٌ مُفتَرًى وَقالَ الَّذينَ كَفَروا لِلحَقِّ لَمّا جاءَهُم إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcl{وَما ءاتَينٰهُم مِن كُتُبٍ يَدرُسونَها وَما أَرسَلنا إِلَيهِم قَبلَكَ مِن نَذيرٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdcli{وَكَذَّبَ الَّذينَ مِن قَبلِهِم وَما بَلَغوا مِعشارَ ما ءاتَينٰهُم فَكَذَّبوا رُسُلى فَكَيفَ كانَ نَكيرِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdclii{قُل إِنَّما أَعِظُكُم بِوٰحِدَةٍ أَن تَقوموا لِلَّهِ مَثنىٰ وَفُرٰدىٰ ثُمَّ تَتَفَكَّروا ما بِصاحِبِكُم مِن جِنَّةٍ إِن هُوَ إِلّا نَذيرٌ لَكُم بَينَ يَدَى عَذابٍ شَديدٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcliii{قُل ما سَأَلتُكُم مِن أَجرٍ فَهُوَ لَكُم إِن أَجرِىَ إِلّا عَلَى اللَّهِ وَهُوَ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdcliv{قُل إِنَّ رَبّى يَقذِفُ بِالحَقِّ عَلّٰمُ الغُيوبِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdclv{قُل جاءَ الحَقُّ وَما يُبدِئُ البٰطِلُ وَما يُعيدُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdclvi{قُل إِن ضَلَلتُ فَإِنَّما أَضِلُّ عَلىٰ نَفسى وَإِنِ اهتَدَيتُ فَبِما يوحى إِلَىَّ رَبّى إِنَّهُ سَميعٌ قَريبٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdclvii{وَلَو تَرىٰ إِذ فَزِعوا فَلا فَوتَ وَأُخِذوا مِن مَكانٍ قَريبٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdclviii{وَقالوا ءامَنّا بِهِ وَأَنّىٰ لَهُمُ التَّناوُشُ مِن مَكانٍ بَعيدٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdclix{وَقَد كَفَروا بِهِ مِن قَبلُ وَيَقذِفونَ بِالغَيبِ مِن مَكانٍ بَعيدٍ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdclx{وَحيلَ بَينَهُم وَبَينَ ما يَشتَهونَ كَما فُعِلَ بِأَشياعِهِم مِن قَبلُ إِنَّهُم كانوا فى شَكٍّ مُريبٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdclxi{\basmalah  الحَمدُ لِلَّهِ فاطِرِ السَّمٰوٰتِ وَالأَرضِ جاعِلِ المَلٰئِكَةِ رُسُلًا أُولى أَجنِحَةٍ مَثنىٰ وَثُلٰثَ وَرُبٰعَ يَزيدُ فِى الخَلقِ ما يَشاءُ إِنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdclxii{ما يَفتَحِ اللَّهُ لِلنّاسِ مِن رَحمَةٍ فَلا مُمسِكَ لَها وَما يُمسِك فَلا مُرسِلَ لَهُ مِن بَعدِهِ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdclxiii{يٰأَيُّهَا النّاسُ اذكُروا نِعمَتَ اللَّهِ عَلَيكُم هَل مِن خٰلِقٍ غَيرُ اللَّهِ يَرزُقُكُم مِنَ السَّماءِ وَالأَرضِ لا إِلٰهَ إِلّا هُوَ فَأَنّىٰ تُؤفَكونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdclxiv{وَإِن يُكَذِّبوكَ فَقَد كُذِّبَت رُسُلٌ مِن قَبلِكَ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdclxv{يٰأَيُّهَا النّاسُ إِنَّ وَعدَ اللَّهِ حَقٌّ فَلا تَغُرَّنَّكُمُ الحَيوٰةُ الدُّنيا وَلا يَغُرَّنَّكُم بِاللَّهِ الغَرورُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdclxvi{إِنَّ الشَّيطٰنَ لَكُم عَدُوٌّ فَاتَّخِذوهُ عَدُوًّا إِنَّما يَدعوا حِزبَهُ لِيَكونوا مِن أَصحٰبِ السَّعيرِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdclxvii{الَّذينَ كَفَروا لَهُم عَذابٌ شَديدٌ وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَهُم مَغفِرَةٌ وَأَجرٌ كَبيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdclxviii{أَفَمَن زُيِّنَ لَهُ سوءُ عَمَلِهِ فَرَءاهُ حَسَنًا فَإِنَّ اللَّهَ يُضِلُّ مَن يَشاءُ وَيَهدى مَن يَشاءُ فَلا تَذهَب نَفسُكَ عَلَيهِم حَسَرٰتٍ إِنَّ اللَّهَ عَليمٌ بِما يَصنَعونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdclxix{وَاللَّهُ الَّذى أَرسَلَ الرِّيٰحَ فَتُثيرُ سَحابًا فَسُقنٰهُ إِلىٰ بَلَدٍ مَيِّتٍ فَأَحيَينا بِهِ الأَرضَ بَعدَ مَوتِها كَذٰلِكَ النُّشورُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdclxx{مَن كانَ يُريدُ العِزَّةَ فَلِلَّهِ العِزَّةُ جَميعًا إِلَيهِ يَصعَدُ الكَلِمُ الطَّيِّبُ وَالعَمَلُ الصّٰلِحُ يَرفَعُهُ وَالَّذينَ يَمكُرونَ السَّيِّـٔاتِ لَهُم عَذابٌ شَديدٌ وَمَكرُ أُولٰئِكَ هُوَ يَبورُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdclxxi{وَاللَّهُ خَلَقَكُم مِن تُرابٍ ثُمَّ مِن نُطفَةٍ ثُمَّ جَعَلَكُم أَزوٰجًا وَما تَحمِلُ مِن أُنثىٰ وَلا تَضَعُ إِلّا بِعِلمِهِ وَما يُعَمَّرُ مِن مُعَمَّرٍ وَلا يُنقَصُ مِن عُمُرِهِ إِلّا فى كِتٰبٍ إِنَّ ذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdclxxii{وَما يَستَوِى البَحرانِ هٰذا عَذبٌ فُراتٌ سائِغٌ شَرابُهُ وَهٰذا مِلحٌ أُجاجٌ وَمِن كُلٍّ تَأكُلونَ لَحمًا طَرِيًّا وَتَستَخرِجونَ حِليَةً تَلبَسونَها وَتَرَى الفُلكَ فيهِ مَواخِرَ لِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdclxxiii{يولِجُ الَّيلَ فِى النَّهارِ وَيولِجُ النَّهارَ فِى الَّيلِ وَسَخَّرَ الشَّمسَ وَالقَمَرَ كُلٌّ يَجرى لِأَجَلٍ مُسَمًّى ذٰلِكُمُ اللَّهُ رَبُّكُم لَهُ المُلكُ وَالَّذينَ تَدعونَ مِن دونِهِ ما يَملِكونَ مِن قِطميرٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdclxxiv{إِن تَدعوهُم لا يَسمَعوا دُعاءَكُم وَلَو سَمِعوا مَا استَجابوا لَكُم وَيَومَ القِيٰمَةِ يَكفُرونَ بِشِركِكُم وَلا يُنَبِّئُكَ مِثلُ خَبيرٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdclxxv{يٰأَيُّهَا النّاسُ أَنتُمُ الفُقَراءُ إِلَى اللَّهِ وَاللَّهُ هُوَ الغَنِىُّ الحَميدُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdclxxvi{إِن يَشَأ يُذهِبكُم وَيَأتِ بِخَلقٍ جَديدٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdclxxvii{وَما ذٰلِكَ عَلَى اللَّهِ بِعَزيزٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdclxxviii{وَلا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ وَإِن تَدعُ مُثقَلَةٌ إِلىٰ حِملِها لا يُحمَل مِنهُ شَيءٌ وَلَو كانَ ذا قُربىٰ إِنَّما تُنذِرُ الَّذينَ يَخشَونَ رَبَّهُم بِالغَيبِ وَأَقامُوا الصَّلوٰةَ وَمَن تَزَكّىٰ فَإِنَّما يَتَزَكّىٰ لِنَفسِهِ وَإِلَى اللَّهِ المَصيرُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdclxxix{وَما يَستَوِى الأَعمىٰ وَالبَصيرُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdclxxx{وَلَا الظُّلُمٰتُ وَلَا النّورُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdclxxxi{وَلَا الظِّلُّ وَلَا الحَرورُ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdclxxxii{وَما يَستَوِى الأَحياءُ وَلَا الأَموٰتُ إِنَّ اللَّهَ يُسمِعُ مَن يَشاءُ وَما أَنتَ بِمُسمِعٍ مَن فِى القُبورِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdclxxxiii{إِن أَنتَ إِلّا نَذيرٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdclxxxiv{إِنّا أَرسَلنٰكَ بِالحَقِّ بَشيرًا وَنَذيرًا وَإِن مِن أُمَّةٍ إِلّا خَلا فيها نَذيرٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdclxxxv{وَإِن يُكَذِّبوكَ فَقَد كَذَّبَ الَّذينَ مِن قَبلِهِم جاءَتهُم رُسُلُهُم بِالبَيِّنٰتِ وَبِالزُّبُرِ وَبِالكِتٰبِ المُنيرِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdclxxxvi{ثُمَّ أَخَذتُ الَّذينَ كَفَروا فَكَيفَ كانَ نَكيرِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdclxxxvii{أَلَم تَرَ أَنَّ اللَّهَ أَنزَلَ مِنَ السَّماءِ ماءً فَأَخرَجنا بِهِ ثَمَرٰتٍ مُختَلِفًا أَلوٰنُها وَمِنَ الجِبالِ جُدَدٌ بيضٌ وَحُمرٌ مُختَلِفٌ أَلوٰنُها وَغَرابيبُ سودٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdclxxxviii{وَمِنَ النّاسِ وَالدَّوابِّ وَالأَنعٰمِ مُختَلِفٌ أَلوٰنُهُ كَذٰلِكَ إِنَّما يَخشَى اللَّهَ مِن عِبادِهِ العُلَمٰؤُا۟ إِنَّ اللَّهَ عَزيزٌ غَفورٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdclxxxix{إِنَّ الَّذينَ يَتلونَ كِتٰبَ اللَّهِ وَأَقامُوا الصَّلوٰةَ وَأَنفَقوا مِمّا رَزَقنٰهُم سِرًّا وَعَلانِيَةً يَرجونَ تِجٰرَةً لَن تَبورَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcxc{لِيُوَفِّيَهُم أُجورَهُم وَيَزيدَهُم مِن فَضلِهِ إِنَّهُ غَفورٌ شَكورٌ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcxci{وَالَّذى أَوحَينا إِلَيكَ مِنَ الكِتٰبِ هُوَ الحَقُّ مُصَدِّقًا لِما بَينَ يَدَيهِ إِنَّ اللَّهَ بِعِبادِهِ لَخَبيرٌ بَصيرٌ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcxcii{ثُمَّ أَورَثنَا الكِتٰبَ الَّذينَ اصطَفَينا مِن عِبادِنا فَمِنهُم ظالِمٌ لِنَفسِهِ وَمِنهُم مُقتَصِدٌ وَمِنهُم سابِقٌ بِالخَيرٰتِ بِإِذنِ اللَّهِ ذٰلِكَ هُوَ الفَضلُ الكَبيرُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcxciii{جَنّٰتُ عَدنٍ يَدخُلونَها يُحَلَّونَ فيها مِن أَساوِرَ مِن ذَهَبٍ وَلُؤلُؤًا وَلِباسُهُم فيها حَريرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcxciv{وَقالُوا الحَمدُ لِلَّهِ الَّذى أَذهَبَ عَنَّا الحَزَنَ إِنَّ رَبَّنا لَغَفورٌ شَكورٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcxcv{الَّذى أَحَلَّنا دارَ المُقامَةِ مِن فَضلِهِ لا يَمَسُّنا فيها نَصَبٌ وَلا يَمَسُّنا فيها لُغوبٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcxcvi{وَالَّذينَ كَفَروا لَهُم نارُ جَهَنَّمَ لا يُقضىٰ عَلَيهِم فَيَموتوا وَلا يُخَفَّفُ عَنهُم مِن عَذابِها كَذٰلِكَ نَجزى كُلَّ كَفورٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcxcvii{وَهُم يَصطَرِخونَ فيها رَبَّنا أَخرِجنا نَعمَل صٰلِحًا غَيرَ الَّذى كُنّا نَعمَلُ أَوَلَم نُعَمِّركُم ما يَتَذَكَّرُ فيهِ مَن تَذَكَّرَ وَجاءَكُمُ النَّذيرُ فَذوقوا فَما لِلظّٰلِمينَ مِن نَصيرٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcxcviii{إِنَّ اللَّهَ عٰلِمُ غَيبِ السَّمٰوٰتِ وَالأَرضِ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcxcix{هُوَ الَّذى جَعَلَكُم خَلٰئِفَ فِى الأَرضِ فَمَن كَفَرَ فَعَلَيهِ كُفرُهُ وَلا يَزيدُ الكٰفِرينَ كُفرُهُم عِندَ رَبِّهِم إِلّا مَقتًا وَلا يَزيدُ الكٰفِرينَ كُفرُهُم إِلّا خَسارًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcc{قُل أَرَءَيتُم شُرَكاءَكُمُ الَّذينَ تَدعونَ مِن دونِ اللَّهِ أَرونى ماذا خَلَقوا مِنَ الأَرضِ أَم لَهُم شِركٌ فِى السَّمٰوٰتِ أَم ءاتَينٰهُم كِتٰبًا فَهُم عَلىٰ بَيِّنَتٍ مِنهُ بَل إِن يَعِدُ الظّٰلِمونَ بَعضُهُم بَعضًا إِلّا غُرورًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcci{إِنَّ اللَّهَ يُمسِكُ السَّمٰوٰتِ وَالأَرضَ أَن تَزولا وَلَئِن زالَتا إِن أَمسَكَهُما مِن أَحَدٍ مِن بَعدِهِ إِنَّهُ كانَ حَليمًا غَفورًا\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdccii{وَأَقسَموا بِاللَّهِ جَهدَ أَيمٰنِهِم لَئِن جاءَهُم نَذيرٌ لَيَكونُنَّ أَهدىٰ مِن إِحدَى الأُمَمِ فَلَمّا جاءَهُم نَذيرٌ ما زادَهُم إِلّا نُفورًا\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcciii{استِكبارًا فِى الأَرضِ وَمَكرَ السَّيِّئِ وَلا يَحيقُ المَكرُ السَّيِّئُ إِلّا بِأَهلِهِ فَهَل يَنظُرونَ إِلّا سُنَّتَ الأَوَّلينَ فَلَن تَجِدَ لِسُنَّتِ اللَّهِ تَبديلًا وَلَن تَجِدَ لِسُنَّتِ اللَّهِ تَحويلًا\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcciv{أَوَلَم يَسيروا فِى الأَرضِ فَيَنظُروا كَيفَ كانَ عٰقِبَةُ الَّذينَ مِن قَبلِهِم وَكانوا أَشَدَّ مِنهُم قُوَّةً وَما كانَ اللَّهُ لِيُعجِزَهُ مِن شَيءٍ فِى السَّمٰوٰتِ وَلا فِى الأَرضِ إِنَّهُ كانَ عَليمًا قَديرًا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdccv{وَلَو يُؤاخِذُ اللَّهُ النّاسَ بِما كَسَبوا ما تَرَكَ عَلىٰ ظَهرِها مِن دابَّةٍ وَلٰكِن يُؤَخِّرُهُم إِلىٰ أَجَلٍ مُسَمًّى فَإِذا جاءَ أَجَلُهُم فَإِنَّ اللَّهَ كانَ بِعِبادِهِ بَصيرًا\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdccvi{\basmalah  يس\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdccvii{وَالقُرءانِ الحَكيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdccviii{إِنَّكَ لَمِنَ المُرسَلينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdccix{عَلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdccx{تَنزيلَ العَزيزِ الرَّحيمِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdccxi{لِتُنذِرَ قَومًا ما أُنذِرَ ءاباؤُهُم فَهُم غٰفِلونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdccxii{لَقَد حَقَّ القَولُ عَلىٰ أَكثَرِهِم فَهُم لا يُؤمِنونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdccxiii{إِنّا جَعَلنا فى أَعنٰقِهِم أَغلٰلًا فَهِىَ إِلَى الأَذقانِ فَهُم مُقمَحونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdccxiv{وَجَعَلنا مِن بَينِ أَيديهِم سَدًّا وَمِن خَلفِهِم سَدًّا فَأَغشَينٰهُم فَهُم لا يُبصِرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdccxv{وَسَواءٌ عَلَيهِم ءَأَنذَرتَهُم أَم لَم تُنذِرهُم لا يُؤمِنونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdccxvi{إِنَّما تُنذِرُ مَنِ اتَّبَعَ الذِّكرَ وَخَشِىَ الرَّحمٰنَ بِالغَيبِ فَبَشِّرهُ بِمَغفِرَةٍ وَأَجرٍ كَريمٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdccxvii{إِنّا نَحنُ نُحىِ المَوتىٰ وَنَكتُبُ ما قَدَّموا وَءاثٰرَهُم وَكُلَّ شَيءٍ أَحصَينٰهُ فى إِمامٍ مُبينٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdccxviii{وَاضرِب لَهُم مَثَلًا أَصحٰبَ القَريَةِ إِذ جاءَهَا المُرسَلونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdccxix{إِذ أَرسَلنا إِلَيهِمُ اثنَينِ فَكَذَّبوهُما فَعَزَّزنا بِثالِثٍ فَقالوا إِنّا إِلَيكُم مُرسَلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdccxx{قالوا ما أَنتُم إِلّا بَشَرٌ مِثلُنا وَما أَنزَلَ الرَّحمٰنُ مِن شَيءٍ إِن أَنتُم إِلّا تَكذِبونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdccxxi{قالوا رَبُّنا يَعلَمُ إِنّا إِلَيكُم لَمُرسَلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdccxxii{وَما عَلَينا إِلَّا البَلٰغُ المُبينُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdccxxiii{قالوا إِنّا تَطَيَّرنا بِكُم لَئِن لَم تَنتَهوا لَنَرجُمَنَّكُم وَلَيَمَسَّنَّكُم مِنّا عَذابٌ أَليمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdccxxiv{قالوا طٰئِرُكُم مَعَكُم أَئِن ذُكِّرتُم بَل أَنتُم قَومٌ مُسرِفونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdccxxv{وَجاءَ مِن أَقصَا المَدينَةِ رَجُلٌ يَسعىٰ قالَ يٰقَومِ اتَّبِعُوا المُرسَلينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdccxxvi{اتَّبِعوا مَن لا يَسـَٔلُكُم أَجرًا وَهُم مُهتَدونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdccxxvii{وَما لِىَ لا أَعبُدُ الَّذى فَطَرَنى وَإِلَيهِ تُرجَعونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdccxxviii{ءَأَتَّخِذُ مِن دونِهِ ءالِهَةً إِن يُرِدنِ الرَّحمٰنُ بِضُرٍّ لا تُغنِ عَنّى شَفٰعَتُهُم شَيـًٔا وَلا يُنقِذونِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdccxxix{إِنّى إِذًا لَفى ضَلٰلٍ مُبينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdccxxx{إِنّى ءامَنتُ بِرَبِّكُم فَاسمَعونِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdccxxxi{قيلَ ادخُلِ الجَنَّةَ قالَ يٰلَيتَ قَومى يَعلَمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdccxxxii{بِما غَفَرَ لى رَبّى وَجَعَلَنى مِنَ المُكرَمينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdccxxxiii{وَما أَنزَلنا عَلىٰ قَومِهِ مِن بَعدِهِ مِن جُندٍ مِنَ السَّماءِ وَما كُنّا مُنزِلينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdccxxxiv{إِن كانَت إِلّا صَيحَةً وٰحِدَةً فَإِذا هُم خٰمِدونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdccxxxv{يٰحَسرَةً عَلَى العِبادِ ما يَأتيهِم مِن رَسولٍ إِلّا كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdccxxxvi{أَلَم يَرَوا كَم أَهلَكنا قَبلَهُم مِنَ القُرونِ أَنَّهُم إِلَيهِم لا يَرجِعونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdccxxxvii{وَإِن كُلٌّ لَمّا جَميعٌ لَدَينا مُحضَرونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdccxxxviii{وَءايَةٌ لَهُمُ الأَرضُ المَيتَةُ أَحيَينٰها وَأَخرَجنا مِنها حَبًّا فَمِنهُ يَأكُلونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdccxxxix{وَجَعَلنا فيها جَنّٰتٍ مِن نَخيلٍ وَأَعنٰبٍ وَفَجَّرنا فيها مِنَ العُيونِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdccxl{لِيَأكُلوا مِن ثَمَرِهِ وَما عَمِلَتهُ أَيديهِم أَفَلا يَشكُرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdccxli{سُبحٰنَ الَّذى خَلَقَ الأَزوٰجَ كُلَّها مِمّا تُنبِتُ الأَرضُ وَمِن أَنفُسِهِم وَمِمّا لا يَعلَمونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdccxlii{وَءايَةٌ لَهُمُ الَّيلُ نَسلَخُ مِنهُ النَّهارَ فَإِذا هُم مُظلِمونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdccxliii{وَالشَّمسُ تَجرى لِمُستَقَرٍّ لَها ذٰلِكَ تَقديرُ العَزيزِ العَليمِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdccxliv{وَالقَمَرَ قَدَّرنٰهُ مَنازِلَ حَتّىٰ عادَ كَالعُرجونِ القَديمِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdccxlv{لَا الشَّمسُ يَنبَغى لَها أَن تُدرِكَ القَمَرَ وَلَا الَّيلُ سابِقُ النَّهارِ وَكُلٌّ فى فَلَكٍ يَسبَحونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdccxlvi{وَءايَةٌ لَهُم أَنّا حَمَلنا ذُرِّيَّتَهُم فِى الفُلكِ المَشحونِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdccxlvii{وَخَلَقنا لَهُم مِن مِثلِهِ ما يَركَبونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdccxlviii{وَإِن نَشَأ نُغرِقهُم فَلا صَريخَ لَهُم وَلا هُم يُنقَذونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdccxlix{إِلّا رَحمَةً مِنّا وَمَتٰعًا إِلىٰ حينٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdccl{وَإِذا قيلَ لَهُمُ اتَّقوا ما بَينَ أَيديكُم وَما خَلفَكُم لَعَلَّكُم تُرحَمونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdccli{وَما تَأتيهِم مِن ءايَةٍ مِن ءايٰتِ رَبِّهِم إِلّا كانوا عَنها مُعرِضينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcclii{وَإِذا قيلَ لَهُم أَنفِقوا مِمّا رَزَقَكُمُ اللَّهُ قالَ الَّذينَ كَفَروا لِلَّذينَ ءامَنوا أَنُطعِمُ مَن لَو يَشاءُ اللَّهُ أَطعَمَهُ إِن أَنتُم إِلّا فى ضَلٰلٍ مُبينٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdccliii{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صٰدِقينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdccliv{ما يَنظُرونَ إِلّا صَيحَةً وٰحِدَةً تَأخُذُهُم وَهُم يَخِصِّمونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdcclv{فَلا يَستَطيعونَ تَوصِيَةً وَلا إِلىٰ أَهلِهِم يَرجِعونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdcclvi{وَنُفِخَ فِى الصّورِ فَإِذا هُم مِنَ الأَجداثِ إِلىٰ رَبِّهِم يَنسِلونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdcclvii{قالوا يٰوَيلَنا مَن بَعَثَنا مِن مَرقَدِنا هٰذا ما وَعَدَ الرَّحمٰنُ وَصَدَقَ المُرسَلونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdcclviii{إِن كانَت إِلّا صَيحَةً وٰحِدَةً فَإِذا هُم جَميعٌ لَدَينا مُحضَرونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdcclix{فَاليَومَ لا تُظلَمُ نَفسٌ شَيـًٔا وَلا تُجزَونَ إِلّا ما كُنتُم تَعمَلونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdcclx{إِنَّ أَصحٰبَ الجَنَّةِ اليَومَ فى شُغُلٍ فٰكِهونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdcclxi{هُم وَأَزوٰجُهُم فى ظِلٰلٍ عَلَى الأَرائِكِ مُتَّكِـٔونَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdcclxii{لَهُم فيها فٰكِهَةٌ وَلَهُم ما يَدَّعونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdcclxiii{سَلٰمٌ قَولًا مِن رَبٍّ رَحيمٍ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdcclxiv{وَامتٰزُوا اليَومَ أَيُّهَا المُجرِمونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdcclxv{أَلَم أَعهَد إِلَيكُم يٰبَنى ءادَمَ أَن لا تَعبُدُوا الشَّيطٰنَ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdcclxvi{وَأَنِ اعبُدونى هٰذا صِرٰطٌ مُستَقيمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdcclxvii{وَلَقَد أَضَلَّ مِنكُم جِبِلًّا كَثيرًا أَفَلَم تَكونوا تَعقِلونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdcclxviii{هٰذِهِ جَهَنَّمُ الَّتى كُنتُم توعَدونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdcclxix{اصلَوهَا اليَومَ بِما كُنتُم تَكفُرونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdcclxx{اليَومَ نَختِمُ عَلىٰ أَفوٰهِهِم وَتُكَلِّمُنا أَيديهِم وَتَشهَدُ أَرجُلُهُم بِما كانوا يَكسِبونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdcclxxi{وَلَو نَشاءُ لَطَمَسنا عَلىٰ أَعيُنِهِم فَاستَبَقُوا الصِّرٰطَ فَأَنّىٰ يُبصِرونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdcclxxii{وَلَو نَشاءُ لَمَسَخنٰهُم عَلىٰ مَكانَتِهِم فَمَا استَطٰعوا مُضِيًّا وَلا يَرجِعونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdcclxxiii{وَمَن نُعَمِّرهُ نُنَكِّسهُ فِى الخَلقِ أَفَلا يَعقِلونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdcclxxiv{وَما عَلَّمنٰهُ الشِّعرَ وَما يَنبَغى لَهُ إِن هُوَ إِلّا ذِكرٌ وَقُرءانٌ مُبينٌ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdcclxxv{لِيُنذِرَ مَن كانَ حَيًّا وَيَحِقَّ القَولُ عَلَى الكٰفِرينَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdcclxxvi{أَوَلَم يَرَوا أَنّا خَلَقنا لَهُم مِمّا عَمِلَت أَيدينا أَنعٰمًا فَهُم لَها مٰلِكونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdcclxxvii{وَذَلَّلنٰها لَهُم فَمِنها رَكوبُهُم وَمِنها يَأكُلونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdcclxxviii{وَلَهُم فيها مَنٰفِعُ وَمَشارِبُ أَفَلا يَشكُرونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdcclxxix{وَاتَّخَذوا مِن دونِ اللَّهِ ءالِهَةً لَعَلَّهُم يُنصَرونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmdcclxxx{لا يَستَطيعونَ نَصرَهُم وَهُم لَهُم جُندٌ مُحضَرونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmdcclxxxi{فَلا يَحزُنكَ قَولُهُم إِنّا نَعلَمُ ما يُسِرّونَ وَما يُعلِنونَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmdcclxxxii{أَوَلَم يَرَ الإِنسٰنُ أَنّا خَلَقنٰهُ مِن نُطفَةٍ فَإِذا هُوَ خَصيمٌ مُبينٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmdcclxxxiii{وَضَرَبَ لَنا مَثَلًا وَنَسِىَ خَلقَهُ قالَ مَن يُحىِ العِظٰمَ وَهِىَ رَميمٌ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmdcclxxxiv{قُل يُحييهَا الَّذى أَنشَأَها أَوَّلَ مَرَّةٍ وَهُوَ بِكُلِّ خَلقٍ عَليمٌ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmdcclxxxv{الَّذى جَعَلَ لَكُم مِنَ الشَّجَرِ الأَخضَرِ نارًا فَإِذا أَنتُم مِنهُ توقِدونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmdcclxxxvi{أَوَلَيسَ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ بِقٰدِرٍ عَلىٰ أَن يَخلُقَ مِثلَهُم بَلىٰ وَهُوَ الخَلّٰقُ العَليمُ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmdcclxxxvii{إِنَّما أَمرُهُ إِذا أَرادَ شَيـًٔا أَن يَقولَ لَهُ كُن فَيَكونُ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmdcclxxxviii{فَسُبحٰنَ الَّذى بِيَدِهِ مَلَكوتُ كُلِّ شَيءٍ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmdcclxxxix{\basmalah  وَالصّٰفّٰتِ صَفًّا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmdccxc{فَالزّٰجِرٰتِ زَجرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmdccxci{فَالتّٰلِيٰتِ ذِكرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmdccxcii{إِنَّ إِلٰهَكُم لَوٰحِدٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmdccxciii{رَبُّ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُما وَرَبُّ المَشٰرِقِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmdccxciv{إِنّا زَيَّنَّا السَّماءَ الدُّنيا بِزينَةٍ الكَواكِبِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmdccxcv{وَحِفظًا مِن كُلِّ شَيطٰنٍ مارِدٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmdccxcvi{لا يَسَّمَّعونَ إِلَى المَلَإِ الأَعلىٰ وَيُقذَفونَ مِن كُلِّ جانِبٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmdccxcvii{دُحورًا وَلَهُم عَذابٌ واصِبٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmdccxcviii{إِلّا مَن خَطِفَ الخَطفَةَ فَأَتبَعَهُ شِهابٌ ثاقِبٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmdccxcix{فَاستَفتِهِم أَهُم أَشَدُّ خَلقًا أَم مَن خَلَقنا إِنّا خَلَقنٰهُم مِن طينٍ لازِبٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmdccc{بَل عَجِبتَ وَيَسخَرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmdccci{وَإِذا ذُكِّروا لا يَذكُرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmdcccii{وَإِذا رَأَوا ءايَةً يَستَسخِرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmdccciii{وَقالوا إِن هٰذا إِلّا سِحرٌ مُبينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmdccciv{أَءِذا مِتنا وَكُنّا تُرابًا وَعِظٰمًا أَءِنّا لَمَبعوثونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmdcccv{أَوَءاباؤُنَا الأَوَّلونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmdcccvi{قُل نَعَم وَأَنتُم دٰخِرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmdcccvii{فَإِنَّما هِىَ زَجرَةٌ وٰحِدَةٌ فَإِذا هُم يَنظُرونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmdcccviii{وَقالوا يٰوَيلَنا هٰذا يَومُ الدّينِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmdcccix{هٰذا يَومُ الفَصلِ الَّذى كُنتُم بِهِ تُكَذِّبونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmdcccx{احشُرُوا الَّذينَ ظَلَموا وَأَزوٰجَهُم وَما كانوا يَعبُدونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmdcccxi{مِن دونِ اللَّهِ فَاهدوهُم إِلىٰ صِرٰطِ الجَحيمِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmdcccxii{وَقِفوهُم إِنَّهُم مَسـٔولونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmdcccxiii{ما لَكُم لا تَناصَرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmdcccxiv{بَل هُمُ اليَومَ مُستَسلِمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmdcccxv{وَأَقبَلَ بَعضُهُم عَلىٰ بَعضٍ يَتَساءَلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmdcccxvi{قالوا إِنَّكُم كُنتُم تَأتونَنا عَنِ اليَمينِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmdcccxvii{قالوا بَل لَم تَكونوا مُؤمِنينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmdcccxviii{وَما كانَ لَنا عَلَيكُم مِن سُلطٰنٍ بَل كُنتُم قَومًا طٰغينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmdcccxix{فَحَقَّ عَلَينا قَولُ رَبِّنا إِنّا لَذائِقونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmdcccxx{فَأَغوَينٰكُم إِنّا كُنّا غٰوينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmdcccxxi{فَإِنَّهُم يَومَئِذٍ فِى العَذابِ مُشتَرِكونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmdcccxxii{إِنّا كَذٰلِكَ نَفعَلُ بِالمُجرِمينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmdcccxxiii{إِنَّهُم كانوا إِذا قيلَ لَهُم لا إِلٰهَ إِلَّا اللَّهُ يَستَكبِرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmdcccxxiv{وَيَقولونَ أَئِنّا لَتارِكوا ءالِهَتِنا لِشاعِرٍ مَجنونٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmdcccxxv{بَل جاءَ بِالحَقِّ وَصَدَّقَ المُرسَلينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmdcccxxvi{إِنَّكُم لَذائِقُوا العَذابِ الأَليمِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmdcccxxvii{وَما تُجزَونَ إِلّا ما كُنتُم تَعمَلونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmdcccxxviii{إِلّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmdcccxxix{أُولٰئِكَ لَهُم رِزقٌ مَعلومٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmdcccxxx{فَوٰكِهُ وَهُم مُكرَمونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmdcccxxxi{فى جَنّٰتِ النَّعيمِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmdcccxxxii{عَلىٰ سُرُرٍ مُتَقٰبِلينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmdcccxxxiii{يُطافُ عَلَيهِم بِكَأسٍ مِن مَعينٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmdcccxxxiv{بَيضاءَ لَذَّةٍ لِلشّٰرِبينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmdcccxxxv{لا فيها غَولٌ وَلا هُم عَنها يُنزَفونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmdcccxxxvi{وَعِندَهُم قٰصِرٰتُ الطَّرفِ عينٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmdcccxxxvii{كَأَنَّهُنَّ بَيضٌ مَكنونٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmdcccxxxviii{فَأَقبَلَ بَعضُهُم عَلىٰ بَعضٍ يَتَساءَلونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmdcccxxxix{قالَ قائِلٌ مِنهُم إِنّى كانَ لى قَرينٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmdcccxl{يَقولُ أَءِنَّكَ لَمِنَ المُصَدِّقينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmdcccxli{أَءِذا مِتنا وَكُنّا تُرابًا وَعِظٰمًا أَءِنّا لَمَدينونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmdcccxlii{قالَ هَل أَنتُم مُطَّلِعونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmdcccxliii{فَاطَّلَعَ فَرَءاهُ فى سَواءِ الجَحيمِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmdcccxliv{قالَ تَاللَّهِ إِن كِدتَ لَتُردينِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmdcccxlv{وَلَولا نِعمَةُ رَبّى لَكُنتُ مِنَ المُحضَرينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmdcccxlvi{أَفَما نَحنُ بِمَيِّتينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmdcccxlvii{إِلّا مَوتَتَنَا الأولىٰ وَما نَحنُ بِمُعَذَّبينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmdcccxlviii{إِنَّ هٰذا لَهُوَ الفَوزُ العَظيمُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmdcccxlix{لِمِثلِ هٰذا فَليَعمَلِ العٰمِلونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmdcccl{أَذٰلِكَ خَيرٌ نُزُلًا أَم شَجَرَةُ الزَّقّومِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmdcccli{إِنّا جَعَلنٰها فِتنَةً لِلظّٰلِمينَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmdccclii{إِنَّها شَجَرَةٌ تَخرُجُ فى أَصلِ الجَحيمِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmdcccliii{طَلعُها كَأَنَّهُ رُءوسُ الشَّيٰطينِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmdcccliv{فَإِنَّهُم لَءاكِلونَ مِنها فَمالِـٔونَ مِنهَا البُطونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmdccclv{ثُمَّ إِنَّ لَهُم عَلَيها لَشَوبًا مِن حَميمٍ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmdccclvi{ثُمَّ إِنَّ مَرجِعَهُم لَإِلَى الجَحيمِ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmdccclvii{إِنَّهُم أَلفَوا ءاباءَهُم ضالّينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmdccclviii{فَهُم عَلىٰ ءاثٰرِهِم يُهرَعونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmdccclix{وَلَقَد ضَلَّ قَبلَهُم أَكثَرُ الأَوَّلينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmdccclx{وَلَقَد أَرسَلنا فيهِم مُنذِرينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmdccclxi{فَانظُر كَيفَ كانَ عٰقِبَةُ المُنذَرينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmdccclxii{إِلّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmdccclxiii{وَلَقَد نادىٰنا نوحٌ فَلَنِعمَ المُجيبونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmdccclxiv{وَنَجَّينٰهُ وَأَهلَهُ مِنَ الكَربِ العَظيمِ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmdccclxv{وَجَعَلنا ذُرِّيَّتَهُ هُمُ الباقينَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmdccclxvi{وَتَرَكنا عَلَيهِ فِى الءاخِرينَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmdccclxvii{سَلٰمٌ عَلىٰ نوحٍ فِى العٰلَمينَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmdccclxviii{إِنّا كَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmdccclxix{إِنَّهُ مِن عِبادِنَا المُؤمِنينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmdccclxx{ثُمَّ أَغرَقنَا الءاخَرينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmdccclxxi{وَإِنَّ مِن شيعَتِهِ لَإِبرٰهيمَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmdccclxxii{إِذ جاءَ رَبَّهُ بِقَلبٍ سَليمٍ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmdccclxxiii{إِذ قالَ لِأَبيهِ وَقَومِهِ ماذا تَعبُدونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmdccclxxiv{أَئِفكًا ءالِهَةً دونَ اللَّهِ تُريدونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmdccclxxv{فَما ظَنُّكُم بِرَبِّ العٰلَمينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmdccclxxvi{فَنَظَرَ نَظرَةً فِى النُّجومِ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmdccclxxvii{فَقالَ إِنّى سَقيمٌ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmdccclxxviii{فَتَوَلَّوا عَنهُ مُدبِرينَ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmdccclxxix{فَراغَ إِلىٰ ءالِهَتِهِم فَقالَ أَلا تَأكُلونَ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmdccclxxx{ما لَكُم لا تَنطِقونَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmdccclxxxi{فَراغَ عَلَيهِم ضَربًا بِاليَمينِ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmdccclxxxii{فَأَقبَلوا إِلَيهِ يَزِفّونَ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmdccclxxxiii{قالَ أَتَعبُدونَ ما تَنحِتونَ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmdccclxxxiv{وَاللَّهُ خَلَقَكُم وَما تَعمَلونَ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmdccclxxxv{قالُوا ابنوا لَهُ بُنيٰنًا فَأَلقوهُ فِى الجَحيمِ\qt@no{﴿٩٧﴾}}
\qt@newcmd\qurantext@mmmdccclxxxvi{فَأَرادوا بِهِ كَيدًا فَجَعَلنٰهُمُ الأَسفَلينَ\qt@no{﴿٩٨﴾}}
\qt@newcmd\qurantext@mmmdccclxxxvii{وَقالَ إِنّى ذاهِبٌ إِلىٰ رَبّى سَيَهدينِ\qt@no{﴿٩٩﴾}}
\qt@newcmd\qurantext@mmmdccclxxxviii{رَبِّ هَب لى مِنَ الصّٰلِحينَ\qt@no{﴿١٠٠﴾}}
\qt@newcmd\qurantext@mmmdccclxxxix{فَبَشَّرنٰهُ بِغُلٰمٍ حَليمٍ\qt@no{﴿١٠١﴾}}
\qt@newcmd\qurantext@mmmdcccxc{فَلَمّا بَلَغَ مَعَهُ السَّعىَ قالَ يٰبُنَىَّ إِنّى أَرىٰ فِى المَنامِ أَنّى أَذبَحُكَ فَانظُر ماذا تَرىٰ قالَ يٰأَبَتِ افعَل ما تُؤمَرُ سَتَجِدُنى إِن شاءَ اللَّهُ مِنَ الصّٰبِرينَ\qt@no{﴿١٠٢﴾}}
\qt@newcmd\qurantext@mmmdcccxci{فَلَمّا أَسلَما وَتَلَّهُ لِلجَبينِ\qt@no{﴿١٠٣﴾}}
\qt@newcmd\qurantext@mmmdcccxcii{وَنٰدَينٰهُ أَن يٰإِبرٰهيمُ\qt@no{﴿١٠٤﴾}}
\qt@newcmd\qurantext@mmmdcccxciii{قَد صَدَّقتَ الرُّءيا إِنّا كَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿١٠٥﴾}}
\qt@newcmd\qurantext@mmmdcccxciv{إِنَّ هٰذا لَهُوَ البَلٰؤُا۟ المُبينُ\qt@no{﴿١٠٦﴾}}
\qt@newcmd\qurantext@mmmdcccxcv{وَفَدَينٰهُ بِذِبحٍ عَظيمٍ\qt@no{﴿١٠٧﴾}}
\qt@newcmd\qurantext@mmmdcccxcvi{وَتَرَكنا عَلَيهِ فِى الءاخِرينَ\qt@no{﴿١٠٨﴾}}
\qt@newcmd\qurantext@mmmdcccxcvii{سَلٰمٌ عَلىٰ إِبرٰهيمَ\qt@no{﴿١٠٩﴾}}
\qt@newcmd\qurantext@mmmdcccxcviii{كَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿١١٠﴾}}
\qt@newcmd\qurantext@mmmdcccxcix{إِنَّهُ مِن عِبادِنَا المُؤمِنينَ\qt@no{﴿١١١﴾}}
\qt@newcmd\qurantext@mmmcm{وَبَشَّرنٰهُ بِإِسحٰقَ نَبِيًّا مِنَ الصّٰلِحينَ\qt@no{﴿١١٢﴾}}
\qt@newcmd\qurantext@mmmcmi{وَبٰرَكنا عَلَيهِ وَعَلىٰ إِسحٰقَ وَمِن ذُرِّيَّتِهِما مُحسِنٌ وَظالِمٌ لِنَفسِهِ مُبينٌ\qt@no{﴿١١٣﴾}}
\qt@newcmd\qurantext@mmmcmii{وَلَقَد مَنَنّا عَلىٰ موسىٰ وَهٰرونَ\qt@no{﴿١١٤﴾}}
\qt@newcmd\qurantext@mmmcmiii{وَنَجَّينٰهُما وَقَومَهُما مِنَ الكَربِ العَظيمِ\qt@no{﴿١١٥﴾}}
\qt@newcmd\qurantext@mmmcmiv{وَنَصَرنٰهُم فَكانوا هُمُ الغٰلِبينَ\qt@no{﴿١١٦﴾}}
\qt@newcmd\qurantext@mmmcmv{وَءاتَينٰهُمَا الكِتٰبَ المُستَبينَ\qt@no{﴿١١٧﴾}}
\qt@newcmd\qurantext@mmmcmvi{وَهَدَينٰهُمَا الصِّرٰطَ المُستَقيمَ\qt@no{﴿١١٨﴾}}
\qt@newcmd\qurantext@mmmcmvii{وَتَرَكنا عَلَيهِما فِى الءاخِرينَ\qt@no{﴿١١٩﴾}}
\qt@newcmd\qurantext@mmmcmviii{سَلٰمٌ عَلىٰ موسىٰ وَهٰرونَ\qt@no{﴿١٢٠﴾}}
\qt@newcmd\qurantext@mmmcmix{إِنّا كَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿١٢١﴾}}
\qt@newcmd\qurantext@mmmcmx{إِنَّهُما مِن عِبادِنَا المُؤمِنينَ\qt@no{﴿١٢٢﴾}}
\qt@newcmd\qurantext@mmmcmxi{وَإِنَّ إِلياسَ لَمِنَ المُرسَلينَ\qt@no{﴿١٢٣﴾}}
\qt@newcmd\qurantext@mmmcmxii{إِذ قالَ لِقَومِهِ أَلا تَتَّقونَ\qt@no{﴿١٢٤﴾}}
\qt@newcmd\qurantext@mmmcmxiii{أَتَدعونَ بَعلًا وَتَذَرونَ أَحسَنَ الخٰلِقينَ\qt@no{﴿١٢٥﴾}}
\qt@newcmd\qurantext@mmmcmxiv{اللَّهَ رَبَّكُم وَرَبَّ ءابائِكُمُ الأَوَّلينَ\qt@no{﴿١٢٦﴾}}
\qt@newcmd\qurantext@mmmcmxv{فَكَذَّبوهُ فَإِنَّهُم لَمُحضَرونَ\qt@no{﴿١٢٧﴾}}
\qt@newcmd\qurantext@mmmcmxvi{إِلّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿١٢٨﴾}}
\qt@newcmd\qurantext@mmmcmxvii{وَتَرَكنا عَلَيهِ فِى الءاخِرينَ\qt@no{﴿١٢٩﴾}}
\qt@newcmd\qurantext@mmmcmxviii{سَلٰمٌ عَلىٰ إِل ياسينَ\qt@no{﴿١٣٠﴾}}
\qt@newcmd\qurantext@mmmcmxix{إِنّا كَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿١٣١﴾}}
\qt@newcmd\qurantext@mmmcmxx{إِنَّهُ مِن عِبادِنَا المُؤمِنينَ\qt@no{﴿١٣٢﴾}}
\qt@newcmd\qurantext@mmmcmxxi{وَإِنَّ لوطًا لَمِنَ المُرسَلينَ\qt@no{﴿١٣٣﴾}}
\qt@newcmd\qurantext@mmmcmxxii{إِذ نَجَّينٰهُ وَأَهلَهُ أَجمَعينَ\qt@no{﴿١٣٤﴾}}
\qt@newcmd\qurantext@mmmcmxxiii{إِلّا عَجوزًا فِى الغٰبِرينَ\qt@no{﴿١٣٥﴾}}
\qt@newcmd\qurantext@mmmcmxxiv{ثُمَّ دَمَّرنَا الءاخَرينَ\qt@no{﴿١٣٦﴾}}
\qt@newcmd\qurantext@mmmcmxxv{وَإِنَّكُم لَتَمُرّونَ عَلَيهِم مُصبِحينَ\qt@no{﴿١٣٧﴾}}
\qt@newcmd\qurantext@mmmcmxxvi{وَبِالَّيلِ أَفَلا تَعقِلونَ\qt@no{﴿١٣٨﴾}}
\qt@newcmd\qurantext@mmmcmxxvii{وَإِنَّ يونُسَ لَمِنَ المُرسَلينَ\qt@no{﴿١٣٩﴾}}
\qt@newcmd\qurantext@mmmcmxxviii{إِذ أَبَقَ إِلَى الفُلكِ المَشحونِ\qt@no{﴿١٤٠﴾}}
\qt@newcmd\qurantext@mmmcmxxix{فَساهَمَ فَكانَ مِنَ المُدحَضينَ\qt@no{﴿١٤١﴾}}
\qt@newcmd\qurantext@mmmcmxxx{فَالتَقَمَهُ الحوتُ وَهُوَ مُليمٌ\qt@no{﴿١٤٢﴾}}
\qt@newcmd\qurantext@mmmcmxxxi{فَلَولا أَنَّهُ كانَ مِنَ المُسَبِّحينَ\qt@no{﴿١٤٣﴾}}
\qt@newcmd\qurantext@mmmcmxxxii{لَلَبِثَ فى بَطنِهِ إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿١٤٤﴾}}
\qt@newcmd\qurantext@mmmcmxxxiii{فَنَبَذنٰهُ بِالعَراءِ وَهُوَ سَقيمٌ\qt@no{﴿١٤٥﴾}}
\qt@newcmd\qurantext@mmmcmxxxiv{وَأَنبَتنا عَلَيهِ شَجَرَةً مِن يَقطينٍ\qt@no{﴿١٤٦﴾}}
\qt@newcmd\qurantext@mmmcmxxxv{وَأَرسَلنٰهُ إِلىٰ مِا۟ئَةِ أَلفٍ أَو يَزيدونَ\qt@no{﴿١٤٧﴾}}
\qt@newcmd\qurantext@mmmcmxxxvi{فَـٔامَنوا فَمَتَّعنٰهُم إِلىٰ حينٍ\qt@no{﴿١٤٨﴾}}
\qt@newcmd\qurantext@mmmcmxxxvii{فَاستَفتِهِم أَلِرَبِّكَ البَناتُ وَلَهُمُ البَنونَ\qt@no{﴿١٤٩﴾}}
\qt@newcmd\qurantext@mmmcmxxxviii{أَم خَلَقنَا المَلٰئِكَةَ إِنٰثًا وَهُم شٰهِدونَ\qt@no{﴿١٥٠﴾}}
\qt@newcmd\qurantext@mmmcmxxxix{أَلا إِنَّهُم مِن إِفكِهِم لَيَقولونَ\qt@no{﴿١٥١﴾}}
\qt@newcmd\qurantext@mmmcmxl{وَلَدَ اللَّهُ وَإِنَّهُم لَكٰذِبونَ\qt@no{﴿١٥٢﴾}}
\qt@newcmd\qurantext@mmmcmxli{أَصطَفَى البَناتِ عَلَى البَنينَ\qt@no{﴿١٥٣﴾}}
\qt@newcmd\qurantext@mmmcmxlii{ما لَكُم كَيفَ تَحكُمونَ\qt@no{﴿١٥٤﴾}}
\qt@newcmd\qurantext@mmmcmxliii{أَفَلا تَذَكَّرونَ\qt@no{﴿١٥٥﴾}}
\qt@newcmd\qurantext@mmmcmxliv{أَم لَكُم سُلطٰنٌ مُبينٌ\qt@no{﴿١٥٦﴾}}
\qt@newcmd\qurantext@mmmcmxlv{فَأتوا بِكِتٰبِكُم إِن كُنتُم صٰدِقينَ\qt@no{﴿١٥٧﴾}}
\qt@newcmd\qurantext@mmmcmxlvi{وَجَعَلوا بَينَهُ وَبَينَ الجِنَّةِ نَسَبًا وَلَقَد عَلِمَتِ الجِنَّةُ إِنَّهُم لَمُحضَرونَ\qt@no{﴿١٥٨﴾}}
\qt@newcmd\qurantext@mmmcmxlvii{سُبحٰنَ اللَّهِ عَمّا يَصِفونَ\qt@no{﴿١٥٩﴾}}
\qt@newcmd\qurantext@mmmcmxlviii{إِلّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿١٦٠﴾}}
\qt@newcmd\qurantext@mmmcmxlix{فَإِنَّكُم وَما تَعبُدونَ\qt@no{﴿١٦١﴾}}
\qt@newcmd\qurantext@mmmcml{ما أَنتُم عَلَيهِ بِفٰتِنينَ\qt@no{﴿١٦٢﴾}}
\qt@newcmd\qurantext@mmmcmli{إِلّا مَن هُوَ صالِ الجَحيمِ\qt@no{﴿١٦٣﴾}}
\qt@newcmd\qurantext@mmmcmlii{وَما مِنّا إِلّا لَهُ مَقامٌ مَعلومٌ\qt@no{﴿١٦٤﴾}}
\qt@newcmd\qurantext@mmmcmliii{وَإِنّا لَنَحنُ الصّافّونَ\qt@no{﴿١٦٥﴾}}
\qt@newcmd\qurantext@mmmcmliv{وَإِنّا لَنَحنُ المُسَبِّحونَ\qt@no{﴿١٦٦﴾}}
\qt@newcmd\qurantext@mmmcmlv{وَإِن كانوا لَيَقولونَ\qt@no{﴿١٦٧﴾}}
\qt@newcmd\qurantext@mmmcmlvi{لَو أَنَّ عِندَنا ذِكرًا مِنَ الأَوَّلينَ\qt@no{﴿١٦٨﴾}}
\qt@newcmd\qurantext@mmmcmlvii{لَكُنّا عِبادَ اللَّهِ المُخلَصينَ\qt@no{﴿١٦٩﴾}}
\qt@newcmd\qurantext@mmmcmlviii{فَكَفَروا بِهِ فَسَوفَ يَعلَمونَ\qt@no{﴿١٧٠﴾}}
\qt@newcmd\qurantext@mmmcmlix{وَلَقَد سَبَقَت كَلِمَتُنا لِعِبادِنَا المُرسَلينَ\qt@no{﴿١٧١﴾}}
\qt@newcmd\qurantext@mmmcmlx{إِنَّهُم لَهُمُ المَنصورونَ\qt@no{﴿١٧٢﴾}}
\qt@newcmd\qurantext@mmmcmlxi{وَإِنَّ جُندَنا لَهُمُ الغٰلِبونَ\qt@no{﴿١٧٣﴾}}
\qt@newcmd\qurantext@mmmcmlxii{فَتَوَلَّ عَنهُم حَتّىٰ حينٍ\qt@no{﴿١٧٤﴾}}
\qt@newcmd\qurantext@mmmcmlxiii{وَأَبصِرهُم فَسَوفَ يُبصِرونَ\qt@no{﴿١٧٥﴾}}
\qt@newcmd\qurantext@mmmcmlxiv{أَفَبِعَذابِنا يَستَعجِلونَ\qt@no{﴿١٧٦﴾}}
\qt@newcmd\qurantext@mmmcmlxv{فَإِذا نَزَلَ بِساحَتِهِم فَساءَ صَباحُ المُنذَرينَ\qt@no{﴿١٧٧﴾}}
\qt@newcmd\qurantext@mmmcmlxvi{وَتَوَلَّ عَنهُم حَتّىٰ حينٍ\qt@no{﴿١٧٨﴾}}
\qt@newcmd\qurantext@mmmcmlxvii{وَأَبصِر فَسَوفَ يُبصِرونَ\qt@no{﴿١٧٩﴾}}
\qt@newcmd\qurantext@mmmcmlxviii{سُبحٰنَ رَبِّكَ رَبِّ العِزَّةِ عَمّا يَصِفونَ\qt@no{﴿١٨٠﴾}}
\qt@newcmd\qurantext@mmmcmlxix{وَسَلٰمٌ عَلَى المُرسَلينَ\qt@no{﴿١٨١﴾}}
\qt@newcmd\qurantext@mmmcmlxx{وَالحَمدُ لِلَّهِ رَبِّ العٰلَمينَ\qt@no{﴿١٨٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxi{\basmalah  ص وَالقُرءانِ ذِى الذِّكرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmcmlxxii{بَلِ الَّذينَ كَفَروا فى عِزَّةٍ وَشِقاقٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxiii{كَم أَهلَكنا مِن قَبلِهِم مِن قَرنٍ فَنادَوا وَلاتَ حينَ مَناصٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmcmlxxiv{وَعَجِبوا أَن جاءَهُم مُنذِرٌ مِنهُم وَقالَ الكٰفِرونَ هٰذا سٰحِرٌ كَذّابٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmcmlxxv{أَجَعَلَ الءالِهَةَ إِلٰهًا وٰحِدًا إِنَّ هٰذا لَشَيءٌ عُجابٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmcmlxxvi{وَانطَلَقَ المَلَأُ مِنهُم أَنِ امشوا وَاصبِروا عَلىٰ ءالِهَتِكُم إِنَّ هٰذا لَشَيءٌ يُرادُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmcmlxxvii{ما سَمِعنا بِهٰذا فِى المِلَّةِ الءاخِرَةِ إِن هٰذا إِلَّا اختِلٰقٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmcmlxxviii{أَءُنزِلَ عَلَيهِ الذِّكرُ مِن بَينِنا بَل هُم فى شَكٍّ مِن ذِكرى بَل لَمّا يَذوقوا عَذابِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmcmlxxix{أَم عِندَهُم خَزائِنُ رَحمَةِ رَبِّكَ العَزيزِ الوَهّابِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmcmlxxx{أَم لَهُم مُلكُ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُما فَليَرتَقوا فِى الأَسبٰبِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmcmlxxxi{جُندٌ ما هُنالِكَ مَهزومٌ مِنَ الأَحزابِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmcmlxxxii{كَذَّبَت قَبلَهُم قَومُ نوحٍ وَعادٌ وَفِرعَونُ ذُو الأَوتادِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmcmlxxxiii{وَثَمودُ وَقَومُ لوطٍ وَأَصحٰبُ لـَٔيكَةِ أُولٰئِكَ الأَحزابُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmcmlxxxiv{إِن كُلٌّ إِلّا كَذَّبَ الرُّسُلَ فَحَقَّ عِقابِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmcmlxxxv{وَما يَنظُرُ هٰؤُلاءِ إِلّا صَيحَةً وٰحِدَةً ما لَها مِن فَواقٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmcmlxxxvi{وَقالوا رَبَّنا عَجِّل لَنا قِطَّنا قَبلَ يَومِ الحِسابِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmcmlxxxvii{اصبِر عَلىٰ ما يَقولونَ وَاذكُر عَبدَنا داوۥدَ ذَا الأَيدِ إِنَّهُ أَوّابٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmcmlxxxviii{إِنّا سَخَّرنَا الجِبالَ مَعَهُ يُسَبِّحنَ بِالعَشِىِّ وَالإِشراقِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmcmlxxxix{وَالطَّيرَ مَحشورَةً كُلٌّ لَهُ أَوّابٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmcmxc{وَشَدَدنا مُلكَهُ وَءاتَينٰهُ الحِكمَةَ وَفَصلَ الخِطابِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmcmxci{وَهَل أَتىٰكَ نَبَؤُا۟ الخَصمِ إِذ تَسَوَّرُوا المِحرابَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmcmxcii{إِذ دَخَلوا عَلىٰ داوۥدَ فَفَزِعَ مِنهُم قالوا لا تَخَف خَصمانِ بَغىٰ بَعضُنا عَلىٰ بَعضٍ فَاحكُم بَينَنا بِالحَقِّ وَلا تُشطِط وَاهدِنا إِلىٰ سَواءِ الصِّرٰطِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmcmxciii{إِنَّ هٰذا أَخى لَهُ تِسعٌ وَتِسعونَ نَعجَةً وَلِىَ نَعجَةٌ وٰحِدَةٌ فَقالَ أَكفِلنيها وَعَزَّنى فِى الخِطابِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmcmxciv{قالَ لَقَد ظَلَمَكَ بِسُؤالِ نَعجَتِكَ إِلىٰ نِعاجِهِ وَإِنَّ كَثيرًا مِنَ الخُلَطاءِ لَيَبغى بَعضُهُم عَلىٰ بَعضٍ إِلَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ وَقَليلٌ ما هُم وَظَنَّ داوۥدُ أَنَّما فَتَنّٰهُ فَاستَغفَرَ رَبَّهُ وَخَرَّ راكِعًا وَأَنابَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmcmxcv{فَغَفَرنا لَهُ ذٰلِكَ وَإِنَّ لَهُ عِندَنا لَزُلفىٰ وَحُسنَ مَـٔابٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmcmxcvi{يٰداوۥدُ إِنّا جَعَلنٰكَ خَليفَةً فِى الأَرضِ فَاحكُم بَينَ النّاسِ بِالحَقِّ وَلا تَتَّبِعِ الهَوىٰ فَيُضِلَّكَ عَن سَبيلِ اللَّهِ إِنَّ الَّذينَ يَضِلّونَ عَن سَبيلِ اللَّهِ لَهُم عَذابٌ شَديدٌ بِما نَسوا يَومَ الحِسابِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmcmxcvii{وَما خَلَقنَا السَّماءَ وَالأَرضَ وَما بَينَهُما بٰطِلًا ذٰلِكَ ظَنُّ الَّذينَ كَفَروا فَوَيلٌ لِلَّذينَ كَفَروا مِنَ النّارِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmcmxcviii{أَم نَجعَلُ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ كَالمُفسِدينَ فِى الأَرضِ أَم نَجعَلُ المُتَّقينَ كَالفُجّارِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmcmxcix{كِتٰبٌ أَنزَلنٰهُ إِلَيكَ مُبٰرَكٌ لِيَدَّبَّروا ءايٰتِهِ وَلِيَتَذَكَّرَ أُولُوا الأَلبٰبِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmm{وَوَهَبنا لِداوۥدَ سُلَيمٰنَ نِعمَ العَبدُ إِنَّهُ أَوّابٌ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmi{إِذ عُرِضَ عَلَيهِ بِالعَشِىِّ الصّٰفِنٰتُ الجِيادُ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmii{فَقالَ إِنّى أَحبَبتُ حُبَّ الخَيرِ عَن ذِكرِ رَبّى حَتّىٰ تَوارَت بِالحِجابِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmiii{رُدّوها عَلَىَّ فَطَفِقَ مَسحًا بِالسّوقِ وَالأَعناقِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmiv{وَلَقَد فَتَنّا سُلَيمٰنَ وَأَلقَينا عَلىٰ كُرسِيِّهِ جَسَدًا ثُمَّ أَنابَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmv{قالَ رَبِّ اغفِر لى وَهَب لى مُلكًا لا يَنبَغى لِأَحَدٍ مِن بَعدى إِنَّكَ أَنتَ الوَهّابُ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmvi{فَسَخَّرنا لَهُ الرّيحَ تَجرى بِأَمرِهِ رُخاءً حَيثُ أَصابَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmvii{وَالشَّيٰطينَ كُلَّ بَنّاءٍ وَغَوّاصٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmviii{وَءاخَرينَ مُقَرَّنينَ فِى الأَصفادِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmix{هٰذا عَطاؤُنا فَامنُن أَو أَمسِك بِغَيرِ حِسابٍ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmx{وَإِنَّ لَهُ عِندَنا لَزُلفىٰ وَحُسنَ مَـٔابٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmxi{وَاذكُر عَبدَنا أَيّوبَ إِذ نادىٰ رَبَّهُ أَنّى مَسَّنِىَ الشَّيطٰنُ بِنُصبٍ وَعَذابٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmxii{اركُض بِرِجلِكَ هٰذا مُغتَسَلٌ بارِدٌ وَشَرابٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmxiii{وَوَهَبنا لَهُ أَهلَهُ وَمِثلَهُم مَعَهُم رَحمَةً مِنّا وَذِكرىٰ لِأُولِى الأَلبٰبِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmxiv{وَخُذ بِيَدِكَ ضِغثًا فَاضرِب بِهِ وَلا تَحنَث إِنّا وَجَدنٰهُ صابِرًا نِعمَ العَبدُ إِنَّهُ أَوّابٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmxv{وَاذكُر عِبٰدَنا إِبرٰهيمَ وَإِسحٰقَ وَيَعقوبَ أُولِى الأَيدى وَالأَبصٰرِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmxvi{إِنّا أَخلَصنٰهُم بِخالِصَةٍ ذِكرَى الدّارِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmxvii{وَإِنَّهُم عِندَنا لَمِنَ المُصطَفَينَ الأَخيارِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmxviii{وَاذكُر إِسمٰعيلَ وَاليَسَعَ وَذَا الكِفلِ وَكُلٌّ مِنَ الأَخيارِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmxix{هٰذا ذِكرٌ وَإِنَّ لِلمُتَّقينَ لَحُسنَ مَـٔابٍ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmxx{جَنّٰتِ عَدنٍ مُفَتَّحَةً لَهُمُ الأَبوٰبُ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmxxi{مُتَّكِـٔينَ فيها يَدعونَ فيها بِفٰكِهَةٍ كَثيرَةٍ وَشَرابٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmxxii{وَعِندَهُم قٰصِرٰتُ الطَّرفِ أَترابٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmxxiii{هٰذا ما توعَدونَ لِيَومِ الحِسابِ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmxxiv{إِنَّ هٰذا لَرِزقُنا ما لَهُ مِن نَفادٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmxxv{هٰذا وَإِنَّ لِلطّٰغينَ لَشَرَّ مَـٔابٍ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmxxvi{جَهَنَّمَ يَصلَونَها فَبِئسَ المِهادُ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmxxvii{هٰذا فَليَذوقوهُ حَميمٌ وَغَسّاقٌ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmxxviii{وَءاخَرُ مِن شَكلِهِ أَزوٰجٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmxxix{هٰذا فَوجٌ مُقتَحِمٌ مَعَكُم لا مَرحَبًا بِهِم إِنَّهُم صالُوا النّارِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmxxx{قالوا بَل أَنتُم لا مَرحَبًا بِكُم أَنتُم قَدَّمتُموهُ لَنا فَبِئسَ القَرارُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmxxxi{قالوا رَبَّنا مَن قَدَّمَ لَنا هٰذا فَزِدهُ عَذابًا ضِعفًا فِى النّارِ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmxxxii{وَقالوا ما لَنا لا نَرىٰ رِجالًا كُنّا نَعُدُّهُم مِنَ الأَشرارِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmxxxiii{أَتَّخَذنٰهُم سِخرِيًّا أَم زاغَت عَنهُمُ الأَبصٰرُ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmxxxiv{إِنَّ ذٰلِكَ لَحَقٌّ تَخاصُمُ أَهلِ النّارِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmxxxv{قُل إِنَّما أَنا۠ مُنذِرٌ وَما مِن إِلٰهٍ إِلَّا اللَّهُ الوٰحِدُ القَهّارُ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmxxxvi{رَبُّ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُمَا العَزيزُ الغَفّٰرُ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmxxxvii{قُل هُوَ نَبَؤٌا۟ عَظيمٌ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmxxxviii{أَنتُم عَنهُ مُعرِضونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmxxxix{ما كانَ لِىَ مِن عِلمٍ بِالمَلَإِ الأَعلىٰ إِذ يَختَصِمونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmxl{إِن يوحىٰ إِلَىَّ إِلّا أَنَّما أَنا۠ نَذيرٌ مُبينٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmxli{إِذ قالَ رَبُّكَ لِلمَلٰئِكَةِ إِنّى خٰلِقٌ بَشَرًا مِن طينٍ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmxlii{فَإِذا سَوَّيتُهُ وَنَفَختُ فيهِ مِن روحى فَقَعوا لَهُ سٰجِدينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmxliii{فَسَجَدَ المَلٰئِكَةُ كُلُّهُم أَجمَعونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmxliv{إِلّا إِبليسَ استَكبَرَ وَكانَ مِنَ الكٰفِرينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmxlv{قالَ يٰإِبليسُ ما مَنَعَكَ أَن تَسجُدَ لِما خَلَقتُ بِيَدَىَّ أَستَكبَرتَ أَم كُنتَ مِنَ العالينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmxlvi{قالَ أَنا۠ خَيرٌ مِنهُ خَلَقتَنى مِن نارٍ وَخَلَقتَهُ مِن طينٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmxlvii{قالَ فَاخرُج مِنها فَإِنَّكَ رَجيمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmxlviii{وَإِنَّ عَلَيكَ لَعنَتى إِلىٰ يَومِ الدّينِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmxlix{قالَ رَبِّ فَأَنظِرنى إِلىٰ يَومِ يُبعَثونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmml{قالَ فَإِنَّكَ مِنَ المُنظَرينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmli{إِلىٰ يَومِ الوَقتِ المَعلومِ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmlii{قالَ فَبِعِزَّتِكَ لَأُغوِيَنَّهُم أَجمَعينَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmliii{إِلّا عِبادَكَ مِنهُمُ المُخلَصينَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmliv{قالَ فَالحَقُّ وَالحَقَّ أَقولُ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmlv{لَأَملَأَنَّ جَهَنَّمَ مِنكَ وَمِمَّن تَبِعَكَ مِنهُم أَجمَعينَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmlvi{قُل ما أَسـَٔلُكُم عَلَيهِ مِن أَجرٍ وَما أَنا۠ مِنَ المُتَكَلِّفينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmlvii{إِن هُوَ إِلّا ذِكرٌ لِلعٰلَمينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmlviii{وَلَتَعلَمُنَّ نَبَأَهُ بَعدَ حينٍ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmlix{\basmalah  تَنزيلُ الكِتٰبِ مِنَ اللَّهِ العَزيزِ الحَكيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmlx{إِنّا أَنزَلنا إِلَيكَ الكِتٰبَ بِالحَقِّ فَاعبُدِ اللَّهَ مُخلِصًا لَهُ الدّينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmlxi{أَلا لِلَّهِ الدّينُ الخالِصُ وَالَّذينَ اتَّخَذوا مِن دونِهِ أَولِياءَ ما نَعبُدُهُم إِلّا لِيُقَرِّبونا إِلَى اللَّهِ زُلفىٰ إِنَّ اللَّهَ يَحكُمُ بَينَهُم فى ما هُم فيهِ يَختَلِفونَ إِنَّ اللَّهَ لا يَهدى مَن هُوَ كٰذِبٌ كَفّارٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmlxii{لَو أَرادَ اللَّهُ أَن يَتَّخِذَ وَلَدًا لَاصطَفىٰ مِمّا يَخلُقُ ما يَشاءُ سُبحٰنَهُ هُوَ اللَّهُ الوٰحِدُ القَهّارُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmlxiii{خَلَقَ السَّمٰوٰتِ وَالأَرضَ بِالحَقِّ يُكَوِّرُ الَّيلَ عَلَى النَّهارِ وَيُكَوِّرُ النَّهارَ عَلَى الَّيلِ وَسَخَّرَ الشَّمسَ وَالقَمَرَ كُلٌّ يَجرى لِأَجَلٍ مُسَمًّى أَلا هُوَ العَزيزُ الغَفّٰرُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmlxiv{خَلَقَكُم مِن نَفسٍ وٰحِدَةٍ ثُمَّ جَعَلَ مِنها زَوجَها وَأَنزَلَ لَكُم مِنَ الأَنعٰمِ ثَمٰنِيَةَ أَزوٰجٍ يَخلُقُكُم فى بُطونِ أُمَّهٰتِكُم خَلقًا مِن بَعدِ خَلقٍ فى ظُلُمٰتٍ ثَلٰثٍ ذٰلِكُمُ اللَّهُ رَبُّكُم لَهُ المُلكُ لا إِلٰهَ إِلّا هُوَ فَأَنّىٰ تُصرَفونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmlxv{إِن تَكفُروا فَإِنَّ اللَّهَ غَنِىٌّ عَنكُم وَلا يَرضىٰ لِعِبادِهِ الكُفرَ وَإِن تَشكُروا يَرضَهُ لَكُم وَلا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ ثُمَّ إِلىٰ رَبِّكُم مَرجِعُكُم فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmlxvi{وَإِذا مَسَّ الإِنسٰنَ ضُرٌّ دَعا رَبَّهُ مُنيبًا إِلَيهِ ثُمَّ إِذا خَوَّلَهُ نِعمَةً مِنهُ نَسِىَ ما كانَ يَدعوا إِلَيهِ مِن قَبلُ وَجَعَلَ لِلَّهِ أَندادًا لِيُضِلَّ عَن سَبيلِهِ قُل تَمَتَّع بِكُفرِكَ قَليلًا إِنَّكَ مِن أَصحٰبِ النّارِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmlxvii{أَمَّن هُوَ قٰنِتٌ ءاناءَ الَّيلِ ساجِدًا وَقائِمًا يَحذَرُ الءاخِرَةَ وَيَرجوا رَحمَةَ رَبِّهِ قُل هَل يَستَوِى الَّذينَ يَعلَمونَ وَالَّذينَ لا يَعلَمونَ إِنَّما يَتَذَكَّرُ أُولُوا الأَلبٰبِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmlxviii{قُل يٰعِبادِ الَّذينَ ءامَنُوا اتَّقوا رَبَّكُم لِلَّذينَ أَحسَنوا فى هٰذِهِ الدُّنيا حَسَنَةٌ وَأَرضُ اللَّهِ وٰسِعَةٌ إِنَّما يُوَفَّى الصّٰبِرونَ أَجرَهُم بِغَيرِ حِسابٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmlxix{قُل إِنّى أُمِرتُ أَن أَعبُدَ اللَّهَ مُخلِصًا لَهُ الدّينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmlxx{وَأُمِرتُ لِأَن أَكونَ أَوَّلَ المُسلِمينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmlxxi{قُل إِنّى أَخافُ إِن عَصَيتُ رَبّى عَذابَ يَومٍ عَظيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmlxxii{قُلِ اللَّهَ أَعبُدُ مُخلِصًا لَهُ دينى\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmlxxiii{فَاعبُدوا ما شِئتُم مِن دونِهِ قُل إِنَّ الخٰسِرينَ الَّذينَ خَسِروا أَنفُسَهُم وَأَهليهِم يَومَ القِيٰمَةِ أَلا ذٰلِكَ هُوَ الخُسرانُ المُبينُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmlxxiv{لَهُم مِن فَوقِهِم ظُلَلٌ مِنَ النّارِ وَمِن تَحتِهِم ظُلَلٌ ذٰلِكَ يُخَوِّفُ اللَّهُ بِهِ عِبادَهُ يٰعِبادِ فَاتَّقونِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmlxxv{وَالَّذينَ اجتَنَبُوا الطّٰغوتَ أَن يَعبُدوها وَأَنابوا إِلَى اللَّهِ لَهُمُ البُشرىٰ فَبَشِّر عِبادِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmlxxvi{الَّذينَ يَستَمِعونَ القَولَ فَيَتَّبِعونَ أَحسَنَهُ أُولٰئِكَ الَّذينَ هَدىٰهُمُ اللَّهُ وَأُولٰئِكَ هُم أُولُوا الأَلبٰبِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmlxxvii{أَفَمَن حَقَّ عَلَيهِ كَلِمَةُ العَذابِ أَفَأَنتَ تُنقِذُ مَن فِى النّارِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmlxxviii{لٰكِنِ الَّذينَ اتَّقَوا رَبَّهُم لَهُم غُرَفٌ مِن فَوقِها غُرَفٌ مَبنِيَّةٌ تَجرى مِن تَحتِهَا الأَنهٰرُ وَعدَ اللَّهِ لا يُخلِفُ اللَّهُ الميعادَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmlxxix{أَلَم تَرَ أَنَّ اللَّهَ أَنزَلَ مِنَ السَّماءِ ماءً فَسَلَكَهُ يَنٰبيعَ فِى الأَرضِ ثُمَّ يُخرِجُ بِهِ زَرعًا مُختَلِفًا أَلوٰنُهُ ثُمَّ يَهيجُ فَتَرىٰهُ مُصفَرًّا ثُمَّ يَجعَلُهُ حُطٰمًا إِنَّ فى ذٰلِكَ لَذِكرىٰ لِأُولِى الأَلبٰبِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmlxxx{أَفَمَن شَرَحَ اللَّهُ صَدرَهُ لِلإِسلٰمِ فَهُوَ عَلىٰ نورٍ مِن رَبِّهِ فَوَيلٌ لِلقٰسِيَةِ قُلوبُهُم مِن ذِكرِ اللَّهِ أُولٰئِكَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmlxxxi{اللَّهُ نَزَّلَ أَحسَنَ الحَديثِ كِتٰبًا مُتَشٰبِهًا مَثانِىَ تَقشَعِرُّ مِنهُ جُلودُ الَّذينَ يَخشَونَ رَبَّهُم ثُمَّ تَلينُ جُلودُهُم وَقُلوبُهُم إِلىٰ ذِكرِ اللَّهِ ذٰلِكَ هُدَى اللَّهِ يَهدى بِهِ مَن يَشاءُ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن هادٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmlxxxii{أَفَمَن يَتَّقى بِوَجهِهِ سوءَ العَذابِ يَومَ القِيٰمَةِ وَقيلَ لِلظّٰلِمينَ ذوقوا ما كُنتُم تَكسِبونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmlxxxiii{كَذَّبَ الَّذينَ مِن قَبلِهِم فَأَتىٰهُمُ العَذابُ مِن حَيثُ لا يَشعُرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmlxxxiv{فَأَذاقَهُمُ اللَّهُ الخِزىَ فِى الحَيوٰةِ الدُّنيا وَلَعَذابُ الءاخِرَةِ أَكبَرُ لَو كانوا يَعلَمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmlxxxv{وَلَقَد ضَرَبنا لِلنّاسِ فى هٰذَا القُرءانِ مِن كُلِّ مَثَلٍ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmlxxxvi{قُرءانًا عَرَبِيًّا غَيرَ ذى عِوَجٍ لَعَلَّهُم يَتَّقونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmlxxxvii{ضَرَبَ اللَّهُ مَثَلًا رَجُلًا فيهِ شُرَكاءُ مُتَشٰكِسونَ وَرَجُلًا سَلَمًا لِرَجُلٍ هَل يَستَوِيانِ مَثَلًا الحَمدُ لِلَّهِ بَل أَكثَرُهُم لا يَعلَمونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmlxxxviii{إِنَّكَ مَيِّتٌ وَإِنَّهُم مَيِّتونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmlxxxix{ثُمَّ إِنَّكُم يَومَ القِيٰمَةِ عِندَ رَبِّكُم تَختَصِمونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmxc{فَمَن أَظلَمُ مِمَّن كَذَبَ عَلَى اللَّهِ وَكَذَّبَ بِالصِّدقِ إِذ جاءَهُ أَلَيسَ فى جَهَنَّمَ مَثوًى لِلكٰفِرينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmxci{وَالَّذى جاءَ بِالصِّدقِ وَصَدَّقَ بِهِ أُولٰئِكَ هُمُ المُتَّقونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmxcii{لَهُم ما يَشاءونَ عِندَ رَبِّهِم ذٰلِكَ جَزاءُ المُحسِنينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmxciii{لِيُكَفِّرَ اللَّهُ عَنهُم أَسوَأَ الَّذى عَمِلوا وَيَجزِيَهُم أَجرَهُم بِأَحسَنِ الَّذى كانوا يَعمَلونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmxciv{أَلَيسَ اللَّهُ بِكافٍ عَبدَهُ وَيُخَوِّفونَكَ بِالَّذينَ مِن دونِهِ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن هادٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmxcv{وَمَن يَهدِ اللَّهُ فَما لَهُ مِن مُضِلٍّ أَلَيسَ اللَّهُ بِعَزيزٍ ذِى انتِقامٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmxcvi{وَلَئِن سَأَلتَهُم مَن خَلَقَ السَّمٰوٰتِ وَالأَرضَ لَيَقولُنَّ اللَّهُ قُل أَفَرَءَيتُم ما تَدعونَ مِن دونِ اللَّهِ إِن أَرادَنِىَ اللَّهُ بِضُرٍّ هَل هُنَّ كٰشِفٰتُ ضُرِّهِ أَو أَرادَنى بِرَحمَةٍ هَل هُنَّ مُمسِكٰتُ رَحمَتِهِ قُل حَسبِىَ اللَّهُ عَلَيهِ يَتَوَكَّلُ المُتَوَكِّلونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmxcvii{قُل يٰقَومِ اعمَلوا عَلىٰ مَكانَتِكُم إِنّى عٰمِلٌ فَسَوفَ تَعلَمونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmxcviii{مَن يَأتيهِ عَذابٌ يُخزيهِ وَيَحِلُّ عَلَيهِ عَذابٌ مُقيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmxcix{إِنّا أَنزَلنا عَلَيكَ الكِتٰبَ لِلنّاسِ بِالحَقِّ فَمَنِ اهتَدىٰ فَلِنَفسِهِ وَمَن ضَلَّ فَإِنَّما يَضِلُّ عَلَيها وَما أَنتَ عَلَيهِم بِوَكيلٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmc{اللَّهُ يَتَوَفَّى الأَنفُسَ حينَ مَوتِها وَالَّتى لَم تَمُت فى مَنامِها فَيُمسِكُ الَّتى قَضىٰ عَلَيهَا المَوتَ وَيُرسِلُ الأُخرىٰ إِلىٰ أَجَلٍ مُسَمًّى إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmci{أَمِ اتَّخَذوا مِن دونِ اللَّهِ شُفَعاءَ قُل أَوَلَو كانوا لا يَملِكونَ شَيـًٔا وَلا يَعقِلونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcii{قُل لِلَّهِ الشَّفٰعَةُ جَميعًا لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ ثُمَّ إِلَيهِ تُرجَعونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmciii{وَإِذا ذُكِرَ اللَّهُ وَحدَهُ اشمَأَزَّت قُلوبُ الَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ وَإِذا ذُكِرَ الَّذينَ مِن دونِهِ إِذا هُم يَستَبشِرونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmciv{قُلِ اللَّهُمَّ فاطِرَ السَّمٰوٰتِ وَالأَرضِ عٰلِمَ الغَيبِ وَالشَّهٰدَةِ أَنتَ تَحكُمُ بَينَ عِبادِكَ فى ما كانوا فيهِ يَختَلِفونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcv{وَلَو أَنَّ لِلَّذينَ ظَلَموا ما فِى الأَرضِ جَميعًا وَمِثلَهُ مَعَهُ لَافتَدَوا بِهِ مِن سوءِ العَذابِ يَومَ القِيٰمَةِ وَبَدا لَهُم مِنَ اللَّهِ ما لَم يَكونوا يَحتَسِبونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcvi{وَبَدا لَهُم سَيِّـٔاتُ ما كَسَبوا وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcvii{فَإِذا مَسَّ الإِنسٰنَ ضُرٌّ دَعانا ثُمَّ إِذا خَوَّلنٰهُ نِعمَةً مِنّا قالَ إِنَّما أوتيتُهُ عَلىٰ عِلمٍ بَل هِىَ فِتنَةٌ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcviii{قَد قالَهَا الَّذينَ مِن قَبلِهِم فَما أَغنىٰ عَنهُم ما كانوا يَكسِبونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcix{فَأَصابَهُم سَيِّـٔاتُ ما كَسَبوا وَالَّذينَ ظَلَموا مِن هٰؤُلاءِ سَيُصيبُهُم سَيِّـٔاتُ ما كَسَبوا وَما هُم بِمُعجِزينَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcx{أَوَلَم يَعلَموا أَنَّ اللَّهَ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يُؤمِنونَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcxi{قُل يٰعِبادِىَ الَّذينَ أَسرَفوا عَلىٰ أَنفُسِهِم لا تَقنَطوا مِن رَحمَةِ اللَّهِ إِنَّ اللَّهَ يَغفِرُ الذُّنوبَ جَميعًا إِنَّهُ هُوَ الغَفورُ الرَّحيمُ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcxii{وَأَنيبوا إِلىٰ رَبِّكُم وَأَسلِموا لَهُ مِن قَبلِ أَن يَأتِيَكُمُ العَذابُ ثُمَّ لا تُنصَرونَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcxiii{وَاتَّبِعوا أَحسَنَ ما أُنزِلَ إِلَيكُم مِن رَبِّكُم مِن قَبلِ أَن يَأتِيَكُمُ العَذابُ بَغتَةً وَأَنتُم لا تَشعُرونَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcxiv{أَن تَقولَ نَفسٌ يٰحَسرَتىٰ عَلىٰ ما فَرَّطتُ فى جَنبِ اللَّهِ وَإِن كُنتُ لَمِنَ السّٰخِرينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcxv{أَو تَقولَ لَو أَنَّ اللَّهَ هَدىٰنى لَكُنتُ مِنَ المُتَّقينَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcxvi{أَو تَقولَ حينَ تَرَى العَذابَ لَو أَنَّ لى كَرَّةً فَأَكونَ مِنَ المُحسِنينَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcxvii{بَلىٰ قَد جاءَتكَ ءايٰتى فَكَذَّبتَ بِها وَاستَكبَرتَ وَكُنتَ مِنَ الكٰفِرينَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcxviii{وَيَومَ القِيٰمَةِ تَرَى الَّذينَ كَذَبوا عَلَى اللَّهِ وُجوهُهُم مُسوَدَّةٌ أَلَيسَ فى جَهَنَّمَ مَثوًى لِلمُتَكَبِّرينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcxix{وَيُنَجِّى اللَّهُ الَّذينَ اتَّقَوا بِمَفازَتِهِم لا يَمَسُّهُمُ السّوءُ وَلا هُم يَحزَنونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcxx{اللَّهُ خٰلِقُ كُلِّ شَيءٍ وَهُوَ عَلىٰ كُلِّ شَيءٍ وَكيلٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcxxi{لَهُ مَقاليدُ السَّمٰوٰتِ وَالأَرضِ وَالَّذينَ كَفَروا بِـٔايٰتِ اللَّهِ أُولٰئِكَ هُمُ الخٰسِرونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcxxii{قُل أَفَغَيرَ اللَّهِ تَأمُرونّى أَعبُدُ أَيُّهَا الجٰهِلونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcxxiii{وَلَقَد أوحِىَ إِلَيكَ وَإِلَى الَّذينَ مِن قَبلِكَ لَئِن أَشرَكتَ لَيَحبَطَنَّ عَمَلُكَ وَلَتَكونَنَّ مِنَ الخٰسِرينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcxxiv{بَلِ اللَّهَ فَاعبُد وَكُن مِنَ الشّٰكِرينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcxxv{وَما قَدَرُوا اللَّهَ حَقَّ قَدرِهِ وَالأَرضُ جَميعًا قَبضَتُهُ يَومَ القِيٰمَةِ وَالسَّمٰوٰتُ مَطوِيّٰتٌ بِيَمينِهِ سُبحٰنَهُ وَتَعٰلىٰ عَمّا يُشرِكونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcxxvi{وَنُفِخَ فِى الصّورِ فَصَعِقَ مَن فِى السَّمٰوٰتِ وَمَن فِى الأَرضِ إِلّا مَن شاءَ اللَّهُ ثُمَّ نُفِخَ فيهِ أُخرىٰ فَإِذا هُم قِيامٌ يَنظُرونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcxxvii{وَأَشرَقَتِ الأَرضُ بِنورِ رَبِّها وَوُضِعَ الكِتٰبُ وَجِا۟يءَ بِالنَّبِيّۦنَ وَالشُّهَداءِ وَقُضِىَ بَينَهُم بِالحَقِّ وَهُم لا يُظلَمونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcxxviii{وَوُفِّيَت كُلُّ نَفسٍ ما عَمِلَت وَهُوَ أَعلَمُ بِما يَفعَلونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcxxix{وَسيقَ الَّذينَ كَفَروا إِلىٰ جَهَنَّمَ زُمَرًا حَتّىٰ إِذا جاءوها فُتِحَت أَبوٰبُها وَقالَ لَهُم خَزَنَتُها أَلَم يَأتِكُم رُسُلٌ مِنكُم يَتلونَ عَلَيكُم ءايٰتِ رَبِّكُم وَيُنذِرونَكُم لِقاءَ يَومِكُم هٰذا قالوا بَلىٰ وَلٰكِن حَقَّت كَلِمَةُ العَذابِ عَلَى الكٰفِرينَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcxxx{قيلَ ادخُلوا أَبوٰبَ جَهَنَّمَ خٰلِدينَ فيها فَبِئسَ مَثوَى المُتَكَبِّرينَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcxxxi{وَسيقَ الَّذينَ اتَّقَوا رَبَّهُم إِلَى الجَنَّةِ زُمَرًا حَتّىٰ إِذا جاءوها وَفُتِحَت أَبوٰبُها وَقالَ لَهُم خَزَنَتُها سَلٰمٌ عَلَيكُم طِبتُم فَادخُلوها خٰلِدينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcxxxii{وَقالُوا الحَمدُ لِلَّهِ الَّذى صَدَقَنا وَعدَهُ وَأَورَثَنَا الأَرضَ نَتَبَوَّأُ مِنَ الجَنَّةِ حَيثُ نَشاءُ فَنِعمَ أَجرُ العٰمِلينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcxxxiii{وَتَرَى المَلٰئِكَةَ حافّينَ مِن حَولِ العَرشِ يُسَبِّحونَ بِحَمدِ رَبِّهِم وَقُضِىَ بَينَهُم بِالحَقِّ وَقيلَ الحَمدُ لِلَّهِ رَبِّ العٰلَمينَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcxxxiv{\basmalah  حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcxxxv{تَنزيلُ الكِتٰبِ مِنَ اللَّهِ العَزيزِ العَليمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcxxxvi{غافِرِ الذَّنبِ وَقابِلِ التَّوبِ شَديدِ العِقابِ ذِى الطَّولِ لا إِلٰهَ إِلّا هُوَ إِلَيهِ المَصيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcxxxvii{ما يُجٰدِلُ فى ءايٰتِ اللَّهِ إِلَّا الَّذينَ كَفَروا فَلا يَغرُركَ تَقَلُّبُهُم فِى البِلٰدِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcxxxviii{كَذَّبَت قَبلَهُم قَومُ نوحٍ وَالأَحزابُ مِن بَعدِهِم وَهَمَّت كُلُّ أُمَّةٍ بِرَسولِهِم لِيَأخُذوهُ وَجٰدَلوا بِالبٰطِلِ لِيُدحِضوا بِهِ الحَقَّ فَأَخَذتُهُم فَكَيفَ كانَ عِقابِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcxxxix{وَكَذٰلِكَ حَقَّت كَلِمَتُ رَبِّكَ عَلَى الَّذينَ كَفَروا أَنَّهُم أَصحٰبُ النّارِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcxl{الَّذينَ يَحمِلونَ العَرشَ وَمَن حَولَهُ يُسَبِّحونَ بِحَمدِ رَبِّهِم وَيُؤمِنونَ بِهِ وَيَستَغفِرونَ لِلَّذينَ ءامَنوا رَبَّنا وَسِعتَ كُلَّ شَيءٍ رَحمَةً وَعِلمًا فَاغفِر لِلَّذينَ تابوا وَاتَّبَعوا سَبيلَكَ وَقِهِم عَذابَ الجَحيمِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcxli{رَبَّنا وَأَدخِلهُم جَنّٰتِ عَدنٍ الَّتى وَعَدتَهُم وَمَن صَلَحَ مِن ءابائِهِم وَأَزوٰجِهِم وَذُرِّيّٰتِهِم إِنَّكَ أَنتَ العَزيزُ الحَكيمُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcxlii{وَقِهِمُ السَّيِّـٔاتِ وَمَن تَقِ السَّيِّـٔاتِ يَومَئِذٍ فَقَد رَحِمتَهُ وَذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcxliii{إِنَّ الَّذينَ كَفَروا يُنادَونَ لَمَقتُ اللَّهِ أَكبَرُ مِن مَقتِكُم أَنفُسَكُم إِذ تُدعَونَ إِلَى الإيمٰنِ فَتَكفُرونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcxliv{قالوا رَبَّنا أَمَتَّنَا اثنَتَينِ وَأَحيَيتَنَا اثنَتَينِ فَاعتَرَفنا بِذُنوبِنا فَهَل إِلىٰ خُروجٍ مِن سَبيلٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcxlv{ذٰلِكُم بِأَنَّهُ إِذا دُعِىَ اللَّهُ وَحدَهُ كَفَرتُم وَإِن يُشرَك بِهِ تُؤمِنوا فَالحُكمُ لِلَّهِ العَلِىِّ الكَبيرِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcxlvi{هُوَ الَّذى يُريكُم ءايٰتِهِ وَيُنَزِّلُ لَكُم مِنَ السَّماءِ رِزقًا وَما يَتَذَكَّرُ إِلّا مَن يُنيبُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcxlvii{فَادعُوا اللَّهَ مُخلِصينَ لَهُ الدّينَ وَلَو كَرِهَ الكٰفِرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcxlviii{رَفيعُ الدَّرَجٰتِ ذُو العَرشِ يُلقِى الرّوحَ مِن أَمرِهِ عَلىٰ مَن يَشاءُ مِن عِبادِهِ لِيُنذِرَ يَومَ التَّلاقِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcxlix{يَومَ هُم بٰرِزونَ لا يَخفىٰ عَلَى اللَّهِ مِنهُم شَيءٌ لِمَنِ المُلكُ اليَومَ لِلَّهِ الوٰحِدِ القَهّارِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcl{اليَومَ تُجزىٰ كُلُّ نَفسٍ بِما كَسَبَت لا ظُلمَ اليَومَ إِنَّ اللَّهَ سَريعُ الحِسابِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcli{وَأَنذِرهُم يَومَ الءازِفَةِ إِذِ القُلوبُ لَدَى الحَناجِرِ كٰظِمينَ ما لِلظّٰلِمينَ مِن حَميمٍ وَلا شَفيعٍ يُطاعُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmclii{يَعلَمُ خائِنَةَ الأَعيُنِ وَما تُخفِى الصُّدورُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcliii{وَاللَّهُ يَقضى بِالحَقِّ وَالَّذينَ يَدعونَ مِن دونِهِ لا يَقضونَ بِشَيءٍ إِنَّ اللَّهَ هُوَ السَّميعُ البَصيرُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcliv{أَوَلَم يَسيروا فِى الأَرضِ فَيَنظُروا كَيفَ كانَ عٰقِبَةُ الَّذينَ كانوا مِن قَبلِهِم كانوا هُم أَشَدَّ مِنهُم قُوَّةً وَءاثارًا فِى الأَرضِ فَأَخَذَهُمُ اللَّهُ بِذُنوبِهِم وَما كانَ لَهُم مِنَ اللَّهِ مِن واقٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmclv{ذٰلِكَ بِأَنَّهُم كانَت تَأتيهِم رُسُلُهُم بِالبَيِّنٰتِ فَكَفَروا فَأَخَذَهُمُ اللَّهُ إِنَّهُ قَوِىٌّ شَديدُ العِقابِ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmclvi{وَلَقَد أَرسَلنا موسىٰ بِـٔايٰتِنا وَسُلطٰنٍ مُبينٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmclvii{إِلىٰ فِرعَونَ وَهٰمٰنَ وَقٰرونَ فَقالوا سٰحِرٌ كَذّابٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmclviii{فَلَمّا جاءَهُم بِالحَقِّ مِن عِندِنا قالُوا اقتُلوا أَبناءَ الَّذينَ ءامَنوا مَعَهُ وَاستَحيوا نِساءَهُم وَما كَيدُ الكٰفِرينَ إِلّا فى ضَلٰلٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmclix{وَقالَ فِرعَونُ ذَرونى أَقتُل موسىٰ وَليَدعُ رَبَّهُ إِنّى أَخافُ أَن يُبَدِّلَ دينَكُم أَو أَن يُظهِرَ فِى الأَرضِ الفَسادَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmclx{وَقالَ موسىٰ إِنّى عُذتُ بِرَبّى وَرَبِّكُم مِن كُلِّ مُتَكَبِّرٍ لا يُؤمِنُ بِيَومِ الحِسابِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmclxi{وَقالَ رَجُلٌ مُؤمِنٌ مِن ءالِ فِرعَونَ يَكتُمُ إيمٰنَهُ أَتَقتُلونَ رَجُلًا أَن يَقولَ رَبِّىَ اللَّهُ وَقَد جاءَكُم بِالبَيِّنٰتِ مِن رَبِّكُم وَإِن يَكُ كٰذِبًا فَعَلَيهِ كَذِبُهُ وَإِن يَكُ صادِقًا يُصِبكُم بَعضُ الَّذى يَعِدُكُم إِنَّ اللَّهَ لا يَهدى مَن هُوَ مُسرِفٌ كَذّابٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmclxii{يٰقَومِ لَكُمُ المُلكُ اليَومَ ظٰهِرينَ فِى الأَرضِ فَمَن يَنصُرُنا مِن بَأسِ اللَّهِ إِن جاءَنا قالَ فِرعَونُ ما أُريكُم إِلّا ما أَرىٰ وَما أَهديكُم إِلّا سَبيلَ الرَّشادِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmclxiii{وَقالَ الَّذى ءامَنَ يٰقَومِ إِنّى أَخافُ عَلَيكُم مِثلَ يَومِ الأَحزابِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmclxiv{مِثلَ دَأبِ قَومِ نوحٍ وَعادٍ وَثَمودَ وَالَّذينَ مِن بَعدِهِم وَمَا اللَّهُ يُريدُ ظُلمًا لِلعِبادِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmclxv{وَيٰقَومِ إِنّى أَخافُ عَلَيكُم يَومَ التَّنادِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmclxvi{يَومَ تُوَلّونَ مُدبِرينَ ما لَكُم مِنَ اللَّهِ مِن عاصِمٍ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن هادٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmclxvii{وَلَقَد جاءَكُم يوسُفُ مِن قَبلُ بِالبَيِّنٰتِ فَما زِلتُم فى شَكٍّ مِمّا جاءَكُم بِهِ حَتّىٰ إِذا هَلَكَ قُلتُم لَن يَبعَثَ اللَّهُ مِن بَعدِهِ رَسولًا كَذٰلِكَ يُضِلُّ اللَّهُ مَن هُوَ مُسرِفٌ مُرتابٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmclxviii{الَّذينَ يُجٰدِلونَ فى ءايٰتِ اللَّهِ بِغَيرِ سُلطٰنٍ أَتىٰهُم كَبُرَ مَقتًا عِندَ اللَّهِ وَعِندَ الَّذينَ ءامَنوا كَذٰلِكَ يَطبَعُ اللَّهُ عَلىٰ كُلِّ قَلبِ مُتَكَبِّرٍ جَبّارٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmclxix{وَقالَ فِرعَونُ يٰهٰمٰنُ ابنِ لى صَرحًا لَعَلّى أَبلُغُ الأَسبٰبَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmclxx{أَسبٰبَ السَّمٰوٰتِ فَأَطَّلِعَ إِلىٰ إِلٰهِ موسىٰ وَإِنّى لَأَظُنُّهُ كٰذِبًا وَكَذٰلِكَ زُيِّنَ لِفِرعَونَ سوءُ عَمَلِهِ وَصُدَّ عَنِ السَّبيلِ وَما كَيدُ فِرعَونَ إِلّا فى تَبابٍ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmclxxi{وَقالَ الَّذى ءامَنَ يٰقَومِ اتَّبِعونِ أَهدِكُم سَبيلَ الرَّشادِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmclxxii{يٰقَومِ إِنَّما هٰذِهِ الحَيوٰةُ الدُّنيا مَتٰعٌ وَإِنَّ الءاخِرَةَ هِىَ دارُ القَرارِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmclxxiii{مَن عَمِلَ سَيِّئَةً فَلا يُجزىٰ إِلّا مِثلَها وَمَن عَمِلَ صٰلِحًا مِن ذَكَرٍ أَو أُنثىٰ وَهُوَ مُؤمِنٌ فَأُولٰئِكَ يَدخُلونَ الجَنَّةَ يُرزَقونَ فيها بِغَيرِ حِسابٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmclxxiv{وَيٰقَومِ ما لى أَدعوكُم إِلَى النَّجوٰةِ وَتَدعونَنى إِلَى النّارِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmclxxv{تَدعونَنى لِأَكفُرَ بِاللَّهِ وَأُشرِكَ بِهِ ما لَيسَ لى بِهِ عِلمٌ وَأَنا۠ أَدعوكُم إِلَى العَزيزِ الغَفّٰرِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmclxxvi{لا جَرَمَ أَنَّما تَدعونَنى إِلَيهِ لَيسَ لَهُ دَعوَةٌ فِى الدُّنيا وَلا فِى الءاخِرَةِ وَأَنَّ مَرَدَّنا إِلَى اللَّهِ وَأَنَّ المُسرِفينَ هُم أَصحٰبُ النّارِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmclxxvii{فَسَتَذكُرونَ ما أَقولُ لَكُم وَأُفَوِّضُ أَمرى إِلَى اللَّهِ إِنَّ اللَّهَ بَصيرٌ بِالعِبادِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmclxxviii{فَوَقىٰهُ اللَّهُ سَيِّـٔاتِ ما مَكَروا وَحاقَ بِـٔالِ فِرعَونَ سوءُ العَذابِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmclxxix{النّارُ يُعرَضونَ عَلَيها غُدُوًّا وَعَشِيًّا وَيَومَ تَقومُ السّاعَةُ أَدخِلوا ءالَ فِرعَونَ أَشَدَّ العَذابِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmclxxx{وَإِذ يَتَحاجّونَ فِى النّارِ فَيَقولُ الضُّعَفٰؤُا۟ لِلَّذينَ استَكبَروا إِنّا كُنّا لَكُم تَبَعًا فَهَل أَنتُم مُغنونَ عَنّا نَصيبًا مِنَ النّارِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmclxxxi{قالَ الَّذينَ استَكبَروا إِنّا كُلٌّ فيها إِنَّ اللَّهَ قَد حَكَمَ بَينَ العِبادِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmclxxxii{وَقالَ الَّذينَ فِى النّارِ لِخَزَنَةِ جَهَنَّمَ ادعوا رَبَّكُم يُخَفِّف عَنّا يَومًا مِنَ العَذابِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmclxxxiii{قالوا أَوَلَم تَكُ تَأتيكُم رُسُلُكُم بِالبَيِّنٰتِ قالوا بَلىٰ قالوا فَادعوا وَما دُعٰؤُا۟ الكٰفِرينَ إِلّا فى ضَلٰلٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmclxxxiv{إِنّا لَنَنصُرُ رُسُلَنا وَالَّذينَ ءامَنوا فِى الحَيوٰةِ الدُّنيا وَيَومَ يَقومُ الأَشهٰدُ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmclxxxv{يَومَ لا يَنفَعُ الظّٰلِمينَ مَعذِرَتُهُم وَلَهُمُ اللَّعنَةُ وَلَهُم سوءُ الدّارِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmclxxxvi{وَلَقَد ءاتَينا موسَى الهُدىٰ وَأَورَثنا بَنى إِسرٰءيلَ الكِتٰبَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmclxxxvii{هُدًى وَذِكرىٰ لِأُولِى الأَلبٰبِ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmclxxxviii{فَاصبِر إِنَّ وَعدَ اللَّهِ حَقٌّ وَاستَغفِر لِذَنبِكَ وَسَبِّح بِحَمدِ رَبِّكَ بِالعَشِىِّ وَالإِبكٰرِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmclxxxix{إِنَّ الَّذينَ يُجٰدِلونَ فى ءايٰتِ اللَّهِ بِغَيرِ سُلطٰنٍ أَتىٰهُم إِن فى صُدورِهِم إِلّا كِبرٌ ما هُم بِبٰلِغيهِ فَاستَعِذ بِاللَّهِ إِنَّهُ هُوَ السَّميعُ البَصيرُ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcxc{لَخَلقُ السَّمٰوٰتِ وَالأَرضِ أَكبَرُ مِن خَلقِ النّاسِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcxci{وَما يَستَوِى الأَعمىٰ وَالبَصيرُ وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ وَلَا المُسيءُ قَليلًا ما تَتَذَكَّرونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcxcii{إِنَّ السّاعَةَ لَءاتِيَةٌ لا رَيبَ فيها وَلٰكِنَّ أَكثَرَ النّاسِ لا يُؤمِنونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcxciii{وَقالَ رَبُّكُمُ ادعونى أَستَجِب لَكُم إِنَّ الَّذينَ يَستَكبِرونَ عَن عِبادَتى سَيَدخُلونَ جَهَنَّمَ داخِرينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcxciv{اللَّهُ الَّذى جَعَلَ لَكُمُ الَّيلَ لِتَسكُنوا فيهِ وَالنَّهارَ مُبصِرًا إِنَّ اللَّهَ لَذو فَضلٍ عَلَى النّاسِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَشكُرونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcxcv{ذٰلِكُمُ اللَّهُ رَبُّكُم خٰلِقُ كُلِّ شَيءٍ لا إِلٰهَ إِلّا هُوَ فَأَنّىٰ تُؤفَكونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcxcvi{كَذٰلِكَ يُؤفَكُ الَّذينَ كانوا بِـٔايٰتِ اللَّهِ يَجحَدونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcxcvii{اللَّهُ الَّذى جَعَلَ لَكُمُ الأَرضَ قَرارًا وَالسَّماءَ بِناءً وَصَوَّرَكُم فَأَحسَنَ صُوَرَكُم وَرَزَقَكُم مِنَ الطَّيِّبٰتِ ذٰلِكُمُ اللَّهُ رَبُّكُم فَتَبارَكَ اللَّهُ رَبُّ العٰلَمينَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcxcviii{هُوَ الحَىُّ لا إِلٰهَ إِلّا هُوَ فَادعوهُ مُخلِصينَ لَهُ الدّينَ الحَمدُ لِلَّهِ رَبِّ العٰلَمينَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcxcix{قُل إِنّى نُهيتُ أَن أَعبُدَ الَّذينَ تَدعونَ مِن دونِ اللَّهِ لَمّا جاءَنِىَ البَيِّنٰتُ مِن رَبّى وَأُمِرتُ أَن أُسلِمَ لِرَبِّ العٰلَمينَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcc{هُوَ الَّذى خَلَقَكُم مِن تُرابٍ ثُمَّ مِن نُطفَةٍ ثُمَّ مِن عَلَقَةٍ ثُمَّ يُخرِجُكُم طِفلًا ثُمَّ لِتَبلُغوا أَشُدَّكُم ثُمَّ لِتَكونوا شُيوخًا وَمِنكُم مَن يُتَوَفّىٰ مِن قَبلُ وَلِتَبلُغوا أَجَلًا مُسَمًّى وَلَعَلَّكُم تَعقِلونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcci{هُوَ الَّذى يُحيۦ وَيُميتُ فَإِذا قَضىٰ أَمرًا فَإِنَّما يَقولُ لَهُ كُن فَيَكونُ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmccii{أَلَم تَرَ إِلَى الَّذينَ يُجٰدِلونَ فى ءايٰتِ اللَّهِ أَنّىٰ يُصرَفونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcciii{الَّذينَ كَذَّبوا بِالكِتٰبِ وَبِما أَرسَلنا بِهِ رُسُلَنا فَسَوفَ يَعلَمونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcciv{إِذِ الأَغلٰلُ فى أَعنٰقِهِم وَالسَّلٰسِلُ يُسحَبونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmccv{فِى الحَميمِ ثُمَّ فِى النّارِ يُسجَرونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmccvi{ثُمَّ قيلَ لَهُم أَينَ ما كُنتُم تُشرِكونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmccvii{مِن دونِ اللَّهِ قالوا ضَلّوا عَنّا بَل لَم نَكُن نَدعوا مِن قَبلُ شَيـًٔا كَذٰلِكَ يُضِلُّ اللَّهُ الكٰفِرينَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmccviii{ذٰلِكُم بِما كُنتُم تَفرَحونَ فِى الأَرضِ بِغَيرِ الحَقِّ وَبِما كُنتُم تَمرَحونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmccix{ادخُلوا أَبوٰبَ جَهَنَّمَ خٰلِدينَ فيها فَبِئسَ مَثوَى المُتَكَبِّرينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmccx{فَاصبِر إِنَّ وَعدَ اللَّهِ حَقٌّ فَإِمّا نُرِيَنَّكَ بَعضَ الَّذى نَعِدُهُم أَو نَتَوَفَّيَنَّكَ فَإِلَينا يُرجَعونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmccxi{وَلَقَد أَرسَلنا رُسُلًا مِن قَبلِكَ مِنهُم مَن قَصَصنا عَلَيكَ وَمِنهُم مَن لَم نَقصُص عَلَيكَ وَما كانَ لِرَسولٍ أَن يَأتِىَ بِـٔايَةٍ إِلّا بِإِذنِ اللَّهِ فَإِذا جاءَ أَمرُ اللَّهِ قُضِىَ بِالحَقِّ وَخَسِرَ هُنالِكَ المُبطِلونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmccxii{اللَّهُ الَّذى جَعَلَ لَكُمُ الأَنعٰمَ لِتَركَبوا مِنها وَمِنها تَأكُلونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmccxiii{وَلَكُم فيها مَنٰفِعُ وَلِتَبلُغوا عَلَيها حاجَةً فى صُدورِكُم وَعَلَيها وَعَلَى الفُلكِ تُحمَلونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmccxiv{وَيُريكُم ءايٰتِهِ فَأَىَّ ءايٰتِ اللَّهِ تُنكِرونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmccxv{أَفَلَم يَسيروا فِى الأَرضِ فَيَنظُروا كَيفَ كانَ عٰقِبَةُ الَّذينَ مِن قَبلِهِم كانوا أَكثَرَ مِنهُم وَأَشَدَّ قُوَّةً وَءاثارًا فِى الأَرضِ فَما أَغنىٰ عَنهُم ما كانوا يَكسِبونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmccxvi{فَلَمّا جاءَتهُم رُسُلُهُم بِالبَيِّنٰتِ فَرِحوا بِما عِندَهُم مِنَ العِلمِ وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmccxvii{فَلَمّا رَأَوا بَأسَنا قالوا ءامَنّا بِاللَّهِ وَحدَهُ وَكَفَرنا بِما كُنّا بِهِ مُشرِكينَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmccxviii{فَلَم يَكُ يَنفَعُهُم إيمٰنُهُم لَمّا رَأَوا بَأسَنا سُنَّتَ اللَّهِ الَّتى قَد خَلَت فى عِبادِهِ وَخَسِرَ هُنالِكَ الكٰفِرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmccxix{\basmalah  حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmccxx{تَنزيلٌ مِنَ الرَّحمٰنِ الرَّحيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmccxxi{كِتٰبٌ فُصِّلَت ءايٰتُهُ قُرءانًا عَرَبِيًّا لِقَومٍ يَعلَمونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmccxxii{بَشيرًا وَنَذيرًا فَأَعرَضَ أَكثَرُهُم فَهُم لا يَسمَعونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmccxxiii{وَقالوا قُلوبُنا فى أَكِنَّةٍ مِمّا تَدعونا إِلَيهِ وَفى ءاذانِنا وَقرٌ وَمِن بَينِنا وَبَينِكَ حِجابٌ فَاعمَل إِنَّنا عٰمِلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmccxxiv{قُل إِنَّما أَنا۠ بَشَرٌ مِثلُكُم يوحىٰ إِلَىَّ أَنَّما إِلٰهُكُم إِلٰهٌ وٰحِدٌ فَاستَقيموا إِلَيهِ وَاستَغفِروهُ وَوَيلٌ لِلمُشرِكينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmccxxv{الَّذينَ لا يُؤتونَ الزَّكوٰةَ وَهُم بِالءاخِرَةِ هُم كٰفِرونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmccxxvi{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَهُم أَجرٌ غَيرُ مَمنونٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmccxxvii{قُل أَئِنَّكُم لَتَكفُرونَ بِالَّذى خَلَقَ الأَرضَ فى يَومَينِ وَتَجعَلونَ لَهُ أَندادًا ذٰلِكَ رَبُّ العٰلَمينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmccxxviii{وَجَعَلَ فيها رَوٰسِىَ مِن فَوقِها وَبٰرَكَ فيها وَقَدَّرَ فيها أَقوٰتَها فى أَربَعَةِ أَيّامٍ سَواءً لِلسّائِلينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmccxxix{ثُمَّ استَوىٰ إِلَى السَّماءِ وَهِىَ دُخانٌ فَقالَ لَها وَلِلأَرضِ ائتِيا طَوعًا أَو كَرهًا قالَتا أَتَينا طائِعينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmccxxx{فَقَضىٰهُنَّ سَبعَ سَمٰواتٍ فى يَومَينِ وَأَوحىٰ فى كُلِّ سَماءٍ أَمرَها وَزَيَّنَّا السَّماءَ الدُّنيا بِمَصٰبيحَ وَحِفظًا ذٰلِكَ تَقديرُ العَزيزِ العَليمِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmccxxxi{فَإِن أَعرَضوا فَقُل أَنذَرتُكُم صٰعِقَةً مِثلَ صٰعِقَةِ عادٍ وَثَمودَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmccxxxii{إِذ جاءَتهُمُ الرُّسُلُ مِن بَينِ أَيديهِم وَمِن خَلفِهِم أَلّا تَعبُدوا إِلَّا اللَّهَ قالوا لَو شاءَ رَبُّنا لَأَنزَلَ مَلٰئِكَةً فَإِنّا بِما أُرسِلتُم بِهِ كٰفِرونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmccxxxiii{فَأَمّا عادٌ فَاستَكبَروا فِى الأَرضِ بِغَيرِ الحَقِّ وَقالوا مَن أَشَدُّ مِنّا قُوَّةً أَوَلَم يَرَوا أَنَّ اللَّهَ الَّذى خَلَقَهُم هُوَ أَشَدُّ مِنهُم قُوَّةً وَكانوا بِـٔايٰتِنا يَجحَدونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmccxxxiv{فَأَرسَلنا عَلَيهِم ريحًا صَرصَرًا فى أَيّامٍ نَحِساتٍ لِنُذيقَهُم عَذابَ الخِزىِ فِى الحَيوٰةِ الدُّنيا وَلَعَذابُ الءاخِرَةِ أَخزىٰ وَهُم لا يُنصَرونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmccxxxv{وَأَمّا ثَمودُ فَهَدَينٰهُم فَاستَحَبُّوا العَمىٰ عَلَى الهُدىٰ فَأَخَذَتهُم صٰعِقَةُ العَذابِ الهونِ بِما كانوا يَكسِبونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmccxxxvi{وَنَجَّينَا الَّذينَ ءامَنوا وَكانوا يَتَّقونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmccxxxvii{وَيَومَ يُحشَرُ أَعداءُ اللَّهِ إِلَى النّارِ فَهُم يوزَعونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmccxxxviii{حَتّىٰ إِذا ما جاءوها شَهِدَ عَلَيهِم سَمعُهُم وَأَبصٰرُهُم وَجُلودُهُم بِما كانوا يَعمَلونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmccxxxix{وَقالوا لِجُلودِهِم لِمَ شَهِدتُم عَلَينا قالوا أَنطَقَنَا اللَّهُ الَّذى أَنطَقَ كُلَّ شَيءٍ وَهُوَ خَلَقَكُم أَوَّلَ مَرَّةٍ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmccxl{وَما كُنتُم تَستَتِرونَ أَن يَشهَدَ عَلَيكُم سَمعُكُم وَلا أَبصٰرُكُم وَلا جُلودُكُم وَلٰكِن ظَنَنتُم أَنَّ اللَّهَ لا يَعلَمُ كَثيرًا مِمّا تَعمَلونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmccxli{وَذٰلِكُم ظَنُّكُمُ الَّذى ظَنَنتُم بِرَبِّكُم أَردىٰكُم فَأَصبَحتُم مِنَ الخٰسِرينَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmccxlii{فَإِن يَصبِروا فَالنّارُ مَثوًى لَهُم وَإِن يَستَعتِبوا فَما هُم مِنَ المُعتَبينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmccxliii{وَقَيَّضنا لَهُم قُرَناءَ فَزَيَّنوا لَهُم ما بَينَ أَيديهِم وَما خَلفَهُم وَحَقَّ عَلَيهِمُ القَولُ فى أُمَمٍ قَد خَلَت مِن قَبلِهِم مِنَ الجِنِّ وَالإِنسِ إِنَّهُم كانوا خٰسِرينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmccxliv{وَقالَ الَّذينَ كَفَروا لا تَسمَعوا لِهٰذَا القُرءانِ وَالغَوا فيهِ لَعَلَّكُم تَغلِبونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccxlv{فَلَنُذيقَنَّ الَّذينَ كَفَروا عَذابًا شَديدًا وَلَنَجزِيَنَّهُم أَسوَأَ الَّذى كانوا يَعمَلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmccxlvi{ذٰلِكَ جَزاءُ أَعداءِ اللَّهِ النّارُ لَهُم فيها دارُ الخُلدِ جَزاءً بِما كانوا بِـٔايٰتِنا يَجحَدونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmccxlvii{وَقالَ الَّذينَ كَفَروا رَبَّنا أَرِنَا الَّذَينِ أَضَلّانا مِنَ الجِنِّ وَالإِنسِ نَجعَلهُما تَحتَ أَقدامِنا لِيَكونا مِنَ الأَسفَلينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmccxlviii{إِنَّ الَّذينَ قالوا رَبُّنَا اللَّهُ ثُمَّ استَقٰموا تَتَنَزَّلُ عَلَيهِمُ المَلٰئِكَةُ أَلّا تَخافوا وَلا تَحزَنوا وَأَبشِروا بِالجَنَّةِ الَّتى كُنتُم توعَدونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccxlix{نَحنُ أَولِياؤُكُم فِى الحَيوٰةِ الدُّنيا وَفِى الءاخِرَةِ وَلَكُم فيها ما تَشتَهى أَنفُسُكُم وَلَكُم فيها ما تَدَّعونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccl{نُزُلًا مِن غَفورٍ رَحيمٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmccli{وَمَن أَحسَنُ قَولًا مِمَّن دَعا إِلَى اللَّهِ وَعَمِلَ صٰلِحًا وَقالَ إِنَّنى مِنَ المُسلِمينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcclii{وَلا تَستَوِى الحَسَنَةُ وَلَا السَّيِّئَةُ ادفَع بِالَّتى هِىَ أَحسَنُ فَإِذَا الَّذى بَينَكَ وَبَينَهُ عَدٰوَةٌ كَأَنَّهُ وَلِىٌّ حَميمٌ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmccliii{وَما يُلَقّىٰها إِلَّا الَّذينَ صَبَروا وَما يُلَقّىٰها إِلّا ذو حَظٍّ عَظيمٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmccliv{وَإِمّا يَنزَغَنَّكَ مِنَ الشَّيطٰنِ نَزغٌ فَاستَعِذ بِاللَّهِ إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcclv{وَمِن ءايٰتِهِ الَّيلُ وَالنَّهارُ وَالشَّمسُ وَالقَمَرُ لا تَسجُدوا لِلشَّمسِ وَلا لِلقَمَرِ وَاسجُدوا لِلَّهِ الَّذى خَلَقَهُنَّ إِن كُنتُم إِيّاهُ تَعبُدونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcclvi{فَإِنِ استَكبَروا فَالَّذينَ عِندَ رَبِّكَ يُسَبِّحونَ لَهُ بِالَّيلِ وَالنَّهارِ وَهُم لا يَسـَٔمونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcclvii{وَمِن ءايٰتِهِ أَنَّكَ تَرَى الأَرضَ خٰشِعَةً فَإِذا أَنزَلنا عَلَيهَا الماءَ اهتَزَّت وَرَبَت إِنَّ الَّذى أَحياها لَمُحىِ المَوتىٰ إِنَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcclviii{إِنَّ الَّذينَ يُلحِدونَ فى ءايٰتِنا لا يَخفَونَ عَلَينا أَفَمَن يُلقىٰ فِى النّارِ خَيرٌ أَم مَن يَأتى ءامِنًا يَومَ القِيٰمَةِ اعمَلوا ما شِئتُم إِنَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcclix{إِنَّ الَّذينَ كَفَروا بِالذِّكرِ لَمّا جاءَهُم وَإِنَّهُ لَكِتٰبٌ عَزيزٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcclx{لا يَأتيهِ البٰطِلُ مِن بَينِ يَدَيهِ وَلا مِن خَلفِهِ تَنزيلٌ مِن حَكيمٍ حَميدٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcclxi{ما يُقالُ لَكَ إِلّا ما قَد قيلَ لِلرُّسُلِ مِن قَبلِكَ إِنَّ رَبَّكَ لَذو مَغفِرَةٍ وَذو عِقابٍ أَليمٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcclxii{وَلَو جَعَلنٰهُ قُرءانًا أَعجَمِيًّا لَقالوا لَولا فُصِّلَت ءايٰتُهُ ءَأَعجَمِىٌّ وَعَرَبِىٌّ قُل هُوَ لِلَّذينَ ءامَنوا هُدًى وَشِفاءٌ وَالَّذينَ لا يُؤمِنونَ فى ءاذانِهِم وَقرٌ وَهُوَ عَلَيهِم عَمًى أُولٰئِكَ يُنادَونَ مِن مَكانٍ بَعيدٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcclxiii{وَلَقَد ءاتَينا موسَى الكِتٰبَ فَاختُلِفَ فيهِ وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ لَقُضِىَ بَينَهُم وَإِنَّهُم لَفى شَكٍّ مِنهُ مُريبٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcclxiv{مَن عَمِلَ صٰلِحًا فَلِنَفسِهِ وَمَن أَساءَ فَعَلَيها وَما رَبُّكَ بِظَلّٰمٍ لِلعَبيدِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcclxv{إِلَيهِ يُرَدُّ عِلمُ السّاعَةِ وَما تَخرُجُ مِن ثَمَرٰتٍ مِن أَكمامِها وَما تَحمِلُ مِن أُنثىٰ وَلا تَضَعُ إِلّا بِعِلمِهِ وَيَومَ يُناديهِم أَينَ شُرَكاءى قالوا ءاذَنّٰكَ ما مِنّا مِن شَهيدٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcclxvi{وَضَلَّ عَنهُم ما كانوا يَدعونَ مِن قَبلُ وَظَنّوا ما لَهُم مِن مَحيصٍ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcclxvii{لا يَسـَٔمُ الإِنسٰنُ مِن دُعاءِ الخَيرِ وَإِن مَسَّهُ الشَّرُّ فَيَـٔوسٌ قَنوطٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcclxviii{وَلَئِن أَذَقنٰهُ رَحمَةً مِنّا مِن بَعدِ ضَرّاءَ مَسَّتهُ لَيَقولَنَّ هٰذا لى وَما أَظُنُّ السّاعَةَ قائِمَةً وَلَئِن رُجِعتُ إِلىٰ رَبّى إِنَّ لى عِندَهُ لَلحُسنىٰ فَلَنُنَبِّئَنَّ الَّذينَ كَفَروا بِما عَمِلوا وَلَنُذيقَنَّهُم مِن عَذابٍ غَليظٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcclxix{وَإِذا أَنعَمنا عَلَى الإِنسٰنِ أَعرَضَ وَنَـٔا بِجانِبِهِ وَإِذا مَسَّهُ الشَّرُّ فَذو دُعاءٍ عَريضٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcclxx{قُل أَرَءَيتُم إِن كانَ مِن عِندِ اللَّهِ ثُمَّ كَفَرتُم بِهِ مَن أَضَلُّ مِمَّن هُوَ فى شِقاقٍ بَعيدٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxi{سَنُريهِم ءايٰتِنا فِى الءافاقِ وَفى أَنفُسِهِم حَتّىٰ يَتَبَيَّنَ لَهُم أَنَّهُ الحَقُّ أَوَلَم يَكفِ بِرَبِّكَ أَنَّهُ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxii{أَلا إِنَّهُم فى مِريَةٍ مِن لِقاءِ رَبِّهِم أَلا إِنَّهُ بِكُلِّ شَيءٍ مُحيطٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxiii{\basmalah  حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcclxxiv{عسق\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxv{كَذٰلِكَ يوحى إِلَيكَ وَإِلَى الَّذينَ مِن قَبلِكَ اللَّهُ العَزيزُ الحَكيمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxvi{لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَهُوَ العَلِىُّ العَظيمُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxvii{تَكادُ السَّمٰوٰتُ يَتَفَطَّرنَ مِن فَوقِهِنَّ وَالمَلٰئِكَةُ يُسَبِّحونَ بِحَمدِ رَبِّهِم وَيَستَغفِرونَ لِمَن فِى الأَرضِ أَلا إِنَّ اللَّهَ هُوَ الغَفورُ الرَّحيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcclxxviii{وَالَّذينَ اتَّخَذوا مِن دونِهِ أَولِياءَ اللَّهُ حَفيظٌ عَلَيهِم وَما أَنتَ عَلَيهِم بِوَكيلٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcclxxix{وَكَذٰلِكَ أَوحَينا إِلَيكَ قُرءانًا عَرَبِيًّا لِتُنذِرَ أُمَّ القُرىٰ وَمَن حَولَها وَتُنذِرَ يَومَ الجَمعِ لا رَيبَ فيهِ فَريقٌ فِى الجَنَّةِ وَفَريقٌ فِى السَّعيرِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcclxxx{وَلَو شاءَ اللَّهُ لَجَعَلَهُم أُمَّةً وٰحِدَةً وَلٰكِن يُدخِلُ مَن يَشاءُ فى رَحمَتِهِ وَالظّٰلِمونَ ما لَهُم مِن وَلِىٍّ وَلا نَصيرٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcclxxxi{أَمِ اتَّخَذوا مِن دونِهِ أَولِياءَ فَاللَّهُ هُوَ الوَلِىُّ وَهُوَ يُحىِ المَوتىٰ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcclxxxii{وَمَا اختَلَفتُم فيهِ مِن شَيءٍ فَحُكمُهُ إِلَى اللَّهِ ذٰلِكُمُ اللَّهُ رَبّى عَلَيهِ تَوَكَّلتُ وَإِلَيهِ أُنيبُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcclxxxiii{فاطِرُ السَّمٰوٰتِ وَالأَرضِ جَعَلَ لَكُم مِن أَنفُسِكُم أَزوٰجًا وَمِنَ الأَنعٰمِ أَزوٰجًا يَذرَؤُكُم فيهِ لَيسَ كَمِثلِهِ شَيءٌ وَهُوَ السَّميعُ البَصيرُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcclxxxiv{لَهُ مَقاليدُ السَّمٰوٰتِ وَالأَرضِ يَبسُطُ الرِّزقَ لِمَن يَشاءُ وَيَقدِرُ إِنَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcclxxxv{شَرَعَ لَكُم مِنَ الدّينِ ما وَصّىٰ بِهِ نوحًا وَالَّذى أَوحَينا إِلَيكَ وَما وَصَّينا بِهِ إِبرٰهيمَ وَموسىٰ وَعيسىٰ أَن أَقيمُوا الدّينَ وَلا تَتَفَرَّقوا فيهِ كَبُرَ عَلَى المُشرِكينَ ما تَدعوهُم إِلَيهِ اللَّهُ يَجتَبى إِلَيهِ مَن يَشاءُ وَيَهدى إِلَيهِ مَن يُنيبُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcclxxxvi{وَما تَفَرَّقوا إِلّا مِن بَعدِ ما جاءَهُمُ العِلمُ بَغيًا بَينَهُم وَلَولا كَلِمَةٌ سَبَقَت مِن رَبِّكَ إِلىٰ أَجَلٍ مُسَمًّى لَقُضِىَ بَينَهُم وَإِنَّ الَّذينَ أورِثُوا الكِتٰبَ مِن بَعدِهِم لَفى شَكٍّ مِنهُ مُريبٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcclxxxvii{فَلِذٰلِكَ فَادعُ وَاستَقِم كَما أُمِرتَ وَلا تَتَّبِع أَهواءَهُم وَقُل ءامَنتُ بِما أَنزَلَ اللَّهُ مِن كِتٰبٍ وَأُمِرتُ لِأَعدِلَ بَينَكُمُ اللَّهُ رَبُّنا وَرَبُّكُم لَنا أَعمٰلُنا وَلَكُم أَعمٰلُكُم لا حُجَّةَ بَينَنا وَبَينَكُمُ اللَّهُ يَجمَعُ بَينَنا وَإِلَيهِ المَصيرُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcclxxxviii{وَالَّذينَ يُحاجّونَ فِى اللَّهِ مِن بَعدِ مَا استُجيبَ لَهُ حُجَّتُهُم داحِضَةٌ عِندَ رَبِّهِم وَعَلَيهِم غَضَبٌ وَلَهُم عَذابٌ شَديدٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcclxxxix{اللَّهُ الَّذى أَنزَلَ الكِتٰبَ بِالحَقِّ وَالميزانَ وَما يُدريكَ لَعَلَّ السّاعَةَ قَريبٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmccxc{يَستَعجِلُ بِهَا الَّذينَ لا يُؤمِنونَ بِها وَالَّذينَ ءامَنوا مُشفِقونَ مِنها وَيَعلَمونَ أَنَّهَا الحَقُّ أَلا إِنَّ الَّذينَ يُمارونَ فِى السّاعَةِ لَفى ضَلٰلٍ بَعيدٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmccxci{اللَّهُ لَطيفٌ بِعِبادِهِ يَرزُقُ مَن يَشاءُ وَهُوَ القَوِىُّ العَزيزُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmccxcii{مَن كانَ يُريدُ حَرثَ الءاخِرَةِ نَزِد لَهُ فى حَرثِهِ وَمَن كانَ يُريدُ حَرثَ الدُّنيا نُؤتِهِ مِنها وَما لَهُ فِى الءاخِرَةِ مِن نَصيبٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmccxciii{أَم لَهُم شُرَكٰؤُا۟ شَرَعوا لَهُم مِنَ الدّينِ ما لَم يَأذَن بِهِ اللَّهُ وَلَولا كَلِمَةُ الفَصلِ لَقُضِىَ بَينَهُم وَإِنَّ الظّٰلِمينَ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmccxciv{تَرَى الظّٰلِمينَ مُشفِقينَ مِمّا كَسَبوا وَهُوَ واقِعٌ بِهِم وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ فى رَوضاتِ الجَنّاتِ لَهُم ما يَشاءونَ عِندَ رَبِّهِم ذٰلِكَ هُوَ الفَضلُ الكَبيرُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmccxcv{ذٰلِكَ الَّذى يُبَشِّرُ اللَّهُ عِبادَهُ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ قُل لا أَسـَٔلُكُم عَلَيهِ أَجرًا إِلَّا المَوَدَّةَ فِى القُربىٰ وَمَن يَقتَرِف حَسَنَةً نَزِد لَهُ فيها حُسنًا إِنَّ اللَّهَ غَفورٌ شَكورٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmccxcvi{أَم يَقولونَ افتَرىٰ عَلَى اللَّهِ كَذِبًا فَإِن يَشَإِ اللَّهُ يَختِم عَلىٰ قَلبِكَ وَيَمحُ اللَّهُ البٰطِلَ وَيُحِقُّ الحَقَّ بِكَلِمٰتِهِ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmccxcvii{وَهُوَ الَّذى يَقبَلُ التَّوبَةَ عَن عِبادِهِ وَيَعفوا عَنِ السَّيِّـٔاتِ وَيَعلَمُ ما تَفعَلونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmccxcviii{وَيَستَجيبُ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ وَيَزيدُهُم مِن فَضلِهِ وَالكٰفِرونَ لَهُم عَذابٌ شَديدٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccxcix{وَلَو بَسَطَ اللَّهُ الرِّزقَ لِعِبادِهِ لَبَغَوا فِى الأَرضِ وَلٰكِن يُنَزِّلُ بِقَدَرٍ ما يَشاءُ إِنَّهُ بِعِبادِهِ خَبيرٌ بَصيرٌ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmccc{وَهُوَ الَّذى يُنَزِّلُ الغَيثَ مِن بَعدِ ما قَنَطوا وَيَنشُرُ رَحمَتَهُ وَهُوَ الوَلِىُّ الحَميدُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmccci{وَمِن ءايٰتِهِ خَلقُ السَّمٰوٰتِ وَالأَرضِ وَما بَثَّ فيهِما مِن دابَّةٍ وَهُوَ عَلىٰ جَمعِهِم إِذا يَشاءُ قَديرٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcccii{وَما أَصٰبَكُم مِن مُصيبَةٍ فَبِما كَسَبَت أَيديكُم وَيَعفوا عَن كَثيرٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccciii{وَما أَنتُم بِمُعجِزينَ فِى الأَرضِ وَما لَكُم مِن دونِ اللَّهِ مِن وَلِىٍّ وَلا نَصيرٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccciv{وَمِن ءايٰتِهِ الجَوارِ فِى البَحرِ كَالأَعلٰمِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcccv{إِن يَشَأ يُسكِنِ الرّيحَ فَيَظلَلنَ رَواكِدَ عَلىٰ ظَهرِهِ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِكُلِّ صَبّارٍ شَكورٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcccvi{أَو يوبِقهُنَّ بِما كَسَبوا وَيَعفُ عَن كَثيرٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcccvii{وَيَعلَمَ الَّذينَ يُجٰدِلونَ فى ءايٰتِنا ما لَهُم مِن مَحيصٍ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcccviii{فَما أوتيتُم مِن شَيءٍ فَمَتٰعُ الحَيوٰةِ الدُّنيا وَما عِندَ اللَّهِ خَيرٌ وَأَبقىٰ لِلَّذينَ ءامَنوا وَعَلىٰ رَبِّهِم يَتَوَكَّلونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcccix{وَالَّذينَ يَجتَنِبونَ كَبٰئِرَ الإِثمِ وَالفَوٰحِشَ وَإِذا ما غَضِبوا هُم يَغفِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcccx{وَالَّذينَ استَجابوا لِرَبِّهِم وَأَقامُوا الصَّلوٰةَ وَأَمرُهُم شورىٰ بَينَهُم وَمِمّا رَزَقنٰهُم يُنفِقونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcccxi{وَالَّذينَ إِذا أَصابَهُمُ البَغىُ هُم يَنتَصِرونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcccxii{وَجَزٰؤُا۟ سَيِّئَةٍ سَيِّئَةٌ مِثلُها فَمَن عَفا وَأَصلَحَ فَأَجرُهُ عَلَى اللَّهِ إِنَّهُ لا يُحِبُّ الظّٰلِمينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcccxiii{وَلَمَنِ انتَصَرَ بَعدَ ظُلمِهِ فَأُولٰئِكَ ما عَلَيهِم مِن سَبيلٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcccxiv{إِنَّمَا السَّبيلُ عَلَى الَّذينَ يَظلِمونَ النّاسَ وَيَبغونَ فِى الأَرضِ بِغَيرِ الحَقِّ أُولٰئِكَ لَهُم عَذابٌ أَليمٌ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcccxv{وَلَمَن صَبَرَ وَغَفَرَ إِنَّ ذٰلِكَ لَمِن عَزمِ الأُمورِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcccxvi{وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن وَلِىٍّ مِن بَعدِهِ وَتَرَى الظّٰلِمينَ لَمّا رَأَوُا العَذابَ يَقولونَ هَل إِلىٰ مَرَدٍّ مِن سَبيلٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcccxvii{وَتَرىٰهُم يُعرَضونَ عَلَيها خٰشِعينَ مِنَ الذُّلِّ يَنظُرونَ مِن طَرفٍ خَفِىٍّ وَقالَ الَّذينَ ءامَنوا إِنَّ الخٰسِرينَ الَّذينَ خَسِروا أَنفُسَهُم وَأَهليهِم يَومَ القِيٰمَةِ أَلا إِنَّ الظّٰلِمينَ فى عَذابٍ مُقيمٍ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcccxviii{وَما كانَ لَهُم مِن أَولِياءَ يَنصُرونَهُم مِن دونِ اللَّهِ وَمَن يُضلِلِ اللَّهُ فَما لَهُ مِن سَبيلٍ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcccxix{استَجيبوا لِرَبِّكُم مِن قَبلِ أَن يَأتِىَ يَومٌ لا مَرَدَّ لَهُ مِنَ اللَّهِ ما لَكُم مِن مَلجَإٍ يَومَئِذٍ وَما لَكُم مِن نَكيرٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcccxx{فَإِن أَعرَضوا فَما أَرسَلنٰكَ عَلَيهِم حَفيظًا إِن عَلَيكَ إِلَّا البَلٰغُ وَإِنّا إِذا أَذَقنَا الإِنسٰنَ مِنّا رَحمَةً فَرِحَ بِها وَإِن تُصِبهُم سَيِّئَةٌ بِما قَدَّمَت أَيديهِم فَإِنَّ الإِنسٰنَ كَفورٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcccxxi{لِلَّهِ مُلكُ السَّمٰوٰتِ وَالأَرضِ يَخلُقُ ما يَشاءُ يَهَبُ لِمَن يَشاءُ إِنٰثًا وَيَهَبُ لِمَن يَشاءُ الذُّكورَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcccxxii{أَو يُزَوِّجُهُم ذُكرانًا وَإِنٰثًا وَيَجعَلُ مَن يَشاءُ عَقيمًا إِنَّهُ عَليمٌ قَديرٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcccxxiii{وَما كانَ لِبَشَرٍ أَن يُكَلِّمَهُ اللَّهُ إِلّا وَحيًا أَو مِن وَرائِ حِجابٍ أَو يُرسِلَ رَسولًا فَيوحِىَ بِإِذنِهِ ما يَشاءُ إِنَّهُ عَلِىٌّ حَكيمٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcccxxiv{وَكَذٰلِكَ أَوحَينا إِلَيكَ روحًا مِن أَمرِنا ما كُنتَ تَدرى مَا الكِتٰبُ وَلَا الإيمٰنُ وَلٰكِن جَعَلنٰهُ نورًا نَهدى بِهِ مَن نَشاءُ مِن عِبادِنا وَإِنَّكَ لَتَهدى إِلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxv{صِرٰطِ اللَّهِ الَّذى لَهُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ أَلا إِلَى اللَّهِ تَصيرُ الأُمورُ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxvi{\basmalah  حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcccxxvii{وَالكِتٰبِ المُبينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxviii{إِنّا جَعَلنٰهُ قُرءٰنًا عَرَبِيًّا لَعَلَّكُم تَعقِلونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxix{وَإِنَّهُ فى أُمِّ الكِتٰبِ لَدَينا لَعَلِىٌّ حَكيمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcccxxx{أَفَنَضرِبُ عَنكُمُ الذِّكرَ صَفحًا أَن كُنتُم قَومًا مُسرِفينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcccxxxi{وَكَم أَرسَلنا مِن نَبِىٍّ فِى الأَوَّلينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcccxxxii{وَما يَأتيهِم مِن نَبِىٍّ إِلّا كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcccxxxiii{فَأَهلَكنا أَشَدَّ مِنهُم بَطشًا وَمَضىٰ مَثَلُ الأَوَّلينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcccxxxiv{وَلَئِن سَأَلتَهُم مَن خَلَقَ السَّمٰوٰتِ وَالأَرضَ لَيَقولُنَّ خَلَقَهُنَّ العَزيزُ العَليمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcccxxxv{الَّذى جَعَلَ لَكُمُ الأَرضَ مَهدًا وَجَعَلَ لَكُم فيها سُبُلًا لَعَلَّكُم تَهتَدونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcccxxxvi{وَالَّذى نَزَّلَ مِنَ السَّماءِ ماءً بِقَدَرٍ فَأَنشَرنا بِهِ بَلدَةً مَيتًا كَذٰلِكَ تُخرَجونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcccxxxvii{وَالَّذى خَلَقَ الأَزوٰجَ كُلَّها وَجَعَلَ لَكُم مِنَ الفُلكِ وَالأَنعٰمِ ما تَركَبونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcccxxxviii{لِتَستَوۥا عَلىٰ ظُهورِهِ ثُمَّ تَذكُروا نِعمَةَ رَبِّكُم إِذَا استَوَيتُم عَلَيهِ وَتَقولوا سُبحٰنَ الَّذى سَخَّرَ لَنا هٰذا وَما كُنّا لَهُ مُقرِنينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcccxxxix{وَإِنّا إِلىٰ رَبِّنا لَمُنقَلِبونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcccxl{وَجَعَلوا لَهُ مِن عِبادِهِ جُزءًا إِنَّ الإِنسٰنَ لَكَفورٌ مُبينٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcccxli{أَمِ اتَّخَذَ مِمّا يَخلُقُ بَناتٍ وَأَصفىٰكُم بِالبَنينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcccxlii{وَإِذا بُشِّرَ أَحَدُهُم بِما ضَرَبَ لِلرَّحمٰنِ مَثَلًا ظَلَّ وَجهُهُ مُسوَدًّا وَهُوَ كَظيمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcccxliii{أَوَمَن يُنَشَّؤُا۟ فِى الحِليَةِ وَهُوَ فِى الخِصامِ غَيرُ مُبينٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcccxliv{وَجَعَلُوا المَلٰئِكَةَ الَّذينَ هُم عِبٰدُ الرَّحمٰنِ إِنٰثًا أَشَهِدوا خَلقَهُم سَتُكتَبُ شَهٰدَتُهُم وَيُسـَٔلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcccxlv{وَقالوا لَو شاءَ الرَّحمٰنُ ما عَبَدنٰهُم ما لَهُم بِذٰلِكَ مِن عِلمٍ إِن هُم إِلّا يَخرُصونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcccxlvi{أَم ءاتَينٰهُم كِتٰبًا مِن قَبلِهِ فَهُم بِهِ مُستَمسِكونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcccxlvii{بَل قالوا إِنّا وَجَدنا ءاباءَنا عَلىٰ أُمَّةٍ وَإِنّا عَلىٰ ءاثٰرِهِم مُهتَدونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcccxlviii{وَكَذٰلِكَ ما أَرسَلنا مِن قَبلِكَ فى قَريَةٍ مِن نَذيرٍ إِلّا قالَ مُترَفوها إِنّا وَجَدنا ءاباءَنا عَلىٰ أُمَّةٍ وَإِنّا عَلىٰ ءاثٰرِهِم مُقتَدونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcccxlix{قٰلَ أَوَلَو جِئتُكُم بِأَهدىٰ مِمّا وَجَدتُم عَلَيهِ ءاباءَكُم قالوا إِنّا بِما أُرسِلتُم بِهِ كٰفِرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcccl{فَانتَقَمنا مِنهُم فَانظُر كَيفَ كانَ عٰقِبَةُ المُكَذِّبينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcccli{وَإِذ قالَ إِبرٰهيمُ لِأَبيهِ وَقَومِهِ إِنَّنى بَراءٌ مِمّا تَعبُدونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmccclii{إِلَّا الَّذى فَطَرَنى فَإِنَّهُ سَيَهدينِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcccliii{وَجَعَلَها كَلِمَةً باقِيَةً فى عَقِبِهِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcccliv{بَل مَتَّعتُ هٰؤُلاءِ وَءاباءَهُم حَتّىٰ جاءَهُمُ الحَقُّ وَرَسولٌ مُبينٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmccclv{وَلَمّا جاءَهُمُ الحَقُّ قالوا هٰذا سِحرٌ وَإِنّا بِهِ كٰفِرونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmccclvi{وَقالوا لَولا نُزِّلَ هٰذَا القُرءانُ عَلىٰ رَجُلٍ مِنَ القَريَتَينِ عَظيمٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmccclvii{أَهُم يَقسِمونَ رَحمَتَ رَبِّكَ نَحنُ قَسَمنا بَينَهُم مَعيشَتَهُم فِى الحَيوٰةِ الدُّنيا وَرَفَعنا بَعضَهُم فَوقَ بَعضٍ دَرَجٰتٍ لِيَتَّخِذَ بَعضُهُم بَعضًا سُخرِيًّا وَرَحمَتُ رَبِّكَ خَيرٌ مِمّا يَجمَعونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmccclviii{وَلَولا أَن يَكونَ النّاسُ أُمَّةً وٰحِدَةً لَجَعَلنا لِمَن يَكفُرُ بِالرَّحمٰنِ لِبُيوتِهِم سُقُفًا مِن فِضَّةٍ وَمَعارِجَ عَلَيها يَظهَرونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmccclix{وَلِبُيوتِهِم أَبوٰبًا وَسُرُرًا عَلَيها يَتَّكِـٔونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmccclx{وَزُخرُفًا وَإِن كُلُّ ذٰلِكَ لَمّا مَتٰعُ الحَيوٰةِ الدُّنيا وَالءاخِرَةُ عِندَ رَبِّكَ لِلمُتَّقينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmccclxi{وَمَن يَعشُ عَن ذِكرِ الرَّحمٰنِ نُقَيِّض لَهُ شَيطٰنًا فَهُوَ لَهُ قَرينٌ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmccclxii{وَإِنَّهُم لَيَصُدّونَهُم عَنِ السَّبيلِ وَيَحسَبونَ أَنَّهُم مُهتَدونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmccclxiii{حَتّىٰ إِذا جاءَنا قالَ يٰلَيتَ بَينى وَبَينَكَ بُعدَ المَشرِقَينِ فَبِئسَ القَرينُ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmccclxiv{وَلَن يَنفَعَكُمُ اليَومَ إِذ ظَلَمتُم أَنَّكُم فِى العَذابِ مُشتَرِكونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmccclxv{أَفَأَنتَ تُسمِعُ الصُّمَّ أَو تَهدِى العُمىَ وَمَن كانَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmccclxvi{فَإِمّا نَذهَبَنَّ بِكَ فَإِنّا مِنهُم مُنتَقِمونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmccclxvii{أَو نُرِيَنَّكَ الَّذى وَعَدنٰهُم فَإِنّا عَلَيهِم مُقتَدِرونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmccclxviii{فَاستَمسِك بِالَّذى أوحِىَ إِلَيكَ إِنَّكَ عَلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmccclxix{وَإِنَّهُ لَذِكرٌ لَكَ وَلِقَومِكَ وَسَوفَ تُسـَٔلونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmccclxx{وَسـَٔل مَن أَرسَلنا مِن قَبلِكَ مِن رُسُلِنا أَجَعَلنا مِن دونِ الرَّحمٰنِ ءالِهَةً يُعبَدونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmccclxxi{وَلَقَد أَرسَلنا موسىٰ بِـٔايٰتِنا إِلىٰ فِرعَونَ وَمَلَإِي۟هِ فَقالَ إِنّى رَسولُ رَبِّ العٰلَمينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmccclxxii{فَلَمّا جاءَهُم بِـٔايٰتِنا إِذا هُم مِنها يَضحَكونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmccclxxiii{وَما نُريهِم مِن ءايَةٍ إِلّا هِىَ أَكبَرُ مِن أُختِها وَأَخَذنٰهُم بِالعَذابِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmccclxxiv{وَقالوا يٰأَيُّهَ السّاحِرُ ادعُ لَنا رَبَّكَ بِما عَهِدَ عِندَكَ إِنَّنا لَمُهتَدونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmccclxxv{فَلَمّا كَشَفنا عَنهُمُ العَذابَ إِذا هُم يَنكُثونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmccclxxvi{وَنادىٰ فِرعَونُ فى قَومِهِ قالَ يٰقَومِ أَلَيسَ لى مُلكُ مِصرَ وَهٰذِهِ الأَنهٰرُ تَجرى مِن تَحتى أَفَلا تُبصِرونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmccclxxvii{أَم أَنا۠ خَيرٌ مِن هٰذَا الَّذى هُوَ مَهينٌ وَلا يَكادُ يُبينُ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmccclxxviii{فَلَولا أُلقِىَ عَلَيهِ أَسوِرَةٌ مِن ذَهَبٍ أَو جاءَ مَعَهُ المَلٰئِكَةُ مُقتَرِنينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmccclxxix{فَاستَخَفَّ قَومَهُ فَأَطاعوهُ إِنَّهُم كانوا قَومًا فٰسِقينَ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmccclxxx{فَلَمّا ءاسَفونَا انتَقَمنا مِنهُم فَأَغرَقنٰهُم أَجمَعينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmccclxxxi{فَجَعَلنٰهُم سَلَفًا وَمَثَلًا لِلءاخِرينَ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmccclxxxii{وَلَمّا ضُرِبَ ابنُ مَريَمَ مَثَلًا إِذا قَومُكَ مِنهُ يَصِدّونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmccclxxxiii{وَقالوا ءَأٰلِهَتُنا خَيرٌ أَم هُوَ ما ضَرَبوهُ لَكَ إِلّا جَدَلًا بَل هُم قَومٌ خَصِمونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmccclxxxiv{إِن هُوَ إِلّا عَبدٌ أَنعَمنا عَلَيهِ وَجَعَلنٰهُ مَثَلًا لِبَنى إِسرٰءيلَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmccclxxxv{وَلَو نَشاءُ لَجَعَلنا مِنكُم مَلٰئِكَةً فِى الأَرضِ يَخلُفونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmccclxxxvi{وَإِنَّهُ لَعِلمٌ لِلسّاعَةِ فَلا تَمتَرُنَّ بِها وَاتَّبِعونِ هٰذا صِرٰطٌ مُستَقيمٌ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmccclxxxvii{وَلا يَصُدَّنَّكُمُ الشَّيطٰنُ إِنَّهُ لَكُم عَدُوٌّ مُبينٌ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmccclxxxviii{وَلَمّا جاءَ عيسىٰ بِالبَيِّنٰتِ قالَ قَد جِئتُكُم بِالحِكمَةِ وَلِأُبَيِّنَ لَكُم بَعضَ الَّذى تَختَلِفونَ فيهِ فَاتَّقُوا اللَّهَ وَأَطيعونِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmccclxxxix{إِنَّ اللَّهَ هُوَ رَبّى وَرَبُّكُم فَاعبُدوهُ هٰذا صِرٰطٌ مُستَقيمٌ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcccxc{فَاختَلَفَ الأَحزابُ مِن بَينِهِم فَوَيلٌ لِلَّذينَ ظَلَموا مِن عَذابِ يَومٍ أَليمٍ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcccxci{هَل يَنظُرونَ إِلَّا السّاعَةَ أَن تَأتِيَهُم بَغتَةً وَهُم لا يَشعُرونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcccxcii{الأَخِلّاءُ يَومَئِذٍ بَعضُهُم لِبَعضٍ عَدُوٌّ إِلَّا المُتَّقينَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcccxciii{يٰعِبادِ لا خَوفٌ عَلَيكُمُ اليَومَ وَلا أَنتُم تَحزَنونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcccxciv{الَّذينَ ءامَنوا بِـٔايٰتِنا وَكانوا مُسلِمينَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcccxcv{ادخُلُوا الجَنَّةَ أَنتُم وَأَزوٰجُكُم تُحبَرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcccxcvi{يُطافُ عَلَيهِم بِصِحافٍ مِن ذَهَبٍ وَأَكوابٍ وَفيها ما تَشتَهيهِ الأَنفُسُ وَتَلَذُّ الأَعيُنُ وَأَنتُم فيها خٰلِدونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcccxcvii{وَتِلكَ الجَنَّةُ الَّتى أورِثتُموها بِما كُنتُم تَعمَلونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcccxcviii{لَكُم فيها فٰكِهَةٌ كَثيرَةٌ مِنها تَأكُلونَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcccxcix{إِنَّ المُجرِمينَ فى عَذابِ جَهَنَّمَ خٰلِدونَ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcd{لا يُفَتَّرُ عَنهُم وَهُم فيهِ مُبلِسونَ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcdi{وَما ظَلَمنٰهُم وَلٰكِن كانوا هُمُ الظّٰلِمينَ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmcdii{وَنادَوا يٰمٰلِكُ لِيَقضِ عَلَينا رَبُّكَ قالَ إِنَّكُم مٰكِثونَ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmcdiii{لَقَد جِئنٰكُم بِالحَقِّ وَلٰكِنَّ أَكثَرَكُم لِلحَقِّ كٰرِهونَ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmcdiv{أَم أَبرَموا أَمرًا فَإِنّا مُبرِمونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmcdv{أَم يَحسَبونَ أَنّا لا نَسمَعُ سِرَّهُم وَنَجوىٰهُم بَلىٰ وَرُسُلُنا لَدَيهِم يَكتُبونَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmcdvi{قُل إِن كانَ لِلرَّحمٰنِ وَلَدٌ فَأَنا۠ أَوَّلُ العٰبِدينَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmcdvii{سُبحٰنَ رَبِّ السَّمٰوٰتِ وَالأَرضِ رَبِّ العَرشِ عَمّا يَصِفونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmcdviii{فَذَرهُم يَخوضوا وَيَلعَبوا حَتّىٰ يُلٰقوا يَومَهُمُ الَّذى يوعَدونَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmcdix{وَهُوَ الَّذى فِى السَّماءِ إِلٰهٌ وَفِى الأَرضِ إِلٰهٌ وَهُوَ الحَكيمُ العَليمُ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmcdx{وَتَبارَكَ الَّذى لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُما وَعِندَهُ عِلمُ السّاعَةِ وَإِلَيهِ تُرجَعونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmcdxi{وَلا يَملِكُ الَّذينَ يَدعونَ مِن دونِهِ الشَّفٰعَةَ إِلّا مَن شَهِدَ بِالحَقِّ وَهُم يَعلَمونَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmcdxii{وَلَئِن سَأَلتَهُم مَن خَلَقَهُم لَيَقولُنَّ اللَّهُ فَأَنّىٰ يُؤفَكونَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmcdxiii{وَقيلِهِ يٰرَبِّ إِنَّ هٰؤُلاءِ قَومٌ لا يُؤمِنونَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmcdxiv{فَاصفَح عَنهُم وَقُل سَلٰمٌ فَسَوفَ يَعلَمونَ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmmcdxv{\basmalah  حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcdxvi{وَالكِتٰبِ المُبينِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcdxvii{إِنّا أَنزَلنٰهُ فى لَيلَةٍ مُبٰرَكَةٍ إِنّا كُنّا مُنذِرينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcdxviii{فيها يُفرَقُ كُلُّ أَمرٍ حَكيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcdxix{أَمرًا مِن عِندِنا إِنّا كُنّا مُرسِلينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcdxx{رَحمَةً مِن رَبِّكَ إِنَّهُ هُوَ السَّميعُ العَليمُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcdxxi{رَبِّ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُما إِن كُنتُم موقِنينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcdxxii{لا إِلٰهَ إِلّا هُوَ يُحيۦ وَيُميتُ رَبُّكُم وَرَبُّ ءابائِكُمُ الأَوَّلينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcdxxiii{بَل هُم فى شَكٍّ يَلعَبونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcdxxiv{فَارتَقِب يَومَ تَأتِى السَّماءُ بِدُخانٍ مُبينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcdxxv{يَغشَى النّاسَ هٰذا عَذابٌ أَليمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcdxxvi{رَبَّنَا اكشِف عَنَّا العَذابَ إِنّا مُؤمِنونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcdxxvii{أَنّىٰ لَهُمُ الذِّكرىٰ وَقَد جاءَهُم رَسولٌ مُبينٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcdxxviii{ثُمَّ تَوَلَّوا عَنهُ وَقالوا مُعَلَّمٌ مَجنونٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcdxxix{إِنّا كاشِفُوا العَذابِ قَليلًا إِنَّكُم عائِدونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcdxxx{يَومَ نَبطِشُ البَطشَةَ الكُبرىٰ إِنّا مُنتَقِمونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcdxxxi{وَلَقَد فَتَنّا قَبلَهُم قَومَ فِرعَونَ وَجاءَهُم رَسولٌ كَريمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcdxxxii{أَن أَدّوا إِلَىَّ عِبادَ اللَّهِ إِنّى لَكُم رَسولٌ أَمينٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcdxxxiii{وَأَن لا تَعلوا عَلَى اللَّهِ إِنّى ءاتيكُم بِسُلطٰنٍ مُبينٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcdxxxiv{وَإِنّى عُذتُ بِرَبّى وَرَبِّكُم أَن تَرجُمونِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcdxxxv{وَإِن لَم تُؤمِنوا لى فَاعتَزِلونِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcdxxxvi{فَدَعا رَبَّهُ أَنَّ هٰؤُلاءِ قَومٌ مُجرِمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcdxxxvii{فَأَسرِ بِعِبادى لَيلًا إِنَّكُم مُتَّبَعونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcdxxxviii{وَاترُكِ البَحرَ رَهوًا إِنَّهُم جُندٌ مُغرَقونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcdxxxix{كَم تَرَكوا مِن جَنّٰتٍ وَعُيونٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcdxl{وَزُروعٍ وَمَقامٍ كَريمٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmcdxli{وَنَعمَةٍ كانوا فيها فٰكِهينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcdxlii{كَذٰلِكَ وَأَورَثنٰها قَومًا ءاخَرينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcdxliii{فَما بَكَت عَلَيهِمُ السَّماءُ وَالأَرضُ وَما كانوا مُنظَرينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcdxliv{وَلَقَد نَجَّينا بَنى إِسرٰءيلَ مِنَ العَذابِ المُهينِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmcdxlv{مِن فِرعَونَ إِنَّهُ كانَ عالِيًا مِنَ المُسرِفينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmcdxlvi{وَلَقَدِ اختَرنٰهُم عَلىٰ عِلمٍ عَلَى العٰلَمينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcdxlvii{وَءاتَينٰهُم مِنَ الءايٰتِ ما فيهِ بَلٰؤٌا۟ مُبينٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcdxlviii{إِنَّ هٰؤُلاءِ لَيَقولونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcdxlix{إِن هِىَ إِلّا مَوتَتُنَا الأولىٰ وَما نَحنُ بِمُنشَرينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcdl{فَأتوا بِـٔابائِنا إِن كُنتُم صٰدِقينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcdli{أَهُم خَيرٌ أَم قَومُ تُبَّعٍ وَالَّذينَ مِن قَبلِهِم أَهلَكنٰهُم إِنَّهُم كانوا مُجرِمينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcdlii{وَما خَلَقنَا السَّمٰوٰتِ وَالأَرضَ وَما بَينَهُما لٰعِبينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcdliii{ما خَلَقنٰهُما إِلّا بِالحَقِّ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcdliv{إِنَّ يَومَ الفَصلِ ميقٰتُهُم أَجمَعينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcdlv{يَومَ لا يُغنى مَولًى عَن مَولًى شَيـًٔا وَلا هُم يُنصَرونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcdlvi{إِلّا مَن رَحِمَ اللَّهُ إِنَّهُ هُوَ العَزيزُ الرَّحيمُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcdlvii{إِنَّ شَجَرَتَ الزَّقّومِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcdlviii{طَعامُ الأَثيمِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcdlix{كَالمُهلِ يَغلى فِى البُطونِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcdlx{كَغَلىِ الحَميمِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxi{خُذوهُ فَاعتِلوهُ إِلىٰ سَواءِ الجَحيمِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxii{ثُمَّ صُبّوا فَوقَ رَأسِهِ مِن عَذابِ الحَميمِ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxiii{ذُق إِنَّكَ أَنتَ العَزيزُ الكَريمُ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxiv{إِنَّ هٰذا ما كُنتُم بِهِ تَمتَرونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcdlxv{إِنَّ المُتَّقينَ فى مَقامٍ أَمينٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcdlxvi{فى جَنّٰتٍ وَعُيونٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxvii{يَلبَسونَ مِن سُندُسٍ وَإِستَبرَقٍ مُتَقٰبِلينَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxviii{كَذٰلِكَ وَزَوَّجنٰهُم بِحورٍ عينٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxix{يَدعونَ فيها بِكُلِّ فٰكِهَةٍ ءامِنينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxx{لا يَذوقونَ فيهَا المَوتَ إِلَّا المَوتَةَ الأولىٰ وَوَقىٰهُم عَذابَ الجَحيمِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxxi{فَضلًا مِن رَبِّكَ ذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxxii{فَإِنَّما يَسَّرنٰهُ بِلِسانِكَ لَعَلَّهُم يَتَذَكَّرونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxxiii{فَارتَقِب إِنَّهُم مُرتَقِبونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxxiv{\basmalah  حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcdlxxv{تَنزيلُ الكِتٰبِ مِنَ اللَّهِ العَزيزِ الحَكيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxxvi{إِنَّ فِى السَّمٰوٰتِ وَالأَرضِ لَءايٰتٍ لِلمُؤمِنينَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxxvii{وَفى خَلقِكُم وَما يَبُثُّ مِن دابَّةٍ ءايٰتٌ لِقَومٍ يوقِنونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxxviii{وَاختِلٰفِ الَّيلِ وَالنَّهارِ وَما أَنزَلَ اللَّهُ مِنَ السَّماءِ مِن رِزقٍ فَأَحيا بِهِ الأَرضَ بَعدَ مَوتِها وَتَصريفِ الرِّيٰحِ ءايٰتٌ لِقَومٍ يَعقِلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxxix{تِلكَ ءايٰتُ اللَّهِ نَتلوها عَلَيكَ بِالحَقِّ فَبِأَىِّ حَديثٍ بَعدَ اللَّهِ وَءايٰتِهِ يُؤمِنونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcdlxxx{وَيلٌ لِكُلِّ أَفّاكٍ أَثيمٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxi{يَسمَعُ ءايٰتِ اللَّهِ تُتلىٰ عَلَيهِ ثُمَّ يُصِرُّ مُستَكبِرًا كَأَن لَم يَسمَعها فَبَشِّرهُ بِعَذابٍ أَليمٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxii{وَإِذا عَلِمَ مِن ءايٰتِنا شَيـًٔا اتَّخَذَها هُزُوًا أُولٰئِكَ لَهُم عَذابٌ مُهينٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxiii{مِن وَرائِهِم جَهَنَّمُ وَلا يُغنى عَنهُم ما كَسَبوا شَيـًٔا وَلا مَا اتَّخَذوا مِن دونِ اللَّهِ أَولِياءَ وَلَهُم عَذابٌ عَظيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxiv{هٰذا هُدًى وَالَّذينَ كَفَروا بِـٔايٰتِ رَبِّهِم لَهُم عَذابٌ مِن رِجزٍ أَليمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxv{اللَّهُ الَّذى سَخَّرَ لَكُمُ البَحرَ لِتَجرِىَ الفُلكُ فيهِ بِأَمرِهِ وَلِتَبتَغوا مِن فَضلِهِ وَلَعَلَّكُم تَشكُرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxvi{وَسَخَّرَ لَكُم ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ جَميعًا مِنهُ إِنَّ فى ذٰلِكَ لَءايٰتٍ لِقَومٍ يَتَفَكَّرونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxvii{قُل لِلَّذينَ ءامَنوا يَغفِروا لِلَّذينَ لا يَرجونَ أَيّامَ اللَّهِ لِيَجزِىَ قَومًا بِما كانوا يَكسِبونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxviii{مَن عَمِلَ صٰلِحًا فَلِنَفسِهِ وَمَن أَساءَ فَعَلَيها ثُمَّ إِلىٰ رَبِّكُم تُرجَعونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcdlxxxix{وَلَقَد ءاتَينا بَنى إِسرٰءيلَ الكِتٰبَ وَالحُكمَ وَالنُّبُوَّةَ وَرَزَقنٰهُم مِنَ الطَّيِّبٰتِ وَفَضَّلنٰهُم عَلَى العٰلَمينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcdxc{وَءاتَينٰهُم بَيِّنٰتٍ مِنَ الأَمرِ فَمَا اختَلَفوا إِلّا مِن بَعدِ ما جاءَهُمُ العِلمُ بَغيًا بَينَهُم إِنَّ رَبَّكَ يَقضى بَينَهُم يَومَ القِيٰمَةِ فيما كانوا فيهِ يَختَلِفونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcdxci{ثُمَّ جَعَلنٰكَ عَلىٰ شَريعَةٍ مِنَ الأَمرِ فَاتَّبِعها وَلا تَتَّبِع أَهواءَ الَّذينَ لا يَعلَمونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcdxcii{إِنَّهُم لَن يُغنوا عَنكَ مِنَ اللَّهِ شَيـًٔا وَإِنَّ الظّٰلِمينَ بَعضُهُم أَولِياءُ بَعضٍ وَاللَّهُ وَلِىُّ المُتَّقينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcdxciii{هٰذا بَصٰئِرُ لِلنّاسِ وَهُدًى وَرَحمَةٌ لِقَومٍ يوقِنونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcdxciv{أَم حَسِبَ الَّذينَ اجتَرَحُوا السَّيِّـٔاتِ أَن نَجعَلَهُم كَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ سَواءً مَحياهُم وَمَماتُهُم ساءَ ما يَحكُمونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcdxcv{وَخَلَقَ اللَّهُ السَّمٰوٰتِ وَالأَرضَ بِالحَقِّ وَلِتُجزىٰ كُلُّ نَفسٍ بِما كَسَبَت وَهُم لا يُظلَمونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcdxcvi{أَفَرَءَيتَ مَنِ اتَّخَذَ إِلٰهَهُ هَوىٰهُ وَأَضَلَّهُ اللَّهُ عَلىٰ عِلمٍ وَخَتَمَ عَلىٰ سَمعِهِ وَقَلبِهِ وَجَعَلَ عَلىٰ بَصَرِهِ غِشٰوَةً فَمَن يَهديهِ مِن بَعدِ اللَّهِ أَفَلا تَذَكَّرونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcdxcvii{وَقالوا ما هِىَ إِلّا حَياتُنَا الدُّنيا نَموتُ وَنَحيا وَما يُهلِكُنا إِلَّا الدَّهرُ وَما لَهُم بِذٰلِكَ مِن عِلمٍ إِن هُم إِلّا يَظُنّونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcdxcviii{وَإِذا تُتلىٰ عَلَيهِم ءايٰتُنا بَيِّنٰتٍ ما كانَ حُجَّتَهُم إِلّا أَن قالُوا ائتوا بِـٔابائِنا إِن كُنتُم صٰدِقينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcdxcix{قُلِ اللَّهُ يُحييكُم ثُمَّ يُميتُكُم ثُمَّ يَجمَعُكُم إِلىٰ يَومِ القِيٰمَةِ لا رَيبَ فيهِ وَلٰكِنَّ أَكثَرَ النّاسِ لا يَعلَمونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmd{وَلِلَّهِ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَيَومَ تَقومُ السّاعَةُ يَومَئِذٍ يَخسَرُ المُبطِلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdi{وَتَرىٰ كُلَّ أُمَّةٍ جاثِيَةً كُلُّ أُمَّةٍ تُدعىٰ إِلىٰ كِتٰبِهَا اليَومَ تُجزَونَ ما كُنتُم تَعمَلونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdii{هٰذا كِتٰبُنا يَنطِقُ عَلَيكُم بِالحَقِّ إِنّا كُنّا نَستَنسِخُ ما كُنتُم تَعمَلونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdiii{فَأَمَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ فَيُدخِلُهُم رَبُّهُم فى رَحمَتِهِ ذٰلِكَ هُوَ الفَوزُ المُبينُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdiv{وَأَمَّا الَّذينَ كَفَروا أَفَلَم تَكُن ءايٰتى تُتلىٰ عَلَيكُم فَاستَكبَرتُم وَكُنتُم قَومًا مُجرِمينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdv{وَإِذا قيلَ إِنَّ وَعدَ اللَّهِ حَقٌّ وَالسّاعَةُ لا رَيبَ فيها قُلتُم ما نَدرى مَا السّاعَةُ إِن نَظُنُّ إِلّا ظَنًّا وَما نَحنُ بِمُستَيقِنينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdvi{وَبَدا لَهُم سَيِّـٔاتُ ما عَمِلوا وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdvii{وَقيلَ اليَومَ نَنسىٰكُم كَما نَسيتُم لِقاءَ يَومِكُم هٰذا وَمَأوىٰكُمُ النّارُ وَما لَكُم مِن نٰصِرينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdviii{ذٰلِكُم بِأَنَّكُمُ اتَّخَذتُم ءايٰتِ اللَّهِ هُزُوًا وَغَرَّتكُمُ الحَيوٰةُ الدُّنيا فَاليَومَ لا يُخرَجونَ مِنها وَلا هُم يُستَعتَبونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdix{فَلِلَّهِ الحَمدُ رَبِّ السَّمٰوٰتِ وَرَبِّ الأَرضِ رَبِّ العٰلَمينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdx{وَلَهُ الكِبرِياءُ فِى السَّمٰوٰتِ وَالأَرضِ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdxi{\basmalah  حم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdxii{تَنزيلُ الكِتٰبِ مِنَ اللَّهِ العَزيزِ الحَكيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdxiii{ما خَلَقنَا السَّمٰوٰتِ وَالأَرضَ وَما بَينَهُما إِلّا بِالحَقِّ وَأَجَلٍ مُسَمًّى وَالَّذينَ كَفَروا عَمّا أُنذِروا مُعرِضونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdxiv{قُل أَرَءَيتُم ما تَدعونَ مِن دونِ اللَّهِ أَرونى ماذا خَلَقوا مِنَ الأَرضِ أَم لَهُم شِركٌ فِى السَّمٰوٰتِ ائتونى بِكِتٰبٍ مِن قَبلِ هٰذا أَو أَثٰرَةٍ مِن عِلمٍ إِن كُنتُم صٰدِقينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdxv{وَمَن أَضَلُّ مِمَّن يَدعوا مِن دونِ اللَّهِ مَن لا يَستَجيبُ لَهُ إِلىٰ يَومِ القِيٰمَةِ وَهُم عَن دُعائِهِم غٰفِلونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdxvi{وَإِذا حُشِرَ النّاسُ كانوا لَهُم أَعداءً وَكانوا بِعِبادَتِهِم كٰفِرينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdxvii{وَإِذا تُتلىٰ عَلَيهِم ءايٰتُنا بَيِّنٰتٍ قالَ الَّذينَ كَفَروا لِلحَقِّ لَمّا جاءَهُم هٰذا سِحرٌ مُبينٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdxviii{أَم يَقولونَ افتَرىٰهُ قُل إِنِ افتَرَيتُهُ فَلا تَملِكونَ لى مِنَ اللَّهِ شَيـًٔا هُوَ أَعلَمُ بِما تُفيضونَ فيهِ كَفىٰ بِهِ شَهيدًا بَينى وَبَينَكُم وَهُوَ الغَفورُ الرَّحيمُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdxix{قُل ما كُنتُ بِدعًا مِنَ الرُّسُلِ وَما أَدرى ما يُفعَلُ بى وَلا بِكُم إِن أَتَّبِعُ إِلّا ما يوحىٰ إِلَىَّ وَما أَنا۠ إِلّا نَذيرٌ مُبينٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdxx{قُل أَرَءَيتُم إِن كانَ مِن عِندِ اللَّهِ وَكَفَرتُم بِهِ وَشَهِدَ شاهِدٌ مِن بَنى إِسرٰءيلَ عَلىٰ مِثلِهِ فَـٔامَنَ وَاستَكبَرتُم إِنَّ اللَّهَ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdxxi{وَقالَ الَّذينَ كَفَروا لِلَّذينَ ءامَنوا لَو كانَ خَيرًا ما سَبَقونا إِلَيهِ وَإِذ لَم يَهتَدوا بِهِ فَسَيَقولونَ هٰذا إِفكٌ قَديمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdxxii{وَمِن قَبلِهِ كِتٰبُ موسىٰ إِمامًا وَرَحمَةً وَهٰذا كِتٰبٌ مُصَدِّقٌ لِسانًا عَرَبِيًّا لِيُنذِرَ الَّذينَ ظَلَموا وَبُشرىٰ لِلمُحسِنينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdxxiii{إِنَّ الَّذينَ قالوا رَبُّنَا اللَّهُ ثُمَّ استَقٰموا فَلا خَوفٌ عَلَيهِم وَلا هُم يَحزَنونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdxxiv{أُولٰئِكَ أَصحٰبُ الجَنَّةِ خٰلِدينَ فيها جَزاءً بِما كانوا يَعمَلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdxxv{وَوَصَّينَا الإِنسٰنَ بِوٰلِدَيهِ إِحسٰنًا حَمَلَتهُ أُمُّهُ كُرهًا وَوَضَعَتهُ كُرهًا وَحَملُهُ وَفِصٰلُهُ ثَلٰثونَ شَهرًا حَتّىٰ إِذا بَلَغَ أَشُدَّهُ وَبَلَغَ أَربَعينَ سَنَةً قالَ رَبِّ أَوزِعنى أَن أَشكُرَ نِعمَتَكَ الَّتى أَنعَمتَ عَلَىَّ وَعَلىٰ وٰلِدَىَّ وَأَن أَعمَلَ صٰلِحًا تَرضىٰهُ وَأَصلِح لى فى ذُرِّيَّتى إِنّى تُبتُ إِلَيكَ وَإِنّى مِنَ المُسلِمينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdxxvi{أُولٰئِكَ الَّذينَ نَتَقَبَّلُ عَنهُم أَحسَنَ ما عَمِلوا وَنَتَجاوَزُ عَن سَيِّـٔاتِهِم فى أَصحٰبِ الجَنَّةِ وَعدَ الصِّدقِ الَّذى كانوا يوعَدونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdxxvii{وَالَّذى قالَ لِوٰلِدَيهِ أُفٍّ لَكُما أَتَعِدانِنى أَن أُخرَجَ وَقَد خَلَتِ القُرونُ مِن قَبلى وَهُما يَستَغيثانِ اللَّهَ وَيلَكَ ءامِن إِنَّ وَعدَ اللَّهِ حَقٌّ فَيَقولُ ما هٰذا إِلّا أَسٰطيرُ الأَوَّلينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdxxviii{أُولٰئِكَ الَّذينَ حَقَّ عَلَيهِمُ القَولُ فى أُمَمٍ قَد خَلَت مِن قَبلِهِم مِنَ الجِنِّ وَالإِنسِ إِنَّهُم كانوا خٰسِرينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdxxix{وَلِكُلٍّ دَرَجٰتٌ مِمّا عَمِلوا وَلِيُوَفِّيَهُم أَعمٰلَهُم وَهُم لا يُظلَمونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdxxx{وَيَومَ يُعرَضُ الَّذينَ كَفَروا عَلَى النّارِ أَذهَبتُم طَيِّبٰتِكُم فى حَياتِكُمُ الدُّنيا وَاستَمتَعتُم بِها فَاليَومَ تُجزَونَ عَذابَ الهونِ بِما كُنتُم تَستَكبِرونَ فِى الأَرضِ بِغَيرِ الحَقِّ وَبِما كُنتُم تَفسُقونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdxxxi{وَاذكُر أَخا عادٍ إِذ أَنذَرَ قَومَهُ بِالأَحقافِ وَقَد خَلَتِ النُّذُرُ مِن بَينِ يَدَيهِ وَمِن خَلفِهِ أَلّا تَعبُدوا إِلَّا اللَّهَ إِنّى أَخافُ عَلَيكُم عَذابَ يَومٍ عَظيمٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdxxxii{قالوا أَجِئتَنا لِتَأفِكَنا عَن ءالِهَتِنا فَأتِنا بِما تَعِدُنا إِن كُنتَ مِنَ الصّٰدِقينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdxxxiii{قالَ إِنَّمَا العِلمُ عِندَ اللَّهِ وَأُبَلِّغُكُم ما أُرسِلتُ بِهِ وَلٰكِنّى أَرىٰكُم قَومًا تَجهَلونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdxxxiv{فَلَمّا رَأَوهُ عارِضًا مُستَقبِلَ أَودِيَتِهِم قالوا هٰذا عارِضٌ مُمطِرُنا بَل هُوَ مَا استَعجَلتُم بِهِ ريحٌ فيها عَذابٌ أَليمٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdxxxv{تُدَمِّرُ كُلَّ شَيءٍ بِأَمرِ رَبِّها فَأَصبَحوا لا يُرىٰ إِلّا مَسٰكِنُهُم كَذٰلِكَ نَجزِى القَومَ المُجرِمينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdxxxvi{وَلَقَد مَكَّنّٰهُم فيما إِن مَكَّنّٰكُم فيهِ وَجَعَلنا لَهُم سَمعًا وَأَبصٰرًا وَأَفـِٔدَةً فَما أَغنىٰ عَنهُم سَمعُهُم وَلا أَبصٰرُهُم وَلا أَفـِٔدَتُهُم مِن شَيءٍ إِذ كانوا يَجحَدونَ بِـٔايٰتِ اللَّهِ وَحاقَ بِهِم ما كانوا بِهِ يَستَهزِءونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdxxxvii{وَلَقَد أَهلَكنا ما حَولَكُم مِنَ القُرىٰ وَصَرَّفنَا الءايٰتِ لَعَلَّهُم يَرجِعونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdxxxviii{فَلَولا نَصَرَهُمُ الَّذينَ اتَّخَذوا مِن دونِ اللَّهِ قُربانًا ءالِهَةً بَل ضَلّوا عَنهُم وَذٰلِكَ إِفكُهُم وَما كانوا يَفتَرونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdxxxix{وَإِذ صَرَفنا إِلَيكَ نَفَرًا مِنَ الجِنِّ يَستَمِعونَ القُرءانَ فَلَمّا حَضَروهُ قالوا أَنصِتوا فَلَمّا قُضِىَ وَلَّوا إِلىٰ قَومِهِم مُنذِرينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdxl{قالوا يٰقَومَنا إِنّا سَمِعنا كِتٰبًا أُنزِلَ مِن بَعدِ موسىٰ مُصَدِّقًا لِما بَينَ يَدَيهِ يَهدى إِلَى الحَقِّ وَإِلىٰ طَريقٍ مُستَقيمٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdxli{يٰقَومَنا أَجيبوا داعِىَ اللَّهِ وَءامِنوا بِهِ يَغفِر لَكُم مِن ذُنوبِكُم وَيُجِركُم مِن عَذابٍ أَليمٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdxlii{وَمَن لا يُجِب داعِىَ اللَّهِ فَلَيسَ بِمُعجِزٍ فِى الأَرضِ وَلَيسَ لَهُ مِن دونِهِ أَولِياءُ أُولٰئِكَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdxliii{أَوَلَم يَرَوا أَنَّ اللَّهَ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ وَلَم يَعىَ بِخَلقِهِنَّ بِقٰدِرٍ عَلىٰ أَن يُحۦِىَ المَوتىٰ بَلىٰ إِنَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdxliv{وَيَومَ يُعرَضُ الَّذينَ كَفَروا عَلَى النّارِ أَلَيسَ هٰذا بِالحَقِّ قالوا بَلىٰ وَرَبِّنا قالَ فَذوقُوا العَذابَ بِما كُنتُم تَكفُرونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdxlv{فَاصبِر كَما صَبَرَ أُولُوا العَزمِ مِنَ الرُّسُلِ وَلا تَستَعجِل لَهُم كَأَنَّهُم يَومَ يَرَونَ ما يوعَدونَ لَم يَلبَثوا إِلّا ساعَةً مِن نَهارٍ بَلٰغٌ فَهَل يُهلَكُ إِلَّا القَومُ الفٰسِقونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdxlvi{\basmalah  الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ أَضَلَّ أَعمٰلَهُم\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdxlvii{وَالَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ وَءامَنوا بِما نُزِّلَ عَلىٰ مُحَمَّدٍ وَهُوَ الحَقُّ مِن رَبِّهِم كَفَّرَ عَنهُم سَيِّـٔاتِهِم وَأَصلَحَ بالَهُم\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdxlviii{ذٰلِكَ بِأَنَّ الَّذينَ كَفَرُوا اتَّبَعُوا البٰطِلَ وَأَنَّ الَّذينَ ءامَنُوا اتَّبَعُوا الحَقَّ مِن رَبِّهِم كَذٰلِكَ يَضرِبُ اللَّهُ لِلنّاسِ أَمثٰلَهُم\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdxlix{فَإِذا لَقيتُمُ الَّذينَ كَفَروا فَضَربَ الرِّقابِ حَتّىٰ إِذا أَثخَنتُموهُم فَشُدُّوا الوَثاقَ فَإِمّا مَنًّا بَعدُ وَإِمّا فِداءً حَتّىٰ تَضَعَ الحَربُ أَوزارَها ذٰلِكَ وَلَو يَشاءُ اللَّهُ لَانتَصَرَ مِنهُم وَلٰكِن لِيَبلُوَا۟ بَعضَكُم بِبَعضٍ وَالَّذينَ قُتِلوا فى سَبيلِ اللَّهِ فَلَن يُضِلَّ أَعمٰلَهُم\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdl{سَيَهديهِم وَيُصلِحُ بالَهُم\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdli{وَيُدخِلُهُمُ الجَنَّةَ عَرَّفَها لَهُم\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdlii{يٰأَيُّهَا الَّذينَ ءامَنوا إِن تَنصُرُوا اللَّهَ يَنصُركُم وَيُثَبِّت أَقدامَكُم\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdliii{وَالَّذينَ كَفَروا فَتَعسًا لَهُم وَأَضَلَّ أَعمٰلَهُم\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdliv{ذٰلِكَ بِأَنَّهُم كَرِهوا ما أَنزَلَ اللَّهُ فَأَحبَطَ أَعمٰلَهُم\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdlv{أَفَلَم يَسيروا فِى الأَرضِ فَيَنظُروا كَيفَ كانَ عٰقِبَةُ الَّذينَ مِن قَبلِهِم دَمَّرَ اللَّهُ عَلَيهِم وَلِلكٰفِرينَ أَمثٰلُها\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdlvi{ذٰلِكَ بِأَنَّ اللَّهَ مَولَى الَّذينَ ءامَنوا وَأَنَّ الكٰفِرينَ لا مَولىٰ لَهُم\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdlvii{إِنَّ اللَّهَ يُدخِلُ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ وَالَّذينَ كَفَروا يَتَمَتَّعونَ وَيَأكُلونَ كَما تَأكُلُ الأَنعٰمُ وَالنّارُ مَثوًى لَهُم\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdlviii{وَكَأَيِّن مِن قَريَةٍ هِىَ أَشَدُّ قُوَّةً مِن قَريَتِكَ الَّتى أَخرَجَتكَ أَهلَكنٰهُم فَلا ناصِرَ لَهُم\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdlix{أَفَمَن كانَ عَلىٰ بَيِّنَةٍ مِن رَبِّهِ كَمَن زُيِّنَ لَهُ سوءُ عَمَلِهِ وَاتَّبَعوا أَهواءَهُم\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdlx{مَثَلُ الجَنَّةِ الَّتى وُعِدَ المُتَّقونَ فيها أَنهٰرٌ مِن ماءٍ غَيرِ ءاسِنٍ وَأَنهٰرٌ مِن لَبَنٍ لَم يَتَغَيَّر طَعمُهُ وَأَنهٰرٌ مِن خَمرٍ لَذَّةٍ لِلشّٰرِبينَ وَأَنهٰرٌ مِن عَسَلٍ مُصَفًّى وَلَهُم فيها مِن كُلِّ الثَّمَرٰتِ وَمَغفِرَةٌ مِن رَبِّهِم كَمَن هُوَ خٰلِدٌ فِى النّارِ وَسُقوا ماءً حَميمًا فَقَطَّعَ أَمعاءَهُم\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdlxi{وَمِنهُم مَن يَستَمِعُ إِلَيكَ حَتّىٰ إِذا خَرَجوا مِن عِندِكَ قالوا لِلَّذينَ أوتُوا العِلمَ ماذا قالَ ءانِفًا أُولٰئِكَ الَّذينَ طَبَعَ اللَّهُ عَلىٰ قُلوبِهِم وَاتَّبَعوا أَهواءَهُم\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdlxii{وَالَّذينَ اهتَدَوا زادَهُم هُدًى وَءاتىٰهُم تَقوىٰهُم\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdlxiii{فَهَل يَنظُرونَ إِلَّا السّاعَةَ أَن تَأتِيَهُم بَغتَةً فَقَد جاءَ أَشراطُها فَأَنّىٰ لَهُم إِذا جاءَتهُم ذِكرىٰهُم\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdlxiv{فَاعلَم أَنَّهُ لا إِلٰهَ إِلَّا اللَّهُ وَاستَغفِر لِذَنبِكَ وَلِلمُؤمِنينَ وَالمُؤمِنٰتِ وَاللَّهُ يَعلَمُ مُتَقَلَّبَكُم وَمَثوىٰكُم\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdlxv{وَيَقولُ الَّذينَ ءامَنوا لَولا نُزِّلَت سورَةٌ فَإِذا أُنزِلَت سورَةٌ مُحكَمَةٌ وَذُكِرَ فيهَا القِتالُ رَأَيتَ الَّذينَ فى قُلوبِهِم مَرَضٌ يَنظُرونَ إِلَيكَ نَظَرَ المَغشِىِّ عَلَيهِ مِنَ المَوتِ فَأَولىٰ لَهُم\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdlxvi{طاعَةٌ وَقَولٌ مَعروفٌ فَإِذا عَزَمَ الأَمرُ فَلَو صَدَقُوا اللَّهَ لَكانَ خَيرًا لَهُم\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdlxvii{فَهَل عَسَيتُم إِن تَوَلَّيتُم أَن تُفسِدوا فِى الأَرضِ وَتُقَطِّعوا أَرحامَكُم\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdlxviii{أُولٰئِكَ الَّذينَ لَعَنَهُمُ اللَّهُ فَأَصَمَّهُم وَأَعمىٰ أَبصٰرَهُم\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdlxix{أَفَلا يَتَدَبَّرونَ القُرءانَ أَم عَلىٰ قُلوبٍ أَقفالُها\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdlxx{إِنَّ الَّذينَ ارتَدّوا عَلىٰ أَدبٰرِهِم مِن بَعدِ ما تَبَيَّنَ لَهُمُ الهُدَى الشَّيطٰنُ سَوَّلَ لَهُم وَأَملىٰ لَهُم\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxi{ذٰلِكَ بِأَنَّهُم قالوا لِلَّذينَ كَرِهوا ما نَزَّلَ اللَّهُ سَنُطيعُكُم فى بَعضِ الأَمرِ وَاللَّهُ يَعلَمُ إِسرارَهُم\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdlxxii{فَكَيفَ إِذا تَوَفَّتهُمُ المَلٰئِكَةُ يَضرِبونَ وُجوهَهُم وَأَدبٰرَهُم\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdlxxiii{ذٰلِكَ بِأَنَّهُمُ اتَّبَعوا ما أَسخَطَ اللَّهَ وَكَرِهوا رِضوٰنَهُ فَأَحبَطَ أَعمٰلَهُم\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdlxxiv{أَم حَسِبَ الَّذينَ فى قُلوبِهِم مَرَضٌ أَن لَن يُخرِجَ اللَّهُ أَضغٰنَهُم\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdlxxv{وَلَو نَشاءُ لَأَرَينٰكَهُم فَلَعَرَفتَهُم بِسيمٰهُم وَلَتَعرِفَنَّهُم فى لَحنِ القَولِ وَاللَّهُ يَعلَمُ أَعمٰلَكُم\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdlxxvi{وَلَنَبلُوَنَّكُم حَتّىٰ نَعلَمَ المُجٰهِدينَ مِنكُم وَالصّٰبِرينَ وَنَبلُوَا۟ أَخبارَكُم\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdlxxvii{إِنَّ الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ وَشاقُّوا الرَّسولَ مِن بَعدِ ما تَبَيَّنَ لَهُمُ الهُدىٰ لَن يَضُرُّوا اللَّهَ شَيـًٔا وَسَيُحبِطُ أَعمٰلَهُم\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdlxxviii{يٰأَيُّهَا الَّذينَ ءامَنوا أَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ وَلا تُبطِلوا أَعمٰلَكُم\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdlxxix{إِنَّ الَّذينَ كَفَروا وَصَدّوا عَن سَبيلِ اللَّهِ ثُمَّ ماتوا وَهُم كُفّارٌ فَلَن يَغفِرَ اللَّهُ لَهُم\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdlxxx{فَلا تَهِنوا وَتَدعوا إِلَى السَّلمِ وَأَنتُمُ الأَعلَونَ وَاللَّهُ مَعَكُم وَلَن يَتِرَكُم أَعمٰلَكُم\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxxi{إِنَّمَا الحَيوٰةُ الدُّنيا لَعِبٌ وَلَهوٌ وَإِن تُؤمِنوا وَتَتَّقوا يُؤتِكُم أُجورَكُم وَلا يَسـَٔلكُم أَموٰلَكُم\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdlxxxii{إِن يَسـَٔلكُموها فَيُحفِكُم تَبخَلوا وَيُخرِج أَضغٰنَكُم\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdlxxxiii{هٰأَنتُم هٰؤُلاءِ تُدعَونَ لِتُنفِقوا فى سَبيلِ اللَّهِ فَمِنكُم مَن يَبخَلُ وَمَن يَبخَل فَإِنَّما يَبخَلُ عَن نَفسِهِ وَاللَّهُ الغَنِىُّ وَأَنتُمُ الفُقَراءُ وَإِن تَتَوَلَّوا يَستَبدِل قَومًا غَيرَكُم ثُمَّ لا يَكونوا أَمثٰلَكُم\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdlxxxiv{\basmalah  إِنّا فَتَحنا لَكَ فَتحًا مُبينًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdlxxxv{لِيَغفِرَ لَكَ اللَّهُ ما تَقَدَّمَ مِن ذَنبِكَ وَما تَأَخَّرَ وَيُتِمَّ نِعمَتَهُ عَلَيكَ وَيَهدِيَكَ صِرٰطًا مُستَقيمًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdlxxxvi{وَيَنصُرَكَ اللَّهُ نَصرًا عَزيزًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdlxxxvii{هُوَ الَّذى أَنزَلَ السَّكينَةَ فى قُلوبِ المُؤمِنينَ لِيَزدادوا إيمٰنًا مَعَ إيمٰنِهِم وَلِلَّهِ جُنودُ السَّمٰوٰتِ وَالأَرضِ وَكانَ اللَّهُ عَليمًا حَكيمًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdlxxxviii{لِيُدخِلَ المُؤمِنينَ وَالمُؤمِنٰتِ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها وَيُكَفِّرَ عَنهُم سَيِّـٔاتِهِم وَكانَ ذٰلِكَ عِندَ اللَّهِ فَوزًا عَظيمًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdlxxxix{وَيُعَذِّبَ المُنٰفِقينَ وَالمُنٰفِقٰتِ وَالمُشرِكينَ وَالمُشرِكٰتِ الظّانّينَ بِاللَّهِ ظَنَّ السَّوءِ عَلَيهِم دائِرَةُ السَّوءِ وَغَضِبَ اللَّهُ عَلَيهِم وَلَعَنَهُم وَأَعَدَّ لَهُم جَهَنَّمَ وَساءَت مَصيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdxc{وَلِلَّهِ جُنودُ السَّمٰوٰتِ وَالأَرضِ وَكانَ اللَّهُ عَزيزًا حَكيمًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdxci{إِنّا أَرسَلنٰكَ شٰهِدًا وَمُبَشِّرًا وَنَذيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdxcii{لِتُؤمِنوا بِاللَّهِ وَرَسولِهِ وَتُعَزِّروهُ وَتُوَقِّروهُ وَتُسَبِّحوهُ بُكرَةً وَأَصيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdxciii{إِنَّ الَّذينَ يُبايِعونَكَ إِنَّما يُبايِعونَ اللَّهَ يَدُ اللَّهِ فَوقَ أَيديهِم فَمَن نَكَثَ فَإِنَّما يَنكُثُ عَلىٰ نَفسِهِ وَمَن أَوفىٰ بِما عٰهَدَ عَلَيهُ اللَّهَ فَسَيُؤتيهِ أَجرًا عَظيمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdxciv{سَيَقولُ لَكَ المُخَلَّفونَ مِنَ الأَعرابِ شَغَلَتنا أَموٰلُنا وَأَهلونا فَاستَغفِر لَنا يَقولونَ بِأَلسِنَتِهِم ما لَيسَ فى قُلوبِهِم قُل فَمَن يَملِكُ لَكُم مِنَ اللَّهِ شَيـًٔا إِن أَرادَ بِكُم ضَرًّا أَو أَرادَ بِكُم نَفعًا بَل كانَ اللَّهُ بِما تَعمَلونَ خَبيرًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdxcv{بَل ظَنَنتُم أَن لَن يَنقَلِبَ الرَّسولُ وَالمُؤمِنونَ إِلىٰ أَهليهِم أَبَدًا وَزُيِّنَ ذٰلِكَ فى قُلوبِكُم وَظَنَنتُم ظَنَّ السَّوءِ وَكُنتُم قَومًا بورًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdxcvi{وَمَن لَم يُؤمِن بِاللَّهِ وَرَسولِهِ فَإِنّا أَعتَدنا لِلكٰفِرينَ سَعيرًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdxcvii{وَلِلَّهِ مُلكُ السَّمٰوٰتِ وَالأَرضِ يَغفِرُ لِمَن يَشاءُ وَيُعَذِّبُ مَن يَشاءُ وَكانَ اللَّهُ غَفورًا رَحيمًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdxcviii{سَيَقولُ المُخَلَّفونَ إِذَا انطَلَقتُم إِلىٰ مَغانِمَ لِتَأخُذوها ذَرونا نَتَّبِعكُم يُريدونَ أَن يُبَدِّلوا كَلٰمَ اللَّهِ قُل لَن تَتَّبِعونا كَذٰلِكُم قالَ اللَّهُ مِن قَبلُ فَسَيَقولونَ بَل تَحسُدونَنا بَل كانوا لا يَفقَهونَ إِلّا قَليلًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdxcix{قُل لِلمُخَلَّفينَ مِنَ الأَعرابِ سَتُدعَونَ إِلىٰ قَومٍ أُولى بَأسٍ شَديدٍ تُقٰتِلونَهُم أَو يُسلِمونَ فَإِن تُطيعوا يُؤتِكُمُ اللَّهُ أَجرًا حَسَنًا وَإِن تَتَوَلَّوا كَما تَوَلَّيتُم مِن قَبلُ يُعَذِّبكُم عَذابًا أَليمًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdc{لَيسَ عَلَى الأَعمىٰ حَرَجٌ وَلا عَلَى الأَعرَجِ حَرَجٌ وَلا عَلَى المَريضِ حَرَجٌ وَمَن يُطِعِ اللَّهَ وَرَسولَهُ يُدخِلهُ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ وَمَن يَتَوَلَّ يُعَذِّبهُ عَذابًا أَليمًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdci{لَقَد رَضِىَ اللَّهُ عَنِ المُؤمِنينَ إِذ يُبايِعونَكَ تَحتَ الشَّجَرَةِ فَعَلِمَ ما فى قُلوبِهِم فَأَنزَلَ السَّكينَةَ عَلَيهِم وَأَثٰبَهُم فَتحًا قَريبًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcii{وَمَغانِمَ كَثيرَةً يَأخُذونَها وَكانَ اللَّهُ عَزيزًا حَكيمًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdciii{وَعَدَكُمُ اللَّهُ مَغانِمَ كَثيرَةً تَأخُذونَها فَعَجَّلَ لَكُم هٰذِهِ وَكَفَّ أَيدِىَ النّاسِ عَنكُم وَلِتَكونَ ءايَةً لِلمُؤمِنينَ وَيَهدِيَكُم صِرٰطًا مُستَقيمًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdciv{وَأُخرىٰ لَم تَقدِروا عَلَيها قَد أَحاطَ اللَّهُ بِها وَكانَ اللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcv{وَلَو قٰتَلَكُمُ الَّذينَ كَفَروا لَوَلَّوُا الأَدبٰرَ ثُمَّ لا يَجِدونَ وَلِيًّا وَلا نَصيرًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcvi{سُنَّةَ اللَّهِ الَّتى قَد خَلَت مِن قَبلُ وَلَن تَجِدَ لِسُنَّةِ اللَّهِ تَبديلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcvii{وَهُوَ الَّذى كَفَّ أَيدِيَهُم عَنكُم وَأَيدِيَكُم عَنهُم بِبَطنِ مَكَّةَ مِن بَعدِ أَن أَظفَرَكُم عَلَيهِم وَكانَ اللَّهُ بِما تَعمَلونَ بَصيرًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcviii{هُمُ الَّذينَ كَفَروا وَصَدّوكُم عَنِ المَسجِدِ الحَرامِ وَالهَدىَ مَعكوفًا أَن يَبلُغَ مَحِلَّهُ وَلَولا رِجالٌ مُؤمِنونَ وَنِساءٌ مُؤمِنٰتٌ لَم تَعلَموهُم أَن تَطَـٔوهُم فَتُصيبَكُم مِنهُم مَعَرَّةٌ بِغَيرِ عِلمٍ لِيُدخِلَ اللَّهُ فى رَحمَتِهِ مَن يَشاءُ لَو تَزَيَّلوا لَعَذَّبنَا الَّذينَ كَفَروا مِنهُم عَذابًا أَليمًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcix{إِذ جَعَلَ الَّذينَ كَفَروا فى قُلوبِهِمُ الحَمِيَّةَ حَمِيَّةَ الجٰهِلِيَّةِ فَأَنزَلَ اللَّهُ سَكينَتَهُ عَلىٰ رَسولِهِ وَعَلَى المُؤمِنينَ وَأَلزَمَهُم كَلِمَةَ التَّقوىٰ وَكانوا أَحَقَّ بِها وَأَهلَها وَكانَ اللَّهُ بِكُلِّ شَيءٍ عَليمًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcx{لَقَد صَدَقَ اللَّهُ رَسولَهُ الرُّءيا بِالحَقِّ لَتَدخُلُنَّ المَسجِدَ الحَرامَ إِن شاءَ اللَّهُ ءامِنينَ مُحَلِّقينَ رُءوسَكُم وَمُقَصِّرينَ لا تَخافونَ فَعَلِمَ ما لَم تَعلَموا فَجَعَلَ مِن دونِ ذٰلِكَ فَتحًا قَريبًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcxi{هُوَ الَّذى أَرسَلَ رَسولَهُ بِالهُدىٰ وَدينِ الحَقِّ لِيُظهِرَهُ عَلَى الدّينِ كُلِّهِ وَكَفىٰ بِاللَّهِ شَهيدًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcxii{مُحَمَّدٌ رَسولُ اللَّهِ وَالَّذينَ مَعَهُ أَشِدّاءُ عَلَى الكُفّارِ رُحَماءُ بَينَهُم تَرىٰهُم رُكَّعًا سُجَّدًا يَبتَغونَ فَضلًا مِنَ اللَّهِ وَرِضوٰنًا سيماهُم فى وُجوهِهِم مِن أَثَرِ السُّجودِ ذٰلِكَ مَثَلُهُم فِى التَّورىٰةِ وَمَثَلُهُم فِى الإِنجيلِ كَزَرعٍ أَخرَجَ شَطـَٔهُ فَـٔازَرَهُ فَاستَغلَظَ فَاستَوىٰ عَلىٰ سوقِهِ يُعجِبُ الزُّرّاعَ لِيَغيظَ بِهِمُ الكُفّارَ وَعَدَ اللَّهُ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ مِنهُم مَغفِرَةً وَأَجرًا عَظيمًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcxiii{\basmalah  يٰأَيُّهَا الَّذينَ ءامَنوا لا تُقَدِّموا بَينَ يَدَىِ اللَّهِ وَرَسولِهِ وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ سَميعٌ عَليمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcxiv{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَرفَعوا أَصوٰتَكُم فَوقَ صَوتِ النَّبِىِّ وَلا تَجهَروا لَهُ بِالقَولِ كَجَهرِ بَعضِكُم لِبَعضٍ أَن تَحبَطَ أَعمٰلُكُم وَأَنتُم لا تَشعُرونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcxv{إِنَّ الَّذينَ يَغُضّونَ أَصوٰتَهُم عِندَ رَسولِ اللَّهِ أُولٰئِكَ الَّذينَ امتَحَنَ اللَّهُ قُلوبَهُم لِلتَّقوىٰ لَهُم مَغفِرَةٌ وَأَجرٌ عَظيمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcxvi{إِنَّ الَّذينَ يُنادونَكَ مِن وَراءِ الحُجُرٰتِ أَكثَرُهُم لا يَعقِلونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcxvii{وَلَو أَنَّهُم صَبَروا حَتّىٰ تَخرُجَ إِلَيهِم لَكانَ خَيرًا لَهُم وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdcxviii{يٰأَيُّهَا الَّذينَ ءامَنوا إِن جاءَكُم فاسِقٌ بِنَبَإٍ فَتَبَيَّنوا أَن تُصيبوا قَومًا بِجَهٰلَةٍ فَتُصبِحوا عَلىٰ ما فَعَلتُم نٰدِمينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcxix{وَاعلَموا أَنَّ فيكُم رَسولَ اللَّهِ لَو يُطيعُكُم فى كَثيرٍ مِنَ الأَمرِ لَعَنِتُّم وَلٰكِنَّ اللَّهَ حَبَّبَ إِلَيكُمُ الإيمٰنَ وَزَيَّنَهُ فى قُلوبِكُم وَكَرَّهَ إِلَيكُمُ الكُفرَ وَالفُسوقَ وَالعِصيانَ أُولٰئِكَ هُمُ الرّٰشِدونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcxx{فَضلًا مِنَ اللَّهِ وَنِعمَةً وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxi{وَإِن طائِفَتانِ مِنَ المُؤمِنينَ اقتَتَلوا فَأَصلِحوا بَينَهُما فَإِن بَغَت إِحدىٰهُما عَلَى الأُخرىٰ فَقٰتِلُوا الَّتى تَبغى حَتّىٰ تَفيءَ إِلىٰ أَمرِ اللَّهِ فَإِن فاءَت فَأَصلِحوا بَينَهُما بِالعَدلِ وَأَقسِطوا إِنَّ اللَّهَ يُحِبُّ المُقسِطينَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdcxxii{إِنَّمَا المُؤمِنونَ إِخوَةٌ فَأَصلِحوا بَينَ أَخَوَيكُم وَاتَّقُوا اللَّهَ لَعَلَّكُم تُرحَمونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdcxxiii{يٰأَيُّهَا الَّذينَ ءامَنوا لا يَسخَر قَومٌ مِن قَومٍ عَسىٰ أَن يَكونوا خَيرًا مِنهُم وَلا نِساءٌ مِن نِساءٍ عَسىٰ أَن يَكُنَّ خَيرًا مِنهُنَّ وَلا تَلمِزوا أَنفُسَكُم وَلا تَنابَزوا بِالأَلقٰبِ بِئسَ الِاسمُ الفُسوقُ بَعدَ الإيمٰنِ وَمَن لَم يَتُب فَأُولٰئِكَ هُمُ الظّٰلِمونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdcxxiv{يٰأَيُّهَا الَّذينَ ءامَنُوا اجتَنِبوا كَثيرًا مِنَ الظَّنِّ إِنَّ بَعضَ الظَّنِّ إِثمٌ وَلا تَجَسَّسوا وَلا يَغتَب بَعضُكُم بَعضًا أَيُحِبُّ أَحَدُكُم أَن يَأكُلَ لَحمَ أَخيهِ مَيتًا فَكَرِهتُموهُ وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ تَوّابٌ رَحيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdcxxv{يٰأَيُّهَا النّاسُ إِنّا خَلَقنٰكُم مِن ذَكَرٍ وَأُنثىٰ وَجَعَلنٰكُم شُعوبًا وَقَبائِلَ لِتَعارَفوا إِنَّ أَكرَمَكُم عِندَ اللَّهِ أَتقىٰكُم إِنَّ اللَّهَ عَليمٌ خَبيرٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdcxxvi{قالَتِ الأَعرابُ ءامَنّا قُل لَم تُؤمِنوا وَلٰكِن قولوا أَسلَمنا وَلَمّا يَدخُلِ الإيمٰنُ فى قُلوبِكُم وَإِن تُطيعُوا اللَّهَ وَرَسولَهُ لا يَلِتكُم مِن أَعمٰلِكُم شَيـًٔا إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxxvii{إِنَّمَا المُؤمِنونَ الَّذينَ ءامَنوا بِاللَّهِ وَرَسولِهِ ثُمَّ لَم يَرتابوا وَجٰهَدوا بِأَموٰلِهِم وَأَنفُسِهِم فى سَبيلِ اللَّهِ أُولٰئِكَ هُمُ الصّٰدِقونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxxviii{قُل أَتُعَلِّمونَ اللَّهَ بِدينِكُم وَاللَّهُ يَعلَمُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxxix{يَمُنّونَ عَلَيكَ أَن أَسلَموا قُل لا تَمُنّوا عَلَىَّ إِسلٰمَكُم بَلِ اللَّهُ يَمُنُّ عَلَيكُم أَن هَدىٰكُم لِلإيمٰنِ إِن كُنتُم صٰدِقينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxxx{إِنَّ اللَّهَ يَعلَمُ غَيبَ السَّمٰوٰتِ وَالأَرضِ وَاللَّهُ بَصيرٌ بِما تَعمَلونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxxi{\basmalah  ق وَالقُرءانِ المَجيدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcxxxii{بَل عَجِبوا أَن جاءَهُم مُنذِرٌ مِنهُم فَقالَ الكٰفِرونَ هٰذا شَيءٌ عَجيبٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcxxxiii{أَءِذا مِتنا وَكُنّا تُرابًا ذٰلِكَ رَجعٌ بَعيدٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcxxxiv{قَد عَلِمنا ما تَنقُصُ الأَرضُ مِنهُم وَعِندَنا كِتٰبٌ حَفيظٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcxxxv{بَل كَذَّبوا بِالحَقِّ لَمّا جاءَهُم فَهُم فى أَمرٍ مَريجٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdcxxxvi{أَفَلَم يَنظُروا إِلَى السَّماءِ فَوقَهُم كَيفَ بَنَينٰها وَزَيَّنّٰها وَما لَها مِن فُروجٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcxxxvii{وَالأَرضَ مَدَدنٰها وَأَلقَينا فيها رَوٰسِىَ وَأَنبَتنا فيها مِن كُلِّ زَوجٍ بَهيجٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcxxxviii{تَبصِرَةً وَذِكرىٰ لِكُلِّ عَبدٍ مُنيبٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdcxxxix{وَنَزَّلنا مِنَ السَّماءِ ماءً مُبٰرَكًا فَأَنبَتنا بِهِ جَنّٰتٍ وَحَبَّ الحَصيدِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdcxl{وَالنَّخلَ باسِقٰتٍ لَها طَلعٌ نَضيدٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdcxli{رِزقًا لِلعِبادِ وَأَحيَينا بِهِ بَلدَةً مَيتًا كَذٰلِكَ الخُروجُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdcxlii{كَذَّبَت قَبلَهُم قَومُ نوحٍ وَأَصحٰبُ الرَّسِّ وَثَمودُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdcxliii{وَعادٌ وَفِرعَونُ وَإِخوٰنُ لوطٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdcxliv{وَأَصحٰبُ الأَيكَةِ وَقَومُ تُبَّعٍ كُلٌّ كَذَّبَ الرُّسُلَ فَحَقَّ وَعيدِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxlv{أَفَعَيينا بِالخَلقِ الأَوَّلِ بَل هُم فى لَبسٍ مِن خَلقٍ جَديدٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxlvi{وَلَقَد خَلَقنَا الإِنسٰنَ وَنَعلَمُ ما تُوَسوِسُ بِهِ نَفسُهُ وَنَحنُ أَقرَبُ إِلَيهِ مِن حَبلِ الوَريدِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxlvii{إِذ يَتَلَقَّى المُتَلَقِّيانِ عَنِ اليَمينِ وَعَنِ الشِّمالِ قَعيدٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxlviii{ما يَلفِظُ مِن قَولٍ إِلّا لَدَيهِ رَقيبٌ عَتيدٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxlix{وَجاءَت سَكرَةُ المَوتِ بِالحَقِّ ذٰلِكَ ما كُنتَ مِنهُ تَحيدُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcl{وَنُفِخَ فِى الصّورِ ذٰلِكَ يَومُ الوَعيدِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcli{وَجاءَت كُلُّ نَفسٍ مَعَها سائِقٌ وَشَهيدٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdclii{لَقَد كُنتَ فى غَفلَةٍ مِن هٰذا فَكَشَفنا عَنكَ غِطاءَكَ فَبَصَرُكَ اليَومَ حَديدٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcliii{وَقالَ قَرينُهُ هٰذا ما لَدَىَّ عَتيدٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcliv{أَلقِيا فى جَهَنَّمَ كُلَّ كَفّارٍ عَنيدٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdclv{مَنّاعٍ لِلخَيرِ مُعتَدٍ مُريبٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdclvi{الَّذى جَعَلَ مَعَ اللَّهِ إِلٰهًا ءاخَرَ فَأَلقِياهُ فِى العَذابِ الشَّديدِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdclvii{قالَ قَرينُهُ رَبَّنا ما أَطغَيتُهُ وَلٰكِن كانَ فى ضَلٰلٍ بَعيدٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdclviii{قالَ لا تَختَصِموا لَدَىَّ وَقَد قَدَّمتُ إِلَيكُم بِالوَعيدِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdclix{ما يُبَدَّلُ القَولُ لَدَىَّ وَما أَنا۠ بِظَلّٰمٍ لِلعَبيدِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdclx{يَومَ نَقولُ لِجَهَنَّمَ هَلِ امتَلَأتِ وَتَقولُ هَل مِن مَزيدٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdclxi{وَأُزلِفَتِ الجَنَّةُ لِلمُتَّقينَ غَيرَ بَعيدٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdclxii{هٰذا ما توعَدونَ لِكُلِّ أَوّابٍ حَفيظٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdclxiii{مَن خَشِىَ الرَّحمٰنَ بِالغَيبِ وَجاءَ بِقَلبٍ مُنيبٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdclxiv{ادخُلوها بِسَلٰمٍ ذٰلِكَ يَومُ الخُلودِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdclxv{لَهُم ما يَشاءونَ فيها وَلَدَينا مَزيدٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdclxvi{وَكَم أَهلَكنا قَبلَهُم مِن قَرنٍ هُم أَشَدُّ مِنهُم بَطشًا فَنَقَّبوا فِى البِلٰدِ هَل مِن مَحيصٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdclxvii{إِنَّ فى ذٰلِكَ لَذِكرىٰ لِمَن كانَ لَهُ قَلبٌ أَو أَلقَى السَّمعَ وَهُوَ شَهيدٌ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdclxviii{وَلَقَد خَلَقنَا السَّمٰوٰتِ وَالأَرضَ وَما بَينَهُما فى سِتَّةِ أَيّامٍ وَما مَسَّنا مِن لُغوبٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdclxix{فَاصبِر عَلىٰ ما يَقولونَ وَسَبِّح بِحَمدِ رَبِّكَ قَبلَ طُلوعِ الشَّمسِ وَقَبلَ الغُروبِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdclxx{وَمِنَ الَّيلِ فَسَبِّحهُ وَأَدبٰرَ السُّجودِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdclxxi{وَاستَمِع يَومَ يُنادِ المُنادِ مِن مَكانٍ قَريبٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdclxxii{يَومَ يَسمَعونَ الصَّيحَةَ بِالحَقِّ ذٰلِكَ يَومُ الخُروجِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxiii{إِنّا نَحنُ نُحيۦ وَنُميتُ وَإِلَينَا المَصيرُ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxiv{يَومَ تَشَقَّقُ الأَرضُ عَنهُم سِراعًا ذٰلِكَ حَشرٌ عَلَينا يَسيرٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdclxxv{نَحنُ أَعلَمُ بِما يَقولونَ وَما أَنتَ عَلَيهِم بِجَبّارٍ فَذَكِّر بِالقُرءانِ مَن يَخافُ وَعيدِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdclxxvi{\basmalah  وَالذّٰرِيٰتِ ذَروًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdclxxvii{فَالحٰمِلٰتِ وِقرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxviii{فَالجٰرِيٰتِ يُسرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxix{فَالمُقَسِّمٰتِ أَمرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdclxxx{إِنَّما توعَدونَ لَصادِقٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdclxxxi{وَإِنَّ الدّينَ لَوٰقِعٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdclxxxii{وَالسَّماءِ ذاتِ الحُبُكِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdclxxxiii{إِنَّكُم لَفى قَولٍ مُختَلِفٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdclxxxiv{يُؤفَكُ عَنهُ مَن أُفِكَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdclxxxv{قُتِلَ الخَرّٰصونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdclxxxvi{الَّذينَ هُم فى غَمرَةٍ ساهونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdclxxxvii{يَسـَٔلونَ أَيّانَ يَومُ الدّينِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdclxxxviii{يَومَ هُم عَلَى النّارِ يُفتَنونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdclxxxix{ذوقوا فِتنَتَكُم هٰذَا الَّذى كُنتُم بِهِ تَستَعجِلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdcxc{إِنَّ المُتَّقينَ فى جَنّٰتٍ وَعُيونٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdcxci{ءاخِذينَ ما ءاتىٰهُم رَبُّهُم إِنَّهُم كانوا قَبلَ ذٰلِكَ مُحسِنينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcxcii{كانوا قَليلًا مِنَ الَّيلِ ما يَهجَعونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcxciii{وَبِالأَسحارِ هُم يَستَغفِرونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdcxciv{وَفى أَموٰلِهِم حَقٌّ لِلسّائِلِ وَالمَحرومِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcxcv{وَفِى الأَرضِ ءايٰتٌ لِلموقِنينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcxcvi{وَفى أَنفُسِكُم أَفَلا تُبصِرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcxcvii{وَفِى السَّماءِ رِزقُكُم وَما توعَدونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcxcviii{فَوَرَبِّ السَّماءِ وَالأَرضِ إِنَّهُ لَحَقٌّ مِثلَ ما أَنَّكُم تَنطِقونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcxcix{هَل أَتىٰكَ حَديثُ ضَيفِ إِبرٰهيمَ المُكرَمينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcc{إِذ دَخَلوا عَلَيهِ فَقالوا سَلٰمًا قالَ سَلٰمٌ قَومٌ مُنكَرونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcci{فَراغَ إِلىٰ أَهلِهِ فَجاءَ بِعِجلٍ سَمينٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdccii{فَقَرَّبَهُ إِلَيهِم قالَ أَلا تَأكُلونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcciii{فَأَوجَسَ مِنهُم خيفَةً قالوا لا تَخَف وَبَشَّروهُ بِغُلٰمٍ عَليمٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcciv{فَأَقبَلَتِ امرَأَتُهُ فى صَرَّةٍ فَصَكَّت وَجهَها وَقالَت عَجوزٌ عَقيمٌ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdccv{قالوا كَذٰلِكِ قالَ رَبُّكِ إِنَّهُ هُوَ الحَكيمُ العَليمُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdccvi{قالَ فَما خَطبُكُم أَيُّهَا المُرسَلونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdccvii{قالوا إِنّا أُرسِلنا إِلىٰ قَومٍ مُجرِمينَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdccviii{لِنُرسِلَ عَلَيهِم حِجارَةً مِن طينٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdccix{مُسَوَّمَةً عِندَ رَبِّكَ لِلمُسرِفينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdccx{فَأَخرَجنا مَن كانَ فيها مِنَ المُؤمِنينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdccxi{فَما وَجَدنا فيها غَيرَ بَيتٍ مِنَ المُسلِمينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdccxii{وَتَرَكنا فيها ءايَةً لِلَّذينَ يَخافونَ العَذابَ الأَليمَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdccxiii{وَفى موسىٰ إِذ أَرسَلنٰهُ إِلىٰ فِرعَونَ بِسُلطٰنٍ مُبينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdccxiv{فَتَوَلّىٰ بِرُكنِهِ وَقالَ سٰحِرٌ أَو مَجنونٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdccxv{فَأَخَذنٰهُ وَجُنودَهُ فَنَبَذنٰهُم فِى اليَمِّ وَهُوَ مُليمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdccxvi{وَفى عادٍ إِذ أَرسَلنا عَلَيهِمُ الرّيحَ العَقيمَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdccxvii{ما تَذَرُ مِن شَيءٍ أَتَت عَلَيهِ إِلّا جَعَلَتهُ كَالرَّميمِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdccxviii{وَفى ثَمودَ إِذ قيلَ لَهُم تَمَتَّعوا حَتّىٰ حينٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdccxix{فَعَتَوا عَن أَمرِ رَبِّهِم فَأَخَذَتهُمُ الصّٰعِقَةُ وَهُم يَنظُرونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdccxx{فَمَا استَطٰعوا مِن قِيامٍ وَما كانوا مُنتَصِرينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdccxxi{وَقَومَ نوحٍ مِن قَبلُ إِنَّهُم كانوا قَومًا فٰسِقينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdccxxii{وَالسَّماءَ بَنَينٰها بِأَيي۟دٍ وَإِنّا لَموسِعونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdccxxiii{وَالأَرضَ فَرَشنٰها فَنِعمَ المٰهِدونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdccxxiv{وَمِن كُلِّ شَيءٍ خَلَقنا زَوجَينِ لَعَلَّكُم تَذَكَّرونَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdccxxv{فَفِرّوا إِلَى اللَّهِ إِنّى لَكُم مِنهُ نَذيرٌ مُبينٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdccxxvi{وَلا تَجعَلوا مَعَ اللَّهِ إِلٰهًا ءاخَرَ إِنّى لَكُم مِنهُ نَذيرٌ مُبينٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdccxxvii{كَذٰلِكَ ما أَتَى الَّذينَ مِن قَبلِهِم مِن رَسولٍ إِلّا قالوا ساحِرٌ أَو مَجنونٌ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdccxxviii{أَتَواصَوا بِهِ بَل هُم قَومٌ طاغونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmdccxxix{فَتَوَلَّ عَنهُم فَما أَنتَ بِمَلومٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmdccxxx{وَذَكِّر فَإِنَّ الذِّكرىٰ تَنفَعُ المُؤمِنينَ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmdccxxxi{وَما خَلَقتُ الجِنَّ وَالإِنسَ إِلّا لِيَعبُدونِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmdccxxxii{ما أُريدُ مِنهُم مِن رِزقٍ وَما أُريدُ أَن يُطعِمونِ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmdccxxxiii{إِنَّ اللَّهَ هُوَ الرَّزّاقُ ذُو القُوَّةِ المَتينُ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmdccxxxiv{فَإِنَّ لِلَّذينَ ظَلَموا ذَنوبًا مِثلَ ذَنوبِ أَصحٰبِهِم فَلا يَستَعجِلونِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmdccxxxv{فَوَيلٌ لِلَّذينَ كَفَروا مِن يَومِهِمُ الَّذى يوعَدونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmdccxxxvi{\basmalah  وَالطّورِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdccxxxvii{وَكِتٰبٍ مَسطورٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdccxxxviii{فى رَقٍّ مَنشورٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdccxxxix{وَالبَيتِ المَعمورِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdccxl{وَالسَّقفِ المَرفوعِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccxli{وَالبَحرِ المَسجورِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdccxlii{إِنَّ عَذابَ رَبِّكَ لَوٰقِعٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdccxliii{ما لَهُ مِن دافِعٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccxliv{يَومَ تَمورُ السَّماءُ مَورًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccxlv{وَتَسيرُ الجِبالُ سَيرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccxlvi{فَوَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccxlvii{الَّذينَ هُم فى خَوضٍ يَلعَبونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccxlviii{يَومَ يُدَعّونَ إِلىٰ نارِ جَهَنَّمَ دَعًّا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccxlix{هٰذِهِ النّارُ الَّتى كُنتُم بِها تُكَذِّبونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccl{أَفَسِحرٌ هٰذا أَم أَنتُم لا تُبصِرونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccli{اصلَوها فَاصبِروا أَو لا تَصبِروا سَواءٌ عَلَيكُم إِنَّما تُجزَونَ ما كُنتُم تَعمَلونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdcclii{إِنَّ المُتَّقينَ فى جَنّٰتٍ وَنَعيمٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdccliii{فٰكِهينَ بِما ءاتىٰهُم رَبُّهُم وَوَقىٰهُم رَبُّهُم عَذابَ الجَحيمِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccliv{كُلوا وَاشرَبوا هَنيـًٔا بِما كُنتُم تَعمَلونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdcclv{مُتَّكِـٔينَ عَلىٰ سُرُرٍ مَصفوفَةٍ وَزَوَّجنٰهُم بِحورٍ عينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcclvi{وَالَّذينَ ءامَنوا وَاتَّبَعَتهُم ذُرِّيَّتُهُم بِإيمٰنٍ أَلحَقنا بِهِم ذُرِّيَّتَهُم وَما أَلَتنٰهُم مِن عَمَلِهِم مِن شَيءٍ كُلُّ امرِئٍ بِما كَسَبَ رَهينٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcclvii{وَأَمدَدنٰهُم بِفٰكِهَةٍ وَلَحمٍ مِمّا يَشتَهونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcclviii{يَتَنٰزَعونَ فيها كَأسًا لا لَغوٌ فيها وَلا تَأثيمٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcclix{وَيَطوفُ عَلَيهِم غِلمانٌ لَهُم كَأَنَّهُم لُؤلُؤٌ مَكنونٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcclx{وَأَقبَلَ بَعضُهُم عَلىٰ بَعضٍ يَتَساءَلونَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxi{قالوا إِنّا كُنّا قَبلُ فى أَهلِنا مُشفِقينَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxii{فَمَنَّ اللَّهُ عَلَينا وَوَقىٰنا عَذابَ السَّمومِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxiii{إِنّا كُنّا مِن قَبلُ نَدعوهُ إِنَّهُ هُوَ البَرُّ الرَّحيمُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxiv{فَذَكِّر فَما أَنتَ بِنِعمَتِ رَبِّكَ بِكاهِنٍ وَلا مَجنونٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxv{أَم يَقولونَ شاعِرٌ نَتَرَبَّصُ بِهِ رَيبَ المَنونِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdcclxvi{قُل تَرَبَّصوا فَإِنّى مَعَكُم مِنَ المُتَرَبِّصينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdcclxvii{أَم تَأمُرُهُم أَحلٰمُهُم بِهٰذا أَم هُم قَومٌ طاغونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxviii{أَم يَقولونَ تَقَوَّلَهُ بَل لا يُؤمِنونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxix{فَليَأتوا بِحَديثٍ مِثلِهِ إِن كانوا صٰدِقينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxx{أَم خُلِقوا مِن غَيرِ شَيءٍ أَم هُمُ الخٰلِقونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxxi{أَم خَلَقُوا السَّمٰوٰتِ وَالأَرضَ بَل لا يوقِنونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxxii{أَم عِندَهُم خَزائِنُ رَبِّكَ أَم هُمُ المُصَۣيطِرونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxxiii{أَم لَهُم سُلَّمٌ يَستَمِعونَ فيهِ فَليَأتِ مُستَمِعُهُم بِسُلطٰنٍ مُبينٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxxiv{أَم لَهُ البَنٰتُ وَلَكُمُ البَنونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxxv{أَم تَسـَٔلُهُم أَجرًا فَهُم مِن مَغرَمٍ مُثقَلونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdcclxxvi{أَم عِندَهُمُ الغَيبُ فَهُم يَكتُبونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdcclxxvii{أَم يُريدونَ كَيدًا فَالَّذينَ كَفَروا هُمُ المَكيدونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxxviii{أَم لَهُم إِلٰهٌ غَيرُ اللَّهِ سُبحٰنَ اللَّهِ عَمّا يُشرِكونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxxix{وَإِن يَرَوا كِسفًا مِنَ السَّماءِ ساقِطًا يَقولوا سَحابٌ مَركومٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxxx{فَذَرهُم حَتّىٰ يُلٰقوا يَومَهُمُ الَّذى فيهِ يُصعَقونَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxi{يَومَ لا يُغنى عَنهُم كَيدُهُم شَيـًٔا وَلا هُم يُنصَرونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxii{وَإِنَّ لِلَّذينَ ظَلَموا عَذابًا دونَ ذٰلِكَ وَلٰكِنَّ أَكثَرَهُم لا يَعلَمونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxiii{وَاصبِر لِحُكمِ رَبِّكَ فَإِنَّكَ بِأَعيُنِنا وَسَبِّح بِحَمدِ رَبِّكَ حينَ تَقومُ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxiv{وَمِنَ الَّيلِ فَسَبِّحهُ وَإِدبٰرَ النُّجومِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxv{\basmalah  وَالنَّجمِ إِذا هَوىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxvi{ما ضَلَّ صاحِبُكُم وَما غَوىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxvii{وَما يَنطِقُ عَنِ الهَوىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxviii{إِن هُوَ إِلّا وَحىٌ يوحىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcclxxxix{عَلَّمَهُ شَديدُ القُوىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccxc{ذو مِرَّةٍ فَاستَوىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdccxci{وَهُوَ بِالأُفُقِ الأَعلىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdccxcii{ثُمَّ دَنا فَتَدَلّىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccxciii{فَكانَ قابَ قَوسَينِ أَو أَدنىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccxciv{فَأَوحىٰ إِلىٰ عَبدِهِ ما أَوحىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccxcv{ما كَذَبَ الفُؤادُ ما رَأىٰ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccxcvi{أَفَتُمٰرونَهُ عَلىٰ ما يَرىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccxcvii{وَلَقَد رَءاهُ نَزلَةً أُخرىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccxcviii{عِندَ سِدرَةِ المُنتَهىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccxcix{عِندَها جَنَّةُ المَأوىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccc{إِذ يَغشَى السِّدرَةَ ما يَغشىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdccci{ما زاغَ البَصَرُ وَما طَغىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdcccii{لَقَد رَأىٰ مِن ءايٰتِ رَبِّهِ الكُبرىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccciii{أَفَرَءَيتُمُ اللّٰتَ وَالعُزّىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdccciv{وَمَنوٰةَ الثّالِثَةَ الأُخرىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdcccv{أَلَكُمُ الذَّكَرُ وَلَهُ الأُنثىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdcccvi{تِلكَ إِذًا قِسمَةٌ ضيزىٰ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdcccvii{إِن هِىَ إِلّا أَسماءٌ سَمَّيتُموها أَنتُم وَءاباؤُكُم ما أَنزَلَ اللَّهُ بِها مِن سُلطٰنٍ إِن يَتَّبِعونَ إِلَّا الظَّنَّ وَما تَهوَى الأَنفُسُ وَلَقَد جاءَهُم مِن رَبِّهِمُ الهُدىٰ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdcccviii{أَم لِلإِنسٰنِ ما تَمَنّىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdcccix{فَلِلَّهِ الءاخِرَةُ وَالأولىٰ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdcccx{وَكَم مِن مَلَكٍ فِى السَّمٰوٰتِ لا تُغنى شَفٰعَتُهُم شَيـًٔا إِلّا مِن بَعدِ أَن يَأذَنَ اللَّهُ لِمَن يَشاءُ وَيَرضىٰ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxi{إِنَّ الَّذينَ لا يُؤمِنونَ بِالءاخِرَةِ لَيُسَمّونَ المَلٰئِكَةَ تَسمِيَةَ الأُنثىٰ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxii{وَما لَهُم بِهِ مِن عِلمٍ إِن يَتَّبِعونَ إِلَّا الظَّنَّ وَإِنَّ الظَّنَّ لا يُغنى مِنَ الحَقِّ شَيـًٔا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxiii{فَأَعرِض عَن مَن تَوَلّىٰ عَن ذِكرِنا وَلَم يُرِد إِلَّا الحَيوٰةَ الدُّنيا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxiv{ذٰلِكَ مَبلَغُهُم مِنَ العِلمِ إِنَّ رَبَّكَ هُوَ أَعلَمُ بِمَن ضَلَّ عَن سَبيلِهِ وَهُوَ أَعلَمُ بِمَنِ اهتَدىٰ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxv{وَلِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ لِيَجزِىَ الَّذينَ أَسٰـٔوا بِما عَمِلوا وَيَجزِىَ الَّذينَ أَحسَنوا بِالحُسنَى\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdcccxvi{الَّذينَ يَجتَنِبونَ كَبٰئِرَ الإِثمِ وَالفَوٰحِشَ إِلَّا اللَّمَمَ إِنَّ رَبَّكَ وٰسِعُ المَغفِرَةِ هُوَ أَعلَمُ بِكُم إِذ أَنشَأَكُم مِنَ الأَرضِ وَإِذ أَنتُم أَجِنَّةٌ فى بُطونِ أُمَّهٰتِكُم فَلا تُزَكّوا أَنفُسَكُم هُوَ أَعلَمُ بِمَنِ اتَّقىٰ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxvii{أَفَرَءَيتَ الَّذى تَوَلّىٰ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxviii{وَأَعطىٰ قَليلًا وَأَكدىٰ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxix{أَعِندَهُ عِلمُ الغَيبِ فَهُوَ يَرىٰ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxx{أَم لَم يُنَبَّأ بِما فى صُحُفِ موسىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxxi{وَإِبرٰهيمَ الَّذى وَفّىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxxii{أَلّا تَزِرُ وازِرَةٌ وِزرَ أُخرىٰ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxxiii{وَأَن لَيسَ لِلإِنسٰنِ إِلّا ما سَعىٰ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxxiv{وَأَنَّ سَعيَهُ سَوفَ يُرىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxxv{ثُمَّ يُجزىٰهُ الجَزاءَ الأَوفىٰ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdcccxxvi{وَأَنَّ إِلىٰ رَبِّكَ المُنتَهىٰ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxxvii{وَأَنَّهُ هُوَ أَضحَكَ وَأَبكىٰ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxxviii{وَأَنَّهُ هُوَ أَماتَ وَأَحيا\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxxix{وَأَنَّهُ خَلَقَ الزَّوجَينِ الذَّكَرَ وَالأُنثىٰ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxxx{مِن نُطفَةٍ إِذا تُمنىٰ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxi{وَأَنَّ عَلَيهِ النَّشأَةَ الأُخرىٰ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxii{وَأَنَّهُ هُوَ أَغنىٰ وَأَقنىٰ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxiii{وَأَنَّهُ هُوَ رَبُّ الشِّعرىٰ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxiv{وَأَنَّهُ أَهلَكَ عادًا الأولىٰ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxv{وَثَمودَا۟ فَما أَبقىٰ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxvi{وَقَومَ نوحٍ مِن قَبلُ إِنَّهُم كانوا هُم أَظلَمَ وَأَطغىٰ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxvii{وَالمُؤتَفِكَةَ أَهوىٰ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxviii{فَغَشّىٰها ما غَشّىٰ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxxxix{فَبِأَىِّ ءالاءِ رَبِّكَ تَتَمارىٰ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxl{هٰذا نَذيرٌ مِنَ النُّذُرِ الأولىٰ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxli{أَزِفَتِ الءازِفَةُ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxlii{لَيسَ لَها مِن دونِ اللَّهِ كاشِفَةٌ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxliii{أَفَمِن هٰذَا الحَديثِ تَعجَبونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxliv{وَتَضحَكونَ وَلا تَبكونَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxlv{وَأَنتُم سٰمِدونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmdcccxlvi{فَاسجُدوا لِلَّهِ وَاعبُدوا\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxlvii{\basmalah  اقتَرَبَتِ السّاعَةُ وَانشَقَّ القَمَرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmdcccxlviii{وَإِن يَرَوا ءايَةً يُعرِضوا وَيَقولوا سِحرٌ مُستَمِرٌّ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxlix{وَكَذَّبوا وَاتَّبَعوا أَهواءَهُم وَكُلُّ أَمرٍ مُستَقِرٌّ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmdcccl{وَلَقَد جاءَهُم مِنَ الأَنباءِ ما فيهِ مُزدَجَرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmdcccli{حِكمَةٌ بٰلِغَةٌ فَما تُغنِ النُّذُرُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmdccclii{فَتَوَلَّ عَنهُم يَومَ يَدعُ الدّاعِ إِلىٰ شَيءٍ نُكُرٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmdcccliii{خُشَّعًا أَبصٰرُهُم يَخرُجونَ مِنَ الأَجداثِ كَأَنَّهُم جَرادٌ مُنتَشِرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmdcccliv{مُهطِعينَ إِلَى الدّاعِ يَقولُ الكٰفِرونَ هٰذا يَومٌ عَسِرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmdccclv{كَذَّبَت قَبلَهُم قَومُ نوحٍ فَكَذَّبوا عَبدَنا وَقالوا مَجنونٌ وَازدُجِرَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmdccclvi{فَدَعا رَبَّهُ أَنّى مَغلوبٌ فَانتَصِر\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmdccclvii{فَفَتَحنا أَبوٰبَ السَّماءِ بِماءٍ مُنهَمِرٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmdccclviii{وَفَجَّرنَا الأَرضَ عُيونًا فَالتَقَى الماءُ عَلىٰ أَمرٍ قَد قُدِرَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmdccclix{وَحَمَلنٰهُ عَلىٰ ذاتِ أَلوٰحٍ وَدُسُرٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmdccclx{تَجرى بِأَعيُنِنا جَزاءً لِمَن كانَ كُفِرَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxi{وَلَقَد تَرَكنٰها ءايَةً فَهَل مِن مُدَّكِرٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxii{فَكَيفَ كانَ عَذابى وَنُذُرِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxiii{وَلَقَد يَسَّرنَا القُرءانَ لِلذِّكرِ فَهَل مِن مُدَّكِرٍ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxiv{كَذَّبَت عادٌ فَكَيفَ كانَ عَذابى وَنُذُرِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxv{إِنّا أَرسَلنا عَلَيهِم ريحًا صَرصَرًا فى يَومِ نَحسٍ مُستَمِرٍّ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxvi{تَنزِعُ النّاسَ كَأَنَّهُم أَعجازُ نَخلٍ مُنقَعِرٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxvii{فَكَيفَ كانَ عَذابى وَنُذُرِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmdccclxviii{وَلَقَد يَسَّرنَا القُرءانَ لِلذِّكرِ فَهَل مِن مُدَّكِرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxix{كَذَّبَت ثَمودُ بِالنُّذُرِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmdccclxx{فَقالوا أَبَشَرًا مِنّا وٰحِدًا نَتَّبِعُهُ إِنّا إِذًا لَفى ضَلٰلٍ وَسُعُرٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxxi{أَءُلقِىَ الذِّكرُ عَلَيهِ مِن بَينِنا بَل هُوَ كَذّابٌ أَشِرٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxxii{سَيَعلَمونَ غَدًا مَنِ الكَذّابُ الأَشِرُ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxxiii{إِنّا مُرسِلُوا النّاقَةِ فِتنَةً لَهُم فَارتَقِبهُم وَاصطَبِر\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxxiv{وَنَبِّئهُم أَنَّ الماءَ قِسمَةٌ بَينَهُم كُلُّ شِربٍ مُحتَضَرٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxxv{فَنادَوا صاحِبَهُم فَتَعاطىٰ فَعَقَرَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxxvi{فَكَيفَ كانَ عَذابى وَنُذُرِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxxvii{إِنّا أَرسَلنا عَلَيهِم صَيحَةً وٰحِدَةً فَكانوا كَهَشيمِ المُحتَظِرِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmdccclxxviii{وَلَقَد يَسَّرنَا القُرءانَ لِلذِّكرِ فَهَل مِن مُدَّكِرٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxxix{كَذَّبَت قَومُ لوطٍ بِالنُّذُرِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmdccclxxx{إِنّا أَرسَلنا عَلَيهِم حاصِبًا إِلّا ءالَ لوطٍ نَجَّينٰهُم بِسَحَرٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxi{نِعمَةً مِن عِندِنا كَذٰلِكَ نَجزى مَن شَكَرَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxii{وَلَقَد أَنذَرَهُم بَطشَتَنا فَتَمارَوا بِالنُّذُرِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxiii{وَلَقَد رٰوَدوهُ عَن ضَيفِهِ فَطَمَسنا أَعيُنَهُم فَذوقوا عَذابى وَنُذُرِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxiv{وَلَقَد صَبَّحَهُم بُكرَةً عَذابٌ مُستَقِرٌّ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxv{فَذوقوا عَذابى وَنُذُرِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxvi{وَلَقَد يَسَّرنَا القُرءانَ لِلذِّكرِ فَهَل مِن مُدَّكِرٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxvii{وَلَقَد جاءَ ءالَ فِرعَونَ النُّذُرُ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxviii{كَذَّبوا بِـٔايٰتِنا كُلِّها فَأَخَذنٰهُم أَخذَ عَزيزٍ مُقتَدِرٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmdccclxxxix{أَكُفّارُكُم خَيرٌ مِن أُولٰئِكُم أَم لَكُم بَراءَةٌ فِى الزُّبُرِ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmdcccxc{أَم يَقولونَ نَحنُ جَميعٌ مُنتَصِرٌ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmdcccxci{سَيُهزَمُ الجَمعُ وَيُوَلّونَ الدُّبُرَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmdcccxcii{بَلِ السّاعَةُ مَوعِدُهُم وَالسّاعَةُ أَدهىٰ وَأَمَرُّ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmdcccxciii{إِنَّ المُجرِمينَ فى ضَلٰلٍ وَسُعُرٍ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmdcccxciv{يَومَ يُسحَبونَ فِى النّارِ عَلىٰ وُجوهِهِم ذوقوا مَسَّ سَقَرَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmdcccxcv{إِنّا كُلَّ شَيءٍ خَلَقنٰهُ بِقَدَرٍ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmdcccxcvi{وَما أَمرُنا إِلّا وٰحِدَةٌ كَلَمحٍ بِالبَصَرِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmdcccxcvii{وَلَقَد أَهلَكنا أَشياعَكُم فَهَل مِن مُدَّكِرٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmdcccxcviii{وَكُلُّ شَيءٍ فَعَلوهُ فِى الزُّبُرِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmdcccxcix{وَكُلُّ صَغيرٍ وَكَبيرٍ مُستَطَرٌ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcm{إِنَّ المُتَّقينَ فى جَنّٰتٍ وَنَهَرٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcmi{فى مَقعَدِ صِدقٍ عِندَ مَليكٍ مُقتَدِرٍ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcmii{\basmalah  الرَّحمٰنُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcmiii{عَلَّمَ القُرءانَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcmiv{خَلَقَ الإِنسٰنَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcmv{عَلَّمَهُ البَيانَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcmvi{الشَّمسُ وَالقَمَرُ بِحُسبانٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcmvii{وَالنَّجمُ وَالشَّجَرُ يَسجُدانِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcmviii{وَالسَّماءَ رَفَعَها وَوَضَعَ الميزانَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcmix{أَلّا تَطغَوا فِى الميزانِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcmx{وَأَقيمُوا الوَزنَ بِالقِسطِ وَلا تُخسِرُوا الميزانَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcmxi{وَالأَرضَ وَضَعَها لِلأَنامِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcmxii{فيها فٰكِهَةٌ وَالنَّخلُ ذاتُ الأَكمامِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcmxiii{وَالحَبُّ ذُو العَصفِ وَالرَّيحانُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcmxiv{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcmxv{خَلَقَ الإِنسٰنَ مِن صَلصٰلٍ كَالفَخّارِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcmxvi{وَخَلَقَ الجانَّ مِن مارِجٍ مِن نارٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcmxvii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcmxviii{رَبُّ المَشرِقَينِ وَرَبُّ المَغرِبَينِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcmxix{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcmxx{مَرَجَ البَحرَينِ يَلتَقِيانِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcmxxi{بَينَهُما بَرزَخٌ لا يَبغِيانِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmcmxxii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmcmxxiii{يَخرُجُ مِنهُمَا اللُّؤلُؤُ وَالمَرجانُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmcmxxiv{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmcmxxv{وَلَهُ الجَوارِ المُنشَـٔاتُ فِى البَحرِ كَالأَعلٰمِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmcmxxvi{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmcmxxvii{كُلُّ مَن عَلَيها فانٍ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmcmxxviii{وَيَبقىٰ وَجهُ رَبِّكَ ذُو الجَلٰلِ وَالإِكرامِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmcmxxix{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmcmxxx{يَسـَٔلُهُ مَن فِى السَّمٰوٰتِ وَالأَرضِ كُلَّ يَومٍ هُوَ فى شَأنٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmcmxxxi{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmcmxxxii{سَنَفرُغُ لَكُم أَيُّهَ الثَّقَلانِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmcmxxxiii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmcmxxxiv{يٰمَعشَرَ الجِنِّ وَالإِنسِ إِنِ استَطَعتُم أَن تَنفُذوا مِن أَقطارِ السَّمٰوٰتِ وَالأَرضِ فَانفُذوا لا تَنفُذونَ إِلّا بِسُلطٰنٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmcmxxxv{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmcmxxxvi{يُرسَلُ عَلَيكُما شُواظٌ مِن نارٍ وَنُحاسٌ فَلا تَنتَصِرانِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmcmxxxvii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmcmxxxviii{فَإِذَا انشَقَّتِ السَّماءُ فَكانَت وَردَةً كَالدِّهانِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmcmxxxix{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmcmxl{فَيَومَئِذٍ لا يُسـَٔلُ عَن ذَنبِهِ إِنسٌ وَلا جانٌّ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmcmxli{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmcmxlii{يُعرَفُ المُجرِمونَ بِسيمٰهُم فَيُؤخَذُ بِالنَّوٰصى وَالأَقدامِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmcmxliii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmcmxliv{هٰذِهِ جَهَنَّمُ الَّتى يُكَذِّبُ بِهَا المُجرِمونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmcmxlv{يَطوفونَ بَينَها وَبَينَ حَميمٍ ءانٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmcmxlvi{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmcmxlvii{وَلِمَن خافَ مَقامَ رَبِّهِ جَنَّتانِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmcmxlviii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmcmxlix{ذَواتا أَفنانٍ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmcml{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmcmli{فيهِما عَينانِ تَجرِيانِ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmcmlii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmcmliii{فيهِما مِن كُلِّ فٰكِهَةٍ زَوجانِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmcmliv{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmcmlv{مُتَّكِـٔينَ عَلىٰ فُرُشٍ بَطائِنُها مِن إِستَبرَقٍ وَجَنَى الجَنَّتَينِ دانٍ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmcmlvi{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmcmlvii{فيهِنَّ قٰصِرٰتُ الطَّرفِ لَم يَطمِثهُنَّ إِنسٌ قَبلَهُم وَلا جانٌّ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmcmlviii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmcmlix{كَأَنَّهُنَّ الياقوتُ وَالمَرجانُ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmcmlx{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxi{هَل جَزاءُ الإِحسٰنِ إِلَّا الإِحسٰنُ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmcmlxii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmcmlxiii{وَمِن دونِهِما جَنَّتانِ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxiv{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxv{مُدهامَّتانِ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxvi{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxvii{فيهِما عَينانِ نَضّاخَتانِ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxviii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxix{فيهِما فٰكِهَةٌ وَنَخلٌ وَرُمّانٌ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxx{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxxi{فيهِنَّ خَيرٰتٌ حِسانٌ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmcmlxxii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmcmlxxiii{حورٌ مَقصورٰتٌ فِى الخِيامِ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxxiv{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxxv{لَم يَطمِثهُنَّ إِنسٌ قَبلَهُم وَلا جانٌّ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxxvi{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxxvii{مُتَّكِـٔينَ عَلىٰ رَفرَفٍ خُضرٍ وَعَبقَرِىٍّ حِسانٍ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxxviii{فَبِأَىِّ ءالاءِ رَبِّكُما تُكَذِّبانِ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxxix{تَبٰرَكَ اسمُ رَبِّكَ ذِى الجَلٰلِ وَالإِكرامِ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxxx{\basmalah  إِذا وَقَعَتِ الواقِعَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxi{لَيسَ لِوَقعَتِها كاذِبَةٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxii{خافِضَةٌ رافِعَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxiii{إِذا رُجَّتِ الأَرضُ رَجًّا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxiv{وَبُسَّتِ الجِبالُ بَسًّا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxv{فَكانَت هَباءً مُنبَثًّا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxvi{وَكُنتُم أَزوٰجًا ثَلٰثَةً\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxvii{فَأَصحٰبُ المَيمَنَةِ ما أَصحٰبُ المَيمَنَةِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxviii{وَأَصحٰبُ المَشـَٔمَةِ ما أَصحٰبُ المَشـَٔمَةِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmcmlxxxix{وَالسّٰبِقونَ السّٰبِقونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmcmxc{أُولٰئِكَ المُقَرَّبونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmcmxci{فى جَنّٰتِ النَّعيمِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmcmxcii{ثُلَّةٌ مِنَ الأَوَّلينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmcmxciii{وَقَليلٌ مِنَ الءاخِرينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmcmxciv{عَلىٰ سُرُرٍ مَوضونَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmcmxcv{مُتَّكِـٔينَ عَلَيها مُتَقٰبِلينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmcmxcvi{يَطوفُ عَلَيهِم وِلدٰنٌ مُخَلَّدونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmcmxcvii{بِأَكوابٍ وَأَباريقَ وَكَأسٍ مِن مَعينٍ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmcmxcviii{لا يُصَدَّعونَ عَنها وَلا يُنزِفونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmcmxcix{وَفٰكِهَةٍ مِمّا يَتَخَيَّرونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmm{وَلَحمِ طَيرٍ مِمّا يَشتَهونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmi{وَحورٌ عينٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmii{كَأَمثٰلِ اللُّؤلُؤِ المَكنونِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmiii{جَزاءً بِما كانوا يَعمَلونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmiv{لا يَسمَعونَ فيها لَغوًا وَلا تَأثيمًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmv{إِلّا قيلًا سَلٰمًا سَلٰمًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmvi{وَأَصحٰبُ اليَمينِ ما أَصحٰبُ اليَمينِ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmvii{فى سِدرٍ مَخضودٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmviii{وَطَلحٍ مَنضودٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmix{وَظِلٍّ مَمدودٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmx{وَماءٍ مَسكوبٍ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmxi{وَفٰكِهَةٍ كَثيرَةٍ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmxii{لا مَقطوعَةٍ وَلا مَمنوعَةٍ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmxiii{وَفُرُشٍ مَرفوعَةٍ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmxiv{إِنّا أَنشَأنٰهُنَّ إِنشاءً\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmxv{فَجَعَلنٰهُنَّ أَبكارًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmxvi{عُرُبًا أَترابًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmxvii{لِأَصحٰبِ اليَمينِ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmxviii{ثُلَّةٌ مِنَ الأَوَّلينَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmxix{وَثُلَّةٌ مِنَ الءاخِرينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmxx{وَأَصحٰبُ الشِّمالِ ما أَصحٰبُ الشِّمالِ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmxxi{فى سَمومٍ وَحَميمٍ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmxxii{وَظِلٍّ مِن يَحمومٍ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmxxiii{لا بارِدٍ وَلا كَريمٍ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmxxiv{إِنَّهُم كانوا قَبلَ ذٰلِكَ مُترَفينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmxxv{وَكانوا يُصِرّونَ عَلَى الحِنثِ العَظيمِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmxxvi{وَكانوا يَقولونَ أَئِذا مِتنا وَكُنّا تُرابًا وَعِظٰمًا أَءِنّا لَمَبعوثونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmxxvii{أَوَءاباؤُنَا الأَوَّلونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmxxviii{قُل إِنَّ الأَوَّلينَ وَالءاخِرينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmxxix{لَمَجموعونَ إِلىٰ ميقٰتِ يَومٍ مَعلومٍ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmxxx{ثُمَّ إِنَّكُم أَيُّهَا الضّالّونَ المُكَذِّبونَ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmxxxi{لَءاكِلونَ مِن شَجَرٍ مِن زَقّومٍ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmxxxii{فَمالِـٔونَ مِنهَا البُطونَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmmxxxiii{فَشٰرِبونَ عَلَيهِ مِنَ الحَميمِ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmmxxxiv{فَشٰرِبونَ شُربَ الهيمِ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmmxxxv{هٰذا نُزُلُهُم يَومَ الدّينِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmmxxxvi{نَحنُ خَلَقنٰكُم فَلَولا تُصَدِّقونَ\qt@no{﴿٥٧﴾}}
\qt@newcmd\qurantext@mmmmmxxxvii{أَفَرَءَيتُم ما تُمنونَ\qt@no{﴿٥٨﴾}}
\qt@newcmd\qurantext@mmmmmxxxviii{ءَأَنتُم تَخلُقونَهُ أَم نَحنُ الخٰلِقونَ\qt@no{﴿٥٩﴾}}
\qt@newcmd\qurantext@mmmmmxxxix{نَحنُ قَدَّرنا بَينَكُمُ المَوتَ وَما نَحنُ بِمَسبوقينَ\qt@no{﴿٦٠﴾}}
\qt@newcmd\qurantext@mmmmmxl{عَلىٰ أَن نُبَدِّلَ أَمثٰلَكُم وَنُنشِئَكُم فى ما لا تَعلَمونَ\qt@no{﴿٦١﴾}}
\qt@newcmd\qurantext@mmmmmxli{وَلَقَد عَلِمتُمُ النَّشأَةَ الأولىٰ فَلَولا تَذَكَّرونَ\qt@no{﴿٦٢﴾}}
\qt@newcmd\qurantext@mmmmmxlii{أَفَرَءَيتُم ما تَحرُثونَ\qt@no{﴿٦٣﴾}}
\qt@newcmd\qurantext@mmmmmxliii{ءَأَنتُم تَزرَعونَهُ أَم نَحنُ الزّٰرِعونَ\qt@no{﴿٦٤﴾}}
\qt@newcmd\qurantext@mmmmmxliv{لَو نَشاءُ لَجَعَلنٰهُ حُطٰمًا فَظَلتُم تَفَكَّهونَ\qt@no{﴿٦٥﴾}}
\qt@newcmd\qurantext@mmmmmxlv{إِنّا لَمُغرَمونَ\qt@no{﴿٦٦﴾}}
\qt@newcmd\qurantext@mmmmmxlvi{بَل نَحنُ مَحرومونَ\qt@no{﴿٦٧﴾}}
\qt@newcmd\qurantext@mmmmmxlvii{أَفَرَءَيتُمُ الماءَ الَّذى تَشرَبونَ\qt@no{﴿٦٨﴾}}
\qt@newcmd\qurantext@mmmmmxlviii{ءَأَنتُم أَنزَلتُموهُ مِنَ المُزنِ أَم نَحنُ المُنزِلونَ\qt@no{﴿٦٩﴾}}
\qt@newcmd\qurantext@mmmmmxlix{لَو نَشاءُ جَعَلنٰهُ أُجاجًا فَلَولا تَشكُرونَ\qt@no{﴿٧٠﴾}}
\qt@newcmd\qurantext@mmmmml{أَفَرَءَيتُمُ النّارَ الَّتى تورونَ\qt@no{﴿٧١﴾}}
\qt@newcmd\qurantext@mmmmmli{ءَأَنتُم أَنشَأتُم شَجَرَتَها أَم نَحنُ المُنشِـٔونَ\qt@no{﴿٧٢﴾}}
\qt@newcmd\qurantext@mmmmmlii{نَحنُ جَعَلنٰها تَذكِرَةً وَمَتٰعًا لِلمُقوينَ\qt@no{﴿٧٣﴾}}
\qt@newcmd\qurantext@mmmmmliii{فَسَبِّح بِاسمِ رَبِّكَ العَظيمِ\qt@no{﴿٧٤﴾}}
\qt@newcmd\qurantext@mmmmmliv{فَلا أُقسِمُ بِمَوٰقِعِ النُّجومِ\qt@no{﴿٧٥﴾}}
\qt@newcmd\qurantext@mmmmmlv{وَإِنَّهُ لَقَسَمٌ لَو تَعلَمونَ عَظيمٌ\qt@no{﴿٧٦﴾}}
\qt@newcmd\qurantext@mmmmmlvi{إِنَّهُ لَقُرءانٌ كَريمٌ\qt@no{﴿٧٧﴾}}
\qt@newcmd\qurantext@mmmmmlvii{فى كِتٰبٍ مَكنونٍ\qt@no{﴿٧٨﴾}}
\qt@newcmd\qurantext@mmmmmlviii{لا يَمَسُّهُ إِلَّا المُطَهَّرونَ\qt@no{﴿٧٩﴾}}
\qt@newcmd\qurantext@mmmmmlix{تَنزيلٌ مِن رَبِّ العٰلَمينَ\qt@no{﴿٨٠﴾}}
\qt@newcmd\qurantext@mmmmmlx{أَفَبِهٰذَا الحَديثِ أَنتُم مُدهِنونَ\qt@no{﴿٨١﴾}}
\qt@newcmd\qurantext@mmmmmlxi{وَتَجعَلونَ رِزقَكُم أَنَّكُم تُكَذِّبونَ\qt@no{﴿٨٢﴾}}
\qt@newcmd\qurantext@mmmmmlxii{فَلَولا إِذا بَلَغَتِ الحُلقومَ\qt@no{﴿٨٣﴾}}
\qt@newcmd\qurantext@mmmmmlxiii{وَأَنتُم حينَئِذٍ تَنظُرونَ\qt@no{﴿٨٤﴾}}
\qt@newcmd\qurantext@mmmmmlxiv{وَنَحنُ أَقرَبُ إِلَيهِ مِنكُم وَلٰكِن لا تُبصِرونَ\qt@no{﴿٨٥﴾}}
\qt@newcmd\qurantext@mmmmmlxv{فَلَولا إِن كُنتُم غَيرَ مَدينينَ\qt@no{﴿٨٦﴾}}
\qt@newcmd\qurantext@mmmmmlxvi{تَرجِعونَها إِن كُنتُم صٰدِقينَ\qt@no{﴿٨٧﴾}}
\qt@newcmd\qurantext@mmmmmlxvii{فَأَمّا إِن كانَ مِنَ المُقَرَّبينَ\qt@no{﴿٨٨﴾}}
\qt@newcmd\qurantext@mmmmmlxviii{فَرَوحٌ وَرَيحانٌ وَجَنَّتُ نَعيمٍ\qt@no{﴿٨٩﴾}}
\qt@newcmd\qurantext@mmmmmlxix{وَأَمّا إِن كانَ مِن أَصحٰبِ اليَمينِ\qt@no{﴿٩٠﴾}}
\qt@newcmd\qurantext@mmmmmlxx{فَسَلٰمٌ لَكَ مِن أَصحٰبِ اليَمينِ\qt@no{﴿٩١﴾}}
\qt@newcmd\qurantext@mmmmmlxxi{وَأَمّا إِن كانَ مِنَ المُكَذِّبينَ الضّالّينَ\qt@no{﴿٩٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxii{فَنُزُلٌ مِن حَميمٍ\qt@no{﴿٩٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxiii{وَتَصلِيَةُ جَحيمٍ\qt@no{﴿٩٤﴾}}
\qt@newcmd\qurantext@mmmmmlxxiv{إِنَّ هٰذا لَهُوَ حَقُّ اليَقينِ\qt@no{﴿٩٥﴾}}
\qt@newcmd\qurantext@mmmmmlxxv{فَسَبِّح بِاسمِ رَبِّكَ العَظيمِ\qt@no{﴿٩٦﴾}}
\qt@newcmd\qurantext@mmmmmlxxvi{\basmalah  سَبَّحَ لِلَّهِ ما فِى السَّمٰوٰتِ وَالأَرضِ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmlxxvii{لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ يُحيۦ وَيُميتُ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxviii{هُوَ الأَوَّلُ وَالءاخِرُ وَالظّٰهِرُ وَالباطِنُ وَهُوَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxix{هُوَ الَّذى خَلَقَ السَّمٰوٰتِ وَالأَرضَ فى سِتَّةِ أَيّامٍ ثُمَّ استَوىٰ عَلَى العَرشِ يَعلَمُ ما يَلِجُ فِى الأَرضِ وَما يَخرُجُ مِنها وَما يَنزِلُ مِنَ السَّماءِ وَما يَعرُجُ فيها وَهُوَ مَعَكُم أَينَ ما كُنتُم وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmlxxx{لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَإِلَى اللَّهِ تُرجَعُ الأُمورُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmlxxxi{يولِجُ الَّيلَ فِى النَّهارِ وَيولِجُ النَّهارَ فِى الَّيلِ وَهُوَ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmlxxxii{ءامِنوا بِاللَّهِ وَرَسولِهِ وَأَنفِقوا مِمّا جَعَلَكُم مُستَخلَفينَ فيهِ فَالَّذينَ ءامَنوا مِنكُم وَأَنفَقوا لَهُم أَجرٌ كَبيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmlxxxiii{وَما لَكُم لا تُؤمِنونَ بِاللَّهِ وَالرَّسولُ يَدعوكُم لِتُؤمِنوا بِرَبِّكُم وَقَد أَخَذَ ميثٰقَكُم إِن كُنتُم مُؤمِنينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmlxxxiv{هُوَ الَّذى يُنَزِّلُ عَلىٰ عَبدِهِ ءايٰتٍ بَيِّنٰتٍ لِيُخرِجَكُم مِنَ الظُّلُمٰتِ إِلَى النّورِ وَإِنَّ اللَّهَ بِكُم لَرَءوفٌ رَحيمٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmlxxxv{وَما لَكُم أَلّا تُنفِقوا فى سَبيلِ اللَّهِ وَلِلَّهِ ميرٰثُ السَّمٰوٰتِ وَالأَرضِ لا يَستَوى مِنكُم مَن أَنفَقَ مِن قَبلِ الفَتحِ وَقٰتَلَ أُولٰئِكَ أَعظَمُ دَرَجَةً مِنَ الَّذينَ أَنفَقوا مِن بَعدُ وَقٰتَلوا وَكُلًّا وَعَدَ اللَّهُ الحُسنىٰ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmlxxxvi{مَن ذَا الَّذى يُقرِضُ اللَّهَ قَرضًا حَسَنًا فَيُضٰعِفَهُ لَهُ وَلَهُ أَجرٌ كَريمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmlxxxvii{يَومَ تَرَى المُؤمِنينَ وَالمُؤمِنٰتِ يَسعىٰ نورُهُم بَينَ أَيديهِم وَبِأَيمٰنِهِم بُشرىٰكُمُ اليَومَ جَنّٰتٌ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها ذٰلِكَ هُوَ الفَوزُ العَظيمُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmlxxxviii{يَومَ يَقولُ المُنٰفِقونَ وَالمُنٰفِقٰتُ لِلَّذينَ ءامَنُوا انظُرونا نَقتَبِس مِن نورِكُم قيلَ ارجِعوا وَراءَكُم فَالتَمِسوا نورًا فَضُرِبَ بَينَهُم بِسورٍ لَهُ بابٌ باطِنُهُ فيهِ الرَّحمَةُ وَظٰهِرُهُ مِن قِبَلِهِ العَذابُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmlxxxix{يُنادونَهُم أَلَم نَكُن مَعَكُم قالوا بَلىٰ وَلٰكِنَّكُم فَتَنتُم أَنفُسَكُم وَتَرَبَّصتُم وَارتَبتُم وَغَرَّتكُمُ الأَمانِىُّ حَتّىٰ جاءَ أَمرُ اللَّهِ وَغَرَّكُم بِاللَّهِ الغَرورُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmxc{فَاليَومَ لا يُؤخَذُ مِنكُم فِديَةٌ وَلا مِنَ الَّذينَ كَفَروا مَأوىٰكُمُ النّارُ هِىَ مَولىٰكُم وَبِئسَ المَصيرُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmxci{أَلَم يَأنِ لِلَّذينَ ءامَنوا أَن تَخشَعَ قُلوبُهُم لِذِكرِ اللَّهِ وَما نَزَلَ مِنَ الحَقِّ وَلا يَكونوا كَالَّذينَ أوتُوا الكِتٰبَ مِن قَبلُ فَطالَ عَلَيهِمُ الأَمَدُ فَقَسَت قُلوبُهُم وَكَثيرٌ مِنهُم فٰسِقونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmxcii{اعلَموا أَنَّ اللَّهَ يُحىِ الأَرضَ بَعدَ مَوتِها قَد بَيَّنّا لَكُمُ الءايٰتِ لَعَلَّكُم تَعقِلونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmxciii{إِنَّ المُصَّدِّقينَ وَالمُصَّدِّقٰتِ وَأَقرَضُوا اللَّهَ قَرضًا حَسَنًا يُضٰعَفُ لَهُم وَلَهُم أَجرٌ كَريمٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmxciv{وَالَّذينَ ءامَنوا بِاللَّهِ وَرُسُلِهِ أُولٰئِكَ هُمُ الصِّدّيقونَ وَالشُّهَداءُ عِندَ رَبِّهِم لَهُم أَجرُهُم وَنورُهُم وَالَّذينَ كَفَروا وَكَذَّبوا بِـٔايٰتِنا أُولٰئِكَ أَصحٰبُ الجَحيمِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmxcv{اعلَموا أَنَّمَا الحَيوٰةُ الدُّنيا لَعِبٌ وَلَهوٌ وَزينَةٌ وَتَفاخُرٌ بَينَكُم وَتَكاثُرٌ فِى الأَموٰلِ وَالأَولٰدِ كَمَثَلِ غَيثٍ أَعجَبَ الكُفّارَ نَباتُهُ ثُمَّ يَهيجُ فَتَرىٰهُ مُصفَرًّا ثُمَّ يَكونُ حُطٰمًا وَفِى الءاخِرَةِ عَذابٌ شَديدٌ وَمَغفِرَةٌ مِنَ اللَّهِ وَرِضوٰنٌ وَمَا الحَيوٰةُ الدُّنيا إِلّا مَتٰعُ الغُرورِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmxcvi{سابِقوا إِلىٰ مَغفِرَةٍ مِن رَبِّكُم وَجَنَّةٍ عَرضُها كَعَرضِ السَّماءِ وَالأَرضِ أُعِدَّت لِلَّذينَ ءامَنوا بِاللَّهِ وَرُسُلِهِ ذٰلِكَ فَضلُ اللَّهِ يُؤتيهِ مَن يَشاءُ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmxcvii{ما أَصابَ مِن مُصيبَةٍ فِى الأَرضِ وَلا فى أَنفُسِكُم إِلّا فى كِتٰبٍ مِن قَبلِ أَن نَبرَأَها إِنَّ ذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmxcviii{لِكَيلا تَأسَوا عَلىٰ ما فاتَكُم وَلا تَفرَحوا بِما ءاتىٰكُم وَاللَّهُ لا يُحِبُّ كُلَّ مُختالٍ فَخورٍ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmxcix{الَّذينَ يَبخَلونَ وَيَأمُرونَ النّاسَ بِالبُخلِ وَمَن يَتَوَلَّ فَإِنَّ اللَّهَ هُوَ الغَنِىُّ الحَميدُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmc{لَقَد أَرسَلنا رُسُلَنا بِالبَيِّنٰتِ وَأَنزَلنا مَعَهُمُ الكِتٰبَ وَالميزانَ لِيَقومَ النّاسُ بِالقِسطِ وَأَنزَلنَا الحَديدَ فيهِ بَأسٌ شَديدٌ وَمَنٰفِعُ لِلنّاسِ وَلِيَعلَمَ اللَّهُ مَن يَنصُرُهُ وَرُسُلَهُ بِالغَيبِ إِنَّ اللَّهَ قَوِىٌّ عَزيزٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmci{وَلَقَد أَرسَلنا نوحًا وَإِبرٰهيمَ وَجَعَلنا فى ذُرِّيَّتِهِمَا النُّبُوَّةَ وَالكِتٰبَ فَمِنهُم مُهتَدٍ وَكَثيرٌ مِنهُم فٰسِقونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcii{ثُمَّ قَفَّينا عَلىٰ ءاثٰرِهِم بِرُسُلِنا وَقَفَّينا بِعيسَى ابنِ مَريَمَ وَءاتَينٰهُ الإِنجيلَ وَجَعَلنا فى قُلوبِ الَّذينَ اتَّبَعوهُ رَأفَةً وَرَحمَةً وَرَهبانِيَّةً ابتَدَعوها ما كَتَبنٰها عَلَيهِم إِلَّا ابتِغاءَ رِضوٰنِ اللَّهِ فَما رَعَوها حَقَّ رِعايَتِها فَـٔاتَينَا الَّذينَ ءامَنوا مِنهُم أَجرَهُم وَكَثيرٌ مِنهُم فٰسِقونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmciii{يٰأَيُّهَا الَّذينَ ءامَنُوا اتَّقُوا اللَّهَ وَءامِنوا بِرَسولِهِ يُؤتِكُم كِفلَينِ مِن رَحمَتِهِ وَيَجعَل لَكُم نورًا تَمشونَ بِهِ وَيَغفِر لَكُم وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmciv{لِئَلّا يَعلَمَ أَهلُ الكِتٰبِ أَلّا يَقدِرونَ عَلىٰ شَيءٍ مِن فَضلِ اللَّهِ وَأَنَّ الفَضلَ بِيَدِ اللَّهِ يُؤتيهِ مَن يَشاءُ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcv{\basmalah  قَد سَمِعَ اللَّهُ قَولَ الَّتى تُجٰدِلُكَ فى زَوجِها وَتَشتَكى إِلَى اللَّهِ وَاللَّهُ يَسمَعُ تَحاوُرَكُما إِنَّ اللَّهَ سَميعٌ بَصيرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcvi{الَّذينَ يُظٰهِرونَ مِنكُم مِن نِسائِهِم ما هُنَّ أُمَّهٰتِهِم إِن أُمَّهٰتُهُم إِلَّا الّٰـٔى وَلَدنَهُم وَإِنَّهُم لَيَقولونَ مُنكَرًا مِنَ القَولِ وَزورًا وَإِنَّ اللَّهَ لَعَفُوٌّ غَفورٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcvii{وَالَّذينَ يُظٰهِرونَ مِن نِسائِهِم ثُمَّ يَعودونَ لِما قالوا فَتَحريرُ رَقَبَةٍ مِن قَبلِ أَن يَتَماسّا ذٰلِكُم توعَظونَ بِهِ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcviii{فَمَن لَم يَجِد فَصِيامُ شَهرَينِ مُتَتابِعَينِ مِن قَبلِ أَن يَتَماسّا فَمَن لَم يَستَطِع فَإِطعامُ سِتّينَ مِسكينًا ذٰلِكَ لِتُؤمِنوا بِاللَّهِ وَرَسولِهِ وَتِلكَ حُدودُ اللَّهِ وَلِلكٰفِرينَ عَذابٌ أَليمٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcix{إِنَّ الَّذينَ يُحادّونَ اللَّهَ وَرَسولَهُ كُبِتوا كَما كُبِتَ الَّذينَ مِن قَبلِهِم وَقَد أَنزَلنا ءايٰتٍ بَيِّنٰتٍ وَلِلكٰفِرينَ عَذابٌ مُهينٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcx{يَومَ يَبعَثُهُمُ اللَّهُ جَميعًا فَيُنَبِّئُهُم بِما عَمِلوا أَحصىٰهُ اللَّهُ وَنَسوهُ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxi{أَلَم تَرَ أَنَّ اللَّهَ يَعلَمُ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ ما يَكونُ مِن نَجوىٰ ثَلٰثَةٍ إِلّا هُوَ رابِعُهُم وَلا خَمسَةٍ إِلّا هُوَ سادِسُهُم وَلا أَدنىٰ مِن ذٰلِكَ وَلا أَكثَرَ إِلّا هُوَ مَعَهُم أَينَ ما كانوا ثُمَّ يُنَبِّئُهُم بِما عَمِلوا يَومَ القِيٰمَةِ إِنَّ اللَّهَ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxii{أَلَم تَرَ إِلَى الَّذينَ نُهوا عَنِ النَّجوىٰ ثُمَّ يَعودونَ لِما نُهوا عَنهُ وَيَتَنٰجَونَ بِالإِثمِ وَالعُدوٰنِ وَمَعصِيَتِ الرَّسولِ وَإِذا جاءوكَ حَيَّوكَ بِما لَم يُحَيِّكَ بِهِ اللَّهُ وَيَقولونَ فى أَنفُسِهِم لَولا يُعَذِّبُنَا اللَّهُ بِما نَقولُ حَسبُهُم جَهَنَّمُ يَصلَونَها فَبِئسَ المَصيرُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxiii{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا تَنٰجَيتُم فَلا تَتَنٰجَوا بِالإِثمِ وَالعُدوٰنِ وَمَعصِيَتِ الرَّسولِ وَتَنٰجَوا بِالبِرِّ وَالتَّقوىٰ وَاتَّقُوا اللَّهَ الَّذى إِلَيهِ تُحشَرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxiv{إِنَّمَا النَّجوىٰ مِنَ الشَّيطٰنِ لِيَحزُنَ الَّذينَ ءامَنوا وَلَيسَ بِضارِّهِم شَيـًٔا إِلّا بِإِذنِ اللَّهِ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxv{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا قيلَ لَكُم تَفَسَّحوا فِى المَجٰلِسِ فَافسَحوا يَفسَحِ اللَّهُ لَكُم وَإِذا قيلَ انشُزوا فَانشُزوا يَرفَعِ اللَّهُ الَّذينَ ءامَنوا مِنكُم وَالَّذينَ أوتُوا العِلمَ دَرَجٰتٍ وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcxvi{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا نٰجَيتُمُ الرَّسولَ فَقَدِّموا بَينَ يَدَى نَجوىٰكُم صَدَقَةً ذٰلِكَ خَيرٌ لَكُم وَأَطهَرُ فَإِن لَم تَجِدوا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcxvii{ءَأَشفَقتُم أَن تُقَدِّموا بَينَ يَدَى نَجوىٰكُم صَدَقٰتٍ فَإِذ لَم تَفعَلوا وَتابَ اللَّهُ عَلَيكُم فَأَقيمُوا الصَّلوٰةَ وَءاتُوا الزَّكوٰةَ وَأَطيعُوا اللَّهَ وَرَسولَهُ وَاللَّهُ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcxviii{أَلَم تَرَ إِلَى الَّذينَ تَوَلَّوا قَومًا غَضِبَ اللَّهُ عَلَيهِم ما هُم مِنكُم وَلا مِنهُم وَيَحلِفونَ عَلَى الكَذِبِ وَهُم يَعلَمونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcxix{أَعَدَّ اللَّهُ لَهُم عَذابًا شَديدًا إِنَّهُم ساءَ ما كانوا يَعمَلونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcxx{اتَّخَذوا أَيمٰنَهُم جُنَّةً فَصَدّوا عَن سَبيلِ اللَّهِ فَلَهُم عَذابٌ مُهينٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcxxi{لَن تُغنِىَ عَنهُم أَموٰلُهُم وَلا أَولٰدُهُم مِنَ اللَّهِ شَيـًٔا أُولٰئِكَ أَصحٰبُ النّارِ هُم فيها خٰلِدونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcxxii{يَومَ يَبعَثُهُمُ اللَّهُ جَميعًا فَيَحلِفونَ لَهُ كَما يَحلِفونَ لَكُم وَيَحسَبونَ أَنَّهُم عَلىٰ شَيءٍ أَلا إِنَّهُم هُمُ الكٰذِبونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcxxiii{استَحوَذَ عَلَيهِمُ الشَّيطٰنُ فَأَنسىٰهُم ذِكرَ اللَّهِ أُولٰئِكَ حِزبُ الشَّيطٰنِ أَلا إِنَّ حِزبَ الشَّيطٰنِ هُمُ الخٰسِرونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcxxiv{إِنَّ الَّذينَ يُحادّونَ اللَّهَ وَرَسولَهُ أُولٰئِكَ فِى الأَذَلّينَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcxxv{كَتَبَ اللَّهُ لَأَغلِبَنَّ أَنا۠ وَرُسُلى إِنَّ اللَّهَ قَوِىٌّ عَزيزٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcxxvi{لا تَجِدُ قَومًا يُؤمِنونَ بِاللَّهِ وَاليَومِ الءاخِرِ يُوادّونَ مَن حادَّ اللَّهَ وَرَسولَهُ وَلَو كانوا ءاباءَهُم أَو أَبناءَهُم أَو إِخوٰنَهُم أَو عَشيرَتَهُم أُولٰئِكَ كَتَبَ فى قُلوبِهِمُ الإيمٰنَ وَأَيَّدَهُم بِروحٍ مِنهُ وَيُدخِلُهُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها رَضِىَ اللَّهُ عَنهُم وَرَضوا عَنهُ أُولٰئِكَ حِزبُ اللَّهِ أَلا إِنَّ حِزبَ اللَّهِ هُمُ المُفلِحونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxvii{\basmalah  سَبَّحَ لِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcxxviii{هُوَ الَّذى أَخرَجَ الَّذينَ كَفَروا مِن أَهلِ الكِتٰبِ مِن دِيٰرِهِم لِأَوَّلِ الحَشرِ ما ظَنَنتُم أَن يَخرُجوا وَظَنّوا أَنَّهُم مانِعَتُهُم حُصونُهُم مِنَ اللَّهِ فَأَتىٰهُمُ اللَّهُ مِن حَيثُ لَم يَحتَسِبوا وَقَذَفَ فى قُلوبِهِمُ الرُّعبَ يُخرِبونَ بُيوتَهُم بِأَيديهِم وَأَيدِى المُؤمِنينَ فَاعتَبِروا يٰأُولِى الأَبصٰرِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxix{وَلَولا أَن كَتَبَ اللَّهُ عَلَيهِمُ الجَلاءَ لَعَذَّبَهُم فِى الدُّنيا وَلَهُم فِى الءاخِرَةِ عَذابُ النّارِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcxxx{ذٰلِكَ بِأَنَّهُم شاقُّوا اللَّهَ وَرَسولَهُ وَمَن يُشاقِّ اللَّهَ فَإِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcxxxi{ما قَطَعتُم مِن لينَةٍ أَو تَرَكتُموها قائِمَةً عَلىٰ أُصولِها فَبِإِذنِ اللَّهِ وَلِيُخزِىَ الفٰسِقينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcxxxii{وَما أَفاءَ اللَّهُ عَلىٰ رَسولِهِ مِنهُم فَما أَوجَفتُم عَلَيهِ مِن خَيلٍ وَلا رِكابٍ وَلٰكِنَّ اللَّهَ يُسَلِّطُ رُسُلَهُ عَلىٰ مَن يَشاءُ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxxxiii{ما أَفاءَ اللَّهُ عَلىٰ رَسولِهِ مِن أَهلِ القُرىٰ فَلِلَّهِ وَلِلرَّسولِ وَلِذِى القُربىٰ وَاليَتٰمىٰ وَالمَسٰكينِ وَابنِ السَّبيلِ كَى لا يَكونَ دولَةً بَينَ الأَغنِياءِ مِنكُم وَما ءاتىٰكُمُ الرَّسولُ فَخُذوهُ وَما نَهىٰكُم عَنهُ فَانتَهوا وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ شَديدُ العِقابِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxxxiv{لِلفُقَراءِ المُهٰجِرينَ الَّذينَ أُخرِجوا مِن دِيٰرِهِم وَأَموٰلِهِم يَبتَغونَ فَضلًا مِنَ اللَّهِ وَرِضوٰنًا وَيَنصُرونَ اللَّهَ وَرَسولَهُ أُولٰئِكَ هُمُ الصّٰدِقونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxxxv{وَالَّذينَ تَبَوَّءُو الدّارَ وَالإيمٰنَ مِن قَبلِهِم يُحِبّونَ مَن هاجَرَ إِلَيهِم وَلا يَجِدونَ فى صُدورِهِم حاجَةً مِمّا أوتوا وَيُؤثِرونَ عَلىٰ أَنفُسِهِم وَلَو كانَ بِهِم خَصاصَةٌ وَمَن يوقَ شُحَّ نَفسِهِ فَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxxxvi{وَالَّذينَ جاءو مِن بَعدِهِم يَقولونَ رَبَّنَا اغفِر لَنا وَلِإِخوٰنِنَا الَّذينَ سَبَقونا بِالإيمٰنِ وَلا تَجعَل فى قُلوبِنا غِلًّا لِلَّذينَ ءامَنوا رَبَّنا إِنَّكَ رَءوفٌ رَحيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxxxvii{أَلَم تَرَ إِلَى الَّذينَ نافَقوا يَقولونَ لِإِخوٰنِهِمُ الَّذينَ كَفَروا مِن أَهلِ الكِتٰبِ لَئِن أُخرِجتُم لَنَخرُجَنَّ مَعَكُم وَلا نُطيعُ فيكُم أَحَدًا أَبَدًا وَإِن قوتِلتُم لَنَنصُرَنَّكُم وَاللَّهُ يَشهَدُ إِنَّهُم لَكٰذِبونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcxxxviii{لَئِن أُخرِجوا لا يَخرُجونَ مَعَهُم وَلَئِن قوتِلوا لا يَنصُرونَهُم وَلَئِن نَصَروهُم لَيُوَلُّنَّ الأَدبٰرَ ثُمَّ لا يُنصَرونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcxxxix{لَأَنتُم أَشَدُّ رَهبَةً فى صُدورِهِم مِنَ اللَّهِ ذٰلِكَ بِأَنَّهُم قَومٌ لا يَفقَهونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcxl{لا يُقٰتِلونَكُم جَميعًا إِلّا فى قُرًى مُحَصَّنَةٍ أَو مِن وَراءِ جُدُرٍ بَأسُهُم بَينَهُم شَديدٌ تَحسَبُهُم جَميعًا وَقُلوبُهُم شَتّىٰ ذٰلِكَ بِأَنَّهُم قَومٌ لا يَعقِلونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcxli{كَمَثَلِ الَّذينَ مِن قَبلِهِم قَريبًا ذاقوا وَبالَ أَمرِهِم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcxlii{كَمَثَلِ الشَّيطٰنِ إِذ قالَ لِلإِنسٰنِ اكفُر فَلَمّا كَفَرَ قالَ إِنّى بَريءٌ مِنكَ إِنّى أَخافُ اللَّهَ رَبَّ العٰلَمينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcxliii{فَكانَ عٰقِبَتَهُما أَنَّهُما فِى النّارِ خٰلِدَينِ فيها وَذٰلِكَ جَزٰؤُا۟ الظّٰلِمينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcxliv{يٰأَيُّهَا الَّذينَ ءامَنُوا اتَّقُوا اللَّهَ وَلتَنظُر نَفسٌ ما قَدَّمَت لِغَدٍ وَاتَّقُوا اللَّهَ إِنَّ اللَّهَ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcxlv{وَلا تَكونوا كَالَّذينَ نَسُوا اللَّهَ فَأَنسىٰهُم أَنفُسَهُم أُولٰئِكَ هُمُ الفٰسِقونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcxlvi{لا يَستَوى أَصحٰبُ النّارِ وَأَصحٰبُ الجَنَّةِ أَصحٰبُ الجَنَّةِ هُمُ الفائِزونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcxlvii{لَو أَنزَلنا هٰذَا القُرءانَ عَلىٰ جَبَلٍ لَرَأَيتَهُ خٰشِعًا مُتَصَدِّعًا مِن خَشيَةِ اللَّهِ وَتِلكَ الأَمثٰلُ نَضرِبُها لِلنّاسِ لَعَلَّهُم يَتَفَكَّرونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcxlviii{هُوَ اللَّهُ الَّذى لا إِلٰهَ إِلّا هُوَ عٰلِمُ الغَيبِ وَالشَّهٰدَةِ هُوَ الرَّحمٰنُ الرَّحيمُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcxlix{هُوَ اللَّهُ الَّذى لا إِلٰهَ إِلّا هُوَ المَلِكُ القُدّوسُ السَّلٰمُ المُؤمِنُ المُهَيمِنُ العَزيزُ الجَبّارُ المُتَكَبِّرُ سُبحٰنَ اللَّهِ عَمّا يُشرِكونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcl{هُوَ اللَّهُ الخٰلِقُ البارِئُ المُصَوِّرُ لَهُ الأَسماءُ الحُسنىٰ يُسَبِّحُ لَهُ ما فِى السَّمٰوٰتِ وَالأَرضِ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcli{\basmalah  يٰأَيُّهَا الَّذينَ ءامَنوا لا تَتَّخِذوا عَدُوّى وَعَدُوَّكُم أَولِياءَ تُلقونَ إِلَيهِم بِالمَوَدَّةِ وَقَد كَفَروا بِما جاءَكُم مِنَ الحَقِّ يُخرِجونَ الرَّسولَ وَإِيّاكُم أَن تُؤمِنوا بِاللَّهِ رَبِّكُم إِن كُنتُم خَرَجتُم جِهٰدًا فى سَبيلى وَابتِغاءَ مَرضاتى تُسِرّونَ إِلَيهِم بِالمَوَدَّةِ وَأَنا۠ أَعلَمُ بِما أَخفَيتُم وَما أَعلَنتُم وَمَن يَفعَلهُ مِنكُم فَقَد ضَلَّ سَواءَ السَّبيلِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclii{إِن يَثقَفوكُم يَكونوا لَكُم أَعداءً وَيَبسُطوا إِلَيكُم أَيدِيَهُم وَأَلسِنَتَهُم بِالسّوءِ وَوَدّوا لَو تَكفُرونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcliii{لَن تَنفَعَكُم أَرحامُكُم وَلا أَولٰدُكُم يَومَ القِيٰمَةِ يَفصِلُ بَينَكُم وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcliv{قَد كانَت لَكُم أُسوَةٌ حَسَنَةٌ فى إِبرٰهيمَ وَالَّذينَ مَعَهُ إِذ قالوا لِقَومِهِم إِنّا بُرَءٰؤُا۟ مِنكُم وَمِمّا تَعبُدونَ مِن دونِ اللَّهِ كَفَرنا بِكُم وَبَدا بَينَنا وَبَينَكُمُ العَدٰوَةُ وَالبَغضاءُ أَبَدًا حَتّىٰ تُؤمِنوا بِاللَّهِ وَحدَهُ إِلّا قَولَ إِبرٰهيمَ لِأَبيهِ لَأَستَغفِرَنَّ لَكَ وَما أَملِكُ لَكَ مِنَ اللَّهِ مِن شَيءٍ رَبَّنا عَلَيكَ تَوَكَّلنا وَإِلَيكَ أَنَبنا وَإِلَيكَ المَصيرُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclv{رَبَّنا لا تَجعَلنا فِتنَةً لِلَّذينَ كَفَروا وَاغفِر لَنا رَبَّنا إِنَّكَ أَنتَ العَزيزُ الحَكيمُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclvi{لَقَد كانَ لَكُم فيهِم أُسوَةٌ حَسَنَةٌ لِمَن كانَ يَرجُوا اللَّهَ وَاليَومَ الءاخِرَ وَمَن يَتَوَلَّ فَإِنَّ اللَّهَ هُوَ الغَنِىُّ الحَميدُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclvii{عَسَى اللَّهُ أَن يَجعَلَ بَينَكُم وَبَينَ الَّذينَ عادَيتُم مِنهُم مَوَدَّةً وَاللَّهُ قَديرٌ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclviii{لا يَنهىٰكُمُ اللَّهُ عَنِ الَّذينَ لَم يُقٰتِلوكُم فِى الدّينِ وَلَم يُخرِجوكُم مِن دِيٰرِكُم أَن تَبَرّوهُم وَتُقسِطوا إِلَيهِم إِنَّ اللَّهَ يُحِبُّ المُقسِطينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclix{إِنَّما يَنهىٰكُمُ اللَّهُ عَنِ الَّذينَ قٰتَلوكُم فِى الدّينِ وَأَخرَجوكُم مِن دِيٰرِكُم وَظٰهَروا عَلىٰ إِخراجِكُم أَن تَوَلَّوهُم وَمَن يَتَوَلَّهُم فَأُولٰئِكَ هُمُ الظّٰلِمونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclx{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا جاءَكُمُ المُؤمِنٰتُ مُهٰجِرٰتٍ فَامتَحِنوهُنَّ اللَّهُ أَعلَمُ بِإيمٰنِهِنَّ فَإِن عَلِمتُموهُنَّ مُؤمِنٰتٍ فَلا تَرجِعوهُنَّ إِلَى الكُفّارِ لا هُنَّ حِلٌّ لَهُم وَلا هُم يَحِلّونَ لَهُنَّ وَءاتوهُم ما أَنفَقوا وَلا جُناحَ عَلَيكُم أَن تَنكِحوهُنَّ إِذا ءاتَيتُموهُنَّ أُجورَهُنَّ وَلا تُمسِكوا بِعِصَمِ الكَوافِرِ وَسـَٔلوا ما أَنفَقتُم وَليَسـَٔلوا ما أَنفَقوا ذٰلِكُم حُكمُ اللَّهِ يَحكُمُ بَينَكُم وَاللَّهُ عَليمٌ حَكيمٌ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxi{وَإِن فاتَكُم شَيءٌ مِن أَزوٰجِكُم إِلَى الكُفّارِ فَعاقَبتُم فَـٔاتُوا الَّذينَ ذَهَبَت أَزوٰجُهُم مِثلَ ما أَنفَقوا وَاتَّقُوا اللَّهَ الَّذى أَنتُم بِهِ مُؤمِنونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxii{يٰأَيُّهَا النَّبِىُّ إِذا جاءَكَ المُؤمِنٰتُ يُبايِعنَكَ عَلىٰ أَن لا يُشرِكنَ بِاللَّهِ شَيـًٔا وَلا يَسرِقنَ وَلا يَزنينَ وَلا يَقتُلنَ أَولٰدَهُنَّ وَلا يَأتينَ بِبُهتٰنٍ يَفتَرينَهُ بَينَ أَيديهِنَّ وَأَرجُلِهِنَّ وَلا يَعصينَكَ فى مَعروفٍ فَبايِعهُنَّ وَاستَغفِر لَهُنَّ اللَّهَ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmclxiii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تَتَوَلَّوا قَومًا غَضِبَ اللَّهُ عَلَيهِم قَد يَئِسوا مِنَ الءاخِرَةِ كَما يَئِسَ الكُفّارُ مِن أَصحٰبِ القُبورِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmclxiv{\basmalah  سَبَّحَ لِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclxv{يٰأَيُّهَا الَّذينَ ءامَنوا لِمَ تَقولونَ ما لا تَفعَلونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmclxvi{كَبُرَ مَقتًا عِندَ اللَّهِ أَن تَقولوا ما لا تَفعَلونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmclxvii{إِنَّ اللَّهَ يُحِبُّ الَّذينَ يُقٰتِلونَ فى سَبيلِهِ صَفًّا كَأَنَّهُم بُنيٰنٌ مَرصوصٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclxviii{وَإِذ قالَ موسىٰ لِقَومِهِ يٰقَومِ لِمَ تُؤذونَنى وَقَد تَعلَمونَ أَنّى رَسولُ اللَّهِ إِلَيكُم فَلَمّا زاغوا أَزاغَ اللَّهُ قُلوبَهُم وَاللَّهُ لا يَهدِى القَومَ الفٰسِقينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclxix{وَإِذ قالَ عيسَى ابنُ مَريَمَ يٰبَنى إِسرٰءيلَ إِنّى رَسولُ اللَّهِ إِلَيكُم مُصَدِّقًا لِما بَينَ يَدَىَّ مِنَ التَّورىٰةِ وَمُبَشِّرًا بِرَسولٍ يَأتى مِن بَعدِى اسمُهُ أَحمَدُ فَلَمّا جاءَهُم بِالبَيِّنٰتِ قالوا هٰذا سِحرٌ مُبينٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclxx{وَمَن أَظلَمُ مِمَّنِ افتَرىٰ عَلَى اللَّهِ الكَذِبَ وَهُوَ يُدعىٰ إِلَى الإِسلٰمِ وَاللَّهُ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclxxi{يُريدونَ لِيُطفِـٔوا نورَ اللَّهِ بِأَفوٰهِهِم وَاللَّهُ مُتِمُّ نورِهِ وَلَو كَرِهَ الكٰفِرونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclxxii{هُوَ الَّذى أَرسَلَ رَسولَهُ بِالهُدىٰ وَدينِ الحَقِّ لِيُظهِرَهُ عَلَى الدّينِ كُلِّهِ وَلَو كَرِهَ المُشرِكونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclxxiii{يٰأَيُّهَا الَّذينَ ءامَنوا هَل أَدُلُّكُم عَلىٰ تِجٰرَةٍ تُنجيكُم مِن عَذابٍ أَليمٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxxiv{تُؤمِنونَ بِاللَّهِ وَرَسولِهِ وَتُجٰهِدونَ فى سَبيلِ اللَّهِ بِأَموٰلِكُم وَأَنفُسِكُم ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxxv{يَغفِر لَكُم ذُنوبَكُم وَيُدخِلكُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ وَمَسٰكِنَ طَيِّبَةً فى جَنّٰتِ عَدنٍ ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmclxxvi{وَأُخرىٰ تُحِبّونَها نَصرٌ مِنَ اللَّهِ وَفَتحٌ قَريبٌ وَبَشِّرِ المُؤمِنينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmclxxvii{يٰأَيُّهَا الَّذينَ ءامَنوا كونوا أَنصارَ اللَّهِ كَما قالَ عيسَى ابنُ مَريَمَ لِلحَوارِيّۦنَ مَن أَنصارى إِلَى اللَّهِ قالَ الحَوارِيّونَ نَحنُ أَنصارُ اللَّهِ فَـٔامَنَت طائِفَةٌ مِن بَنى إِسرٰءيلَ وَكَفَرَت طائِفَةٌ فَأَيَّدنَا الَّذينَ ءامَنوا عَلىٰ عَدُوِّهِم فَأَصبَحوا ظٰهِرينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmclxxviii{\basmalah  يُسَبِّحُ لِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ المَلِكِ القُدّوسِ العَزيزِ الحَكيمِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmclxxix{هُوَ الَّذى بَعَثَ فِى الأُمِّيّۦنَ رَسولًا مِنهُم يَتلوا عَلَيهِم ءايٰتِهِ وَيُزَكّيهِم وَيُعَلِّمُهُمُ الكِتٰبَ وَالحِكمَةَ وَإِن كانوا مِن قَبلُ لَفى ضَلٰلٍ مُبينٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmclxxx{وَءاخَرينَ مِنهُم لَمّا يَلحَقوا بِهِم وَهُوَ العَزيزُ الحَكيمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmclxxxi{ذٰلِكَ فَضلُ اللَّهِ يُؤتيهِ مَن يَشاءُ وَاللَّهُ ذُو الفَضلِ العَظيمِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmclxxxii{مَثَلُ الَّذينَ حُمِّلُوا التَّورىٰةَ ثُمَّ لَم يَحمِلوها كَمَثَلِ الحِمارِ يَحمِلُ أَسفارًا بِئسَ مَثَلُ القَومِ الَّذينَ كَذَّبوا بِـٔايٰتِ اللَّهِ وَاللَّهُ لا يَهدِى القَومَ الظّٰلِمينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmclxxxiii{قُل يٰأَيُّهَا الَّذينَ هادوا إِن زَعَمتُم أَنَّكُم أَولِياءُ لِلَّهِ مِن دونِ النّاسِ فَتَمَنَّوُا المَوتَ إِن كُنتُم صٰدِقينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmclxxxiv{وَلا يَتَمَنَّونَهُ أَبَدًا بِما قَدَّمَت أَيديهِم وَاللَّهُ عَليمٌ بِالظّٰلِمينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmclxxxv{قُل إِنَّ المَوتَ الَّذى تَفِرّونَ مِنهُ فَإِنَّهُ مُلٰقيكُم ثُمَّ تُرَدّونَ إِلىٰ عٰلِمِ الغَيبِ وَالشَّهٰدَةِ فَيُنَبِّئُكُم بِما كُنتُم تَعمَلونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmclxxxvi{يٰأَيُّهَا الَّذينَ ءامَنوا إِذا نودِىَ لِلصَّلوٰةِ مِن يَومِ الجُمُعَةِ فَاسعَوا إِلىٰ ذِكرِ اللَّهِ وَذَرُوا البَيعَ ذٰلِكُم خَيرٌ لَكُم إِن كُنتُم تَعلَمونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmclxxxvii{فَإِذا قُضِيَتِ الصَّلوٰةُ فَانتَشِروا فِى الأَرضِ وَابتَغوا مِن فَضلِ اللَّهِ وَاذكُرُوا اللَّهَ كَثيرًا لَعَلَّكُم تُفلِحونَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmclxxxviii{وَإِذا رَأَوا تِجٰرَةً أَو لَهوًا انفَضّوا إِلَيها وَتَرَكوكَ قائِمًا قُل ما عِندَ اللَّهِ خَيرٌ مِنَ اللَّهوِ وَمِنَ التِّجٰرَةِ وَاللَّهُ خَيرُ الرّٰزِقينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmclxxxix{\basmalah  إِذا جاءَكَ المُنٰفِقونَ قالوا نَشهَدُ إِنَّكَ لَرَسولُ اللَّهِ وَاللَّهُ يَعلَمُ إِنَّكَ لَرَسولُهُ وَاللَّهُ يَشهَدُ إِنَّ المُنٰفِقينَ لَكٰذِبونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcxc{اتَّخَذوا أَيمٰنَهُم جُنَّةً فَصَدّوا عَن سَبيلِ اللَّهِ إِنَّهُم ساءَ ما كانوا يَعمَلونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcxci{ذٰلِكَ بِأَنَّهُم ءامَنوا ثُمَّ كَفَروا فَطُبِعَ عَلىٰ قُلوبِهِم فَهُم لا يَفقَهونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcxcii{وَإِذا رَأَيتَهُم تُعجِبُكَ أَجسامُهُم وَإِن يَقولوا تَسمَع لِقَولِهِم كَأَنَّهُم خُشُبٌ مُسَنَّدَةٌ يَحسَبونَ كُلَّ صَيحَةٍ عَلَيهِم هُمُ العَدُوُّ فَاحذَرهُم قٰتَلَهُمُ اللَّهُ أَنّىٰ يُؤفَكونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcxciii{وَإِذا قيلَ لَهُم تَعالَوا يَستَغفِر لَكُم رَسولُ اللَّهِ لَوَّوا رُءوسَهُم وَرَأَيتَهُم يَصُدّونَ وَهُم مُستَكبِرونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcxciv{سَواءٌ عَلَيهِم أَستَغفَرتَ لَهُم أَم لَم تَستَغفِر لَهُم لَن يَغفِرَ اللَّهُ لَهُم إِنَّ اللَّهَ لا يَهدِى القَومَ الفٰسِقينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcxcv{هُمُ الَّذينَ يَقولونَ لا تُنفِقوا عَلىٰ مَن عِندَ رَسولِ اللَّهِ حَتّىٰ يَنفَضّوا وَلِلَّهِ خَزائِنُ السَّمٰوٰتِ وَالأَرضِ وَلٰكِنَّ المُنٰفِقينَ لا يَفقَهونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcxcvi{يَقولونَ لَئِن رَجَعنا إِلَى المَدينَةِ لَيُخرِجَنَّ الأَعَزُّ مِنهَا الأَذَلَّ وَلِلَّهِ العِزَّةُ وَلِرَسولِهِ وَلِلمُؤمِنينَ وَلٰكِنَّ المُنٰفِقينَ لا يَعلَمونَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcxcvii{يٰأَيُّهَا الَّذينَ ءامَنوا لا تُلهِكُم أَموٰلُكُم وَلا أَولٰدُكُم عَن ذِكرِ اللَّهِ وَمَن يَفعَل ذٰلِكَ فَأُولٰئِكَ هُمُ الخٰسِرونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcxcviii{وَأَنفِقوا مِن ما رَزَقنٰكُم مِن قَبلِ أَن يَأتِىَ أَحَدَكُمُ المَوتُ فَيَقولَ رَبِّ لَولا أَخَّرتَنى إِلىٰ أَجَلٍ قَريبٍ فَأَصَّدَّقَ وَأَكُن مِنَ الصّٰلِحينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcxcix{وَلَن يُؤَخِّرَ اللَّهُ نَفسًا إِذا جاءَ أَجَلُها وَاللَّهُ خَبيرٌ بِما تَعمَلونَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcc{\basmalah  يُسَبِّحُ لِلَّهِ ما فِى السَّمٰوٰتِ وَما فِى الأَرضِ لَهُ المُلكُ وَلَهُ الحَمدُ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcci{هُوَ الَّذى خَلَقَكُم فَمِنكُم كافِرٌ وَمِنكُم مُؤمِنٌ وَاللَّهُ بِما تَعمَلونَ بَصيرٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccii{خَلَقَ السَّمٰوٰتِ وَالأَرضَ بِالحَقِّ وَصَوَّرَكُم فَأَحسَنَ صُوَرَكُم وَإِلَيهِ المَصيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcciii{يَعلَمُ ما فِى السَّمٰوٰتِ وَالأَرضِ وَيَعلَمُ ما تُسِرّونَ وَما تُعلِنونَ وَاللَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcciv{أَلَم يَأتِكُم نَبَؤُا۟ الَّذينَ كَفَروا مِن قَبلُ فَذاقوا وَبالَ أَمرِهِم وَلَهُم عَذابٌ أَليمٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccv{ذٰلِكَ بِأَنَّهُ كانَت تَأتيهِم رُسُلُهُم بِالبَيِّنٰتِ فَقالوا أَبَشَرٌ يَهدونَنا فَكَفَروا وَتَوَلَّوا وَاستَغنَى اللَّهُ وَاللَّهُ غَنِىٌّ حَميدٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccvi{زَعَمَ الَّذينَ كَفَروا أَن لَن يُبعَثوا قُل بَلىٰ وَرَبّى لَتُبعَثُنَّ ثُمَّ لَتُنَبَّؤُنَّ بِما عَمِلتُم وَذٰلِكَ عَلَى اللَّهِ يَسيرٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccvii{فَـٔامِنوا بِاللَّهِ وَرَسولِهِ وَالنّورِ الَّذى أَنزَلنا وَاللَّهُ بِما تَعمَلونَ خَبيرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccviii{يَومَ يَجمَعُكُم لِيَومِ الجَمعِ ذٰلِكَ يَومُ التَّغابُنِ وَمَن يُؤمِن بِاللَّهِ وَيَعمَل صٰلِحًا يُكَفِّر عَنهُ سَيِّـٔاتِهِ وَيُدخِلهُ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها أَبَدًا ذٰلِكَ الفَوزُ العَظيمُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccix{وَالَّذينَ كَفَروا وَكَذَّبوا بِـٔايٰتِنا أُولٰئِكَ أَصحٰبُ النّارِ خٰلِدينَ فيها وَبِئسَ المَصيرُ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccx{ما أَصابَ مِن مُصيبَةٍ إِلّا بِإِذنِ اللَّهِ وَمَن يُؤمِن بِاللَّهِ يَهدِ قَلبَهُ وَاللَّهُ بِكُلِّ شَيءٍ عَليمٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxi{وَأَطيعُوا اللَّهَ وَأَطيعُوا الرَّسولَ فَإِن تَوَلَّيتُم فَإِنَّما عَلىٰ رَسولِنَا البَلٰغُ المُبينُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxii{اللَّهُ لا إِلٰهَ إِلّا هُوَ وَعَلَى اللَّهِ فَليَتَوَكَّلِ المُؤمِنونَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmccxiii{يٰأَيُّهَا الَّذينَ ءامَنوا إِنَّ مِن أَزوٰجِكُم وَأَولٰدِكُم عَدُوًّا لَكُم فَاحذَروهُم وَإِن تَعفوا وَتَصفَحوا وَتَغفِروا فَإِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmccxiv{إِنَّما أَموٰلُكُم وَأَولٰدُكُم فِتنَةٌ وَاللَّهُ عِندَهُ أَجرٌ عَظيمٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmccxv{فَاتَّقُوا اللَّهَ مَا استَطَعتُم وَاسمَعوا وَأَطيعوا وَأَنفِقوا خَيرًا لِأَنفُسِكُم وَمَن يوقَ شُحَّ نَفسِهِ فَأُولٰئِكَ هُمُ المُفلِحونَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmccxvi{إِن تُقرِضُوا اللَّهَ قَرضًا حَسَنًا يُضٰعِفهُ لَكُم وَيَغفِر لَكُم وَاللَّهُ شَكورٌ حَليمٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmccxvii{عٰلِمُ الغَيبِ وَالشَّهٰدَةِ العَزيزُ الحَكيمُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmccxviii{\basmalah  يٰأَيُّهَا النَّبِىُّ إِذا طَلَّقتُمُ النِّساءَ فَطَلِّقوهُنَّ لِعِدَّتِهِنَّ وَأَحصُوا العِدَّةَ وَاتَّقُوا اللَّهَ رَبَّكُم لا تُخرِجوهُنَّ مِن بُيوتِهِنَّ وَلا يَخرُجنَ إِلّا أَن يَأتينَ بِفٰحِشَةٍ مُبَيِّنَةٍ وَتِلكَ حُدودُ اللَّهِ وَمَن يَتَعَدَّ حُدودَ اللَّهِ فَقَد ظَلَمَ نَفسَهُ لا تَدرى لَعَلَّ اللَّهَ يُحدِثُ بَعدَ ذٰلِكَ أَمرًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxix{فَإِذا بَلَغنَ أَجَلَهُنَّ فَأَمسِكوهُنَّ بِمَعروفٍ أَو فارِقوهُنَّ بِمَعروفٍ وَأَشهِدوا ذَوَى عَدلٍ مِنكُم وَأَقيمُوا الشَّهٰدَةَ لِلَّهِ ذٰلِكُم يوعَظُ بِهِ مَن كانَ يُؤمِنُ بِاللَّهِ وَاليَومِ الءاخِرِ وَمَن يَتَّقِ اللَّهَ يَجعَل لَهُ مَخرَجًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxx{وَيَرزُقهُ مِن حَيثُ لا يَحتَسِبُ وَمَن يَتَوَكَّل عَلَى اللَّهِ فَهُوَ حَسبُهُ إِنَّ اللَّهَ بٰلِغُ أَمرِهِ قَد جَعَلَ اللَّهُ لِكُلِّ شَيءٍ قَدرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxxi{وَالّٰـٔى يَئِسنَ مِنَ المَحيضِ مِن نِسائِكُم إِنِ ارتَبتُم فَعِدَّتُهُنَّ ثَلٰثَةُ أَشهُرٍ وَالّٰـٔى لَم يَحِضنَ وَأُولٰتُ الأَحمالِ أَجَلُهُنَّ أَن يَضَعنَ حَملَهُنَّ وَمَن يَتَّقِ اللَّهَ يَجعَل لَهُ مِن أَمرِهِ يُسرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxxii{ذٰلِكَ أَمرُ اللَّهِ أَنزَلَهُ إِلَيكُم وَمَن يَتَّقِ اللَّهَ يُكَفِّر عَنهُ سَيِّـٔاتِهِ وَيُعظِم لَهُ أَجرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxxiii{أَسكِنوهُنَّ مِن حَيثُ سَكَنتُم مِن وُجدِكُم وَلا تُضارّوهُنَّ لِتُضَيِّقوا عَلَيهِنَّ وَإِن كُنَّ أُولٰتِ حَملٍ فَأَنفِقوا عَلَيهِنَّ حَتّىٰ يَضَعنَ حَملَهُنَّ فَإِن أَرضَعنَ لَكُم فَـٔاتوهُنَّ أُجورَهُنَّ وَأتَمِروا بَينَكُم بِمَعروفٍ وَإِن تَعاسَرتُم فَسَتُرضِعُ لَهُ أُخرىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxxiv{لِيُنفِق ذو سَعَةٍ مِن سَعَتِهِ وَمَن قُدِرَ عَلَيهِ رِزقُهُ فَليُنفِق مِمّا ءاتىٰهُ اللَّهُ لا يُكَلِّفُ اللَّهُ نَفسًا إِلّا ما ءاتىٰها سَيَجعَلُ اللَّهُ بَعدَ عُسرٍ يُسرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxxv{وَكَأَيِّن مِن قَريَةٍ عَتَت عَن أَمرِ رَبِّها وَرُسُلِهِ فَحاسَبنٰها حِسابًا شَديدًا وَعَذَّبنٰها عَذابًا نُكرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccxxvi{فَذاقَت وَبالَ أَمرِها وَكانَ عٰقِبَةُ أَمرِها خُسرًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccxxvii{أَعَدَّ اللَّهُ لَهُم عَذابًا شَديدًا فَاتَّقُوا اللَّهَ يٰأُولِى الأَلبٰبِ الَّذينَ ءامَنوا قَد أَنزَلَ اللَّهُ إِلَيكُم ذِكرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccxxviii{رَسولًا يَتلوا عَلَيكُم ءايٰتِ اللَّهِ مُبَيِّنٰتٍ لِيُخرِجَ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ مِنَ الظُّلُمٰتِ إِلَى النّورِ وَمَن يُؤمِن بِاللَّهِ وَيَعمَل صٰلِحًا يُدخِلهُ جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها أَبَدًا قَد أَحسَنَ اللَّهُ لَهُ رِزقًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxxix{اللَّهُ الَّذى خَلَقَ سَبعَ سَمٰوٰتٍ وَمِنَ الأَرضِ مِثلَهُنَّ يَتَنَزَّلُ الأَمرُ بَينَهُنَّ لِتَعلَموا أَنَّ اللَّهَ عَلىٰ كُلِّ شَيءٍ قَديرٌ وَأَنَّ اللَّهَ قَد أَحاطَ بِكُلِّ شَيءٍ عِلمًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxxx{\basmalah  يٰأَيُّهَا النَّبِىُّ لِمَ تُحَرِّمُ ما أَحَلَّ اللَّهُ لَكَ تَبتَغى مَرضاتَ أَزوٰجِكَ وَاللَّهُ غَفورٌ رَحيمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxxxi{قَد فَرَضَ اللَّهُ لَكُم تَحِلَّةَ أَيمٰنِكُم وَاللَّهُ مَولىٰكُم وَهُوَ العَليمُ الحَكيمُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxxxii{وَإِذ أَسَرَّ النَّبِىُّ إِلىٰ بَعضِ أَزوٰجِهِ حَديثًا فَلَمّا نَبَّأَت بِهِ وَأَظهَرَهُ اللَّهُ عَلَيهِ عَرَّفَ بَعضَهُ وَأَعرَضَ عَن بَعضٍ فَلَمّا نَبَّأَها بِهِ قالَت مَن أَنبَأَكَ هٰذا قالَ نَبَّأَنِىَ العَليمُ الخَبيرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxxxiii{إِن تَتوبا إِلَى اللَّهِ فَقَد صَغَت قُلوبُكُما وَإِن تَظٰهَرا عَلَيهِ فَإِنَّ اللَّهَ هُوَ مَولىٰهُ وَجِبريلُ وَصٰلِحُ المُؤمِنينَ وَالمَلٰئِكَةُ بَعدَ ذٰلِكَ ظَهيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxxxiv{عَسىٰ رَبُّهُ إِن طَلَّقَكُنَّ أَن يُبدِلَهُ أَزوٰجًا خَيرًا مِنكُنَّ مُسلِمٰتٍ مُؤمِنٰتٍ قٰنِتٰتٍ تٰئِبٰتٍ عٰبِدٰتٍ سٰئِحٰتٍ ثَيِّبٰتٍ وَأَبكارًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxxxv{يٰأَيُّهَا الَّذينَ ءامَنوا قوا أَنفُسَكُم وَأَهليكُم نارًا وَقودُهَا النّاسُ وَالحِجارَةُ عَلَيها مَلٰئِكَةٌ غِلاظٌ شِدادٌ لا يَعصونَ اللَّهَ ما أَمَرَهُم وَيَفعَلونَ ما يُؤمَرونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxxxvi{يٰأَيُّهَا الَّذينَ كَفَروا لا تَعتَذِرُوا اليَومَ إِنَّما تُجزَونَ ما كُنتُم تَعمَلونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxxxvii{يٰأَيُّهَا الَّذينَ ءامَنوا توبوا إِلَى اللَّهِ تَوبَةً نَصوحًا عَسىٰ رَبُّكُم أَن يُكَفِّرَ عَنكُم سَيِّـٔاتِكُم وَيُدخِلَكُم جَنّٰتٍ تَجرى مِن تَحتِهَا الأَنهٰرُ يَومَ لا يُخزِى اللَّهُ النَّبِىَّ وَالَّذينَ ءامَنوا مَعَهُ نورُهُم يَسعىٰ بَينَ أَيديهِم وَبِأَيمٰنِهِم يَقولونَ رَبَّنا أَتمِم لَنا نورَنا وَاغفِر لَنا إِنَّكَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccxxxviii{يٰأَيُّهَا النَّبِىُّ جٰهِدِ الكُفّارَ وَالمُنٰفِقينَ وَاغلُظ عَلَيهِم وَمَأوىٰهُم جَهَنَّمُ وَبِئسَ المَصيرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccxxxix{ضَرَبَ اللَّهُ مَثَلًا لِلَّذينَ كَفَرُوا امرَأَتَ نوحٍ وَامرَأَتَ لوطٍ كانَتا تَحتَ عَبدَينِ مِن عِبادِنا صٰلِحَينِ فَخانَتاهُما فَلَم يُغنِيا عَنهُما مِنَ اللَّهِ شَيـًٔا وَقيلَ ادخُلَا النّارَ مَعَ الدّٰخِلينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccxl{وَضَرَبَ اللَّهُ مَثَلًا لِلَّذينَ ءامَنُوا امرَأَتَ فِرعَونَ إِذ قالَت رَبِّ ابنِ لى عِندَكَ بَيتًا فِى الجَنَّةِ وَنَجِّنى مِن فِرعَونَ وَعَمَلِهِ وَنَجِّنى مِنَ القَومِ الظّٰلِمينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccxli{وَمَريَمَ ابنَتَ عِمرٰنَ الَّتى أَحصَنَت فَرجَها فَنَفَخنا فيهِ مِن روحِنا وَصَدَّقَت بِكَلِمٰتِ رَبِّها وَكُتُبِهِ وَكانَت مِنَ القٰنِتينَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccxlii{\basmalah  تَبٰرَكَ الَّذى بِيَدِهِ المُلكُ وَهُوَ عَلىٰ كُلِّ شَيءٍ قَديرٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccxliii{الَّذى خَلَقَ المَوتَ وَالحَيوٰةَ لِيَبلُوَكُم أَيُّكُم أَحسَنُ عَمَلًا وَهُوَ العَزيزُ الغَفورُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccxliv{الَّذى خَلَقَ سَبعَ سَمٰوٰتٍ طِباقًا ما تَرىٰ فى خَلقِ الرَّحمٰنِ مِن تَفٰوُتٍ فَارجِعِ البَصَرَ هَل تَرىٰ مِن فُطورٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccxlv{ثُمَّ ارجِعِ البَصَرَ كَرَّتَينِ يَنقَلِب إِلَيكَ البَصَرُ خاسِئًا وَهُوَ حَسيرٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccxlvi{وَلَقَد زَيَّنَّا السَّماءَ الدُّنيا بِمَصٰبيحَ وَجَعَلنٰها رُجومًا لِلشَّيٰطينِ وَأَعتَدنا لَهُم عَذابَ السَّعيرِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccxlvii{وَلِلَّذينَ كَفَروا بِرَبِّهِم عَذابُ جَهَنَّمَ وَبِئسَ المَصيرُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccxlviii{إِذا أُلقوا فيها سَمِعوا لَها شَهيقًا وَهِىَ تَفورُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccxlix{تَكادُ تَمَيَّزُ مِنَ الغَيظِ كُلَّما أُلقِىَ فيها فَوجٌ سَأَلَهُم خَزَنَتُها أَلَم يَأتِكُم نَذيرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccl{قالوا بَلىٰ قَد جاءَنا نَذيرٌ فَكَذَّبنا وَقُلنا ما نَزَّلَ اللَّهُ مِن شَيءٍ إِن أَنتُم إِلّا فى ضَلٰلٍ كَبيرٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccli{وَقالوا لَو كُنّا نَسمَعُ أَو نَعقِلُ ما كُنّا فى أَصحٰبِ السَّعيرِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcclii{فَاعتَرَفوا بِذَنبِهِم فَسُحقًا لِأَصحٰبِ السَّعيرِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccliii{إِنَّ الَّذينَ يَخشَونَ رَبَّهُم بِالغَيبِ لَهُم مَغفِرَةٌ وَأَجرٌ كَبيرٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccliv{وَأَسِرّوا قَولَكُم أَوِ اجهَروا بِهِ إِنَّهُ عَليمٌ بِذاتِ الصُّدورِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcclv{أَلا يَعلَمُ مَن خَلَقَ وَهُوَ اللَّطيفُ الخَبيرُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcclvi{هُوَ الَّذى جَعَلَ لَكُمُ الأَرضَ ذَلولًا فَامشوا فى مَناكِبِها وَكُلوا مِن رِزقِهِ وَإِلَيهِ النُّشورُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcclvii{ءَأَمِنتُم مَن فِى السَّماءِ أَن يَخسِفَ بِكُمُ الأَرضَ فَإِذا هِىَ تَمورُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcclviii{أَم أَمِنتُم مَن فِى السَّماءِ أَن يُرسِلَ عَلَيكُم حاصِبًا فَسَتَعلَمونَ كَيفَ نَذيرِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcclix{وَلَقَد كَذَّبَ الَّذينَ مِن قَبلِهِم فَكَيفَ كانَ نَكيرِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcclx{أَوَلَم يَرَوا إِلَى الطَّيرِ فَوقَهُم صٰفّٰتٍ وَيَقبِضنَ ما يُمسِكُهُنَّ إِلَّا الرَّحمٰنُ إِنَّهُ بِكُلِّ شَيءٍ بَصيرٌ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxi{أَمَّن هٰذَا الَّذى هُوَ جُندٌ لَكُم يَنصُرُكُم مِن دونِ الرَّحمٰنِ إِنِ الكٰفِرونَ إِلّا فى غُرورٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxii{أَمَّن هٰذَا الَّذى يَرزُقُكُم إِن أَمسَكَ رِزقَهُ بَل لَجّوا فى عُتُوٍّ وَنُفورٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcclxiii{أَفَمَن يَمشى مُكِبًّا عَلىٰ وَجهِهِ أَهدىٰ أَمَّن يَمشى سَوِيًّا عَلىٰ صِرٰطٍ مُستَقيمٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxiv{قُل هُوَ الَّذى أَنشَأَكُم وَجَعَلَ لَكُمُ السَّمعَ وَالأَبصٰرَ وَالأَفـِٔدَةَ قَليلًا ما تَشكُرونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxv{قُل هُوَ الَّذى ذَرَأَكُم فِى الأَرضِ وَإِلَيهِ تُحشَرونَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxvi{وَيَقولونَ مَتىٰ هٰذَا الوَعدُ إِن كُنتُم صٰدِقينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxvii{قُل إِنَّمَا العِلمُ عِندَ اللَّهِ وَإِنَّما أَنا۠ نَذيرٌ مُبينٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxviii{فَلَمّا رَأَوهُ زُلفَةً سيـَٔت وُجوهُ الَّذينَ كَفَروا وَقيلَ هٰذَا الَّذى كُنتُم بِهِ تَدَّعونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxix{قُل أَرَءَيتُم إِن أَهلَكَنِىَ اللَّهُ وَمَن مَعِىَ أَو رَحِمَنا فَمَن يُجيرُ الكٰفِرينَ مِن عَذابٍ أَليمٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcclxx{قُل هُوَ الرَّحمٰنُ ءامَنّا بِهِ وَعَلَيهِ تَوَكَّلنا فَسَتَعلَمونَ مَن هُوَ فى ضَلٰلٍ مُبينٍ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxxi{قُل أَرَءَيتُم إِن أَصبَحَ ماؤُكُم غَورًا فَمَن يَأتيكُم بِماءٍ مَعينٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxxii{\basmalah  ن وَالقَلَمِ وَما يَسطُرونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcclxxiii{ما أَنتَ بِنِعمَةِ رَبِّكَ بِمَجنونٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxxiv{وَإِنَّ لَكَ لَأَجرًا غَيرَ مَمنونٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxxv{وَإِنَّكَ لَعَلىٰ خُلُقٍ عَظيمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxxvi{فَسَتُبصِرُ وَيُبصِرونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxxvii{بِأَييِكُمُ المَفتونُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxxviii{إِنَّ رَبَّكَ هُوَ أَعلَمُ بِمَن ضَلَّ عَن سَبيلِهِ وَهُوَ أَعلَمُ بِالمُهتَدينَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxxix{فَلا تُطِعِ المُكَذِّبينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcclxxx{وَدّوا لَو تُدهِنُ فَيُدهِنونَ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxi{وَلا تُطِع كُلَّ حَلّافٍ مَهينٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxii{هَمّازٍ مَشّاءٍ بِنَميمٍ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxiii{مَنّاعٍ لِلخَيرِ مُعتَدٍ أَثيمٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxiv{عُتُلٍّ بَعدَ ذٰلِكَ زَنيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxv{أَن كانَ ذا مالٍ وَبَنينَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxvi{إِذا تُتلىٰ عَلَيهِ ءايٰتُنا قالَ أَسٰطيرُ الأَوَّلينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxvii{سَنَسِمُهُ عَلَى الخُرطومِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxviii{إِنّا بَلَونٰهُم كَما بَلَونا أَصحٰبَ الجَنَّةِ إِذ أَقسَموا لَيَصرِمُنَّها مُصبِحينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcclxxxix{وَلا يَستَثنونَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmccxc{فَطافَ عَلَيها طائِفٌ مِن رَبِّكَ وَهُم نائِمونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmccxci{فَأَصبَحَت كَالصَّريمِ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmccxcii{فَتَنادَوا مُصبِحينَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmccxciii{أَنِ اغدوا عَلىٰ حَرثِكُم إِن كُنتُم صٰرِمينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmccxciv{فَانطَلَقوا وَهُم يَتَخٰفَتونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmccxcv{أَن لا يَدخُلَنَّهَا اليَومَ عَلَيكُم مِسكينٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmccxcvi{وَغَدَوا عَلىٰ حَردٍ قٰدِرينَ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmccxcvii{فَلَمّا رَأَوها قالوا إِنّا لَضالّونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmccxcviii{بَل نَحنُ مَحرومونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmccxcix{قالَ أَوسَطُهُم أَلَم أَقُل لَكُم لَولا تُسَبِّحونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmccc{قالوا سُبحٰنَ رَبِّنا إِنّا كُنّا ظٰلِمينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmccci{فَأَقبَلَ بَعضُهُم عَلىٰ بَعضٍ يَتَلٰوَمونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcccii{قالوا يٰوَيلَنا إِنّا كُنّا طٰغينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmccciii{عَسىٰ رَبُّنا أَن يُبدِلَنا خَيرًا مِنها إِنّا إِلىٰ رَبِّنا رٰغِبونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmccciv{كَذٰلِكَ العَذابُ وَلَعَذابُ الءاخِرَةِ أَكبَرُ لَو كانوا يَعلَمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmcccv{إِنَّ لِلمُتَّقينَ عِندَ رَبِّهِم جَنّٰتِ النَّعيمِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmcccvi{أَفَنَجعَلُ المُسلِمينَ كَالمُجرِمينَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmcccvii{ما لَكُم كَيفَ تَحكُمونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmcccviii{أَم لَكُم كِتٰبٌ فيهِ تَدرُسونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmcccix{إِنَّ لَكُم فيهِ لَما تَخَيَّرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmcccx{أَم لَكُم أَيمٰنٌ عَلَينا بٰلِغَةٌ إِلىٰ يَومِ القِيٰمَةِ إِنَّ لَكُم لَما تَحكُمونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxi{سَلهُم أَيُّهُم بِذٰلِكَ زَعيمٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxii{أَم لَهُم شُرَكاءُ فَليَأتوا بِشُرَكائِهِم إِن كانوا صٰدِقينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmcccxiii{يَومَ يُكشَفُ عَن ساقٍ وَيُدعَونَ إِلَى السُّجودِ فَلا يَستَطيعونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxiv{خٰشِعَةً أَبصٰرُهُم تَرهَقُهُم ذِلَّةٌ وَقَد كانوا يُدعَونَ إِلَى السُّجودِ وَهُم سٰلِمونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxv{فَذَرنى وَمَن يُكَذِّبُ بِهٰذَا الحَديثِ سَنَستَدرِجُهُم مِن حَيثُ لا يَعلَمونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxvi{وَأُملى لَهُم إِنَّ كَيدى مَتينٌ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxvii{أَم تَسـَٔلُهُم أَجرًا فَهُم مِن مَغرَمٍ مُثقَلونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxviii{أَم عِندَهُمُ الغَيبُ فَهُم يَكتُبونَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxix{فَاصبِر لِحُكمِ رَبِّكَ وَلا تَكُن كَصاحِبِ الحوتِ إِذ نادىٰ وَهُوَ مَكظومٌ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxx{لَولا أَن تَدٰرَكَهُ نِعمَةٌ مِن رَبِّهِ لَنُبِذَ بِالعَراءِ وَهُوَ مَذمومٌ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxxi{فَاجتَبٰهُ رَبُّهُ فَجَعَلَهُ مِنَ الصّٰلِحينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxxii{وَإِن يَكادُ الَّذينَ كَفَروا لَيُزلِقونَكَ بِأَبصٰرِهِم لَمّا سَمِعُوا الذِّكرَ وَيَقولونَ إِنَّهُ لَمَجنونٌ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxiii{وَما هُوَ إِلّا ذِكرٌ لِلعٰلَمينَ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxiv{\basmalah  الحاقَّةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxv{مَا الحاقَّةُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxvi{وَما أَدرىٰكَ مَا الحاقَّةُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxxvii{كَذَّبَت ثَمودُ وَعادٌ بِالقارِعَةِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxxviii{فَأَمّا ثَمودُ فَأُهلِكوا بِالطّاغِيَةِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxxix{وَأَمّا عادٌ فَأُهلِكوا بِريحٍ صَرصَرٍ عاتِيَةٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxxx{سَخَّرَها عَلَيهِم سَبعَ لَيالٍ وَثَمٰنِيَةَ أَيّامٍ حُسومًا فَتَرَى القَومَ فيها صَرعىٰ كَأَنَّهُم أَعجازُ نَخلٍ خاوِيَةٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxi{فَهَل تَرىٰ لَهُم مِن باقِيَةٍ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxii{وَجاءَ فِرعَونُ وَمَن قَبلَهُ وَالمُؤتَفِكٰتُ بِالخاطِئَةِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxiii{فَعَصَوا رَسولَ رَبِّهِم فَأَخَذَهُم أَخذَةً رابِيَةً\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxiv{إِنّا لَمّا طَغَا الماءُ حَمَلنٰكُم فِى الجارِيَةِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxv{لِنَجعَلَها لَكُم تَذكِرَةً وَتَعِيَها أُذُنٌ وٰعِيَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxvi{فَإِذا نُفِخَ فِى الصّورِ نَفخَةٌ وٰحِدَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxvii{وَحُمِلَتِ الأَرضُ وَالجِبالُ فَدُكَّتا دَكَّةً وٰحِدَةً\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxviii{فَيَومَئِذٍ وَقَعَتِ الواقِعَةُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxxxix{وَانشَقَّتِ السَّماءُ فَهِىَ يَومَئِذٍ واهِيَةٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxl{وَالمَلَكُ عَلىٰ أَرجائِها وَيَحمِلُ عَرشَ رَبِّكَ فَوقَهُم يَومَئِذٍ ثَمٰنِيَةٌ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxli{يَومَئِذٍ تُعرَضونَ لا تَخفىٰ مِنكُم خافِيَةٌ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxlii{فَأَمّا مَن أوتِىَ كِتٰبَهُ بِيَمينِهِ فَيَقولُ هاؤُمُ اقرَءوا كِتٰبِيَه\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxliii{إِنّى ظَنَنتُ أَنّى مُلٰقٍ حِسابِيَه\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxliv{فَهُوَ فى عيشَةٍ راضِيَةٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcccxlv{فى جَنَّةٍ عالِيَةٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxlvi{قُطوفُها دانِيَةٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxlvii{كُلوا وَاشرَبوا هَنيـًٔا بِما أَسلَفتُم فِى الأَيّامِ الخالِيَةِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxlviii{وَأَمّا مَن أوتِىَ كِتٰبَهُ بِشِمالِهِ فَيَقولُ يٰلَيتَنى لَم أوتَ كِتٰبِيَه\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxlix{وَلَم أَدرِ ما حِسابِيَه\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcccl{يٰلَيتَها كانَتِ القاضِيَةَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcccli{ما أَغنىٰ عَنّى مالِيَه\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmccclii{هَلَكَ عَنّى سُلطٰنِيَه\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcccliii{خُذوهُ فَغُلّوهُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcccliv{ثُمَّ الجَحيمَ صَلّوهُ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmccclv{ثُمَّ فى سِلسِلَةٍ ذَرعُها سَبعونَ ذِراعًا فَاسلُكوهُ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmccclvi{إِنَّهُ كانَ لا يُؤمِنُ بِاللَّهِ العَظيمِ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmccclvii{وَلا يَحُضُّ عَلىٰ طَعامِ المِسكينِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmccclviii{فَلَيسَ لَهُ اليَومَ هٰهُنا حَميمٌ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmccclix{وَلا طَعامٌ إِلّا مِن غِسلينٍ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmccclx{لا يَأكُلُهُ إِلَّا الخٰطِـٔونَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxi{فَلا أُقسِمُ بِما تُبصِرونَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxii{وَما لا تُبصِرونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxiii{إِنَّهُ لَقَولُ رَسولٍ كَريمٍ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxiv{وَما هُوَ بِقَولِ شاعِرٍ قَليلًا ما تُؤمِنونَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmccclxv{وَلا بِقَولِ كاهِنٍ قَليلًا ما تَذَكَّرونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxvi{تَنزيلٌ مِن رَبِّ العٰلَمينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxvii{وَلَو تَقَوَّلَ عَلَينا بَعضَ الأَقاويلِ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmccclxviii{لَأَخَذنا مِنهُ بِاليَمينِ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmccclxix{ثُمَّ لَقَطَعنا مِنهُ الوَتينَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmccclxx{فَما مِنكُم مِن أَحَدٍ عَنهُ حٰجِزينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxxi{وَإِنَّهُ لَتَذكِرَةٌ لِلمُتَّقينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxxii{وَإِنّا لَنَعلَمُ أَنَّ مِنكُم مُكَذِّبينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxxiii{وَإِنَّهُ لَحَسرَةٌ عَلَى الكٰفِرينَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxxiv{وَإِنَّهُ لَحَقُّ اليَقينِ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxv{فَسَبِّح بِاسمِ رَبِّكَ العَظيمِ\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxvi{\basmalah  سَأَلَ سائِلٌ بِعَذابٍ واقِعٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxvii{لِلكٰفِرينَ لَيسَ لَهُ دافِعٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxviii{مِنَ اللَّهِ ذِى المَعارِجِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxxix{تَعرُجُ المَلٰئِكَةُ وَالرّوحُ إِلَيهِ فى يَومٍ كانَ مِقدارُهُ خَمسينَ أَلفَ سَنَةٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmccclxxx{فَاصبِر صَبرًا جَميلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxi{إِنَّهُم يَرَونَهُ بَعيدًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxii{وَنَرىٰهُ قَريبًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxiii{يَومَ تَكونُ السَّماءُ كَالمُهلِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxiv{وَتَكونُ الجِبالُ كَالعِهنِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxv{وَلا يَسـَٔلُ حَميمٌ حَميمًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxvi{يُبَصَّرونَهُم يَوَدُّ المُجرِمُ لَو يَفتَدى مِن عَذابِ يَومِئِذٍ بِبَنيهِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxvii{وَصٰحِبَتِهِ وَأَخيهِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxviii{وَفَصيلَتِهِ الَّتى تُـٔويهِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmccclxxxix{وَمَن فِى الأَرضِ جَميعًا ثُمَّ يُنجيهِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcccxc{كَلّا إِنَّها لَظىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcccxci{نَزّاعَةً لِلشَّوىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcccxcii{تَدعوا مَن أَدبَرَ وَتَوَلّىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcccxciii{وَجَمَعَ فَأَوعىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcccxciv{إِنَّ الإِنسٰنَ خُلِقَ هَلوعًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcccxcv{إِذا مَسَّهُ الشَّرُّ جَزوعًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcccxcvi{وَإِذا مَسَّهُ الخَيرُ مَنوعًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcccxcvii{إِلَّا المُصَلّينَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcccxcviii{الَّذينَ هُم عَلىٰ صَلاتِهِم دائِمونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcccxcix{وَالَّذينَ فى أَموٰلِهِم حَقٌّ مَعلومٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcd{لِلسّائِلِ وَالمَحرومِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdi{وَالَّذينَ يُصَدِّقونَ بِيَومِ الدّينِ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdii{وَالَّذينَ هُم مِن عَذابِ رَبِّهِم مُشفِقونَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdiii{إِنَّ عَذابَ رَبِّهِم غَيرُ مَأمونٍ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdiv{وَالَّذينَ هُم لِفُروجِهِم حٰفِظونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmcdv{إِلّا عَلىٰ أَزوٰجِهِم أَو ما مَلَكَت أَيمٰنُهُم فَإِنَّهُم غَيرُ مَلومينَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmcdvi{فَمَنِ ابتَغىٰ وَراءَ ذٰلِكَ فَأُولٰئِكَ هُمُ العادونَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmcdvii{وَالَّذينَ هُم لِأَمٰنٰتِهِم وَعَهدِهِم رٰعونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmcdviii{وَالَّذينَ هُم بِشَهٰدٰتِهِم قائِمونَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmcdix{وَالَّذينَ هُم عَلىٰ صَلاتِهِم يُحافِظونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmcdx{أُولٰئِكَ فى جَنّٰتٍ مُكرَمونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxi{فَمالِ الَّذينَ كَفَروا قِبَلَكَ مُهطِعينَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxii{عَنِ اليَمينِ وَعَنِ الشِّمالِ عِزينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxiii{أَيَطمَعُ كُلُّ امرِئٍ مِنهُم أَن يُدخَلَ جَنَّةَ نَعيمٍ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxiv{كَلّا إِنّا خَلَقنٰهُم مِمّا يَعلَمونَ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxv{فَلا أُقسِمُ بِرَبِّ المَشٰرِقِ وَالمَغٰرِبِ إِنّا لَقٰدِرونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxvi{عَلىٰ أَن نُبَدِّلَ خَيرًا مِنهُم وَما نَحنُ بِمَسبوقينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmcdxvii{فَذَرهُم يَخوضوا وَيَلعَبوا حَتّىٰ يُلٰقوا يَومَهُمُ الَّذى يوعَدونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxviii{يَومَ يَخرُجونَ مِنَ الأَجداثِ سِراعًا كَأَنَّهُم إِلىٰ نُصُبٍ يوفِضونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxix{خٰشِعَةً أَبصٰرُهُم تَرهَقُهُم ذِلَّةٌ ذٰلِكَ اليَومُ الَّذى كانوا يوعَدونَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxx{\basmalah  إِنّا أَرسَلنا نوحًا إِلىٰ قَومِهِ أَن أَنذِر قَومَكَ مِن قَبلِ أَن يَأتِيَهُم عَذابٌ أَليمٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxxi{قالَ يٰقَومِ إِنّى لَكُم نَذيرٌ مُبينٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxxii{أَنِ اعبُدُوا اللَّهَ وَاتَّقوهُ وَأَطيعونِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxxiii{يَغفِر لَكُم مِن ذُنوبِكُم وَيُؤَخِّركُم إِلىٰ أَجَلٍ مُسَمًّى إِنَّ أَجَلَ اللَّهِ إِذا جاءَ لا يُؤَخَّرُ لَو كُنتُم تَعلَمونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxxiv{قالَ رَبِّ إِنّى دَعَوتُ قَومى لَيلًا وَنَهارًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxxv{فَلَم يَزِدهُم دُعاءى إِلّا فِرارًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxxvi{وَإِنّى كُلَّما دَعَوتُهُم لِتَغفِرَ لَهُم جَعَلوا أَصٰبِعَهُم فى ءاذانِهِم وَاستَغشَوا ثِيابَهُم وَأَصَرّوا وَاستَكبَرُوا استِكبارًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxxvii{ثُمَّ إِنّى دَعَوتُهُم جِهارًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxxviii{ثُمَّ إِنّى أَعلَنتُ لَهُم وَأَسرَرتُ لَهُم إِسرارًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxxix{فَقُلتُ استَغفِروا رَبَّكُم إِنَّهُ كانَ غَفّارًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxxx{يُرسِلِ السَّماءَ عَلَيكُم مِدرارًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxi{وَيُمدِدكُم بِأَموٰلٍ وَبَنينَ وَيَجعَل لَكُم جَنّٰتٍ وَيَجعَل لَكُم أَنهٰرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxii{ما لَكُم لا تَرجونَ لِلَّهِ وَقارًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxiii{وَقَد خَلَقَكُم أَطوارًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxiv{أَلَم تَرَوا كَيفَ خَلَقَ اللَّهُ سَبعَ سَمٰوٰتٍ طِباقًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxv{وَجَعَلَ القَمَرَ فيهِنَّ نورًا وَجَعَلَ الشَّمسَ سِراجًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxvi{وَاللَّهُ أَنبَتَكُم مِنَ الأَرضِ نَباتًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxvii{ثُمَّ يُعيدُكُم فيها وَيُخرِجُكُم إِخراجًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxviii{وَاللَّهُ جَعَلَ لَكُمُ الأَرضَ بِساطًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxxxix{لِتَسلُكوا مِنها سُبُلًا فِجاجًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxl{قالَ نوحٌ رَبِّ إِنَّهُم عَصَونى وَاتَّبَعوا مَن لَم يَزِدهُ مالُهُ وَوَلَدُهُ إِلّا خَسارًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcdxli{وَمَكَروا مَكرًا كُبّارًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxlii{وَقالوا لا تَذَرُنَّ ءالِهَتَكُم وَلا تَذَرُنَّ وَدًّا وَلا سُواعًا وَلا يَغوثَ وَيَعوقَ وَنَسرًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxliii{وَقَد أَضَلّوا كَثيرًا وَلا تَزِدِ الظّٰلِمينَ إِلّا ضَلٰلًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxliv{مِمّا خَطيـٰٔتِهِم أُغرِقوا فَأُدخِلوا نارًا فَلَم يَجِدوا لَهُم مِن دونِ اللَّهِ أَنصارًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxlv{وَقالَ نوحٌ رَبِّ لا تَذَر عَلَى الأَرضِ مِنَ الكٰفِرينَ دَيّارًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxlvi{إِنَّكَ إِن تَذَرهُم يُضِلّوا عِبادَكَ وَلا يَلِدوا إِلّا فاجِرًا كَفّارًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxlvii{رَبِّ اغفِر لى وَلِوٰلِدَىَّ وَلِمَن دَخَلَ بَيتِىَ مُؤمِنًا وَلِلمُؤمِنينَ وَالمُؤمِنٰتِ وَلا تَزِدِ الظّٰلِمينَ إِلّا تَبارًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxlviii{\basmalah  قُل أوحِىَ إِلَىَّ أَنَّهُ استَمَعَ نَفَرٌ مِنَ الجِنِّ فَقالوا إِنّا سَمِعنا قُرءانًا عَجَبًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxlix{يَهدى إِلَى الرُّشدِ فَـٔامَنّا بِهِ وَلَن نُشرِكَ بِرَبِّنا أَحَدًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdl{وَأَنَّهُ تَعٰلىٰ جَدُّ رَبِّنا مَا اتَّخَذَ صٰحِبَةً وَلا وَلَدًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdli{وَأَنَّهُ كانَ يَقولُ سَفيهُنا عَلَى اللَّهِ شَطَطًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlii{وَأَنّا ظَنَنّا أَن لَن تَقولَ الإِنسُ وَالجِنُّ عَلَى اللَّهِ كَذِبًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdliii{وَأَنَّهُ كانَ رِجالٌ مِنَ الإِنسِ يَعوذونَ بِرِجالٍ مِنَ الجِنِّ فَزادوهُم رَهَقًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdliv{وَأَنَّهُم ظَنّوا كَما ظَنَنتُم أَن لَن يَبعَثَ اللَّهُ أَحَدًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlv{وَأَنّا لَمَسنَا السَّماءَ فَوَجَدنٰها مُلِئَت حَرَسًا شَديدًا وَشُهُبًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlvi{وَأَنّا كُنّا نَقعُدُ مِنها مَقٰعِدَ لِلسَّمعِ فَمَن يَستَمِعِ الءانَ يَجِد لَهُ شِهابًا رَصَدًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlvii{وَأَنّا لا نَدرى أَشَرٌّ أُريدَ بِمَن فِى الأَرضِ أَم أَرادَ بِهِم رَبُّهُم رَشَدًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlviii{وَأَنّا مِنَّا الصّٰلِحونَ وَمِنّا دونَ ذٰلِكَ كُنّا طَرائِقَ قِدَدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdlix{وَأَنّا ظَنَنّا أَن لَن نُعجِزَ اللَّهَ فِى الأَرضِ وَلَن نُعجِزَهُ هَرَبًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlx{وَأَنّا لَمّا سَمِعنَا الهُدىٰ ءامَنّا بِهِ فَمَن يُؤمِن بِرَبِّهِ فَلا يَخافُ بَخسًا وَلا رَهَقًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxi{وَأَنّا مِنَّا المُسلِمونَ وَمِنَّا القٰسِطونَ فَمَن أَسلَمَ فَأُولٰئِكَ تَحَرَّوا رَشَدًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxii{وَأَمَّا القٰسِطونَ فَكانوا لِجَهَنَّمَ حَطَبًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxiii{وَأَلَّوِ استَقٰموا عَلَى الطَّريقَةِ لَأَسقَينٰهُم ماءً غَدَقًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxiv{لِنَفتِنَهُم فيهِ وَمَن يُعرِض عَن ذِكرِ رَبِّهِ يَسلُكهُ عَذابًا صَعَدًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxv{وَأَنَّ المَسٰجِدَ لِلَّهِ فَلا تَدعوا مَعَ اللَّهِ أَحَدًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxvi{وَأَنَّهُ لَمّا قامَ عَبدُ اللَّهِ يَدعوهُ كادوا يَكونونَ عَلَيهِ لِبَدًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlxvii{قُل إِنَّما أَدعوا رَبّى وَلا أُشرِكُ بِهِ أَحَدًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlxviii{قُل إِنّى لا أَملِكُ لَكُم ضَرًّا وَلا رَشَدًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxix{قُل إِنّى لَن يُجيرَنى مِنَ اللَّهِ أَحَدٌ وَلَن أَجِدَ مِن دونِهِ مُلتَحَدًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxx{إِلّا بَلٰغًا مِنَ اللَّهِ وَرِسٰلٰتِهِ وَمَن يَعصِ اللَّهَ وَرَسولَهُ فَإِنَّ لَهُ نارَ جَهَنَّمَ خٰلِدينَ فيها أَبَدًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxi{حَتّىٰ إِذا رَأَوا ما يوعَدونَ فَسَيَعلَمونَ مَن أَضعَفُ ناصِرًا وَأَقَلُّ عَدَدًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxii{قُل إِن أَدرى أَقَريبٌ ما توعَدونَ أَم يَجعَلُ لَهُ رَبّى أَمَدًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxiii{عٰلِمُ الغَيبِ فَلا يُظهِرُ عَلىٰ غَيبِهِ أَحَدًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxiv{إِلّا مَنِ ارتَضىٰ مِن رَسولٍ فَإِنَّهُ يَسلُكُ مِن بَينِ يَدَيهِ وَمِن خَلفِهِ رَصَدًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxv{لِيَعلَمَ أَن قَد أَبلَغوا رِسٰلٰتِ رَبِّهِم وَأَحاطَ بِما لَدَيهِم وَأَحصىٰ كُلَّ شَيءٍ عَدَدًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxvi{\basmalah  يٰأَيُّهَا المُزَّمِّلُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxvii{قُمِ الَّيلَ إِلّا قَليلًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxviii{نِصفَهُ أَوِ انقُص مِنهُ قَليلًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxix{أَو زِد عَلَيهِ وَرَتِّلِ القُرءانَ تَرتيلًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxx{إِنّا سَنُلقى عَلَيكَ قَولًا ثَقيلًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxi{إِنَّ ناشِئَةَ الَّيلِ هِىَ أَشَدُّ وَطـًٔا وَأَقوَمُ قيلًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxii{إِنَّ لَكَ فِى النَّهارِ سَبحًا طَويلًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxiii{وَاذكُرِ اسمَ رَبِّكَ وَتَبَتَّل إِلَيهِ تَبتيلًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxiv{رَبُّ المَشرِقِ وَالمَغرِبِ لا إِلٰهَ إِلّا هُوَ فَاتَّخِذهُ وَكيلًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxv{وَاصبِر عَلىٰ ما يَقولونَ وَاهجُرهُم هَجرًا جَميلًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxvi{وَذَرنى وَالمُكَذِّبينَ أُولِى النَّعمَةِ وَمَهِّلهُم قَليلًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxvii{إِنَّ لَدَينا أَنكالًا وَجَحيمًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxviii{وَطَعامًا ذا غُصَّةٍ وَعَذابًا أَليمًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcdlxxxix{يَومَ تَرجُفُ الأَرضُ وَالجِبالُ وَكانَتِ الجِبالُ كَثيبًا مَهيلًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcdxc{إِنّا أَرسَلنا إِلَيكُم رَسولًا شٰهِدًا عَلَيكُم كَما أَرسَلنا إِلىٰ فِرعَونَ رَسولًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcdxci{فَعَصىٰ فِرعَونُ الرَّسولَ فَأَخَذنٰهُ أَخذًا وَبيلًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcdxcii{فَكَيفَ تَتَّقونَ إِن كَفَرتُم يَومًا يَجعَلُ الوِلدٰنَ شيبًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcdxciii{السَّماءُ مُنفَطِرٌ بِهِ كانَ وَعدُهُ مَفعولًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcdxciv{إِنَّ هٰذِهِ تَذكِرَةٌ فَمَن شاءَ اتَّخَذَ إِلىٰ رَبِّهِ سَبيلًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcdxcv{إِنَّ رَبَّكَ يَعلَمُ أَنَّكَ تَقومُ أَدنىٰ مِن ثُلُثَىِ الَّيلِ وَنِصفَهُ وَثُلُثَهُ وَطائِفَةٌ مِنَ الَّذينَ مَعَكَ وَاللَّهُ يُقَدِّرُ الَّيلَ وَالنَّهارَ عَلِمَ أَن لَن تُحصوهُ فَتابَ عَلَيكُم فَاقرَءوا ما تَيَسَّرَ مِنَ القُرءانِ عَلِمَ أَن سَيَكونُ مِنكُم مَرضىٰ وَءاخَرونَ يَضرِبونَ فِى الأَرضِ يَبتَغونَ مِن فَضلِ اللَّهِ وَءاخَرونَ يُقٰتِلونَ فى سَبيلِ اللَّهِ فَاقرَءوا ما تَيَسَّرَ مِنهُ وَأَقيمُوا الصَّلوٰةَ وَءاتُوا الزَّكوٰةَ وَأَقرِضُوا اللَّهَ قَرضًا حَسَنًا وَما تُقَدِّموا لِأَنفُسِكُم مِن خَيرٍ تَجِدوهُ عِندَ اللَّهِ هُوَ خَيرًا وَأَعظَمَ أَجرًا وَاستَغفِرُوا اللَّهَ إِنَّ اللَّهَ غَفورٌ رَحيمٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcdxcvi{\basmalah  يٰأَيُّهَا المُدَّثِّرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcdxcvii{قُم فَأَنذِر\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcdxcviii{وَرَبَّكَ فَكَبِّر\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcdxcix{وَثِيابَكَ فَطَهِّر\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmd{وَالرُّجزَ فَاهجُر\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdi{وَلا تَمنُن تَستَكثِرُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdii{وَلِرَبِّكَ فَاصبِر\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdiii{فَإِذا نُقِرَ فِى النّاقورِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdiv{فَذٰلِكَ يَومَئِذٍ يَومٌ عَسيرٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdv{عَلَى الكٰفِرينَ غَيرُ يَسيرٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdvi{ذَرنى وَمَن خَلَقتُ وَحيدًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdvii{وَجَعَلتُ لَهُ مالًا مَمدودًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdviii{وَبَنينَ شُهودًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdix{وَمَهَّدتُ لَهُ تَمهيدًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdx{ثُمَّ يَطمَعُ أَن أَزيدَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdxi{كَلّا إِنَّهُ كانَ لِءايٰتِنا عَنيدًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdxii{سَأُرهِقُهُ صَعودًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdxiii{إِنَّهُ فَكَّرَ وَقَدَّرَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdxiv{فَقُتِلَ كَيفَ قَدَّرَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdxv{ثُمَّ قُتِلَ كَيفَ قَدَّرَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdxvi{ثُمَّ نَظَرَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdxvii{ثُمَّ عَبَسَ وَبَسَرَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdxviii{ثُمَّ أَدبَرَ وَاستَكبَرَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdxix{فَقالَ إِن هٰذا إِلّا سِحرٌ يُؤثَرُ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdxx{إِن هٰذا إِلّا قَولُ البَشَرِ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdxxi{سَأُصليهِ سَقَرَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdxxii{وَما أَدرىٰكَ ما سَقَرُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdxxiii{لا تُبقى وَلا تَذَرُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdxxiv{لَوّاحَةٌ لِلبَشَرِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdxxv{عَلَيها تِسعَةَ عَشَرَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdxxvi{وَما جَعَلنا أَصحٰبَ النّارِ إِلّا مَلٰئِكَةً وَما جَعَلنا عِدَّتَهُم إِلّا فِتنَةً لِلَّذينَ كَفَروا لِيَستَيقِنَ الَّذينَ أوتُوا الكِتٰبَ وَيَزدادَ الَّذينَ ءامَنوا إيمٰنًا وَلا يَرتابَ الَّذينَ أوتُوا الكِتٰبَ وَالمُؤمِنونَ وَلِيَقولَ الَّذينَ فى قُلوبِهِم مَرَضٌ وَالكٰفِرونَ ماذا أَرادَ اللَّهُ بِهٰذا مَثَلًا كَذٰلِكَ يُضِلُّ اللَّهُ مَن يَشاءُ وَيَهدى مَن يَشاءُ وَما يَعلَمُ جُنودَ رَبِّكَ إِلّا هُوَ وَما هِىَ إِلّا ذِكرىٰ لِلبَشَرِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdxxvii{كَلّا وَالقَمَرِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdxxviii{وَالَّيلِ إِذ أَدبَرَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdxxix{وَالصُّبحِ إِذا أَسفَرَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdxxx{إِنَّها لَإِحدَى الكُبَرِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdxxxi{نَذيرًا لِلبَشَرِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdxxxii{لِمَن شاءَ مِنكُم أَن يَتَقَدَّمَ أَو يَتَأَخَّرَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdxxxiii{كُلُّ نَفسٍ بِما كَسَبَت رَهينَةٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdxxxiv{إِلّا أَصحٰبَ اليَمينِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdxxxv{فى جَنّٰتٍ يَتَساءَلونَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdxxxvi{عَنِ المُجرِمينَ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdxxxvii{ما سَلَكَكُم فى سَقَرَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdxxxviii{قالوا لَم نَكُ مِنَ المُصَلّينَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdxxxix{وَلَم نَكُ نُطعِمُ المِسكينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdxl{وَكُنّا نَخوضُ مَعَ الخائِضينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdxli{وَكُنّا نُكَذِّبُ بِيَومِ الدّينِ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdxlii{حَتّىٰ أَتىٰنَا اليَقينُ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmdxliii{فَما تَنفَعُهُم شَفٰعَةُ الشّٰفِعينَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmdxliv{فَما لَهُم عَنِ التَّذكِرَةِ مُعرِضينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmdxlv{كَأَنَّهُم حُمُرٌ مُستَنفِرَةٌ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmdxlvi{فَرَّت مِن قَسوَرَةٍ\qt@no{﴿٥١﴾}}
\qt@newcmd\qurantext@mmmmmdxlvii{بَل يُريدُ كُلُّ امرِئٍ مِنهُم أَن يُؤتىٰ صُحُفًا مُنَشَّرَةً\qt@no{﴿٥٢﴾}}
\qt@newcmd\qurantext@mmmmmdxlviii{كَلّا بَل لا يَخافونَ الءاخِرَةَ\qt@no{﴿٥٣﴾}}
\qt@newcmd\qurantext@mmmmmdxlix{كَلّا إِنَّهُ تَذكِرَةٌ\qt@no{﴿٥٤﴾}}
\qt@newcmd\qurantext@mmmmmdl{فَمَن شاءَ ذَكَرَهُ\qt@no{﴿٥٥﴾}}
\qt@newcmd\qurantext@mmmmmdli{وَما يَذكُرونَ إِلّا أَن يَشاءَ اللَّهُ هُوَ أَهلُ التَّقوىٰ وَأَهلُ المَغفِرَةِ\qt@no{﴿٥٦﴾}}
\qt@newcmd\qurantext@mmmmmdlii{\basmalah  لا أُقسِمُ بِيَومِ القِيٰمَةِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdliii{وَلا أُقسِمُ بِالنَّفسِ اللَّوّامَةِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdliv{أَيَحسَبُ الإِنسٰنُ أَلَّن نَجمَعَ عِظامَهُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdlv{بَلىٰ قٰدِرينَ عَلىٰ أَن نُسَوِّىَ بَنانَهُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdlvi{بَل يُريدُ الإِنسٰنُ لِيَفجُرَ أَمامَهُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdlvii{يَسـَٔلُ أَيّانَ يَومُ القِيٰمَةِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdlviii{فَإِذا بَرِقَ البَصَرُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdlix{وَخَسَفَ القَمَرُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdlx{وَجُمِعَ الشَّمسُ وَالقَمَرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxi{يَقولُ الإِنسٰنُ يَومَئِذٍ أَينَ المَفَرُّ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxii{كَلّا لا وَزَرَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdlxiii{إِلىٰ رَبِّكَ يَومَئِذٍ المُستَقَرُّ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxiv{يُنَبَّؤُا۟ الإِنسٰنُ يَومَئِذٍ بِما قَدَّمَ وَأَخَّرَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxv{بَلِ الإِنسٰنُ عَلىٰ نَفسِهِ بَصيرَةٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxvi{وَلَو أَلقىٰ مَعاذيرَهُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxvii{لا تُحَرِّك بِهِ لِسانَكَ لِتَعجَلَ بِهِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxviii{إِنَّ عَلَينا جَمعَهُ وَقُرءانَهُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxix{فَإِذا قَرَأنٰهُ فَاتَّبِع قُرءانَهُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdlxx{ثُمَّ إِنَّ عَلَينا بَيانَهُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxxi{كَلّا بَل تُحِبّونَ العاجِلَةَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxxii{وَتَذَرونَ الءاخِرَةَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdlxxiii{وُجوهٌ يَومَئِذٍ ناضِرَةٌ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxxiv{إِلىٰ رَبِّها ناظِرَةٌ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxxv{وَوُجوهٌ يَومَئِذٍ باسِرَةٌ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxxvi{تَظُنُّ أَن يُفعَلَ بِها فاقِرَةٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxxvii{كَلّا إِذا بَلَغَتِ التَّراقِىَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxxviii{وَقيلَ مَن راقٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxxix{وَظَنَّ أَنَّهُ الفِراقُ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdlxxx{وَالتَفَّتِ السّاقُ بِالسّاقِ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxi{إِلىٰ رَبِّكَ يَومَئِذٍ المَساقُ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxii{فَلا صَدَّقَ وَلا صَلّىٰ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxiii{وَلٰكِن كَذَّبَ وَتَوَلّىٰ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxiv{ثُمَّ ذَهَبَ إِلىٰ أَهلِهِ يَتَمَطّىٰ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxv{أَولىٰ لَكَ فَأَولىٰ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxvi{ثُمَّ أَولىٰ لَكَ فَأَولىٰ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxvii{أَيَحسَبُ الإِنسٰنُ أَن يُترَكَ سُدًى\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxviii{أَلَم يَكُ نُطفَةً مِن مَنِىٍّ يُمنىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdlxxxix{ثُمَّ كانَ عَلَقَةً فَخَلَقَ فَسَوّىٰ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdxc{فَجَعَلَ مِنهُ الزَّوجَينِ الذَّكَرَ وَالأُنثىٰ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdxci{أَلَيسَ ذٰلِكَ بِقٰدِرٍ عَلىٰ أَن يُحۦِىَ المَوتىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdxcii{\basmalah  هَل أَتىٰ عَلَى الإِنسٰنِ حينٌ مِنَ الدَّهرِ لَم يَكُن شَيـًٔا مَذكورًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdxciii{إِنّا خَلَقنَا الإِنسٰنَ مِن نُطفَةٍ أَمشاجٍ نَبتَليهِ فَجَعَلنٰهُ سَميعًا بَصيرًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdxciv{إِنّا هَدَينٰهُ السَّبيلَ إِمّا شاكِرًا وَإِمّا كَفورًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdxcv{إِنّا أَعتَدنا لِلكٰفِرينَ سَلٰسِلَا۟ وَأَغلٰلًا وَسَعيرًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdxcvi{إِنَّ الأَبرارَ يَشرَبونَ مِن كَأسٍ كانَ مِزاجُها كافورًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdxcvii{عَينًا يَشرَبُ بِها عِبادُ اللَّهِ يُفَجِّرونَها تَفجيرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdxcviii{يوفونَ بِالنَّذرِ وَيَخافونَ يَومًا كانَ شَرُّهُ مُستَطيرًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdxcix{وَيُطعِمونَ الطَّعامَ عَلىٰ حُبِّهِ مِسكينًا وَيَتيمًا وَأَسيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdc{إِنَّما نُطعِمُكُم لِوَجهِ اللَّهِ لا نُريدُ مِنكُم جَزاءً وَلا شُكورًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdci{إِنّا نَخافُ مِن رَبِّنا يَومًا عَبوسًا قَمطَريرًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcii{فَوَقىٰهُمُ اللَّهُ شَرَّ ذٰلِكَ اليَومِ وَلَقّىٰهُم نَضرَةً وَسُرورًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdciii{وَجَزىٰهُم بِما صَبَروا جَنَّةً وَحَريرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdciv{مُتَّكِـٔينَ فيها عَلَى الأَرائِكِ لا يَرَونَ فيها شَمسًا وَلا زَمهَريرًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcv{وَدانِيَةً عَلَيهِم ظِلٰلُها وَذُلِّلَت قُطوفُها تَذليلًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcvi{وَيُطافُ عَلَيهِم بِـٔانِيَةٍ مِن فِضَّةٍ وَأَكوابٍ كانَت قَواريرا۠\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcvii{قَواريرَا۟ مِن فِضَّةٍ قَدَّروها تَقديرًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcviii{وَيُسقَونَ فيها كَأسًا كانَ مِزاجُها زَنجَبيلًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcix{عَينًا فيها تُسَمّىٰ سَلسَبيلًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcx{وَيَطوفُ عَلَيهِم وِلدٰنٌ مُخَلَّدونَ إِذا رَأَيتَهُم حَسِبتَهُم لُؤلُؤًا مَنثورًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxi{وَإِذا رَأَيتَ ثَمَّ رَأَيتَ نَعيمًا وَمُلكًا كَبيرًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxii{عٰلِيَهُم ثِيابُ سُندُسٍ خُضرٌ وَإِستَبرَقٌ وَحُلّوا أَساوِرَ مِن فِضَّةٍ وَسَقىٰهُم رَبُّهُم شَرابًا طَهورًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxiii{إِنَّ هٰذا كانَ لَكُم جَزاءً وَكانَ سَعيُكُم مَشكورًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxiv{إِنّا نَحنُ نَزَّلنا عَلَيكَ القُرءانَ تَنزيلًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxv{فَاصبِر لِحُكمِ رَبِّكَ وَلا تُطِع مِنهُم ءاثِمًا أَو كَفورًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxvi{وَاذكُرِ اسمَ رَبِّكَ بُكرَةً وَأَصيلًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxvii{وَمِنَ الَّيلِ فَاسجُد لَهُ وَسَبِّحهُ لَيلًا طَويلًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxviii{إِنَّ هٰؤُلاءِ يُحِبّونَ العاجِلَةَ وَيَذَرونَ وَراءَهُم يَومًا ثَقيلًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxix{نَحنُ خَلَقنٰهُم وَشَدَدنا أَسرَهُم وَإِذا شِئنا بَدَّلنا أَمثٰلَهُم تَبديلًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxx{إِنَّ هٰذِهِ تَذكِرَةٌ فَمَن شاءَ اتَّخَذَ إِلىٰ رَبِّهِ سَبيلًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxxi{وَما تَشاءونَ إِلّا أَن يَشاءَ اللَّهُ إِنَّ اللَّهَ كانَ عَليمًا حَكيمًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxxii{يُدخِلُ مَن يَشاءُ فى رَحمَتِهِ وَالظّٰلِمينَ أَعَدَّ لَهُم عَذابًا أَليمًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxiii{\basmalah  وَالمُرسَلٰتِ عُرفًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxiv{فَالعٰصِفٰتِ عَصفًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxxv{وَالنّٰشِرٰتِ نَشرًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxxvi{فَالفٰرِقٰتِ فَرقًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxxvii{فَالمُلقِيٰتِ ذِكرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxxviii{عُذرًا أَو نُذرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxxix{إِنَّما توعَدونَ لَوٰقِعٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxxx{فَإِذَا النُّجومُ طُمِسَت\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxi{وَإِذَا السَّماءُ فُرِجَت\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxii{وَإِذَا الجِبالُ نُسِفَت\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxiii{وَإِذَا الرُّسُلُ أُقِّتَت\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxiv{لِأَىِّ يَومٍ أُجِّلَت\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxv{لِيَومِ الفَصلِ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxvi{وَما أَدرىٰكَ ما يَومُ الفَصلِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxvii{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxviii{أَلَم نُهلِكِ الأَوَّلينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxxxix{ثُمَّ نُتبِعُهُمُ الءاخِرينَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxl{كَذٰلِكَ نَفعَلُ بِالمُجرِمينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxli{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxlii{أَلَم نَخلُقكُم مِن ماءٍ مَهينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxliii{فَجَعَلنٰهُ فى قَرارٍ مَكينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxliv{إِلىٰ قَدَرٍ مَعلومٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxlv{فَقَدَرنا فَنِعمَ القٰدِرونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxlvi{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxlvii{أَلَم نَجعَلِ الأَرضَ كِفاتًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxlviii{أَحياءً وَأَموٰتًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxlix{وَجَعَلنا فيها رَوٰسِىَ شٰمِخٰتٍ وَأَسقَينٰكُم ماءً فُراتًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcl{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcli{انطَلِقوا إِلىٰ ما كُنتُم بِهِ تُكَذِّبونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdclii{انطَلِقوا إِلىٰ ظِلٍّ ذى ثَلٰثِ شُعَبٍ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcliii{لا ظَليلٍ وَلا يُغنى مِنَ اللَّهَبِ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcliv{إِنَّها تَرمى بِشَرَرٍ كَالقَصرِ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdclv{كَأَنَّهُ جِمٰلَتٌ صُفرٌ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdclvi{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdclvii{هٰذا يَومُ لا يَنطِقونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdclviii{وَلا يُؤذَنُ لَهُم فَيَعتَذِرونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdclix{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdclx{هٰذا يَومُ الفَصلِ جَمَعنٰكُم وَالأَوَّلينَ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxi{فَإِن كانَ لَكُم كَيدٌ فَكيدونِ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxii{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxiii{إِنَّ المُتَّقينَ فى ظِلٰلٍ وَعُيونٍ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdclxiv{وَفَوٰكِهَ مِمّا يَشتَهونَ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxv{كُلوا وَاشرَبوا هَنيـًٔا بِما كُنتُم تَعمَلونَ\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxvi{إِنّا كَذٰلِكَ نَجزِى المُحسِنينَ\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxvii{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxviii{كُلوا وَتَمَتَّعوا قَليلًا إِنَّكُم مُجرِمونَ\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxix{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٤٧﴾}}
\qt@newcmd\qurantext@mmmmmdclxx{وَإِذا قيلَ لَهُمُ اركَعوا لا يَركَعونَ\qt@no{﴿٤٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxxi{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿٤٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxxii{فَبِأَىِّ حَديثٍ بَعدَهُ يُؤمِنونَ\qt@no{﴿٥٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxxiii{\basmalah  عَمَّ يَتَساءَلونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdclxxiv{عَنِ النَّبَإِ العَظيمِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxxv{الَّذى هُم فيهِ مُختَلِفونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxxvi{كَلّا سَيَعلَمونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxxvii{ثُمَّ كَلّا سَيَعلَمونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxxviii{أَلَم نَجعَلِ الأَرضَ مِهٰدًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxxix{وَالجِبالَ أَوتادًا\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdclxxx{وَخَلَقنٰكُم أَزوٰجًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxi{وَجَعَلنا نَومَكُم سُباتًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxii{وَجَعَلنَا الَّيلَ لِباسًا\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxiii{وَجَعَلنَا النَّهارَ مَعاشًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxiv{وَبَنَينا فَوقَكُم سَبعًا شِدادًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxv{وَجَعَلنا سِراجًا وَهّاجًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxvi{وَأَنزَلنا مِنَ المُعصِرٰتِ ماءً ثَجّاجًا\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxvii{لِنُخرِجَ بِهِ حَبًّا وَنَباتًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxviii{وَجَنّٰتٍ أَلفافًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdclxxxix{إِنَّ يَومَ الفَصلِ كانَ ميقٰتًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcxc{يَومَ يُنفَخُ فِى الصّورِ فَتَأتونَ أَفواجًا\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcxci{وَفُتِحَتِ السَّماءُ فَكانَت أَبوٰبًا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcxcii{وَسُيِّرَتِ الجِبالُ فَكانَت سَرابًا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcxciii{إِنَّ جَهَنَّمَ كانَت مِرصادًا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcxciv{لِلطّٰغينَ مَـٔابًا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcxcv{لٰبِثينَ فيها أَحقابًا\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcxcvi{لا يَذوقونَ فيها بَردًا وَلا شَرابًا\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcxcvii{إِلّا حَميمًا وَغَسّاقًا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcxcviii{جَزاءً وِفاقًا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcxcix{إِنَّهُم كانوا لا يَرجونَ حِسابًا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcc{وَكَذَّبوا بِـٔايٰتِنا كِذّابًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcci{وَكُلَّ شَيءٍ أَحصَينٰهُ كِتٰبًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccii{فَذوقوا فَلَن نَزيدَكُم إِلّا عَذابًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcciii{إِنَّ لِلمُتَّقينَ مَفازًا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdcciv{حَدائِقَ وَأَعنٰبًا\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccv{وَكَواعِبَ أَترابًا\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccvi{وَكَأسًا دِهاقًا\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccvii{لا يَسمَعونَ فيها لَغوًا وَلا كِذّٰبًا\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccviii{جَزاءً مِن رَبِّكَ عَطاءً حِسابًا\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccix{رَبِّ السَّمٰوٰتِ وَالأَرضِ وَما بَينَهُمَا الرَّحمٰنِ لا يَملِكونَ مِنهُ خِطابًا\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccx{يَومَ يَقومُ الرّوحُ وَالمَلٰئِكَةُ صَفًّا لا يَتَكَلَّمونَ إِلّا مَن أَذِنَ لَهُ الرَّحمٰنُ وَقالَ صَوابًا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxi{ذٰلِكَ اليَومُ الحَقُّ فَمَن شاءَ اتَّخَذَ إِلىٰ رَبِّهِ مَـٔابًا\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxii{إِنّا أَنذَرنٰكُم عَذابًا قَريبًا يَومَ يَنظُرُ المَرءُ ما قَدَّمَت يَداهُ وَيَقولُ الكافِرُ يٰلَيتَنى كُنتُ تُرٰبًا\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxiii{\basmalah  وَالنّٰزِعٰتِ غَرقًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdccxiv{وَالنّٰشِطٰتِ نَشطًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxv{وَالسّٰبِحٰتِ سَبحًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxvi{فَالسّٰبِقٰتِ سَبقًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxvii{فَالمُدَبِّرٰتِ أَمرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxviii{يَومَ تَرجُفُ الرّاجِفَةُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxix{تَتبَعُهَا الرّادِفَةُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxx{قُلوبٌ يَومَئِذٍ واجِفَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxxi{أَبصٰرُها خٰشِعَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxxii{يَقولونَ أَءِنّا لَمَردودونَ فِى الحافِرَةِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxxiii{أَءِذا كُنّا عِظٰمًا نَخِرَةً\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdccxxiv{قالوا تِلكَ إِذًا كَرَّةٌ خاسِرَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxxv{فَإِنَّما هِىَ زَجرَةٌ وٰحِدَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxxvi{فَإِذا هُم بِالسّاهِرَةِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxxvii{هَل أَتىٰكَ حَديثُ موسىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxxviii{إِذ نادىٰهُ رَبُّهُ بِالوادِ المُقَدَّسِ طُوًى\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxxix{اذهَب إِلىٰ فِرعَونَ إِنَّهُ طَغىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxxx{فَقُل هَل لَكَ إِلىٰ أَن تَزَكّىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxi{وَأَهدِيَكَ إِلىٰ رَبِّكَ فَتَخشىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxii{فَأَرىٰهُ الءايَةَ الكُبرىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxiii{فَكَذَّبَ وَعَصىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxiv{ثُمَّ أَدبَرَ يَسعىٰ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxv{فَحَشَرَ فَنادىٰ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxvi{فَقالَ أَنا۠ رَبُّكُمُ الأَعلىٰ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxvii{فَأَخَذَهُ اللَّهُ نَكالَ الءاخِرَةِ وَالأولىٰ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxviii{إِنَّ فى ذٰلِكَ لَعِبرَةً لِمَن يَخشىٰ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxxxix{ءَأَنتُم أَشَدُّ خَلقًا أَمِ السَّماءُ بَنىٰها\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxl{رَفَعَ سَمكَها فَسَوّىٰها\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxli{وَأَغطَشَ لَيلَها وَأَخرَجَ ضُحىٰها\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxlii{وَالأَرضَ بَعدَ ذٰلِكَ دَحىٰها\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxliii{أَخرَجَ مِنها ماءَها وَمَرعىٰها\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccxliv{وَالجِبالَ أَرسىٰها\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxlv{مَتٰعًا لَكُم وَلِأَنعٰمِكُم\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxlvi{فَإِذا جاءَتِ الطّامَّةُ الكُبرىٰ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxlvii{يَومَ يَتَذَكَّرُ الإِنسٰنُ ما سَعىٰ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxlviii{وَبُرِّزَتِ الجَحيمُ لِمَن يَرىٰ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxlix{فَأَمّا مَن طَغىٰ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccl{وَءاثَرَ الحَيوٰةَ الدُّنيا\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccli{فَإِنَّ الجَحيمَ هِىَ المَأوىٰ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclii{وَأَمّا مَن خافَ مَقامَ رَبِّهِ وَنَهَى النَّفسَ عَنِ الهَوىٰ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccliii{فَإِنَّ الجَنَّةَ هِىَ المَأوىٰ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdccliv{يَسـَٔلونَكَ عَنِ السّاعَةِ أَيّانَ مُرسىٰها\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclv{فيمَ أَنتَ مِن ذِكرىٰها\qt@no{﴿٤٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclvi{إِلىٰ رَبِّكَ مُنتَهىٰها\qt@no{﴿٤٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclvii{إِنَّما أَنتَ مُنذِرُ مَن يَخشىٰها\qt@no{﴿٤٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclviii{كَأَنَّهُم يَومَ يَرَونَها لَم يَلبَثوا إِلّا عَشِيَّةً أَو ضُحىٰها\qt@no{﴿٤٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclix{\basmalah  عَبَسَ وَتَوَلّىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcclx{أَن جاءَهُ الأَعمىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxi{وَما يُدريكَ لَعَلَّهُ يَزَّكّىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxii{أَو يَذَّكَّرُ فَتَنفَعَهُ الذِّكرىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxiii{أَمّا مَنِ استَغنىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxiv{فَأَنتَ لَهُ تَصَدّىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxv{وَما عَلَيكَ أَلّا يَزَّكّىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxvi{وَأَمّا مَن جاءَكَ يَسعىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxvii{وَهُوَ يَخشىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxviii{فَأَنتَ عَنهُ تَلَهّىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxix{كَلّا إِنَّها تَذكِرَةٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcclxx{فَمَن شاءَ ذَكَرَهُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxi{فى صُحُفٍ مُكَرَّمَةٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxii{مَرفوعَةٍ مُطَهَّرَةٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxiii{بِأَيدى سَفَرَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxiv{كِرامٍ بَرَرَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxv{قُتِلَ الإِنسٰنُ ما أَكفَرَهُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxvi{مِن أَىِّ شَيءٍ خَلَقَهُ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxvii{مِن نُطفَةٍ خَلَقَهُ فَقَدَّرَهُ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxviii{ثُمَّ السَّبيلَ يَسَّرَهُ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxix{ثُمَّ أَماتَهُ فَأَقبَرَهُ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxx{ثُمَّ إِذا شاءَ أَنشَرَهُ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxi{كَلّا لَمّا يَقضِ ما أَمَرَهُ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxii{فَليَنظُرِ الإِنسٰنُ إِلىٰ طَعامِهِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxiii{أَنّا صَبَبنَا الماءَ صَبًّا\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxiv{ثُمَّ شَقَقنَا الأَرضَ شَقًّا\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxv{فَأَنبَتنا فيها حَبًّا\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxvi{وَعِنَبًا وَقَضبًا\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxvii{وَزَيتونًا وَنَخلًا\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxviii{وَحَدائِقَ غُلبًا\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdcclxxxix{وَفٰكِهَةً وَأَبًّا\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccxc{مَتٰعًا لَكُم وَلِأَنعٰمِكُم\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccxci{فَإِذا جاءَتِ الصّاخَّةُ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccxcii{يَومَ يَفِرُّ المَرءُ مِن أَخيهِ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccxciii{وَأُمِّهِ وَأَبيهِ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccxciv{وَصٰحِبَتِهِ وَبَنيهِ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccxcv{لِكُلِّ امرِئٍ مِنهُم يَومَئِذٍ شَأنٌ يُغنيهِ\qt@no{﴿٣٧﴾}}
\qt@newcmd\qurantext@mmmmmdccxcvi{وُجوهٌ يَومَئِذٍ مُسفِرَةٌ\qt@no{﴿٣٨﴾}}
\qt@newcmd\qurantext@mmmmmdccxcvii{ضاحِكَةٌ مُستَبشِرَةٌ\qt@no{﴿٣٩﴾}}
\qt@newcmd\qurantext@mmmmmdccxcviii{وَوُجوهٌ يَومَئِذٍ عَلَيها غَبَرَةٌ\qt@no{﴿٤٠﴾}}
\qt@newcmd\qurantext@mmmmmdccxcix{تَرهَقُها قَتَرَةٌ\qt@no{﴿٤١﴾}}
\qt@newcmd\qurantext@mmmmmdccc{أُولٰئِكَ هُمُ الكَفَرَةُ الفَجَرَةُ\qt@no{﴿٤٢﴾}}
\qt@newcmd\qurantext@mmmmmdccci{\basmalah  إِذَا الشَّمسُ كُوِّرَت\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccii{وَإِذَا النُّجومُ انكَدَرَت\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccciii{وَإِذَا الجِبالُ سُيِّرَت\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccciv{وَإِذَا العِشارُ عُطِّلَت\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccv{وَإِذَا الوُحوشُ حُشِرَت\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccvi{وَإِذَا البِحارُ سُجِّرَت\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccvii{وَإِذَا النُّفوسُ زُوِّجَت\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccviii{وَإِذَا المَوءۥدَةُ سُئِلَت\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccix{بِأَىِّ ذَنبٍ قُتِلَت\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccx{وَإِذَا الصُّحُفُ نُشِرَت\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxi{وَإِذَا السَّماءُ كُشِطَت\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxii{وَإِذَا الجَحيمُ سُعِّرَت\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxiii{وَإِذَا الجَنَّةُ أُزلِفَت\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxiv{عَلِمَت نَفسٌ ما أَحضَرَت\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxv{فَلا أُقسِمُ بِالخُنَّسِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxvi{الجَوارِ الكُنَّسِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxvii{وَالَّيلِ إِذا عَسعَسَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxviii{وَالصُّبحِ إِذا تَنَفَّسَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxix{إِنَّهُ لَقَولُ رَسولٍ كَريمٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxx{ذى قُوَّةٍ عِندَ ذِى العَرشِ مَكينٍ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxi{مُطاعٍ ثَمَّ أَمينٍ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxii{وَما صاحِبُكُم بِمَجنونٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxiii{وَلَقَد رَءاهُ بِالأُفُقِ المُبينِ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxiv{وَما هُوَ عَلَى الغَيبِ بِضَنينٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxv{وَما هُوَ بِقَولِ شَيطٰنٍ رَجيمٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxvi{فَأَينَ تَذهَبونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxvii{إِن هُوَ إِلّا ذِكرٌ لِلعٰلَمينَ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxviii{لِمَن شاءَ مِنكُم أَن يَستَقيمَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxix{وَما تَشاءونَ إِلّا أَن يَشاءَ اللَّهُ رَبُّ العٰلَمينَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxx{\basmalah  إِذَا السَّماءُ انفَطَرَت\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxi{وَإِذَا الكَواكِبُ انتَثَرَت\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxii{وَإِذَا البِحارُ فُجِّرَت\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxiii{وَإِذَا القُبورُ بُعثِرَت\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxiv{عَلِمَت نَفسٌ ما قَدَّمَت وَأَخَّرَت\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxv{يٰأَيُّهَا الإِنسٰنُ ما غَرَّكَ بِرَبِّكَ الكَريمِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxvi{الَّذى خَلَقَكَ فَسَوّىٰكَ فَعَدَلَكَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxvii{فى أَىِّ صورَةٍ ما شاءَ رَكَّبَكَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxviii{كَلّا بَل تُكَذِّبونَ بِالدّينِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxxxix{وَإِنَّ عَلَيكُم لَحٰفِظينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxl{كِرامًا كٰتِبينَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxli{يَعلَمونَ ما تَفعَلونَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlii{إِنَّ الأَبرارَ لَفى نَعيمٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxliii{وَإِنَّ الفُجّارَ لَفى جَحيمٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxliv{يَصلَونَها يَومَ الدّينِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlv{وَما هُم عَنها بِغائِبينَ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlvi{وَما أَدرىٰكَ ما يَومُ الدّينِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlvii{ثُمَّ ما أَدرىٰكَ ما يَومُ الدّينِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlviii{يَومَ لا تَملِكُ نَفسٌ لِنَفسٍ شَيـًٔا وَالأَمرُ يَومَئِذٍ لِلَّهِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxlix{\basmalah  وَيلٌ لِلمُطَفِّفينَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdcccl{الَّذينَ إِذَا اكتالوا عَلَى النّاسِ يَستَوفونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccli{وَإِذا كالوهُم أَو وَزَنوهُم يُخسِرونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclii{أَلا يَظُنُّ أُولٰئِكَ أَنَّهُم مَبعوثونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccliii{لِيَومٍ عَظيمٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccliv{يَومَ يَقومُ النّاسُ لِرَبِّ العٰلَمينَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclv{كَلّا إِنَّ كِتٰبَ الفُجّارِ لَفى سِجّينٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclvi{وَما أَدرىٰكَ ما سِجّينٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclvii{كِتٰبٌ مَرقومٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclviii{وَيلٌ يَومَئِذٍ لِلمُكَذِّبينَ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclix{الَّذينَ يُكَذِّبونَ بِيَومِ الدّينِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdccclx{وَما يُكَذِّبُ بِهِ إِلّا كُلُّ مُعتَدٍ أَثيمٍ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxi{إِذا تُتلىٰ عَلَيهِ ءايٰتُنا قالَ أَسٰطيرُ الأَوَّلينَ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxii{كَلّا بَل رانَ عَلىٰ قُلوبِهِم ما كانوا يَكسِبونَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxiii{كَلّا إِنَّهُم عَن رَبِّهِم يَومَئِذٍ لَمَحجوبونَ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxiv{ثُمَّ إِنَّهُم لَصالُوا الجَحيمِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxv{ثُمَّ يُقالُ هٰذَا الَّذى كُنتُم بِهِ تُكَذِّبونَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclxvi{كَلّا إِنَّ كِتٰبَ الأَبرارِ لَفى عِلِّيّينَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclxvii{وَما أَدرىٰكَ ما عِلِّيّونَ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclxviii{كِتٰبٌ مَرقومٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclxix{يَشهَدُهُ المُقَرَّبونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxx{إِنَّ الأَبرارَ لَفى نَعيمٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxi{عَلَى الأَرائِكِ يَنظُرونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxii{تَعرِفُ فى وُجوهِهِم نَضرَةَ النَّعيمِ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxiii{يُسقَونَ مِن رَحيقٍ مَختومٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxiv{خِتٰمُهُ مِسكٌ وَفى ذٰلِكَ فَليَتَنافَسِ المُتَنٰفِسونَ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxv{وَمِزاجُهُ مِن تَسنيمٍ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxvi{عَينًا يَشرَبُ بِهَا المُقَرَّبونَ\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxvii{إِنَّ الَّذينَ أَجرَموا كانوا مِنَ الَّذينَ ءامَنوا يَضحَكونَ\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxviii{وَإِذا مَرّوا بِهِم يَتَغامَزونَ\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxix{وَإِذَا انقَلَبوا إِلىٰ أَهلِهِمُ انقَلَبوا فَكِهينَ\qt@no{﴿٣١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxx{وَإِذا رَأَوهُم قالوا إِنَّ هٰؤُلاءِ لَضالّونَ\qt@no{﴿٣٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxi{وَما أُرسِلوا عَلَيهِم حٰفِظينَ\qt@no{﴿٣٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxii{فَاليَومَ الَّذينَ ءامَنوا مِنَ الكُفّارِ يَضحَكونَ\qt@no{﴿٣٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxiii{عَلَى الأَرائِكِ يَنظُرونَ\qt@no{﴿٣٥﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxiv{هَل ثُوِّبَ الكُفّارُ ما كانوا يَفعَلونَ\qt@no{﴿٣٦﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxv{\basmalah  إِذَا السَّماءُ انشَقَّت\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxvi{وَأَذِنَت لِرَبِّها وَحُقَّت\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxvii{وَإِذَا الأَرضُ مُدَّت\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxviii{وَأَلقَت ما فيها وَتَخَلَّت\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmdccclxxxix{وَأَذِنَت لِرَبِّها وَحُقَّت\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmdcccxc{يٰأَيُّهَا الإِنسٰنُ إِنَّكَ كادِحٌ إِلىٰ رَبِّكَ كَدحًا فَمُلٰقيهِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmdcccxci{فَأَمّا مَن أوتِىَ كِتٰبَهُ بِيَمينِهِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcii{فَسَوفَ يُحاسَبُ حِسابًا يَسيرًا\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmdcccxciii{وَيَنقَلِبُ إِلىٰ أَهلِهِ مَسرورًا\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmdcccxciv{وَأَمّا مَن أوتِىَ كِتٰبَهُ وَراءَ ظَهرِهِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcv{فَسَوفَ يَدعوا ثُبورًا\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcvi{وَيَصلىٰ سَعيرًا\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcvii{إِنَّهُ كانَ فى أَهلِهِ مَسرورًا\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcviii{إِنَّهُ ظَنَّ أَن لَن يَحورَ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmdcccxcix{بَلىٰ إِنَّ رَبَّهُ كانَ بِهِ بَصيرًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcm{فَلا أُقسِمُ بِالشَّفَقِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmi{وَالَّيلِ وَما وَسَقَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmii{وَالقَمَرِ إِذَا اتَّسَقَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmiii{لَتَركَبُنَّ طَبَقًا عَن طَبَقٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmiv{فَما لَهُم لا يُؤمِنونَ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmv{وَإِذا قُرِئَ عَلَيهِمُ القُرءانُ لا يَسجُدونَ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmvi{بَلِ الَّذينَ كَفَروا يُكَذِّبونَ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmvii{وَاللَّهُ أَعلَمُ بِما يوعونَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcmviii{فَبَشِّرهُم بِعَذابٍ أَليمٍ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcmix{إِلَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَهُم أَجرٌ غَيرُ مَمنونٍ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcmx{\basmalah  وَالسَّماءِ ذاتِ البُروجِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxi{وَاليَومِ المَوعودِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxii{وَشاهِدٍ وَمَشهودٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxiii{قُتِلَ أَصحٰبُ الأُخدودِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxiv{النّارِ ذاتِ الوَقودِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxv{إِذ هُم عَلَيها قُعودٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxvi{وَهُم عَلىٰ ما يَفعَلونَ بِالمُؤمِنينَ شُهودٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxvii{وَما نَقَموا مِنهُم إِلّا أَن يُؤمِنوا بِاللَّهِ العَزيزِ الحَميدِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxviii{الَّذى لَهُ مُلكُ السَّمٰوٰتِ وَالأَرضِ وَاللَّهُ عَلىٰ كُلِّ شَيءٍ شَهيدٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxix{إِنَّ الَّذينَ فَتَنُوا المُؤمِنينَ وَالمُؤمِنٰتِ ثُمَّ لَم يَتوبوا فَلَهُم عَذابُ جَهَنَّمَ وَلَهُم عَذابُ الحَريقِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxx{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ لَهُم جَنّٰتٌ تَجرى مِن تَحتِهَا الأَنهٰرُ ذٰلِكَ الفَوزُ الكَبيرُ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxi{إِنَّ بَطشَ رَبِّكَ لَشَديدٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxii{إِنَّهُ هُوَ يُبدِئُ وَيُعيدُ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxxiii{وَهُوَ الغَفورُ الوَدودُ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxxiv{ذُو العَرشِ المَجيدُ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxxv{فَعّالٌ لِما يُريدُ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxxvi{هَل أَتىٰكَ حَديثُ الجُنودِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxxvii{فِرعَونَ وَثَمودَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxxviii{بَلِ الَّذينَ كَفَروا فى تَكذيبٍ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxxix{وَاللَّهُ مِن وَرائِهِم مُحيطٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxxx{بَل هُوَ قُرءانٌ مَجيدٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxi{فى لَوحٍ مَحفوظٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxii{\basmalah  وَالسَّماءِ وَالطّارِقِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxiii{وَما أَدرىٰكَ مَا الطّارِقُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxiv{النَّجمُ الثّاقِبُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxv{إِن كُلُّ نَفسٍ لَمّا عَلَيها حافِظٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxvi{فَليَنظُرِ الإِنسٰنُ مِمَّ خُلِقَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxvii{خُلِقَ مِن ماءٍ دافِقٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxviii{يَخرُجُ مِن بَينِ الصُّلبِ وَالتَّرائِبِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxxxix{إِنَّهُ عَلىٰ رَجعِهِ لَقادِرٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmxl{يَومَ تُبلَى السَّرائِرُ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmxli{فَما لَهُ مِن قُوَّةٍ وَلا ناصِرٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmxlii{وَالسَّماءِ ذاتِ الرَّجعِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmxliii{وَالأَرضِ ذاتِ الصَّدعِ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxliv{إِنَّهُ لَقَولٌ فَصلٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxlv{وَما هُوَ بِالهَزلِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxlvi{إِنَّهُم يَكيدونَ كَيدًا\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxlvii{وَأَكيدُ كَيدًا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxlviii{فَمَهِّلِ الكٰفِرينَ أَمهِلهُم رُوَيدًا\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmxlix{\basmalah  سَبِّحِ اسمَ رَبِّكَ الأَعلَى\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcml{الَّذى خَلَقَ فَسَوّىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmli{وَالَّذى قَدَّرَ فَهَدىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlii{وَالَّذى أَخرَجَ المَرعىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmliii{فَجَعَلَهُ غُثاءً أَحوىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmliv{سَنُقرِئُكَ فَلا تَنسىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlv{إِلّا ما شاءَ اللَّهُ إِنَّهُ يَعلَمُ الجَهرَ وَما يَخفىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlvi{وَنُيَسِّرُكَ لِليُسرىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlvii{فَذَكِّر إِن نَفَعَتِ الذِّكرىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlviii{سَيَذَّكَّرُ مَن يَخشىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlix{وَيَتَجَنَّبُهَا الأَشقَى\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmlx{الَّذى يَصلَى النّارَ الكُبرىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxi{ثُمَّ لا يَموتُ فيها وَلا يَحيىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxii{قَد أَفلَحَ مَن تَزَكّىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxiii{وَذَكَرَ اسمَ رَبِّهِ فَصَلّىٰ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxiv{بَل تُؤثِرونَ الحَيوٰةَ الدُّنيا\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxv{وَالءاخِرَةُ خَيرٌ وَأَبقىٰ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxvi{إِنَّ هٰذا لَفِى الصُّحُفِ الأولىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxvii{صُحُفِ إِبرٰهيمَ وَموسىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxviii{\basmalah  هَل أَتىٰكَ حَديثُ الغٰشِيَةِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxix{وُجوهٌ يَومَئِذٍ خٰشِعَةٌ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxx{عامِلَةٌ ناصِبَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxi{تَصلىٰ نارًا حامِيَةً\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxii{تُسقىٰ مِن عَينٍ ءانِيَةٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxiii{لَيسَ لَهُم طَعامٌ إِلّا مِن ضَريعٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxiv{لا يُسمِنُ وَلا يُغنى مِن جوعٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxv{وُجوهٌ يَومَئِذٍ ناعِمَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxvi{لِسَعيِها راضِيَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxvii{فى جَنَّةٍ عالِيَةٍ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxviii{لا تَسمَعُ فيها لٰغِيَةً\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxix{فيها عَينٌ جارِيَةٌ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxx{فيها سُرُرٌ مَرفوعَةٌ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxi{وَأَكوابٌ مَوضوعَةٌ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxii{وَنَمارِقُ مَصفوفَةٌ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxiii{وَزَرابِىُّ مَبثوثَةٌ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxiv{أَفَلا يَنظُرونَ إِلَى الإِبِلِ كَيفَ خُلِقَت\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxv{وَإِلَى السَّماءِ كَيفَ رُفِعَت\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxvi{وَإِلَى الجِبالِ كَيفَ نُصِبَت\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxvii{وَإِلَى الأَرضِ كَيفَ سُطِحَت\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxviii{فَذَكِّر إِنَّما أَنتَ مُذَكِّرٌ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmcmlxxxix{لَستَ عَلَيهِم بِمُصَيطِرٍ\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxc{إِلّا مَن تَوَلّىٰ وَكَفَرَ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxci{فَيُعَذِّبُهُ اللَّهُ العَذابَ الأَكبَرَ\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxcii{إِنَّ إِلَينا إِيابَهُم\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxciii{ثُمَّ إِنَّ عَلَينا حِسابَهُم\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmcmxciv{\basmalah  وَالفَجرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmcmxcv{وَلَيالٍ عَشرٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmcmxcvi{وَالشَّفعِ وَالوَترِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmcmxcvii{وَالَّيلِ إِذا يَسرِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmcmxcviii{هَل فى ذٰلِكَ قَسَمٌ لِذى حِجرٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmcmxcix{أَلَم تَرَ كَيفَ فَعَلَ رَبُّكَ بِعادٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmm{إِرَمَ ذاتِ العِمادِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmi{الَّتى لَم يُخلَق مِثلُها فِى البِلٰدِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmii{وَثَمودَ الَّذينَ جابُوا الصَّخرَ بِالوادِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmiii{وَفِرعَونَ ذِى الأَوتادِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmiv{الَّذينَ طَغَوا فِى البِلٰدِ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmv{فَأَكثَروا فيهَا الفَسادَ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmvi{فَصَبَّ عَلَيهِم رَبُّكَ سَوطَ عَذابٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmvii{إِنَّ رَبَّكَ لَبِالمِرصادِ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmviii{فَأَمَّا الإِنسٰنُ إِذا مَا ابتَلىٰهُ رَبُّهُ فَأَكرَمَهُ وَنَعَّمَهُ فَيَقولُ رَبّى أَكرَمَنِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmix{وَأَمّا إِذا مَا ابتَلىٰهُ فَقَدَرَ عَلَيهِ رِزقَهُ فَيَقولُ رَبّى أَهٰنَنِ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmx{كَلّا بَل لا تُكرِمونَ اليَتيمَ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmxi{وَلا تَحٰضّونَ عَلىٰ طَعامِ المِسكينِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmxii{وَتَأكُلونَ التُّراثَ أَكلًا لَمًّا\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmxiii{وَتُحِبّونَ المالَ حُبًّا جَمًّا\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmxiv{كَلّا إِذا دُكَّتِ الأَرضُ دَكًّا دَكًّا\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmmxv{وَجاءَ رَبُّكَ وَالمَلَكُ صَفًّا صَفًّا\qt@no{﴿٢٢﴾}}
\qt@newcmd\qurantext@mmmmmmxvi{وَجِا۟يءَ يَومَئِذٍ بِجَهَنَّمَ يَومَئِذٍ يَتَذَكَّرُ الإِنسٰنُ وَأَنّىٰ لَهُ الذِّكرىٰ\qt@no{﴿٢٣﴾}}
\qt@newcmd\qurantext@mmmmmmxvii{يَقولُ يٰلَيتَنى قَدَّمتُ لِحَياتى\qt@no{﴿٢٤﴾}}
\qt@newcmd\qurantext@mmmmmmxviii{فَيَومَئِذٍ لا يُعَذِّبُ عَذابَهُ أَحَدٌ\qt@no{﴿٢٥﴾}}
\qt@newcmd\qurantext@mmmmmmxix{وَلا يوثِقُ وَثاقَهُ أَحَدٌ\qt@no{﴿٢٦﴾}}
\qt@newcmd\qurantext@mmmmmmxx{يٰأَيَّتُهَا النَّفسُ المُطمَئِنَّةُ\qt@no{﴿٢٧﴾}}
\qt@newcmd\qurantext@mmmmmmxxi{ارجِعى إِلىٰ رَبِّكِ راضِيَةً مَرضِيَّةً\qt@no{﴿٢٨﴾}}
\qt@newcmd\qurantext@mmmmmmxxii{فَادخُلى فى عِبٰدى\qt@no{﴿٢٩﴾}}
\qt@newcmd\qurantext@mmmmmmxxiii{وَادخُلى جَنَّتى\qt@no{﴿٣٠﴾}}
\qt@newcmd\qurantext@mmmmmmxxiv{\basmalah  لا أُقسِمُ بِهٰذَا البَلَدِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxxv{وَأَنتَ حِلٌّ بِهٰذَا البَلَدِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxxvi{وَوالِدٍ وَما وَلَدَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxxvii{لَقَد خَلَقنَا الإِنسٰنَ فى كَبَدٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxxviii{أَيَحسَبُ أَن لَن يَقدِرَ عَلَيهِ أَحَدٌ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxxix{يَقولُ أَهلَكتُ مالًا لُبَدًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmxxx{أَيَحسَبُ أَن لَم يَرَهُ أَحَدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmxxxi{أَلَم نَجعَل لَهُ عَينَينِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmxxxii{وَلِسانًا وَشَفَتَينِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmxxxiii{وَهَدَينٰهُ النَّجدَينِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmxxxiv{فَلَا اقتَحَمَ العَقَبَةَ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmxxxv{وَما أَدرىٰكَ مَا العَقَبَةُ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmxxxvi{فَكُّ رَقَبَةٍ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmxxxvii{أَو إِطعٰمٌ فى يَومٍ ذى مَسغَبَةٍ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmxxxviii{يَتيمًا ذا مَقرَبَةٍ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmxxxix{أَو مِسكينًا ذا مَترَبَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmxl{ثُمَّ كانَ مِنَ الَّذينَ ءامَنوا وَتَواصَوا بِالصَّبرِ وَتَواصَوا بِالمَرحَمَةِ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmxli{أُولٰئِكَ أَصحٰبُ المَيمَنَةِ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmxlii{وَالَّذينَ كَفَروا بِـٔايٰتِنا هُم أَصحٰبُ المَشـَٔمَةِ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmxliii{عَلَيهِم نارٌ مُؤصَدَةٌ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmxliv{\basmalah  وَالشَّمسِ وَضُحىٰها\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxlv{وَالقَمَرِ إِذا تَلىٰها\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxlvi{وَالنَّهارِ إِذا جَلّىٰها\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxlvii{وَالَّيلِ إِذا يَغشىٰها\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxlviii{وَالسَّماءِ وَما بَنىٰها\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxlix{وَالأَرضِ وَما طَحىٰها\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmml{وَنَفسٍ وَما سَوّىٰها\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmli{فَأَلهَمَها فُجورَها وَتَقوىٰها\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlii{قَد أَفلَحَ مَن زَكّىٰها\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmliii{وَقَد خابَ مَن دَسّىٰها\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmliv{كَذَّبَت ثَمودُ بِطَغوىٰها\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmlv{إِذِ انبَعَثَ أَشقىٰها\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmlvi{فَقالَ لَهُم رَسولُ اللَّهِ ناقَةَ اللَّهِ وَسُقيٰها\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmlvii{فَكَذَّبوهُ فَعَقَروها فَدَمدَمَ عَلَيهِم رَبُّهُم بِذَنبِهِم فَسَوّىٰها\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmlviii{وَلا يَخافُ عُقبٰها\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmlix{\basmalah  وَالَّيلِ إِذا يَغشىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmlx{وَالنَّهارِ إِذا تَجَلّىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxi{وَما خَلَقَ الذَّكَرَ وَالأُنثىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxii{إِنَّ سَعيَكُم لَشَتّىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxiii{فَأَمّا مَن أَعطىٰ وَاتَّقىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxiv{وَصَدَّقَ بِالحُسنىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxv{فَسَنُيَسِّرُهُ لِليُسرىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxvi{وَأَمّا مَن بَخِلَ وَاستَغنىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxvii{وَكَذَّبَ بِالحُسنىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxviii{فَسَنُيَسِّرُهُ لِلعُسرىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmlxix{وَما يُغنى عَنهُ مالُهُ إِذا تَرَدّىٰ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmlxx{إِنَّ عَلَينا لَلهُدىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxxi{وَإِنَّ لَنا لَلءاخِرَةَ وَالأولىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxxii{فَأَنذَرتُكُم نارًا تَلَظّىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxxiii{لا يَصلىٰها إِلَّا الأَشقَى\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxxiv{الَّذى كَذَّبَ وَتَوَلّىٰ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxxv{وَسَيُجَنَّبُهَا الأَتقَى\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxxvi{الَّذى يُؤتى مالَهُ يَتَزَكّىٰ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxxvii{وَما لِأَحَدٍ عِندَهُ مِن نِعمَةٍ تُجزىٰ\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxxviii{إِلَّا ابتِغاءَ وَجهِ رَبِّهِ الأَعلىٰ\qt@no{﴿٢٠﴾}}
\qt@newcmd\qurantext@mmmmmmlxxix{وَلَسَوفَ يَرضىٰ\qt@no{﴿٢١﴾}}
\qt@newcmd\qurantext@mmmmmmlxxx{\basmalah  وَالضُّحىٰ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxi{وَالَّيلِ إِذا سَجىٰ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxii{ما وَدَّعَكَ رَبُّكَ وَما قَلىٰ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxiii{وَلَلءاخِرَةُ خَيرٌ لَكَ مِنَ الأولىٰ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxiv{وَلَسَوفَ يُعطيكَ رَبُّكَ فَتَرضىٰ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxv{أَلَم يَجِدكَ يَتيمًا فَـٔاوىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxvi{وَوَجَدَكَ ضالًّا فَهَدىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxvii{وَوَجَدَكَ عائِلًا فَأَغنىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxviii{فَأَمَّا اليَتيمَ فَلا تَقهَر\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmlxxxix{وَأَمَّا السّائِلَ فَلا تَنهَر\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmxc{وَأَمّا بِنِعمَةِ رَبِّكَ فَحَدِّث\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmxci{\basmalah  أَلَم نَشرَح لَكَ صَدرَكَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmxcii{وَوَضَعنا عَنكَ وِزرَكَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmxciii{الَّذى أَنقَضَ ظَهرَكَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmxciv{وَرَفَعنا لَكَ ذِكرَكَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmxcv{فَإِنَّ مَعَ العُسرِ يُسرًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmxcvi{إِنَّ مَعَ العُسرِ يُسرًا\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmxcvii{فَإِذا فَرَغتَ فَانصَب\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmxcviii{وَإِلىٰ رَبِّكَ فَارغَب\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmxcix{\basmalah  وَالتّينِ وَالزَّيتونِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmc{وَطورِ سينينَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmci{وَهٰذَا البَلَدِ الأَمينِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcii{لَقَد خَلَقنَا الإِنسٰنَ فى أَحسَنِ تَقويمٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmciii{ثُمَّ رَدَدنٰهُ أَسفَلَ سٰفِلينَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmciv{إِلَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ فَلَهُم أَجرٌ غَيرُ مَمنونٍ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcv{فَما يُكَذِّبُكَ بَعدُ بِالدّينِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcvi{أَلَيسَ اللَّهُ بِأَحكَمِ الحٰكِمينَ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcvii{\basmalah  اقرَأ بِاسمِ رَبِّكَ الَّذى خَلَقَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcviii{خَلَقَ الإِنسٰنَ مِن عَلَقٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcix{اقرَأ وَرَبُّكَ الأَكرَمُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcx{الَّذى عَلَّمَ بِالقَلَمِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxi{عَلَّمَ الإِنسٰنَ ما لَم يَعلَم\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxii{كَلّا إِنَّ الإِنسٰنَ لَيَطغىٰ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxiii{أَن رَءاهُ استَغنىٰ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxiv{إِنَّ إِلىٰ رَبِّكَ الرُّجعىٰ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxv{أَرَءَيتَ الَّذى يَنهىٰ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmcxvi{عَبدًا إِذا صَلّىٰ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmcxvii{أَرَءَيتَ إِن كانَ عَلَى الهُدىٰ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmcxviii{أَو أَمَرَ بِالتَّقوىٰ\qt@no{﴿١٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxix{أَرَءَيتَ إِن كَذَّبَ وَتَوَلّىٰ\qt@no{﴿١٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxx{أَلَم يَعلَم بِأَنَّ اللَّهَ يَرىٰ\qt@no{﴿١٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxi{كَلّا لَئِن لَم يَنتَهِ لَنَسفَعًا بِالنّاصِيَةِ\qt@no{﴿١٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxii{ناصِيَةٍ كٰذِبَةٍ خاطِئَةٍ\qt@no{﴿١٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxxiii{فَليَدعُ نادِيَهُ\qt@no{﴿١٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxxiv{سَنَدعُ الزَّبانِيَةَ\qt@no{﴿١٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxxv{كَلّا لا تُطِعهُ وَاسجُد وَاقتَرِب\qt@no{﴿١٩﴾}}
\qt@newcmd\qurantext@mmmmmmcxxvi{\basmalah  إِنّا أَنزَلنٰهُ فى لَيلَةِ القَدرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxxvii{وَما أَدرىٰكَ ما لَيلَةُ القَدرِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxxviii{لَيلَةُ القَدرِ خَيرٌ مِن أَلفِ شَهرٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxxix{تَنَزَّلُ المَلٰئِكَةُ وَالرّوحُ فيها بِإِذنِ رَبِّهِم مِن كُلِّ أَمرٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxx{سَلٰمٌ هِىَ حَتّىٰ مَطلَعِ الفَجرِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxi{\basmalah  لَم يَكُنِ الَّذينَ كَفَروا مِن أَهلِ الكِتٰبِ وَالمُشرِكينَ مُنفَكّينَ حَتّىٰ تَأتِيَهُمُ البَيِّنَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxii{رَسولٌ مِنَ اللَّهِ يَتلوا صُحُفًا مُطَهَّرَةً\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxiii{فيها كُتُبٌ قَيِّمَةٌ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxiv{وَما تَفَرَّقَ الَّذينَ أوتُوا الكِتٰبَ إِلّا مِن بَعدِ ما جاءَتهُمُ البَيِّنَةُ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxv{وَما أُمِروا إِلّا لِيَعبُدُوا اللَّهَ مُخلِصينَ لَهُ الدّينَ حُنَفاءَ وَيُقيمُوا الصَّلوٰةَ وَيُؤتُوا الزَّكوٰةَ وَذٰلِكَ دينُ القَيِّمَةِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxvi{إِنَّ الَّذينَ كَفَروا مِن أَهلِ الكِتٰبِ وَالمُشرِكينَ فى نارِ جَهَنَّمَ خٰلِدينَ فيها أُولٰئِكَ هُم شَرُّ البَرِيَّةِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxvii{إِنَّ الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ أُولٰئِكَ هُم خَيرُ البَرِيَّةِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxviii{جَزاؤُهُم عِندَ رَبِّهِم جَنّٰتُ عَدنٍ تَجرى مِن تَحتِهَا الأَنهٰرُ خٰلِدينَ فيها أَبَدًا رَضِىَ اللَّهُ عَنهُم وَرَضوا عَنهُ ذٰلِكَ لِمَن خَشِىَ رَبَّهُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxxxix{\basmalah  إِذا زُلزِلَتِ الأَرضُ زِلزالَها\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxl{وَأَخرَجَتِ الأَرضُ أَثقالَها\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxli{وَقالَ الإِنسٰنُ ما لَها\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxlii{يَومَئِذٍ تُحَدِّثُ أَخبارَها\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxliii{بِأَنَّ رَبَّكَ أَوحىٰ لَها\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxliv{يَومَئِذٍ يَصدُرُ النّاسُ أَشتاتًا لِيُرَوا أَعمٰلَهُم\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcxlv{فَمَن يَعمَل مِثقالَ ذَرَّةٍ خَيرًا يَرَهُ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcxlvi{وَمَن يَعمَل مِثقالَ ذَرَّةٍ شَرًّا يَرَهُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmcxlvii{\basmalah  وَالعٰدِيٰتِ ضَبحًا\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxlviii{فَالمورِيٰتِ قَدحًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxlix{فَالمُغيرٰتِ صُبحًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcl{فَأَثَرنَ بِهِ نَقعًا\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcli{فَوَسَطنَ بِهِ جَمعًا\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclii{إِنَّ الإِنسٰنَ لِرَبِّهِ لَكَنودٌ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcliii{وَإِنَّهُ عَلىٰ ذٰلِكَ لَشَهيدٌ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmcliv{وَإِنَّهُ لِحُبِّ الخَيرِ لَشَديدٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclv{أَفَلا يَعلَمُ إِذا بُعثِرَ ما فِى القُبورِ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclvi{وَحُصِّلَ ما فِى الصُّدورِ\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmclvii{إِنَّ رَبَّهُم بِهِم يَومَئِذٍ لَخَبيرٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmclviii{\basmalah  القارِعَةُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclix{مَا القارِعَةُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclx{وَما أَدرىٰكَ مَا القارِعَةُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxi{يَومَ يَكونُ النّاسُ كَالفَراشِ المَبثوثِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxii{وَتَكونُ الجِبالُ كَالعِهنِ المَنفوشِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxiii{فَأَمّا مَن ثَقُلَت مَوٰزينُهُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxiv{فَهُوَ فى عيشَةٍ راضِيَةٍ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxv{وَأَمّا مَن خَفَّت مَوٰزينُهُ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxvi{فَأُمُّهُ هاوِيَةٌ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclxvii{وَما أَدرىٰكَ ما هِيَه\qt@no{﴿١٠﴾}}
\qt@newcmd\qurantext@mmmmmmclxviii{نارٌ حامِيَةٌ\qt@no{﴿١١﴾}}
\qt@newcmd\qurantext@mmmmmmclxix{\basmalah  أَلهىٰكُمُ التَّكاثُرُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxx{حَتّىٰ زُرتُمُ المَقابِرَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxi{كَلّا سَوفَ تَعلَمونَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxii{ثُمَّ كَلّا سَوفَ تَعلَمونَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxxiii{كَلّا لَو تَعلَمونَ عِلمَ اليَقينِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxxiv{لَتَرَوُنَّ الجَحيمَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxxv{ثُمَّ لَتَرَوُنَّها عَينَ اليَقينِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxxvi{ثُمَّ لَتُسـَٔلُنَّ يَومَئِذٍ عَنِ النَّعيمِ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxxvii{\basmalah  وَالعَصرِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxxviii{إِنَّ الإِنسٰنَ لَفى خُسرٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxix{إِلَّا الَّذينَ ءامَنوا وَعَمِلُوا الصّٰلِحٰتِ وَتَواصَوا بِالحَقِّ وَتَواصَوا بِالصَّبرِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxx{\basmalah  وَيلٌ لِكُلِّ هُمَزَةٍ لُمَزَةٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxi{الَّذى جَمَعَ مالًا وَعَدَّدَهُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxii{يَحسَبُ أَنَّ مالَهُ أَخلَدَهُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxiii{كَلّا لَيُنبَذَنَّ فِى الحُطَمَةِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxiv{وَما أَدرىٰكَ مَا الحُطَمَةُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxv{نارُ اللَّهِ الموقَدَةُ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxvi{الَّتى تَطَّلِعُ عَلَى الأَفـِٔدَةِ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxvii{إِنَّها عَلَيهِم مُؤصَدَةٌ\qt@no{﴿٨﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxviii{فى عَمَدٍ مُمَدَّدَةٍ\qt@no{﴿٩﴾}}
\qt@newcmd\qurantext@mmmmmmclxxxix{\basmalah  أَلَم تَرَ كَيفَ فَعَلَ رَبُّكَ بِأَصحٰبِ الفيلِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxc{أَلَم يَجعَل كَيدَهُم فى تَضليلٍ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxci{وَأَرسَلَ عَلَيهِم طَيرًا أَبابيلَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxcii{تَرميهِم بِحِجارَةٍ مِن سِجّيلٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxciii{فَجَعَلَهُم كَعَصفٍ مَأكولٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcxciv{\basmalah  لِإيلٰفِ قُرَيشٍ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxcv{إۦلٰفِهِم رِحلَةَ الشِّتاءِ وَالصَّيفِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcxcvi{فَليَعبُدوا رَبَّ هٰذَا البَيتِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcxcvii{الَّذى أَطعَمَهُم مِن جوعٍ وَءامَنَهُم مِن خَوفٍ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmcxcviii{\basmalah  أَرَءَيتَ الَّذى يُكَذِّبُ بِالدّينِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmcxcix{فَذٰلِكَ الَّذى يَدُعُّ اليَتيمَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmcc{وَلا يَحُضُّ عَلىٰ طَعامِ المِسكينِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmcci{فَوَيلٌ لِلمُصَلّينَ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccii{الَّذينَ هُم عَن صَلاتِهِم ساهونَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmcciii{الَّذينَ هُم يُراءونَ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmcciv{وَيَمنَعونَ الماعونَ\qt@no{﴿٧﴾}}
\qt@newcmd\qurantext@mmmmmmccv{\basmalah  إِنّا أَعطَينٰكَ الكَوثَرَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccvi{فَصَلِّ لِرَبِّكَ وَانحَر\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccvii{إِنَّ شانِئَكَ هُوَ الأَبتَرُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccviii{\basmalah  قُل يٰأَيُّهَا الكٰفِرونَ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccix{لا أَعبُدُ ما تَعبُدونَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccx{وَلا أَنتُم عٰبِدونَ ما أَعبُدُ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxi{وَلا أَنا۠ عابِدٌ ما عَبَدتُم\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxii{وَلا أَنتُم عٰبِدونَ ما أَعبُدُ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxiii{لَكُم دينُكُم وَلِىَ دينِ\qt@no{﴿٦﴾}}
\qt@newcmd\qurantext@mmmmmmccxiv{\basmalah  إِذا جاءَ نَصرُ اللَّهِ وَالفَتحُ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxv{وَرَأَيتَ النّاسَ يَدخُلونَ فى دينِ اللَّهِ أَفواجًا\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxvi{فَسَبِّح بِحَمدِ رَبِّكَ وَاستَغفِرهُ إِنَّهُ كانَ تَوّابًا\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxvii{\basmalah  تَبَّت يَدا أَبى لَهَبٍ وَتَبَّ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxviii{ما أَغنىٰ عَنهُ مالُهُ وَما كَسَبَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxix{سَيَصلىٰ نارًا ذاتَ لَهَبٍ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxx{وَامرَأَتُهُ حَمّالَةَ الحَطَبِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxi{فى جيدِها حَبلٌ مِن مَسَدٍ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxii{\basmalah  قُل هُوَ اللَّهُ أَحَدٌ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxiii{اللَّهُ الصَّمَدُ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxiv{لَم يَلِد وَلَم يولَد\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxv{وَلَم يَكُن لَهُ كُفُوًا أَحَدٌ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxvi{\basmalah  قُل أَعوذُ بِرَبِّ الفَلَقِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxvii{مِن شَرِّ ما خَلَقَ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxviii{وَمِن شَرِّ غاسِقٍ إِذا وَقَبَ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxix{وَمِن شَرِّ النَّفّٰثٰتِ فِى العُقَدِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxx{وَمِن شَرِّ حاسِدٍ إِذا حَسَدَ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxi{\basmalah  قُل أَعوذُ بِرَبِّ النّاسِ\qt@no{﴿١﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxii{مَلِكِ النّاسِ\qt@no{﴿٢﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxiii{إِلٰهِ النّاسِ\qt@no{﴿٣﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxiv{مِن شَرِّ الوَسواسِ الخَنّاسِ\qt@no{﴿٤﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxv{الَّذى يُوَسوِسُ فى صُدورِ النّاسِ\qt@no{﴿٥﴾}}
\qt@newcmd\qurantext@mmmmmmccxxxvi{مِنَ الجِنَّةِ وَالنّاسِ\qt@no{﴿٦﴾}}
