\qt@newcmd\qurantrans@ur@i{عظیم اور دائمی رحمتوں والے خدا کے نام سے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ii{ساری تعریف اللہ کے لئے ہے جو عالمین کا پالنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@iii{وہ عظیم اوردائمی رحمتوں والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@iv{روزِقیامت کا مالک و مختار ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@v{پروردگار! ہم تیری ہی عبادت کرتے ہیں ا ور تجھی سے مدد چاہتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@vi{ہمیں سیدھے راستہ کی ہدایت فرماتا رہ\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@vii{جو اُن لوگوں کا راستہ ہے جن پر تو نے نعمتیں نازل کی ہیں ان کا راستہ نہیں جن پر غضب نازل ہوا ہے یا جو بہکے ہوئے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@viii{\basmalahur الۤمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ix{یہ وہ کتاب ہے جس میں کسی طرح کے شک و شبہ کی گنجائش نہیں ہے. یہ صاحبانِ تقویٰ اور پرہیزگار لوگوں کے لئے مجسم ہدایت ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@x{جو غیب پر ایمان رکھتے ہیں پابندی سے پورے اہتمام کے ساتھ نماز ادا کرتے ہیں اور جو کچھ ہم نے رزق دیا ہے اس میں سے ہماری راہ میں خرچ بھی کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@xi{وہ ان تمام باتوں پر بھی ایمان رکھتے ہیں جنہیں (اے رسول) ہم نے آپ پر نازل کیا ہے اور جو آپ سے پہلے نازل کی گئی ہیں اور آخرت پر بھی یقین رکھتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@xii{یہی وہ لوگ ہیں جو اپنے پروردگار کی طرف سے ہدایت کے حامل ہیں اور فلاح یافتہ اور کامیاب ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@xiii{اے رسول! جن لوگوں نے کفر اختیار کرلیا ہے ان کے لئے سب برابر ہے. آپ انہیں ڈرائیں یا نہ ڈرائیں یہ ایمان لانے والے نہیں ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@xiv{خدا نے ان کے دلوں اور کانوں پر گویا مہر لگا دی ہے کہ نہ کچھ سنتے ہیںاور نہ سمجھتے ہیں اور آنکھوں پر بھی پردے پڑ گئے ہیں. ان کے واسطےآخرت میں عذابِ عظیم ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@xv{کچھ لوگ ایسے بھی ہیں جو یہ کہتے ہیں کہ ہم خدا اور آخرت پر ایمان لائے ہیں حالانکہ وہ صاحب ایمان نہیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@xvi{یہ خدا اور صاحبان ایمان کو دھوکہ دینا چاہتے ہیں حالانکہ اپنے ہی کو دھوکہ دے رہے ہیں اور سمجھتے بھی نہیں ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@xvii{ان کے دلوں میں بیماری ہے اور خدا نے نفاق کی بنا پر اسے اور بھی بڑھا دیا ہے. اب اس جھوٹ کے نتیجہ میں انہیں درد ناک عذاب ملے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@xviii{جب ان سے کہا جاتا ہے کہ زمین میں فساد نہ برپا کرو تو کہتے ہیں کہ ہم تو صرف اصلاح کرنے والے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@xix{حالانکہ یہ سب مفسد ہیں اور اپنے فسادکو سمجھتے بھی نہیں ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@xx{جب ان سے کہا جاتا ہے کہ دوسرے مومنین کی طرح ایمان لے آؤ تو کہتے ہیں کہ ہم بے وقوفوں کی طرح ایمان اختیار کرلیں حالانکہ اصل میں یہی بے وقوف ہیں اور انہیں اس کی واقفیت بھی نہیں ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@xxi{جب یہ صاحبانِ ایمان سے ملتے ہیںتو کہتے ہیں کہ ہم ایمان لے آئے اور جب اپنے شیاطین کی خلوتوں میں جاتے ہیں تو کہتے ہیں کہ ہم تمہاری ہی پارٹی میں ہیں ہم تو صرف صاحبانِ ایمان کا مذاق اڑاتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@xxii{حالانکہ خدا خود ان کو مذاق بنائے ہوئے ہے اور انہیںسرکشی میں ڈھیل دیئے ہوئے ہے جو انہیں نظر بھی نہیں آرہی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@xxiii{یہی وہ لوگ ہیں جنہوں نے ہدایت کو دے کرگمراہی خرید لی ہے جس تجارت سے نہ کوئی فائدہ ہے اور نہ اس میں کسی طرح کی ہدایت ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@xxiv{ان کی مثال اس شخص کی ہے جس نے روشنی کے لئے آگ بھڑکائی اور جب ہر طرف روشنی پھیل گئی تو خدا نے اس کے نور کو سلب کرلیا اور اب اسے اندھیرے میں کچھ سوجھتا بھی نہیں ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@xxv{یہ سب بہرےً گونگے اور اندھے ہوگئے ہیں اور اب پلٹ کر آنے والے نہیں ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@xxvi{ان کی دوسری مثال آسمان کی اس بارش کی ہے جس میں تاریکی اور گرج چمک سب کچھ ہوکہ موت کے خوف سے کڑک دیکھ کر کانوں میں انگلیاں رکھ لیں. حالانکہ خدا کافروں کا احاطہ کئے ہوئے ہے اور یہ بچ کر نہیں جاسکتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@xxvii{قریب ہے کہ بجلی ان کی آنکھوں کو چکاچوندھ کردے کہ جب وہ چمک جائے تو چل پڑیں اور جب اندھیرا ہوجائے تو ٹھہر جائیں. خدا چاہے تو ان کی سماعت و بصارت کو بھی ختم کرسکتا ہے کہ وہ ہر شے پر قدرت و اختیار رکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@xxviii{اے انسانو! پروردگار کی عبادت کرو جس نے تمہیں بھی پیدا کیا ہے اور تم سے پہلے والوں کو بھی خلق کیاہے. شاید کہ تم اسی طرح متقی اور پرہیزگار بن جاؤ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@xxix{اس پروردگار نے تمہارے لئے زمین کا فرش اور آسمان کا شامیانہ بنایا ہے اور پھر آسمان سے پانی برسا کر تمہاری روزی کے لئے زمین سے پھل نکالے ہیں لہذا اس کے لئے جان بوجھ کر کسی کو ہمسر اور مثل نہ بناؤ\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@xxx{اگر تمہیں اس کلام کے بارے میں کوئی شک ہے جسے ہم نے اپنے بندے پر نازل کیا ہے تو اس کا جیسا ایک ہی سورہ لے آؤ اور اللہ کے علاوہ جتنے تمہارے مددگار ہیںسب کو بلالو اگر تم اپنے دعوے اور خیال میںسچّے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@xxxi{اور اگر تم ایسا نہ کرسکے اور یقینا نہ کرسکوگے تو اس آگ سے ڈرو جس کا ایندھن انسان اور پتھر ہیں اور جسے کافرین کے لئے مہیا کیا گیا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@xxxii{پیغمبر آپ ایمان اور عمل صالح والوں کو بشارت دے دیں کہ ان کے لئے ایسے باغات ہیں جن کے نیچے نہریں جاری ہیں. انہیں جب بھی وہاںکوئی پھل دیا جائے گا تو وہ یہی کہیں گے کہ یہ تو ہمیں پہلے مل چکا ہے. حالانکہ وہ صرف اس کے مشابہ ہوگا اور ان کے لئے وہاں پاکیزہ بیویاں بھی ہوں گی اور انہیں اس میں ہمیشہ رہنا بھی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@xxxiii{اللہ اس بات میں کوئی شرم نہیں محسوس کرتا کہ وہ مچھر یا اس سے بھی کمتر کی مثال بیان کرے. اب جو صاحبانِ ایمان ہیں وہ جانتے ہیں کہ یہ سب پروردگار کی طرف سے بر حق ہے اور جنہوں نے کفر اختیار کیا ہے وہ یہی کہتے ہیں کہ آخر ان مثالوں سے خدا کا مقصد کیا ہے. خدا اسی طرح بہت سے لوگوں کو گمراہی میں چھوڑ دیتا ہے اور بہت سوں کو ہدایت دے دیتا ہے اور گمراہی صرف انہیں کا حصّہ ہے جو فاسق ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@xxxiv{جو خدا کے ساتھ مضبوط عہد کرنے کے بعد بھی اسے توڑ دیتے ہیں اور جسے خدا نے جوڑنے کا حکم دیا ہے اسے کاٹ دیتے ہیں اور زمین میں فساد برپا کرتے ہیں یہی وہ لوگ ہیں جو حقیقتا خسارہ والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@xxxv{آخر تم لوگ کس طرح کفر اختیار کرتے ہو جب کہ تم بے جان تھے اور خدا نے تمہیں زندگی دی ہے اور پھرموت بھی دے گا اور پھر زندہ بھی کرے گا اور پھر اس کی بارگاہ میں پلٹا کر لے جائے جاؤگے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@xxxvi{وہ خدا وہ ہے جس نے زمین کے تمام ذخیروں کو تم ہی لوگوں کے لئے پیدا کیا ہے. اس کے بعد اس نے آسمان کا رخ کیا تو سات مستحکم آسمان بنادیئے اور وہ ہر شے کا جاننے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@xxxvii{اے رسول. اس وقت کو یاد کرو جب تمہارے پروردگار نے ملائکہ سے کہا کہ میں زمین میں اپنا خلیفہ بنانے والا ہوں اور انہوں نے کہا کہ کیا اسے بنائے گاجو زمین میں فساد برپا کرے اور خونریزی کرے جب کہ ہم تیری تسبیح اور تقدیس کرتے ہیں توارشاد ہوا کہ میں وہ جانتا ہوں جو تم نہیں جانتے ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@xxxviii{اور خدا نے آدم علیھ السّلام کو تمام اسمائ کی تعلیم دی اور پھر ان سب کو ملائکہ کے سامنے پیش کرکے فرمایا کہ ذرا تم ان سب کے نام تو بتاؤ اگر تم اپنے خیالِ استحقاق میں سچّے ہو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@xxxix{ملائکہ نے عرض کی کہ ہم تو اتنا ہی جانتے ہیں جتنا تونے بتایا ہے کہ تو صاحبِ علم بھی ہے اور صاحبِ حکمت بھی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@xl{ارشاد ہوا کہ آدم علیھ السّلام اب تم انہیں باخبر کردو. تو جب آدم علیھ السّلام نے باخبر کردیا تو خدا نے فرمایا کہمیں نے تم سے نہ کہا تھا کہ میں آسمان و زمین کے غیب کو جانتا ہوں اور جو کچھ تم ظاہر کرتے ہو یا چھپاتے ہو سب کو جانتا ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@xli{اور یاد کرو وہ موقع جب ہم نے ملائکہ سے کہا کہ آدم علیھ السّلام کے لئے سجدہ کرو تو ابلیس کے علاوہ سب نے سجدہ کرلیا. اس نے انکار اور غرور سے کام لیا اور کافرین میں ہوگیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@xlii{اور ہم نے کہا کہ اے آدم علیھ السّلام! اب تم اپنی زوجہ کے ساتھ جنّت میں ساکن ہوجاؤ اور جہاں چاہو آرام سے کھاؤ صرف اس درخت کے قریب نہ جانا کہ اپنے اوپر ظلم کرنے والوں میں سے ہوجاؤگے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@xliii{تب شیطان نے انہیں فریب دینے کی کوشش کی اور انہیں ان نعمتوں سے باہر نکال لیا اور ہم نے کہا کہ اب تم سب زمین پر اترجاؤ وہاں ایک دوسرے کی دشمنی ہوگی اور وہیں تمہارا مرکز ہوگا اور ایک خاص وقت تک کے لئے عیش زندگانی رہےگی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@xliv{پھر آدم علیھ السّلام نے پروردگار سے کلمات کی تعلیم حاصل کی اور ان کی برکت سے خدا نے ان کی توبہ قبول کرلی کہ وہ توبہ قبول کرنے والا اور مہربان ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@xlv{اور ہم نے یہ بھی کہا کہ یہاں سے اترپڑو پھر اگر ہماری طرف سے ہدایت آجائے تو جو بھی اس کا اتباع کرلے گا اس کے لئے نہ کوئی خوف ہوگا نہ حزن\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@xlvi{جو لوگ کافر ہوگئے اور انہوں نے ہماری نشانیوں کو جھٹلا دیا وہ جہنمّی ہیں اور ہمیشہ وہیں پڑے رہیں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@xlvii{اے بنی اسرائیل ہماری نعمتوں کو یاد کرو جو ہم نے تم پر نازل کی ہیں اور ہمارے عہد کو پورا کرو ہم تمہارے عہد کو پورا کریں گے اور ہم سے ڈرتے رہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@xlviii{ہم نے جو قرآن تمہاری توریت کی تصدیق کے لئے بھیجا ہے اس پر ایمان لے آؤ اور سب سے پہلے کافر نہ بن جاؤ ہماری آیتوں کو معمولی قیمت پر نہ بیچو اور ہم سے ڈرتے رہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@xlix{حقکو باطل سے مخلوط نہ کرو اور جان بوجھ کر حق کی پردہ پوشی نہ کرو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@l{نماز قائم کرو.زکوٰ ِ ادا کرو اور رکوع کرنے والوں کے ساتھ رکوع کرو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@li{کیا تم لوگوں کو نیکیوں کا حکم دیتے ہو اور خود اپنے کو بھول جاتے ہو جب کہ کتاب خدا کی تلاوت بھی کرتے ہو . کیا تمہارے پاس عقل نہیں ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@lii{صبر او ر نماز کے ذریعہ مدد مانگو. نماز بہت مشکل کام ہے مگر ان لوگوں کے لئے جو خشوع و خضوع والے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@liii{اور جنہیں یہ خیال ہے کہ انہیں اللہ سے ملاقات کرنا ہے اور اس کی بارگاہ میں واپس جانا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@liv{اے بنی اسرائیل! ہماری ان نعمتوں کویاد کرو جو ہم نے تمہیں عنایت کی ہیں اور ہم نے تمہیں عالمین سے بہتر بنایا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@lv{اس دن سے ڈرو جس دن کوئی کسی کابدل نہ بن سکے گا اور کسی کی سفارش قبول نہ ہوگی. نہ کوئی معاوضہ لیا جائے گا اور نہ کسی کی مدد کی جائے گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@lvi{اور جب ہم نے تم کوفرعون والوں سے بچالیا جو تمہیں بدترین دکھ دے رہے تھےً تمہارے بچوں کو قتل کررہے تھے اور عورتوں کو زندہ رکھتے تھے اور اس میں تمہارے لئے بہت بڑا امتحان تھا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@lvii{ہمارا یہ احسان بھی یادکرو کہ ہم نے دریا کو شگافتہ کرکے تمہیں بچالیا اور فرعون والوں کو تمہاری نگاہوں کے سامنے ڈبو دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@lviii{اور ہم نے موسٰی علیھ السّلام سے چالیس راتوں کا وعدہ لیا تو تم نے ان کے بعد گو سالہ تیار کرلیا کہ تم بڑے ظالم ہو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@lix{پھر ہم نے تمہیں معاف کردیا کہ شاید شکر گزار بن جاؤ\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@lx{اور ہم نے موسٰی علیھ السّلام کو کتاب اور حق و باطل کو جدا کرنے والا قانون دیا کہ شاید تم ہدایت یافتہ بن جاؤ\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@lxi{اور وہ وقت بھی یاد کرو جب موسٰی علیھ السّلام نے اپنی قوم سے کہا کہ تم نے گو سالہ بنا کر اپنے اوپر ظلم کیا ہے. اب تم خالق کی بارگاہ میں توبہ کرو اور اپنے نفسوں کو قتل کر ڈالو کہ یہی تمہارے حق میں خیر ہے. پھر خدا نے تمہاری توبہ قبول کرلی کہ وہ بڑا توبہ قبول کرنے والا مہربان ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@lxii{اور وہ وقت بھی یاد کرو جب تم نے موسٰی علیھ السّلام سے کہا کہ ہم اس وقت تک ایمان نہ لائیں گے جب تک خدا کو اعلانیہ نہ دیکھ لیں جس کے بعد بجلی نے تم کو لے ڈالا اور تم دیکھتے ہی رہ گئے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@lxiii{پھر ہم نے تمہیں موت کے بعد زندہ کردیا کہ شاید اب شکر گزار بن جاؤ\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@lxiv{اور ہم نے تمہارے سروں پر ابر کا سایہ کیا. تم پر من و سلٰوی نازل کیا کہ پاکیزہ رزق اطمینان سے کھاؤ. ان لوگوں نے ہمارا کچھ نہیں بگاڑا بلکہ خود اپنے نفس پر ظلم کیا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@lxv{اوروہ وقت بھی یاد کروجب ہم نے کہا کہ اس قریہ میں داخل ہوجاؤ اور جہاں چاہو اطمینان سے کھاؤ اور دروازہ سے سجدہ کرتے ہوئے اور حطکہتے ہوئے داخل ہو کہ ہم تمہاری خطائیں معاف کردیں گے اور ہم نیک عمل والوں کی جزا میں اضافہ بھی کردیتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@lxvi{مگر ظالموں نے جو بات ان سے کہی گئی تھی اسے بدل دیا تو ہم نے ان ظالموں پر ان کی نافرمانی کی بنا ئ پر آسمان سے عذاب نازل کر دیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@lxvii{اور اس موقع کو یاد کرو جب موسٰی علیھ السّلام نے اپنی قوم کے لئے پانی کا مطالبہ کیا تو ہم نے کہا کہ اپنا اعصا پتھر پر مارو جس کے نتیجہ میں بارہ چشمے جاری ہوگئے اور سب نے اپنا اپنا گھاٹ پہچان لیا. اب ہم نے کہا کہ من وسلوٰی کھاؤ اور چشمہ کا پانی پیو اور روئے زمینمیں فساد نہ پھیلاؤ\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@lxviii{اور وہ وقت بھی یادکرو جب تم نے موسٰی علیھ السّلام سے کہا کہ ہم ایک قسم کے کھانے پر صبر نہیں کرسکتے. آپ پروردگار سے دعا کیجئے کہ ہمارے لئے زمین سے سبزیً ککڑیً لہسنً مسوراور پیاز وغیرہ پیدا کرے. موسٰی علیھ السّلام نے تمہیں سمجھایا کہ کیا بہترین نعمتوں کے بدلے معمولی نعمت لینا چاہتے ہو تو جاؤ کسی شہر میں اتر پڑو وہاں یہ سب کچھ مل جائے گا. اب ان پر ذلّت اور محتاجی کی مار پڑ گئی اور وہ غضب الٰہی میں گرفتار ہوگئے. یہ سب اس لئے ہوا کہ یہ لوگ آیات الٰہی کا انکار کرتے تھے اور ناحق انبیائ خدا کو قتل کردیا کرتے تھے. اس لئے کہ یہ سب نافرمان تھے اور ظلم کیا کرتے تھے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@lxix{جو لوگ بظاہر ایمان لائے یا یہودی ً نصاریٰ اور ستارہ پرست ہیں ان میں سے جو واقعی اللہ اور آخرت پر ایمان لائے گا اور نیک عمل کرے گا اس کے لئے پروردگار کے یہاں اجر و ثواب ہے اور کوئی حزن و خوف نہیں ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@lxx{اور اس وقت کو یاد کرو جب ہم نے تم سے توریت پر عمل کرنے کا عہد لیا اور تمہارے سروں پر کوہ طور کو لٹکا دیا کہ اب توریت کو مضبوطی سے پکڑو اور جو کچھ اس میں ہے اسے یاد رکھو شاید اس طرح پرہیز گار بن جاؤ\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@lxxi{پھر تم لوگوں نے انحراف کیا کہ اگر فضل هخدا اور رحمت الٰہی شامل حال نہ ہوتی تو تم خسارہ والوں میں سے ہوجاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@lxxii{تم ان لوگوں کو بھی جانتے ہو جنہوں نے شنبہ کے معاملہ میں زیادتی سے کام لیا تو ہم نے حکم دے دیا کہ اب ذلّت کے ساتھ بندر بن جائیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@lxxiii{اور ہم نے اس جنسی تبدیلی کو دیکھنے والوں او ر بعد والوں کے لئے عبرت اور صاحبانِ تقویٰ کے لئے نصیحت بنا دیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@lxxiv{اور وہ موقع بھی یاد کروجب موسٰی علیھ السّلام نے قوم سے کہا کہ خدا کا حکم ہے کہ ایک گائے ذبح کرو تو ان لوگوں نے کہا کہ آپ ہمیں مذاق بنا رہے ہیں. فرمایا پناہ بخدا کہ میں جاہلوں میں سے ہوجاؤں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@lxxv{ان لوگوں نے کہا کہ اچھا خدا سے دعا کیجئے کہ ہمیں اس کی حقیقت بتائے. انہوں نے کہا کہ ایسی گائے چاہئے جو نہ بوڑھی ہو نہ بچہ. درمیانی قسم کی ہو. اب حکم خدا پر عمل کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@lxxvi{ان لوگوں نے کہا یہ بھی پوچھئے کہ رنگ کیا ہوگا. کہا کہ حکم خدا ہے کہ زرد بھڑک دار رنگ کی ہو جو دیکھنے میں بھلی معلوم ہو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@lxxvii{ان لوگوں نے کہا کہ ایسی تو بہت سی گائیں ہیں اب کون سی ذبح کریں اسے بیان کیاجائے ہم انشائ اللرُ تلاش کرلیں گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@lxxviii{حکم ہوا کہ ایسے گائے جو کاروباری نہ ہونہ زمین جوتے نہ کھیت سینچے ایسی صاف ستھری کہ اس میں کوئی دھبّہ بھی نہ ہو. ان لوگوں نے کہا کہ اب آپ نے ٹھیک بیان کیا ہے. اس کے بعد ان لوگوں نے ذبح کردیا حالانکہ وہ ایسا کرنے والے نہیں تھے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@lxxix{اور جب تم نے ایک شخص کو قتل کردیا اور اس کے قاتل کے بارے میں جھگڑا کرنے لگے جبکہ خدا اس راز کا واضح کرنے والا ہے جسے تم چھپا رہے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@lxxx{تو ہم نے کہا کہ مقتول کو گائے کے ٹکڑے سے مس کردو خدا اسی طرح مفِدوں کو زندہ کرتا ہے اور تمہیں اپنی نشانیاں دکھلاتا ہے کہ شاید تمہیں عقل آجائے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@lxxxi{پھر تمہارے دل سخت ہوگئے جیسے پتھر یا اس سے بھی کچھ زیادہ سخت کہ پتھروں میں سے تو بعض سے نہریں بھی جاری ہوجاتی ہیںاور بعض شگافتہ ہوجاتے ہیں تو ان سے پانی نکل آتا ہے اور بعض خورِ خدا سے گر پڑتے ہیں. لیکن اللہ تمہارے اعمال سے غافل نہیں ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@lxxxii{مسلمانو! کیا تمہیں امید ہے کہ یہ یہودی تمہاری طرح ایمان لے آئیں گے جبکہ ان کے اسلاف کا ایک گروہ کلاهِ خدا کو سن کر تحریف کردیتا تھا حالانکہ سب سمجھتے بھی تھے اور جانتے بھی تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@lxxxiii{یہ یہودی ایمان والوںسے ملتے ہیں تو کہتے ہیں کہ ہم بھی ایمان لے آئے اور آپس میں ایک دوسرے ملتے ہیں توکہتے ہیں کہ کیا تم مسلمانوںکو توریت کے مطالب بتادوگے کہ وہ اپنے نبی کے اوصاف سے تمہارے اوپر استدلال کریں کیا تمہیں عقل نہیں ہے کہ ایسی حماقت کروگے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@lxxxiv{کیا تمہیں نہیں معلوم کہ خدا سب کچھ جانتا ہے جس کا یہ اظہار کررہے ہیں اورجس کی یہ پردہ پوشی کررہے ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@lxxxv{ان یہودیوں میں کچھ ایسے جاہل بھی ہیں جو توریت کو یاد کئے ہوئے ہیں اور اس کے بارے میں سوائے امیدوں کے کچھ نہیں جانتے ہیں حالانکہ یہ ا ن کا فقط خیالِ خام ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@lxxxvi{وائے ہو ان لوگوںپر جو اپنے ہاتھ سے کتاب لکھ کر یہ کہتے ہیں کہ یہ خدا کی طرف سے ہے تاکہ اسے تھوڑے دام میں بیچ لیں. ان کے لئے اس تحریر پر بھی عذاب ہے اور اس کی کمائی پر بھی\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@lxxxvii{یہ کہتے ہیں کہ ہمیں آتش جہّنم چند دن کے علاوہ چھو بھی نہیں سکتی. ان سے پوچھئے کہ کیا تم نے اللہ سے کوئی عہد لے لیا ہے جس کی وہ مخالفت نہیں کرسکتا یا اس کے خلاف جہالت کی باتیں کررہے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@lxxxviii{یقینا جس نے کوئی برائی حاصل کی اور اس کی غلطی نے اسے گھیر لیا وہ لوگ اہلِ جہّنم ہیں اور وہیں ہمیشہ رہنے والے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@lxxxix{اور جو ایمان لائے اور انہوں نے نیک عمل کئے وہ اہل جنّت ہیں اور وہیں ہمیشہ رہنے والے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@xc{اس وقت کو یاد کرو جب ہم نے بنی اسرائیل سے عہد لیا کہ خبردار خدا کے علاوہ کسی کی عبادت نہ کرنا اور ماں باپً قرابتداروںً یتیموں اور مسکینوں کے ساتھ اچھا برتاؤ کرنا. لوگوں سے اچھی باتیں کرناً نماز قائم کرناًزکوِٰ ادا کرنا لیکن اس کے بعد تم میں سے چند کے علاوہ سب منحرف ہوگئے اور تم لوگ تو بس اعراض کرنے والے ہی ہو\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@xci{اور ہم نے تم سے عہد لیا کہ آپس میں ایک دوسرے کا خون نہ بہانا اور کسی کواپنے وطن سے نکال باہر نہ کرنا اور تم نے اس کا اقرار کیا اور تم خود ہی اس کے گواہ بھی ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@xcii{لیکن اس کے بعد تم نے قتل و خون شروع کردیا. لوگوں کو علاقہ سے باہر نکالنے لگے اور گناہ وتعدی میں ظالموںکی مدد کرنے لگے حالانکہ کوئی قیدی بن کر آتا ہے تو فدیہ دے کر آزاد بھی کرالیتے ہو جبکہ شروع سے ان کا نکالنا ہی حرام تھا. کیا تم کتاب کے ایک حصّہ پر ایمان رکھتے ہو اور ایک کا انکار کردیتے ہو. ایسا کرنے والوں کی کیا سزاہے سوائے اس کے کہ زندگانی دنیا میں ذلیل ہوں اور قیامت کے دن سخت ترین عذاب کی طرف پلٹاد یئے جائیں گے . اور اللہ تمہارے کرتوت سے بے خبر نہیں ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@xciii{یہ وہ لوگ ہیں جنہوں نے آخر کو دے کر دنیا خریدلی ہے اب نہ ان کے عذاب میں تخفیف ہوگی اور نہ ان کی مدد کی جائے گی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@xciv{ہم نے موسٰی علیھ السّلام کو کتاب دی ان کے پیچھے رسولوںکا سلسلہ قائم کیا. عیسٰی علیھ السّلام بن مریم کو واضح معجزات عطا کئےً روح القدس سے ان کی تائید کرادی لیکن کیا تمہارا مستقل طریقہ یہی ہے کہ جب کوئی رسول علیھ السّلام تمہاری خواہش کے خلاف کوئی پیغام لے کر آتا ہے تو اکڑ جاتے ہو اور ایک جماعت کو جھٹلا دیتے ہو اور ایک کو قتل کردیتے ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@xcv{اور یہ لوگ کہتے ہیں کہ ہمارے دلوں پر پردے پڑے ہوئے ہیں ہماری کچھ سمجھ میں نہیں آتا بے شک ان کے کفر کی بنا پر ان پر خدا کی مار ہے اور یہ بہت کم ایمان لے آئیں گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@xcvi{اور جب ان کے پاس خدا کی طرف سے کتاب آئی ہے جو ان کی توریت وغیرہ کی تصدیق بھی کرنے والی ہے اور اس کے پہلے وہ دشمنوںکے مقابلہ میں اسی کے ذریعہ طلب فتح بھی کرتے تھے لیکن اس کے آتے ہی منکر ہوگئے حالانکہ اسے پہچانتے بھی تھے تو اب کافروں پر خدا کی لعنت ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@xcvii{ان لوگوں نے اپنے نفس کا کتنا برا سودا کیا ہے کہ زبردستی خدا کے نازل کئے کا انکار کر بیٹھے اس ضد میں کہ خدا اپنے فضل و کر م سے اپنے جس بندے پر جو چاہے نازل کردیتا ہے. اب یہ غضب بالائے غضب کے حقدار ہیں اور ان کے لئے رسوا کن عذاب بھی ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@xcviii{جب ان سے کہا جاتا ہے کہ خدا کے نازل کئے ہوئے پر ایمان لے آؤ تو کہتے ہیں کہ ہم صرف اس پر ایمان لے آئیں گے جو ہم پر نازل ہوا ہے اور اس کے علاوہ سب کا انکار کردیتے ہیں. اگرچہ وہ بھی حق ہے اور ان کے پاس جو کچھ ہے اس کی تصدیق کرنے والا بھی ہے. اب آپ ان سے کہئے کہ اگر تم مومن ہو تو اس سے پہلے انبیائ خدا کو قتل کیوں کرتے تھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@xcix{یقینا موسٰی علیھ السّلام تمہارے پاس واضح نشانیاں لے کر آئے لیکن تم نے ان کے بعد گو سالہ کو اختیار کرلیا اور تم واقعی ظالم ہو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@c{اور اس وقت کو یاد کرو جب ہم نے تم سے توریت پر عمل کرنے کا عہد لیا اور تمہارے سروں پر کوسِ طور کو معلق کردیا کہ توریت کو مضبوطی سئے پکڑلو تو انہوں نے ڈر کے مارے فورا اقرار کرلیا کہ ہم نے سن تو لیا لیکن پھر نافرمانی بھی کریں گے کہ ان کے دلوں میں گو سالہ کی محبت گھول کر پلادی گئی ہے. پیغمبر ان سے کہہ دو کہ اگر تم ایماندار ہو تو تمہارا ایمان بہت برے احکام دیتا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ci{ان سے کہو کہ اگر سارے انسانوں میںدا» آخرت فقط تمہارے لئے ہے اور تم اپنے دعوے میں سچّے ہو تو موت کی تمّنا کرو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@cii{اور یہ اپنے پچھلے اعمال کی بنا پر ہرگز موت کی تمّنا نہیں کریں گے کہ خدا ظالموں کے حالات سے خوب واقف ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ciii{اے رسول آپ دیکھیں گے کہ یہ زندگی کے سب سے زیادہ حریص ہیں اور بعض مشرکین تو یہ چاہتے ہیں کہ انہیں ہزار برس کی عمر دے دی جائے جبکہ یہ ہزار برس بھی زندہ رہیں تو طول هحیات انہیںعذابِ الٰہی سے نہیں بچا سکتا. اللہ ان کے اعمال کو خوب دیکھ رہا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@civ{اے رسول کہہ دیجئے کہ جو شخص بھی جبریل کا دشمن ہے اسے معلوم ہونا چاہئے کہ جبریل نے آپ کے دل پر قرآن حکم خدا سے اتارا ہے جو سابق کتابوں کی تصدیق کرنے والاً ہدایت اور صاحبانِ ایمان کے لئے بشارت ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cv{جو بھی اللہً ملائکہً مرسلین اور جبریل و میکائیکل کا دشمن ہوگا اسے معلوم رہے کہ خدا بھی تمام کافروں کا دشمن ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cvi{ہم نے آپ کی طرف روشن نشانیاں نازل کی ہیں اور ان کا انکار فاسقوں کے سوا کوئی نہ کرے گا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cvii{ان کا حال یہ ہے کہ جب بھی انہوں نے کوئی عہد کیا تو ایک فریق نے ضرور توڑ دیا بلکہ ان کی اکثریت بے ایمان ہی ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cviii{اور جب ان کے پاس خدا کی طرف سے سابق کی کتابوں کی تصدیق کرنے والا رسول آیا تو اہلِ کتاب کی ایک جماعت نے کتابِ خدا کو پبُ پشت ڈال دیا جیسے وہ اسے جانتے ہی نہ ہوں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cix{اور ان باتوں کا اتباع شروع کردیا جو شیاطین سلیمان علیھ السّلامکی سلطنت میں جپا کرتے تھے حالانکہ سلیمان علیھ السّلام کافر نہیں تھے. کافر یہ شیاطین تھے جو لوگوں کو جادو کی تعلیم دیتے تھے اور پھر جو کچھ دو فرشتوں ہاروت ماروت پر بابل میں نازل ہوا ہے. وہ اس کی بھی تعلیم اس وقت تک نہیںدیتے تھے جب تک یہ کہہ نہیں دیتے تھے کہ ہم ذریعہ امتحان ہیں. خبردار تم کافر نہ ہوجانا .لیکن وہ لوگ ان سے وہ باتیں سیکھتے تھے جس سے میاں بیوی کے درمیان جھگڑاکرادیں حالانکہ اذنِ خدا کے بغیر وہ کسی کو نقصان نہیں پہنچا سکتے. یہ ان سے وہ سب کچھ سیکھتے تھے جو ان کے لئے مضر تھا اور اس کا کوئی فائدہ نہیںتھا یہ خوب جانتے تھے کہ جو بھی ان چیزوں کو خریدے گا اس کا آخرت میں کوئی حصہّ نہ ہوگا. انہوں نے اپنے نفس کا بہت برا سو دا کیا ہے اگر یہ کچھ جانتے اور سمجھتے ہوں\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cx{اگر یہ لوگ ایمان لے آتے اور متقی بن جاتے تو خدائی ثواب بہت بہتر تھا. اگر ان کی سمجھ میں آجاتا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cxi{ایمان والو! راعنا (ہماری رعایت کرو) نہ کہا کرو «انظرنامِ کہا کرو اور غور سے سنا کرو اور یاد رکھو کہ کافرین کے لئے بڑا دردناک عذاب ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cxii{کافر اہلِ کتاب یہود و نصارٰی اور عام مشرکین یہ نہیں چاہتے کہ تمہارے او پر پروردگار کی طرف سے کوئی خیر نازل ہو حالانکہ اللہ جسے چاہتاہے اپنی رحمت کے لئے مخصوص کرلیتا ہے اور اللہ بڑے فضل و کرم کا مالک ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cxiii{اور اے رسول ہم جب بھی کسی آیت کو منسوخ کرتے ہیں یا دلوں سے محو کردیتے ہیں تو اس سے بہتر یا اس کی جیسی آیت ضرور لے آتے ہیں. کیا تم نہیں جانتے کہ اللہ ہر شے پر قادر ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cxiv{کیا تم نہیں جانتے کہ آسمان و زمین کی حکومت صرف اللہ کے لئے ہے اور اس کے علاوہ کوئی سرپرست ہے نہ مددگار\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cxv{اے لوگو! کیا تم یہ چاہتے ہو کہ اپنے رسول سے ویسا ہی مطالبہ کرو جیسا کہ موسٰی علیھ السّلامسے کیاگیا تھا تویاد رکھو کہ جس نے ایمان کو کفر سے بدل لیا وہ بدترین راستہ پر گمراہ ہوگیا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cxvi{بہت سے اہلِ کتاب یہ چاہتے ہیں کہ تمہیں بھی ایمان کے بعد کافر بنالیں وہ تم سے حسد رکھتے ہیں ورنہ حق ان پر بالکل واضح ہے تو اب تم انہیں معاف کردو اور ان سے درگزر کرو یہاں تک کہ خدا اپنا کوئی حکم بھیج دے اور اللہ ہر شے پر قادر ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cxvii{اور تم نماز قائم کرو اور زکوِٰ ادا کرو کہ جو کچھ اپنے واسطے پہلے بھیج دو گے سب خدا کے یہاں مل جائے گا. خدا تمہارے اعمال کو خوب دیکھنے والا ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cxviii{یہ یہودی کہتے ہیں کہ جنّت میں یہودیوں اور عیسائیوں کے علاوہ کوئی داخل نہ ہوگا. یہ صرف ان کی امیدیں ہیں. ان سے کہہ دیجئے کہ اگر تم سچّے ہو تو کوئی دلیل لے آؤ\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cxix{نہیں جو شخص اپنا رخ خدا کی طرف کردے گااور نیک عمل کرے گا اس کے لئے پروردگار کے یہاں اجر ہے اور نہ کوئی خوف ہے نہ حزن\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cxx{اور یہودی کہتے ہیں کہ نصاریٰ کا مذہب کچھ نہیں ہے اور نصاریٰ کہتے ہیں کہ یہودیوں کی کوئی بنیاد نہیں ہے حالانکہ دونوں ہی کتاب الٰہی کی تلاوت کرتے ہیں اور اس کے پہلے جاہل مشرکین عرب بھی یہی کہا کرتے تھے. خدا ان سب کے درمیان روزِ قیامت فیصلہ کرنے والا ہے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cxxi{اور اس سے بڑھ کر ظالم کون ہوگا جو مساجد خدا میں اس کا نام لینے سے منع کرے اور ان کی بربادی کی کوشش کرے. ان لوگوں کا حصّہ صرف یہ ہے کہ مساجد میں خوفزدہ ہوکر داخل ہوں اور ان کے لئے دنیا میں رسوائی ہے اور آخرت میں عذاب عظیم\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cxxii{اور اللہ کے لئے مشرق بھی ہے اور مغرب بھی لہٰذا تم جس جگہ بھی قبلہ کا رخ کرلو گے سمجھو وہیں خدا موجود ہے وہ صاحبِ وسعت بھی ہے اور صاحبِ علم بھی ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cxxiii{اور یہودی کہتے ہیں کہ خدا کے اولاد بھی ہے حالانکہ وہ پاک و بے نیاز ہے. زمین و آسمان میں جو کچھ بھی ہے سب اسی کا ہے اور سب اسی کے فرمانبردار ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cxxiv{وہ زمین و آسمان کا موجد ہے اور جب کسی امر کا فیصلہ کرلیتا ہے تو صرف کن کہتا ہے اور وہ چیز ہوجاتی ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cxxv{یہ جاہل مشرکین کہتے ہیں کہ خدا ہم سے کلام کیوں نہیں کرتا اور ہم پر آیت کیوں نازل نہیں کرتا. ان کے پہلے والے بھی ایسی ہی جہالت کی باتیں کرچکے ہیں. ان سب کے دل ملتے جلتے ہیں اور ہم نے تو اہلِ یقین کے لئے آیات کو واضح کردیا ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cxxvi{اے پیغمبر ہم نے آپ کو حق کے ساتھ بشارت دینے والا اور ڈرانے والا بناکر بھیجا ہے اور آپ سے اہلِ جہنّم کے بارے میں کوئی سوال نہ کیا جائے گا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cxxvii{یہود و نصاریٰ آپ سے اس وقت تک راضی نہ ہوں گے جب تک آپ ان کی ملّت کی پیروی نہ کرلیں تو آپ کہہ دیجئے کہ ہدایت صرف ہدایت هپروردگار ہے--- اور اگر آپ علم کے آنے کے بعد ان کی خواہشات کی پیروی کریں گے تو پھر خدا کے عذاب سے بچانے والا نہ کوئی سرپرست ہوگا نہ مددگار\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cxxviii{اور جن لوگوں کو ہم نے قرآن دیا ہے وہ اس کی باقاعدہ تلاوت کرتے ہیں اور ان ہی کا اس پر ایمان بھی ہے اور جو اس کا انکار کرے گااس کاشمار خسارہ والوں میں ہوگا\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cxxix{اے بنی اسرائیل ان نعمتوں کو یاد کرو جو ہم نے تمہیں عنایت کی ہیں اور جن کے طفیل تمہیں سارے عالم سے بہتر بنا دیا ہے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cxxx{اور اس دن سے ڈرو جس دن کوئی کسی کا فدیہ نہ ہوسکے گا اور نہ کوئی معاوضہ کام آئے گا نہ کوئی سفارش ہوگی اور نہ کوئی مدد کی جاسکے گی\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cxxxi{اور اس وقت کو یاد کرو جب خدانے چند کلمات کے ذریعے ابراہیم علیھ السّلام کا امتحان لیا اور انہوں نے پورا کردیا تو اس نے کہا کہ ہم تم کو لوگوں کا امام اور قائد بنا رہے ہیں. انہوں نے عرض کی کہ میری ذریت? ارشاد ہوا کہ یہ عہدئہ امامت ظالمین تک نہیں جائے گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cxxxii{اور اس وقت کو یاد کرو جب ہم نے خانہ کعبہ کو ثواب اور امن کی جگہ بنایا اور حکم دے دیا کہ مقام ابراہیم کو مصّلی بناؤ اور ابراہیم علیھ السّلام و اسماعیل علیھ السّلام سے عہد لیا کہ ہمارے گھر کو طواف اور اعتکاف کرنے والوںاو ر رکوع و سجدہ کرنے والوں کے لئے پاک و پاکیزہ بنائے رکھو\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cxxxiii{اور اس وقت کویاد کرو جب ابراہیم علیھ السّلام نے دعا کی کہ پروردگار اس شہر کو امن کاشہر قرار دے دے اور اس کے ان اہلِ شہر کو جو اللہ اور آخرت پر ایمان رکھتے ہوں پھلوں کا رزق عطا فرما. ارشاد ہوا کہ پھر جو کافر ہوجائیں گے انہیں دنیا میں تھوڑی نعمتیں دے کر آخرت میں عذابِ جہّنم میں زبردستی ڈھکیل دیا جائے گا جو بدترین انجام ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cxxxiv{اور اس وقت کو یاد کرو جب ابراہیم علیھ السّلامو اسماعیل علیھ السّلامخانہ کعبہ کی دیواروں کو بلند کر رہے تھے اوردل میں یہ دعا تھی کہ پروردگار ہماری محنت کو قبول فرمالے کہ تو بہترین سننے والا اورجاننے والا ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cxxxv{پروردگار ہم دنوںکو اپنا مسلمان او ر فرمانبردار قرار دے دے اور ہماری اولاد میں بھی ایک فرمانبردار امت پیدا کر. ہمیں ہمارے مناسک دکھلا دے اورہماری توبہ قبول فرما کہ تو بہترین توبہ قبول کرنے والا مہربان ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cxxxvi{پروردگار ان کے درمیان ایک رسول کو مبعوث فرما جو ان کے سامنے تیری آیتوں کی تلاوت کرے. انہیں کتاب و حکمت کی تعلیم دے اور انکے نفوس کو پاکیزہ بنائے. بے شک تو صاحبِ عزّت اور صاحبِ حکمت ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cxxxvii{اور کون ہے جو ملّاُ ابراہیم علیھ السّلام سے اعراض کرے مگر یہ کہ اپنے ہی کوبے وقوف بنائے . اور ہم نے انہیں دنیا میں منتخب قرار دیا ہے اور وہ آخرت میں نیک کردار لوگوں میں ہیں\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cxxxviii{جب ان سے ان کے پروردگار نے کہا کہ اپنے کو میرے حوالے کردو تو انہوں نے کہا کہ میں رب العالمین کے لئے سراپا تسلیم ہوں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cxxxix{اور اسی بات کی ابراہیم علیھ السّلام اور یعقوب علیھ السّلام نے اپنی اولاد کو وصیت کی کہ اے میرے فرزندوں اللہ نے تمہارے لئے دین کو منتخب کردیا ہے اب اس وقت تک دنیا سے نہ جانا جب تک واقعی مسلمان نہ ہوجاؤ\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cxl{کیا تم اس وقت تک موجود تھے جب یعقوب علیھ السّلام کا وقاُ موت آیا اور انہوں نے اپنی اولاد سے پوچھا کہ میرے بعد کس کی عبادت کرو گے تو انہوں نے کہا کہ آپ کے اور آپ کے آباؤ اجداد ابراہیم علیھ السّلام و اسماعیل علیھ السّلامو اسحاق علیھ السّلامکے پروردگار خدائے وحدہِ لاشریک کی اور ہم اسی کے مسلمان اور فرمانبردار ہیں\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cxli{یہودیو! یہ قوم تھی جو گزر گئی انہیں وہ ملے گا جو انہوں نے کمایا اور تمہیں وہ ملے گا جو تم کماؤ گے تم سے ان کے اعمال کے بارے میں سوال نہ ہوگا\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cxlii{اور یہ یہودی اور عیسائی کہتے ہیں کہ تم لوگ بھی یہودی اورعیسائی ہوجاؤ تاکہ ہدایت پا جاؤ توآپ کہہ دیں کہ صحیح راستہ باطل سے کترا کر چلنے والے ابراہیم علیھ السّلام کا راستہ ہے کہ وہ مشرکین میں نہیں تھے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cxliii{اور مسلمانو! تم ان سے کہو کہ ہم اللہ پر اور جو اس نے ہماری طرف بھیجا ہے اور جو ابراہیم علیھ السّلامً اسماعیل علیھ السّلام ً اسحاق علیھ السّلامً یعقوب علیھ السّلامً اولاد یعقوب علیھ السّلام کی طرف نازل کیا ہے اور جو موسیٰ علیھ السّلام ً عیسیٰ علیھ السّلام اور انبیائ علیھ السّلام کو پروردگار کی طرف سے دیا گیا ہے ان سب پر ایمان لے آئے ہیں. ہم پیغمبروں علیھ السّلام میں تفریق نہیں کرتے اور ہم خدا کے سچّے مسلمان ہیں\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cxliv{اب اگر یہ لوگ بھی ایسا ہی ایمان لے آئیں گے تو ہدایت یافتہ ہوجائیں گے اور اگر اعراض کریںگے تو یہ صرف عناد ہوگا اور عنقریب اللہ تمہیں ان سب کے شر سے بچا لے گا کہ وہ سننے والا بھی ہے اورجاننے والا بھی ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cxlv{رنگ تو صرف اللہ کا رنگ ہے اور اس سے بہتر کس کا رنگ ہوسکتا ہے اور ہم سب اسی کے عبادت گزار ہیں\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cxlvi{اے رسول کہہ دیجئے کہ کیا تم ہم سے اس خدا کے بارے میں جھگڑتے ہو جو ہمارا بھی پروردگار ہے اور تمہارا بھی---- تو ہمارے لئے ہمارے اعمال ہیں اور تمہارے لئے تمہارے اعمال اورہم تو صرف خدا کے مخلص بندے ہیں\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cxlvii{کیا تمہارا کہنا یہ ہے کہ ابراہیم علیھ السّلامً اسماعیل علیھ السّلامً اسحاق ً یعقوب علیھ السّلام ا ور اولادیعقوب علیھ السّلام یہودی یا نصرانی تھے تو اے رسول کہہ دیجئے کہ کیا تم خدا سے بہتر جانتے ہو .اور اس سے بڑا ظالم کون ہوگا جس کے پاس خدائی شہادت موجود ہو اور وہ پھر پردہ پوشی کرے اور اللہ تمہارے اعمال سے غافل نہیں ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cxlviii{یہ امّت گزر چکی ہے اس کا حصّہ وہ ہے جو اس نے کیا ہے اور تمہارا حصّہ وہ ہے جو تم کرو گے اور خدا تم سے ان کے اعمال کے بارے میں کوئی سوال نہیں کرے گا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cxlix{عنقریب احمق لوگ یہ کہیں گے کہ ان مسلمانوں کو اس قبلہ سے کس نے موڑ دیا ہے جس پر پہلے قائم تھے تو اے پیغمبر کہہ دیجئے کہ مشرق و مغرب سب خدا کے ہیں وہ جسے چاہتاہے صراط مستقیم کی ہدایت دے دیتا ہے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cl{اور تحویل قبلہ کی طرح ہم نے تم کو درمیانی اُمت قرار دیا ہے تاکہ تم لوگوںکے اعمال کے گواہ رہو اور پیغمبر تمہارے اعمال کے گواہ رہیں اور ہم نے پہلے قبلہ کو صرف اس لئے قبلہ بنایا تھا کہ ہم یہ دیکھیں کہ کون رسول کا اتباع کرتاہے اور کون پچھلے پاؤں پلٹ جاتا ہے. اگرچہ یہ قبلہ ان لوگوںکے علاوہ سب پر گراں ہے جن کی اللہ نے ہدایت کردی ہے اور خدا تمہارے ایمان کو ضائع نہیں کرنا چاہتا. وہ بندوں کے حال پر مہربان اور رحم کرنے والا ہے\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cli{اے رسول ہم آپ کی توجہ کو آسمان کی طرف دیکھ رہے ہیں تو ہم عنقریب آپ کو اس قبلہ کی طرف موڑ دیں گے جسے آپ پسند کرتے ہیں لہٰذا آپ اپنا رخ مسجدالحرام کی جہت کی طرف موڑ دیجئے اور جہاں بھی رہئے اسی طرف رخ کیجئے. اہلِ کتاب خوب جانتے ہیں کہ خدا کی طرف سے یہی برحق ہے اور اللہ ان لوگوں کے اعمال سے غافل نہیں ہے\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@clii{اگر آپ ان اہلِ کتاب کے پاس تمام آیتیں بھی پیش کردیں کہ یہ آپ کے قبلہ کو مان لیں تو ہرگز نہ مانیں گے اور آپ بھی ان کے قبلہ کو نہ مانیں گے اور یہ آپس میں بھی ایک دوسرے کے قبلہ کو نہیں مانتے اور علم کے آجانے کے بعد اگر آپ ان کی خواہشات کا اتباع کرلیں گے تو آپ کا شمار ظالموں میں ہوجائے گا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cliii{جن لوگوں کو ہم نے کتاب دی ہے وہ رسول کو بھی اپنی اولاد کی طرح پہچانتے ہیں. بس ان کا ایک گروہ ہے جو حق کو دیدہ و دانستہ چھپا رہا ہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cliv{اے رسول یہ حق آپ کے پروردگار کی طرف سے ہے لہٰذاآپ ان شک وشبہ کرنے والوں میں نہ ہوجائیں\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@clv{ہر ایک کے لئے ایک رخ معین ہے اور وہ اسی کی طرف منہ کرتا ہے. اب تم نیکیوں کی طرف سبقت کرو اور تم سب جہاں بھی رہوگے خدا ایک دن سب کو جمع کردے گا کہ وہ ہر شے پر قادر ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@clvi{پیغمبر آپ جہاںسے باہر نکلیں اپنا رخ مسجد الحرام کی سمت ہی رکھیں کہ یہی پروردگار کی طرف سے حق ہے--- اور اللہ تم لوگوںکے اعمال سے غافل نہیں ہے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@clvii{اور آپ جہاں سے بھی نکلیں اپنا رخ خانئہ کعبہ کی طرف رکھیں اور پھر تم سب جہاں رہو تم سب بھی اپنا رخ ادھر ہی رکھو تاکہ لوگوں کے لئے تمہارے اوپر کوئی حجت نہ رہ جائے سوائے ان لوگوں کے کہ جو ظالم ہیں تو ان کا خوف نہ کرو بلکہ اللہ سے ڈرو کہ ہم تم پر اپنی نعمت تمام کردینا چاہتے ہیں کہ شاید تم ہدایت یافتہ ہوجاؤ\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@clviii{جس طرح ہم نے تمہارے درمیان تم ہی میں سے ایک رسول بھیجا ہے جو تم پر ہماری آیات کی تلاوت کرتاہے تمہیں پاک و پاکیزہ بنا تا ہے اور تمہیں کتاب و حکمت کی تعلیم دیتا ہے اور وہ سب کچھ بتاتاہے جو تم نہیں جانتے تھے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@clix{اب تم ہم کو یاد کرو تاکہ ہم تمہیں یاد رکھیں اور ہمارا شکریہ ادا کرو اور کفرانِ نعمت نہ کرو\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@clx{ایمان والو! صبر اور نماز کے ذریعہ مدد مانگو کہ خدا صبر کرنے والوں کے ساتھ ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@clxi{اور جو لوگ راہ هخدا میں قتل ہوجاتے ہیں انہیں مفِدہ نہ کہو بلکہ وہ زندہ ہیں لیکن تمہیں ان کی زندگی کا شعور نہیں ہے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@clxii{اور ہم یقینا تمہیں تھوڑے خوف تھوڑی بھوک اور اموالًنفوس اور ثمرات کی کمی سے آزمائیں گے اور اے پیغمبر آپ ان صبر کرنے والوں کو بشارت دے دیں\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@clxiii{جو مصیبت پڑنے کے بعد یہ کہتے ہیں کہ ہم اللہ ہی کے لئے ہیں اور اسی کی بارگاہ میں واپس جانے والے ہیں\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@clxiv{کہ ان کے لئے پروردگار کی طرف سے صلوات اور رحمت ہے اور وہی ہدایت یافتہ ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@clxv{بے شک صفا اور مروہ دونوںپہاڑیاں اللہ کی نشانیوں میں ہیںلہٰذاجو شخص بھی حج یا عمرہ کرے اس کے لئے کوئی حرج نہیں ہے کہ ان دونوں پہاڑیوںکا چکر لگائے اور جو مزید خیر کرے گا تو خدا اس کے عمل کا قدر دان اوراس سے خوب واقف ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@clxvi{جو لوگ ہمارے نازل کئے ہوئے واضح بیانات اور ہدایات کو ہمارے بیان کردینے کے بعد بھی حُھپاتے ہیں ان پر اللہ بھی لعنت کرتا ہے اور تمام لعنت کرنے والے بھی لعنت کرتے ہیں\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@clxvii{علاوہ ان لوگوں کے جو توبہ کرلیں اور اپنے کئے کی اصلاح کرلیں اور جس کو چھپایا ہے اس کو واضح کردیں تو ہم ان کی توبہ قبول کرلیتے ہیں کہ ہم بہترین توبہ قبول کرنے والے اور مہربان ہیں\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@clxviii{جو لوگ کافرہوگئے اور اسی حالاُ کفر میں مر گئے ان پر اللہ ملائکہ اور تمام انسانوں کی لعنت ہے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@clxix{وہ اسی لعنت میں ہمیشہ رہیں گے کہ نہ ان کے عذاب میں تخفیف ہوگی اور نہ انہیں مہلت دی جائے گی\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@clxx{اور تمہارا خدا بس ایک ہے. اس کے علاوہ کوئی خدا نہیں ہے وہی رحمان بھی ہے اور وہی رحیم بھی ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@clxxi{بیشک زمین و آسمان کی خلقت روز و شب کی رفت وآمد. ان کشتیوں میں جو دریاؤں میں لوگوں کے فائدہ کے لئے چلتی ہیں اور اس پانی میں جسے خدا نے آسمان سے نازل کرکے اس کے ذریعہ مفِدہ زمینوںکو زندہ کردیا ہے اور اس میں طرح طرح کے چوپائے پھیلا دیئے ہیںاور ہواؤں کے چلانے میں اور آسمان و زمین کے درمیان لَسخر کئے جانے والے بادل میں صاحبانِ عقل کے لئے اللہ کی نشانیاں پائی جاتی ہیں\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@clxxii{لوگوں میں کچھ ا یسے لوگ بھی ہیں جو اللہ کے علاوہ دوسروں کو اس کا مثل قرار دیتے ہیں اور ان سے اللہ جیسی محبت بھی کرتے ہیں جب کہ ایمان والوںکی تمام تر محبّت خدا سے ہوتی ہے اور اے کاش ظالمین اس بات کو اس وقت دیکھ لیتے جو عذاب کو دیکھنے کے بعد سمجھیں گے کہ ساری قوت صرف اللہ کے لئے ہے اور اللہ سخت ترین عذاب کرنے والا ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@clxxiii{اس وقت جبکہ پیر اپنے مریدوں سے بیزاری کا اظہار کریں گے اور سب کے سامنے عذاب ہوگا اور تمام وسائل منقطع ہوچکے ہوں گے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@clxxiv{اور مرید بھی یہ کہیں گے کہ اے کاش ہم نے ان سے اسی طرح بیزاری اختیار کی ہوتی جس طرح یہ آج ہم سے نفرت کر رہے ہیں. خدا ان سب کے اعمال کو اسی طرح حسرت بنا کر پیش کرے گا اور ان میں سے کوئی جہّنم سے نکلنے والا نہیں ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@clxxv{اے انسانو! زمین میں جو کچھ بھی حلال و طیب ہے اسے استعمال کرو اور شیطانی اقدامات کا اتباع نہ کرو کہ وہ تمہاراکھلا ہوا دشمن ہے\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@clxxvi{وہ بس تمہیں بدعملی اور بدکاری کا حکم دیتا ہے اوراس بات پر آمادہ کرتاہے کہ خدا کے خلاف جہالت کی باتیںکرتے رہو\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@clxxvii{جب ان سے کہاجاتا ہے کہ جو کچھ خدا نے نازل کیا ہے اس کا اتباع کرو تو کہتے ہیں کہ ہم اس کا اتباع کریں گے جس پر ہم نے اپنے باپ دادا کوپایا ہے. کیا یہ ایسا ہی کریں گے چاہے ان کے باپ دادا بے عقل ہی رہے ہوں اورہدایت یافتہ نہ رہے ہوں\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@clxxviii{جو لوگ کافر ہوگئے ہیں ان کے پکارنے والے کی مثال اس شخص کی ہے جو جانوروں کو آواز دے اور جانور پکار اور آواز کے علاوہ کچھ نہ سنیں اور نہ سمجھیں. یہ کفار بہرےً گونگے اور اندھے ہیں. انہیں عقل سے سروکار نہیںہے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@clxxix{صاحبانِ ایمان جو ہم نے پاکیزہ رزق عطا کیا ہے اسے کھاؤ اور دینے والے خدا کا شکریہ ادا کرو اگر تم اس کی عبادت کرتے ہو\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@clxxx{اس نے تمہارے اوپر بس مفِدارً خونً سور کا گوشت اور جو غیر خدا کے نام پر ذبح کیا جائے اس کو حرام قرار دیا ہے پھر بھی اگر کوئی مضطر ہوجائے اور حرام کاطلب گار اور ضرورت سے زیادہ استعمال کرنے والا نہ ہو تو اس کے لئے کوئی گناہ نہیں ہے . بیشک خدا بخشنے والا اورمہربان ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@clxxxi{جو لوگ خدا کی نازل کی ہوئی کتاب کے احکام کو حُھپاتے ہیں اور اسے تھوڑی قیمت پر بیچ ڈالتے ہیں وہ درحقیقت اپنے پیٹ میں صرف آگ بھر رہے ہیں اور خدا روز هقیامت ان سے بات بھی نہ کرے گااور نہ انہیں پاکیزہ قرار دے گا اور ان کے لئے دردناک عذاب ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@clxxxii{یہی وہ لوگ ہیں جنہوں نے گمراہی کو ہدایت کے عوض اور عذاب کو مغفرت کے عوض خرید لیا ہے آخریہ آتش جہّنم پر کس قدرصبرکریں گے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@clxxxiii{یہ عذاب صرف اس لئے ہے کہ اللہ نے کتاب کو حق کے ساتھ نازل کیا ہے اور اس میں اختلاف کرنے والے حق سے بہت دورہوکر جھگڑے کررہے ہیں\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@clxxxiv{نیکی یہ نہیں ہے کہ اپنا رخ مشرق اور مغرب کی طرف کرلو بلکہ نیکی اس شخص کا حصّہ ہے جو اللہ اور آخرت ملائکہ اور کتاب پر ایمان لے آئے اورمحبت خدا میں قرابتداروں ً یتیموںً مسکینوں ً غربت زدہ مسافروںً سوال کرنے والوں اور غلاموں کی آزادی کے لئے مال دے اور نماز قائم کرے اور زکوِٰ ادا کرے اور جو بھی عہد کرے اسے پوراکرے اور فقر وفاقہ میں اور پریشانیوں اور بیماریوں میں اور میدانِ جنگ کے حالات میں صبرکرنے والے ہوںتویہی لوگ اپنے دعوائے ایمان و احسان میں سچے ہیں اور یہی صاحبان تقویٰ اور پرہیزگار ہیں\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@clxxxv{ایمان والو! تمہارے اوپر مقتولین کے بارے میں قصاص لکھ دیا گیا ہے آزادکے بدلے آزاد اورغلام کے بدلے غلام اور عورت کے بدلے عورت. اب اگرکسی کو مقتول کے وارث کی طرف سے معافی مل جائے تو نیکی کا اتباع کرے اور احسان کے ساتھ اس کے حق کو ادا کردے. یہ پروردگار کی طرف سے تمہارے حق میں تخفیف اور رحمت ہے لیکن اب جو شخص زیادتی کرے گا اس کے لئے دردناک عذاب بھی ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@clxxxvi{صاحبانِ عقل تمہارے لئے قصاص میں زندگی ہے کہ شاید تم اس طرح متقی بن جاؤ\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@clxxxvii{تمہارے اوپر یہ بھی لکھ دیا ہے کہ جب تم میں سے کسی کی موت سامنے آجائے تو اگر کوئی مال چھوڑا ہے تواپنے ماں باپ اور قرابتداروں کے لئے وصیت کردے یہ صاحبانِ تقویٰ پر ایک طرح کا حق ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@clxxxviii{اس کے بعد وصیت کو سن کر جو شخص تبدیل کردے گا اس کا گناہ تبدیل کرنے والے پر ہوگا تم پر نہیں. خدا سب کا سننے والا اور سب کے حالات سے باخبر ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@clxxxix{پھر اگر کوئی شخص وصیت کرنے والے کی طرف سے طرفداری یا ناانصافی کا خوف رکھتاہو اور وہ ورثہ میں صلح کرادے تو اس پر کوئی گناہ نہیں ہے. اللہ بڑا بخشنے والا اور مہربان ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cxc{صاحبانِ ایمان تمہارے اوپر روزے اسی طرح لکھ دیئے گئے ہیں جس طرح تمہارے پہلے والوںپر لکھے گئے تھے شایدتم اسی طرح متقی بن جاؤ\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cxci{یہ روزے صرف چند دن کے ہیںلیکن اس کے بعد بھی کوئی شخص مریض ہے یا سفر میں ہے تو اتنے ہی دن دوسرے زمانے میں رکھ لے گا اور جو لوگ صرف شدت اور مشقت کی بنائ پر روزے نہیں رکھ سکتے ہیں وہ ایک مسکین کو کھانا کھلا دیں اور اگراپنی طرف سے زیادہ نیکی کردیں تو اور بہتر ہے--- لیکن روزہ رکھنا بہرحال تمہارے حق میں بہتر ہے اگر تم صاحبانِ علم و خبر ہو\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cxcii{ماسِ رمضان وہ مہینہ ہے جس میں قرآن نازل کیا گیا ہے جو لوگوں کے لئے ہدایت ہے اور اس میں ہدایت اور حق و باطل کے امتیاز کی واضح نشانیاں موجود ہیں لہٰذا جو شخص اس مہینہ میں حاضر رہے اس کا فرض ہے کہ روزہ رکھے اور جو مریض یا مسافر ہو وہ اتنے ہی دن دوسرے زمانہ میں رکھے. خدا تمہارے بارے میں آسانی چاہتا ہے زحمت نہیں چاہتا. اور اتنے ہی دن کا حکم اس لئے ہے کہ تم عدد پورے کردو اور اللہ تعالیٰ کی دی ہوئی ہدایت پر اس کی کبریائی کا اقرار کرو اور شاید تم اس طرح اس کے شکر گزار بندے بن جاؤ\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cxciii{اور اے پیغمبر! اگر میرے بندے تم سے میرے بارے میں سوال کریں تو میں ان سے قریب ہوں. پکارنے والے کی آواز سنتا ہوں جب بھی پکارتا ہے لہٰذا مجھ سے طلب قبولیت کریں اور مجھ ہی پرایمان و اعتماد رکھیں کہ شاید اس طرح راسِ راست پر آجائیں\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cxciv{تمہارے لئے ماہ رمضان کی رات میں عورتوں کے پاس جانا حلال کر دےا گےا ہے۔ہو تمہارے لئے پردہ پوش ہیں اور تم انکے لئے ۔خدا کو معلام ہے کہ تم اپنے ہی نفس سے خیانت کرتے تھے تو اس نے تمہاری توبہ قبول کرکے تمہےں معاف کر دےا۔ اب تم بہ اطمینان مباشرت کرو اور جو خدا نے تمہارے لئے مقدر کیا ہے اس کی آرزو کرو اوراس وقت تک کھا پی سکتے ہوجب تک فجر کا سیاہ ڈورا ،سفید ڈورے سے نمایاں نہ ہو جائے۔ اس کے بعد رات کی سیاہی تک روزہ کو پورا کرو اور خبردار مسجدوںمیں اعتکاف کے موقع پر عورتوں سے مباشرت نہ کرنا۔یہ سب مقررہ حدود الٰہی ہیں ۔ان کے قرےب بھی نہ جانا ۔اللہ اس طرح اپنی آیتوں کو لوگوں کے لئے واضح طور پر بیان کرتا ہے کہ شاید وہ متقی اور پرہیزگار بن جائیں\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cxcv{اور خبردار ایک دوسرے کا مال ناجائز طریقے سے نہ کھانااور نہ حکام کے حوالہ کر دینا کہ رشوت دےکر حرام طریقے سے لوگوں کے اموال کو کھا جاﺅ،جب کہ تم جانتے ہو کہ یہ تمہارا مال نہیں ہے\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cxcvi{اے پیمبر ےہ لوگ آپ سے چاند کے بارے میں سوال کرتے ہیں تو فرمادیجئے کہ ےہ لوگوں کے لئے اور حج کے لئے وقت معلوم کرنے کا ذریعہ ہے۔اور یہ کوئی نیکی نہیں ہے کہ مکانات میں پچھواڑے کی طرف سے آﺅ،بلکہ نیکی ان کے لئے ہے جو پرہیزگار ہوں اور مکانات میں دروازوں کی طرف سے آئیں اور اللہ سے ڈرو شاید تم کامیاب ہو جاﺅ\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cxcvii{جولوگ تم سے جنگ کرتے ہیں تم بھی ان سے راہِ خدا میں جہادکرو اور زےادتی نہ کرو کہ خدا زیادتی کرنے والوں کو دوست نہیں رکھتا\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cxcviii{اور ان مشرکین کو جہاں پاؤ قتل کردو اور جس طرح انہوں نے تم کو آوارہ وطن کردیا ہے تم بھی انہیں نکال باہر کردو--- اور فتنہ پردازی تو قتل سے بھی بدتر ہے. اور ان سے مسجد الحرام کے پاس اس وقت تک جنگ نہ کرنا جب تک وہ تم سے جنگ نہ کریں. اس کے بعد جنگ چھیڑ دیں تو تم بھی چپ نہ بیٹھو اور جنگ کرو کہ یہی کافرین کی سزا ہے\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cxcix{پھر اگر جنگ سے باز آجائیں تو خدا بڑا بخشنے والا مہربان ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cc{اوران سے اس وقت تک جنگ جاری رکھو جب تک سارا فتنہ ختم نہ ہوجائے اور دین صرف اللہ کا نہ رہ جائے پھر اگر وہ لوگ باز آجائیں توظالمین کے علاوہ کسی پر زیادتی جائز نہیں ہے\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cci{شہر حرام کا جواب شہر حرام ہے اور حرمات کا بھی قصاص ہے لہٰذا جو تم پر زیادتی کرے تم بھی ویسا ہی برتاؤ کرو جیسی زیادتی اس نے کی ہے اور اللہ سے ڈرتے رہو اور یہ سمجھ لو کہ خدا پرہیزگاروں ہی کے ساتھ ہے\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@ccii{او رراسِ خدا میں خرچ کرو اور اپنے نفس کو ہلاکت میں نہ ڈالو. نیک برتاؤ کرو کہ خدا نیک عمل کرنے والوں کے ساتھ ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cciii{حج اور عمرہ کو اللہ کے لئے تمام کرو اب اگر گرفتار ہوجاؤ توجو قربانی ممکن ہو وہ دے دو اور اس وقت تک سر نہ منڈواؤ جب تک قربانی اپنی منزل تک نہ پہنچ جائے. اب جو تم میں سے مریض ہے یا اس کے سر میں کوئی تکلیف ہے تو وہ روزہ یاصدقہ یا قربانی دے دے پھر جب اطمینان ہوجائے تو جس نے عمرہ سے حج تمتع کا ارادہ کیا ہے وہ ممکنہ قربانی دے دے اور قربانی نہ مل سکے تو تین روزے حج کے دوران اور سات واپس آنے کے بعد رکھے کہ اس طرح دس پورے ہوجائیں. یہ حج تمتع اور قربانی ان لوگوں کے لئے ہے جن کے اہلِ مسجدالحرام کے حاضر شمار نہیں ہوتے اور اللہ سے ڈرتے رہو اوریہ یاد رکھو کہ خدا کا عذاب بہت سخت ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cciv{حج چند مقررہ مہینوں میں ہوتا ہے اور جو شخص بھی اس زمانے میں اپنے اوپر حج لازم کرلے اسے عورتوں سے مباشرتً گناہ اور جھگڑے کی اجازت نہیں ہے اور تم جو بھی خیر کرو گے خدا اسے جانتا ہے اپنے لئے زادُ راہ فراہم کرو کہ بہترین زادُ راہ تقویٰ ہے اوراے صاحبانِ عقل! ہم سے ڈرو\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@ccv{تمہارے لئے کوئی حرج نہیں ہے کہ اپنے پروردگار کے فضل وکرم کو تلاش کرو پھر جب عرفات سے کوچ کرو تو مشعرالحرام کے پاس ذکر خداکرو اور اس طرح ذکر کرو جس طرح اس نے ہدایت دی ہے اگرچہ تم لوگ اس کے پہلے گمراہوں میں سے تھے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@ccvi{پھر تمام لوگوں کی طرح تم بھی کوچ کرو اور اللہ سے استغفار کروکہ اللہ بڑا بخشنے والا اور مہربان ہے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@ccvii{پھر جب سارے مناسک تمام کرلو توخدا کو اسی طرح یاد رکھوجس طرح اپنے باپ دادا کو یاد کرتے ہو بلکہ اس سے بھی زیادہ کہ بعض لوگ ایسے ہیں جو کہتے ہیں کہ پروردگار ہمیں دنیا ہی میں نیکی دے دے اور ان کا آخرت میں کوئی حصّہ نہیں ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@ccviii{اور بعض کہتے ہیں کہ پروردگار ہمیں دنیا میں بھی نیکی عطا فرما اورآخرت میں بھی اور ہم کو عذاب جہّنم سے محفوظ فرما\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@ccix{یہی وہ لوگ ہیں جن کے لئے ان کی کمائی کا حصّہ ہے اور خدا بہت جلد حساب کرنے والاہے\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@ccx{اور چند معین دنوں میں ذک» خدا کرو. اسکے بعد جو دو دن کے اندر جلدی کرے گا اس پر بھی کوئی گناہ نہیں ہے اور جو تاخیر کرے گا اس پر بھی کوئی گناہ نہیں ہے بشرطیکہ پرہیزگار رہا ہو اور اللہ سے ڈرو اور یہ یاد رکھو کہ تم سب اسی کی طرف محشور کئے جاؤ گے\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@ccxi{انسانوں میں ایسے لوگ بھی ہیں جن کی باتیں زندگانی دنیا میںبھلی لگتی ہیں اور وہ اپنے دل کی باتوں پر خدا کو گواہ بناتے ہیں حالانکہ وہ بدترین دشمن ہیں\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@ccxii{اور جب آپ کے پاس سے منہ پھیرتے ہیں تو زمین میں فساد برپا کرنے کی کوشش کرتے ہیں اور کھیتیوں اور نسلوں کو برباد کرتے ہیں جب کہ خدا فساد کو پسند نہیں کرتا ہے\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@ccxiii{جب ان سے کہا جاتاہے کہ تقویٰ الٰہی اختیار کرو تو غرور گناہ کے آڑے آجاتا ہے ایسے لوگوں کے لئے جہّنم کافی ہے جو بدترین ٹھکانا ہے\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@ccxiv{اور لوگوں میں وہ بھی ہیں جو اپنے نفس کو مرضی پروردگار کے لئے بیچ ڈالتے ہیں اور اللہ اپنے بندوں پر بڑا مہربان ہے\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@ccxv{ایمان والو! تم سب مکمل طریقہ سے اسلام میں داخل ہوجاؤ اور شیطانی اقدامات کا اتباع نہ کرو کہ وہ تمہارا کھلا ہوا دشمن ہے\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@ccxvi{پھر اگر کھلی نشانیوں کے آجانے کے بعد لغزش پیدا ہوجائے تو یاد رکھو کہ خدا سب پر غالب ہے اور صاحبِ حکمت ہے\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@ccxvii{یہ لوگ اس بات کا انتظار کررہے ہیں کہ ابر کے سایہ کے پیچھے عذابِ خدا یا ملائکہ آجائیں اور ہر امر کا فیصلہ ہوجائے اور سارے امور کی بازگشت تو خدا ہی کی طرف ہے\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@ccxviii{ذرا بنی اسرائیل سے پوچھئے کہ ہم نے انہیں کس قدر نعمتیں عطا کی ہیں---- او رجو شخص بھی نعمتوں کے آجانے کے بعد انہیں تبدیل کردے گا وہ یاد رکھے کہ خدا کاعذاب بہت شدید ہوتا ہے\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@ccxix{اصل میں کافروں کے لئے زندگانی دنیا آراستہ کردی گئی ہے اور وہ صاحبانِ ایمان کا مذاق اڑاتے ہیں حالانکہ قیامت کے دن متقی اور پرہیزگار افراد کا درجہ ان سے کہیں زیادہ بالاتر ہوگا اور اللہ جس کو چاہتا ہے بے حساب رزق دیتا ہے\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@ccxx{( فطری اعتبار سے) سارے انسان ایک قوم تھے . پھر اللہ نے بشارت دینے والے اور ڈرانے والے انبیائ بھیجے اور ان کے ساتھ برحق کتاب نازل کی تاکہ لوگوں کے اختلافات کا فیصلہ کریں اور اصل اختلاف ان ہی لوگوں نے کیا جنہیں کتاب مل گئی ہے اور ان پر آیات واضح ہوگئیں صرف بغاوت اور تعدی کی بنا پر----- تو خدا نے ایمان والوں کو ہدایت دے دی اور انہوں نے اختلافات میں حکم الٰہی سے حق دریافت کرلیا اور وہ تو جس کو چاہتا ہے صراظُ مستقیم کی ہدایت دے دیتا ہے\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@ccxxi{کیا تمہارا خیال ہے کہ تم آسانی سے جنّت میںداخل ہوجاؤ گے جبکہ ابھی تمہارے سامنے سابق اُمتوں کی مثال پیش نہیں آئی جنہیںفقر و فاقہ اور پریشانیوں نے گھیر لیا اور اتنے جھٹکے دیئے گئے کہ خود رسول اور ان کے ساتھیوں نے یہ کہناشروع کردیا کہ آخر خدائی امداد کب آئے گی. تو آگاہ ہوجاؤ کہ خدائی امداد بہت قریب ہے\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@ccxxii{پیغمبر یہ لوگ آپ سے سوال کرتے ہیں کہ راسِ خدا میں کیا خرچ کریں تو آپ کہہ دیجئے کہ جو بھی خرچ کرو گے وہ تمہارے والدینً قرابتدرً ایتامً مساکین اور غربت زدہ مسافروں کے لئے ہوگا اور جو بھی کا»خیر کروگے خدا اسے خوب جانتا ہے\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@ccxxiii{تمہارے اوپر جہاد فرض کیا گیا ہے اور وہ تمہیں ناگوار ہے اور یہ ممکن ہے کہ جسے تم اِرا سمجھتے ہو وہ تمہارے حق میں بہتر ہو اور جسے تم دوست رکھتے ہو وہ اِرا ہو خدا سب کو جانتا ہے اور تم نہیں جانتے ہو\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@ccxxiv{پیغمبر یہ آپ سے محترم مہینوں کے جہاد کے بارے میں سوال کرتے ہیں تو آپ کہہ دیجئے کہ ان میں جنگ کرنا گناہ کبیرہ ہے اور راسِ خدا سے روکنا اور خدا اورمسجدالحرام کی حرمت کا انکار ہے اور اہلِ مسجد الحرام کا وہاںسے نکال دینا خدا کی نگاہ میں جنگ سے بھی بدتر گناہ ہے اور فتنہ تو قتل سے بھی بڑا جرم ہے--- اور یہ کفار برابر تم لوگوں سے جنگ کرتے رہیں گے یہاں تک کہ ان کے امکان میں ہو تو تم کو تمہارے دین سے پلٹا دیں. اور جو بھی اپنے دین سے پلٹ جائے گا اور کفر کی حالت میں مر جائے گا اس کے سارے اعمال برباد ہوجائیں گئے اور وہ جہنّمی ہوگا اور وہیں ہمیشہ رہے گا\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@ccxxv{بےشک جو لوگ ایمان لائے اور جنہوں نے ہجرت کی اور راہ خدا میں جہاد کیا وہ رحمت الٰہی کی امید رکھتے ہیں اور خدا بہت بخشنے والا اور مہربان ہے\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@ccxxvi{یہ آپ سے شراب اورجوئے کے بارے میں سوال کرتے ہیں تو کہہ دیجئے کہ ان دونوں میں بہت بڑا گناہ ہے اور بہت سے فائدے بھی ہیں لیکن ان کا گناہ فائدے سے کہیں زیادہ بڑا ہے اور یہ راسِ خدا میں خرچ کے بارے میں سوال کرتے ہیں کہ کیا خرچ کریں تو کہہ دیجئے کہ جو بھی ضرورت سے زیادہ ہو. خدا اسی طرح اپنی آیات کو واضح کرکے بیان کرتا ہے کہ شاید تم فکر کرسکو\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@ccxxvii{دنیا میں بھی اور آخرت میں بھی---- اور یہ لوگ تم سے یتیموں کے بارے میں سوال کرتے ہیں تو کہہ دو کہ ان کے حال کی اصلاح بہترین بات ہے اور اگر ان سے مل چُل کر رہو تو یہ بھی تمہارے بھائی ہیں اور اللہ بہتر جانتاہے کہ مصلح کون ہے اور مفسدکون ہے اگر وہ چاہتا تو تمہیں مصیبت میں ڈال دیتا لیکن وہ صاحبِ عزّت بھی ہے اور صاحبِ حکمت بھی ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@ccxxviii{خبردار مشرک عورتوں سے اس وقت تک نکاح نہ کرنا جب تک ایمان نہ لے آئیں کہ ایک مومن کنیز مشرک آزاد عورت سے بہتر ہے چاہے وہ تمہیں کتنی ہی بھلی معلوم ہو اورمشرکین کو بھی لڑکیاں نہ دینا جب تک مسلمان نہ ہوجائیں کہ مسلمان غلام آزاد مشرک سے بہتر ہے چاہے وہ تمہیں کتنا ہی اچھا کیوں نہ معلوم ہو. یہ مشرکین تمہیں جہّنم کی دعوت دیتے ہیں اور خدا اپنے حکم سے جنّت اورمغفرت کی دعوت دیتا ہے اور اپنی آیتوں کو واضح کرکے بیان کرتاہے کہ شاید یہ لوگ سمجھ سکیں\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@ccxxix{اور اے پیغمبر یہ لوگ تم سے ایاّم حیض کے بارے میں سوال کرتے ہیں تو کہہ دو کہ حیض ایک اذیت اور تکلیف ہے لہذا اس زمانے میں عورتوں سے الگ رہو اور جب تک پاک نہ ہوجائیں ان کے قریب نہ جاؤ پھر جب پاک ہوجائیں تو جس طرح سے خدا نے حکم دیا ہے اس طرح ان کے پاس جاؤ. بہ تحقیق خدا توبہ کرنے والوں اور پاکیزہ رہنے والوں کو دوست رکھتا ہے\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@ccxxx{تمہاری عورتیں تمہاری کھیتیاں ہیں لہٰذا اپنی کھیتی میں جہاں چاہو داخل ہوجاؤ اور اپنے واسطے پیشگی اعمال خدا کی بارگاہ میں بھیج دو اور اس سے ڈرتے رہو---- یہ سمجھو کہ تمہیں اس سے ملاقات کرنا ہے اورصاحبانِ ایمان کو بشارت دے دو\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@ccxxxi{خبردار خدا کو اپنی قسموںکا نشانہ نہ بناؤ کہ قسموںکو نیکی کرنےً تقویٰ اختیارکرنے اور لوگوں کے درمیان اصلاح کرنے میں مانع بنادو اللہ سب کچھ سننے اور جاننے والا ہے\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@ccxxxii{خدا تمہاری لغواور غیر ارادی قسموںکا مواخذہ نہیں کرتا ہے لیکن جس کو تمہارے دلوں نے حاصل کیا ہے اس کا ضرور مواخذہ کرے گا. وہ بخشنے والا بھی ہے اور برداشت کرنے والا بھی\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@ccxxxiii{جو لوگ اپنی بیویوں سے ترک جماع کی قسم کھا لیتے ہیں انہیں چار مہینے کی مہلت ہے. اس کے بعد واپس آگئے تو خدا غفوررحیم ہے\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@ccxxxiv{اورطلاق کا ارادہ کریں تو خدا سن بھی رہا ہے اور دیکھ بھی رہاہے\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@ccxxxv{مطلقہ عورتیں تین حیض تک انتظار کریں گی اور انہیں حق نہیں ہے کہ جو کچھ خدا نے ان کے رحم میں پیدا کیا ہے اس کی پردہ پوشی کریں اگر ان کا ایمان اللہ اور آخرت پر ہے. اورپھر ان کے شوہر اس مدّت میں انہیں واپس کرلینے کے زیادہ حقدار ہیں اگر اصلاح چاہتے ہیں .اور عورتوں کے لئے ویسے ہی حقوق بھی ہیں جیسی ذمہ داریاں ہیں اور مردوں کو ان پر ایک امتیاز حاصل ہے اور خدا صاحبِ عزّت و حکمت ہے\qt@no{(228)}}%
\qt@newcmd\qurantrans@ur@ccxxxvi{طلاق دو مرتبہ دی جائے گی. اس کے بعد یا نیکی کے ساتھ روک لیا جائے گا یا حسنِ سلوک کے ساتھ آزاد کردیا جائے گا اور تمہارے لئے جائز نہیں ہے کہ جو کچھ انہیں دے دیا ہے اس میں سے کچھ واپس لو مگر یہ کہ یہ اندیشہ ہو کہ دونوں حدود الٰہی کو قائم نہ رکھ سکیں گے تو جب تمہیں یہ خوف پیدا ہوجائے کہ وہ دونوں حدود الٰہی کو قائم نہ رکھ سکیں گے تو دونوں کے لئے آزادی ہے اس فدیہ کے بارے میں جو عورت مرد کو دے. لیکن یہ حدود الہٰیہ ہیں ان سے تجاوز نہ کرنا اور جو حدود الٰہی سے تجاوز کرے گا وہ ظالمین میں شمار ہوگا\qt@no{(229)}}%
\qt@newcmd\qurantrans@ur@ccxxxvii{پھر اگر تیسری مرتبہ طلاق دے دی تو عورت مرد کے لئے حلال نہ ہوگی یہاں تک کہ دوسرا شوہر کرے پھر اگر وہ طلاق دے دے تو دونوں کے لئے کوئی حرج نہیں ہے کہ آپس میں میل کرلیں اگر یہ خیال ہے کہ حدود الہٰیہ کو قائم رکھ سکیں گے. یہ حدود الہٰیہ ہیں جنہیں خدا صاحبانِ علم واطلاع کے لئے واضح طور سے بیان کررہا ہے\qt@no{(230)}}%
\qt@newcmd\qurantrans@ur@ccxxxviii{اور جب تم عورتوں کو طلاق دو اور وہ مدّاُ عدت کے خاتمہ کے قریب پہنچ جائیں تو یا انہیں اصلاح اور حسنِ معاشرت کے ساتھ روک لو یا انہیں حسنِ سلوک کے ساتھ آزاد کردو اور خبردار نقصان پہنچانے کی غرض سے انہیں نہ روکنا کہ ان پر ظلم کرو کہ جو ایسا کرے گا وہ خود اپنے نفس پر ظلم کرے گا اور خبردار آیات الٰہی کو مذاق نہ بناؤ. خدا کی نعمت کو یاد کرو. اس نے کتاب و حکمت کو تمہاری نصیحت کےلئے نازل کیا ہے اور یاد رکھو کہ وہ ہر شے کا جاننے والا ہے\qt@no{(231)}}%
\qt@newcmd\qurantrans@ur@ccxxxix{اور جب تم لوگ عورتوں کو طلاق دو اور ان کی مدّاُ عدت پوری ہوجائے تو خبردار انہیں شوہر کرنے سے نہ روکنا اگر وہ شوہروں کے ساتھ نیک سلوک پر راضی ہوجائیں. اس حکم کے ذریعے خدا انہیں نصیحت کرتا ہے جن کا ایمان اللہ اور روزِ آخرت پر ہے اور ان احکام پر عمل تمہارے لئے باعجُ تزکیہ بھی ہے اور باعث طہارت بھی. اللہ سب کچھ جانتا ہے اور تم نہیں جانتے ہو\qt@no{(232)}}%
\qt@newcmd\qurantrans@ur@ccxl{اور مائیں اپنی اولاد کو دو برس کامل دودھ پلائیں گی جو رضاعت کو پورا کرنا چاہے گا اس درمیان صاحب اولاد کا فرض ہے کہ ماؤں کی روٹی اور کپڑے کا مناسب طریقہ سے انتظام کرے. کسی شخص کو اس کی وسعت سے زیادہ تکلیف نہیں دی جاسکتی. نہ ماں کو اس کی اولاد کے ذریعہ تکلیف دینے کا حق ہے اور نہ باپ کو اس کی اولاد کے ذریعہ. اور وارث کی بھی ذمہ داری ہے کہ وہ اسی طرح اجرت کا انتظام کرے. پھر اگر دونوں باہمی رضامندی اور مشورہ سے دودھ چھڑانا چاہیں تو کوئی حرج نہیں ہے اور اگر تم اپنی اولاد کے لئے دودھ پلانے والی تلاش کرنا چاہو تو اس میں بھی کوئی حرج نہیں ہے بشرطیکہ متعارف طریقہ کی اجرت ادا کردو اور اللہ سے ڈرو اور یہ سمجھو کہ وہ تمہارے اعمال کو خوب دیکھ رہا ہے\qt@no{(233)}}%
\qt@newcmd\qurantrans@ur@ccxli{اور جو لوگ تم میں سے بیویاں چھوڑ کر مرجائیں ان کی بیویاں چار مہینے دس دن انتظار کریں گی جب یہ مدّت پوری ہو جائے تو جو مناسب کام اپنے حق میں کریں اس میں کوئی حرج نہیں ہے خدا تمہارے اعمال سے خو ب باخبر ہے\qt@no{(234)}}%
\qt@newcmd\qurantrans@ur@ccxlii{تمہارے لئے نکاح کے پیغام کی پیشکش یا دل ہی دل میں پوشیدہ ارادہ میں کوئی حرج نہیں ہے. خدا کو معلوم ہے کہ تم بعد میں ان سے تذکرہ کرو گے لیکن فی الحال خفیہ وعدہ بھی نہ لو صرف کوئی نیک بات کہہ دو تو کوئی حرج نہیں ہے اور جب تک مقررہ مدّت پوری نہ ہوجائے عقد نکاح کا ارادہ نہ کرنا یہ یاد رکھو کہ خدا تمہارے دل کی باتیں خوب جانتا ہے لہذا اس سے ڈرتے رہو اور یہ جان لو کہ وہ غفور بھی ہے اور حلیم واِردبار بھی\qt@no{(235)}}%
\qt@newcmd\qurantrans@ur@ccxliii{اور تم پر کوئی ذمہ داری نہیں ہے اگر تم نے عورتوں کو اس وقت طلاق دے دی جب کہ ان کو چھوا بھی نہیں ہے اور ان کے لئے کوئی مہر بھی معین نہیں کیا ہے البتہ انہیں کچھ مال و متاع دیدو. مالدار اپنی حیثیت کے مطابق اور غریب اپنی حیثیت کے مطابق. یہ متاع بقدر مناسب ہونا ضروری ہے کہ یہ نیک کرداروں پر ایک حق ہے\qt@no{(236)}}%
\qt@newcmd\qurantrans@ur@ccxliv{اور اگر تم نے ان کو چھونے سے پہلے طلاق دے دی اور ان کے لئے مہر معین کر چکے تھے تو معین مہر کا نصف دینا ہوگا مگر یہ کہ وہ خود معاف کردیں یا ان کا ولی معاف کر دے اور معاف کردینا تقویٰ سے زیادہ قریب تر ہے اور آپس میں بزرگی کو فراموش نہ کرو. خدا تمہارے اعمال کو خوب دیکھ رہا ہے\qt@no{(237)}}%
\qt@newcmd\qurantrans@ur@ccxlv{اپنی تمام نمازوں اور بالخصوص نماز وسطٰی کی محافظت اور پابندی کرو اور اللہ کی بارگاہ میں خشوع و خضوع کے ساتھ کھڑے ہوجاؤ\qt@no{(238)}}%
\qt@newcmd\qurantrans@ur@ccxlvi{پھر اگر خوف کی حالت ہو تو پیدل ًسوار جس طرح ممکن ہو نماز اداکرو اور جب اطمینان ہوجائے تو اس طرح ذکر خدا کرو جس طرح اس نے تمہاری لاعلمی میں تمہیں بتایا ہے\qt@no{(239)}}%
\qt@newcmd\qurantrans@ur@ccxlvii{اور جو لوگ مدّاُ حیات پوری کررہے ہوں اور ازواج کو چھوڑ کر جارہے ہوں انہیں چاہئے کہ اپنی ازواج کے لئے ایک سال کے خرچ اور گھر سے نہ نکالنے کی وصیت کرکے جائیں پھر اگر وہ خود سے نکل جائیں تو تمہارے لئے کوئی حرج نہیں ہے وہ اپنے بارے میں جو بھی مناسب کام انجام دیں خدا صاحبِ عزّت اور صاحبِ حکمت بھی ہے\qt@no{(240)}}%
\qt@newcmd\qurantrans@ur@ccxlviii{اور مطلقہ عورتوں کو دستور کے مطابق کچھ خرچہ دینا، یہ متقی لوگوں کی ذمے داری ہے\qt@no{(241)}}%
\qt@newcmd\qurantrans@ur@ccxlix{اسی طرح پروردگار اپنی آیات کو بیان کرتا ہے کہ شاید تمہیں عقل آجائے\qt@no{(242)}}%
\qt@newcmd\qurantrans@ur@ccl{کیا تم نے ان لوگوں کو نہیں دیکھا جو ہزاروں کی تعداد میںاپنے گھروں سے نکل پڑے موت کے خوف سے اور خدا نے انہیںموت کا حکم دے دیا اور پھر زندہ کردیا کہ خدا لوگوں پر بہت فضل کرنے والا ہے لیکن اکثر لوگ شکریہ نہیں ادا کرتے ہیں\qt@no{(243)}}%
\qt@newcmd\qurantrans@ur@ccli{اور راسِ خدا میں جہاد کرو اور یاد رکھو کہ خدا سننے والا بھی ہے اور جاننے والا بھی ہے\qt@no{(244)}}%
\qt@newcmd\qurantrans@ur@cclii{کون ہے جو خدا کو قرض حسن دے اور پھر خدا اسے کئی گنا کرکے واپس کردے خدا کم بھی کرسکتاہے اور زیادہ بھی اور تم سب اسی کی بارگاہ میں پلٹائے جاؤگے\qt@no{(245)}}%
\qt@newcmd\qurantrans@ur@ccliii{کیا تم نے موسیٰ علیھ السّلامکے بعد بنی اسرائیل کی اس جماعت کونہیں دیکھا جس نے اپنے نبی سے کہا کہ ہمارے واسطے ایک بادشاہ مقرر کیجئے تاکہ ہم راسِ خدا میں جہاد کریں. نبی نے فرمایا کہ اندیشہ یہ ہے کہ تم پر جہادواجب ہوجائے توتم جہاد نہ کرو. ان لوگوں نے کہا کہ ہم کیوںکر جہاد نہ کریں گے جب کہ ہمیں ہمارے گھروں اور بال بّچوںسے الگ نکال باہر کردیا گیا ہے. اس کے بعد جب جہاد واجب کردیا گیا تو تھوڑے سے افراد کے علاوہ سب منحرف ہوگئے اور اللہ ظالمین کو خوب جانتا ہے\qt@no{(246)}}%
\qt@newcmd\qurantrans@ur@ccliv{ان کے پیغمبر علیھ السّلامنے کہا کہ اللہ نے تمہارے لئے طالوت کو حاکم مقرر کیا ہے. ان لوگوں نے کہا کہ یہ کس طرح حکومت کریں گے ان کے پاس تو مال کی فراوانی نہیں ہے ان سے زیادہ تو ہم ہی حقدار حکومت ہیں. نبی نے جواب دیا کہ انہیں اللہ نے تمہارے لئے منتخب کیا ہے اور علم و جسم میں وسعت عطا فرمائی ہے اور اللہ جسے چاہتا ہے اپنا ملک دے دیتا ہے کہ وہ صاحبِ وسعت بھی ہے اور صاحبِ علم بھی\qt@no{(247)}}%
\qt@newcmd\qurantrans@ur@cclv{اور ان کے پیغمبر علیھ السّلام نے یہ بھی کہا کہ ان کی حکومت کی نشانی یہ ہے یہ تمہارے پاس وہ تابوت لے آئیں گے جس میںپروردگار کی طرف سے سامانِ سکون اور آل موسیٰ علیھ السّلام اور آل ہارون علیھ السّلام کا چھوڑا ہوا ترکہ بھی ہے. اس تابوت کو ملائکہ اٹھائے ہوئے ہوں گے اور اس میں تمہارے لئے قدراُ پروردگار کی نشانی بھی ہے اگر تم صاحبِ ایمان ہو\qt@no{(248)}}%
\qt@newcmd\qurantrans@ur@cclvi{اس کے بعد جب طالوت علیھ السّلام لشکر لے کرچلے تو انہوں نے کہا کہ اب خدا ایک نہر کے ذریعہ تمہارا امتحان لینے والا ہے جو اس میں سے پی لے گا وہ مجھ سے نہ ہوگا اور جو نہ چکھے گا وہ مجھ سے ہوگا مگر یہ کہ ایک چلّو پانی لے لے. نتیجہ یہ ہوا کہ سب نے پانی پی لیا سوائے چند افراد کے---- پھر جب وہ صاحبانِ ایمان کو لے کر آگے بڑھے لوگوں نے کہا کہ آج تو جالوت اور اس کے لشکروں کے مقابلہ کی ہمت نہیں ہے اور ایک جماعت نے جسے خدا سے ملاقات کرنے کا خیال تھا کہا کہ اکثر چھوٹے چھوٹے گروہ بڑی بڑی جماعتوں پر حکم خدا سے غالب آجاتے ہیں اور اللہ صبر کرنے والوں کے ساتھ ہے\qt@no{(249)}}%
\qt@newcmd\qurantrans@ur@cclvii{اور یہ لوگ جب جالوت اور اس کے لشکروں کے مقابلے کے لئے نکلے تو انہوں نے کہا کہ خدایا ہمیں بے پناہ صبر عطا فرما ہمارے قدموں کو ثبات دے اور ہمیں کافروں کے مقابلہ میں نصرت عطا فرما\qt@no{(250)}}%
\qt@newcmd\qurantrans@ur@cclviii{نتیجہ یہ ہوا کہ ان لوگوں نے جالوت کے لشکر کو خدا کے حکم سے شکست دے دی اور داؤد علیھ السّلامنے جالوت کو قتل کردیا اور اللہ نے انہیں ملک اور حکمت عطاکردی اور اپنے علم سے جس قدر چاہا دے دیا اور اگر اسی طرح خدا بعض کو بعض سے نہ روکتا رہتا تو ساری زمین میں فساد پھیل جاتا لیکن خدا عالمین پر بڑا فضل کرنے والا ہے\qt@no{(251)}}%
\qt@newcmd\qurantrans@ur@cclix{یہ آیااُ الہٰیہ ہیں جن کو ہم واقعیت کے ساتھ آپ کو پڑھ کر سناتے ہیں اور آپ یقینا مرسلین میں سے ہیں\qt@no{(252)}}%
\qt@newcmd\qurantrans@ur@cclx{یہ سب رسول علیھ السّلاموہ ہیں جنہیں ہم نے بعض کو بعض پر فضیلت دی ہے. ان میں سے بعض وہ ہیں جن سے خدا نے کلام کیا ہے اور بعض کے درجات بلند کئے ہیں اور ہم نے عیسیٰ علیھ السّلام بن مریم کو کھلی ہوئی نشانیاںدی ہیں اور روح القدس کے ذریعہ ان کی تائید کی ہے. اگر خدا چاہتا تو ان رسولوں کے بعد والے ان واضح معجزات کے آجانے کے بعد آپس میں جھگڑا نہ کرتے لیکن ان لوگوں نے (خدا کے جبر نہ کرنے کی بنا پر) اختلاف کیا ہے . بعض ایمان لائے اور بعض کافر ہو گئے اور اگر خدا طے کر لیتا تو یہ جھگڑا نہ کرسکتے لیکن خدا جو چاہتا ہے وہی کرتا ہے\qt@no{(253)}}%
\qt@newcmd\qurantrans@ur@cclxi{اے ایمان والو جو تمہیں رزق دیا گیا ہے اس میں سے راسِ خدا میں خرچ کرو قبل اسکے کہ وہ دن آجائے جس دن نہ تجارت ہوگی نہ دوستی کام آئے گی اور نہ سفارش. اورکافرین ہی اصل میں ظالمین ہیں\qt@no{(254)}}%
\qt@newcmd\qurantrans@ur@cclxii{اللہ جس کے علاوہ کوئی خدا نہیں ہے زندہ بھی ہے اوراسی سے کِل کائنات قائم ہے اسے نہ نیند آتی ہے نہ اُونگھ آسمانوں اور زمین میں جو کچھ بھی ہے سب اسی کا ہے. کون ہے جو اس کی بارگاہ میں اس کی اجازت کے بغیر سفارش کرسکے. وہ جو کچھ ان کے سامنے ہے اور جو پبُ پشت ہے سب کوجانتا ہے اور یہ اس کے علم کے ایک حّصہ کا بھی احاطہ نہیں کرسکتے مگر وہ جس قدر چاہے. اس کی کرس علم و اقتدار زمین و آسمان سے وسیع تر ہے اور اسے ا ن کے تحفظ میں کوئی تکلیف بھی نہیں ہوتی وہ عالی مرتبہ بھی ہے اور صاحبِ عظمت بھی\qt@no{(255)}}%
\qt@newcmd\qurantrans@ur@cclxiii{دین میں کسی طرح کا جبر نہیں ہے. ہدایت گمراہی سے الگ اور واضح ہوچکی ہے. اب جو شخص بھی طاغوت کا انکار کرکے اللہ پر ایمان لے آئے وہ اس کی مضبوط رسّی سے متمسک ہوگیا ہے جس کے ٹوٹنے کا امکان نہیں ہے اور خدا سمیع بھی ہے اور علیم بھی ہے\qt@no{(256)}}%
\qt@newcmd\qurantrans@ur@cclxiv{اللہ صاحبانِ ایمان کا ولی ہے وہ انہیں تاریکیوں سے نکال کر روشنی میں لے آتا ہے اور کفارکے ولی طاغوت ہیں جو انہیں روشنی سے نکال کر اندھیروں میں لے جاتے ہیں یہی لوگ جہّنمی ہیں اور وہاں ہمیشہ رہنے والے ہیں\qt@no{(257)}}%
\qt@newcmd\qurantrans@ur@cclxv{کیا تم نے اس کے حال پر نظر نہیں کی جس نے ابراہیم علیھ السّلام سے پروردگار کے بارے میں بحث کی صرف اس بات پر کہ خدا نے اسے ملک دے دیا تھا جب ابرہیم علیھ السّلام نے یہ کہا کہ میرا خدا جلِتا بھی ہے اور مارتا بھی ہے تو اس نے کہا کہ یہ کام میں بھی کرسکتا ہوں تو ابراہیم علیھ السّلام نے کہا کہ میرا خدامشرق سے آفتاب نکالتا ہے تو مغرب سے نکال دے تو کافر حیران رہ گیا اور اللہ ظالم قوم کی ہدایت نہیں کرتا ہے\qt@no{(258)}}%
\qt@newcmd\qurantrans@ur@cclxvi{یا اس بندے کی مثال جس کا گذر ایک قریہ سے ہوا جس کے سارے عرش و فرش گرچکے تھے تو اس بندہ نے کہا کہ خدا ان سب کو موت کے بعد کس طرح زندہ کرے گا تو خدا نے اس بندہ کو سوسال کے لئے موت دے دی اورپھرزندہ کیا اور پوچھا کہ کتنی دیر پڑے رہے تو اس نے کہا کہ ایک دن یا کچھ کم . فرمایا نہیں . سو سال ذرا اپنے کھانے اور پینے کو تو دیکھو کہ خراب تک نہیں ہوا اور اپنے گدھے پر نگاہ کرو (کہ سڑ گل گیا ہے) اور ہم اسی طرح تمہیں لوگوں کے لئے ایک نشانی بنانا چاہتے ہیں پھر ان ہڈیوںکو دیکھو کہ ہم کس طرح جوڑ کر ان پر گوشت چڑھاتے ہیں. پھر جب ان پر یہ بات واضح ہوگئی تو بیساختہ آواز دی کہ مجھے معلوم ہے کہ خدا ہر شے پرقادر ہے\qt@no{(259)}}%
\qt@newcmd\qurantrans@ur@cclxvii{اور اس موقع کو یاد کرو جب ابراہیم علیھ السّلامنے التجا کی کہ پروردگار مجھے یہ دکھا دے کہ تو مفِدوںکو کس طرح زندہ کرتا ہے . ارشاد ہوا کیا تمہارا ایمان نہیں ہے . عرض کی ایمان توہے لیکن اطمینان چاہتا ہوں . ارشاد ہوا کہ چار طائر پکڑلو اور انہیں اپنے سے مانوس بناؤ پھر ٹکڑے ٹکڑے کرکے ہر پہاڑ پر ایک حصّہ رکھ دو اور پھرآواز دو سب دوڑتے ہوئے آجائیں گے اور یاد رکھو کہ خدا صاحبِ عزّت بھی اور صاحبِ حکمت بھی\qt@no{(260)}}%
\qt@newcmd\qurantrans@ur@cclxviii{جو لوگ راسِ خدا میں اپنے اموال خرچ کرتے ہیں ان کے عمل کی مثال اس دانہ کی ہے جس سے سات بالیاں پیدا ہوں اور پھر ہر بالی میں سو سو دانے ہوںاور خدا جس کے لئے چاہتا ہے اضافہ بھی کردیتا ہے کہ وہ صاحبِ وسعت بھی ہے اور علیم و دانا بھی\qt@no{(261)}}%
\qt@newcmd\qurantrans@ur@cclxix{جو لوگ راسِ خدا میں اپنے اموال خرچ کرتے ہیں اور اس کے بعد احسان نہیں جتاتے اور اذّیت بھی نہیں دیتے ان کے لئے پروردگار کے یہاں اجر بھی ہے اور نہ کوئی خوف ہے نہ حزن\qt@no{(262)}}%
\qt@newcmd\qurantrans@ur@cclxx{نیک کلام اور مغفرت اس صدقہ سے بہتر ہے جس کے پیچھے دل دکھانے کا سلسلہ بھی ہو . خدا سب سے بے نیاز اور بڑا اِرد بار ہے\qt@no{(263)}}%
\qt@newcmd\qurantrans@ur@cclxxi{ایمان والو اپنے صدقات کو منّت گزاری اور اذیت سے برباد نہ کرو اس شخص کی طرح جو اپنے مال کو دنیا دکھانے کے لئے صرف کرتاہے اور اس کا ایمان نہ خدا پر ہے اور نہ آخرت پر اس کی مثال اس صاف چٹان کی ہے جس پر گرد جم گئی ہو کہ تیز بارش کے آتے ہی بالکل صاف ہوجائے یہ لوگ اپنی کمائی پر بھی اختیار نہیں رکھتے اور اللہ کافروں کی ہدایت بھی نہیں کرتا\qt@no{(264)}}%
\qt@newcmd\qurantrans@ur@cclxxii{اور جو لوگ اپنے اموال کو رضائے خدا کی طلب اور اپنے نفس کے استحکام کی غرض سے خرچ کرتے ہیں ان کے مال کی مثال اس باغ کی ہے جو کسی بلندی پر ہو اور تیز بارش آکر اس کی فصل دوگنا بنا دے اور اگر تیز بارش نہ آئے تو معمولی بارش ہی کافی ہوجائے اور اللہ تمہارے اعمال کی نیتوں سے خوب باخبر ہے\qt@no{(265)}}%
\qt@newcmd\qurantrans@ur@cclxxiii{کیا تم میں سے کوئی یہ پسند کرتا ہے کہ اس کے پاس کھجور اور انگور کے باغ ہوں. ان کے نیچے نہریں جاری ہوں ان میں ہر طرح کے پھل ہوں--- اور آدمی بوڑھاہوجائے . اس کے کمزور بچے ہوں اور پھراچانک تیز گرم ہوا جس میں آگ بھری ہو چل جائے اور سب جل کر خاک ہوجائے . خداا سی طرح اپنی آیات کو واضح کرکے بیان کرتا ہے کہ شاید تم فکر کرسکو\qt@no{(266)}}%
\qt@newcmd\qurantrans@ur@cclxxiv{اے ایمان والو اپنی پاکیزہ کمائی اور جو کچھ ہم نے زمین سے تمہارے لئے پیدا کیا ہے سب میں سے راسِ خدا میں خرچ کرو اور خبردار انفاق کے ارادے سے خراب مال کو ہاتھ بھی نہ لگانا کہ اگر یہ مال تم کو دیا جائے تو آنکھ بند کئے بغیر چھوؤ گے بھی نہیں یاد رکھو کہ خدا سب سے بے نیاز ہے اور سزاوار حمد و ثنا بھی ہے\qt@no{(267)}}%
\qt@newcmd\qurantrans@ur@cclxxv{شیطان تم سے فقیری کا وعدہ کرتا ہے اور تمہیں برائیوں کا حکم دیتا ہے اور خدا مغفرت اور فضل و احسان کا وعدہ کرتا ہے . خدا صاحبِ وسعت بھی ہے اور علیم و دانا بھی\qt@no{(268)}}%
\qt@newcmd\qurantrans@ur@cclxxvi{وہ جس کو بھی چاہتا ہے حکمت عطا کردیتا ہے اور جسے حکمت عطا کردی جائے اسے گویاخیرکثیر عطا کردیا گیا اور اس بات کوصاحبانِ عقل کے علاوہ کوئی نہیں سمجھتا ہے\qt@no{(269)}}%
\qt@newcmd\qurantrans@ur@cclxxvii{اور تم جو کچھ بھی راسِ خدا میں خرچ کرو گے یا نذر کروگے تو خدا اس سے باخبر ہے البتہ ظالمین کا کوئی مددگار نہیں ہے\qt@no{(270)}}%
\qt@newcmd\qurantrans@ur@cclxxviii{اگر تم صدقہ کوعلی الاعلان دوگے تو یہ بھی ٹھیک ہے اور اگر حُھپا کر فقرائ کے حوالے کردوگے تو یہ بھی بہت بہترہے اور اس کے ذریعہ تمہارے بہت سے گناہ معاف ہوجائیں گے اور خدا تمہارے اعمال سے خوب باخبر ہے\qt@no{(271)}}%
\qt@newcmd\qurantrans@ur@cclxxix{اے پیغمبران کی ہدایت پا جانے کی ذمہ داری آپ پر نہیںہے بلکہ خدا جس کو چاہتا ہے ہدایت دے دیتا ہے اورلوگو جو مال بھی تم راسِ خدا میں خرچ کروگے وہ دراصل اپنے ہی لئے ہوگا اور تم تو صرف خوشنودی خدا کے لئے خرچ کرتے ہو اور جوکچھ بھی خرچ کروگے وہ پوراپورا تمہاری طرف واپس آئے گا اور تم پرکسی طرح کا ظلم نہ ہوگا\qt@no{(272)}}%
\qt@newcmd\qurantrans@ur@cclxxx{یہ صدقہ ان فقرائ کے لئے ہے جو راسِ خدا میں گرفتار ہوگئے ہیں اور کسی طرف جانے کے قابل بھی نہیں ہیں ناواقف افراد انہیں ان کی حیا و عفت کی بنا پر مالدار سمجھتے ہیں حالانکہ تم آثار سے ان کی غربت کا اندازہ کرسکتے ہو اگرچہ یہ لوگوں سے چمٹ کر سوال نہیں کرتے ہیںاور تم لوگ جو کچھ بھی انفاق کرو گے خدا اسے خوب جانتا ہے\qt@no{(273)}}%
\qt@newcmd\qurantrans@ur@cclxxxi{جو لوگ اپنے اموال کو راسِ خدا میں رات میں .دن میں خاموشی سے اور علی الاعلان خرچ کرتے ہیں ان کے لئے پیش پروردگار اجر بھی ہے اور انہیں نہ کوئی خوف ہوگا اور نہ حزن\qt@no{(274)}}%
\qt@newcmd\qurantrans@ur@cclxxxii{جو لوگ سود کھاتے ہیں وہ روزِ قیامت اس شخص کی طرح اُٹھیں گے جسے شیطان نے چھوکر مخبوط الحواس بنا دیا ہو اس لئے کہ انہوں نے یہ کہہ دیا ہے کہ تجارت بھی سود جیسی ہے جب کہ خدا نے تجارت کو حلال قرار دیا ہے اور سودکو حرام . اب جس کے پاس خدا کی طرف سے نصیحت آگئی اور اس نے سود کو ترک کردیاتو گزشتہ کاروبار کا معاملہ خداکے حوالے ہے اور جو اس کے بعد بھی سود لے تو وہ لوگ سب جہّنمی ہیں او ر وہیں ہمیشہ رہنے والے ہیں\qt@no{(275)}}%
\qt@newcmd\qurantrans@ur@cclxxxiii{خدا سود کو برباد کردیتا ہے اور صدقات میں اضافہ کردیتا ہے اور خدا کسی بھی ناشکرے گناہگار کو دوست نہیں رکھتا\qt@no{(276)}}%
\qt@newcmd\qurantrans@ur@cclxxxiv{جو لوگ ایمان لے آئے اور انہوں نے نیک عمل کئے نماز قائم کی . زکوِٰ ادا کی ان کے لئے پروردگار کے یہاں اجر ہے اور ان کے لئے کسی طرح کا خوف یا حزن نہیں ہے\qt@no{(277)}}%
\qt@newcmd\qurantrans@ur@cclxxxv{ایمان والو اللہ سے ڈرو اور جو سود باقی رہ گیا ہے اسے چھوڑ دو اگر تم صاحبان هایمان ہو\qt@no{(278)}}%
\qt@newcmd\qurantrans@ur@cclxxxvi{اگر تم نے ایسا نہ کیا تو خد ا و رسول سے جنگ کرنے کے لئے تیار ہو جاؤ اور اگر توبہ کرلو تو اصل مال تمہارا ہی ہے . نہ تم ظلم کروگے نہ تم پر ظلم کیا جائے گا\qt@no{(279)}}%
\qt@newcmd\qurantrans@ur@cclxxxvii{اور اگر تمہارا مقروض تنگ دست ہے تو اسے وسعت حال تک مہلت دی جائے گی اور اگرتم معاف کردو گے توتمہارے حق میں زیادہ بہتر ہے بشرطیکہ تم اسے سمجھ سکو\qt@no{(280)}}%
\qt@newcmd\qurantrans@ur@cclxxxviii{اس دن سے ڈرو جب تم سب پلٹا کر اللہ کی بارگاہ میں لے جائے جاؤگے اس کے بعد ہر نفس کو اس کے کئے کا پورا پورا بدلہ ملے گا اور کسی پر کوئی ظلم نہیں کیا جائے گا\qt@no{(281)}}%
\qt@newcmd\qurantrans@ur@cclxxxix{ایمان والو جب بھی آپس میں ایک مقررہ مدّت کے لئے قرض کا لین دین کرو تو اسے لکھ لو اورتمہارے درمیان کوئی بھی کاتب لکھے لیکن انصاف کے ساتھ لکھے اور کاتب کو نہ چاہئے کہ خدا کی تعلیم کے مطابق لکھنے سے انکار کرے . اسے لکھ دینا چاہئے اور جس کے ذمہ قرض ہے اس کو چاہئے کہ وہ املا کرے اور اس خدا سے ڈرتا رہے جو اس کا پالنے والاہے اور کسی طرح کی کمی نہ کرے . اب اگرجس کے ذمہ قرض ہے وہ نادان کمزور یامضمون بتانے کے قابل نہیں ہے تو اس کا ولی مضمون تیار کرے---- اور اپنے مردوں میں سے دو کو گواہ بناؤ اور دو مذِد نہ ہوں تو ایک مذِد اور دو عورتیں تاکہ ایک بہکنے لگے تو دوسری یاد دلادے اور گواہوں کو چاہئے کہ گواہی کے لئے بلائے جائیں تو انکار نہ کریں اور خبردار لکھا پڑھی سے ناگواری کا اظہار نہ کرنا چاہے قرض چھوٹا ہو یا بڑا مّدت معین ہونی چاہئے .یہی پروردگار کے نزدیک عدالت کے مطابق اورگواہی کے لئے زیادہ مستحکم طریقہ ہے او ر اس امر سے قریب تر ہے کہ آپس میںشک و شبہ نہ پیدا ہو---- ہاں اگر تجارت نقد ہے جس سے تم لوگ آپس میں اموال کی الٹ پھیر کرتے ہو تو نہ لکھنے میں کوئی حرج بھی نہیں ہے اور اگر تجارت میں بھی گواہ بناؤ تو کاتب یا گواہ کو حق نہیں کہ اپنے طرزِ عمل سے لوگوں کو نقصان پہنچائے اور نہ لوگوں کو یہ حق ہے اوراگرتم نے ایسا کیا تویہ اطاعت خدا سے نافرمانی\qt@no{(282)}}%
\qt@newcmd\qurantrans@ur@ccxc{اور اگر تم سفر میں ہو اور کوئی کاتب نہیں مل رہا ہے تو کوئی رہن رکھ دو اور ایک کو دوسرے پر اعتبار ہو تو جس پراعتبار ہے اس کو چاہئے کہ امانت کو واپس کردے اورخدا سے ڈرتا رہے---- اور خبردار گواہی کو حُھپانا نہیں کہ جو ایسا کرے گا اس کا دل گنہگار ہوگا اور اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(283)}}%
\qt@newcmd\qurantrans@ur@ccxci{اللہ ہی کے لئے زمین و آسمان کی کِل کائنات ہے تم اپنے دل کی باتوں کا اظہار کرو یا ان پر پردہ ڈالو وہ سب کا محاسبہ کرے گا وہ جس کو چاہے گا بخش دے گااور جس پر چاہے گا عذاب کرے گا وہ ہرشے پر قدرت و اختیار رکھنے والا ہے\qt@no{(284)}}%
\qt@newcmd\qurantrans@ur@ccxcii{رسول ان تمام باتوں پر ایمان رکھتا ہے جو اس کی طرف نازل کی گئی ہیں اور مومنین بھی سب اللہ اور ملائکہ اور مرسلین پر ایمان رکھتے ہیں ان کا کہنا ہے کہ ہم رسولوں کے درمیان تفریق نہیں کرتے . ہم نے پیغام الٰہی کو صَنا اور اس کی اطاعت کی پروردگار اب تیری مغفرت درکار ہے اور تیری ہی طرف پلٹ کر آنا ہے\qt@no{(285)}}%
\qt@newcmd\qurantrans@ur@ccxciii{اللہ کس نفس کو اس کی وسعت سے زیادہ تکلیف نہیں دیتا . ہر نفس کے لئے اس کی حاصل کی ہوئی نیکیوں کا فائدہ بھی ہے اور اس کی کمائی ہوئی برائیوں کا مظلمہ بھی---- پروردگار! ہم جو کچھ بھول جائیں یا ہم سے غلطی ہوجائے اس کا ہم سے مواخذہ نہ کرنا . خدایا ہم پر ویسا بوجھ نہ ڈالنا جیسا پہلے والی امتوں پر ڈالا گیا ہے پروردگار ! ہم پر وہ بار نہ ڈالنا جس کی ہم میںطاقت نہ ہو . ہمیں معاف کردیناً ہمیں بخش دیناً ہم پر رحم کرنا توہمارا مولا اور مالک ہے اب کافروں کے مقابلہ میں ہماری مدد فرما\qt@no{(286)}}%
\qt@newcmd\qurantrans@ur@ccxciv{\basmalahur الۤم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@ccxcv{اللہ جس کے علاوہ کوئی خدا نہیں ہے اور وہ ہمیشہ زندہ ہے اور ہر شے اسی کے طفیل میں قائم ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@ccxcvi{اس نے آپ پر وہ برحق کتاب نازل کی ہے جو تمام کتابوں کی تصدیق کرنے والی ہے اور توریت و انجیل بھی نازل کی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@ccxcvii{اس سے پہلے لوگوں کے لئے ہدایت بنا کر اور حق و باطل میں فرق کرنے والی کتاب بھی نازل کی ہے بیشک جو لوگ آیااُ الٰہی کا انکار کرتے ہیں ان کے واسطے شدید عذاب ہے اور خدا سخت انتقام لینے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@ccxcviii{خدا کے لئے آسمان و زمین کی کوئی شے مخفی نہیں ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@ccxcix{وہ خدا جس طرح چاہتا ہے رحهِ مادر کے اندر تصویریں بناتا ہے اس کے علاوہ کوئی خدا نہیں ہے وہ صاحب عزّت بھی ہے اور صاحب هحکمت بھی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@ccc{اس نے آپ پروہ کتاب نازل کی ہے جس میں سے کچھ آیتیں لَحکم اور واضح ہیں جو اصل کتاب ہیں اور کچھ متشابہ ہیں - اب جن کے دلوں میں کجی ہے وہ ا ن ہی متشابہات کے پیچھے لگ جاتے ہیں تاکہ فتنہ برپا کریں اور من مانی تاویلیں کریں حالانکہ اس کی تاویل کا حکم صرف خدا کو ہے اور انہیں جو علم میں رسوخ رکھنے والے ہیں - جن کا کہنا یہ ہے کہ ہم اس کتاب پر ایمان رکھتے ہیں اور یہ سب کی سب محکم و متشابہ ہمارے پروردگار ہی کی طرف سے ہے اور یہ بات سوائے صاحبانِ عقل کے کوئی نہیں سمجھ سکتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@ccci{ان کا کہنا ہے کہ پروردگار جب تونے ہمیں ہدایت دے دی ہے تو اب ہمارے دلوں میں کجی نہ پیدا ہونے پائے اور ہمیں اپنے پاس سے رحمت عطا فرما کہ تو بہترین عطا کرنے والا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cccii{خدایا تو تمام انسانوں کو اس دن جمع کرنے والا ہے جس میں کوئی شک نہیں ہے. اور اللہ کا وعدہ غلط نہیں ہوتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@ccciii{جو لوگ کافر ہوگئے ہیں ان کے اموال و اولاد کچھ بھی کام آنے والے نہیں ہیں اور وہ جہّنم کا ایندھن بننے والے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@ccciv{ان کا حال بھی فرعونیوں اور ان سے پہلے لوگوں کا سا ہو گا جنھوں نے بمارے آیات کو جھٹلایا، پس الله نے انہیں ان کے گناہوں کے وجہ سے گرفت میں لے لیا اور الله سخت عذاب دینے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cccv{(اے رسول) جنہوں نے انکار کیا ہے ان سے کہدیجیے: تم عنقریب مغلوب ہو جاؤ گے اور جہنم کے طرف اکھٹے کیے جاؤ گے اور وہ بدترین ٹھکانا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cccvi{تمہارے واسطے ان دونوں گروہوں کے حالات میں ایک نشانی موجود ہے جو میدان جنگ میں آمنے سامنے آئے کہ ایک گروہ راسِ خدا میں جہاد کررہا تھا اور دوسرا کافر تھا جو ان مومنین کو اپنے سے دوگنا دیکھ رہا تھا اور اللہ اپنی نصرت کے ذریعہ جس کی چاہتا ہے تائید کرتا ہے اور اس میں صاحبان هنظر کے واسطے سامان هعبرت و نصیحت بھی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cccvii{لوگوں کے لئے خواہشااُ دنیا - عورتیں,اولاد, سونے چاندی کے ڈھیر, تندرست گھوڑے یا چوپائےً کھیتیاں سب مزیّن اور آراستہ کردی گئی ہیں کہ یہی متاع دنیا ہے اور اللہ کے پاس بہترین انجام ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cccviii{پیغمبر آپ کہہ دیں کہ کیا میں ان سب سے بہتر چیز کی خبر دوں- جو لوگ تقوٰی اختیار کرنے والے ہیں ان کے لئے پروردگار کے یہاں وہ باغات ہیں جن کے نیچے نہریں جاری ہیں اور وہ ان میں ہمیشہ رہنے والے ہیں . ان کے لئے پاکیزہ بیویاں ہیں اور اللہ کی خوشنودی ہے اور اللہ اپنے بندوں کے حالات سے خوب باخبر ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cccix{قابل تعریف ہیں وہ لوگ جو یہ کہتے ہیں کہ پروردگار ہم ایمان لے آئے- ہمارے گناہوں کو بخش دے اور ہمیں آتش جہّنم سے بچالے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cccx{یہ سب صبر کرنے والے, سچ بولنے والے, اطاعت کرنے والے, راہ خدا میں خرچ کرنے والے اور ہنگاهِ سحر استغفار کرنے والے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cccxi{اللہ خود گواہ ہے کہ اس کے علاوہ کوئی خدا نہیں ہے ملائکہ اور صاحبانِ علم گواہ ہیں کہ وہ عدل کے ساتھ قائم ہے- اس کے علاوہ کوئی خدا نہیں ہے اور وہ صاحبِ عزّت و حکمت ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cccxii{دین,اللہ کے نزدیک صرف اسلام ہے اور اہل کتاب نے علم آنے کے بعد ہی جھگڑا شروع کیا ہے صرف آپس کی شرارتوں کی بنائ پر اور جو بھی آیات الٰہی کا انکار کرے گا تو خدا بہت جلد حساب کرنے والا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cccxiii{اے پیغمبر اگر یہ لوگ آپ سے کٹ حجتی کریں تو کہہ دیجئے کہ میرا رخ تمام تر اللہ کی طرف ہے اور میرے پیرو بھی ایسے ہی ہیں اور پھر اہلِ کتاب اور جاہل مشرکین سے پوچھئے کیا تم اسلام لے آئے- اگر وہ اسلام لے آئے تو گویا ہدایت پاگئے اور اگر منہ پھیر لیا تو آپ کا فرض صرف تبلیغ تھا اور اللہ اپنے بندوں کو خوب پہچانتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cccxiv{جو لوگ آیات الٰہیہ کا انکار کرتے ہیں اور ناحق انبیائ کو قتل کرتے ہیں اور ان لوگوں کو قتل کرتے ہیں جو عدل و انصاف کا حکم دینے والے ہیں انہیں دردناک عذاب کی خبرصَنادیجئے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cccxv{یہی وہ لوگ ہیں جن کے اعمال دنیا میں بھی برباد ہوگئے اور آخرت میں بھی ان کا کوئی مددگار نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cccxvi{کیا تم نے ان لوگوں کو نہیں دیکھا جنہیں کتاب کا تھوڑا سا حصّہ دے دیا گیا کہ انہیں کتاب هخدا کی طرف فیصلہ کے لئے بلایا جاتا ہے تو ایک فریق مکر جاتا ہے اور وہ بالکل کنارہ کشی کرنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cccxvii{یہ اس لئے کہ ان کا عقیدہ ہے کہ انہیں آتش جہّنم صرف چند دن کے لئے چھوئے گی اور ان کو دین کے بارے میں ان کی افتراپردازیوں نے دھوکہ میں رکھا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cccxviii{اس وقت کیا ہوگا جب ہم سب کو اس دن جمع کریں گے جس میں کسی شک اور شبہہ کی گنجائش نہیں ہے اور ہر نفس کو اس کے کئے کا پورا پورا بدلہ دیا جائے گا اور کسی پر کوئی ظلم نہیں کیا جائے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cccxix{پیغمبر آپ کہئے کہ خدایا تو صاحب هاقتدار ہے جس کو چاہتا ہے اقتدار دیتا ہے اور جس سے چاہتا ہے سلب کرلیتا ہے- جس کو چاہتا ہے عزّت دیتا ہے اور جس کو چاہتا ہے ذلیل کرتا ہے- سارا خیر تیرے ہاتھ میں ہے اور تو ہی ہر شے پر قادر ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cccxx{تو رات کو دن اور دن کو رات میں داخل کرتا ہے اور مفِدہ کو زندہ سے اور زندہ کو مفِدہ سے نکالتا ہے اور جسے چاہتا ہے بے حساب رزق دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cccxxi{خبردار صاحبانِ ایمان .مومنین کو چھوڑ کر کفار کو اپنا و لی اور سرپرست نہ بنائیں کہ جو بھی ایسا کرے گا اس کا خدا سے کوئی تعلق نہ ہوگا مگر یہ کہ تمہیں کفار سے خوف ہو تو کوئی حرج بھی نہیں ہے اور خدا تمہیں اپنی ہستی سے ڈراتا ہے اور اسی کی طرف پلٹ کر جانا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cccxxii{آپ ان سے کہہ دیجئے کہ تم دل کی باتوں کو چھپاؤ یا اس کا اظہار کرو خدا تو بہرحال جانتا ہے اور وہ زمین و آسمان کی ہر چیز کو جانتا ہے اور ہر شے پر قدرت و اختیار رکھنے والا بھی ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cccxxiii{اس دن کو یاد کرو جب ہر نفس اپنے نیک اعمال کو بھی حاضر پائے گا اور اعمال بد کو بھی جن کو دیکھ کر یہ تمناّ کرے گا کہ کاش ہمارے اور ان اِرے اعمال کے درمیان طویل فاصلہ ہوجاتا اور خدا تمہیں اپنی ہستی سے ڈراتا ہے اور وہ اپنے بندوں پر مہربان بھی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cccxxiv{اے پیغمبر! کہہ دیجئے کہ اگر تم لوگ اللہ سے محبّت کرتے ہو تو میری پیروی کرو- خدا بھی تم سے محبّت کرے گا اور تمہارے گناہوں کو بخش دے گا کہ وہ بڑا بخشنے والا اور مہربان ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cccxxv{کہہ دیجئے کہ اللہ اور رسول کی اطاعت کرو کہ جو اس سے روگردانی کرے گا تو خدا کافرین کو ہرگز دوست نہیں رکھتا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cccxxvi{اللہ نے آدم علیھ السّلام,نوح علیھ السّلام اور آل ابراہیم علیھ السّلام اور آل عمران علیھ السّلام کو منتخب کرلیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cccxxvii{یہ ایک نسل ہے جس میں ایک کا سلسلہ ایک سے ہے اور اللہ سب کی سننے والا اور جاننے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cccxxviii{اس وقت کو یاد کرو جب عمران علیھ السّلام کی زوجہ نے کہا کہ پروردگار میں نے اپنے شکم کے بّچے کو تیرے گھر کی خدمت کے لئے نذر کردیا ہے اب تو قبول فرمالے کہ تو ہر ایک کی سننے والا اور نیتوں کا جاننے والا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cccxxix{اس کے بعد جب ولادت ہوئی تو انہوں نے کہا پروردگار یہ تو لڑکی ہے حالانکہ اللہ خوب جانتا ہے کہ وہ کیا ہے اور وہ جانتا ہے کہ لڑکا اس لڑکی جیسا نہیں ہوسکتا.اور میں نے اس کا نام مریم رکھا ہے اور میں اسے اور اس کی اولاد کو شیطان رجیم سے تیری پناہ میں دیتی ہوں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cccxxx{تو خدا نے اسے بہترین انداز سے قبول کرلیا اور اس کی بہترین نشوونما کا انتظام فرمادیا اور زکریا علیھ السّلام نے اس کی کفالت کی کہ جب زکریا علیھ السّلاممحراب هعبادت میں داخل ہوتے تو مریم کے پاس رزق دیکھتے اور پوچھتے کہ یہ کہاں سے آیا اور مریم جواب دیتیں کہ یہ سب خدا کی طرف ہے- وہ جسے چاہتا ہے رزق بے حساب عطا کردیتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cccxxxi{اس وقت زکریا علیھ السّلامنے اپنے پرودگار سے دعا کی کہ مجھے اپنی طرف سے ایک پاکیزہ اولاد عطا فرما کہ تو ہر ایک کی دعا کا سننے والا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cccxxxii{تو ملائکہ نے انہیں اس وقت آواز دی جب وہ محراب میں کھڑے مصرورِ عبادت تھے کہ خدا تمہیں یحیٰی علیھ السّلام کی بشارت دے رہا ہے جو اس کے کلمہ کی تصدیق کرنے والا, سردار, پاکیزہ کردار اور صالحین میں سے نبی ہوگا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cccxxxiii{انہوں نے عرض کی کہ میرے یہاں کس طرح اولاد ہوگی جب کہ مجھ پر بڑھاپا آگیا ہے اور میری عورت بھی بانجھ ہے تو ارشاد ہوا کہ خدا اسی طرح جو چاہتا ہے کرتاہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cccxxxiv{انہوں نے کہا کہ پروردگار میرے لئے قبولیت هدعا کی کوئی علامت قرار دے دے- ارشاد ہوا کہ تم تین دن تک اشاروں کے علاوہ بات نہ کرسکو گے اور خدا کا ذکر کثرت سے کرتے رہنا اور صبح و شام اس کی تسبیح کرتے رہنا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cccxxxv{اور اس وقت کو یاد کرو جب ملائکہ نے مریم کو آواز دی کہ خدا نے تمہیں چن لیا ہے اور پاکیزہ بنادیا ہے اور عالمین کی عورتوں میں منتخب قرار دے دیا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cccxxxvi{اے مریم تم اپنے پروردگار کی اطاعت کرو, سجدہ کرو, اور رکوع کرنے والوں کے ساتھ رکوع کرو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cccxxxvii{پیغمبر یہ غیب کی خبریں ہیں جن کی وحی ہم آپ کی طرف کررہے ہیں اور آپ تو ان کے پاس نہیں تھے جب وہ قرعہ ڈال رہے تھے کہ مریم کی کفالت کون کرے گا اور آپ ان کے پاس نہیں تھے جب وہ اس موضوع پر جھگڑا کررہے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cccxxxviii{اور اس وقت کو یاد کرو جب ملائکہ نے کہا کہ اے مریم خدا تم کو اپنے کلمہ مسیح عیسٰی علیھ السّلامبن مریم کی بشارت دے رہا ہے جو دنیا اور آخرت میں صاحبِ وجاہت اور مقربین بارگاہ الٰہی میں سے ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@cccxxxix{وہ لوگوں سے گہوارہ میں بھی بات کرے گا اور بھرپور جوان ہونے کے بعد بھی اور صالحین میں سے ہوگا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@cccxl{مریم نے کہا کہ میرے یہاں فرزند کس طرح ہوگا جب کہ مجھ کو کسی بشر نے چھوا بھی نہیں ہے- ارشاد ہوا کہ اسی طرح خدا جو چاہتاہے پیدا کرتا ہے جب وہ کسی کام کا فیصلہ کرلیتا ہے تو کہتا ہے کہ ہوجا اور وہ چیز ہوجاتی ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@cccxli{اور خدا اس فرزند کو کتاب و حکمت اور توریت و انجیل کی تعلیم دے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@cccxlii{اور اسے بنی اسرائیل کی طرف رسول بنائے گا اور وہ ان سے کہے گا کہ میں تمھارے پاس تمہارے پروردگار کی طرف سے نشانی لے کر آیا ہوں کہ میں تمہارے لئے مٹی سے پرندہ کی شکل بناؤں گا اور اس میں کچھ دم کردوں گا تو وہ حکهِ خدا سے پرندہ بن جائے گا اور میں پیدائشی اندھے اور َمبروص کا علاج کروں گا اور حکهِ خدا سے مفِدوں کو زندہ کروں گا اور تمہیں اس بات کی خبردوں گا کہ تم کیا کھاتے ہو اور کیا گھر میں ذخیرہ کرتے ہو- ان سب میں تمہارے لئے نشانیاں ہیں اگر تم صاحبانِ ایمان ہو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@cccxliii{اور میں اپنے پہلے کی کتاب توریت کی تصدیق کرنے والا ہوں اور میں بعض ان چیزوں کو حلال قرار دوں گا جو تم پر حرام تھیں اور تمھارے پروردگار کی طرف سے نشانی لے کر آیا ہوں لہذا اس سے ڈرو اور میری اطاعت کرو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@cccxliv{اللہ میرا اور تمہارا دونوں کا رب ہے لہذا اس کی عبادت کرو کہ یہی صراظُ مستقیم ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@cccxlv{پھر جب عیسٰی علیھ السّلام نے قوم سے کفر کا احساس کیا تو فرمایا کہ کون ہے جو خدا کی راہ میں میرا مددگار ہو...حواریین نے کہا کہ ہم اللہ کے مددگار ہیں- اس پر ایمان لائے ہیں اور آپ گواہ رہیں کہ ہم مسلمان ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@cccxlvi{پروردگار ہم ان تمام باتوں پر ایمان لے آئے جو تو نے نازل کی ہیں اور تیرے رسول کا اتباع کیا لہذا ہمارا نام اپنے رسول کے گواہوں میں درج کرلے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@cccxlvii{اور یہودیوں نے عیسٰی علیھ السّلام سے مکاری کی تو اللہ نے بھی جوابی تدبیر کی اور خدا بہترین تدبیر کرنے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@cccxlviii{اور جب خدا نے فرمایا کہ عیسٰی علیھ السّلام ہم تمہاری مدّاُ قیام دنیا پوری کرنے والے اور تمہیں اپنی طرف اُٹھالینے والے اور تمھیں کفار کی خباثت سے نجات دلانے والے اور تمھاری پیروی کرنے والوں کو انکار کرنے والوں پر قیامت تک کی برتری دینے والے ہیں- اس کے بعد تم سب کی بازگشت ہماری طرف ہوگی اور ہم تمہارے اختلافات کا صحیح فیصلہ کردیں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@cccxlix{پھر جن لوگوں نے کفر اختیار کیا ان پر دنیا اور آخرت میں شدید عذاب کریں گے اور ان کا کوئی مددگار نہ ہوگا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@cccl{اور جو لوگ ایمان لے آئے اور انہوں نے نیک اعمال کئے ان کو مکمل اجر دیں گے اور خدا ظلم کرنے والوں کو پسند نہیں کرتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@cccli{یہ تمام نشانیاں اور پفِاز حکمت تذکرے ہیں جو ہم آپ سے بیان کررہے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@ccclii{عیسٰی علیھ السّلام کی مثال اللہ کے نزدیک آدم علیھ السّلام جیسی ہے کہ انہیں مٹی سے پیدا کیا اور پھر کہا ہوجا اور وہ ہوگیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@cccliii{حق تمہارے پروردگار کی طرف سے آچکا ہے لہذا خبردار اب تمہارا شمار شک کرنے والوں میں نہ ہونا چاہئے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@cccliv{پیغمبر علم کے آجانے کے بعد جو لوگ تم سے کٹ حجتی کریں ان سے کہہ دیجئے کہ آؤ ہم لوگ اپنے اپنے فرزند, اپنی اپنی عورتوں اور اپنے اپنے نفسوں کو بلائیں اور پھر خدا کی بارگاہ میں دعا کریں اور جھوٹوں پر خدا کی لعنت قرار دیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@ccclv{یہ سب حقیقی واقعات ہیں اور خدا کے علاوہ کوئی دوسرا خدا نہیں ہے اور وہی خدا صاحبِ عزّت و حکمت\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@ccclvi{اب اس کے بعد بھی یہ لوگ انحراف کریں تو خدا مفسدین کو خوب جانتا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@ccclvii{اے پیغمبر آپ کہہ دیں کہ اہلِ کتاب آؤ ایک منصفانہ کلمہ پر اتفاق کرلیں کہ خدا کے علاوہ کسی کی عبادت نہ کریں کسی کو اس کا شریک نہ بنائیں آپس میں ایک دوسرے کو خدائی کا درجہ نہ دیں اور اس کے بعد بھی یہ لوگ منہ موڑیں تو کہہ دیجئے کہ تم لوگ بھی گواہ رہنا کہ ہم لوگ حقیقی مسلمان اور اطاعت گزار ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@ccclviii{اے اہلِ کتاب آخر ابراہیم علیھ السّلام کے بارے میں کیوں بحث کرتے ہو جب کہ توریت اور انجیل ان کے بعد نازل ہوئی ہے کیا تمہیں اتنی بھی عقل نہیں ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@ccclix{اب تک تم نے ان باتوں میں بحث کی ہے جن کا کچھ علم تھا تو اب اس بات میں کیوں بحث کرتے ہو جس کا کچھ بھی علم نہیں ہے بیشک خدا جانتا ہے اور تم نہیں جانتے ہو\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@ccclx{ابراہیم علیھ السّلام نہ یہودی تھے اور نہ عیسائی وہ مسلمان حق پرست اور باطل سے کنارہ کش تھے اور وہ مشرکین میں سے ہرگز نہیں تھے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@ccclxi{یقینا ابراہیم علیھ السّلام سے قریب تر ان کے پیرو ہیں اور پھر یہ پیغمبر اور صاحبانِ ایمان ہیں اور اللہ صاحبان هایمان کا سرپرست ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@ccclxii{اہلِ کتاب کا ایک گروہ یہ چاہتا ہے کہ تم لوگوں کو گمراہ کردے حالانکہ یہ اپنے ہی کو گمراہ کررہے ہیں اور سمجھتے بھی نہیں ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@ccclxiii{اے اہلِ هکتاب تم آیات هالٰہیٰہ کا انکار کیوں کررہے ہو جب کہ تم خود ہی ان کے گواہ بھی ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@ccclxiv{اے اہلِ کتاب کیوں حق کو باطل سے مشتبہ کرتے ہو اور جانتے ہوئے حق کی پردہ پوشی کرتے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@ccclxv{اور اہلِ کتاب کی ایک جماعت نے اپنے ساتھیوں سے کہا کہ جو کچھ ایمان والوں پر نازل ہوا ہے اس پر صبح کو ایمان لے آؤ اور شام کو انکار کر دو شاید اس طرح وہ لوگ بھی پلٹ جائیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@ccclxvi{اور خبردار ان لوگوں کے علاوہ کسی پر اعتبار نہ کرنا جو تمہارے دین کا اتباع کرتے ہیں.... پیغمبر آپ کہہ دیں کہ ہدایت صرف خدا کی ہدایت ہے اور ہرگز یہ نہ ماننا کہ خدا ویسی ہی فضیلت اور نبوت کسی اور کو بھی دے سکتا ہے جیسی تم کو دی ہے یا کوئی تم سے پیش پروردگار بحث بھی کرسکتا ہے پیغمبر آپ کہہ دیجئے کہ فضل و کرم خدا کے ہاتھ میں ہے وہ جسے چاہتا عطا کرتا ہے اور وہ صاحبِ وسعت بھی ہے اور صاحبِ علم بھی\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@ccclxvii{وہ اپنی رحمت سے جسے چاہتا ہے مخصوص کرتا ہے اور وہ بڑے فضل والا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@ccclxviii{اور اہلِ کتاب میں سے کچھ ایسے بھی ہیں جن کے پاس ڈھیر بھر مال بھی امانت رکھ دیا جائے تو واپس کردیں گے اور کچھ ایسے بھی ہیں کہ ایک دینار بھی امانت رکھ دی جائے تو اس وقت تک واپس نہ کریں گے جب تک ان کے سر پر کھڑے نہ رہو- یہ اس لئے کہ ان کا کہنا یہ ہے کہ عربوں کی طرف سے ہمارے اوپر کوئی ذمہ داری نہیں ہے یہ خدا کے خلاف جھوٹ بولتے ہیں اور جانتے بھی ہیں کہ جھوٹے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@ccclxix{بیشک جو اپنے عہد کو پورا کرے گا اور خورِ خدا پیدا کرے گا تو خدا متقّین کو دوست رکھتا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@ccclxx{جو لوگ اللہ سے کئے گئے عہد اور قسم کو تھوڑی قیمت پر بیچ ڈالتے ہیں ان کے لئے آخرت میں کوئی حصّہ نہیں ہے اور نہ خدا ان سے بات کرے گا اور نہ روزِ قیامت ان کی طرف نظر کرے گا اور نہ انہیں گناہوں کی آلودگی سے پاک بنائے گا اور ان کے لئے دردناک عذاب ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@ccclxxi{ان ہی یہودیوں میں سے بعض وہ ہیں جو کتاب پڑھنے میں زبان کو توڑ موڑ دیتے ہیں تاکہ تم لوگ اس تحریف کو بھی اصل کتاب سمجھنے لگو حالانکہ وہ اصل کتاب نہیں ہے اور یہ لوگ کہتے ہیں کہ یہ سب اللہ کی طرف سے ہے حالانکہ اللہ کی طرف سے ہرگز نہیں ہے یہ خدا کے خلاف جھوٹ بولتے ہیں حالانکہ سب جانتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@ccclxxii{کسی بشر کے لئے یہ مناسب نہیں ہے کہ خدا اسے کتاب و حکمت اور نبوت عطا کردے اور پھر وہ لوگوں سے یہ کہنے لگے کہ خدا کو چھوڑ کر ہمارے بندے بن جاؤ بلکہ اس کا قول یہی ہوتا ہے کہ اللہ والے بنو کہ تم کتاب کی تعلیم بھی دیتے ہو اور اسے پڑھتے بھی رہتے ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@ccclxxiii{وہ یہ حکم بھی نہیں دے سکتا کہ ملائکہ یا انبیائ کو اپنا پروردگار بنالو کیا وہ تمہیں کفر کا حکم دے سکتا ہے جب کہ تم لوگ مسلمان ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@ccclxxiv{اور اس وقت کو یاد کرو جب خدا نے تمام انبیائ سے عہد لیا کہ ہم تم کو جو کتاب و حکمت دے رہے ہیں اس کے بعد جب وہ رسول آجائے جو تمہاری کتابوں کی تصدیق کرنے والا ہے تو تم سب اس پر ایمان لے آنا اور اس کی مدد کرنا .اور پھر پوچھا کیا تم نے ان باتوں کا اقرار کرلیا اور ہمارے عہد کو قبول کرلیا تو سب نے کہا بیشک ہم نے اقرار کرلیا- ارشاد ہوا کہ اب تم سب گواہ بھی رہنا اور میں بھی تمہارے ساتھ گواہوں میں ہوں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@ccclxxv{اس کے بعد جو انحراف کرے گا وہ فاسقین کی منزل میں ہوگا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@ccclxxvi{کیا یہ لوگ دینِ خدا کے علاوہ کچھ اور تلاش کررہے ہیں جب کہ زمین و آسمان کی ساری مخلوقات بہ رضا و رغبت یا بہ جبر وکراہت اسی کی بارگاہ میں سر تسلیم خم کئے ہوئے ہے اور سب کو اسی کی بارگاہ میں واپس جانا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@ccclxxvii{پیغمبر ان سے کہہ دیجئے کہ ہمارا ایمان اللہ پر ہے اور جو ہم پر نازل ہوا ہے اور جو ابراہیم علیھ السّلام,اسماعیل علیھ السّلام, اسحاق علیھ السّلامًیعقوب علیھ السّلام اور اسباط علیھ السّلامپر نازل ہوا ہے اور جو موسٰی علیھ السّلام, عیسٰی علیھ السّلام اور انبیائ کو خدا کی طرف سے دیا گیا ہے ان سب پر ہے. ہم ان کے درمیان تفریق نہیں کرتے ہیں اور ہم خدا کے اطاعت گزار بندے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@ccclxxviii{اور جو اسلام کے علاوہ کوئی بھی دین تلاش کرے گا تو وہ دین اس سے قبول نہ کیا جائے گا اور وہ قیامت کے دن خسارہ والوں میں ہوگا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@ccclxxix{خدا اس قوم کو کس طرح ہدایت دے گا جو ایمان کے بعد کافر ہوگئی اور وہ خود گواہ ہے کہ رسول برحق ہے اور ان کے پاس کھلی نشانیاں بھی آچکی ہیں بیشک خدا ظالم قوم کو ہدایت نہیں دیتا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@ccclxxx{ان لوگوں کی جزا یہ ہے کہ ان پر خدا ً ملائکہ اور انسان سب کی لعنت ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@ccclxxxi{یہ ہمیشہ اسی لعنت میں گرفتار رہیں گے .ان کے عذاب میں تخفیف نہ ہوگی اور نہ انہیں مہلت دی جائے گی\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@ccclxxxii{علاوہ ان لوگوں کے جنہوں نے اس کے بعد توبہ کرلی اور اصلاح کرلی کہ خدا غفور اور رحیم ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiii{جن لوگوں نے ایمان کے بعد کفر اختیار کرلیا اور پھر کفر میں بڑھتے ہی چلے گئے ان کی توبہ ہرگز قبول نہ ہوگی اور وہ حقیقی طور پر گمراہ ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@ccclxxxiv{جن لوگوں نے کفر اختیار کیا اور اسی کفر کی حالت میں مرگئے ان سے ساری زمین بھر کر سونا بھی بطور فدیہ قبول نہیں کیا جائے گا اور ان کے لئے دردناک عذاب ہے اور ان کا کوئی مددگار نہیں ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@ccclxxxv{تم نیکی کی منزل تک نہیں پہنچ سکتے جب تک اپنی محبوب چیزوں میں سے راسِ خدا میں انفاق نہ کرو اور جو کچھ بھی انفاق کرو گے خدا اس سے بالکل باخبر ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvi{بنی اسرائیل کے لئے تمام کھانے حلال تھے سوائے اس کے جسے توریت کے نازل ہونے سے پہلے اسرائیل نے اپنے اوپر ممنوع قرار دے لیا تھا- اب تم توریت کو پڑھو اگر تم اپنے دعوٰی میں سچےّ ہو\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@ccclxxxvii{اس کے بعد جو بھی خدا پر بہتان رکھے گا اس کا شمار ظالمین میں ہوگا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@ccclxxxviii{پیغمبر آپ کہہ دیجئے کہ خدا سچاّ ہے .تم سب ملّت ابراہیم علیھ السّلام کا اتباع کرو وہ باطل سے کنارہ کش تھے اور مشرکین میں سے نہیں تھے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ccclxxxix{بیشک سب سے پہلا مکان جو لوگوں کے لئے بنایا گیا ہے وہ مکّہ میں ہے مبارک ہے اور عالمین کے لئے مجسم ہدایت ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@cccxc{اس میں کھلی ہوئی نشانیاں مقام ابراہیم علیھ السّلامہے اور جو اس میں داخل ہوجائے گا وہ محفوظ ہوجائے گا اور اللہ کے لئے لوگوں پر اس گھر کا حج کرنا واجب ہے اگر اس راہ کی استطاعت رکھتے ہوں اور جو کافر ہوجائے تو خدا تمام عالمین سے بے نیاز ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@cccxci{اے اہل ههکتاب کیوں آیات الٰہی کا انکار کرتے ہو جب کہ خدا تمہارے اعمال کا گواہ ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@cccxcii{کہئے اے اہلِ کتاب کیوں صاحبانِ ایمان کو راسِ خدا سے روکتے ہو اور اس میں کجی تلاش کرتے ہو جبکہ تم خود اس کی صحت کے گواہ ہو اور اللہ تمہارے اعمال سے غافل نہیں ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@cccxciii{اے ایمان والواگر تم نے اہلِ کتاب کے ِس گروہ کی اطاعت کرلی تو یہ تم کو ایمان کے بعد کفر کی طرف پلٹا دیں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@cccxciv{اور تم لوگ کس طرح کافر ہوجاؤ گے جب کہ تمہارے سامنے آیات هالٰہیٰہ کی تلاوت ہورہی ہے اور تمہارے درمیان رسول موجود ہے اور جو خدا سے وابستہ ہوجائے سمجھو کہ اسے سیدھے راستہ کی ہدایت کردی گئی\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@cccxcv{ایمان والو اللہ سے اس طرح ڈرو جو ڈرنے کا حق ہے اور خبردار اس وقت تک نہ مرنا جب تک مسلمان نہ ہوجاؤ\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@cccxcvi{اور اللہ کی ر سّی کو مضبوطی سے پکڑے رہو اور آپس میں تفرقہ نہ پیدا کرو اور اللہ کی نعمت کو یاد کرو کہ تم لوگ آپس میں دشمن تھے اس نے تمہارے دلوں میں اُلفت پیدا کردی تو تم اس کی نعمت سے بھائی بھائی بن گئے اور تم جہّنم کے کنارے پر تھے تو اس نے تمہیں نکال لیا اور اللہ اسی طرح اپنی آیتیں بیان کرتا ہے کہ شاید تم ہدایت یافتہ بن جاؤ\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@cccxcvii{اور تم میں سے ایک گروہ کو ایسا ہونا چاہئے جو خیر کی دعوت دے, نیکیوں کا حکم دے برائیوں سے منع کرے اور یہی لوگ نجات یافتہ ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@cccxcviii{اور خبردار ان لوگوں کی طرح نہ ہوجاؤ جنہوں نے تفرقہ پیدا کیا اور واضح نشانیوں کے آجانے کے بعد بھی اختلاف کیا کہ ان کے لئے عذاب هعظیم ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@cccxcix{قیامت کے دن جب بعض چہرے سفید ہوں گے اور بعض سیاہ. جن کے چہرے سیاہ ہوں گے ان سے کہا جائے گا کہ تم ایمان کے بعد کیوں کافر ہوگئے تھے اب اپنے کفر کی بنائ پر عذاب کا مزہ چکھو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@cd{اور جن کے چہرے سفید اور روشن ہوں گے وہ رحمت الٰہی میں ہمیشہ ہمیشہ رہیں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@cdi{یہ آیااُ الٰہی ہیں جن کی ہم حق کے ساتھ تلاوت کررہے ہیں اور اللہ عالمین کے بارے میں ہرگز ظلم نہیں چاہتا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@cdii{زمین و آسمان میں جو کچھ ہے سب اللہ کے لئے ہے اور اسی کی طرف سارے امور کی باز گشت ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@cdiii{تم بہترین امت ہو جسے لوگوں کے لئے منظرعام پر لایا گیا ہے تم لوگوں کو نیکیوں کا حکم دیتے ہو اور برائیوں سے روکتے ہو اور اللہ پر ایمان رکھتے ہو اور اگر اہل کتاب بھی ایمان لے آتے تو ان کے حق میں بہتر ہوتا لیکن ان میں صرف چند مومنین ہیں اور اکثریت فاسق ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cdiv{یہ تم کو اذیت کے علاوہ کوئی نقصان نہیں پہنچاسکتے اور اگر تم سے جنگ بھی کریں گے تو میدان چھوڑ کر بھاگ جائیں گے اور پھر ان کی مدد بھی نہ کی جائے گی\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cdv{ان پر ذلّت کے نشان لگادئیے گئے ہیں یہ جہاں بھی رہیں مگر یہ کہ خدائی عہد یا لوگوں کے معاہدہ کی پناہ مل جائے .یہ غضبِ الٰہی میں رہیں گے اور ان پر مسکنت کی مار رہے گی. یہ اس لئے ہے کہ یہ آیات الٰہی کا انکار کرتے تھے اور ناحق انبیائ کو قتل کرتے تھے. یہ اس لئے کہ یہ نافرمان تھے اور زیادتیاں کیا کرتے تھے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cdvi{یہ لوگ بھی سب ایک جیسے نہیں ہیں .اہلِ کتاب ہی میں وہ جماعت بھی ہے جو دین پر قائم ہے راتوں کو آیات الٰہی کی تلاوت کرتی ہے اور سجدہ کرتی ہے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cdvii{یہ اللہ اور آخرت پر ایمان رکھتے ہیں. نیکیوں کا حکم دیتے ہیں برائیوں سے روکتے ہیں اور نیکیوں کی طرف سبقت کرتے ہیں اور یہی لوگ صالحین اور نیک کرداروں میں ہیں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cdviii{یہ جو بھی خیر کریں گے اس کا انکار نہ کیا جائے گا اور اللہ متّقین کے اعمال سے خوب باخبر ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cdix{جن لوگوں نے کفر اختیار کیا ان کے مال و اولاد کچھ کام نہ آئیں گے اور یہ حقیقی جہّنمی ہیں اور وہیں ہمیشہ رہنے والے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cdx{یہ لوگ زندگانی دنیا میں جو کچھ خرچ کرتے ہیں اس کی مثال اس ہوا کی ہے جس میں بہت پالا ہو اور وہ اس قوم کے کھیتوں پر گر پڑے جنہوں نے اپنے اوپر ظلم کیا ہے اور اسے تباہ کردے اور یہ ظلم ان پر خدا نے نہیں کیا ہے بلکہ یہ خود اپنے اوپر ظلم کرتے ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cdxi{اے ایمان والو خبردار غیروں کو اپنا راز دار نہ بنانا یہ تمہیں نقصان پہنچانے میں کوئی کوتاہی نہ کریں گے- یہ صرف تمہاری مشقت و مصیبت کے خواہش مند ہیں- ان کی عداوت زبان سے بھی ظاہر ہے اور جو دل میں چھپا رکھا ہے وہ تو بہت زیادہ ہے. ہم نے تمہارے لئے نشانیوں کو واضح کرکے بیان کردیا ہے اگر تم صاحبانِ عقل ہو\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cdxii{خبردار... تم ان سے دوستی کرتے ہو اور یہ تم سے دوستی نہیں کرتے ہیں- تم تمام کتابوں پر ایمان رکھتے ہو اور یہ جب تم سے ملتے ہیں تو کہتے ہیں کہ ہم ایمان لے آئے اور جب اکیلے ہوتے ہیں تو غّصہ سے انگلیاںکاٹتے ہیں- پیغمبر آپ کہہ دیجئے کہ تم اسی غّصہ میں مرجاؤ. خدا سب کے دل کے حالات سے خوب باخبر ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cdxiii{تمہیں ذرا بھی نیکی ملے تو انہیں برا لگے گا اور تمہیں تکلیف پہنچ جائے گی تو خوش ہوں گے اور اگر تم صبر کرو اور تقوٰی اختیار کرو تو ان کے مکر سے کوئی نقصان نہ ہوگا خدا ان کے اعمال کا احاطہ کئے ہوئے ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cdxiv{اس وقت کو یاد کرو جب تم صبح سویرے گھر سے نکل پڑے اور مومنین کو جنگ کی پوزیشن بتارہے تھے اور خدا سب کچھ سننے والا اور جاننے والا ہے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cdxv{اس وقت جب تم میں سے دو گروہوں نےصَستی کا مظاہرہ کرنا چاہا لیکن بچ گئے کہ اللہ ان کا سرپرست تھا اور اسی پر ایمان والوں کو بھروسہ کرنا چاہئے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cdxvi{اور اللہ نے بدر میں تمہاری مدد کی ہے جب کہ تم کمزور تھے لہذا اللہ سے ڈرو شاید تم شکر گزار بن جاؤ\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cdxvii{اس وقت جب آپ مومنین سے کہہ رہے تھے کہ کیا یہ تمہارے لئے کافی نہیں ہے کہ خدا تین ہزار فرشتوں کو نازل کرکے تمہاری مدد کرے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cdxviii{یقینا اگر تم صبر کرو گے اور تقوٰی اختیار کرو گے اور دشمن فی الفور تم تک آجائیں گے تو خدا پانچ ہزار فرشتوں سے تمہاری مدد کرے گا جن پر بہادری کے نشان لگے ہوں گے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cdxix{اور اس امداد کو خدانے صرف تمہارے لئے بشارت اور اطمینانِ قلب کا سامان قرار دیا ہے ورنہ مدد تو ہمیشہ صرف خدائے عزیز و حکیم ہی کی طرف سے ہوتی ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cdxx{تاکہ کفار کے ایک حصّہ کو کاٹ دے یا ان کو ذلیل کردے کہ وہ رسوا ہوکر پلٹ جائیں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cdxxi{ان معاملات میں آپ کا کوئی حصہّ نہیں ہے .چاہے خدا توبہ قبول کرے یا عذاب کرے. یہ سب بہرحال ظالم ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cdxxii{اور اللرُ ہی کے لئے زمین و آسمان کی کل کائنات ہے وہ جس کو چاہتا ہے بخش دیتا ہے اور جس پر چاہتا ہے عذاب کرتا ہے وہ غفور بھی ہے اور رحیم بھی ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cdxxiii{اے ایمان والو یہ دوگنا چوگنا سود نہ کھاؤ اور ا للہ سے ڈرو کہ شاید نجات پاجاؤ\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cdxxiv{اور اس آگ سے بچو جو کافروں کے واسطے مہیا کی گئی ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cdxxv{اور اللہ و رسول کی اطاعت کرو کہ شاید رحم کے قابل ہوجاؤ\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cdxxvi{اور اپنے پروردگار کی مغفرت اور اس جنّت کی طرف سبقت کرو جس کی وسعت زمین و آسمان کے برابر ہے اور اسے ان صاحبان هتقوٰی کے لئے مہیاّ کیا گیا ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cdxxvii{جو راحت اور سختی ہر حال میں انفاق کرتے ہیں اور غصّہ کو پی جاتے ہیں اور لوگوں کو معاف کرنے والے ہیں اور خدا احسان کرنے والوں کو دوست رکھتا ہے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cdxxviii{وہ لوگ وہ ہیں کہ جب کوئی نمایاں گناہ کرتے ہیں یا اپنے نفس پر ظلم کرتے ہیں تو خدا کو یاد کرکے اپنے گناہوں پر استغفار کرتے ہیں اور خدا کے علاوہ کون گناہوں کا معاف کرنے والا ہے اور وہ اپنے کئے پر جان بوجھ کر اصرار نہیں کرتے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cdxxix{یہی وہ ہیں جن کی جزا مغفرت ہے اور وہ جنّت ہے جس کے نیچے نہریں جاری ہیں .وہ اسی میں ہمیشہ رہنے والے ہیں اور عمل کرنے کی یہ جزا بہترین جزا ہے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cdxxx{تم سے پہلے مثالیں گزر چکی ہیں اب تم زمین میں سیر کرو اور دیکھو کہ جھٹلانے والوں کا کیا انجام ہوتا ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cdxxxi{یہ عام انسانوں کے لئے ایک بیان حقائق ہے اور صاحبانِ تقویٰ کے لئے ہدایت اور نصیحت ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cdxxxii{خبردار سستی نہ کرنا. مصائب پر محزون نہ ہونا اگر تم صاحب هایمان ہو تو سر بلندی تمہارے ہی لئے ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cdxxxiii{اگر تمہیں کوئی تکلیف چھولیتی ہے تو قوم کو بھی اس سے پہلے ایسی ہی تکلیف ہوچکی ہے اور ہم تو زمانے کو لوگوں کے درمیان الٹتے پلٹتے رہتے ہیں تاکہ خدا صاحبانِ ایمان کو دیکھ لے اور تم میں سے بعض کو شہدائ قرار دے اور وہ ظالمین کو دوست نہیں رکھتا ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cdxxxiv{اور خدا صاحبان هایمان کو چھانٹ کر الگ کرنا چاہتا تھا اور کافروں کو مٹا دینا چاہتا تھا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cdxxxv{کیا تمہارا یہ خیال ہے کہ تم جنّت میں یوں ہی داخل ہوجاؤ گے جب کہ خدا نے تم میں سے جہاد کرنے والوں اور صبر کرنے والوں کو بھی نہیں جانا ہے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cdxxxvi{تم موت کی ملاقات سے پہلے اس کی بہت تمنّا کیا کرتے تھے اور جیسے ہی اسے دیکھا دیکھتے ہی رہ گئے\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cdxxxvii{اور محمد تو صرف ایک رسول ہیں جن سے پہلے بہت سے رسول گزر چکے ہیں کیااگر وہ مر جائیں یا قتل ہو جائیں تو تم اُلٹے پیروں پلٹ جاؤ گے تو جو بھی ایسا کرے گا وہ خدا کا کوئی نقصان نہیں کرے گا اور خدا تو عنقریب شکر گزاروں کو ان کی جزا دے گا\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cdxxxviii{کوئی نفس بھی اسُنِ پروردگار کے بغیر نہیں مرسکتا ہے سب کی ایک اجل اور مدّت معین ہے اور جو دنیا ہی میں بدلہ چاہے گا ہم اسے وہ دیں گے اور جو آخرت کا ثواب چاہے گا ہم اسے اس میں سے عطا کردیں گے اور ہم عنقریب شکر گزاروں کو جزا دیں گے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cdxxxix{اور بہت سے ایسے نبی گزر چکے ہیں جن کے ساتھ بہت سے اللہ والوں نے اس شان سے جہاد کیا ہے کہ راسِ خدا میں پڑنے والی مصیبتوں سے نہ کمزور ہوئے اور نہ بزدلی کا اظہار کیا اور نہ دشمن کے سامنے ذلّت کا مظاہرہ کیا اور اللہ صبر کرنے والوں ہی کو دوست رکھتا ہے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cdxl{ان کا قول صرف یہی تھا کہ خدایا ہمارے گناہوں کو بخش دے- ہمارے امور میں زیادتیوں کو معاف فرما- ہمارے قدموں کو ثبات عطا فرما اور کافروں کے مقابلہ میں ہماری مدد فرما\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cdxli{تو خدا نے انہیں معاوضہ بھی دیا اور آخرت کا بہترین ثواب بھی دیا اور اللہ نیک عمل کرنے والوں کو دوست رکھتا ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cdxlii{ایمان والو اگر تم کفر اختیار کرنے والوں کی اطاعت کرلو گے تو یہ تمہیں اُلٹے پاؤںپلٹا لے جائیں گے اور پھر تم ہی اُلٹے خسارہ والوں میں ہوجاؤ گے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cdxliii{بلکہ خدا تمہارا سرپرست ہے اور و ہ بہترین مدد کرنے والا ہے\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cdxliv{ہم عنقریب کافروں کے دلوں میں تمہارا رعب ڈال دیں گے کہ انہوں نے اس کو خدا کا شریک بنایا ہے جس کے بارے میں خدا نے کوئی دلیل نازل نہیں کی ہے اور ان کا انجام جہّنم ہوگا اور وہ ظالمین کا بدترین ٹھکانہ ہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cdxlv{خدا نے اپنا وعدہ اس وقت پورا کردیا جب تم اس کے حکم سے کفاّر کو قتل کررہے تھے یہاں تک کہ تم نے کمزوری کا مظاہرہ کیا اور آپس میں جھگڑا کرنے لگے اور اس وقت خدا کی نافرمانی کی جب اس نے تمہاری محبوب شے کو دکھلا دیا تھا تم میں کچھ دنیا کے طلب گار تھے اور کچھ آخرت کے- اس کے بعد تم کو ان کفاّر کی طرف سے پھیر دیا تاکہ تمہارا امتحان لیا جائے اور پھر اس نے تمہیں معاف بھی کردیا کہ وہ صاحبانِ ایمان پر بڑا فضل و کرم کرنے والا ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cdxlvi{اس وقت کو یاد کرو جب تم بلندی پر جارہے تھے اور مڑ کر کسی کو دیکھتے بھی نہ تھے جب کہ رسول پیچھے کھڑے تمہیں آواز دے رہے تھے جس کے نتیجہ میں خدا نے تمہیں غم کے بدلے غم دیا تاکہ نہ اس پر رنجیدہ ہو جو چیز ہاتھ سے نکل گئی اور نہ اس مصیبت پر جو نازل ہوگئی ہے اور اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cdxlvii{اس کے بعد خدا نے ایک گروہ پرپُر سکون نیند طاری کردی اور ایک کو نیند بھی نہ آئی کہ اسے صرف اپنی جان کی فکر تھی اور ان کے ذہن میں خلاف حق جاہلیت جیسے خیالات تھے اور وہ یہ کہہ رہے تھے کہ جنگ کے معاملات میں ہمارا کیا اختیار ہے پیغمبر آپ کہہ دیجئے کہ اختیار صرف خدا کا ہے- یہ اپنے دل میں وہ باتیں چھپائے ہوئے ہیں جن کا آپ سے اظہار نہیں کرتے اور کہتے ہیں کہ اگر اختیار ہمارے ہاتھ میں ہوتا تو ہم یہاں نہ مارے جاتے تو آپ کہہ دیجئے کہ اگر تم گھروں میں بھی رہ جاتے تو جن کے لئے شہادت لکھ دی گئی ہے وہ اپنے مقتل تک بہرحال جاتے اور خدا تمہارے دلوں کے حال کو آزمانا چاہتا ہے اور تمہارے ضمیر کی حقیقت کو واضح کرنا چاہتا ہے اور وہ خود ہر دل کا حال جانتا ہے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cdxlviii{جن لوگوں نے دونوں لشکروں کے ٹکراؤ کے دن پیٹھ پھیرلی یہ وہی ہیں جنہیں شیطان نے ان کے کئے دھرے کی بنائ پر بہکا دیاہے اور خدا نے ان کو معاف کردیا کہ وہ غفور اور حلیم ہے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cdxlix{اے ایمان والوں خبردار کافروں جیسے نہ ہوجاؤ جنہوں نے اپنے ساتھیوں کے سفر یا جنگ میں مرنے پر یہ کہنا شروع کردیا کہ وہ ہمارے پاس ہوتے تو نہ مرتے اور نہ قتل کئے جاتے.. خدا تمہاری علیحدگی ہی کو ان کے لئے باعجُ مسرّت قرار دینا چاہتا ہے کہ موت و حیات اسی کے اختیار میں ہے اور وہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cdl{اگر تم راسِ خدا میں مرگئے یا قتل ہوگئے تو خدا کی طرف سے مغفرت اور رحمت ان چیزوں سے کہیں زیادہ بہتر ہے جنہیں یہ جمع کررہے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cdli{اور تم اپنی موت سے مرو یا قتل ہوجاؤ سب اللہ ہی کی بارگاہ میں حاضر کئے جاؤ گے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cdlii{پیغمبر یہ اللہ کی مہربانی ہے کہ تم ان لوگوں کے لئے نرم ہو ورنہ اگر تم بدمزاج اور سخت دل ہوتے تو یہ تمہارے پاس سے بھاگ کھڑے ہوتے لہذا اب انہیں معاف کردو- ان کے لئے استغفار کرو اور ان سے امر جنگ میں مشورہ کرو اور جب ارادہ کرلو تو اللہ پر بھروسہ کرو کہ وہ بھروسہ کرنے والوں کو دوست رکھتا ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cdliii{اللہ تمہاری مدد کرے گا تو کوئی تم پر غالب نہیں آسکتا اور وہ تمہیں چھوڑ دے گا تو اس کے بعد کون مدد کرے گا اور صاحبانِ ایمان تو اللہ ہی پر بھروسہ کرتے ہیں\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cdliv{کسی نبی کے لئے یہ ممکن نہیں ہے کہ وہ خیانت کرے اور جو خیانت کرے گا وہ روزِ قیامت خیانت کے مال سمیت حاضر ہوگا اس کے بعد ہر نفس کو اس کے کئے کا پورا پورا بدلہ دیا جائے گا اور کسی پر کوئی ظلم نہیں کیاجائے گا\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cdlv{کیا رضائے الٰہی کا اتباع کرنے والا اس کے جیسا ہوگا جو غضب الٰہی میں گرفتار ہو کہ اس کا انجام جہّنم ہے اور وہ بدترین منزل ہے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cdlvi{سب کے پیش پروردگار درجات ہیں اور خدا سب کے اعمال سے باخبر ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cdlvii{یقنیا خدا نے صاحبانِ ایمان پر احسان کیا ہے کہ ان کے درمیان ان ہی میں سے ایک رسول بھیجا ہے جو ان پر آیات الٰہیٰہ کی تلاوت کرتا ہے انہیں پاکیزہ بناتا ہے اور کتاب و حکمت کی تعلیم دیتا ہے اگرچہ یہ لوگ پہلے سے بڑی کھلی گمراہی میں مبتلا تھے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cdlviii{کیا جب تم پر وہ مصیبت پڑی جس کی دوگنی تم کفّارپر ڈال چکے تھے تو تم نے یہ کہنا شروع کردیا کہ یہ کیسے ہوگیا تو پیغمبر آپ کہہ دیجئے کہ یہ سب خود تمہاری طرف سے ہے اور اللہ ہر شے پر قادر ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cdlix{اورجو کچھ بھی اسلام و کفر کے لشکر کے مقابلہ کے دن تم لوگوں کو تکلیف پہنچی ہے وہ خدا کے علم میں ہے اور اسی لئے کہ وہ مومنین کو جاننا چاہتا تھا\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@cdlx{اور منافقین کو بھی دیکھنا چاہتا تھا .ان منافقین سے کہا گیا کہ آؤ راسِ خدا میں جہاد کرو یا اپنے نفس سے دفاع کرو تو انہوں نے کہا کہ ہم کو معلوم ہوتا کہ واقعی جنگ ہوگی تو تمہارے ساتھ ضرور آتے.. یہ ایمان کی نسبت کفر سے زیادہ قریب تر ہیں اور زبان سے وہ کہتے ہیں جو دل میں نہیں ہوتا اور اللہ ان کے پوشیدہ امور سے باخبر ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@cdlxi{یہی وہ لوگ ہیں جنہوں نے اپنے مقتول بھائیوں کے بارے میں یہ کہنا شروع کردیا کہ وہ ہماری اطاعت کرتے تو ہرگز قتل نہ ہوتے تو پیغمبر ان سے کہہ دیجئے کہ اگر اپنے دعوٰی میں سچےّ ہو تو اب اپنی ہی موت کو ٹال دو\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@cdlxii{اور خبردار راسِ خدا میں قتل ہونے والوں کو مردہ خیال نہ کرنا وہ زندہ ہیں اور اپنے پروردگار کے یہاں رزق پارہے ہیں\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@cdlxiii{خدا کی طرف سے ملنے والے فضل و کرم سے خوش ہیں اور جو ابھی تک ان سے ملحق نہیں ہوسکے ہیں ان کے بارے میں یہ خوش خبری رکھتے ہیں کہ ان کے واسطے بھی نہ کوئی خوف ہے اور نہ حزن\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@cdlxiv{وہ اپنے پروردگار کی نعمت, اس کے فضل اور اس کے وعدہ سے خوش ہیں کہ وہ صاحبانِ ایمان کے اجر کو ضائع نہیں کرتا\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@cdlxv{یہ صاحبانِ ایمان ہیں جنہوں نے زخمی ہونے کے بعد بھی خدا اور رسول کی دعوت پر لبیک کہی- ان کے نیک کردار اور متقی افراد کے لئے نہایت درجہ اج» عظیم ہے\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@cdlxvi{یہ وہ ایمان والے ہیں کہ جب ان سے بعض لوگوں نے کہاکہ لوگو ں نے تمہارے لئے عظےم لشکر جمع کرلیا ہے لہذا ان سے ڈرو تو ان کے ایمان میں اور اضافہ ہوگیا اور انہوں نے کہا کہ ہمارے لئے خدا کافی ہے اور وہی ہمارا ذمہ دار ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@cdlxvii{پس یہ مجاہدین خدا کے فضل و کرم سے یوں پلٹ آئے کہ انہیں کوئی تکلیف نہیں پہنچی اور انہوں نے رضائے الٰہی کا اتباع کیااور اللہ صاحبِ فضلِ عظیم ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@cdlxviii{یہ شیطان صرف اپنے چاہنے والوں کو ڈراتا ہے لہذا تم ان سے نہ ڈرو اور اگر مومن ہو تو مجھ سے ڈرو\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@cdlxix{اور آپ کفر میں تیزی کرنے والوں کی طرف سے رنجیدہ نہ ہوں یہ خدا کا کوئی نقصان نہیں کرسکتے... خدا چاہتا ہے کہ ان کا آخرت میں کوئی حصّہ نہ رہ جائے اور صرف عذابِ عظیم رہ جائے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@cdlxx{جن لوگوں نے ایمان کے بدلے کفر خرید لیا ہے وہ خدا کو کوئی نقصان نہیں پہنچاسکتے اور ان کے لئے دردناک عذاب ہے\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@cdlxxi{اور خبردار یہ کفاّر یہ نہ سمجھیں کہ ہم جس قدر راحت و آرام دے رہے ہیں وہ ان کے حق میں کوئی بھلائی ہے- ہم تو صرف اس لئے دے رہے ہیں کہ جتنا گناہ کرسکیں کرلیں ورنہ ان کے لئے رسوا کن عذاب ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@cdlxxii{خدا صاحبان هایمان کو ان ہی حالات میں نہیں چھوڑ سکتا جب تک خبیث اور طیّب کو الگ الگ نہ کردے اور وہ تم کو غیب پر مطلع بھی نہیں کرنا چاہتا ہاں اپنے نمائندوں میں سے کچھ لوگوں کو اس کام کے لئے منتخب کرلیتا ہے لہذا تم خدا اور رسول پر ایمان رکھو اور اگر ایمان و تقوٰی اختیار کرو گے تو تمہارے لئے اجر عظیم ہے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@cdlxxiii{اور خبردار جو لوگ خدا کے دیئے ہوئے میں بخل کرتے ہیں ان کے بارے میں یہ نہ سوچنا کہ اس بخل میں کچھ بھلائی ہے- یہ بہت اِرا ہے اور عنقریب جس مال میں بخل کیا ہے وہ روزِ قیامت ان کی گردن میں طوق بنا دیا جائے گا اور اللہ ہی کے لئے زمین و آسمان کی ملکیت ہے اور وہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@cdlxxiv{اللہ نے ان کی بات کوبھی سن لیا ہے جن کا کہنا ہے کہ خدا فقیر ہے اور ہم مالدار ہیں- ہم ان کی اس مہمل بات کو اور ان کے انبیائ کے ناحق قتل کرنے کو لکھ رہے ہیں اور انجام کار ان سے کہیں گے کہ اب جہّنم کا مزا چکھو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@cdlxxv{اس لئے کہ تم نے پہلے ہی اس کے اسباب فراہم کرلئے ہیں اور خدا اپنے بندوں پر ظلم نہیں کرتا ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@cdlxxvi{جو لوگ یہ کہتے ہیں کہ اللہ نے ہم سے عہد لیا ہے کہ ہم اس وقت تک کسی رسول پر ایمان نہ لائیں جب تک وہ ایسی قربانی پیش نہ کرے جسے آسمانی آگ کھا جائے تو ان سے کہہ دیجئے کہ مجھ سے پہلے بہت سے رسول معجزات اور تمہاری فرمائش کے مطابق صداقت کی نشانی لے آئے پھر تم نے انہیں کیوں قتل کردیا اگر تم اپنی بات میں سچےّ ہو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@cdlxxvii{اس کے بعد بھی آپ کی تکذیب کریں تو آپ سے پہلے بھی رسولوں کی تکذیب ہوچکی ہے جو معجزات, مواعظ اور روشن کتاب سب کچھ لے کر آئے تھے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@cdlxxviii{ہر نفس موت کا مزہ چکھنے والا ہے اور تمہارا مکمل بدلہ تو صرف قیامت کے دن ملے گا- اس وقت جسے جہّنم سے بچا لیا گیا اور جنّت میں داخل کردیا گیا وہ کامیاب ہے اور زندگانی دنیا تو صرف دھوکہ کاسرمایہ ہے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@cdlxxix{یقینا تم اپنے اموال اور نفوس کے ذریعہ آزمائے جاؤگے اور جن کو تم سے پہلے کتاب دی گئی ہے اور جو مشرک ہوگئے ہیں سب کی طرف سے بہت اذیت ناک باتیں سنوگے- اب اگر تم صبر کروگے اور تقوٰی اختیارکروگے تو یہی امورمیں استحکام کا سبب ہے\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@cdlxxx{اس موقع کو یاد کرو جب خدا نے جن کو کتاب دی ان سے عہد لیا کہ اسے لوگوں کے لئے بیان کریں گے اور اسے حُھپائیں گے نہیں.. لیکن انہوں نے اس عہد کو پبُ پشت ڈال دیا اور تھوڑی قیمت پر بیچ دیا تو یہ بہت اِرا سودا کیا ہے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@cdlxxxi{خبردار جو لوگ اپنے کئے پر مغرور ہیں اور چاہتے ہیں کہ جو اچھے کام نہیں کئے ہیں ان پر بھی ان کی تعریف کی جائے تو خبردار انہیں عذاب سے محفوظ خیال بھی نہ کرنا- ان کے لئے دردناک عذاب ہے\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@cdlxxxii{اور اللہ کے لئے زمین و آسمان کی کل حکومت ہے اور وہ ہر شے پر قادر ہے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiii{بے شک زمین و آسمان کی خلقت لیل و نہار کی آمدو رفت میں صاحبانِ عقل کے لئے قدرت کی نشانیاں ہیں\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@cdlxxxiv{جو لوگ اٹھتے, بیٹھتے, لیٹتے خدا کو یاد کرتے ہیں اور آسمان و زمین کی تخلیق میں غوروفکر کرتے ہیں... کہ خدایا تو نے یہ سب بے کار نہیں پیدا کیا ہے- تو پاک و بے نیاز ہے ہمیں عذاب جہّنم سے محفوظ فرما\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@cdlxxxv{پروردگار تو جسے جہّنم میں ڈال دے گا گویا اسے ذلیل و فِسوا کردیا اور ظالمین کا کوئی مددگار نہیں ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvi{پروردگار ہم نے اس منادی کو صَنا جو ایمان کی آواز لگا رہا تھا کہ اپنے پروردگار پر ایمان لے آؤ تو ہم ایمان لے آئے- پروردگار اب ہمارے گناہوں کو معاف فرما اور ہماری برائیوں کی پردہ پوشی فرما اور ہمیں نیک بندوں کے ساتھ محشور فرما\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@cdlxxxvii{پروردگار جو تو نے اپنے رسولوں سے وعدہ کیا ہے اسے عطا فرما اور روزِ قیامت ہمیں رسوا نہ کرنا کہ تو وعدہ کے خلاف نہیں کرتا\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@cdlxxxviii{پس خدا نے ان کی دعا کوقبول کیا کہ میں تم میںسے کسی بھی عمل کرنے والے کے عمل کو ضائع نہیں کروں گا چاہے وہ مرد ہو یا عورت- تم میں بعض بعض سے ہیں- پس جن لوگوں نے ہجرت کی اور اپنے وطن سے نکالے گئے اور میری راہ میں ستائے گئے اور انہوں نے جہاد کیا اور قتل ہوگئے تو میں ان کی برائیوں کی پردہ پوشی کروں گا اور انہیں ان جنتوں میں داخل کروں گا جن کے نیچے نہریں جاری ہوں گی- یہ خدا کی طرف سے ثواب ہے اور اس کے پاس بہترین ثواب ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@cdlxxxix{خبردار تمہیں کفّار کا شہر شہر چکر لگانا دھوکہ میں نہ ڈال دے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@cdxc{یہ حقیر سرمایہ اور سامانِ تعیش ہے اس کے بعد انجام جہّنم ہے اور وہ بدترین منزل ہے\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@cdxci{لیکن جن لوگوں نے تقوٰی الٰہی اختیار کیا ان کے لئے وہ باغات ہیں جن کے نیچے نہریں جاری ہوں گی- خدا کی طرف سے یہ سامانِ ضیافت ہے اور جو کچھ اس کے پاس ہے سب نیک افراد کے لئے خیر ہی خیرہے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@cdxcii{اہلِ کتاب میں وہ لوگ بھی ہیں جو اللہ پر اور جو کچھ تمہاری طرف نازل ہوا ہے اور جو اُن کی طرف نازل ہوا ہے سب پر ایمان رکھتے ہیں- اللہ کے سامنے سر جھکائے ہوئے ہیں- آیااُ خدا حقیرسی قیمت پر فروخت نہیں کرتے- ان کے لئے پروردگار کے یہاں ان کا اجر ہے اور خدا بہت جلد حساب کرنے والا ہے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@cdxciii{اے ایمان والو صبر کرو.صبر کی تعلیم دو.جہاد کے لئے تیاری کرو اور اللہ سے ڈرو شاید تم فلاح یافتہ اور کامیاب ہوجاؤ\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@cdxciv{\basmalahur انسانو! اس پروردگار سے ڈرو جس نے تم سب کو ایک نفس سے پیدا کیا ہے اور اس کا جوڑا بھی اسی کی جنس سے پیدا کیا ہے اور پھر دونوں سے بکثرت مرد وعورت دنیا میں پھیلا دئیے ہیں اور اس خدا سے بھی ڈرو جس کے ذریعہ ایک دوسرے سے سوال کرتے ہو اور قرابتداروں کی بے تعلقی سے بھی- اللہ تم سب کے اعمال کا نگراں ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cdxcv{اور یتیموں کو ان کا مال دے دو اور ان کے مال کو اپنے مال سے نہ بدلو اور ان کے مال کو اپنے مال کے ساتھ ملا کر نہ کھا جاؤ کہ یہ گناہ کبیرہ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cdxcvi{اور اگر یتیموں کے بارے میں انصاف نہ کرسکنے کا خطرہ ہے تو جو عورتیں تمہیں پسند ہیں دو. تین. چار ان سے نکاح کرلو اور اگر ان میں بھی انصاف نہ کرسکنے کا خطرہ ہے تو صرف ایک... یا جو کنیزیں تمہارے ہاتھ کی ملکیت ہیں, یہ بات انصاف سے تجاوز نہ کرنے سے قریب تر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cdxcvii{عورتوں کو ان کا مہر عطا کردو پھر اگر وہ خوشی خوشی تمہیں دینا چاہیں تو شوق سے کھالو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cdxcviii{اور ناسمجھ لوگوں کو ان کے وہ اموال جن کو تمہارے لئے قیام کا ذریعہ بنایا گیا ہے نہ دو- اس میں ان کے کھانے کپڑے کا انتظام کردو اور ان سے مناسب گفتگو کرو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cdxcix{اور یتیموں کا امتحان لو اور جب وہ نکاح کے قابل ہوجائیں تو اگر ان میں رشید ہونے کا احساس کروتو ان کے اموال ان کے حوالے کردو اور زیادتی کے ساتھ یا اس خوف سے کہ کہیں وہ بڑے نہ ہوجائیں جلدی جلدی نہ کھاجاؤ ... اور تم میں جو غنی ہے وہ ان کے مال سے پرہیز کرے اور جو فقیر ہے وہ بھی صرف بقدر مناسب کھائے- پھر جب ان کے اموال ان کے حوالے کرو تو گواہ بنالو اور خدا تو حساب کے لئے خود ہی کافی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@d{مردوں کے لئے ان کے والدین اور اقربا کے ترکہ میں ایک حصہّ ہے اور عورتوں کے لئے بھی ان کے والدین اور اقربا کے ترکہ میں سے ایک حصہّ ہے وہ مال بہت ہو یا تھوڑا یہ حصہّ بطور فریضہ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@di{اور اگر تقسیم کے وقت دیگر قرابتدار, ایتام, مساکین بھی آجائیں تو انہیں بھی اس میں سے بطور رزق دے دو اور ان سے نرم اور مناسب گفتگو کرو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dii{اور ان لوگوں کو اس بات سے ڈرنا چاہئے کہ اگر وہ خود اپنے بعد ضعیف و ناتواں اولاد چھوڑ جاتے تو کس قدر پریشان ہوتے لہذا خدا سے ڈریں اور سیدھی سیدھی گفتگو کریں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@diii{جو لوگ ظالمانہ انداز سے یتیموں کا مال کھاجاتے ہیں وہ درحقیقت اپنے پیٹ میں آگ بھررہے ہیں اور عنقریب واصل جہّنم ہوں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@div{اللہ تمہاری اولاد کے بارے میں تمہیں ہدایت فرماتا ہے، ایک لڑکے کا حصہ دو لڑکیوں کے حصے کے برابر ہے، پس اگر لڑکیاں دو سے زائد ہوں تو ترکے کا دو تہائی ان کا حق ہے اور اگر صرف ایک لڑکی ہے تو نصف (ترکہ) اس کا ہے اور میت کی اولاد ہونے کی صورت میں والدین میں سے ہر ایک کو ترکے کا چھٹا حصہ ملے گا اور اگر میت کی اولاد نہ ہو بلکہ صرف ماں باپ اس کے وارث ہوں تواس کی ماں کو تیسرا حصہ ملے گا، پس اگر میت کے بھائی ہوں تو ماں کوچھٹا حصہ ملے گا، یہ تقسیم میت کی وصیت پر عمل کرنے اور اس کے قرض کی ادائیگی کے بعد ہو گی، تمہیں نہیں معلوم تمہارے والدین اور تمہاری اولاد میں فائدے کے حوالے سے کون تمہارے زیادہ قریب ہے، یہ حصے اللہ کے مقرر کردہ ہیں، یقینا اللہ بڑا جاننے والا، باحکمت ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dv{اور تمہیںاپنی بیویوں کے ترکے میں سے اگر ان کی اولاد نہ ہو نصف حصہ ملے گا اور اگر ان کی اولاد ہو تو ان کے ترکے میں سے چوتھائی تمہارا ہو گا، یہ تقسیم میت کی وصیت پر عمل کرنے اور قرض ادا کرنے کے بعد ہو گی اور تمہاری اولاد نہ ہو تو انہیں تمہارے ترکے میں سے چوتھائی ملے گااور اگر تمہاری اولاد ہو تو انہیں تمہارے ترکے میںسے آٹھواں حصہ ملے گا، یہ تقسیم تمہاری وصیت پر عمل کرنے اور قرض ادا کرنے کے بعد ہو گی اور اگر کوئی مرد یا عورت بے اولادہو اور والدین بھی زندہ نہ ہوں اور اس کا ایک بھائی یا ایک بہن ہو تو بھائی اور بہن میں سے ہر ایک کو چھٹا حصہ ملے گا، پس اگر بہن بھائی ایک سے زیادہ ہوں تو سب ایک تہائی حصے میں شریک ہوں گے، یہ تقسیم وصیت پرعمل کرنے اور قرض ادا کرنے کے بعد ہو گی، بشرطیکہ ضرر رساں نہ ہو، یہ نصیحت اللہ کی طرف سے ہے اور اللہ بڑا دانا، بردبار ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dvi{یہ سب الٰہی حدود ہیں اور جو اللہ و رسول کی اطاعت کرے گا خدا اسے ان جنتوں میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی اور وہ ان میں ہمیشہ رہیں گے اور درحقیقت یہی سب سے بڑی کامیابی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dvii{اور جو خدا و رسول کی نافرمانی کرے گا اور ا سکے حدود سے تجاوز کرجائے گا خدا اسے جہّنم میں داخل کردے گا اور وہ وہیں ہمیشہ رہے گا اور اس کے لئے رسوا کن عذاب ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dviii{اور تمہاری عورتوں میں سے جو عورتیں بدکاری کریں ان پر اپنوں میں سے چار گواہوں کی گواہی لو اور جب گواہی دے دیں تو انہیں گھروں میں بند کردو- یہاں تک کہ موت آجائے یا خدا ان کے لئے کوئی راستہ مقرر کردے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dix{اور تم میں سے جو آدمی بدکاری کریں انہیں اذیت دو پھر اگر توبہ کرلیں اور اپنے حال کی اصلاح کرلیں تو ان سے اعراض کرو کہ خدا بہت توبہ قبول کرنے والا اور مہربان ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dx{توبہ خد اکے ذمہ صرف ان لوگوں کے لئے ہے جو جہالت کی بنائ پر برائی کرتے ہیں اور پھر فورا توبہ کرلیتے ہیں کہ خدا ان کی توبہ کو قبول کرلیتا ہے وہ علیم و دانا بھی ہے اور صاحبِ حکمت بھی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dxi{اور توبہ ان لوگوں کے لئے نہیں ہے جو پہلے برائیاں کرتے ہیں اور پھر جب موت سامنے آجاتی ہے تو کہتے ہیں کہ اب ہم نے توبہ کرلی اور نہ ان کے لئے ہے جو حالاُ کفر میں مرجاتے ہیں کہ ان کے لئے ہم نے بڑا دردناک عذاب مہّیا کر رکھا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dxii{اے ایمان والو تمہارے لئے جائز نہیں ہے کہ جبرا عورتوں کے وارث بن جاؤ اور خبردار انہیں منع بھی نہ کرو کہ جو کچھ ان کو دے دیا ہے اس کا کچھ حصہّ لے لو مگر یہ کہ واضح طور پر بدکاری کریں اور ان کے ساتھ نیک برتاؤ کرو اب اگر تم انہیں ناپسند بھی کرتے ہو تو ہوسکتا ہے کہ تم کسی چیز کو ناپسند کرتے ہو اور خدا اسی میں خیر کثیر قرار دے دے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dxiii{اور اگر تم ایک زوجہ کی جگہ پر دوسری زوجہ کو لانا چاہو اور ایک کو مال کثیر بھی دے چکے ہو تو خبردار اس میں سے کچھ واپس نہ لینا- کیا تم اس مال کو بہتان اور کھلے گناہ کے طور پر لینا چاہتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dxiv{اور آخر کس طرح تم مال کو واپس لو گے جب کہ ایک دوسرے سے متصل ہوچکا ہے اور ان عورتوں نے تم سے بہت سخت قسم کا عہد لیا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dxv{اور خبردار جن عورتوں سے تمہارے باپ دادا نے نکاح(جماع) کیا ہے ان سے نکاح نہ کرنا مگر وہ جو اب تک ہوچکا ہے... یہ کھلی ہوئی برائی اور پروردگار کا غضب اور بدترین راستہ ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dxvi{تمہارے اوپر تمہاری مائیں, بیٹیاں, بہنیں, پھوپھیاں, خالائیں, بھتیجیاں, بھانجیاں, وہ مائیں جنہوں نے تم کو دودھ پلایا ہے, تمہاری رضاعی(دودھ شریک) بہنیں, تمہاری بیویوں کی مائیں, تمہاری پروردہ عورتیں جو تمہاری آغوش میں ہیں اور ان عورتوں کی اولاد, جن سے تم نے دخول کیا ہے ہاں اگر دخول نہیں کیا ہے تو کوئی حرج نہیں ہے اور تمہارے فرزندوں کی بیویاں جو فرزند تمہارے صلب سے ہیں اور دو بہنوں کا ایک ساتھ جمع کرنا سب حرام کردیا گیا ہے علاوہ اس کے جو اس سے پہلے ہوچکا ہے کہ خدا بہت بخشنے والا اور مہربان ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dxvii{اورتم پر حرام ہیں شادی شدہ عورتیں- علاوہ ان کے جو تمہاری کنیزیں بن جائیں- یہ خدا کا کھلا ہوا قانون ہے اور ان سب عورتوں کے علاوہ تمہارے لئے حلال ہے کہ اپنے اموال کے ذریعہ عورتوں سے رشتہ پیدا کرو عفت و پاک دامنی کے ساتھً سفاح و زنا کے ساتھ نہیں پس جو بھی ان عورتوں سے تمتع کرے ان کی اجرت انہیں بطور فریضہ دے دے اور فریضہ کے بعد آپس میں رضا مندی ہوجائے تو کوئی حرج نہیں ہے بیشک اللہ علیم بھی ہے اور حکیم بھی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dxviii{اور جس کے پاس اس قدر مالی وسعت نہیں ہے کہ مومن آزاد عورتوں سے نکاح کرے تو وہ مومنہ کنیز عورت سے عقد کرلے- خدا تمہارے ایمان سے باخبر ہے تم سب ایک دوسرے سے ہو- ان کنیزوں سے ان کے اہل کی اجازت سے عقد کرو اور انہیں ان کی مناسب اجرت(مہر) دے دو- ان کنیزوں سے عقد کرو جو عفیفہ اور پاک دامن ہوں نہ کہ کھّلم کھلاّ زنا کار ہوں اور نہ چوری چھاَپے دوستی کرنے والی ہوں پھر جب عقد میں آگئیں تو اگر زنا کرائیں تو ان کے لئے آزاد عورتوں کے نصف کے برابر سزا ہے- یہ کنیزوں سے عقد ان کے لئے ہے جو بے صبری کا خطرہ رکھتے ہوں ورنہ صبر کرو تو تمہارے حق میں بہتر ہے اور اللہ غفور و رحیم ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dxix{وہ چاہتا ہے کہ تمہارے لئے واضح احکام بیان کردے اور تمہیں تم سے پہلے والوں کے طریقہ کار کی ہدایت کردے اور تمہاری توبہ قبول کرلے اور وہ خوب جاننے والا اور صاحبِ حکمت ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dxx{خدا چاہتا ہے کہ تمہاری توبہ قبول کرے اور خواہشات کی پیروی کرنے والے چاہتے ہیں کہ تمہیں بالکل ہی راسِ حق سے دور کردیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dxxi{خدا چاہتا ہے کہ تمہارے لئے تخفیف کا سامان کردے اور انسان تو کمزو ر ہی پیدا کیا گیا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dxxii{اے ایمان والو- آپس میںایک دوسرے کے مال کو ناحق طریقہ سے نہ کھا جایا کرو ... مگر یہ کہ باہمی رضامندی سے معاملت ہو اور خبردار اپنے نفس کو قتل نہ کرو - اللہ تمہارے حال پر بہت مہربان ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dxxiii{اور جو ایسا اقدام حدود سے تجاوز اور ظلم کے عنوان سے کرے گا ہم عنقریب اسے جہّنم میں ڈال دیں گے اور اللہ کے لئے یہ کام بہت آسان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dxxiv{اگر تم بڑے بڑے گناہوں سے جن سے تمہیں روکا گیا ہے پرہیز کرلو گے تو ہم دوسرے گناہوں کی پردہ پوشی کردیں گے اور تمہیں باعزّت منزل تک پہنچادیں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dxxv{اور خبردار جو خدا نے بعض افراد کو بعض سے کچھ زیادہ دیا ہے اس کی تمنّا اور آرزو نہ کرنا مردوں کے لئے وہ حصہّ ہے جو انہوں نے کمایا ہے اور عورتوں کے لئے وہ حصہّ ہے جو انہوں نے حاصل کیا ہے- اللہ سے اس کے فضل کا سوال کرو کہ وہ بیشک ہر شے کا جاننے والا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dxxvi{اور جو کچھ ماں باپ یا اقربا نے چھوڑا ہے ہم نے سب کے لئے ولی و وارث مقرر کردئیے ہیں اور جن سے تم نے عہد و پیمان کیا ہے ان کا حصہ ّبھی انہیں دے دو بیشک اللہ ہر شے پر گواہ اور نگراں ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dxxvii{مرد عورتوں کے حاکم اور نگراں ہیں ان فضیلتوں کی بنا پر جو خد انے بعض کو بعض پر دی ہیں اور اس بنا پر کہ انہوں نے عورتوں پر اپنا مال خرچ کیا ہے- پس نیک عورتیں وہی ہیں جو شوہروں کی اطاعت کرنے والی اور ان کی غیبت میں ان چیزوں کی حفاظت کرنے والی ہیں جن کی خدا نے حفاظت چاہی ہے اور جن عورتوں کی نافرمانی کا خطرہ ہے انہیں موعظہ کرو- انہیں خواب گاہ میں الگ کردو اور مارو اور پھر اطاعت کرنے لگیں تو کوئی زیادتی کی راہ تلاش نہ کرو کہ خدا بہت بلند اور بزرگ ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dxxviii{اور اگر دونوں کے درمیان اختلاف کا اندیشہ ہے تو ایک دَکُم مرد کی طرف سے اور ایک عورت والوں میں سے بھیجو- پھر وہ دونوں اصلاح چاہیں گے تو خدا ان کے درمیان ہم آہنگی پیدا کردے گا بیشک اللہ علیم بھی ہے اور خبیر بھی\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dxxix{اور اللہ کی عبادت کرو اور کسی شے کو اس کا شریک نہ بناؤ اور والدین کے ساتھ نیک برتاؤ کرو اور قرابتداروں کے ساتھ اور یتیموں, مسکینوں, قریب کے ہمسایہ, دور کے ہمسایہ, پہلو نشین, مسافر غربت زدہ, غلام و کنیز سب کے ساتھ نیک برتاؤ کرو کہ اللہ مغرور اور متکبر لوگوں کو پسند نہیں کرتا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dxxx{جو خود بھی بخل کرتے ہیں اور دوسروں کو بھی بخل کا حکم دیتے ہیں اور جو کچھ خدانے اپنے فضل و کرم سے عطا کیا ہے اس پر پردہ ڈالتے ہیں اور ہم نے کافروں کے واسطے فِسوا کن عذاب مہّیا کر رکھا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dxxxi{اور جو لوگ اپنے اموال کو لوگوں کو دکھانے کے لئے خرچ کرتے ہیں اور اللہ اور آخرت پر ایمان نہیں رکھتے ہیں انہیں معلوم ہونا چاہئے کہ جس کا شیطان ساتھی ہوجائے وہ بدترین ساتھی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dxxxii{ان کا کیا نقصان ہے اگر یہ اللہ اور آخرت پر ایمان لے آئیں اور جو اللہ نے بطور رزق دیا ہے اسے اس کی راہ میں خرچ کریں اور اللہ ہر ایک کو خوب جانتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dxxxiii{اللہ کسی پر ذرہ برابر ظلم نہیں کرتا- انسان کے پاس نیکی ہوتی ہے تو اسے دوگنا کردیتا ہے اور اپنے پاس سے اجر عظیم عطا کرتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dxxxiv{اس وقت کیا ہوگا جب ہم ہر امت کو اس کے گواہ کے ساتھ بلائیں گے اور پیغمبر آ پ کو ان سب کا گواہ بناکر بلائیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dxxxv{اس دن جن لوگوں نے کفر اختیار کیا ہے اور رسول کی نافرمانی کی ہے یہ خواہش کریں گے کہ اے کاش ان کے اوپر سے زمین برابر کردی جاتی اور وہ خدا سے کسی بات کو نہیں چھپا سکتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dxxxvi{ایمان والو خبر دار نشہ کی حالت میں نماز کے قریب بھی نہ جانا جب تک یہ ہوش نہ آجائے کہ تم کیا کہہ رہے ہو اور جنابت کی حالت میں بھی مگر یہ کہ راستہ سے گزر رہے ہو جب تک غسل نہ کرلو اور اگر بیمار ہو یا سفر کی حالت میں ہو اور کسی کے پیخانہ نکل آئے, یا عورتوں سے باہمی جنسی ربط قائم ہوجائے اور پانی نہ ملے تو پاک مٹی سے تمیم کرلو اس طرح کہ اپنے چہروں اور ہاتھوں پر مسح کرلو بیشک خدا بہت معاف کرنے والا اور بخشنے والا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dxxxvii{کیا تم نے ان لوگوں کو نہیں دیکھا ہے جنہیں کتاب کا تھوڑا سا حصہّ دے دیا گیا ہے کہ وہ گمراہی کا سودا کرتے ہیں اور چاہتے ہیں کہ تم بھی راستہ سے بہک جاؤ\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dxxxviii{اور اللہ تمہارے دشمنوں کو خوب جانتا ہے اور وہ تمہاری سرپرستی اور مدد کے لئے کافی ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dxxxix{یہودیوں میں وہ لوگ بھی ہیں جو کلمات الٰہٰیہ کو ان کی جگہ سے ہٹا دیتے ہیں اور کہتے ہیں کہ ہم نے بات سنی اور نافرمانی کی اور تم بھی سنو مگر تمہاری بات نہ سنی جائے گی یہ سب زبان کے توڑ مروڑ اور دین میں طعنُہ زنی کی بنا پر ہوتا ہے حالانکہ اگر یہ لوگ یہ کہتے کہ ہم نے سنا اور اطاعت کی آپ بھی سنئے اور نظ» کرم کیجئے تو ان کے حق میں بہتر اور مناسب تھا لیکن خدا نے ان کے کفر کی بنا پر ان پر لعنت کی ہے تو یہ ایمان نہ لائیں گے مگر بہت قلیل تعداد میں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dxl{اے وہ لوگ جنہیں کتاب دی گئی ہے ہمارے نازل کئے ہوئے قرآن پر ایمان لے آؤ جو تمہاری کتابوں کی تصدیق کرنے والا ہے قبل اس کے کہ ہم تمھارے چہروں کو بگاڑ کر پشت کی طرف پھیر دیں یا ان پر اس طرح لعنت کریں جس طرح ہم نے اصحابِ سبت پر لعنت کی ہے اور اللہ کا حکم بہرحال نافذ ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dxli{اللہ اس بات کو معاف نہیں کرسکتا کہ اس کا شریک قرار دیا جائے اور اس کے علاوہ جس کو چاہے بخش سکتا ہے اور جو بھی اس کا شریک بنائے گا اس نے بہت بڑا گناہ کیا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dxlii{کیا تم نے ان لوگوں کو نہیں دیکھا جو اپنے نفس کی پاکیزگی کا اظہار کرتے ہیں ... حالانکہ اللہ جس کو چاہتا ہے پاکیزہ بناتا ہے اور بندوں پر دھاگے کے برابر بھی ظلم نہیں ہوتا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dxliii{دیکھو تو انہوں نے کس طرح خدا پر کھّلم کّھلا الزام لگایا ہے اور یہی ان کے کھّلم کّھلا گناہ کے لئے کافی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dxliv{کیا تم نے نہیں دیکھا کہ جن لوگوں کو کتاب کا کچھ حصہّ دے دیا گیا وہ شیطان اور بتوں پر ایمان رکھتے ہیں اور کفار کو بھی بتاتے ہیں کہ یہ لوگ ایمان والوں سے زیادہ سیدھے راستے پر ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dxlv{یہی وہ لوگ ہیں جن پر خدا نے لعنت کی ہے اور جس پر خدا لعنت کردے آپ پھر اس کا کوئی مددگار نہ پائیں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dxlvi{کیا ملک دنیا میں ان کا بھی کوئی حصہ ّہے کہ لوگوں کو بھوسی برابر بھی نہیں دینا چاہتے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dxlvii{یا وہ ان لوگوں سے حسد کرتے ہیں جنہیں خدا نے اپنے فضل و کرم سے بہت کچھ عطا کیا ہے تو پھر ہم نے آلِ ابراہیم علیھ السّلامکو کتاب و حکمت اور ملک عظیم سب کچھ عطا کیا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dxlviii{پھر ان میں سے بعض ان چیزوں پر ایمان لے آئے اور بعض نے انکار کردیا اور ان لوگوں کے لئے دہکتا ہوا جہّنم ہی کافی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dxlix{بیشک جن لوگوں نے ہماری آیتوں کا انکار کیا ہے ہم انہیں آگ میں بھون دیں گے اور جب ایک کھال پک جائے گی تو دوسری بدل دیں گے تاکہ عذاب کا مزہ چکھتے رہیں خدا سب پر غالب اور صاحبِ حکمت ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dl{اور جو لوگ ایمان لے آئے اور انہوں نے نیک عمل کئے ہم عنقریب انہیں جنتوں میں داخل کریں گے جن کے نیچے نہریں جاری ہوں گی اور وہ ان ہی میں ہمیشہ رہیں گے ان کے لئے وہاں پاکیزہ بیویاں ہوں گی اور انہیں گھنی چھاؤں میں رکھا جائے گا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dli{بیشک اللہ تمہیں حکم دیتا ہے کہ امانتوں کو ان کے اہل تک پہنچا دو اور جب کوئی فیصلہ کرو تو انصاف کے ساتھ کرو اللہ تمہیں بہترین نصیحت کرتا ہے بیشک اللہ سمیع بھی ہے اور بصیر بھی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dlii{ایمان والو اللہ کی اطاعت کرو رسول اور صاحبانِ امر کی اطاعت کرو جو تم ہی میں سے ہیں پھر اگر آپس میں کسی بات میں اختلاف ہوجائے تو اسے خدا اور رسول کی طرف پلٹا دو اگر تم اللہ اور روز آخرت پر ایمان رکھنے والے ہو- یہی تمہارے حق میں خیر اور انجام کے اعتبار سے بہترین بات ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dliii{کیا آپ نے ان لوگوں کو نہیں دیکھا جن کا خیال یہ ہے کہ وہ آپ پر اور آپ کے پہلے نازل ہونے والی چیزوں پر ایمان لے آئے ہیں اور پھر یہ چاہتے ہیں کہ سرکش لوگوں کے پاس فیصلہ کرائیں جب کہ انہیں حکم دیا گیا ہے کہ طاغوت کا انکار کریں اور شیطان تو یہی چاہتا ہے کہ انہیں گمراہی میں دور تک کھینچ کر لے جائے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dliv{اور جب ان سے کہا جاتا ہے کہ حکم خدا .... اور اس کے رسول کی طرف آؤ تو تم منافقین کو دیکھو گے کہ وہ شدّت سے انکار کردیتے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dlv{پس اس وقت کیا ہوگا جب ان پر ان کے اعمال کی بنا پر مصیبت نازل ہوگی اور وہ آپ کے پاس آکر خدا کی قسم کھائیں گے کہ ہمارا مقصد صرف نیکی کرنا اور اتحاد پیدا کرنا تھا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dlvi{یہی وہ لوگ ہیں جن کے دل کا حال خدا خوب جانتا ہے لہذا آپ ان سے کنارہ کش رہیں انہیں نصیحت کریں اور ان کے دل پر اثر کرنے والی محل موقع کے مطابق بات کریں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dlvii{اور ہم نے کسی رسول کو بھی نہیں بھیجا ہے مگر صرف اس لئے کہ حکِم خدا سے اس کی اطاعت کی جائے اور کاش جب ان لوگوں نے اپنے نفس پر ظلم کیا تھا تو آپ کے پاس آتے اور خود بھی اپنے گناہوں کے لئے استغفار کرتے اور رسول بھی ان کے حق میں استغفار کرتا تو یہ خدا کو بڑا ہی توبہ قبول کرنے والا اور مہربان پاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dlviii{پس آپ کے پروردگار کی قسم کہ یہ ہرگز صاحبِ ایمان نہ بن سکیں گے جب تک آپ کو اپنے اختلافات میں حکُم نہ بنائیں اور پھر جب آپ فیصلہ کردیں تو اپنے دل میں کسی طرح کی تنگی کا احساس نہ کریں اور آپ کے فیصلہ کے سامنے سراپا تسلیم ہوجائیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dlix{اور اگر ہم ان منافقین پر فرض کردیتے کہ اپنے کو قتل کر ڈالیں یا گھر چھوڑ کر نکل جائیں تو چند افراد کے علاوہ کوئی عمل نہ کرتا حالانکہ اگر یہ اس نصیحت پر عمل کرتے تو ان کے حق میں بہتر ہی ہوتا اور ان کو زیادہ ثبات حاصل ہوتا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dlx{اور ہم انہیں اپنی طرف سے اج» عظیم بھی عطا کرتے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dlxi{اور انہیں سیدھے راستہ کی ہدایت بھی کردیتے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dlxii{اور جو بھی اللہ اور رسول کی اطاعت کرے گا وہ ان لوگوں کے ساتھ رہے گا جن پر خدا نے نعمتیں نازل کی ہیں انبیائً صدیقین, شہدائ اور صالحین اور یہی بہترین رفقائ ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dlxiii{یہ اللہ کی طرف سے فضل و کرم ہے اور خدا ہر ایک کے حالات کے علم کے لئے کافی ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dlxiv{ایمان والو اپنے تحفظ کا سامان سنبھال لو اور جماعت جماعت یا اکٹھا جیسا موقع ہو سب نکل پڑو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dlxv{تم میں ایسے لوگ بھی گھس گئے ہیں جو لوگوں کو روکیں گے اور اگر تم پر کوئی مصیبت آگئی تو کہیں گے کہ خد انے ہم پر احسان کیا کہ ہم ان کے ساتھ حاضر نہیں تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dlxvi{اور اگر تمہیں خدائی فضل و کرم مل گیا تو اس طرح جیسے تمہارے ان کے درمیان کبھی دوستی ہی نہیں تھی کہنے لگیں گے کہ کاش ہم بھی ان کے ساتھ ہوتے اور کامیابی کی عظیم منزل پر فائز ہوجاتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dlxvii{اب ضرورت ہے کہ راسِ خدا میں وہ لوگ جہاد کریں جو زندگانی دنیا کو آخرت کے عوض بیچ ڈالتے ہیں اور جو بھی راسِ خدا میں جہاد کرے گا وہ قتل ہوجائے یا غالب آجائے دونوں صورتوں میں ہم اسے اج» عظیم عطا کریں گے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dlxviii{اور آخر تمہیں کیا ہوگیا ہے کہ تم اللہ کی راہ میں اور ان کمزور مردوں, عورتوں اور بچوں کے لئے جہاد نہیں کرتے ہو جنہیں کمزور بناکر رکھا گیا ہے اور جو برابر دعا کرتے ہیں کہ خدایا ہمیں اس قریہ سے نجات دے دے جس کے باشندے ظالم ہیں اور ہمارے لئے کوئی سرپرست اور اپنی طرف سے مددگار قرار دے دے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dlxix{ایمان والے ہمیشہ اللہ کی راہ میں جہاد کرتے ہیں اور جو کافر ہیں وہ ہمیشہ طاغوت کی راہ میں لڑتے ہیں لہذا تم شیطان کے ساتھیوں سے جہاد کرو بیشک شیطان کا مکر بہت کمزور ہوتا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dlxx{کیا تم نے ان لوگوں کو نہیں دیکھا جن سے کہا گیا تھا کہ ہاتھ روکے رکھو اور نماز قائم کرو, زکوِٰادا کرو(تو بے چین ہوگئے) اور جب جہاد واجب کردیا گیا تو ایک گروہ لوگوں(دشمنوں) سے اس قدر ڈرتا تھا جیسے خدا سے ڈرتا ہو یا اس سے بھی کچھ زیادہ اور یہ کہتے ہیں کہ خدایا اتنی جلدی کیوں جہاد واجب کردیا کاش تھوڑی مدت تک اور ٹال دیاجاتا پیغمبرآپ کہہ دیجئے کہ دنیا کا سرمایہ بہت تھوڑا ہے اور آخرت صاحبانِ تقوٰی کے لئے بہترین جگہ ہے اور تم پر دھاگہ برابر بھی ظلم نہیں کیا جائے گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dlxxi{تم جہاں بھی رہو گے موت تمہیں پالے گی چاہے مستحکم قلعوں میں کیوں نہ بند ہوجاؤ- ان لوگوں کا حال یہ ہے کہ اچھے حالات پیدا ہوتے ہیں تو کہتے ہیں کہ یہ خدا کی طرف سے ہے اور مصیبت آتی ہے تو کہتے ہیں کہ یہ آپ کی طرف سے ہے تو آپ کہہ دیجئے کہ سب خدا کی طرف سے ہے پھر آخر اس قوم کو کیا ہوگیا ہے کہ یہ کوئی بات سمجھتی ہی نہیں ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dlxxii{تم تک جو بھی اچھائی اور کامیابی پہنچی ہے وہ اللہ کی طرف سے ہے اور جو بھی برائی پہنچی ہے وہ خود تمہاری طرف سے ہے .... اور اے پیغمبرہم نے آپ کو لوگوں کے لئے رسول بنایا ہے اور خدا گواہی کے لئے کافی ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dlxxiii{جو رسول کی اطاعت کرے گا اس نے اللہ کی اطاعت کی اور جو منہ موڑ لے گا تو ہم نے آپ کو اس کا ذمہ دار بناکر نہیں بھیجا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dlxxiv{اور یہ لوگ پہلے اطاعت کی بات کرتے ہیں- پھر جب آپ کے پاس سے باہر نکلتے ہیں تو ایک گروہ اپنے قول کے خلاف تدبیریں کرتا ہے اور خدا ان کی ان باتوں کو لکھ رہا ہے- آپ ان سے اعراض کریں اور خدا پر بھروسہ کریں اور خدا اس ذمہ داری کے لئے کافی ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dlxxv{کیا یہ لوگ قرآن میں غور و فکر نہیں کرتے ہیں کہ اگر وہ غیر خدا کی طرف سے ہوتا تو اس میں بڑا اختلاف ہوتا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dlxxvi{اور جب ان کے پاس امن یا خوف کی خبر آتی ہے تو فورا نشر کردیتے ہیں حالانکہ اگر رسول اور صاحبانِ امر کی طرف پلٹا دیتے تو ان سے استفادہ کرنے والے حقیقت حال کا علم پیدا کرلیتے اور اگر تم لوگوں پر خدا کا فضل اور ا سکی رحمت نہ ہوتی تو چند افراد کے علاوہ سب شیطان کا اتباع کرلیتے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dlxxvii{اب آپ راسِ خدا میں جہاد کریں اور آپ اپنے نفس کے علاوہ دوسروں کے مکلف نہیں ہیں اور مومنین کو جہاد پر آمادہ کریں- عنقریب خدا کفار کے شر کو روک دے گا اور اللہ انتہائی طاقت والا اور سخت سزا دینے والا ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dlxxviii{جو شخص اچھی سفارش کرے گا اسے اس کا حصہ ّملے گااور جو اِری سفارش کرے گا اسے اس میں سے حصہّ ملے گا اور اللہ ہر شے پر اقتدار رکھنے والا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dlxxix{اور جب تم لوگوں کو کوئی تحفہ(سلام) پیش کیا جائے تو اس سے بہتر یا کم سے کم ویسا ہی واپس کرو کہ بیشک اللہ ہر شے کا حساب کرنے والا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dlxxx{اللہ وہ خدا ہے جس کے علاوہ کوئی معبود نہیں ہے- وہ تم سب کو روزِ قیامت جمع کرے گا اور اس میں کوئی شک نہیں ہے اور اللہ سے زیادہ سچی بات کون کرنے والا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dlxxxi{آخر تمہیں کیا ہوگیا ہے کہ منافقین کے بارے میں دو گروہ ہوگئے ہو جب کہ اللہ نے ان کے اعمال کی بنا پر انہیں اُلٹ دیا ہے کیا تم اسے ہدایت دینا چاہتے ہو خدا نے جسے گمراہی پر چھوڑ دیا ہے- حالانکہ جسے خدا گمراہی میں چھوڑ دے اس کے لئے تم کوئی راستہ نہیں نکال سکتے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dlxxxii{یہ منافقین چاہتے ہیں کہ تم بھی ان کی طرح کافر ہوجاؤ اور سب برابر ہوجائیں تو خبردار تم انہیں اپنا دوست نہ بنانا جب تک راسِ خدا میں ہجرت نہ کریں پھر یہ انحراف کریں تو انہیں گرفتار کرلو اور جہاں پا جاؤ قتل کردو اور خبر دار ان میں سے کسی کو اپنا دوست اور مددگار نہ بنانا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dlxxxiii{علاوہ ان کے جو کسی ایسی قوم سے مل جائیں جن کے اور تمہارے درمیان معاہدہ ہو یا وہ تمہارے پاس دل تنگ ہوکر آجائیں کہ نہ تم سے جنگ کریں گے اور نہ اپنی قوم سے- اور اگر خدا چاہتا تو ان کو تمہارے اوپر مسلّط کردیتا اور وہ تم سے بھی جنگ کرتے لہذا اگر تم سے الگ رہیں اور جنگ نہ کریں اور صلح کا پیغام دیں تو خدا نے تمہارے لئے ان کے اوپر کوئی راہ نہیں قرار دی ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dlxxxiv{عنقریب تم ایک اور جماعت کو پاؤ گے جو چاہتے ہیں کہ تم سے بھی محفوظ رہیں اور اپنی قوم سے بھی- یہ جب بھی فتنہ کی طرف بلائے جاتے ہیں الٹے اس میں اوندھے منہ گر پڑتے ہیں لہذا یہ اگر تم سے الگ نہ ہوں اور صلح کا پیغام نہ دیں اور ہاتھ نہ روکیں تو انہیں گرفتار کرلو اور جہاں پاؤ قتل کردو یہی وہ ہیں کہ جن پر تمہیں کھلا غلبہ عطا کیا گیا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dlxxxv{اور کسی مومن کو یہ حق نہیں ہے کہ وہ کسی مومن کو قتل کردے مگر غلطی سے اور جو غلطی سے قتل کردے اسے چاہئے کہ ایک غلام آزاد کرے اور مقتول کے وارثوں کو دیت دے مگر یہ کہ وہ معاف کردیں پھر اگر مقتول ایسی قوم سے ہے جو تمہاری دشمن ہے اور(اتفاق سے) خود مومن ہے تو صرف غلام آزاد کرنا ہوگا اور اگر ایسی قوم کا فرد ہے جس کا تم سے معاہدہ ہے تو اس کے اہل کو دیت دینا پڑے گی اور ایک مومن غلام آزاد کرنا ہوگا اور غلام نہ ملے تو دو ماہ کے مسلسل روزے رکھنا ہوں گے یہی اللہ کی طرف سے توبہ کا راستہ ہے اور اللہ سب کی نیتوں سے باخبر ہے اور اپنے احکام میں صاحب هحکمت بھی ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dlxxxvi{اور جو بھی کسی مومن کو قصدا قتل کردے گا اس کی جزا جہّنم ہے- اسی میں ہمیشہ رہنا ہے اور اس پر خدا کا غضب بھی ہے اور خدا لعنت بھی کرتا ہے اور اس نے اس کے لئے عذابِ عظیم بھی مہیاّ کررکھا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dlxxxvii{ایمان والو جب تم راسِ خدا میں جہاد کے لئے سفر کرو تو پہلے تحقیق کرلو اور خبردار جو اسلام کی پیش کش کرے اس سے یہ نہ کہنا کہ تو مومن نہیں ہے کہ اس طرح تم زندگانی دنیا کا چند روزہ سرمایہ چاہتے ہو اور خدا کے پاس بکثرت فوائد پائے جاتے ہیں- آخر تم بھی تو پہلے ایسے ہی کافر تھے- خدا نے تم پر احسان کیا کہ تمہارے اسلام کو قبول کرلیا(اور دل چیرنے کی شرط نہیں لگائی) تو اب تم بھی اقدام سے پہلے تحقیق کرو کہ خدا تمہارے اعمال سے خوب باخبر ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dlxxxviii{اندھے بیمار اور معذور افراد کے علاوہ گھر بیٹھ رہنے والے صاحبانِ ایمان ہرگز ان لوگوں کے برابر نہیں ہوسکتے جو راسِ خدا میں اپنے جان و مال سے جہاد کرنے والے ہیں- اللہ نے اپنے مال اور جان سے جہاد کرنے والوں کو بیٹھ رہنے والوں پر امتیاز عنایت کئے ہیں اور ہر ایک سے نیکی کا وعدہ کیا ہے اور مجاہدین کو بیٹھ رہنے والوں کے مقابلہ میں اج» عظیم عطا کیا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dlxxxix{اس کی طرف سے درجات مغفرت اور رحمت ہے اور وہ بڑا بخشنے والا اور مہربان ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dxc{جن لوگوں کو ملائکہ نے اس حال میں اٹھایا کہ وہ اپنے نفس پر ظلم کرنے والے تھے ان سے پوچھا کہ تم کس حال میں تھے- انہوں نے کہا کہ ہم زمین میں کمزور بنادئے گئے تھے. ملائکہ نے کہا کہ کیا زمین هخدا وسیع نہیں تھی کہ تم ہجرت کرجاتے- ان لوگوں کا ٹھکاناجہّنم ہے اور وہ بدترین منزل ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dxci{علاوہ ان کمزور مردوں, عورتوں اور بچوں کے جن کے اختیار میں کوئی تدبیر نہ تھی اور وہ کوئی راستہ نہ نکال سکتے تھے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dxcii{یہی وہ لوگ ہیں جن کو عنقریب خدا معاف کردے گا کہ وہ بڑا معاف کرنے والا اور بخشنے والا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dxciii{اور جو بھی راسِ خدا میں ہجرت کرے گا وہ زمین میں بہت سے ٹھکانے اور وسعت پائے گا اور جو اپنے گھر سے خدا و رسول کی طرف ہجرت کے ارادہ سے نکلے گا اس کے بعد اسے موت بھی آجائے گی تو اس کا اجر اللہ کے ذمہ ہے اور اللہ بڑا بخشنے والا مہربان ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dxciv{اور جب تم زمین میں سفر کرو تو تمہارے لئے کوئی حرج نہیں ہے کہ اپنی نمازیں قصر کردو اگر تمہیں کفار کے حملہ کردینے کا خوف ہے کہ کفار تمہارے لئے کھاَلے ہوئے دشمن ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dxcv{اور جب آپ مجاہدین کے درمیان ہوں اور ان کے لئے نماز قائم کریں تو ان کی ایک جماعت آپ کے ساتھ نماز پڑھے اور اپنے اسلحہ ساتھ رکھے اس کے بعد جب یہ سجدہ کرچکیں تو یہ پشت پناہ بن جائیں اور دوسری جماعت جس نے نماز نہیں پڑھی ہے وہ آکر شریمَ نماز ہوجائے اور اپنے اسلحہ اور بچاؤ کے سامان اپنے ساتھ رکھے- کفار کی خواہش یہی ہے کہ تم اپنے سازو سامان اور اسلحہ سے غافل ہوجاؤ تو یہ یکبارگی حملہ کردیں .... ہاں اگر بارش یا بیماری کی وجہ سے اسلحہ نہ اٹھاسکتے ہو تو کوئی حرج نہیں ہے کہ اسلحہ رکھ دو لیکن بچاؤ کا سامان ساتھ رکھو- اللہ نے کفر کرنے والوں کے لئے رسوا کن عذاب مہیّا کررکھا ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dxcvi{اس کے بعد جب یہ نماز تمام ہوجائے تو کھڑے, بیٹھے, لیٹے ہمیشہ خدا کو یاد کرتے رہو اور جب اطمینان حاصل ہوجائے تو باقاعدہ نماز قائم کرو کہ نماز صاحبانِ ایمان کے لئے ایک وقت معین کے ساتھ فریضہ ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dxcvii{اور خبردار دشمنوں کا پیچھا کرنے میں سستی سے کام نہ لینا کہ اگر تمہیں کوئی بھی رنج پہنچتا ہے تو تمہاری طرح کفار کو بھی تکلیف پہنچتی ہے اور تم اللہ سے وہ امیدیں رکھتے ہو جو انہیں حاصل نہیں ہیں اور اللہ ہر ایک کی نیت کا جاننے والا اور صاحبِ حکمت ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dxcviii{ہم نے آپ کی طرف یہ برحق کتاب نازل کی ہے کہ لوگوں کے درمیان حکم خدا کے مطابق فیصلہ کریں اور خیانت کاروں کے طرفدار نہ بنیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dxcix{اور اللہ سے استغفار کیجئے کہ اللہ بڑا غفور و رحیم ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dc{اور خبردار جو لوگ خود اپنے نفس سے خیانت کرتے ہیں ان کی طرف سے دفاع نہ کیجئے گا کہ خدا خیانت کار مجرموں کو ہرگز دوست نہیں رکھتا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dci{یہ لوگ انسانوں کی نظروں سے اپنے کو چھپاتے ہیں اور خدا سے نہیں چھپ سکتے ہیں جب کہ وہ اس وقت بھی ان کے ساتھ رہتا ہے جب وہ ناپسندیدہ باتوں کی سازش کرتے ہیں اور خدا ان کے تمام اعمال کا احاطہ کئے ہوئے ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcii{ہوشیار .... اس وقت تم نے زندگانی دنیا میں ان کی طرف سے جھگڑا شروع بھی کردیا تو اب روزِ قیامت ان کی طرف سے اللہ سے کون جھگڑا کرے گا اور کون ان کا وکیل اور طرفدار بنے گا\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dciii{اور جو بھی کسی کے ساتھ برائی کرے گا یا اپنے نفس پر ظلم کرے گا اس کے بعد استغفار کرے گا تو خدا کو غفور اور رحیم پائے گا\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dciv{اور جو قصدا گناہ کرتا ہے وہ اپنے ہی خلاف کرتا ہے اور خدا سب کا جاننے والا ہے اور صاحبِ حکمت بھی ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcv{اور جو شخص بھی کوئی غلطی یا گناہ کرکے دوسرے بے گناہ کے سر ڈال دیتا ہے وہ بہت بڑے بہتان اور کِھلے گناہ کا ذمہ دار ہوتا ہے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcvi{اگر آپ پر فضل خدا اور رحمت پروردگار کا سایہ نہ ہوتا تو ان کی ایک جماعت نے آپ کوبہکانے کا ارادہ کرلیا تھا اور یہ اپنے علاوہ کسی کو گمراہ نہیں کرسکتے اور آپ کو کوئی تکلیف نہیں پہنچاسکتے اور اللہ نے آپ پر کتاب اور حکمت نازل کی ہے اور آپ کو ان تمام باتوں کا علم دے دیا ہے جن کا علم نہ تھا اور آپ پر خدا کا بہت بڑا فضل ہے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcvii{ان لوگوں کی اکثر راز کی باتوں میں کوئی خیر نہیںہے مگر وہ شخص جو کسی صدقہ, کا» خیر یا لوگوں کے درمیان اصلاح کا حکم دے اور جو بھی یہ سارے کام رضائے الٰہی کی طلب میں انجام دے گا ہم اسے اجر هعظیم عطا کریں گے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcviii{اور جو شخص بھی ہدایت کے واضح ہوجانے کے بعد رسول سے اختلاف کرے گا اور مومنین کے راستہ کے علاوہ کوئی دوسرا راستہ اختیار کرے گا اسے ہم ادھر ہی پھیر دیں گے جدھر وہ پھر گیا ہے اور جہّنم میں جھونک دیں گے جو بدترین ٹھکانا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcix{خدا اس بات کو معاف نہیں کرسکتا کہ اس کا شریک قرار دیا جائے اور اس کے علاوہ جس کو چاہے بخش سکتا ہے اور جو خدا کا شریک قرار دے گا وہ گمراہی میں بہت دور تک چلا گیا ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcx{یہ لوگ خدا کو چھوڑ کر بس عورتوں کی پرستش کرتے ہیں اور سرکش شیطان کو آواز دیتے ہیں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcxi{جس پر خدا کی لعنت ہے اور اس نے خدا سے بھی کہہ دیا کہ میں تیرے بندوں میں سے ایک مقرر حصّہ ضرور لے لوں گا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcxii{اور انہیں گمراہ کروں گا- امیدیں دلاؤں گا اور ایسے احکام دوں گا کہ وہ جانورں کے کان کاٹ ڈالیں گے پھر حکم دوں گا تو اللہ کی مقررہ خلقت کو تبدیل کردیں گے اور جو خد اکو چھوڑ کر شیطان کو اپنا ولی اور سرپرست بنائے گا وہ کھلے ہوئے خسارہ میں رہے گا\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcxiii{شیطان ان سے وعدہ کرتا ہے اور انہیں امیدیں دلاتا ہے اور وہ جو بھی وعدہ کرتاہے وہ دھوکہ کے سوا کچھ نہیں ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dcxiv{یہی وہ لوگ ہیں جن کا انجام جہّنم ہے اور وہ اس سے چھٹکارا نہیں پاسکتے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@dcxv{اور جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ہم عنقریب انہیں ان جنتّوں میں داخل کریں گے جن کے نیچے نہریں جاری ہوں گی وہ ان میں ہمیشہ ہمیشہ رہیں گے- یہ خدا کا برحق وعدہ ہے اور خدا سے زیادہ راست گو کون ہوسکتا ہے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@dcxvi{کوئی کام نہ تمہاری امیدوں سے بنے گا نہ اہلِ کتاب کی امیدوں سے- جو بھی اِرا کام کرے گا اس کی سزا بہرحال ملے گی اور خدا کے علاوہ اسے کوئی سرپرست اور مددگار بھی نہیں مل سکتا ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@dcxvii{اور جو بھی نیک کام کرے گا چاہے وہ مرد ہو یا عورت بشرطیکہ وہ صاحب هایمان بھی ہو- ان سب کو جنّت میں داخل کیا جائے گا اور ان پر ذرّہ برابر ظلم نہیں کیا جائے گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@dcxviii{اور اس سے اچھا دیندار کون ہوسکتا ہے جو اپنا رخ خد اکی طرف رکھے اور نیک کردار بھی ہو اور ملّت ابراہیم علیھ السّلام کا اتباع کرے جو باطل سے کترانے والے تھے اور اللہ نے ابراہیم علیھ السّلام کو اپنا خلیل اور دوست بنایا ہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@dcxix{اور اللہ ہی کے لئے زمین و آسمان کی کل کائنات ہے اور اللہ ہر شے پر احاطہ رکھنے والا ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@dcxx{پیغمبر یہ لوگ آپ سے یتیم لڑکیوں کے بارے میں حکهِ خدا دریافت کرتے ہیں تو آپ کہہ دیجئے کہ ان کے بارے میں خدا اجازت دیتا ہے اور جو کتاب میں تمہارے سامنے حکم بیان کیا جاتا ہے وہ ان یتیم عورتوں کے بارے میں ہے جن کو تم ان کا حق میراث نہیں دیتے ہو اور چاہتے ہو کہ ان سے نکاح کرکے سارا مال روک لو اور ان کمزور بّچوں کے بارے میں ہے کہ یتیموں کے بارے میں انصاف کے ساتھ قیام کرو اور جو بھی تم کا»خیر کرو گے خدا اس کا بخوبی جاننے والا ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@dcxxi{اور اگر کوئی عورت شوہر سے حقوق ادا نہ کرنے یا اس کی کنارہ کشی سے طلاق کا خطرہ محسوس کرے تو دونوں کے لئے کوئی حرج نہیں ہے کہ کسی طرح آپس میں صلح کرلیں کہ صلح میں بہتری ہے اور بخل تو ہر نفس کے ساتھ حاضر رہتا ہے اور اگر تم اچھا برتاؤ کرو گے اور زیادتی سے بچو گے تو خدا تمہارے اعمال سے خوب باخبر ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@dcxxii{اور تم کتنا ہی کیوں نہ چاہو عورتوں کے درمیان مکمل انصاف نہیں کرسکتے ہو لیکن اب بالکل ایک طرف نہ جھک جاؤ کہ دوسری کو معلق چھوڑ دو اور اگر اصلاح کرلو اور تقویٰ اختیار کرو تو اللہ بہت بخشنے والا اور مہربان ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@dcxxiii{اور اگر دونوں الگ ہی ہونا چاہیں تو خدا دونوں کو اپنے خزانے کی وسعت سے غنی اور بے نیاز بنادے گا کہ اللہ صاحبِ هوسعت بھی ہے اور صاحبِ حکمت بھی ہے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@dcxxiv{اور اللہ کے لئے زمین و آسمان کی کل کائنات ہے اور ہم نے تم سے پہلے اہلِ کتاب کو اور اب تم کو یہ وصیت کی ہے کہ اللہ سے ڈرو اور اگر کفر اختیار کرو گے تو خدا کا کوئی نقصان نہیں ہے اس کے لئے زمین و آسمان کی کل کائنات ہے اور وہ بے نیاز بھی ہے اور قابل هحمدو ستائش بھی ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@dcxxv{اور اللہ کے لئے زمین و آسمان کی کل ملکیت ہے اور وہ سب کی نگرانی اور کفالت کے لئے کافی ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@dcxxvi{وہ چاہے تو تم سب کو اٹھا لے جائے اور دوسروں لوگوں کو لے آئے اور وہ ہر شے پر قادر ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@dcxxvii{جو انسان دنیا کا ثواب اور بدلہ چاہتا ہے (اسے معلوم ہونا چاہئے) کہ خدا کے پاس دنیا اور آخرت دونوں کا انعام ہے اور وہ ہر ایک کا سننے والا اور دیکھنے والا ہے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@dcxxviii{اے ایمان والو! عدل و انصاف کے ساتھ قیام کرو اور اللہ کے لئے گواہ بنو چاہے اپنی ذات یا اپنے والدین اور اقربا ہی کے خلاف کیوں نہ ہو- جس کے لئے گواہی دینا ہے وہ غنی ہو یا فقیر اللہ دونوں کے لئے تم سے اولیٰ ہے لہذا خبردار خواہشات کا اتباع نہ کرنا تاکہ انصاف کرسکو اور اگر توڑ مروڑ سے کام لیا یا بالکل کنارہ کشی کرلی تو یاد رکھو کہ اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@dcxxix{ایمان والو! اللہ ً رسول اور وہ کتاب جو رسول پر نازل ہوئی ہے اور وہ کتاب جو اس سے پہلے نازل ہوچکی ہے سب پر ایمان لے آؤ اور یاد رکھو کہ جو خدا, ملائکہ, کتب سماویہ, رسول اور روزِ قیامت کا انکار کرے گا وہ یقینا گمراہی میں بہت دور نکل گیا ہے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@dcxxx{جو لوگ ایمان لائے اور پھر کفر اختیار کرلیا پھر ایمان لے آئے اور پھر کافر ہوگئے اور پھر کفر میں شدید و مزید ہوگئے تو خدا ہرگز انہیں معاف نہیں کرسکتا اور نہ سیدھے راستے کی ہدایت دے سکتا ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@dcxxxi{آپ ان منافقین کو دردناک عذاب کی بشارت دے دیں\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@dcxxxii{جو لوگ مومنین کو چھوڑ کر کفار کو اپنا ولی اور سرپرست بناتے ہیں ... کیا یہ ان کے پاس عزّت تلاش کررہے ہیں جب کہ ساری عزّت صرف اللہ کے لئے ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@dcxxxiii{اور اس نے کتاب میں یہ بات نازل کردی ہے کہ جب آیااُ الٰہی کے بارے میں یہ سنو کہ ان کا انکار اور استہزائ ہورہا ہے تو خبردار ان کے ساتھ ہرگز نہ بیٹھنا جب تک وہ دوسری باتوں میں مصروف نہ ہوجائیں ورنہ تم ان ہی کے مثل ہوجاؤ گے خدا کفار اور منافقین سب کو جہّنم میں ایک ساتھ اکٹھا کرنے والا ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@dcxxxiv{یہ منافقین تمہارے حالات کا انتظار کرتے رہتے ہیں کہ تمہیں خدا کی طرف سے فتح نصیب ہو تو کہیں گے کیا ہم تمہارے ساتھ نہیں تھے اور اگر کفاّر کو کوئی حصّہ مل جائے گا تو ان سے کہیں گے کہ کیا ہم تم پر غالب نہیں آگئے تھے اور تمہیں مومنین سے بچا نہیں لیا تھا تو اب خدا ہی قیامت کے دن تمہارے درمیان فیصلہ کرے گا اور خدا کفاّر کے لئے صاحبان هایمان کے خلاف کوئی راہ نہیں دے سکتا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@dcxxxv{منافقین خدا کو دھوکہ دینا چاہتے ہیں اور خدا ان کو دھوکہ میں رکھنے والا ہے اور یہ نماز کے لئے اٹھتے بھی ہیں تو سستی کے ساتھ- لوگوں کو دکھانے کے لئے عمل کرتے ہیں اور اللہ کو بہت کم یاد کرتے ہیں\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@dcxxxvi{یہ کفر و اسلام کے درمیان حیران و سرگرداں ہیں نہ ان کی طرف ہیں اور نہ اُن کی طرف اور جس کو خدا گمراہی میں چھوڑ دے اس کے لئے آپ کو کوئی راستہ نہ ملے گا\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@dcxxxvii{ایمان والو خبردار مومنین کو چھوڑ کر کفاّر کو اپنا ولی اور سرپرست نہ بنانا کیا تم چاہتے ہو کہ اللہ کے لئے اپنے خلاف صریحی دلیل و حجت قرار دے لو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@dcxxxviii{بے شک منافقین جہّنم کے سب سے نچلے طبقہ میں ہوں گے اور آپ ان کے لئے کوئی مددگار نہ پائیں گے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@dcxxxix{علاوہ ان لوگوں کے جو توبہ کرلیں اور اپنی اصلاح کرلیں اور خدا سے وابستہ ہوجائیں اور دین کو خالص اللہ کے لئے اختیار کریں تو یہ صاحبان ایمان کے ساتھ ہوں گے اور عنقریب اللرُ ان صاحبان ایمان کو اجر عظیم عطا کرے گا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@dcxl{خدا تم پر عذاب کرکے کیا کرے گا اگر تم اس کے شکر گزار اور صاحبِ ایمان بن جاؤ اور وہ تو ہر ایک کے شکریہ کا قبول کرنے والا اور ہر ایک کی نیت کا جاننے والا ہے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@dcxli{اللہ مظلوم کے علاوہ کسی کی طرف سے بھی علی الاعلان اِرا کہنے کو پسند نہیں کرتا اور اللہ ہر بات کا سننے والا اور تمام حالات کا جاننے والا ہے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@dcxlii{تم کسی خیر کا اظہار کرو یا اسے مخفی رکھو یا کسی برائی سے درگزر کرو تو اللہ گناہوں کا معاف کرنے والا اور صاحبِ اختیار ہے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@dcxliii{بے شک جو لوگ اللہ اور رسول کا انکار کرتے ہیں اور خدا اور رسول کے درمیان تفرقہ پیدا کرنا چاہتے ہیں اور یہ کہتے ہیں کہ ہم بعض پر ایمان لائیں گے اور بعض کا انکار کریں گے اور چاہتے ہیں کہ ایمان و کفر کے درمیان سے کوئی نیا راستہ نکال لیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@dcxliv{تو درحقیقت یہی لوگ کافر ہیں اور ہم نے کافروں کے لئے بڑا رسوا کن عذاب مہّیا کررکھا ہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@dcxlv{اور جو لوگ اللہ اور رسول پر ایمان لے آئے اور رسولوں کے درمیان تفرقہ نہیں پیدا کیا خدا عنقریب انہیں ان کا اجر عطا کرے گا اور وہ بہت زیادہ بخشنے والا اور مہربانی کرنے والا ہے\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@dcxlvi{پیغمبر یہ اہل هکتاب آپ سے مطالبہ کرتے ہیں کہ ان پر آسمان سے کوئی کتاب نازل کردیجئے تو انہوں نے موسٰی سے اس سے زیادہ سنگین سوال کیا تھا جب ان سے یہ کہا کہ ہمیں اللہ کو علی الاعلان دکھلا دیجئے تو ان کے ظلم کی بنا پر انہیں ایک بجلی نے اپنی گرفت میں لے لیا پھر انہوں نے ہماری نشانیوں کے آجانے کے باوجود گوسالہ بنالیا تو ہم نے اس سے بھی درگزر کیا اور موسٰی علیھ السّلام کو کھلی ہوئی دلیل عطا کردی\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@dcxlvii{اور ہم نے ان کے عہد کی خلاف ورزی کی بنا پر ان کے سروں پر کوئہ طور کو بلند کردیا اور ان سے کہا کہ دروازہ سے سجدہ کرتے ہوئے داخل ہو اور ان سے کہا کہ خبردار شنبہ کے معاملہ میں زیادتی نہ کرنا اور ان سے بڑا سخت عہد لے لیا\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@dcxlviii{پس ان کے عہد کو توڑ دینے ,آیات هخدا کے انکار کرنے اور انبیائ کو ناحق قتل کر دینے اور یہ کہنے کی بنا پر کہ ہمارے دلوں پر فطرتا غلاف چڑھے ہوئے ہیں حالانکہ ایسا نہیں ہے بلکہ خدا نے ان کے کفر کی بنا پر ان کے دلوں پر مہر لگادی ہے اور اب چند ایک کے علاوہ کوئی ایمان نہ لائے گا\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@dcxlix{اور ان کے کفر اور مریم پر عظیم بہتان لگانے کی بنا پر\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@dcl{اور یہ کہنے کی بنا پر کہ ہم نے مسیح عیسٰی علیھ السّلام بن مریم رسول اللہ کو قتل کردیا ہے حالانکہ انہوں نے نہ انہیں قتل کیا ہے اور نہ سولی دی ہے بلکہ دوسرے کو ان کی شبہیہ بنا دیا گیا تھا اور جن لوگوں نے عیسٰی علیھ السّلام کے بارے میں اختلاف کیا ہے وہ سب منزل ه شک میں ہیں اور کسی کو گمان کی پیروی کے علاوہ کوئی علم نہیں ہے اور انہوں نے یقینا انہیں قتل نہیں کیا ہے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@dcli{بلکہ خدا نے اپنی طرف اٹھا لیا ہے اور خدا صاحبِ غلبہ اور صاحب هحکمت بھی ہے\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@dclii{اور کوئی اہل کتاب میں ایسا نہیں ہے جو اپنی موت سے پہلے ان پر ایمان نہ لائے اور قیامت کے دن عیسٰی علیھ السّلام اس کے گواہ ہوں گے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@dcliii{پس ان یہودیوں کے ظلم کی بنا پر ہم نے جن پاکیزہ چیزوں کو حلال کر رکھا تھا ان پر حرام کردیا اور ان کے بہت سے لوگوں کو راسِ خدا سے روکنے کی بنا پر\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@dcliv{اور سود لینے کی بنا پر جس سے انہیں روکا گیا تھا اور ناجائز طریقہ سے لوگوں کا مال کھانے کی بنا پر اور ہم نے کافروں کے لئے بڑا دردناک عذاب مہّیا کیا ہے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@dclv{لیکن ان میں سے جو لوگ علم میں رسوخ رکھنے والے اور ایمان لانے والے ہیں وہ ان سب پر ایمان رکھتے ہیں جو تم پر نازل ہوا ہے یا تم سے پہلے نازل ہوچکا ہے اور بالخصوص نماز قائم کرنے والے اور زکوِٰدینے والے اور آخرت پر ایمان رکھنے والے ہیں ہم عنقریب ان سب کو اج» عظیم عطا کریں گے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@dclvi{ہم نے آپ کی طرف اسی طرح وحی نازل کی ہے جس طرح نوح علیھ السّلاماور ان کے بعد کے انبیائ کی طرف وحی کی تھی اور ابراہیم علیھ السّلام,اسماعیل علیھ السّلام,اسحاق علیھ السّلام,یعقوب علیھ السّلام,اسباط علیھ السّلام,عیسٰی علیھ السّلام ,ایوب علیھ السّلام, یونس علیھ السّلام,ہارون علیھ السّلام اور سلیمان علیھ السّلام کی طرف وحی کی ہے اور داؤد علیھ السّلام کو زبور عطا کی ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@dclvii{کچھ رسول ہیں جن کے قصے ّہم آپ سے بیان کرچکے ہیں اور کچھ رسول ہیں جن کا تذکرہ ہم نے نہیں کیا ہے اور اللہ نے موسٰی علیھ السّلام سے باقاعدہ گفتگو کی ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@dclviii{یہ سارے رسول بشارت دینے والے اور ڈرانے والے اس لئے بھیجے گئے تاکہ رسولوں کے آنے کے بعد انسانوں کی حجت خدا پر قائم نہ ہونے پائے اور خدا سب پر غالب اور صاحب ه حکمت ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@dclix{یہ مانیں یا نہ مانیں)لیکن خدا نے جو کچھ آپ پر نازل کیا ہے وہ خود اس کی گواہی دیتا ہے کہ اس نے اسے اپنے علم سے نازل کیا ہے اور ملائکہ بھی گواہی دیتے ہیں اور خدا خود بھی شہادت کے لئے کافی ہے\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@dclx{بے شک جن لوگوں نے کفر اختیار کیا اور راسِ هخد ا سے منع کردیا وہ گمراہی میں بہت دور تک چلے گئے ہیں\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@dclxi{اورجن لوگوں نے کفر اختیار کرنے کے بعد ضِلم کیا ہے خدا انہیں ہرگز معاف نہیں کرسکتا اور نہ انہیں کسی راستہ کی ہدایت کرسکتا ہے\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@dclxii{سوائے جہّنم کے راستے کے جہاں ان کو ہمیشہ ہمیشہ رہنا ہے اور یہ خدا کے لئے بہت آسان ہے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@dclxiii{اے انسانو!تمہارے پاس پروردگار کی طرف سے حق لے کر رسول آگیا ہے لہذا اس پر ایمان لے آؤ اسی میں تمہاری بھلائی ہے اور اگر تم نے کفر اختیار کیا تو یاد رکھو کہ زمین و آسمان کی کل کائنات خدا کے لئے ہے اور وہی علم والا بھی ہے اور حکمت والا بھی ہے\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@dclxiv{اے اہل کتاب اپنے دین میں حد سے تجاوز نہ کرو اور خدا کے بارے میں حق کے علاوہ کچھ نہ کہو ---مسیح عیسٰی علیھ السّلام بن مریم صرف اللہ کے رسول اور اس کا کلمہ ہیں جسے مریم کی طرف القائ کیا گیا ہے اور وہ اس کی طرف سے ایک روح ہیں لہذا خدا اور مرسلین پر ایمان لے آؤ اور خبردار تین کا نام بھی نہ لو -اس سے باز آجاؤ کہ اسی میں بھلائی ہے -اللہ فقط خدائے واحد ہے اور وہ اس بات سے منزہ ہے کہ اس کا کوئی بیٹا ہو ,زمین و آسمان میں جو کچھ بھی ہے سب اسی کا ہے اور وہ کفالت و وکالت کے لئے کافی ہے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@dclxv{نہ مسیح کو اس بات سے انکار ہے کہ وہ بندئہ خدا ہیں اور نہ ملائکہ مقربین کو اس کی بندگی سے کوئی انکار ہے اور جو بھی اس کی بندگی سے انکار و استکبار کرے گا تو اللہ سب کو اپنی بارگاہ میں محشور کرے گا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@dclxvi{پھر جو لوگ ایمان لے آئے اور انہوں نے نیک اعمال کئے انہیں مکمل اجر دے گا اور اپنے فضل و کرم سے اضافہ بھی کردے گا اور جن لوگوں نے انکار اور تکّبرسے کام لیا ہے ان پر دردناک عذاب کرے گا اور انہیں خدا کے علاوہ نہ کوئی سرپرست ملے گا اور نہ مددگار\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@dclxvii{اے انسانو !تمہارے پاس تمہارے پروردگار کی طرف سے برہان آچکا ہے اور ہم نے تمہاری طرف روشن نور بھی نازل کردیا ہے\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@dclxviii{پس جو لوگ اللہ پر ایمان لائے اور اس سے وابستہ ہوئے انہیں وہ اپنی رحمت اور اپنے فضل میں داخل کرلے گا اور سیدھے راستہ کی ہدایت کردے گا\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@dclxix{پیغمبر یہ لوگ آپ سے فتوٰی دریافت کرتے ہیں تو آپ کہہ دیجئے کہ کلالہ (بھائی بہن)کے بارے میں خدا خود یہ حکم بیان کرتا ہے کہ اگر کوئی شخص مر جائے اور اس کی اولاد نہ ہو اور صرف بہن وارث ہو تو اسے ترکہ کا نصف ملے گا اور اسی طرح اگر بہن مر جائے اور اس کی اولاد نہ ہو تو بھائی اس کا وارث ہوگا -پھر اگر وارث دو بہنیں ہیں تو انہیں ترکہ کا دو تہائی ملے گا اور اگر بھائی بہن دونوں ہیں تو مرد کے لئے عورت کا رَہرا حصّہ ہوگا خدا یہ سب واضح کررہا ہے تاکہ تم بہکنے نہ پاؤ اور خدا ہر شے کا خوب جاننے والا ہے\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@dclxx{\basmalahur ایمان والو اپنے عہد و پیمان اور معاملات کی پابندی کرو تمہارے لئے تمام چوپائے حلال کردیئے گئے ہیں علاوہ ان کے جوتمہیں پڑھ کر سنائے جارہے ہیں. مگر حالاُ احرام میں شکار کو حلال مت سمجھ لینا بے شک اللہ جو چاہتا حکم دیتا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dclxxi{ایمان والو !خبردار خدا کی نشانیوں کی حرمت کو ضائع نہ کرنا اور نہ محترم مہینے. قربانی کے جانور اور جن جانوروں کے گلے میں پٹےّ باندھ دیئے گئے ہیں اور جو لوگ خانہ خدا کا ارادہ کرنے والے ہیں اور فرض پروردگار اور رضائے الٰہی کے طلبگار ہیں ان کی حرمت کی خلاف ورزی کرنا اور جب احرام ختم ہوجائے تو شکار کرو اور خبردار کسی قوم کی عداوت فقط اس بات پر کہ اس نے تمہیں مسجدالحرام سے روک دیا ہے تمہیں ظلم پر آمادہ نہ کردے --نیکی اور تقویٰ پر ایک دوسرے کی مدد کرو اور گناہ اور تعدّی پر آپس میں تعاون نہ کرنا اور اللہ سے ڈرتے رہنا کہ اس کا عذاب بہت سخت ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dclxxii{تمہارے اوپر حرام کردیا گیا ہے مردار -خون - سور کا گوشت اور جو جانور غیر خدا کے نام پر ذبح کیا جائے اورمنخنقہ اور موقوذہً اور متردیہ اور نطیحہ اور جس کو درندہ کھا جائے مگریہ کہ تم خود ذبح کرلو اور جو نصاب پر ذبح کیا جائے اور جس کی تیروں کے ذریعہ قرعہ اندازی کرو کہ یہ سب فسق ہے اور کفار تمہارے دین سے مایوس ہوگئے ہیں لہذا تم ان سے نہ ڈرو اور مجھ سے ڈرو -آج میں نے تمہارے لئے دین کو کامل کردیا ہے اور اپنی نعمتوں کو تمام کردیا ہے اور تمہارے لئے دین اسلام کو پسندیدہ بنادیا ہے لہذا جو شخص بھوک میں مجبور ہوجائے اور گناہ کی طرف مائل نہ ہو تو خدا بڑا بخشنے والا مہربان ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dclxxiii{پیغمبر یہ تم سے سوال کرتے ہیں کہ ان کے لئے کیا حلال کیا گیا ہے تو کہہ دیجئے کہ تمہارے لئے تمام پاکیزہ چیزیں حلال ہیں اور جو کچھ تم نے شکاری کتوں کو سکھا رکھا ہے اور خدائی تعلیم میں سے کچھ ان کے حوالہ کر دیاہے تو جو کچھ وہ پکڑ کے لائیں اسے کھالو اور اس پر نام خدا ضرور لو اور اللہ سے ڈرو کہ وہ بہت جلد حساب کرنے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dclxxiv{آج تمہارے لئے تمام پاکیزہ چیزیں حلال کردی گئی ہیں اور اہلِ کتاب کا طعام بھی تمہارے لئے حلال ہے اور تمہارا طعام ان کے لئے حلال ہے اور اہلِ ایمان کی آزاد اور پاک دامن عورتیں یا ان کی آزاد عورتیں جن کو تم سے پہلے کتاب دی گئی ہے تمہارے لئے حلال ہے بشرطیکہ تم ان کی اجرت دے دو پاکیزگی کے ساتھ -نہ کھّلم کھلاّ زنا کی اجرت کے طور پر اور نہ پوشیدہ طور پر دوستی کے انداز سے اور جو بھی ایمان سے انکار کرے گا اس کے اعمال یقینا برباد ہوجائیں گے اور وہ آخرت میں گھاٹا اُٹھانے والوں میں ہوگا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dclxxv{ایمان والو جب بھی نماز کے لئے اٹھو تو پہلے اپنے چہروں کو اور کہنیوں تک اپنے ہاتھوںکو دھوؤ اور اپنے سر اور گٹّے تک پیروں کا مسح کرو اور اگر جنابت کی حالت میں ہو تو غسل کرو اور اگر مریض ہو یا سفر کے عالم میں ہو یا پیخانہ وغیرہ نکل آیا ہے یا عورتوں کو باہم لمس کیاہے اور پانی نہ ملے تو پاک مٹی سے تیمم کرلو -اس طرح کہ اپنے چہرے اور ہاتھوں کا مسح کرلو کہ خدا تمہارے لئے کسی طرح کی زحمت نہیں چاہتا. بلکہ یہ چاہتا ہے کہ تمہیں پاک و پاکیزہ بنا دے اور تم پر اپنی نعمت کو تمام کردے شاید تم اس طرح اس کے شکر گزار بندے بن جاؤ\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dclxxvi{اور اپنے اوپر اللہ کی نعمت اور اس کے اس عہد کو یاد کرو جو اس نے تم سے لیاہے جب تم نے یہ کہاکہ ہم نے سن لیا اور اطاعت کی اور خبردار اللہ سے ڈرتے رہو کہ اللہ دل کے رازوں کا بھی جاننے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dclxxvii{ایمان والو خدا کے لئے قیام کرنے والے اور انصاف کے ساتھ گواہی دینے والے بنو اور خبردار کسی قوم کی عداوت تمہیں اس بات پر آمادہ نہ کردے کہ انصاف کو ترک کردو -انصاف کرو کہ یہی تقوٰی سے قریب تر ہے اور اللرُسے ڈرتے رہو کہ اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dclxxviii{اللہ نے صاحبان ایمان اور عمل صالح والوں سے وعدہ کیا ہے کہ ان کے لئے مغفرت اور اج» عظیم ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dclxxix{اور جن لوگوں نے کفر اختیار کیا اور ہماری آیات کی تکذیب کی وہ سب کے سب جہّنمی ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dclxxx{ایمان والو! اپنے اوپر اللہ کی اس نعمت کو یاد کرو کہ جب ایک قوم نے تمہاری طرف ہاتھ بڑھانے کا ارادہ کیاتو خدا نے ان کے ہاتھوں کو تم تک پہنچنے سے روک دیا اور اللہ سے ڈرتے رہو کہ صاحبان هایمان اللہ ہی پر بھروسہ کرتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dclxxxi{اور بے شک اللہ نے بنی اسرائیل سے عہد لیا اور ہم نے ان میں سے بارہ نقیب بھیجے اور خدا نے یہ بھی کہہ دیاکہ ہم تمہارے ساتھ ہیں اگر تم نے نماز قائم کی اور زکوِٰ ادا کی اور ہمارے رسولوں پر ایمان لے آئے اور ان کی مدد کی اور خدا کی راہ میں قرض حسنہ دیاتو ہم یقینا تمہاری برائیوں سے درگزر کریں گے اور تمہیں ان باغات میں داخل کریں گے جن کے نیچے نہریں جاری ہوں گی -پھر جو اس کے بعد کفر کرے گا تو وہ بہت اِرے راستہ کی طرف بہک گیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dclxxxii{پھر ان کی عہد شکنی کی بنا پر ہم نے ان پر لعنت کی اور ان کے دلوں کو سخت بنا دیا وہ ہمارے کلمات کو ان کی جگہ سے ہٹا دیتے ہیں اور انہوں نے ہماری یاددہانی کا اکثر حصّہ فراموش کردیا ہے اور تم ان کی خیانتوں پر برابر مطلع ہوتے رہوگے علاوہ چند افراد کے لہذا ان سے درگزر کرو اور ان کی طرف سے کنارہ کشی کرو کہ اللہ احسان کرنے والوں کو دوست رکھتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dclxxxiii{اور جن لوگوں کا کہنا ہے کہ ہم نصرانی ہیں ہم نے ان سے بھی عہد لیا اور انہوں نے بھی ہماری نصیحت (انجیل)کے ایک حصّہ کو فراموش کردیا تو ہم نے بطور سزا ان کے درمیان عداوت اور بغض کو قیامت تک کے لئے راستہ دے دیا اور عنقریب خدا انہیں ان باتوں سے باخبر کرے گا جو وہ انجام دے رہے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dclxxxiv{اے اہل کتاب تمہارے پاس ہمارا رسول آچکا ہے جو اُن میں سے بہت سی باتوں کی وضاحت کررہا ہے جن کو تم کتاب هخدا میں سے چھاَپا رہے تھے اور بہت سی باتوں سے درگزر بھی کرتا ہے تمہارے پاس خدا کی طرف سے نور اور روشن کتاب آچکی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dclxxxv{جس کے ذریعہ خدا اپنی خوشنودی کا اتباع کرنے والوں کو سلامتی کے راستوں کی ہدایت کرتا ہے اور انہیں تاریکیوں سے نکال کر اپنے حکم سے نور کی طرف لے آتا ہے اور انہیں صراط مستقیم کی ہدایت کرتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dclxxxvi{یقینا وہ لوگ کافر ہیں جن کا کہنا یہ ہے کہ مسیح علیھ السّلامابن مریم ہی اللہ ہیں -پیغمبر آپ ان سے کہئے کہ پھر خدا کے مقابلہ میں کون کسی امر کا صاحبِ اختیار ہوگا اگر وہ مسیح علیھ السّلام بن مریم اور ان کی ماں اور سارے اہل زمین کو مار ڈالنا چاہے اور اللہ ہی کے لئے زمین و آسمان اور ان کے درمیان کی کل حکومت ہے -وہ جسے بھی چاہتا ہے پیدا کرتا ہے اور وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dclxxxvii{اور یہودیوں نے یہ کہنا شروع کردیا کہ ہم اللہ کے فرزند اور اس کے دوست ہیں تو پیغمبر آپ کہہ دیجئے کہ پھر خدا تم پر تمہارے گناہوں کی بنا پر عذاب کیوںکرتا ہے ... بلکہ تم اس کی مخلوقات میں سے بشر ہو اور وہ جس کو چاہتا ہے بخش دیتا ہے اور جس پر چاہتا ہے عذاب کرتا ہے اور اس کے لئے زمین و آسمان اور ان کے درمیان کی کل کائنات ہے اور اسی کی طرف سب کی بازگشت ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dclxxxviii{اے اہلِ کتاب تمہارے پاس رسولوں کے ایک وقفہ کے بعد ہمارا یہ رسول آیا ہے کہ تم یہ نہ کہو کہ ہمارے پاس کوئی بشیر و نذیر نہیں آیا تھا تو لو یہ بشیر و نذیر آگیا ہے اور خدا ہر شے پر قادر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dclxxxix{اور اس وقت کو یاد کرو جب موسٰی نے اپنی قوم سے کہا کہ اے قوم اپنے اوپر اللہ کی نعمت کو یاد کرو جب اس نے تم میں انبیائ قرار دئیے اور تمہیں بادشاہ بنایا اور تمہیں وہ سب کچھ دے دیا جو عالمین میں کسی کو نہیں دیا تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcxc{اور اے قوم اس ارعَ مقدس میں داخل ہوجاؤ جسے اللہ نے تمہارے لئے لکھ دیا ہے اور میدان سے اُلٹے پاؤں نہ پلٹ جاؤ کہ اُلٹے خسارہ والوں میں سے ہوجاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcxci{ان لوگوں نے کہا کہ موسٰی علیھ السّلام وہاں تو جابروں کی قوم آباد ہے اور ہم اس وقت تک داخل نہ ہوں گے جب تک وہ وہاں سے نکل نہ جائیں پھر اگر وہ نکل گئے تو ہم یقینا داخل ہوجائیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcxcii{مگر دو انسان جنہیں خدا کا خوف تھا اور ان پر خدا نے فضل و کرم کیا تھا انہوں نے کہا کہ ان کے دروازے سے داخل ہوجاؤ -اگر تم دروازے میں داخل ہوگئے تو یقینا غالب آجاؤ گے اور اللہ پر بھروسہ کرو اگر تم صاحبانِ ایمان ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcxciii{ان لوگوں نے کہا کہ موسٰی علیھ السّلام ہم ہرگز وہاں داخل نہ ہوں گے جب تک وہ لوگ وہاں ہیں -آپ اپنے پروردگار کے ساتھ جاکر جنگ کیجئے ہم یہاں بیٹھے ہوئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcxciv{موسٰی علیھ السّلامنے کہا پروردگار میں صرف اپنی ذات اور اپنے بھائی کا اختیار رکھتا ہوں لہذا ہمارے اور اس فاسق قوم کے درمیان جدائی پیدا کردے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcxcv{ارشاد ہوا کہ اب ان پر چالیس سال حرام کردئیے گئے کہ یہ زمین میں چکرّ لگاتے رہیں گے لہذا تم اس فاسق قوم پر افسوس نہ کرو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcxcvi{اور پیغمبر علیھ السّلامآپ ان کو آدم علیھ السّلامکے دونوں فرزندوں کا سچا ّقصّہ پڑھ کر سنائیے کہ جب دونوں نے قربانی دی اور ایک کی قربانی قبول ہوگئی اور دوسرے کی نہ ہوئی تو اس نے کہا کہ میں تجھے قتل کردوں گا تو دوسرے نے جواب دیا کہ میرا کیا قصور ہے خدا صرف صاحبان ه تقوٰی کے اعمال کو قبول کرتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcxcvii{اگر آپ میری طرف قتل کے لئے ہاتھ بڑھائیں گے بھی تو میں آپ کی طرف ہرگز ہاتھ نہ بڑھاؤں گا کہ میں عالمین کے پالنے والے خدا سے ڈرتا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcxcviii{میں چاہتا ہوں کہ آپ میرے اور اپنے دونوں کے گناہوں کا مرکز بن جائیے اور جہنمیوں میں شامل ہوجائیے کہ ظالمین کی یہی سزا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcxcix{پھر اس کے نفس نے اسے بھائی کے قتل پر آمادہ کردیا اور اس نے اسے قتل کردیا اور وہ خسارہ والوں میں شامل ہوگیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcc{پھر خدا نے ایک کوّا بھیجا جو زمین کھود رہا تھا کہ اسے دکھلائے کہ بھائی کی لاش کو کس طرح چھپائے گا تو اس نے کہا کہ افسوس میں اس کوّے کے جیسا بھی نہ ہوسکا کہ اپنے بھائی کی لاش کو زمین میں چھاَپا دیتا اور اس طرح وہ نادمین اور پشیمان لوگوں میں شامل ہوگیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcci{اسی بنا پر ہم نے بنی اسرائیل پر لکھ دیا کہ جو شخص کسی نفس کو .... کسی نفس کے بدلے یا روئے زمین میں فساد کی سزا کے علاوہ قتل کرڈالے گا اس نے گویا سارے انسانوں کو قتل کردیا اور جس نے ایک نفس کو زندگی دے دی اس نے گویا سارے انسانوں کو زندگی دے دی اور بنی اسرائیل کے پاس ہمارے رسول کھلی ہوئی نشانیاں لے کر آئے مگر اس کے بعد بھی ان میں کے اکثر لوگ زمین میں زیادتیاں کرنے والے ہی رہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dccii{بس خدا و رسول سے جنگ کرنے والے اور زمین میں فساد کرنے والوں کی سزا یہی ہے کہ انہیں قتل کردیا جائے یا سولی پر چڑھا دیا جائے یا ان کے ہاتھ اور پیر مختلف سمت سے قطع کردئیے جائیں یا انہیں ارض ه وطن سے نکال باہر کیا جائے .یہ ان کے لئے دنیا میں رسوائی ہے اور ان کے لئے آخرت میں عذاب هعظیم ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcciii{علاوہ ان لوگوں کے جو تمہارے قابو میں آنے سے پہلے ہی توبہ کرلیں تو سمجھ لو کہ خدا بڑا بخشنے والا مہربان ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcciv{ایمان والو اللہ سے ڈرو اور اس تک پہنچے کا وسیلہ تلاش کرو اوراس کی راہ میں جہاد کرو کہ شاید اس طرح کامیاب ہوجاؤ\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dccv{یقینا جن لوگوں نے کفر اختیار کیا اگر ان کے پاس ساری زمین کا سرمایہ ہو اور اتنا ہی اور شامل کردیں کہ روز هقیامت کے عذاب کا بدلہ ہوجائے تو یہ معاوضہ قبول نہ کیا جائے گا اور ان کے لئے دردناک عذاب ہوگا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dccvi{یہ لوگ چاہتے ہیں جہّنم سے نکل جائیں حالانکہ یہ نکلنے والے نہیں ہیں اور ان کے لئے ایک مستقل عذاب ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dccvii{چور مرد اور چور عورت دونوں کے ہاتھ کاٹ دو کہ یہ ان کے لئے بدلہ اور خدا کی طرف سے ایک سزا ہے اور خدا صاحبِ عزّت بھی ہے اور صاحبِ حکمت بھی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dccviii{پھر ظلم کے بعد جو شخص توبہ کرلے اور اپنی اصلاح کرلے تو خدا اس کی توبہ قبول کرلے گا کہ اللہ بڑا بخشنے والا اور مہربان ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dccix{کیا تم کو نہیں معلوم کہ زمین و آسمان کا ملک صرف خدا ہی کے لئے ہے وہ جس پر چاہتا ہے عذاب کرتا ہے اور جس کو چاہتا ہے بخش دیتا ہے اور اللہ ہر شے پر قادر و مختار ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dccx{اے رسول ایمان کا دعویٰ کرنے والوں میں جو لوگ کفر کی طرف جلد بازی سے بڑھ رہے ہیں ان کی حرکات سے آپ رنجیدہ نہ ہوں -یہ صرف زبان سے ایمان کا نام لیتے ہیں اور ان کے دل مومن نہیں ہیں اور یہودیوں میں سے بھی بعض ایسے ہیں جو جھوٹی باتیں سنتے ہیں اور دوسری قوم والے جو آپ کے پاس حاضر نہیں ہوئے انہیں سناتے ہیں - یہ کلمات کو ان کی جگہ سے ہٹا دیتے ہیں اور لوگوں سے کہتے ہیں کہ اگر پیغمبر کی طرف سے یہی دیا جائے تو لے لینا اور اگر یہ نہ دیا جائے تو پرہیز کرنا اور جس کے فتنہ کے بارے میں خدا ارادہ کرلے اس کے بارے میں آپ کا کوئی اختیار نہیں ہے یہ وہ افراد ہیں جن کے بارے میں خدا نے یہ ارادہ ہی نہیں کیا کہ زبردستی ان کے دلوں کو پاک کردے گا -ان کے لئے دنیا میں بھی رسوائی ہے اور آخرت میں بھی عذابِ عظیم ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dccxi{یہ جھوٹ کے سننے والے اور حرام کے کھانے والے ہیں لہذا اگر آپ کے پاس مقدمہ لے کر آئیں تو آپ کو اختیار ہے کہ فیصلہ کردیں یا اعراض کرلیں کہ اگر اعراض بھی کرلیں گے تو یہ آپ کو کوئی نقصان نہ پہنچا سکیں گے لیکن اگر فیصلہ ہی کریں تو انصاف کے ساتھ کریں کہ خدا انصاف کرنے والوں کو دوست رکھتا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dccxii{اور یہ کس طرح آپ سے فیصلہ کرائیں گے جب کہ ان کے پاس توریت موجود ہے جس میں حکهِ خدا بھی ہے اور یہ اس کے بعد بھی منہ پھیر لیتے ہیں اور پھر ایمان لانے والے نہیں ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dccxiii{بیشک ہم نے توریت کو نازل کیا ہے جس میں ہدایت اور نور ہے اور اس کے ذریعہ اطاعت گزار انبیائ یہودیوں کے لئے فیصلہ کرتے ہیں اور اللہ والے اور علمائے یہود اس چیز سے فیصلہ کرتے ہیں جس کا کتاب هخدا میں ان کو محافظ بنایا گیا ہے اور جس کے یہ گواہ بھی ہیں لہذا تم ان لوگوں سے نہ ڈرو صرف ہم سے ڈرو اور خبردار تھوڑی سی قیمت کے لئے ہماری آیات کا کاروبار نہ کرنا اور جو بھی ہمارے نازل کئے ہوئے قانون کے مطابق فیصلہ نہ کرے گا وہ سب کافر شمار ہوں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dccxiv{اور ہم نے توریت میں یہ بھی لکھ دیا ہے کہ جان کا بدلہ جان اور آنکھ کا بدلہ آنکھ اور ناک کا بدلہ ناک اور کان کا بدلہ کان اور دانت کا بدلہ دانت ہے اور زخموں کا بھی بدلہ لیا جائے گا اب اگر کوئی شخص معاف کردے تو یہ اس کے گناہوں کا بھی کفارہ ہوجائے گا اور جو بھی خدا کے نازل کردہ حکم کے خلاف فیصلہ کرے گا وہ ظالموں میں سے شمار ہوگا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dccxv{اور ہم نے ان ہی انبیائ کے نقشِ قدم پر عیسٰی علیھ السّلامبن مریم کو چلادیا جو اپنے سامنے کی توریت کی تصدیق کرنے والے تھے اور ہم نے انہیں انجیل دے دی جس میں ہدایت اور نور تھا اور وہ اپنے سامنے کی توریت کی تصدیق کرنے والی اور ہدایت تھی اور صاحبانِ تقوٰی کے لئے سامانِ نصیحت تھی\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dccxvi{اہلِ انجیل کو چاہئے کہ خدا نے جو حکم نازل کیا ہے اس کے مطابق فیصلہ کریں کہ جو بھی تنزیل هخدا کے مطابق فیصلہ نہ کرے گا وہ فاسقوں میں شمار ہوگا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dccxvii{اور اے پیغمبر ہم نے آپ کی طرف کتاب نازل کی ہے جو اپنے پہلے کی توریت اور انجیل کی لَصدق اور محافظ ہے لہذا آپ ان کے درمیان تنزیل خدا کے مطابق فیصلہ کریں اور خدا کی طرف سے آئے ہوئے حق سے الگ ہوکر ان کی خواہشات کا اتباع نہ کریں .ہم نے سب کے لئے الگ الگ شریعت اور راستہ مقرر کردیا ہے اور خدا چاہتا تو سب کو ایک ہی امت بنا دیتا لیکن وہ اپنے دئیے ہوئے قانون سے تمہاری آزمائش کرنا چاہتا ہے لہذا تم سب نیکیوں کی طرف سبقت کرو کہ تم سب کی بازگشت اللہ ہی کی طرف ہے -وہاں وہ تمہیں ان تمام باتوں سے باخبر کرے گا جن میں تم اختلاف کررہے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dccxviii{اور پیغمبر آپ ان کے درمیان تنزیلِ خدا کے مطابق فیصلہ کریں اور ان کی خواہشات کا اتباع نہ کریں اور اس بات سے بچتے رہیں کہ یہ بعض احکام الٰہی سے منحرف کردیں -پھر اگر یہ خود منحرف ہوجائیں تو یاد رکھیں کہ خدا ان کو ان کے بعض گناہوں کی مصیبت میں مبتلا کرنا چاہتا ہے اور انسانوں کی اکثریت فاسق اور دائرسِ اطاعت سے خارج ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dccxix{کیا یہ لوگ جاہلیت کا حکم چاہتے ہیں جب کہ صاحبانِ یقین کے لئے اللہ کے فیصلہ سے بہتر کس کا فیصلہ ہوسکتا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dccxx{ایمان والو یہودیوں اور عیسائیوں کو اپنا دوست اور سرپرست نہ بناؤ کہ یہ خود آپس میں ایک دوسرے کے دوست ہیں اور تم میں سے کوئی انہیں دوست بنائے گا تو ان ہی میں شمار ہوجائے گا بیشک اللہ ظالم قوم کی ہدایت نہیں کرتا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dccxxi{پیغمبر آپ دیکھیں گے کہ جن کے دلوں میں نفاق کی بیماری ہے وہ دوڑ دوڑ کر ان کی طرف جارہے ہیں اور یہ عذر بیان کرتے ہیں کہ ہمیں گردشِ زمانہ کا خوف ہے -پس عنقریب خدا اپنی طرف سے فتح یا کوئی دوسرا امر لے آئے گا تو یہ اپنے دل کے چھپائے ہوئے راز پر پشیمان ہوجائیں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dccxxii{اور صاحبان هایمان کہیں گے کہ کیا یہی لوگ ہیں جنہوں نے نام ه خدا پر سخت ترین قسمیں کھائی تھیں کہ ہم تمہارے ساتھ ہیں تو اب ان کے اعمال برباد ہوگئے اور یہ خسارہ والے ہوگئے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dccxxiii{ایمان والو تم میں سے جو بھی اپنے دین سے پلٹ جائے گا ...تو عنقریب خدا ایک قوم کو لے آئے گا جو اس کی محبوب اور اس سے محبت کرنے والی مومنین کے سامنے خاکسار اور کفار کے سامنے صاحبِ عزت, راسِ خدا میں جہاد کرنے والی اور کسی ملامت کرنے والے کی ملامت کی پرواہ نہ کرنے والی ہوگی -یہ فضلِ خدا ہے وہ جسے چاہتا ہے عطا کرتا ہے اور وہ صاحبِ وسعت اور علیم و دانا بھی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dccxxiv{ایمان والو بس تمہارا ولی اللہ ہے اور اس کا رسول اور وہ صاحبانِ ایمان جو نماز قائم کرتے ہیں اور حالت رکوع میں زکوِٰ دیتے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dccxxv{اور جو بھی اللہ ,رسول اور صاحبانِ ایمان کو اپنا سرپرست بنائے گا تو اللہ کی ہی جماعت غالب آنے والی ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dccxxvi{ایمان والو خبردار اہل ه کتاب میں جن لوگوں نے تمہارے دین کو مذاق اور تماشہ بنالیا ہے اور دیگر کفار کو بھی اپنا ولی اور سرپرست نہ بنانا اور اللہ سے ڈرتے رہنا اگر تم واقعی صاحب ایمان ہو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dccxxvii{اور جب تم نماز کے لئے اذان دیتے ہو تو یہ اس کو مذا ق اور کھیل بنالیتے ہیں اس لئے کہ یہ بالکل بے عقل قوم ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dccxxviii{پیغمبر آپ کہہ دیجئے کہ اے اہلِ کتاب کیا تم ہم سے صرف اس بات پر ناراض ہوکہ ہم اللہ اور اس نے جو کچھ ہماری طرف یا ہم سے پہلے نازل کیا ہے ان سب پر ایمان رکھتے ہیں اور تمہاری اکثریت فاسق اور نافرمان ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dccxxix{کیا ہم تم کو خدا کے نزدیک ایک منزل کے اعتبار سے اس سے بدتر عیب کی خبر دیں کہ جس پر خد انے لعنت اور غضب نازل کیا ہے اوران میں سے بعض کو بندر اور سور بنادیا ہے اور جس نے بھی طاغوت کی عبادت کی ہے وہ جگہ کے اعتبار سے بدترین اور سیدھے راستہ سے انتہائی بہکا ہوا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dccxxx{اور یہ جب تمہارے پاس آتے ہیں تو کہتے ہیں کہ ہم ایمان لے آئے ہیں حالانکہ یہ کفر ہی کے ساتھ داخل ہوئے ہیں اور اسی کو لے کر نکلے ہیں اور خدا ان سب باتوں کو خوب جانتا ہے جن کو یہ چھپائے ہوئے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dccxxxi{ان میں سے بہت سوں کو آپ دیکھیں گے کہ وہ گناہ اور ظلم اور حرام خوری میں دوڑتے پھرتے ہیں اور یہ بدترین کام انجام دے رہے ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccxxxii{آخر انہیں اللہ والے اور علمائ ان کے جھوٹ بولنے اور حرام کھانے سے کیوں نہیں منع کرتے -یہ یقینا بہت برا کررہے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dccxxxiii{اور یہودی کہتے ہیں کہ خدا کے ہاتھ بندھے ہوئے ہیں جب کہ اصل میں ان ہی کے ہاتھ بندھے ہوئے ہیں اور یہ اپنے قول کی بنا پر ملعون ہیں اور خدا کے دونوں ہاتھ کھلے ہوئے ہیں اور وہ جس طرح چاہتا ہے خرچ کرتاہے اور جو کچھ آپ پر پروردگار کی طرف سے نازل ہوا ہے اس کا انکار ان میں سے بہت سوں کے کفر اور ان کی سرکشی کو اور بڑھادے گا اور ہم نے ان کے درمیان قیامت تک کے لئے عداوت اور بغض پیدا کردیا ہے کہ جب بھی جنگ کی آگ بھڑکانا چاہیں گے خدا بجھا دے گا اور یہ زمین میں فساد کی کوشش کررہے ہیں اور خدا مفسدوں کو دوست نہیں رکھتا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dccxxxiv{اور اگر اہلِ کتاب ایمان لے آتے اور ہم سے ڈرتے رہتے تو ہم ان کے گناہوں کو معاف کردیتے اور انہیں نعمتوں کے باغات میں داخل کردیتے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccxxxv{اور اگر یہ لوگ توریت و انجیل اور جو کچھ ان کی طرف پروردگار کی طرف سے نازل کیا گیا ہے سب کو قائم کرتے تو اپنے اوپر اور قدموں کے نیچے سے رزق هخدا حاصل کرتے ,ان میں سے ایک قوم میانہ رو ہے اور زیادہ حصّہ لوگ بدترین اعمال انجام دے رہے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccxxxvi{اے پیغمبر آپ اس حکم کو پہنچادیں جو آپ کے پروردگار کی طرف سے نازل کیا گیا ہے اور اگر آپ نے یہ نہ کیا تو گویا اس کے پیغام کو نہیں پہنچایا اور خدا آپ کو لوگوں کے شر سے محفوظ رکھے گا کہ اللہ کافروں کی ہدایت نہیں کرتا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccxxxvii{کہہ دیجئے کہ اے اہل کتاب تمہارا کوئی مذہب نہیں ہے جب تک توریت و انجیل اور جو کچھ پروردگار کی طرف سے نازل ہوا ہے اسے قائم نہ کرو اور جو کچھ آپ کے پاس پروردگار کی طرف سے نازل ہوا ہے وہ ان کی کثیر تعداد کی سرکشی اور کفر میں اضافہ کردے گا تو آپ کافروں کے حال پر رنجیدہ نہ ہوں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccxxxviii{بیشک جو لوگ صاحبِ ایمان ہیںیا یہودی اور ستارہ پرست اور عیسائی ہیں ان میں سے جو بھی اللہ اور آخرت پر واقعی ایمان لائے گا اور عمل صالح کرے گا اس کے لئے نہ خوف ہے اور نہ اُسے حزن ہوگا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccxxxix{ہم نے بنی اسرائیل سے عہد لیا ہے اور ان کی طرف بہت سے رسول بھیجے ہیں لیکن جب ان کے پاس کوئی رسول ان کی خواہش کے خلاف حکم لے آیا تو انہوں نے ایک جماعت کی تکذیب کی اور ایک گروہ کو قتل کردیتے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccxl{اور ان لوگوں نے خیال کیا کہ اس میں کوئی خرابی نہ ہوگی اسی لئے یہ حقائق سے اندھے اور بہرے ہوگئے ہیں -اس کے بعد خدا نے ان کی توبہ قبول کرلی لیکن پھر بھی اکثریت اندھی بہری ہوگئی اور خدا ان کے تمام اعمال پر گہری نگاہ رکھتا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccxli{یقینا وہ لوگ کافر ہیں جن کا کہنا ہے کہ اللہ ہی مسیح علیھ السّلامبن مریم ہیں جبکہ خود مسیح کا کہنا ہے کہ اے بنی اسرائیل اپنے اور میرے پروردگار کی عبادت کرو -جو کوئی اس کا شریک قرار دے گا اس پر خدا نے جنّت حرام کردی ہے اور اس کا انجام جہّنم ہے اور ظالموں کا کوئی مددگار نہ ہوگا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccxlii{یقینا وہ لوگ کافر ہیں جن کا کہنا یہ ہے کہ اللہ تین میں کا تیسرا ہے .... حالانکہ اللہ کے علاوہ کوئی خدا نہیں ہے اور اگر یہ لوگ اپنے قول سے باز نہ آئیں گے تو ان میں سے کِفر اختیار کرنے والوں پر دردناک عذاب نازل ہوجائے گا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccxliii{یہ لوگ خدا کی بارگاہ میں توبہ اور استغفار کیوں نہیں کرتے جب کہ اللہ بہت بخشنے والا اور مہربان ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccxliv{مسیح علیھ السّلامبن مریم کچھ نہیں ہیں صرف ہمارے رسول ہیں جن سے پہلے بہت سے رسول گزر چکے ہیں اور ان کی ماں صدیقہ تھیں اور وہ دونوں کھانا کھایا کرتے تھے .... دیکھو ہم اپنی نشانیوں کو کس طرح واضح کرکے بیان کرتے ہیں اور پھر دیکھو کہ یہ لوگ کس طرح بہکے جارہے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccxlv{پیغمبر آپ ان سے کہئے کہ کیا تم اللہ کو چھوڑ کر ان کی عبادت کرتے ہو جو تمہارے لئے نفع اور نقصان کے مالک بھی نہیں ہیں اور خدا سننے والا بھی ہے اور جاننے والا بھی ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccxlvi{پیغمبر آپ کہہ دیجئے کہ اے اہلِ هکتاب اپنے دین میں ناحق غلو سے کام نہ لو اور اس قوم کی خواہشات کا اتباع نہ کرو جو پہلے سے گمراہ ہوچکی ہے اور بہت سے لوگوں کو گمراہ بھی کرچکی ہے اور سیدھے راستہ سے بہک چکی ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccxlvii{بنی اسرائیل میں سے کفر اختیار کرنے والوں پر جناب داؤد علیھ السّلام اور جناب عیسٰی علیھ السّلامکی زبان سے لعنت کی جاچکی ہے کہ ان لوگوں نے نافرمانی کی اور ہمیشہ حد سے تجاوز کیا کرتے تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccxlviii{انہوں نے جو برائی بھی کی ہے اس سے باز نہیں آتے تھے اور بدترین کام کیا کرتے تھے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccxlix{ان میں سے اکثر کو آپ دیکھیں گے کہ یہ کفار سے دوستی کرتے ہیں-انہوں نے اپنے نفس کے لئے جو سامان پہلے سے فراہم کیا ہے وہ بہت اِرا سامان ہے جس پر خدا ان سے ناراض ہے اور وہ عذاب میں ہمیشہ رہنے والے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccl{اگر یہ لوگ اللرُ اور نبی موسٰی علیھ السّلام اور جو کچھ ان پر نازل ہوا ہے سب پر ایمان رکھتے تو ہرگز کفاّر کو دوست نہ بناتے لیکن ان میں سے بہت سے لوگ فاسق اور نافرمان ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccli{آپ دیکھیں گے کہ صاحبانِ ایمان سے سب سے زیادہ عداوت رکھنے والے یہودی اور مشرک ہیں اور ان کی محبت سے سب سے زیادہ قریب وہ لوگ ہیں جو کہتے ہیں کہ ہم نصرانی ہیں ...._ یہ اس لئے ہے کہ ان میں بہت سے قسیس اور راہب پائے جاتے ہیں اور یہ متکبر اور برائی کرنے والے نہیں ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dcclii{اور جب اس کلام کو سنتے ہیں جو رسول پر نازل ہوا ہے تو تم دیکھتے ہو کہ ان کی آنکھوں سے بے ساختہ آنسو جاری ہوجاتے ہیں کہ انہوں نے حق کو پہچان لیا ہے اور کہتے ہیں کہ پروردگار ہم ایمان لے آئے ہیں لہذا ہمارا نام بھی تصدیق کرنے والوں میں درج کرلے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccliii{بھلا ہم اللہ اور اپنے پاس آنے والے حق پر کس طرح ایمان نہ لائیں گے جب کہ ہماری خواہش ہے کہ پروردگار ہمیں نیک کردار بندوں میں شامل کرلے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccliv{تو اس قول کی بنا پر پروردگار نے انہیں وہ باغات دے دئیے جن کے نیچے نہریں بہہ رہی ہیں اور وہ انہی میں ہمیشہ رہنے والے ہیں کہ یہی نیک کردار لوگوں کی جزا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dcclv{اور جن لوگوں نے کفر اختیار کرلیا اور ہماری آیات کو جھٹلا دیا تو وہ لوگ جہنّمی ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dcclvi{ایمان والو جن چیزوں کو خدا نے تمہارے لئے حلال کیا ہے انہیں حرام نہ بناؤ اور حد سے تجاوز نہ کرو کہ خدا تجاوز کرنے والوں کو دوست نہیں رکھتا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dcclvii{اور جو اس نے رزق حلال و پاکیزہ دیا ہے اس کو کھاؤ اور اس خدا سے ڈرتے رہو جس پر ایمان رکھنے والے ہو\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dcclviii{خدا تم سے بے مقصد قسمیں کھانے پر مواخذہ نہیں کرتا ہے لیکن جن قسموں کی گرہ دل نے باندھ لی ہے ان کی مخالفت کا کفارہ دس مسکینوں کے لئے اوسط درجہ کا کھانا ہے جو اپنے گھر والوں کو کھلاتے ہو یا ان کا کپڑا یا ایک غلام کی آزادی ہے .... پھر اگر یہ سب ناممکن ہو تو تین روزے رکھو ...._ کہ یہ تمہاری قسموں کا کفارہ ہے جب بھی تم قسم کھا کر اس کی مخالفت کرو اپنی قسموں کا تحفظ کرو کہ خدا اس طرح اپنی آیات کو واضح کرکے بیان کرتا ہے کہ شاید تم اس کے شکر گزار بندے بن جاؤ\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dcclix{ایمان والو !شرابً جوا ,بت ,پانسہ یہ سب گندے شیطانی اعمال ہیں لہذا ان سے پرہیز کرو تاکہ کامیابی حاصل کرسکو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dcclx{شیطان تو بس یہی چاہتا ہے کہ شراب اور جوے کے بارے میں تمہارے درمیان بغض اور عداوت پیدا کردے اور تمہیں یاد خدا اور نماز سے روک دے تو کیا تم واقعا رک جاؤ گے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dcclxi{اور دیکھو اللہ کی اطاعت کرو اور رسول کی اطاعت کرو اور نافرمانی سے بچتے رہو ورنہ اگر تم نے روگردانی کی توجان لو کہ رسول کی ذمہ داری صرف واضح پیغام کا پہنچادینا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dcclxii{جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ان کے لئے اس میں کوئی حرج نہیں ہے جو کچھ کھا پی چکے ہیں جب کہ وہ متقی بن گئے اور ایمان لے آئے اور نیک اعمال کئے اور پرہیز کیااور ایمان لے آئے اور پھر پرہیز کیا اور نیک عمل کیا اور نیک اعمال کرنے والوں ہی کو دوست رکھتا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dcclxiii{ایمان والو !اللہ ان شکاروں کے ذریعہ تمہارا امتحان ضرور لے گا جن تک تمہارے ہاتھ اور نیزے پہنچ جاتے ہیں تاکہ وہ یہ دیکھے کہ اس سے لوگوں کے غائبانہ میں بھی کون کون ڈرتا ہے پھر جو اس کے بعد بھی زیادتی کرے گا اس کے لئے دردناک عذاب ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dcclxiv{ایمان والو حالاُ احرام میں شکار کو نہ مارو اور جو تم میں قصدا ایسا کرے گا اس کی سزا انہی جانوروں کے برابر ہے جنہیں قتل کیا ہے جس کا فیصلہ تم میں سے دو عادل افراد کریں اور اس قربانی کو کعبہ تک جانا چاہئے یا مساکین کے کھانے کی شکل میں کفارہ دیا جائے یا اس کے برابر روزے رکھے جائیں تاکہ اپنے کام کے انجام کا مزہ چکھیں -اللہ نے گزشتہ معاملات کو معاف کردیا ہے لیکن اب جو دوبارہ شکار کرے گا تو اس سے انتقام لے گا اور وہ سب پر غالب آنے والا اور بدلہ لینے والا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dcclxv{تمہارے لئے دریائی جانور کا شکار کرنا اور اس کا کھانا حلال کردیا گیا ہے کہ تمہارے لئے اور قافلوں کے لئے فائدہ کا ذریعہ ہے اور تمہارے لئے خشکی کا شکار حرام کردیا گیا ہے جب تک حالت احرام میں رہو اور اس خدا سے ڈرتے رہو جس کی بارگاہ میں حاضر ہونا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dcclxvi{اللہ نے کعبہ کو جو بیت الحرام ہے اور محترم مہینے کو اور قربانی کے عام جانوروں کو اور جن جانوروں کے گلے میں پٹہ ڈال دیا گیا ہے سب کو لوگوں کے قیام و صلاح کا ذریعہ قرار دیا ہے تاکہ تمہیں یہ معلوم رہے کہ اللہ زمین و آسمان کی ہر شے سے باخبر ہے اور وہ کائنات کی ہر شے کا جاننے والا ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dcclxvii{یاد رکھو خدا سخت عذاب کرنے والا بھی ہے اور غفور و رحیم بھی ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dcclxviii{اور رسول پر تبلیغ کے علاوہ کوئی ذمہ داری نہیں ہے اور اللہ سے جن باتوں کا تم اظہار کرتے ہو یا چھپاتے ہو سب سے باخبر ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dcclxix{پیغمبر آپ کہہ دیجئے کہ خبیث اور پاکیزہ برابر نہیں ہوسکتے ,چاہے خبیث کی کثرت اچھی ہی کیوں نہ لگے صاحبان عقل اللہ سے ڈرتے رہو شاید کہ تم اس طرح کامیاب ہوجاؤ\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcclxx{ایمان والو ان چیزوں کے بارے میں سوال نہ کرو جو تم پر ظاہر ہوجائیں تو تمہیں بری لگیں اور اگر نزول قرآن کے وقت دریافت کرلو گے تو ظاہر بھی کردی جائیں گی اور اب تک کی باتوں کواللہ نے معاف کردیا ہے کہ وہ بڑا بخشنے والا اور برداشت کرنے والا ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcclxxi{تم سے سے پہلے والی قوموں نے بھی ایسے ہی سوالات کئے اور اس کے بعد پھر کافر ہوگئے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcclxxii{اللہ نے بحیرہ ,سائبہ ,وصیلہ اور ہام کا کوئی قانون نہیں بنایا یہ جو لوگ کافر ہوگئے ہیں وہ اللہ پر جھوٹا بہتان باندھتے ہیں اور ان میں کے اکثر بے عقل ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcclxxiii{اور جب ان سے کہا جاتا ہے کہ خد اکے نازل کئے ہوئے احکام اور اس کے رسول کی طرف آؤ تو کہتے ہیں کہ ہمارے لئے وہی کافی ہے جس پر ہم نے اپنے آباؤ و اجداد کو پایا ہے چاہے ان کے آباؤ و اجداد نہ کچھ سمجھتے ہوں اور نہ کسی طرح کی ہدایت کرتے ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcclxxiv{ایمان والو اپنے نفس کی فکر کرو -اگر تم ہدایت یافتہ رہے تو گمراہوں کی گمراہی تمہیں کوئی نقصان نہیں پہنچاسکتی -تم سب کی بازگشت خدا کی طرف ہے پھر وہ تمہیں تمہارے اعمال سے باخبر کرے گا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcclxxv{ایمان والو جب تم میں سے کسی کی موت سامنے آجائے تو گواہی کا خیال رکھنا کہ وصیت کے وقت دو عادل گواہ تم میں سے ہوں یا پھر تمہارے غیر میں سے ہوں اگر تم سفر کی حالت میں ہو اور وہیں موت کی مصیبت نازل ہوجائے ان دونوں کو نماز کے بعد روک کر رکھو پھر اگر تمہیں شک ہو تو یہ خدا کی قسم کھائیں کہ ہم اس گواہی سے کسی طرح کا فائدہ نہیں چاہتے ہیں چاہے قرابتدار ہی کا معاملہ کیوں نہ ہو اور نہ خدائی شہادت کو چھپاتے ہیں کہ اس طرح ہم یقینا گناہگاروں میں شمار ہوجائیں گے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcclxxvi{پھر اگر معلوم ہوجائے کہ وہ دونوں گناہ کے حقدار ہوگئے ہیں تو ان کی جگہ دو دوسرے آدمی کھڑے ہوں گے ان افراد میں سے جو میت سے قریب تر ہیں اور وہ قسم کھائیں گے کہ ہماری شہادت ان کی شہادت سے زیادہ صحیح ہے اور ہم نے کسی طرح کی زیادتی نہیں کی ہے کہ اس طرح ظالمین میں شمار ہوجائیں گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcclxxvii{یہ بہترین طریقہ ہے کہ شہادت کو صحیح طریقہ سے پیش کریں یا اس بات سے ڈریں کہ کہیں ہماری گواہی دوسروں کی گواہی کے بعد رد نہ کردی جائے اوراللہ سے ڈرتے رہو اور اس کی سنو کہ وہ فاسق قوم کی ہدایت نہیں کرتا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcclxxviii{جس دن خدا تمام مرسلین کو جمع کرکے سوال کرے گا کہ تمہیں قوم کی طرف سے تبلیغ کا کیا جواب ملا تو وہ کہیں گے کہ ہم کیا بتائیں تو خود ہی غیب کا جاننے والا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcclxxix{اور جب اللہ نے کہا کہ اے عیسٰی بن مریم کیا تم نے لوگوں سے یہ کہہ دیا ہے کہ اللہ کو چھوڑ کو مجھے اور میری ماں کو خدا مان لو .... تو عیسٰی نے عرض کی کہ تیری ذات بے نیاز ہے میں ایسی بات کیسے کہوں گا جس کا مجھے کوئی حق نہیں ہے اور اگر میں نے کہا تھا تو تجھے تو معلوم ہی ہے کہ تو میرے دل کا حال جانتا ہے اور میں تیرے اسرار نہیں جانتا ہوں -تو ,تو غیب کا جاننے والا بھی ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@dcclxxx{اور جب ہم نے حواریین کی طرف الہام کیا کہ ہم پر اور ہمارے رسولوں پر ایمان لے آؤ تو انہوں نے کہا کہ ہم ایمان لے آئے اور تو گواہ رہنا کہ ہم مسلمان ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@dcclxxxi{اور جب حواریین نے کہا کہ اے عیسٰی بن مریم کیا تمہارے رب میں یہ طاقت بھی ہے کہ ہمارے اوپر آسمان سے دسترخوان نازل کردے تو انہوں نے جواب دیا کہ تم اگر مومن ہو تو اللہ سے ڈرو\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@dcclxxxii{ان لوگوں نے کہا کہ ہم چاہتے ہیں کہ ہم اس میں سے کھائیں اور اطمینان قلب پیدا کریں اور یہ جان لیں کہ آپ نے ہم سے سچ کہا ہے اور ہم خود بھی اس کے گواہوں میں شامل ہوجائیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiii{عیسٰی بن مریم نے کہا خدایا پروردگار !ہمارے اوپر آسمان سے دستر خوان نازل کردے کہ ہمارے اول و آخر کے لئے عید ہوجائے اور تیری قدرت کی نشانی بن جائے اور ہمیں رزق دے کہ تو بہترین رزق دینے والا ہے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@dcclxxxiv{پروردگار نے کہا کہ ہم نازل تو کررہے ہیں لیکن اس کے بعد جو تم میں سے انکار کرے گا اس پر ایسا عذاب نازل کریں گے کہ عالمین میں کسی پر نہیں کیا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@dcclxxxv{اور جب اللہ نے کہا کہ اے عیسٰی بن مریم کیا تم نے لوگوں سے یہ کہہ دیا ہے کہ اللہ کو چھوڑ کو مجھے اور میری ماں کو خدا مان لو .... تو عیسٰی نے عرض کی کہ تیری ذات بے نیاز ہے میں ایسی بات کیسے کہوں گا جس کا مجھے کوئی حق نہیں ہے اور اگر میں نے کہا تھا تو تجھے تو معلوم ہی ہے کہ تو میرے دل کا حال جانتا ہے اور میں تیرے اسرار نہیں جانتا ہوں -تو ,تو غیب کا جاننے والا بھی ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvi{میں نے ان سے صرف وہی کہا ہے جس کا تو نے حکم دیا تھا کہ میری اور اپنے پروردگار کی عبادت کرو اور میں جب تک ان کے درمیان رہا ان کا گواہ اور نگراں رہا -پھر جب تو نے مجھے اٹھالیا تو تو ان کا نگہبان ہے اور تو ہر شے کا گواہ اور نگراں ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@dcclxxxvii{اگر تو ان پر عذاب کرے گا تو وہ تیرے ہی بندے ہیں اور اگر معاف کردے گا تو صاحب عزت بھی ہے اور صاحب حکمت بھی ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@dcclxxxviii{اللہ نے کہا کہ یہ قیامت کا دن ہے جب صادقین کو ان کا سچ فائدہ پہنچائے گا کہ ان کے لئے باغات ہوں گے جن کے نیچے نہریں جاری ہوں گی اور وہ ان میں ہمیشہ ہمیشہ رہیں گے -خدا ان سے راضی ہوگا اور وہ خدا سے اور یہی ایک عظیم کامیابی ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@dcclxxxix{اللہ کے لئے زمین و آسمان اور ان کے درمیان کی کل حکومت ہے اور وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@dccxc{\basmalahur ساری تعریف اس اللہ کے لئے ہے جس نے آسمانوں اور زمین کو پیدا کیا ہے اور تاریکیوں اور نور کو مقرر کیا ہے اس کے بعد بھی کفر اختیار کرنے والے دوسروں کو اس کے برابر قرار دیتے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@dccxci{وہ خدا وہ ہے جس نے تم کو مٹی سے پیدا کیا ہے پھر ایک مدت کا فیصلہ کیا ہے اور ایک مقررہ مدت اس کے پاس اور بھی ہے لیکن اس کے بعد بھی تم شک کرتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@dccxcii{وہ آسمانوں اور زمین ہرجگہ کا خدا ہے وہ تمہارے باطن اور ظاہر اور جو تم کاروبار کرتے ہو سب کو جانتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@dccxciii{ان لوگوں کے پاس ان کے پروردگار کی کوئی نشانی نہیں آتی مگر یہ کہ یہ اس سے کنارہ کشی اختیار کرلیتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@dccxciv{ان لوگوں نے اس کے پہلے بھی حق کے آنے کے بعد حق کا انکار کیا ہے عنقریب ان کے پاس جن چیزوں کا مذاق اڑاتے تھے ان کی خبریں آنے والی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@dccxcv{کیا انہوں نے نہیں دیکھا کہ ہم نے ان سے پہلے کتنی نسلوں کو تباہ کردیا ہے جنہیں تم سے زیادہ زمین میں اقتدار دیا تھا اور ان پر موسلادھار پانی بھی برسایا تھا -ان کے قدموں میں نہریں بھی جاری تھیں پھر ان کے گناہوں کی بنا پر انہیں ہلاک کردیا اور ان کے بعد دوسری نسل جاری کردی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@dccxcvi{اور اگر ہم آپ پر کاغذ پر لکھی ہوئی کتاب بھی نازل کردیتے اور یہ اپنے ہاتھ سے چھو بھی لیتے تو بھی ان کے کافر یہی کہتے کہ یہ کھلا ہوا جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@dccxcvii{اور یہ کہتے ہیں کہ ان پر مُلکُ کیوں نہیں نازل ہوتا حالانکہ ہم ملُک نازل کردیتے تو کام کا فیصلہ ہوجاتا اور پھر انہیں کسی طرح کی مہلت نہ دی جاتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@dccxcviii{اگر ہم پیغمبر کو فرشتہ بھی بناتے تو بھی مرد ہی بناتے اور وہی لباس پہنچاتے جو مرد پہنا کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@dccxcix{پیغمبر آپ سے پہلے بہت سے رسولوں کا مذاق اُڑایا گیا ہے جس کے نتیجہ میں مذاق اُڑانے والوں کے لئے ان کا مذاق ہی ان کے گلے پڑ گیا اور وہ اس میں گھر گئے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@dccc{آپ ان سے کہہ دیجئے کہ زمین میں سیر کریں پھر اس کے بعد دیکھیں کہ جھٹلانے والوں کا انجام کیا ہوتا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@dccci{ان سے کہئے کہ زمین و آسمان میں جو کچھ بھی ہے وہ سب کس کے لئے ہے? پھر بتائیے کہ سب اللہ ہی کے لئے ہے اس نے اپنے اوپر رحمت کو لازم قرار دے لیا ہے وہ تم سب کو قیامت کے دن اکٹھا کرے گا جس میں کسی شک کی گنجائش نہیں ہے -جن لوگوں نے اپنے نفس کو خسارہ میں ڈال دیا ہے وہ اب ایمان نہ لائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@dcccii{اور اس خدا کے لئے وہ تمام چیزیں ہیں جو رات اور دن میں ثابت ہیں اور وہ سب کی سننے والا اور سب کا جاننے والا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@dccciii{آپ کہئے کہ کیا میں خدا کے علاوہ کسی اور کو اپنا ولی بنالوں جب کہ زمین و آسمان کا پیدا کرنے والا وہی ہے اور وہی سب کو کھلاتا ہے اس کو کوئی نہیں کھلاتا ہے. کہئے کہ مجھے حکم دیا گیا ہے کہ میں سب سے پہلا اطاعت گزار بنوں اور خبردار تم لوگ مشرک نہ ہوجانا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@dccciv{کہئے کہ میں اپنے خدا کی نافرمانی کروں تو مجھے بڑے سنگین دن کے عذاب کا خطرہ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@dcccv{اس دن جس سے عذاب ٹال دیا جائے اس پر خدا نے بڑا رحم کیا اور یہ ایک کھلی ہوئی کامیابی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@dcccvi{اگر خدا کی طرف سے تم کو کوئی نقصان پہنچ جائے تو اس کے علاوہ کوئی ٹالنے والا بھی نہیں ہے اور اگر وہ خیر دے دے تو وہی ہر شے پر قدرت رکھنے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@dcccvii{اور اپنے تمام بندوں پر غالب اور صاحب حکمت اور باخبر رہنے والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@dcccviii{آپ کہہ دیجئے کہ گواہی کے لئے سب سے بڑی چیز کیا ہے اور بتادیجئے کہ خدا ہمارے اور تمہارے درمیان گواہ ہے اور میری طرف اس قرآن کی وحی کی گئی ہے تاکہ اس کے ذریعہ میں تمہیں اور جہاں تک یہ پیغام پہنچے سب کو ڈراؤں کیا تم لوگ گواہی دیتے ہو کہ خدا کے ساتھ کوئی اور خدا بھی ہے تو آپ کہہ دیجئے کہ میں اس کی گواہی نہیں دے سکتا اور بتادیجئے کہ خدا صرف خدائے واحد ہے اور میں تمہارے شرک سے بیزار ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@dcccix{جن لوگوں کو ہم نے کتاب دی ہے وہ پیغمبر کو اسی طرح پہچانتے ہیں جس طرح اپنی اولاد کو پہنچاتے ہیں لیکن جن لوگوں نے اپنے نفس کو خسارہ میں ڈال دیا ہے وہ ایمان نہیں لاسکتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@dcccx{اس سے زیادہ ظالم کون ہوسکتا ہے جو خدا پر بہتان باندھے اور اس کی آیات کی تکذیب کرے -یقینا ان ظالمین کے لئے نجات نہیں ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@dcccxi{قیامت کے دن ہم سب کو ایک ساتھ اُٹھائیں گے پھر مشرکین سے کہیں گے کہ تمہارے وہ شرکائ کہاں ہیں جو تمہارے خیال میں خدا کے شریک تھے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@dcccxii{اس کے بعد ان کا کوئی فتنہ نہ ہوگا سوائے اس کے کہ یہ کہہ دیں کہ خدا کی قسم ہم مشرک نہیں تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@dcccxiii{دیکھئے انہوں نے کس طرح اپنے آپ کو جھٹلایا اور کس طرح ان کا افترا حقیقت سے دور نکلا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@dcccxiv{اور ان میں سے بعض لوگ کان لگا کر آپ کی بات سنتے ہیں لیکن ہم نے ان کے دلوں پر پردے ڈال دئیے ہیں ... یہ سمجھ نہیں سکتے ہیں اور ان کے کانوں میں بھی بہراپن ہے -یہ اگر تمام نشانیوں کو دیکھ لیں تو بھی ایمان نہ لائیں گے یہاں تک کہ جب آپ کے پاس آئیں گے تو بھی بحث کریں گے اور کفار کہیں گے کہ یہ قرآن تو صرف اگلے لوگوں کی کہانی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@dcccxv{یہ لوگ دوسروں کو قرآن سے روکتے ہیں اور خود بھی دور بھاگتے ہیں حالانکہ یہ اپنے ہی کو ہلاک کررہے ہیں اور انہیں شعور تک نہیں ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@dcccxvi{اگر آپ دیکھتے کہ یہ کس طرح جہنّم کے سامنے کھڑے کئے گئے اور کہنے لگے کہ کاش ہم پلٹا دئیے جاتے اور پروردگار کی نشانیوں کی تکذیب نہ کرتے اور مومنین میں شامل ہوجاتے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@dcccxvii{بلکہ ان کے لئے وہ سب واضح ہوگیا جسے پہلے سے چھپارہے تھے اور اگر یہ پلٹا بھی دئیے جائیں تو وہی کریں گے جس سے یہ روکے گئے ہیں اور یہ سب جھوٹے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@dcccxviii{اور یہ کہتے ہیں کہ یہ صرف زندگانی دنیا ہے اور ہم دوبارہ نہیں اُٹھائے جائیں گے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@dcccxix{اور اگر آپ اس وقت دیکھتے جب انہیں پروردگار کے سامنے کھڑا کیا جائے گا اور ان سے خطاب ہوگا کہ کیا یہ سب حق نہیں ہے تو وہ لوگ کہیں گے کہ بیشک ہمارے پروردگار کی قسم یہ سب حق ہے تو ارشاد ہوگا کہ اب اپنے کفر کے عذاب کا مزہ چکھو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@dcccxx{بیشک وہ لوگ خسارہ میں ہیں جنہوں نے اللہ کی ملاقات کا انکار کیا یہاں تک کہ جب اچانک قیامت آگئی تو کہنے لگے کہ ہائے افسوس ہم نے قیامت کے بارے میں بہت کوتاہی کی ہے -اس وقت وہ اپنے گناہوں کا بوجھ اپنی پشت پر لادے ہوں گے اور یہ بدترین بوجھ ہوگا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@dcccxxi{اور یہ زندگانی دنیا صرف کھیل تماشہ ہے اور دار آخرت صاحبان تقوٰی کے لئے سب سے بہتر ہے ... کیا تمہاری سمجھ میں یہ بات نہیں آرہی ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@dcccxxii{ہمیں معلوم ہے کہ آپ کو ان کے اقوال سے دکھ ہوتا ہے لیکن یہ آپ کی تکذیب نہیں کررہے ہیں بلکہ یہ ظالمین آیات الٰہی کا انکار کررہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@dcccxxiii{اور آپ سے پہلے والے رسولوں کو بھی جھٹلایا گیا ہے تو انہوں نے اس تکذیب اور اذیت پر صبر کیا ہے یہاں تک کہ ہماری مدد آگئی اور اللہ کی باتوں کا کوئی بدلنے والا نہیں ہے اور آپ کے پاس تو مرسلین کی خبریں آچکی ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@dcccxxiv{اور اگر ان کا اعراض و انحراف آپ پر گراں گزرتا ہے تو اگر آپ کے بس میں ہے کہ زمین میں سرنگ بنادیں یا آسمان میں سیڑھی لگا کر کوئی نشانی لے آئیں تو لے آئیں ....بیشک اگر خدا چاہتا تو جبرا سب کو ہدایت پر جمع ہی کردیتا لہذا آپ اپنا شمار ناواقف لوگوں میں نہ ہونے دیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@dcccxxv{بس بات کو وہی لوگ قبول کرتے ہیں جو سنتے ہیں اور مفِدوں کو تو خدا ہی اُٹھائے گا اور پھر اس کی بارگاہ میں پلٹائے جائیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@dcccxxvi{اور یہ کہتے ہیں کہ ان کے اوپر کوئی نشانی کیوں نہیں نازل ہوتی تو کہہ دیجئے کہ خدا تمہاری پسندیدہ نشانی بھی نازل کرسکتا ہے لیکن اکثریت اس بات کو بھی نہیں جانتی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@dcccxxvii{اور زمین میں کوئی بھی رینگنے والا یا دونوں پروں سے پرواز کرنے والا طائر ایسا نہیں ہے جو اپنی جگہ پر تمہاری طرح کی جماعت نہ رکھتا ہو -ہم نے کتاب میں کسی شے کے بیان میں کوئی کمی نہیں کی ہے اس کے بعد سب اپنے پروردگار کی بارگاہ میں پیش ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@dcccxxviii{اور جن لوگوں نے ہماری آیات کی تکذیب کی وہ بہرے گونگے تاریکیوں میں پڑے ہوئے ہیں اور خدا جسے چاہتا ہے یوں ہی گمراہی میں رکھتا ہے اور جسے چاہتا ہے صراط مستقیم پر لگا دیتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@dcccxxix{آپ ان سے کہئے کہ تمہارا کیا خیال ہے کہ اگر تمہارے پاس عذاب یا قیامت آجائے تو کیا تم اپنے دعوے کی صداقت میں غیر خدا کو بلاؤ گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@dcccxxx{نہیں تم خدا ہی کو پکارو گے اور وہی اگر چاہے گا تو اس مصیبت کو رفع کرسکتا ہے ....اور تم اپنے مشرکانہ خداؤں کو بھول جاؤ گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@dcccxxxi{ہم نے تم سے پہلے والی اُمتوں کی طرف بھی رسول بھیجے ہیں اس کے بعد انہیں سختی اور تکلیف میں مبتلا کیا کہ شاید ہم سے گڑ گڑائیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@dcccxxxii{پھر ان سختیوں کے بعد انہوں نے کیوں فریاد نہیں کی بات یہ ہے کہ ان کے دل سخت ہوگئے ہیں اور شیطان نے ان کے اعمال کو ان کے لئے آراستہ کردیا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiii{پھر جب ان نصیحتوں کو بھول گئے جو انہیں یاد دلائی گئی تھیں تو ہم نے امتحان کے طور پر ان کے لئے ہر چیز کے دروازے کھول دئیے یہاں تک کہ جب وہ ان نعمتوں سے خوشحال ہوگئے تو ہم نے اچانک انہیں اپنی گرفت میں لے لیا اور وہ مایوس ہوکر رہ گئے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@dcccxxxiv{پھر ظالمین کا سلسلہ منقطع کردیا گیا اور ساری تعریف اس خد اکے لئے ہے جو رب العالمین ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@dcccxxxv{آپ ان سے پوچھئے کہ اگر خد انے ان کی سماعت و بصارت کو لے لیا اور ان کے دل پر مہر لگادی تو خدا کے علاوہ دوسرا کون ہے جو دوبارہ انہیں یہ نعمتیں دے سکے گا دیکھو ہم اپنی نشانیوں کو کس طرح الٹ پلٹ کر دکھلاتے ہیں اور پھر بھی یہ منہ موڑ لیتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvi{آپ ان سے کہئے کہ کیا تمہارا خیال ہے کہ اگر اچانک یا علی الاعلان عذاب آجائے تو کیا ظالمین کے علاوہ کوئی اور ہلاک کیا جائے گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@dcccxxxvii{اور ہم تو مرسلین کو صرف بشارت دینے والا اور ڈرانے والا بنا کر بھیجتے ہیں اس کے بعد جو ایمان لے آئے اور اپنی اصلاح کرلے اس کے لئے نہ خوف ہے اور نہ حزن\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@dcccxxxviii{اور جن لوگوں نے تکذیب کی انہیں ان کی نافرمانیوں کی وجہ سے عذاب اپنی لپیٹ میں لے لے گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@dcccxxxix{آپ کہئے کہ ہمارا دعو ٰی یہ نہیں ہے کہ ہمارے پاس خدائی خزانے ہیں یا ہم عالم الغیب ہیں اور نہ ہم یہ کہتے ہیں کہ ہم مُلک ہیں. ہم تو صرف وحی پروردگار کا اتباع کرتے ہیں اور پوچھئے کہ کیا اندھے اور بینا برابر ہوسکتے ہیں آخر تم کیوں نہیں سوچتے ہو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@dcccxl{اور آپ اس کتاب کے ذریعہ انہیں ڈرائیں جنہیں یہ خوف ہے کہ خدا کی بارگاہ میں حاضر ہوں گے اور اس کے علاوہ کوئی سفارش کرنے والا یا مددگار نہ ہوگا شاید ان میں خوف خدا پیدا ہوجائے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@dcccxli{اور خبردار جو لوگ صبح و شام اپنے خدا کو پکارتے ہیں اور خدا ہی کو مقصود بنائے ہوئے ہیں انہیں اپنی بزم سے الگ نہ کیجئے گا. نہ آپ کے ذمہ ان کا حساب ہے اور نہ ان کے ذمہ آپ کا حساب ہے کہ آپ انہیں دھتکار دیں اور اس طرح ظالموں میں شمارہوجائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@dcccxlii{اور اسی طرح ہم نے بعض کو بعض کے ذریعہ آزمایا ہے تاکہ وہ یہ کہیں کہ یہی لوگ ہیں جن پر خدا نے ہمارے درمیان فضل و کرم کیا ہے اور کیا وہ اپنے شکر گزار بندوں کو بھی نہیں جانتا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@dcccxliii{اور جب آپ کے پاس وہ لوگ آئیں جو ہماری آیتوں پر ایمان رکھتے ہیں تو ان سے کہئے السلام علیکم ...._ تمہارے پروردگار نے اپنے اوپر رحمت لازم قرر دے لی ہے کہ تم میں جو بھی ازروئے جہالت برائی کرے گا اور اس کے بعد توبہ کرکے اپنی اصلاح کرلے گا تو خدا بہت زیادہ بخشنے والا اور مہربان ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@dcccxliv{اور ہم اسی طرح اپنی نشانیوں کو تفصیل کے ساتھ بیان کرتے ہیں تاکہ مجرمین کا راستہ ان پر واضح ہوجائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@dcccxlv{آپ کہہ دیجئے کہ مجھے اس بات سے روکا گیا ہے کہ میں ان کی عبادت کروں جنہیں تم خدا کو چھوڑ کر پکارتے ہو کہہ دیجئے کہ میں تمہاری خواہشات کا اتباع نہیں کرسکتا کہ اس طرح گمراہ ہوجاؤں گا اور ہدایت یافتہ نہ رہ سکوں گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@dcccxlvi{کہہ دیجئے کہ میں پروردگار کی طرف سے کھلی ہوئی دلیل رکھتا ہوں اور تم نے اسے جھٹلایا ہے تو میرے پاس وہ عذاب نہیں ہے جس کی تمہیں جلدی ہے حکم صرف اللہ کے اختیار میں ہے وہی حق کو بیان کرتا ہے اور وہی بہترین فیصلہ کرنے والا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@dcccxlvii{کہہ دیجئے کہ اگر میرے اختیار میں وہ عذاب ہوتا جس کی تمہیں جلدی ہے تو اب تک ہمارے تمہارے درمیان فیصلہ ہوچکا ہوتا اور خدا ظالمین کو خوب جانتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@dcccxlviii{اور اس کے پاس غیب کے خزانے ہیں جنہیں اس کے علاوہ کوئی نہیں جانتا ہے اور وہ خشک و تر سب کا جاننے والا ہے -کوئی پتہ بھی گرتا ہے تو اسے اس کا علم ہے زمین کی تاریکیوں میں کوئی دانہ یا کوئی خشک و تر ایسا نہیں ہے جو کتاب همبین کے اندر محفوظ نہ ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@dcccxlix{اور وہی خدا ہے جو تمہیں رات میں گویا کہ ایک طرح کی موت دے دیتا ہے اور دن میں تمہارے تمام اعمال سے باخبر ہے اور پھر دن میں تمہیں اُٹھادیتا ہے تاکہ مقررہ مدت حیات پوری کی جاسکے -اس کے بعد تم سب کی باز گشت اسی کی بارگاہ میں ہے اور پھر وہ تمہیں تمہارے اعمال کے بارے میں باخبر کرے گا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@dcccl{اور وہی خدا ہے جو اپنے بندوں پر غالب ہے اور تم سب پر محافظ فرشتے بھیجتا ہے یہاں تک کہ جب کسی کی موت کا وقت آجاتا ہے تو ہمارے بھیجے ہوئے نمائندے اسے اُٹھالیتے ہیں اور کسی طرح کی کوتاہی نہیں کرتے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@dcccli{پھر سب اپنے مولائے برحق پروردگار کی طرف پلٹا دئیے جاتے ہیں .... آگاہ ہوجاؤ کہ فیصلہ کا حق صرف اسی کو ہے اور وہ بہت جلدی حساب کرنے والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@dccclii{ان سے کہئے کہ خشکی اور تری کی تاریکیوں سے کون نجات دیتا ہے جسے تم گڑگڑا کر اور خفیہ طریقہ سے آواز دیتے ہو کہ اگر اس مصیبت سے نجات دے دے گا تو ہم شکر گزار بن جائیں گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@dcccliii{کہہ دیجئے کہ خد اہی تمہیں ان تمام ظلمات سے اور ہر کرب و بے چینی سے نجات دینے والا ہے اس کے بعد تم لوگ شرک اختیار کرلیتے ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@dcccliv{کہہ دیجئے کہ وہی اس بات پر بھی قادر ہے کہ تمہارے اوپر سے یا پیروں کے نیچے سے عذاب بھیج دے یا ایک گروہ کو دوسرے سے ٹکرادے اور ایک کے ذریعہ دوسرے کو عذاب کا مزہ چکھادے -دیکھو ہم کس طرح آیات کو پلٹ پلٹ کر بیان کرتے ہیں کہ شاید ان کی سمجھ میں آجائے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@dccclv{اور آپ کی قوم نے اس قرآن کی تکذیب کی حالانکہ وہ بالکل حق ہے تو آپ کہہ دیجئے کہ میں تمہارا نگہبان نہیں ہوں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@dccclvi{ہر خبر کے لئے ایک وقت مقررہے اور عنقریب تمہیں معلوم ہوجائے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@dccclvii{اور جب تم دیکھو کہ لوگ ہماری نشانیوں کے بارے میں بے ربط بحث کررہے ہیں تو ان سے کنارہ کش ہوجاؤ یہاں تک کہ وہ دوسری بات میں مصروف ہوجائیں اور اگر شیطان غافل کردے تو یاد آنے کے بعد پھر ظالموں کے ساتھ نہ بیٹھنا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@dccclviii{اور صاحبان هتقو یٰ پر ان کے حساب کی کوئی ذمہ داری نہیں ہے لیکن یہ ایک یاددہانی ہے کہ شاید یہ لوگ بھی تقوٰی اختیار کرلیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@dccclix{اور ان لوگوں کو چھوڑ دو جنہوں نے اپنے دین کو کھیل تماشہ بنا رکھا ہے اور انہیں زندگانی دنیا نے دھوکہ میں مبتلا کردیا ہے اور ان کو یاد دہانی کراتے رہو کہ مبادا کوئی شخص اپنے کئے کی بنا پر ایسے عذاب میں مبتلا ہوجائے کہ اللہ کے علاوہ کوئی سفارش کرنے والا اور مدد کرنے والا نہ ہو اور سارے معاوضے اکٹھا بھی کردے تو اسے قبول نہ کیا جائے یہی وہ لوگ ہیں جنہیں ان کے کرتوت کی بنا پر بلاؤں میں مبتلا کیا گیا ہے کہ اب ان کے لئے گرم پانی کا مشروب ہے اور ان کے کفر کی بنا پر دردناک عذاب ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@dccclx{پیغمبر آپ کہہ دیجئے کہ ہم خدا کو چھوڑ کر ان کو پکاریں جو نہ فائدہ پہنچاسکتے ہیں اور نہ نقصان اور اس طرح اللہ کے ہدایت دینے کے بعد اُلٹے پاؤں پلٹ جائیں جس طرح کہ کسی شخص کو شیطان نے روئے زمین پر بہکا دیا ہو اور وہ حیران و سرگرداں مارا مارا پھر رہا ہو اور اس کے کچھ اصحاب اسے ہدایت کی طرف پکار رہے ہوں کہ ادھر آجاؤ .... آپ کہہ دیجئے کہ ہدایت صرف اللہ کی ہدایت ہے اور ہمیں حکم دیا گیا ہے کہ ہم رب العالمین کی بارگاہ میں سراپا تسلیم رہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@dccclxi{اور دیکھو نماز قائم کرواور اللہ سے ڈرو کہ وہی وہ ہے جس کی بارگاہ میں حاضر کئے جاؤ گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@dccclxii{وہی وہ ہے جس نے آسمان و زمین کو حق کے ساتھ پیدا کیا ہے اور وہ جب بھی کہتا ہے کہ ہوجا تو وہ چیز ہوجاتی ہے اس کا قول برحق ہے اور جس دن صور پھونکا جائے گا اس دن سارا اختیار اسی کے ہاتھ میں ہوگا وہ غائب اور حاضر سب کا جاننے والا صاحب حکمت اور ہر شے سے باخبر ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@dccclxiii{اور اس وقت کو یاد کرو جب ابراہیم علیھ السّلامنے اپنے مربی باپ آزر سے کہا کہ کیا تو ان بتوں کو خدا بنائے ہوئے ہے .میں تو تجھے اور تیری قوم کو کِھلی ہوئی گمراہی میں دیکھ رہا ہوں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@dccclxiv{اور اسی طرح ہم ابراہیم علیھ السّلامکو آسمان و زمین کے اختیارات دکھلاتے ہیں اور اس لئے کہ وہ یقین کرنے والوں میں شامل ہوجائیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@dccclxv{پس جب ان پر رات کی تاریکی چھائی اور انہوں نے ستارہ کو دیکھا تو کہا کہ کیا یہ میرا رب ہے . پھر جب وہ غروب ہوگیا تو انہوں نے کہا کہ میں ڈوب جانے والوں کو دوست نہیں رکھتا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@dccclxvi{پھر جب چاند کو چمکتا دیکھا تو کہا کہ پھر یہ رب ہوگا .پھر جب وہ بھی ڈوب گیا تو کہا کہ اگر پروردگار ہی ہدایت نہ دے گا تو میں گمراہوں میں ہوجاؤں گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@dccclxvii{پھر جب چمکتے ہوئے سورج کو دیکھا تو کہا کہ پھر یہ خدا ہوگا کہ یہ زیادہ بڑا ہے لیکن جب وہ بھی غروب ہوگیا تو کہا کہ اے قوم میں تمہارے شِرک سے بری اور بیزار ہوں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@dccclxviii{میرا رخ تمام تر اس خدا کی طرف ہے جس نے آسمانوں اور زمین کو پیدا کیا ہے اور میں باطل سے کنارہ کش ہوں اور مشرکوں میں سے نہیں ہوں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@dccclxix{اور جب ان کی قوم نے ان سے کٹ حجتی کی تو کہا کہ کیا مجھ سے خدا کے بارے میں بحث کررہے ہو جس نے مجھے ہدایت دے دی ہے اور میں تمہارے شریک کردہ خداؤں سے بالکل نہیں ڈرتا ہوں .مگر یہ کہ خود میرا خدا کوئی بات چاہے کہ اس کا علم ہر شے سے وسیع تر ہے کیا یہ بات تمہاری سمجھ میں نہیں آتی ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@dccclxx{اور میں کس طرح تمہارے خداؤں سے ڈر سکتا ہوں جب کہ تم اس بات سے نہیں ڈرتے ہو کہ تم نے ان کو خدا کا شریک بنادیا ہے جس کے بارے میں خدا کی طرف سے کوئی دلیل نہیں نازل ہوئی ہے تو اب دونوں فریقوں میں کون زیادہ امن و سکون کا حقدار ہے اگر تم جاننے والے ہو تو بتاؤ\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@dccclxxi{جو لوگ ایمان لے آئے اور انہوں نے اپنے ایمان کو ظلم سے آلودہ نہیں کیا ان ہی کے لئے امن وسکون ہے اور وہی ہدایت یافتہ ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@dccclxxii{یہ ہماری دلیل ہے جسے ہم نے ابراہیم علیھ السّلامکو ان کی قوم کے مقابلہ میں عطا کی اور ہم جس کو چاہتے ہیں اس کے درجات کو بلند کردیتے ہیں . بیشک تمہارا پروردگار صاحب هحکمت بھی ہے اور باخبر بھی ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@dccclxxiii{اور ہم نے ابراہیم علیھ السّلامکو اسحاق علیھ السّلامو یعقوب علیھ السّلامدئیے اور سب کو ہدایت بھی دی اور اس کے پہلے نوح علیھ السّلامکو ہدایت دی اور پھر ابراہیم علیھ السّلامکی اولاد میں داؤد علیھ السّلام ,سلیمان علیھ السّلامًایوب علیھ السّلامً یوسف علیھ السّلام,موسٰی علیھ السّلام ,اور ہارون علیھ السّلامقرار دئیے اور ہم ِسی طرح نیک عمل کرنے والوں کو جزا دیتے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@dccclxxiv{اور زکریا علیھ السّلام,یحیٰی علیھ السّلام,عیسٰی علیھ السّلاماور الیاس علیھ السّلام کو بھی رکھا جو سب کے سب نیک کرداروں میں تھے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@dccclxxv{اور اسماعیل علیھ السّلام, الیسع علیھ السّلام ,یونس علیھ السّلام اور لوط علیھ السّلام بھی بنائے اور سب کو عالمین سے افضل و بہتر بنایا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@dccclxxvi{اور پھر ان کے باپ دادا ,اولاد اور برادری میں سے اور خود انہیں بھی منتخب کیا اور سب کو سیدھے راستہ کی ہدایت کردی\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@dccclxxvii{یہی خدا کی ہدایت ہے جسے جس بندے کو چاہتا ہے عطا کردیتاہے اور اگر یہ لوگ شرک اختیار کرلیتے تو ان کے بھی سارے اعمال برباد ہوجاتے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@dccclxxviii{یہی وہ افراد ہیں جنہیں ہم نے کتاب ,حکومت اور نبوت عطا کی ہے . اب اگر یہ لوگ ان باتوں کا بھی انکار کرتے ہیں تو ہم نے ان باتوں کا ذمہ دار ایک ایسی قوم کو بنایا ہے جو انکار کرنے والی نہیں ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@dccclxxix{یہی وہ لوگ ہیں جنہیں اللہ نے ہدایت دی ہے لہذا آپ بھی اسی ہدایت کے راستہ پر چلیں اور کہہ دیجئے کہ ہم تم سے اس کار تبلیغ و ہدایت کا کوئی اجر نہیں چاہتے ہیں یہ قرآن تو عالمین کی یاددہانی کا ذریعہ ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@dccclxxx{اور ان لوگوں نے واقعی خدا کی قدر نہیں کی جب کہ یہ کہہ دیا کہ اللہ نے کسی بشر پر کچھ نہیں نازل کیا ہے تو ان سے پوچھئے کہ یہ کتاب جو موسٰی علیھ السّلاملے کر آئے تھے جو نور اور لوگوں کے لئے ہدایت تھی اور جسے تم نے چند کاغذات بنادیا ہے اور کچھ حصّہ ظاہر کیا اور کچھ چھپادیا حالانکہ اس کے ذریعہ تمہیں وہ سب بتادیا گیا تھا جو تمہارے باپ دادا کو بھی نہیں معلوم تھا یہ سب کس نے نازل کیا ہے اب آپ کہہ دیجئے کہ وہ وہی اللہ ہے اور پھر انہیں چھوڑ دیجئے یہ اپنی بکواس میں کھیلتے پھریں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@dccclxxxi{اور یہ کتاب جو ہم نے نازل کی ہے یہ بابرکت ہے اور اپنے پہلے والی کتابوں کی تصدیق کرنے والی ہے اور یہ اس لئے ہے کہ آپ مکّہ اور اس کے اطراف والوں کو ڈرائیں اور جو لوگ آخرت پر ایمان رکھتے ہیں وہ اس پر ایمان رکھتے ہیں اور اپنی نماز کی پابندی کرتے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@dccclxxxii{اور اس سے بڑا ظالم کون ہوگا جو خدا پر جھوٹا الزام لگائے یا اس کے نازل کئے بغیر یہ کہہ دے کہ مجھ پر وحی نازل ہوئی ہے اور جو یہ کہہ دے کہ میں بھی خدا کی طرح باتیں نازل کرسکتا ہوں اور اگر آپ دیکھتے کہ ظالم موت کی سختیوں میں ہیں اور ملائکہ اپنے ہاتھ بڑھائے ہوئے آواز دے رہے ہیں کہ اب اپنی جان نکال دو کہ آج تمہیں تمہارے جھوٹے بیانات اور الزامات پر رسوائی کا عذاب دیا جائے گا کہ تم آیات خدا سے انکار اور استکبار کررہے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiii{اور بالآخر تم اسی طرح ہمارے پاس تنہا آئے جس طرح ہم نے تم کو پیدا کیا تھا اور جو کچھ تمہیں دیا تھا سب اپنے پیچھے چھوڑ آئے اور ہم تمہارے ساتھ تمہارے ان سفارش کرنے والوں کو بھی نہیں دیکھتے جنہیں تم نے اپنے لئے خدا کا شریک بنایا تھا. تمہارے ان کے تعلقات قطع ہوگئے اور تمہارا خیال تم سے غائب ہوگیا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@dccclxxxiv{خدا ہی وہ ہے جو گٹھلی اور دانے کا شگافتہ کرنے والا ہے -وہ لَردہ سے زندہ اور زندہ سے لَردہ کو نکالتا ہے. یہی تمہارا خدا ہے تو تم کدھر بہکے جارہے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@dccclxxxv{وہ نور سحر کا شگافتہ کرنے والا ہے اور اس نے رات کو وجہ سکون اور شمس و قمر کو ذریعہ حساب بنایا ہے . یہ اس صاحب هعزّت و حکمت کی مقرر کردہ تقدیر ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvi{وہی وہ ہے جس نے تمہارے لئے ستارے مقرر کئے ہیں کہ ان کے ذریعہ خشکی اور تری کی تاریکیوں میں راستہ معلوم کرسکو -ہم نے تمام نشانیوں کو اس قوم کے لئے تفصیل کے ساتھ بیان کیا ہے جو جاننے والی ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@dccclxxxvii{وہی وہ ہے جس نے تم سب کو ایک نفس سے پیدا کیا ہے پھر سب کے لئے قرار گاہ اور منزلِ ودیعت مقرر کی ہے. ہم نے صاحبانِ فہم کے لئے تمام نشانیوں کو تفصیل کے ساتھ بیان کردیا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@dccclxxxviii{وہی خدا وہ ہے جس نے آسمان سے پانی نازل کیا ہے پھر ہم نے ہر شے کے کوئے نکالے پھر ہری بھری شاخیں نکالیں جس سے ہم گتھے ہوئے دانے نکالتے ہیں اور کھجور کے شگوفے سے لٹکتے ہوئے گچھےّ پیدا کئے اور انگور و زیتون اور انار کے باغات پیدا کئے جو شکل میں ملتے جلتے اور مزہ میں بالکل الگ الگ ہیں -ذرا اس کے پھل اور اس کے پکنے کی طرف غور سے دیکھو کہ اس میں صاحبان هایمان کے لئے کتنی نشانیاں پائی جاتی ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@dccclxxxix{اور ان لوگوں نے جنّات کو خدا کا شریک بنادیا ہے حالانکہ خدا نے انہیں پیدا کیا ہے پھر اس کے لئے بغیر جانے بوجھے بیٹے اور بیٹیاں بھی تیار کردی ہیں .جب کہ وہ بے نیاز اور ان کے بیان کردہ اوصاف سے کہیں زیادہ بلند وبالا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@dcccxc{وہ زمین و آسمان کا ایجاد کرنے والا ہے -اس کے اولاد کس طرح ہوسکتی ہے اس کی تو کوئی بیوی بھی نہیں ہے اور وہ ہر شے کا خالق ہے اور ہرچیز کا جاننے والا ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@dcccxci{وہی اللہ تمہارا پروردگار ہے جس کے علاوہ کوئی خدا نہیں -وہ ہر شے کا خالق ہے اسی کی عبادت کرو .وہی ہر شے کا نگہبان ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@dcccxcii{نگاہیں اسے پا نہیں سکتیں اور وہ نگاہوں کا برابر ادراک رکھتا ہے کہ وہ لطیف بھی ہے اور خبیر بھی ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@dcccxciii{تمہارے پاس تمہارے پروردگار کی طرف سے دلائل آچکے ہیں اب جو بصیرت سے کام لے گا وہ اپنے لئے اور جو اندھا بن جائے گا وہ بھی اپنا ہی نقصان کرے گا اور میں تم لوگوں کا نگہبان نہیں ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@dcccxciv{اور اسی طرح ہم پلٹ پلٹ کر آیتیں پیش کرتے ہیں اور تاکہ وہ یہ کہیں کہ آپ نے قرآن پڑھ لیا ہے اور ہم جاننے والوں کے لئے قرآن کو واضح کردیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@dcccxcv{آپ اپنی طرف آنے والی وحی الٰہی کا اتباع کریں کہ اس کے علاوہ کوئی خدا نہیں ہے اور مشرکین سے کنارہ کشی کرلیں\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@dcccxcvi{اور اگر خدا چاہتا تو یہ شرک ہی نہ کرسکتے اور ہم نے آپ کو ان کا نگہبان نہیں بنایا ہے اور نہ آپ ان کے ذمہ دار ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@dcccxcvii{اور خبردار تم لوگ انہیں برا بھلا نہ کہو جن کو یہ لوگ خدا کو چھوڑ کر پکارتے ہیں کہ اس طرح یہ دشمنی میں بغیر سمجھے بوجھے خدا کو برا بھلا کہیں گے ہم نے اسی طرح ہر قوم کے لئے اس کے عمل کو آراستہ کردیا ہے اس کے بعد سب کی بازگشت پروردگار ہی کی بارگاہ میں ہے اور وہی سب کو ان کے اعمال کے بارے میں باخبر کرے گا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@dcccxcviii{اور ان لوگوں نے اللہ کی سخت قسمیں کھائیں کہ ان کی مرضی کی نشانی آئی تو ضرور ایمان لے آئیں گے تو آپ کہہ دیجئے کہ نشانیاں تو سب خدا ہی کے پاس ہیں اور تم لوگ کیا جانو کہ وہ آبھی جائیں گی تو یہ لوگ ایمان نہ لائیں گے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@dcccxcix{اور ہم ان کے قلب و نظر کو اس طرح پلٹ دیں گے جس طرح یہ پہلے ایمان نہیں لائے تھے اور ان کو گمراہی میں ٹھوکر کھانے کے لئے چھوڑ دیں گے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@cm{اور اگر ہم ان کی طرف ملائکہ نازل بھی کردیں اور ان سے مردے کلام بھی کرلیں اور ان کے سامنے تمام چیزوں کو جمع بھی کردیں تو بھی یہ ایمان نہ لائیں گے مگر یہ کہ خدا ہی چاہ لے لیکن ان کی اکثریت جہالت ہی سے کام لیتی ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@cmi{اور اسی طرح ہم نے ہر نبی کے لئے جنات و انسان کے شیاطین کو ان کا دشمن قرار دے دیا ہے یہ آپس میں ایک دوسرے کی طرف دھوکہ دینے کے لئے مہمل باتوں کے اشارے کرتے ہیں اور اگر خدا چاہ لیتا تو یہ ایسا نہ کرسکتے لہذا اب آپ انہیں ان کے افترا کے حال پر چھوڑ دیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@cmii{اور یہ اس لئے کرتے ہیں کہ جن لوگوں کا ایمان آخرت پر نہیں ہے ان کے دل ان کی طرف مائل ہوجائیں اور وہ اسے پسند کرلیں اور پھر خود بھی ان ہی کی طرح افترا پردازی کرنے لگیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@cmiii{کیا میں خدا کے علاوہ کوئی حکم تلاش کروں جب کہ وہی وہ ہے جس نے تمہاری طرف مفصل کتاب نازل کی ہے اور جن لوگوں کو ہم نے کتاب دی ہے انہیں معلوم ہے کہ یہ قرآن ان کے پروردگار کی طرف سے حق کے ساتھ نازل ہوا ہے لہذا ہرگز آپ شک کرنے والوں میں شامل نہ ہوں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@cmiv{اور آپ کے رب کا کلمہ قرآن صداقت اور عدالت کے اعتبار سے بالکل مکمل ہے اس کا کوئی تبدیل کرنے والا نہیں ہے اور وہ سننے والا بھی ہے اور جاننے والا بھی ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@cmv{اور اگر آپ روئے زمین کی اکثریت کا اتباع کرلیں گے تو یہ راسِ خدا سے بہکادیں گے.یہ صرف گمان کا اتباع کرتے ہیں اور صرف اندازوں سے کام لیتے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@cmvi{آپ کے پروردگار کو خوب معلوم ہے کہ کون اس کے راستے سے بہکنےوالا ہے. اور کون ہدایت حاصل کرنے والا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@cmvii{لہذا تم لوگ صرف اس جانور کا گوشت کھاؤ جس پر خد اکا نام لیا گیا ہو اگر تمہارا ایمان اس کی آیتوں پر ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@cmviii{اورتمہیں کیا ہوگیا ہے کہ تم وہ نہیں کھاتے ہو جس پر نام خدا لیا گیا ہے جب کہ اس نے جن چیزوں کو حرام کیا ہے انہیں تفصیل سے بیان کردیا ہے مگر یہ کہ تم مجبور ہوجاؤ تو اور بات ہے اور بہت سے لوگ تو اپنی خواہشات کی بنا پر لوگوں کو بغیر جانے بوجھے گمراہ کرتے ہیں .اور تمہارا پروردگار ان زیادتی کرنے والوں کو خوب جانتا ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@cmix{اور تم لوگ ظاہری اور باطنی تمام گناہوں کو چھوڑ دو کہ جو لوگ گناہ کا ارتکاب کرتے ہیں عنقریب انہیں ان کے اعمال کا بدلہ دیا جائے گا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@cmx{اور دیکھو جس پر ناهِ خدا نہ لیا گیا ہو اسے نہ کھانا کہ یہ فسق ہے اور شیاطین تو اپنے والوں کی طرف خفیہ اشارے کرتے ہی رہتے ہیں تاکہ یہ لوگ تم سے جھگڑا کریں اور اگر تم لوگوں نے ان کی اطاعت کر لی تو تمہارا شمار بھی مشرکین میں ہوجائے گا\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@cmxi{کیا جو شخص مفِدہ تھا پھر ہم نے اسے زندہ کیااوراس کے لئے ایک نور قرار دیا جس کے سہارے وہ لوگوں کے درمیان چلتا ہے اس کی مثال اس کی جیسی ہوسکتی ہے جو تاریکیوں میں ہو اور ان سے نکل بھی نہ سکتا ہو -اسی طرح کفار کے لئے ان کے اعمال کو آراستہ کردیا گیا ہے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@cmxii{اور اسی طرح ہم نے ہر قریہ میں بڑے بڑے مجرمین کو موقع دیا ہے کہ وہ مکاّری کریں اور ان کی مکاّری کا اثر خود ان کے علاوہ کسی پر نہیں ہوتا ہے لیکن انہیں اس کا بھی شعور نہیں ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@cmxiii{اور جب ان کے پاس کوئی نشانی آتی ہے تو کہتے ہیں کہ ہم اس وقت تک ایمان نہ لائیں گے جب تک ہمیں بھی ویسی ہی وحی نہ دی جائے جیسی رسولوں کو دی گئی ہے جب کہ اللہ بہتر جانتا ہے کہ اپنی رسالت کو کہاں رکھے گا اور عنقریب مجرمین کو ان کے جرم کی پاداش میں خدا کے یہاں ذلّت اور شدید ترین عذاب کا سامنا کرنا ہوگا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@cmxiv{پس خدا جسے ہدایت دینا چاہتا ہے اس کے سینے کو اسلام کے لئے کشادہ کردیتا ہے اور جس کو گمراہی میں چھوڑنا چاہتا ہے اس کے سینے کو ایسا تنگ اور دشوار گزار بنادیتا ہے جیسے آسمان کی طرف بلند ہورہا ہو ,وہ اسی طرح بے ایمانوں پر ان کی کثافت کو مسّلط کردیتاہے\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@cmxv{اور یہ ہی تمہارے پروردگار کا سیدھا راستہ ہے .ہم نے نصیحت حاصل کرنے والوں کے لئے آیات کو مفصل طور سے بیان کردیا ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@cmxvi{ان لوگوں کے لئے پروردگار کے نزدیک دارالّسلام ہے اور وہ ان کے اعمال کی بنا پر ان کا سرپرست ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@cmxvii{اور جس دن وہ سب کو محشور کرے گا تو کہے گا کہ اے گروہ هجناّت تم نے تو اپنے کوانسانوں سے زیادہ بنا لیا تھا اور انسانوں میں ان کے دوست کہیں گے کہ پروردگار ہم میں سب نے ایک دوسرے سے فائدہ اٹھایا ہے اور اب ہم اس مدّت کو پہنچ گئے ہیں جو تو نے ہماری مہلت کے واسطے معین کی تھی .ارشاد ہوگا تواب تمہارا ٹھکانہ جہّنم ہے جہاں ہمیشہ ہمیشہ رہنا ہے مگر یہ کہ خدا ہی آزادی چاہ لے -بیشک تمہارا پروردگار صاحب هحکمت بھی ہے اور جاننے والا بھی ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@cmxviii{اور اسی طرح ہم بعض ظالموں کو ان کے اعمال کی بنا پر بعض پر مسلّط کردیتے ہیں\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@cmxix{اے گروہ جن و انس کیا تمہارے پاس تم میں سے رسول نہیں آئے جو ہماری آیتوں کو بیان کرتے اور تمہیں آج کے دن کی ملاقات سے ڈراتے -وہ کہیں گے کہ ہم خود اپنے خلاف گواہ ہیں اور ان کو زندگانی دنیا نے دھوکہ میں ڈال رکھا تھا انہوں نے خود اپنے خلاف گواہی دی کہ وہ کافر تھے\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@cmxx{یہ اس لئے کہ تمہارا پروردگار کسی بھی قریہ کو ظلم و زیادتی سے اس طرح تباہ و برباد نہیں کرنا چاہتا کہ اس کے رہنے والے بالکل غافل اور بے خبر ہوں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@cmxxi{اور ہر ایک کے لئے اس کے اعمال کے مطابق درجات ہیں اور تمہارا پروردگار ان کے اعمال سے غافل نہیں ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@cmxxii{اور آپ کا پروردگار بے نیاز اور صاحبِ رحمت ہے -وہ چاہے تو تم سب کو دنیا سے اٹھالے اور تمہاری جگہ پر جس قوم کو چاہے لے آئے جس طرح تم کو دوسری قوم کی اولاد میں رکھا ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@cmxxiii{یقینا جو تم سے وعدہ کیا گیا ہے وہ سامنے آنے والا ہے اور تم خدا کو عاجز بنانے والے نہیں ہو\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@cmxxiv{پیغمبر آپ کہہ دیجئے کہ تم بھی اپنی جگہ پر عمل کرو اور میں بھی کررہا ہوں -عنقریب تم کو معلوم ہوجائے گا کہ انجام کار کس کے حق میں بہتر ہے -بیشک ظالم کامیاب ہونے والے نہیں ہیں\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@cmxxv{اور ان لوگوں نے خدا کی پیدا کی ہوئی کھیتی میں اور جانوروں میں اس کا حصہّ بھی لگایا ہے اور یہ اعلان کیا ہے کہ یہ ان کے خیال کے مطابق خد اکے لئے ہے اور یہ ہمارے شریکوں کے لئے ہے -اس کے بعد جو شرکائ کا حصّہ ہے وہ خدا تک نہیں جاسکتا ہے .اور جو خدا کا حصہّ ہے وہ ان کے شریکوں تک پہنچ سکتا ہے.کس قدر بدترین فیصلہ ہے جو یہ لوگ کررہے ہیں\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@cmxxvi{اور اسی طرح ان شریکوں نے بہت سے مشرکین کے لئے اولاد کے قتل کو بھی آراستہ کردیا ہے تاکہ ان کو تباہ و برباد کردیں اور ان پر دین کو مشتبہ کردیں حالانکہ خدا اس کے خلاف چاہ لیتا تو یہ کچھ نہیں کرسکتے تھے لہذا آپ ان کو ان کی افترا پردازیوں پر چھوڑ دیں اور پریشان نہ ہوں\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@cmxxvii{اور یہ لوگ کہتے ہیں کہ یہ جانور اور کھیتی اچھوتی ہے اسے ان کے خیالات کے مطابق وہی کھاسکتے ہیں جن کے بارے میں وہ چاہیں گے اور کچھ چوپائے ہیں جن کی پیٹھ حرام ہے اور کچھ چوپائے جن کو ذبح کرتے وقت نام خدا بھی نہیں لیا گیا اور سب کی نسبت خدا کی طرف دے رکھی ہے عنقریب ان تمام بہتانوں کا بدلہ انہیں دیا جائے گا\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@cmxxviii{اور کہتے ہیں کہ ان چوپاؤں کے پیٹ میں جو بچے ّہیں وہ صرف ہمارے مذِدوں کے لئے ہیں اور عورتوں پر حرام ہیں -ہاں اگر مفِدار ہوں تو سب شریک ہوں گے ,عنقریب خدا ان بیانات کا بدلہ دے گا کہ وہ صاحب هحکمت بھی ہے اور سب کا جاننے والا بھی ہے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@cmxxix{یقینا وہ لوگ خسارہ میں ہیں جنہوں نے حماقت میں بغیر جانے بوجھے اپنی اولاد کو قتل کردیا اور جو رزق خدا نے انہیں دیا ہے اسے اسی پر بہتان لگا کر اپنے اوپر حرام کرلیا -یہ سب بہک گئے ہیں اور ہدایت یافتہ نہیں ہیں\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@cmxxx{وہ خدا وہ ہے جس نے تختوں پر چڑھائے ہوئے بھی اور اس کے خلاف بھی ہر طرح کے باغات پیدا کئے ہیں اور کھجور اور زراعت پیدا کی ہے جس کے مزے مختلف ہیں اور زیتون اورانار بھی پیدا کئے ہیں جن میں بعض آپس میں ایک دوسرے سے ملتے جلتے ہیں اور بعض مختلف ہیں -تم سب ان کے پھلوں کو جب وہ تیار ہوجائیں تو کھاؤ اور جب کاٹنے کا دن آئے تو ان کا حق ادا کردو اور خبردار اسراف نہ کرنا کہ خدا اسراف کرنے والوں کو دوست نہیں رکھتا ہے\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@cmxxxi{اور چوپاؤں میں بعض بوجھ اٹھانے والے اور بعض زمین سے لگ کر چلنے والے ہیں -تم سب خدا کے دئیے ہوئے رزق کو کھاؤ اور شیطانی قدموںکی پیروی نہ کرو کہ شیطان تمہارا کھلا ہوا دشمن ہے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@cmxxxii{آٹھ قسم کے جوڑے ہیں -بھیڑ کے دو اور بکری کے دو -ان سے کہئے خدا نے ان دونوں کے نر حرام کئے ہیں یا مادہ یا وہ بچے جو ان کی مادہ کے پیٹ میں پائے جاتے ہیں -ذرا تم لوگ اس بارے میں ہمیں بھی خبردو اگر اپنے دعویٰ میں سچے ہو\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@cmxxxiii{اور اونٹ میں سے دو اور گائے میں سے دو .... ان سے کہیے کہ خدا نے نروں کو حرام قرار دیا ہے یا مادینوں کو یا ان کو جو مادینوں کے شکم میں ہیں .... کیا تم لوگ اس وقت حاضر تھے جب خدا ان کو حرام کرنے کی وصیت کررہا تھا -پھر اس سے بڑا ظالم کون ہے جو خدا پر جھوٹا الزام لگائے تاکہ لوگوں کو بغیر جانے بوجھے گمراہ کرے -یقینا اللہ ظالم قوم کو ہدایت نہیں دیتا ہے\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@cmxxxiv{آپ کہہ دیجئے کہ میں اپنی طرف آنے والی وحی میں کسی بھی کھانے والے کے لئے کوئی حرام نہیں پاتا مگر یہ کہ مفِدار ہو یا بہایا ہوا خون یا سور کا گوشت ہوکہ یہ سب نجس اور گندگی ہے یا وہ نافرمانی ہو جسے غیر خد اکے نام پر ذبح کیا گیا ہو .... اس کے بعد بھی کوئی مجبور ہوجائے اور نہ سرکش ہو نہ حد سے تجاوز کرنے والا تو پروردگار بڑا بخشنے والا مہربان ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@cmxxxv{اور یہودیوں پر ہم نے ہر ناخن والے جانور کو حرام کردیا اور گائے اور بھیڑ کی چربی کو حرام کردیا مگر جو چربی کہ پیٹھ پر ہو یا آنتوں پر ہو یا جو ہڈیوں سے لگی ہوئی ہو .... یہ ہم نے ان کو ان کی بغاوت اور سرکشی کی سزادی ہے اور ہم بالکل سچےّ ہیں\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@cmxxxvi{پھر اگر یہ لوگ آپ کو جھٹلائیں تو کہہ دیجئے کہ تمہارا پروردگار بڑی وسیع رحمت والا ہے لیکن اس کا عذاب مجرمین سے ٹالابھی نہیں جاسکتا ہے\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@cmxxxvii{عنقریب یہ مشرکین کہیں گے کہ اگر خدا چاہتا تو نہ ہم مشرک ہوتے نہ ہمارے باپ دادا اور نہ ہم کسی چیز کو حرام قرار دیتے -اسی طرح ان سے پہلے والوں نے رسولوں کی تکذیب کی تھی یہاں تک کہ ہمارے عذاب کا مزہ چکھ لیا -ان سے کہہ دیجئے کہ تمہارے پاس کوئی دلیل ہے تو ہمیں بھی بتاؤ -تم تو صرف خیالات کا اتباع کرتے ہو اور اندازوں کی باتیں کرتے ہو\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@cmxxxviii{کہہ دیجئے کہ اللہ کے پاس منزل تک پہنچانے والی دلیلیں ہیں وہ اگر چاہتا تو جبرا تم سب کو ہدایت دے دیتا\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@cmxxxix{کہہ دیجئے کہ ذرا اپنے گواہوں کو تو لاؤ جو گواہی دیتے ہیں کہ خدا نے اس چیز کو حرام قرار دیا ہے ...._ اس کے بعد وہ گواہی بھی دے دیں تو آپ ان کے ساتھ گواہی نہ دیجئے گا اور ان لوگوں کی خواہشات کا اتباع نہ کیجئے گا جنہوں نے ہماری آیتوں کو جھٹلایا ہے اور وہ آخرت پر ایمان نہیں رکھتے ہیں اور اپنے پروردگار کا ہمسر قرار دیتے ہیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@cmxl{کہہ دیجئے کہ آؤ ہم تمہیں بتائیں کہ تمہارے پروردگار نے کیا کیا حرام کیا ہے .... خبردار کسی کو اس کا شریک نہ بنانا اور ماں باپ کے ساتھ اچھا برتاؤ کرنا .اپنی اولاد کو غربت کی بنا پر قتل نہ کرنا کہ ہم تمہیں بھی رزق دے رہے ہیں اور انہیں بھی ... اور بدکاریوں کے قریب نہ جانا وہ ظاہری ہوں یا چھپی ہوئی اور کسی ایسے نفس کو جسے خدا نے حرام کردیا ہے قتل نہ کرنا مگر یہ کہ تمہارا کوئی حق ہو .یہ وہ باتیں ہیں جن کی خدا نے نصیحت کی ہے تاکہ تمہیں عقل آجائے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@cmxli{اور خبردار مال هیتیم کے قریب بھی نہ جانا مگر اس طریقہ سے جو بہترین طریقہ ہو یہاں تک کہ وہ توانائی کی عمر تک پہنچ جائیں اور ناپ تول میں انصاف سے پورا پورا دینا -ہم کسی نفس کو اس کی وسعت سے زیادہ تکلیف نہیں دیتے ہیں اور جب بات کرو تو انصاف کے ساتھ چاہے اپنی اقرباہی کے خلاف کیوں نہ ہو اور عہد خدا کو پورا کرو کہ اس کی پروردگار نے تمہیں وصیت کی ہے کہ شاید تم عبرت حاصل کرسکو\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@cmxlii{اور یہ ہمارا سیدھا راستہ ہے اس کا اتباع کرو اور دوسرے راستوں کے پیچھے نہ جاؤ کہ راہ هخدا سے الگ ہوجاؤ گے اسی کی پروردگار نے ہدایت دی ہے کہ اس طرح شاید متقی اور پرہیز گار بن جاؤ\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@cmxliii{اس کے بعد ہم نے موسٰی علیھ السّلام کو اچھی باتوں کی تکمیل کرنے والی کتاب دی اور اس میں ہر شے کو تفصیل سے بیان کردیا اور اسے ہدایت اور رحمت قرار دے دیا کہ شاید یہ لوگ لقائے الٰہی پر ایمان لے آئیں\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@cmxliv{اور یہ کتاب جو ہم نے نازل کی ہے یہ بڑی بابرکت ہے لہذا اس کا اتباع کرو اور تقوٰی اختیار کرو کہ شاید تم پر رحم کیا جائے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@cmxlv{یہ نہ کہنے لگو کہ کتاب خدا تو ہم سے پہلے دو جماعتوں پر نازل ہوئی تھی اور ہم اس کے پڑھنے پڑھانے سے بے خبر تھے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@cmxlvi{یا یہ کہو کہ ہمارے اوپر بھی کتاب نازل ہوتی تو ہم ان سے زیادہ ہدایت یافتہ ہوتے تو اب تمہارے پروردگار کی طرف سے واضح دلیل اور ہدایت و رحمت آچکی ہے پھر اس کے بعد اس سے بڑا ظالم کون ہوگا جو اللہ کی نشانیوں کو جھٹلائے اور ان سے اعراض کرے ...عنقریب ہم اپنی نشانیوں سے اعراض کرنے والوں پر بدترین عذاب کریں گے اور وہ ہماری آیتوں سے اعراض کرنے والے اور روکنے والے ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@cmxlvii{یہ صرف اس بات کے منتظر ہیں کہ ان کے پاس ملائکہ آجائیں یا خود پروردگار آجائے یا اس کی بعض نشانیاں آجائیں تو جس دن اس کی بعض نشانیاں آجائیں گی اس دن جو نفس پہلے سے ایمان نہیں لایا ہے یا اس نے ایمان لانے کے بعد کوئی بھلائی نہیں کی ہے اس کے ایمان کا کوئی فائدہ نہ ہوگا تو اب کہہ دیجئے کہ تم لوگ بھی انتظار کرو اور میں بھی انتظار کررہا ہوں\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@cmxlviii{جن لوگوں نے اپنے دین میں تفرقہ پیدا کیا اور ٹکڑے ٹکڑے ہوگئے ان سے آپ کا کوئی تعلق نہیں ہے -ان کا معاملہ خدا کے حوالے ہے پھر وہ انہیں ان کے اعمال کے بارے میں باخبر کرے گا\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@cmxlix{جو شخص بھی نیکی کرے گا اسے دس گنا اجر ملے گا اور جو برائی کرے گا اسے صرف اتنی ہی سزا ملے گی اور کوئی ظلم نہ کیا جائے گا\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@cml{آپ کہہ دیجئے کہ میرے پروردگار نے مجھے سیدھے راستے کی ہدایت دے دی ہے جو ایک مضبوط دین اور باطل سے اعراض کرنے والے ابراہیم علیھ السّلامکا مذہب ہے اور وہ مشرکین میں سے ہرگز نہیں تھے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@cmli{کہہ دیجئے کہ میری نماز ,میری عبادتیں ,میری زندگی ,میری موت سب اللہ کے لئے ہے جو عالمین کا پالنے والا ہے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@cmlii{اس کا کوئی شریک نہیں ہے اور اسی کا مجھے حکم دیا گیا ہے اور میں سب سے پہلا مسلمان ہوں\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@cmliii{کہہ دیجئے کہ کیا میں خدا کے علاوہ کوئی اور رب تلاش کروں جب کہ وہی ہر شے کا پالنے والا ہے اور جو نفس جو کچھ کرے گا اس کا وبال اسی کی ذمہ ہوگا اور کوئی نفس دوسرے کا بوجھ نہ اٹھائے گا -اس کے بعد تم سب کی بازگشت تمہارے پروردگار کی طرف ہے پھر وہ بتائے گا کہ تم کس چیز میں اختلاف کررہے تھے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@cmliv{وہی وہ خدا ہے جس نے تم کو زمین میں نائب بنایا اور بعض کے درجات کو بعض سے بلند کیا تاکہ تمہیں اپنے دئیے ہوئے سے آزمائے -تمہارا پروردگار بہت جلد حساب کرنے والا ہے اور وہ بیشک بہت بخشنے والا مہربان ہے\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@cmlv{\basmalahur الۤمۤصۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@cmlvi{یہ کتاب آپ کی طرف نازل کی گئی ہے لہذا آپ اس کی طرف سے کسی تنگی کا شکار نہ ہوں اور اس کے ذریعہ لوگوں کو ڈرائیں یہ کتاب صاحبانِ ایمان کے لئے مکمل یاددہانی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@cmlvii{لوگوتم اس کا اتباع کرو جو تمہارے پروردگار کی طرف سے نازل ہوا ہے اور اس کے علاوہ دوسرے سرپرستوں کا اتباع نہ کرو ,تم بہت کم نصیحت مانتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@cmlviii{اور کتنے قرئیے ہیں جنہیں ہم نے برباد کردیا اور ان کے پاس ہمارا عذاب اس وقت آیا جب وہ رات میں سورہے تھے یا دن میں قیلولہ کررہے تھے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@cmlix{پھر ہمارا عذاب آنے کے بعد ان کی پکار صرف یہ تھی کہ یقینا ہم لوگ ظالم تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@cmlx{پس اب ہم ان لوگوں سے بھی سوال کریں گے اور ان کے رسولوں سے بھی سوال کریں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@cmlxi{پھر ان سے ساری داستان علم و اطلاع کے ساتھ بیان کریں گے اور ہم خود بھی غائب تو تھے نہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@cmlxii{آج کے دن اعمال کا وزن ایک برحق شے ہے پھر جس کے نیک اعمال کا پّلہ بھاری ہوگا وہی لوگ نجات پانے والے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@cmlxiii{اور جن کا پّلہ ہلکا ہوگیا یہی وہ لوگ تھے جنہوں نے اپنے نفس کو خسارہ میں رکھا کہ وہ ہماری آیتوں پر ظلم کررہے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@cmlxiv{یقینا ہم نے تم کو زمین میں اختیار دیا اور تمہارے لئے سامان زندگی قرار دئیے مگر تم بہت کم شکر ادا کرتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@cmlxv{اور ہم نے تم سب کو پیدا کیا پھر تمہاری صورتیں مقرر کیں -اس کے بعد ملائکہ کو حکم دیا کہ آدم کو سجدہ کریں تو سب نے سجدہ کرلیا صرف ابلیس نے انکار کردیا اور وہ سجدہ کرنے والوں میں شامل نہیں ہوا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@cmlxvi{ارشاد ہوا کہ تجھے کس چیز نے روکا تھا کہ تونے میرے حکم کے بعد بھی سجدہ نہیں کیا -اس نے کہا کہ میں ان سے بہتر ہوں -تو نے مجھے آگ سے پیدا کیا ہے اور انہیں خاک سے بنایا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@cmlxvii{فرمایا تو یہاں سے اتر جا تجھے حق نہیں ہے کہ یہاں غرور سے کام لے -نکل جا کہ تو ذلیل لوگوں میں ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@cmlxviii{اس نے کہا کہ پھر مجھے قیامت تک کی مہلت دے دے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@cmlxix{ارشاد ہوا کہ تو مہلت والوں میں سے ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@cmlxx{اس نے کہا کہ پس جس طرح تو نے مجھے گمراہ کیا ہے میں تیرے سیدھے راستہ پر بیٹھ جاؤں گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@cmlxxi{اس کے بعد سامنے ,پیچھے اور داہنے بائیں سے آؤں گا اور تو اکثریت کو شکر گزار نہ پائے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@cmlxxii{فرمایا کہ یہاں سے نکل جا تو ذلیل اور مردود ہے اب جو بھی تیرا اتباع کرے گا میں تم سب سے جہّنم کو بھردوں گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@cmlxxiii{اور اے آدم علیھ السّلامتم اور تمہاری زوجہ دونوں جنّت میں داخل ہوجاؤ اور جہاں جو چاہو کھاؤ لیکن اس درخت کے قریب نہ جانا کہ ظلم کرنے والوں میں شمار ہوجاؤ گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@cmlxxiv{پھر شیطان نے ان دونوں میں وسوسہ پیدا کرایا کہ جن شرم کے مقامات کو چھپا رکھا ہے وہ نمایاں ہوجائیں اور کہنے لگا کہ تمہارے پروردگار نے تمہیں اس درخت سے صرف اس لئے روکا ہے کہ تم فرشتے ہوجاؤ گے یا تم ہمیشہ رہنے والو میں سے ہوجاؤ گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@cmlxxv{اور دونوں سے قسم کھائی کہ میں تمہیں نصیحت کرنے والوں میں ہوں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@cmlxxvi{پھر انہیں دھوکہ کے ذریعہ درخت کی طرف جھکا دیا اور جیسے ہی ان دونوں نے چکّھا شرمگاہیں کھلنے لگیں اور انہوں نے درختوں کے پتے جوڑ کر شرمگاہوں کو چھپانا شروع کردیا تو ان کے رب نے آواز دی کہ کیا ہم نے تم دونوں کو اس درخت سے منع نہیں کیا تھا اور کیا ہم نے تمہیں نہیں بتایا تھا کہ شیطان تمہارا کھلا ہوا دشمن ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@cmlxxvii{ان دونوں نے کہا کہ پروردگار ہم نے اپنے نفس پر ظلم کیا ہے اب اگر تو معاف نہ کرے گا اور رحم نہ کرے گا تو ہم خسارہ اٹھانے والوں میں ہوجائیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@cmlxxviii{ارشاد ہوا کہ تم سب زمین میں اتر جاؤ اور سب ایک دوسرے کے دشمن ہو -زمین میں تمہارے لئے ایک مّدت تک ٹھکانا اور سامان زندگانی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@cmlxxix{فرمایا کہ وہیں تمہیں جینا ہے اور وہیں مرنا ہے اور پھر اسی زمین سے نکالے جاؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@cmlxxx{اے اولادُ آدم ہم نے تمہارے لئے لباس نازل کیا ہے جس سے اپنی شرمگاہوں کا پردہ کرو اور زینت کا لباس بھی دیا ہے لیکن تقوٰی کا لباس سب سے بہتر ہے یہ بات آیات الٰہیٰہ میں ہے کہ شاید وہ لوگ عبرت حاصل کرسکیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@cmlxxxi{اے اولاد آدم خبردار شیطان تمہیں بھی نہ بہکادے جس طرح تمہارے ماں باپ کو جنّت سے نکال لیا اس عالم میں کہ ان کے لباس الگ کرادئیے تاکہ شرمگاہیں ظاہر ہوجائیں -وہ اور اس کے قبیلہ والے تمہیں دیکھ رہے ہیں اس طرح کہ تم انہیں نہیں دیکھ رہے ہو بیشک ہم نے شیاطین کو بے ایمان انسانوں کا دوست بنادیا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@cmlxxxii{اور یہ لوگ جب کوئی براکام کرتے ہیں تو کہتے ہیں کہ ہم نے آباؤ اجداد کو اسی طریقہ پر پایا ہے اور اللہ نے یہی حکم دیا ہے -آپ فرمادیجئے کہ خدا بری بات کا حکم دے ہی نہیں سکتا ہے کیا تم خدا کے خلاف وہ کہہ رہے ہو جو جانتے بھی نہیں ہو\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiii{کہہ دیجئے کہ میرے پروردگار نے انصاف کا حکم دیا ہے اور تم سب ہر نماز کے وقت اپنا رخ سیدھا رکھا کرو اور خدا کو خالص دین کے ساتھ پکارو اس نے جس طرح تمہاری ابتدا کی ہے اسی طرح تم پلٹ کر بھی جاؤ گے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@cmlxxxiv{اس نے ایک گروہ کو ہدایت دی ہے اور ایک پر گمراہی مسلط ہوگئی ہے کہ انہوں نے شیاطین کو اپنا ولی بنالیا ہے اور خدا کو نظر انداز کردیا ہے اور پھر ان کا خیال ہے کہ وہ ہدایت یافتہ بھی ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@cmlxxxv{اے اولاد آدم ہر نماز کے وقت اور ہر مسجد کے پاس زینت ساتھ رکھو اور کھاؤ پیو مگر اسراف نہ کرو کہ خدا اسراف کرنے والوں کو دوست نہیں رکھتا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvi{پیغمبر آپ پوچھئے کہ کس نے اس زینت کو جس کو خدا نے اپنے بندوں کے لئے پیدا کیا ہے اور پاکیزہ رزق کو حرام کردیا ہے ... اور بتائیے کہ یہ چیزیں روزِ قیامت صرف ان لوگوں کے لئے ہیں جو زندگانی دنیا میں ایمان لائے ہیں .ہم اسی طرح صاحبان هعلم کے لئے مفصل آیات بیان کرتے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@cmlxxxvii{کہہ دیجئے کہ ہمارے پروردگار نے صرف بدکاریوں کو حرام کیا ہے چاہے وہ ظاہری ہوں یا باطنی .... اور گناہ اور ناحق ظلم اور بلادلیل کسی چیز کو خدا کا شریک بنانے اور بلاجانے بوجھے کسی بات کو خدا کی طرف منسوب کرنے کو حرام قرار دیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@cmlxxxviii{ہر قوم کے لئے ایک وقت مقر ّر ہے جب وہ وقت آجائے گا تو ایک گھڑی کے لئے نہ پیچھے ٹل سکتا ہے اور نہ آگے بڑھ سکتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@cmlxxxix{اے اولاد آدم جب بھی تم میں سے ہمارے پیغمبر تمہارے پاس آئیں گے اور ہماری آیتوں کو بیان کریں گے تو جو بھی تقوی ٰ اختیار کرے گا اور اپنی اصلاح کرلے گا اس کے لئے نہ کوئی خوف ہے اور نہ وہ رنجیدہ ہوگا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@cmxc{اور جن لوگوں نے ہماری آیات کی تکذیب کی اور اکڑ گئے وہ سب جہّنمی ہیں اور اسی میں ہمیشہ رہنے والے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@cmxci{اس سے بڑا ظالم کون ہے جو خدا پر جھوٹا الزام لگائے یا اس کی آیات کی تکذیب کرے -ان لوگوں کو ان کی قسمت کا لکھا ملتا رہے گا یہاں تک کہ جب ہمارے نمائندے فرشتے مّدت حیات پوری کرنے کے لئے آئیں گے تو پوچھیں گے کہ وہ سب کہاں ہیں جن کو تم خدا کو چھوڑ کر پکارا کرتے تھے وہ لوگ کہیں گے کہ وہ سب تو گم ہوگئے اور اس طرح اپنے خلاف خود بھی گواہی دیں گے کہ وہ لوگ کافر تھے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@cmxcii{ارشاد ہوگا کہ تم سے پہلے جو جن و انس کی مجرم جماعتیں گزر چکی ہیں تم بھی انہی کے ساتھ جہّنم میں داخل ہوجاؤ-حالت یہ ہوگی کہ ہر داخل ہونے والی جماعت دوسری پر لعنت کرے گی اور جب سب اکٹھا ہوجائیں گے تو بعد والے پہلے والوں کے بارے میں کہیں گے کہ پروردگار ا ن ہی نے ہمیں گمراہ کیا ہے لہٰذا ان کے عذاب کو دوگنا کردے -ارشاد ہوگا کہ سب کا عذاب دوگنا ہے صرف تمہیں معلوم نہیں ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@cmxciii{پھر پہلے والے بعد والوں سے کہیں گے کہ تمہیں ہمارے اوپر کوئی فضیلت نہیں ہے لہذا اپنے کئے کا عذاب چکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@cmxciv{بیشک جن لوگوں نے ہماری آیتوں کی تکذیب کی اور غرور سے کام لیا ان کے لئے نہ آسمان کے دروازے کھولے جائیں گے اور نہ وہ جنّت میں داخل ہوسکیں گے جب تک اونٹ سوئی کے ناکہ کے اندر داخل نہ ہوجائے اور ہم اسی طرح مجرمین کو سزا دیا کرتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@cmxcv{ان کے لئے جہّنم ہی کا فرش ہوگا اور ان کے اوپر اسی کا اوڑھنا بھی ہوگا اور ہم اسی طرح ظالموں کو ان کے اعمال کا بدلہ دیا کرتے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@cmxcvi{اور جن لوگوں نے ایمان اختیار کیا اور نیک اعمال کئے ہم کسی نفس کو اس کی وسعت سے زیادہ تکلیف نہیں دیتے وہی لوگ جنّتی ہیں اور اس میں ہمیشہ رہنے والے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@cmxcvii{اور ہم نے ان کے سینوں سے ہر کینہ کو الگ کردیا. ان کے قدموں میں نہریں جاری ہوں گی اور وہ کہیں گے کہ طُکر ہے پروردگار کا کہ اس نے ہمیں یہاں تک آنے کا راستہ بتادیا ورنہ اس کی ہدایت نہ ہوتی تو ہم یہاں تک آنے کا راستہ بھی نہیں پاسکتے تھے -بیشک ہمارے رسول سب دینِ حق لے کر آئے تھے تو پھر انہیں آواز دی جائے گی کہ یہ وہ جّنتہے جس کا تمہیں تمہارے اعمال کی بنا پر وارث بنایا گیا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@cmxcviii{اور جنّتی لوگ جہّنمیوں سے پکار کر کہیں گے کہ جو کچھ ہمارے پروردگار نے ہم سے وعدہ کیا تھا وہ ہم نے تو پالیا کیا تم نے بھی حسب وعدہ حاصل کرلیا ہے وہ کہیں گے بیشک .پھر ایک منادی آواز دے گا کہ ظالمین پر خدا کی لعنت ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@cmxcix{جو راہ هخدا سے روکتے تھے اور اس میں کجی پیدا کیا کرتے تھے اور آخرت کے منکر تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@m{اور ان کے درمیان پردہ ڈال دیا جائے گا اور اعراف پر کچھ لوگ ہوں گے جو سب کو ان کی نشانیوں سے پہچان لیں گے اور اصحابِ جنّت کو آواز دیں گے کہ تم پر ہمارا سلام -وہ جنّت میں داخل نہ ہوئے ہوں گے لیکن اس کی خواہش رکھتے ہوں گے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mi{اور پھر جب ان کی نظر جہّنموالوں کی طرف مڑ جائے گی تو کہیں گے کہ پروردگار ہم کو ان ظالمین کے ساتھ نہ قرار دینا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mii{اور اعراف والے ان لوگوں کو جنہیں وہ نشانیوں سے پہچانتے ہوں گے آواز دیں گے کہ آج نہ تمہاری جماعت کام آئی اور نہ تمہارا غرور کام آیا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@miii{کیا یہی لوگ ہیں جن کے بارے میں تم قسمیں کھایا کرتے تھے کہ انہیں رحمت خدا حاصل نہ ہوگی جن سے ہم نے کہہ دیا ہے کہ جاؤ جنّت میں چلے جاؤ تمہارے لئے نہ کوئی خوف ہے اور نہ کوئی حزن\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@miv{اور جہّنم والے جنّت والوں سے پکار کر کہیں گے کہ ذرا ٹھنڈا پانی یا خدا نے جو رزق تمہیں دیا ہے اس میں سے ہمیں بھی پہنچاؤ تو وہ لوگ جواب دیں گے کہ ان چیزوں کو اللہ نے کافروں پر حرام کردیا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mv{جن لوگوں نے اپنے دین کو کھیل تماشہ بنالیا تھا اور انہیں زندگانی دنیا نے دھوکہ دے دیا تھا تو آج ہم انہیں اسی طرح بھلادیں گے جس طرح انہوں نے آج کے دن کی ملاقات کو بھلادیا تھا اور ہماری آیات کا دیدہ و دانستہ انکار کررہے تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mvi{ہم ان کے پاس ایسی کتاب لے آئے ہیں جسے علم و اطلاع کے ساتھ مفصل بیان کیا ہے اور وہ صاحبانِ ایمان کے لئے ہدایت اور رحمت ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mvii{کیا یہ لوگ صرف انجام کار کا انتظار کررہے ہیں تو جس دن انجام سامنے آجائے گا تو جو لوگ پہلے سے اسے بھولے ہوئے تھے وہ کہنے لگیں گے کہ بیشک ہمارے پروردگار کے رسول صحیح ہی پیغام لائے تھے تو کیا ہمارے لئے بھی شفیع ہیں جو ہماری سفارش کریں یا ہمیں واپس کردیا جائے تو ہم جو اعمال کرتے تھے اس کے علاوہ دوسرے قسم کے اعمال کریں -درحقیقت ان لوگوں نے اپنے کو خسارہ میں ڈال دیا ہے اور ان کی ساری افترا پردازیاں غائب ہوگئی ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mviii{بیشک تمہارا پروردگار وہ ہے جس نے آسمانوں اور زمین کو چھ دن میں پیدا کیا ہے اور اس کے بعد عرش پر اپنا اقتدار قائم کیا ہے وہ رات کو دن پر ڈھانپ دیتاہے اور رات تیزی سے اس کے پیچھے دوڑا کرتی ہے اور آفتاب و ماہتاب اور ستارے سب اسی کے حکم کے تابع ہیں اسی کے لئے خلق بھی ہے اور امر بھی وہ نہایت ہی صاحب هبرکت اللہ ہے جو عالمین کا پالنے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mix{تم اپنے رب کو گڑگڑا کراور خاموشی کے ساتھ پکارو کہ وہ زیادتی کرنے والوں کو دوست نہیں رکھتا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mx{اور خبردار زمین میں اصلاح کے بعد فساد نہ پیدا کرنا اور خدا سے ڈرتے ڈرتے اور امیدوار بن کر دعا کرو کہ اس کی رحمت صاحبان هحسن هعمل سے قریب تر ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mxi{وہ خدا وہ ہے جو ہواؤں کو رحمت کی بشارت بناکر بھیجتا ہے یہاں تک کہ جب ہوائیں وزنی بادلوں کو اٹھالیتی ہیں تو ہم ان کو مردہ شہروں کو زندہ کرنے کے لئے لے جاتے ہیں اور پھر پانی برسادیتے ہیں اور اس کے ذریعہ مختلف پھل پیدا کردیتے ہیں اور اسی طرح ہم مفِدوں کو زندہ کردیا کرتے ہیں کہ شاید تم عبرت و نصیحت حاصل کرسکو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mxii{اور پاکیزہ زمین کا سبزہ بھی اس کے پروردگار کے حکم سے خوب نکلتا ہے اور جو زمین خبیث ہوتی ہے اس کا سبزہ بھی خراب نکلتا ہے ہم اسی طرح شکر کرنے والی قوم کے لئے اپنی آیتیں الٹ پلٹ کر بیان کرتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mxiii{یقینا ہم نے نوح علیھ السّلامکو ان کی قوم کی طرف بھیجا تو انہوں نے کہا کہ اے قوم والو اللہ کی عبادت کرو کہ اس کے علاوہ تمہارا کوئی خدا نہیں ہے. میں تمہارے بارے میں عذاب عظیم سے ڈرتا ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mxiv{تو قوم کے رؤسا نے جواب دیا کہ ہم تم کو کھلی ہوئی گمراہی میں دیکھ رہے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mxv{نوح علیھ السّلامنے کہا کہ اے قوم مجھ میں گمراہی نہیں ہے بلکہ میں ربّالعالمین کی طرف سے بھیجا ہوا نمائندہ ہوں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mxvi{میں تم تک اپنے پروردگار کے پیغامات پہنچاتا ہوں اور تمہیں نصیحت کرتا ہوں اور اللہ کی طرف سے وہ سب جانتا ہوں جو تم نہیں جانتے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mxvii{کیا تمہیں اس بات پر تعجب ہے کہ تمہارے پروردگار کی طرف سے تم ہی میں سے سے ایک مرد پر ذکر نازل ہوجائے کہ وہ تمہیں ڈرائے اور تم متقی بن جاؤ اور شاید اس طرح قابل هرحم بھی ہوجاؤ\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mxviii{پھر ان لوگوں نے نوح علیھ السّلامکی تکذیب کی تو ہم نے انہیں اور ان کے ساتھیوں کو کشتی میں نجات دے دی اور جن لوگوں نے ہماری آیتوں کو جھٹلایا تھا انہیں غرق کردیا کہ وہ سب بالکل اندھے لوگ تھے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mxix{اور ہم نے قوم عاد علیھ السّلامکی طرف ان کے بھائی ہود کو بھیجا تو انہوں نے کہا کہ اے قوم والو اللہ کی عبادت کرو اس کے علاوہ تمہارا دوسرا خدا نہیں ہے کیا تم ڈرتے نہیں ہو\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mxx{قوم میں سے کفر اختیار کرنے والے رؤسا نے کہا کہ ہم تم کو حماقت میں مبتلا دیکھ رہے ہیں اور ہمارے خیال میں تم جھوٹوں میں سے ہو\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mxxi{انہوں نے جواب دیا کہ مجھ میں حماقت نہیں ہے بلکہ میں ربّ العالمین کی طرف سے فرستادہ رسول ہوں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mxxii{میں تم تک اپنے رب کے پیغامات پہنچاتا ہوں اور تمہارے لئے ایک امانتدار ناصح ہوں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mxxiii{کیا تم لوگوں کو اس بات پر تعجب ہے کہ تم تک ذکر خدا تمہارے ہی کسی آدمی کے ذریعہ آجائے تاکہ وہ تمہیں ڈرائے اور یاد کرو کہ تم کو اس نے قوم نوح علیھ السّلامکے بعد زمین میں جانشین بنایا ہے اور مخلوقات میں وسعت عطا کی ہے لہذا تم اللہ کی نعمتوں کو یاد کرو کہ شاید اسی طرح فلاح اور نجات پاجاؤ\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mxxiv{ان لوگوں نے کہا کہ کیا آپ یہ پیغام لائے ہیں کہ ہم صرف ایک خدا کی عبادت کریں اور جن کی ہمارے آباؤ و اجداد عبادت کرتے تھے ان سب کو چھوڑ دیں تو آپ اپنے وعدہ و عید کو لے کر آئیے اگر اپنی بات میں سچے ّہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mxxv{انہوں نے جواب دیا کہ تمہارے اوپر پروردگا رکی طرف سے عذاب اور غضب طے ہوچکا ہے -کیا تم مجھ سے ان ناموں کے بارے میں جھگڑا کرتے ہو جو تم نے اور تمہارے بزرگوں نے خود طے کرلئے ہیں اور خدا نے ان کے بارے میں کوئی برہان نازل نہیں کیا ہے تو اب تم عذاب کا انتظار کرو میں بھی تمہارے ساتھ انتظار کرنے والوں میں ہوں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mxxvi{پھر ہم نے انہیں اور ان کے ساتھیوں کو اپنی رحمت سے نجات دے دی اور اپنی آیات کی تکذیب کرنے والوں کی نسل منقطع کردی اور وہ لوگ ہرگز صاحبان هایمان نہیں تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mxxvii{اور ہم نے قوم ثمود علیھ السّلام کی طرف ان کے بھائی صالح علیھ السّلامکو بھیجا تو انہوں نے کہا کہ اے قوم والو اللہ کی عبادت کرو کہ اس کے علاوہ کوئی خدا نہیں ہے -تمہارے پاس پروردگار کی طرف سے دلیل آچکی ہے -یہ خدائی ناقہ ہے جو تمہارے لئے اس کی نشانی ہے -اسے آزاد چھوڑ دو کہ زمینِ خدا میں کھاتا پھرے اور خبردار اسے کوئی تکلیف نہ پہنچانا کہ تم کو عذاب الیم اپنی گرفت میں لے لے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mxxviii{اس وقت کو یاد کرو جب اس نے تم کو قوم عاد علیھ السّلام کے بعد جانشین بنایا اور زمین میںاس طرح بسایا کہ تم ہموار زمینوں میں قصر بناتے تھے اور پہاڑوں کو کاٹ کاٹ کر گھر بناتے تھے تو اب اللہ کی نعمتوں کو یاد کرو اور زمین میں فساد نہ پھیلاتے پھرو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mxxix{تو ان کی قوم کے بڑے لوگوں نے کمزور بنادئیے جانے والے لوگوں میں سے جو ایمان لائے تھے ان سے کہنا شروع کیا کہ کیا تمہیں اس کا یقین ہے کہ صالح علیھ السّلامخدا کی طرف سے بھیجے گئے ہیں انہوں نے کہا کہ بیشک ہمیں ان کے پیغام کا ایمان اور ایقان حاصل ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mxxx{تو بڑے لوگوں نے جوابد یا کہ ہم تو ان باتوں کے منکر ہیں جن پر تم ایمان لانے والے ہو\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mxxxi{پھر یہ کہہ کر ناقہ کے پاؤں کاٹ دئیے اور حکم خدا سے سرتابی کی اور کہا کہ صالح علیھ السّلاماگر تم خدا کے رسول ہو تو جس عذاب کی دھمکی دے رہے تھے اسے لے آؤ\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mxxxii{تو انہیں زلزلہ نے اپنی گرفت میں لے لیاکہ اپنے گھر ہی میں سربہ زانو رہ گئے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mxxxiii{تو اس کے بعد صالح علیھ السّلامنے ان سے منہ پھیر لیا اور کہا کہ اے قوم میں نے خدائی پیغام کو پہنچایا تم کو نصیحت کی مگر افسوس کہ تم نصیحت کرنے والوں کو دوست نہیں رکھتے ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mxxxiv{اور لوط علیھ السّلام کو یاد کرو کہ جب انہوں نے اپنی قوم سے کہا کہ تم بدکاری کرتے ہو اس کی تو تم سے پہلے عالمین میں کوئی مثال نہیں ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mxxxv{تم ازراسِ شہوت عورتوں کے بجائے مردوں سے تعلقات پیدا کرتے ہو اور تم یقینا اسراف اور زیادتی کرنے والے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mxxxvi{اور ان کی قوم کے پاس کوئی جواب نہ تھا سوائے اس کے کہ انہوں نے لوگوں کو ابھارا کہ انہیں اپنے قریہ سے نکال باہر کرو کہ یہ بہت پاک باز بنتے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mxxxvii{تو ہم نے انہیں اور ان کے تمام اہل کو نجات دے دی ان کی زوجہ کے علاوہ کہ وہ پیچھے رہ جانے والوں میں سے تھی\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mxxxviii{ہم نے ان کے اوپر خاص قسم کے (پتھروں)کی بارش کی تو اب دیکھو کہ مجرمین کا انجام کیسا ہوتا ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mxxxix{اور ہم نے قوم مدین کی طرف ان کے بھائی شعیب علیھ السّلامکو بھیجا تو انہوں نے کہا کہ اللہ کی عبادت کرو کہ اس کے علاوہ کوئی خدا نہیں ہے - تمہارے پاس پروردگار کی طرف سے دلیل آچکی ہے اب ناپ تول کو پورا پورا رکھو اور لوگوں کو چیزیں کم نہ دو اور اصلاح کے بعد زمین میں فساد برپا نہ کرو -یہی تمہارے حق میں بہتر ہے اگر تم ایمان لانے والے ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mxl{اورخبردار ہر راستہ پر بیٹھ کر ایمان والوں کو ڈرانے دھمکانے اور راہ هخدا سے روکنے کا کام چھوڑ دو کہ تم اس میں بھی کجی تلاش کررہے ہو اور یہ یاد کرو کہ تم بہت کم تھے خدا نے کثرت عطا کی اور یہ دیکھو کہ فساد کرنے والوں کا انجام کیا ہوتا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mxli{اور اگر تم میں سے ایک جماعت میرے لائے ہوئے پیغام پر ایمان لے آئی اور ایک ایمان نہیں لائی تو ٹھہرو یہاں تک کہ خدا ہمارے درمیان اپنا فیصلہ صادر کردے کہ وہ بہترین فیصلہ کرنے والا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mxlii{ان کی قوم کے مستکبرین نے کہا کہ اے شعیب علیھ السّلامہم تم کو اور تمہارے ساتھ ایمان لانے والوں کو اپنی بستی سے نکال باہر کریں گے یا تم بھی پلٹ کر ہمارے مذہب پر آجاؤ .... انہوں نے جواب دیا کہ چاہے ہم تمہارے مذہب سے بیزار ہی کیوں نہ ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mxliii{یہ اللہ پر بڑا بہتان ہوگا اگر ہم تمہارے مذہب پرآجائیں جب کہ اس نے ہم کو اس مذہب سے نجات دے دی ہے اور ہمیں حق نہیں ہے کہ ہم تمہارے مذہب پر آجائیں جب تک خدا خود نہ چاہے .ہمارے پروردگار کا علم ہر شے پر حاوی ہے اور ہمارا اعتماد اسی کے اوپر ہے -خدایا تو ہمارے اور ہماری قوم کے درمیان حق سے فیصلہ فرمادے کہ تو بہترین فیصلہ کرنے والا ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mxliv{تو ان کی قوم کے کفاّر نے کہا کہ اگر تم لوگ شعیب علیھ السّلامکا اتباع کرلو گے تو تمہارا شمار خسارہ والوں میں ہوجائے گا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mxlv{نتیجہ یہ ہوا کہ انہیں زلزلہ نے اپنی گرفت میں لے لیا اور اپنے گھر میں سربہ زانو ہوگئے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mxlvi{جن لوگوں نے شعیب علیھ السّلامکی تکذیب کی وہ ایسے برباد ہوئے گویا اس بستی میں بسے ہی نہیں تھے -جن لوگوں نے شعیب علیھ السّلامکو جھٹلایا وہی خسارہ والے قرار پائے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mxlvii{اس کے بعد شعیب علیھ السّلامنے ان سے منہ پھیر لیا اور کہا کہ اے قوم میں نے اپنے پروردگار کے پیغامات کو پہنچادیا اور تمہیں نصیحت بھی کی تو اب کفر اختیار کرنے والوں کے حال پر کس طرح افسوس کروں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mxlviii{اور ہم نے جب بھی کسی قریہ میں کوئی نبی بھیجا تو اہل قریہ کو نافرمانی پر سختی اور پریشانی میں ضرور مبتلا کیا کہ شاید وہ لوگ ہماری بارگاہ میں تضرع و زاری کریں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mxlix{پھر ہم نے برائی کی جگہ اچھائی دے دی یہاں تک کہ وہ لوگ بڑھ نکلے اور کہنے لگے کہ یہ تکلیف و راحت تو ہمارے بزرگوں تک بھی آچکی ہے تو ہم نے اچانک انہیں اپنی گرفت میں لے لیا اور انہیں اس کا شعور بھی نہ ہوسکا\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@ml{اور اگر اہل قریہ ایمان لے آتے اور تقوٰی اختیار کرلیتے تو ہم ان کے لئے زمین اور آسمان سے برکتوں کے دروازے کھول دیتے لیکن انہوں نے تکذیب کی تو ہم نے ان کو ان کے اعمال کی گرفت میں لے لیا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mli{کیا اہلِ قریہ اس بات سے مامون ہیں کہ یہ سوتے ہی رہیں اور ہمارا عذاب راتوں رات نازل ہوجائے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mlii{یا اس بات سے مطمئن ہیں کہ یہ کھیل کود میں مصروف رہیں اور ہمارا عذاب دن دھاڑے نازل ہوجائے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mliii{کیا یہ لوگ خدائی تدبیر کی طرف سے مطمئن ہوگئے ہیں جب کہ ایسا اطمینان صرف گھاٹے میں رہنے والوں کو ہوتا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mliv{کیا ایک قوم کے بعد دوسرے زمین کے وارث ہونے والوں کو یہ ہدایت نہیں ملتی کہ اگر ہم چاہتے تو ان کے گناہوں کی بنا پر انہیں بھی مبتلائے مصیبت کردیتے اور ان کے دلوں پر مہرلگادیتے اور پھر انہیں کچھ سنائی نہ دیتا\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mlv{یہ وہ بستیاں ہیں جن کی خبریں ہم آپ سے بیان کررہے ہیں کہ ہمارے پیغمبران کے پاس معجزات لے کر آئے مگر پہلے سے تکذیب کرنے کی بنا پر یہ ایمان نہ لاسکے .ہم اسی طرح کافروں کے دلوں پر مہر لگادیا کرتے ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mlvi{ہم نے ان کی اکثریت میں عہدو پیمان کی پاسداری نہیں پائی اور ان کی اکثریت کو فاسق اور حدود اطاعت سے خارج ہی پایا\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mlvii{پھر ان سب کے بعد ہم نے موسٰی علیھ السّلامکو اپنی نشانیاں دے کر فرعون اور اس کی قوم کی طرف بھیجا تو ان لوگوں نے بھی ظلم کیا تو اب دیکھو کہ فساد کرنے والوں کا انجام کیا ہوتا ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mlviii{اور موسٰی علیھ السّلامنے فرعون سے کہا کہ میں رب العالمین کی طرف سے فرستادہ پیغمبر ہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mlix{میرے لئے لازم ہے کہ میں خدا کے بارے میں حق کے علاوہ کچھ نہ کہوں -میں تیرے پاس تیرے رب کی طرف سے معجزہ لے کر آیا ہوں لہٰذا بنی اسرائیل کو میرے ساتھ بھیج دے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mlx{اس نے کہا کہ اگر تم معجزہ لائے ہو اور اپنی بات میں سچےّ ہو تو وہ معجزہ پیش کرو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mlxi{موسٰی علیھ السّلامنے اپنا عصا پھینک دیا اور وہ اچھا خاصا سانپ بن گیا\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mlxii{اور پھر اپنے ہاتھ کو نکالا تو وہ دیکھنے والوں کے لئے انتہائی روشن اور چمکدار تھا\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mlxiii{فرعون کی قوم کے رؤسا نے کہا کہ یہ تو سمجھدار جادوگر ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mlxiv{جو تم لوگوں کو تمہاری سرزمین سے نکالنا چاہتاہے اب تم لوگوں کا کیا خیال ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mlxv{لوگوں نے کہا کہ ان کو اور ان کے بھائی کو روک لیجئے اور مختلف شہروں میں جمع کرنے والوں کو بھیجئے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mlxvi{جو تمام ماہر جادوگروں کو بلا کر لے آئیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mlxvii{جادوگر فرعون کے پاس حاضر ہو گئے اور انہوں نے کہا کہ اگر ہم غالب آگئے تو کیا ہمیں اس کی اجرت ملے گی\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mlxviii{. فرعون نے کہا بیشک تم میرے دربار میں مقرب ہوجاؤ گے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mlxix{ان لوگوں نے کہا کہ موسٰی علیھ السّلامآپ عصاپھیکنیں گے یا ہم اپنے کام کا آغاز کریں\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mlxx{موسٰی علیھ السّلامنے کہا کہ تم ابتدا کرو -ان لوگوں نے رسیاں پھینکیں تو لوگوں کی آنکھوں پر جادو کردیا اور انہیں خوفزدہ کردیا اور بہت بڑے جادو کا مظاہرہ کیا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mlxxi{اور ہم نے موسٰی علیھ السّلامکو اشارہ کیا کہ اب تم بھی اپنا عصا ڈال دو وہ ان کے تمام جادو کے سانپوں کو نگل جائے گا\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mlxxii{نتیجہ یہ ہوا کہ حق ثابت ہوگیا اور ان کا کاروبار باطل ہوگیا\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mlxxiii{وہ سب مغلوب ہوگئے اور ذلیل ہوکر واپس ہوگئے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mlxxiv{اور جادوگر سب کے سب سجدہ میں گر پڑے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mlxxv{ان لوگوں نے کہا کہ ہم عالمین کے پروردگار پر ایمان لے آئے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mlxxvi{یعنی موسٰی علیھ السّلاماور ہارون علیھ السّلامکے رب پر\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mlxxvii{فرعون نے کہا کہ تم میری اجازت سے پہلے کیسے ایمان لے آئے .... یہ تمہارا مکر ہے جو تم شہر میں پھیلارہے ہو تاکہ لوگوں کو شہر سے باہر نکال سکو تو عنقریب تمہیں اس کا انجام معلوم ہوجائے گا\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mlxxviii{میں تمہارے ہاتھ اور پاؤں مختلف سمتوں سے کاٹ دوں گا اور اس کے بعد تم سب کو سولی پر لٹکادوں گا\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mlxxix{ان لوگوں نے جواب دیا کہ ہم لوگ بہرحال اپنے پروردگار کی بارگاہ میں پلٹ کر جانے والے ہیں\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mlxxx{اور تو ہم سے صرف اس بات پر ناراض ہے کہ ہم اپنے رب کی نشانیوں پر ایمان لے آئے ہیں .... خدایا ہم پر صبر کی بارش فرما اور ہمیں مسلمان دنیا سے اٹھانا\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mlxxxi{اور فرعون کی قوم کے ایک گروہ نے کہا کہ کیا تو موسٰی علیھ السّلاماور ان کی قوم کو یوں ہی چھوڑ دے گا کہ یہ زمین میں فساد برپا کریں اور تجھے اور تیرے خداؤں کو چھوڑ دیں -اس نے کہا کہ میں عنقریب ان کے لڑکوں کو قتل کر ڈالوں گا اور ان کی عورتوں کو زندہ رکھوں گا .میں ان پر قوت اور غلبہ رکھتا ہوں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mlxxxii{موسٰی علیھ السّلامنے اپنی قوم سے کہا کہ اللہ سے مدد مانگو اور صبر کرو -زمین اللہ کی ہے وہ اپنے بندوں میں جس کو چاہتا ہے وارث بناتا ہے اور انجام کار بہرحال صاحبان هتقوٰی کے لئے ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mlxxxiii{قوم نے کہا کہ ہم تمہارے آنے سے پہلے بھی ستائے گئے اور تمہارے آنے کے بعد بھی ستائے گئے -موسٰی علیھ السّلامنے جواب دیا کہ عنقریب تمہارا پروردگار تمہارے دشمن کو ہلاک کردے گا اور تمہیں زمین میں اس کا جانشین بنادے گا اور پھر دیکھے گا تمہارا طرز عمل کیسا ہوتا ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mlxxxiv{اور ہم نے آل فرعون کو قحط اور ثمرات کی کمی کی گرفت میں لے لیا کہ شاید وہ اسی طرح نصیحت حاصل کرسکیں\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mlxxxv{اس کے بعد جب ان کے پاس کوئی نیکی آئی تو انہوں نے کہا کہ یہ تو ہمارا حق ہے اور جب برائی آئی تو کہنے لگے کہ یہ موسٰی علیھ السّلاماور ان کے ساتھیوں کا اثر ہے -آگاہ ہوجاؤ کہ ان کی بدشگونی کے اسباب خدا کے یہاں معلوم ہیں لیکن ان کی اکثریت اس رازسے بے خبر ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mlxxxvi{اور قوم والوں نے کہاکہ موسٰی علیھ السّلامتم کتنی ہی نشانیاں جادو کرنے کے لئے لاؤ ہم تم پر ایمان لانے والے نہیں ہیں\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mlxxxvii{پھر ہم نے ان پر طوفان ,ٹڈی ,جوں ,مینڈک اور خون کو مفصل نشانی بناکر بھیجا لیکن ان لوگوں نے استکبار اور انکار سے کام لیا اور یہ لوگ واقعا مجرم لوگ تھے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mlxxxviii{اور جب ان پر عذاب نازل ہوگیا تو کہنے لگے کہ موسٰی علیھ السّلام اپنے رب سے دعا کرو جس بات کا اس نے وعدہ کیا ہے اگر تم نے اس عذاب کو دور کرادیاتو ہم تم پر ایمان بھی لائیں گے اور بنی اسرائیل کو تمہارے حوالے بھی کردیں گے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mlxxxix{اس کے بعد جب ہم نے ایک مّدت کے لئے عذاب کو برطرف کردیا تو پھر اپنے عہد کو توڑنے والوں میں شامل ہوگئے\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mxc{پھر ہم نے ان سے انتقام لیا اور انہیں دریا میں غرق کردیا کہ انہوں نے ہماری آیات کو جھٹلایا تھا اور ان کی طرف سے غفلت برتنے والے تھے\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mxci{اور ہم نے مستضعفین کو شرق و غرب زمین کا وارث بنادیااور اس میں برکت عطا کردی اور اس طرح بنی اسرائیل پر اللہ کی بہترین بات تمام ہوگئی کہ انہوں نے صبر کیاتھا اور جو کچھ فرعون اور اس کی قوم والے بنارہے تھے ہم نے سب کو برباد کردیا اور ان کی اونچی اونچی عمارتوں کو مسمار کردیا\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mxcii{اور ہم نے بنی اسرائیل کو دریا پار پہنچا دیا تو وہ ایک ایسی قوم کے پاس پہنچے جو اپنے بتوں کے گرد مجمع لگائے بیٹھی تھی -ان لوگوں نے موسٰی علیھ السّلامسے کہا کہ موسٰی علیھ السّلامہمارے لئے بھی ایسا ہی خدا بنادو جیسا کہ ان کا خدا ہے انہوں نے کہا کہ تم لوگ بالکل جاہل ہو\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mxciii{ان لوگوںکا نظام برباد ہونے والا اور ان کے اعمال باطل ہیں\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mxciv{کیا میں خدا کے علاوہ تمہارے لئے دوسرا خدا تلاش کروں جب کہ اس نے تمہیں عالمین پر فضیلت دی ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mxcv{اور جب ہم نے تم کو فرعون والوں سے نجات دی جو تمہیں بدترین عذاب میں مبتلا کررہے تھے تمہارے لڑکوں کو قتل کررہے تھے اور لڑکیوں کو خدمت کے لئے باقی رکھ رہے تھے اور اس میں تمہارے لئے پروردگار کی طرف سے سخت ترین امتحان تھا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mxcvi{اور ہم نے موسٰی علیھ السّلامسے تیس راتوں کا وعدہ لیا اور اسے دس مزید راتوں سے مکمل کردیا کہ اس طرح ان کے رب کا وعدہ چالیس راتوں کا وعدہ ہوگیا اور انہوں نے اپنے بھائی ہارون علیھ السّلامسے کہا کہ تم قوم میں میری نیابت کرو اور اصلاح کرتے رہو اور خبردار مفسدوں کے راستہ کا اتباع نہ کرنا\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mxcvii{تو اس کے بعد جب موسٰی علیھ السّلامہمارا وعدہ پورا کرنے کے لئے آئے اور ان کے رب نے ان سے کلام کیا تو انہوں نے کہا کہ پروردگار مجھے اپنا جلوہ دکھادے ارشاد ہوا تم ہرگز مجھے نہیں دیکھ سکتے ہو البتہ پہاڑ کی طرف دیکھو اگر یہ اپنی جگہ پر قائم رہ گیا تو پھر مجھے دیکھ سکتے ہو .اس کے بعد جب پہاڑ پر پروردگار کی تجلی ہوئی تو پہاڑ چور چور ہوگیا اور موسٰی علیھ السّلام بیہوش ہوکر گر پڑے پھر جب انہیں ہوش آیا تو کہنے لگے کہ پروردگار تو پاک و پاکیزہ ہے میں تیری بارگاہ میں توبہ کرتا ہوں اور میں سب سے پہلا ایمان لانے والا ہوں\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mxcviii{ارشاد ہوا کہ موسٰی علیھ السّلامہم نے تمام انسانوں میں اپنی رسالت اور اپنے کلام کے لئے تمہارا انتخاب کیا ہے لہذا اب اس کتاب کو لے لو اور اللہ کے شکر گذار بندوں میں ہوجاؤ\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mxcix{اور ہم نے توریت کی تختیوں میں ہر شے میں سے نصیحت کاحصہ اور ہر چیز کی تفصیل لکھ دی ہے لہذا اسے مضبوطی کے ساتھ پکڑلو اور اپنی قوم کوحکم دو کہ اس کی اچھی اچھی باتوں کو لے لیں. میں عنقریب تمہیں فاسقین کے گھردکھلادوں گا\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mc{میں عنقریب اپنی آیتوں کی طرف سے ان لوگوں کو پھیر دوں گا جو روئے زمین میں ناحق اکڑتے پھرتے ہیں اور یہ کسی بھی نشانی کو دیکھ لیں ایمان لانے والے نہیں ہیں -ان کا حال یہ ہے کہ ہدایت کا راستہ دیکھیں گے تو اسے اپنا راستہ نہ بنائیں گے اور گمراہی کا راستہ دیکھیں گے تو اسے فورا اختیار کرلیں گے یہ سب اس لئے ہے کہ انہوں نے ہماری نشانیوں کو جھٹلایا ہے اوران کی طرف سے غافل تھے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mci{اور جن لوگوں نے ہماری نشانیوں اور آخرت کی ملاقات کو جھٹلایا ہے ان کے اعمال برباد ہیں اور ظاہر ہے کہ انھیں ویساہی بدلہ تو دیا جائے گا جیسے اعمال کررہے ہیں\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mcii{اور موسٰی علیھ السّلامکی قوم نے ان کے بعد اپنے زیورات سے گوسالہ کا مجسمہ بنایا جس میں آواز بھی تھی کیاان لوگوں نے نہیں دیکھا کہ وہ نہ بات کرنے کے لائق ہے اور نہ کوئی راستہ دکھا سکتا ہے انہوں نے اسے خدا بنالیا اور وہ لوگ واقعاظلم کرنے والے تھے\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mciii{اور جب وہ پچھتائے اور انہوں نے دیکھ لیا کہ وہ بہک گئے ہیں تو کہنے لگے کہ اگر ہمارا پروردگار ہمارے او پر رحم نہ کرے گا اور ہمیں معاف نہ کرے گا تو ہم خسارہ والوں میں شامل ہوجائیں گے\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mciv{اورجب موسٰی علیھ السّلاماپنی قوم کی طرف واپس آئے تو غیظ و غضب کے عالم میں کہنے لگے کہ تم نے میرے بعد بہت بفِی حرکت کی ہے -تم نے حکم خدا کے آنے میں کس قدر عجلت سے کام لیا ہے اور پھر انہوں نے توریت کی تختیوں کو ڈال دیا اور اپنے بھائی کا سرپکڑ کر کھینچنے لگے -ہارون علیھ السّلامنے کہا بھائی قوم نے مجھے کمزور بنادیا تھا اور قریب تھاکہ مجھے قتل کردیتے تو میں کیا کرتا -آپ دشمنوں کو طعنہ کا موقع نہ دیجئے اور میرا شمار ظالمین کے ساتھ نہ کیجئے\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mcv{موسٰی علیھ السّلامنے کہا کہ پروردگار مجھے اور میرے بھائی کو معاف کردے اور ہمیں اپنی رحمت میں داخل کرلے کہ تو سب سے زیادہ رحم کرنے والاہے\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mcvi{بیشک جن لوگوں نے گوسالہ کو اختیار کیا ہے عنقریب ان پر غضب پروردُگار نازل ہوگا اور ان کے لئے زندگانی دنیا میں بھی ذلّت ہے اور ہم اسی طرح افترا کرنے والوں کوسزا دیا کرتے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mcvii{اور جن لوگوں نے بفِے اعمال کئے اور پھر توبہ کرلی اور ایمان لے آئے تو توبہ کے بعد تمھارا پروردگار بہت بخشنے والا بڑا مہربان ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mcviii{اس کے بعد جب موسٰی کا غّصہ ٹھنڈا پڑگیا تو انہوں نے تختیوں کو اٹھالیا اور اس کے نسخہ میں ہدایت اور رحمت کی باتیں تھیں ان لوگوں کے لئے جو اپنے پروردگار سے ڈرنے والے تھے\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mcix{اور موسٰی علیھ السّلامنے ہمارے وعدہ کے لئے اپنی قوم کے ستر ّ افراد کا انتخاب کیا پھر اس کے بعد جب ایک جھٹکے نے انھیں اپنی لپیٹ میں لے لیا تو کہنے لگے کہ پرودگار اگر تو چاہتا تو انھیں پہلے ہی ہلاک کردیتا اور مجھے بھی -کیا اب احمقوں کی حرکت کی بناپرہمیں بھی ہلاک کردے گا یہ تو صرف تیرا امتحان ہے جس سے جس کو چاہتا ہے گمراہی میں چھوڑدیتا ہے اور جس کو چاہتا ہے ہدایت دے دیتا ہے تو ہمارا ولی ہے -ہمیں معاف کردے اورہم پر رحم فرما کہ تو بڑا بخشنے والا ہے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mcx{اور ہمارے لئے اس دار دنیا اور آخرت میں نیکی لکھ دے -ہم تیری ہی طرف رجوع کررہے ہیں -ارشاد ہوا کہ میرا عذاب جسے میں چاہوں گا اس تک پہنچے گا اور میری رحمت ہر شے پر وسیع ہے جسے میں عنقریب ان لوگوں کے لئے لکھ دوں گا جو خوف خدا رکھنے والے -زکوِٰادا کرنے والے اور ہماری نشانیوں پر ایمان لانے والے ہیں\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mcxi{جو لوگ کہ رسولِ نبی امّی کا اتباع کرتے ہیں جس کا ذکر اپنے پاس توریت اور انجیل میں لکھا ہوا پاتے ہیں کہ وہ نیکیوں کا حکم دیتا ہے اور برائیوں سے روکتا ہے اور پاکیزہ چیزوں کو حلال قرار دیتاہے اور خبیث چیزوں کو حرام قرار دیتا ہے اور ان پر سے احکام کے سنگین بوجھ اور قیدوبند کو اٹھا دیتا ہے پس جو لوگ اس پر ایمان لائے اس کا احترام کیا اس کی امداد کی اور اس نور کا اتباع کیا جو اس کے ساتھ نازل ہوا ہے وہی درحقیقت فلاح یافتہ اور کامیاب ہیں\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mcxii{پیغمبر ----- کہہ دو کہ میں تم سب کی طرف اس اللہ کا رسول اور نمائندہ ہوں جس کے لئے زمین وآسمان کی مملکت ہے-اس کے علاوہ کوئی خدا نہیں ہے -وہی حیات دیتا ہے اور وہی موت دیتاہے لہٰذا اللہ اور اس کے پیغمبرامی ّپر ایمان لے آؤ جو اللہ اور اس کے کلمات پر ایمان رکھتا ہے اور اسی کا اتباع کرو کہ شاید اسی طرح ہدایت یافتہ ہوجاؤ\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mcxiii{اور موسٰی علیھ السّلام کی قوم میں سے ایک ایسی جماعت بھی ہے جو حق کے ساتھ ہدایت کرتی ہے اور معاملات میں حق وانصاف کے ساتھ کام کرتی ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mcxiv{اور ہم نے بنی اسرائیل کو یعقوب علیھ السّلام کی بارہ اولاد کے بارہ حصّو ں پر تقسیم کردیا اور موسٰی علیھ السّلام کی طرف وحی کی جب ان کی قوم نے پانی کا مطالبہ کیا کہ زمین پر عصا ماردو -انہوں نے عصا ماراتو بارہ چشمے جاری ہوگئے اس طرح کہ ہر گردہ نے اپنے گھاٹ کو پہچان لیا اور ہم نے ان کے سروں پر ابر کا سایہ کیااور ان پر من و سلوٰی جیسی نعمت نازل کی کہ ہمارے دیئے ہوئے پاکیزہ رزق کو کھاؤ اور ان لوگوں نے مخالفت کرکے ہمارے اوپر ظلم نہیں کیا بلکہ یہ اپنے ہی نفس پر ظلم کررہے تھے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mcxv{اور اس وقت کو یاد کرو جب ان سے کہاگیا کہ اس قریہ میں داخل ہوجاؤ اور جو چاہو کھاؤ لیکن حطّہ کہہ کر داخل ہونا اور داخل ہوتے وقت سجدہ کرتے ہوئے داخل ہونا تاکہ ہم تمھاری خطاؤں کو معاف کردیں کہ ہم عنقریب نیک عمل والوں کے اجر میںاضافہ بھی کردیں گے\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mcxvi{لیکن ظالموں نے جو انھیں بتایا گیا تھا اس کو بدل کرکچھ اور کہنا شروع کردیا تو ہم نے ان کے اوپر آسمان سے عذاب نازل کردیا کہ یہ فسق اور نافرمانی کررہے تھے\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mcxvii{اور ان سے اس قریہ کے بارے میں پوچھو جو سمندر کے کنارے تھا اور جس کے باشندے شنبہ کے بارے میں زیادتی سے کام لیتے تھے کہ ان کی مچھلیاں شنبہ کے دن سطح آب تک آجاتی تھیں اور دوسرے دن نہیں آتی تھیں تو انہوں نے حیلہ گری کرنا شروع کردی -ہم اسی طرح ان کا امتحان لیتے تھے کہ یہ لوگ فسق اور نافرمانی سے کام لے رہے تھے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mcxviii{اور جب ان کی ایک جماعت نے مصلحین سے کہا کہ تم کیوں ایسی قوم کو نصیحت کرتے ہو جسے اللہ ہلاک کرنے والا ہے یا اس پرشدید عذاب کرنے والا ہے تو انہوں نے کہا کہ ہم پروردگار کی بارگاہ میں عذرچاہتے ہیں اور شاید یہ لوگ متقی بن ہی جائیں\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mcxix{اس کے بعد جب انہوں نے یاد دہانی کو فراموش کردیا تو ہم نے برائیوں سے روکنے والوں کو بچالیا اور ظالموں کو ان کے فسق اور بدکرداری کی بنا پرسخت ترین عذاب کی گرفت میں لے لیا\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mcxx{پھر جب دوبارہ ممانعت کے باوجود سرکشی کی تو ہم نے حکم دے دیا کہ اب ذلّت کے ساتھ بندر بن جاؤ\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mcxxi{اور اس وقت کو یاد کرو جب تمھارے پروردگار نے علی الاعلان کہہ دیا کہ قیامت تک ان پر ایسے افراد مسلّط کئے جائیں گے جو انھیں بدترین سختیوں میں مبتلا کریں گے کہ تمھارا پروردگار جلدی عذاب کرنے والا بھی ہے اور بہت زیادہ بخشنے والا مہربان بھی ہے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mcxxii{اورہم نے بنیاسرائیل کو مختلف ٹکڑوں میں تقسیم کردیا بعض نیک کردار تھے اور بعض اس کے خلاف -اور ہم نے انھیں آرام اور سختی کے ذریعہ آزمایا کہ شاید راستہ پر آجائیں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mcxxiii{اس کے بعد ان میں ایک نسل پیدا ہوئی جو کتاب کی وراث تو بنی لیکن دنیا کا ہر مال لیتی رہی اور یہ کہتی رہی کہ عنقریب ہمیں بخش دیا جائے گا اور پھر ویسا ہی مال مل گیا تو پھر لے لیا تو کیا ان سے کتاب کا عہد نہیں لیا گیا کہ خبردار خدا کے بارے میں حق کے علاوہ کچھ نہ کہیں اور انہوں نے کتاب کو پڑھا بھی ہے اور دار آخرت ہی صاحبان هتقویٰ کے لئے بہترین ہے کیا تمھاری سمجھ میں نہیں آتا ہے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mcxxiv{اور جو لوگ کتاب سے تمسک کرتے ہیں اور انہوں نے نماز قائم کی ہے توہم صالح اورنیک کردار لوگوں کے اجر کو ضائع نہیں کرتے ہیں\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mcxxv{اور اس وقت کو یاد دلِاؤ جب ہم نے پہاڑ کو ایک سائبان کی طرح ان کے سروں پر معلّق کردیا اور انہوں نے گمان کرلیا کہ یہ اب گرنے والا ہے تو ہم نے کہا کہ توریت کو مضبوطی کے ساتھ پکڑو اور جو کچھ اس میں ہے اسے یاد کرو شاید اس طرح متقی اور پرہیزگار بن جاؤ\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mcxxvi{اور جب تمھارے پروردگار نے فرزند ان آدم علیھ السّلامکی پشتوں سے انکی ذرّیت کو لے کر انھیںخود ان کے اوپر گواہ بناکر سوال کیا کہ کیا میں تمھارا خدا نہیں ہوں تو سب نے کہا بیشک ہم اس کے گواہ ہیں -یہ عہد اس لئے لیا کہ روز هقیامت یہ نہ کہہ سکو کہ ہم اس عہد سے غافل تھے\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mcxxvii{یا یہ کہہ دو کہ ہم سے پہلے ہمارے بزرگوں نے شرک کیا تھا اور ہم صرف ان کی اولاد میں تھے تو کیا اہل باطل کے اعمال کی بنا پر ہم کو ہلاک کردے گا\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mcxxviii{اور اسی طرح ہم آیتوں کو مفّصل بیان کرتے ہیں اور شاید یہ لوگ پلٹ کرآجائیں\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mcxxix{اور انھیں اس شخص کی خبر سنائیے جس کو ہم نے اپنی آیتیں عطا کیں پھر وہ ان سے بالکل الگ ہوگیا اور شیطان نے اس کا پیچھا پکڑلیا تو وہ گمراہوں میں ہوگیا\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mcxxx{اور اگر ہم چاہتے تو اسے ان ہی آیتوں کے سبب بلند کردیتے لیکن وہ خود زمین کی طرف جھک گیا اور اس نے خواہشات کی پیروی اختیار کرلی تو اب اس کی مثال کِتّے جیسی ہے کہ اس پر حملہ کرو توبھی زبان نکالے رہے اور چھوڑ دو تو بھی زبان نکالے رہے -یہ اس قوم کی مثال ہے جس نے ہماری آیات کی تکذیب کی تو اب آپ ان قصّوں کو بیان کریں کہ شاید یہ غور وفکر کرنے لگیں\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mcxxxi{کس قدر بفِی مثال ہے اس قوم کی جس نے ہماری آیات کی تکذیب کی اور وہ لوگ اپنے ہی نفس پرظلم کررہے تھے\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mcxxxii{جس کو خدا ہدایت دے دے ہدایت یافتہ ہے اور جس کو گمراہی میں چھوڑدے وہی خسارہ والوں میں ہے\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mcxxxiii{اور یقینا ہم نے انسان و جنات کی ایک کثیر تعداد کو گویا جہّنم کے لئے پیدا کیا ہے کہ ان کے پاس دل ہیں مگر سمجھتے نہیں ہیں اور آنکھیں ہیں مگر دیکھتے نہیں ہیں اور کان ہیں مگر سنتے نہیں ہیں -یہ چوپایوں جیسے ہیں بلکہ ان سے بھی زیادہ گمراہ ہیں اور یہی لوگ اصل میں غافل ہیں\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mcxxxiv{اور اللہ ہی کے لئے بہترین نام ہیں لہذا اسے ان ہی کے ذریعہ پکارو اور ان لوگوں کو چھوڑ دو جو اس کے ناموں میں بے دینی سے کام لیتے ہیں عنقریب انہیں ان کے اعمال کا بدلہ دیا جائے گا\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mcxxxv{اور ہماری مخلوقات ہی میں سے وہ قوم بھی ہے جو حق کے ساتھ ہدایت کرتی ہے اور حق ہی کے ساتھ انصاف کرتی ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mcxxxvi{اور جن لوگوں نے ہماری آیات کی تکذیب کی ہم انہیں عنقریب اس طرح لپیٹ لیں گے کہ انہیں معلوم بھی نہ ہوگا\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mcxxxvii{اور ہم تو انہیں ڈھیل دے رہے ہیں کہ ہماری تدبیر بہت مستحکم ہوتی ہے\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mcxxxviii{اور کیا ان لوگوں نے یہ غور نہیں کیا کہ ان کے ساتھی پیغمبر میں کسی طرح کا جنون نہیں ہے -وہ صرف واضح طور سے عذاب الٰہی سے ڈرانے والا ہے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mcxxxix{اور کیا ان لوگوں نے زمین و آسمان کی حکومت اور خدا کی تمام مخلوقات میں غور نہیں کیا اور یہ کہ شاید ان کی اجل قریب آگئی ہو تو یہ اس کے بعد کس بات پر ایمان لے آئیں گے\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mcxl{جسے خدا ہی گمراہی میں چھوڑ دے اس کا کوئی ہدایت کرنے والا نہیں ہے اور وہ انہیں سرکشی میں چھوڑ دیتا ہے کہ ٹھوکریں کھاتے پھریں\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mcxli{پیغمبر !یہ آپ سے قیامت کے بارے میں سوال کرتے ہیں کہ اس کا ٹھکانا کب ہے تو کہہ دیجئے کہ اس کا علم میرے پروردگار کے پاس ہے وہی اس کو بروقت ظاہر کرے گا یہ قیامت زمین و آسمان دونوں کے لئے بہت گراں ہے اور تمہارے پاس اچانک آنے والی ہے یہ لوگ آپ سے اس طرح سوال کرتے ہیں گویا آپ کو اس کی مکمل فکر ہے تو کہہ دیجئے کہ اس کا علم اللہ کے پاس ہے لیکن اکثر لوگوں کو اس کا علم بھی نہیں ہے\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mcxlii{آپ کہہ دیجئے کہ میں خود بھی اپنے نفس کے نفع و نقصان کا اختیارنہیں رکھتا ہوں مگر جو خد اچاہے اور اگر میں غیب سے باخبر ہوتا تو بہت زیادہ خیر انجام دیتا اور کوئی برائی مجھ تک نہ آسکتی -میں تو صرف صاحبان هایمان کے لئے بشارت دینے والا اور عذاب الٰہی سے ڈرنے والا ہوں\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mcxliii{وہی خد اہے جس نے تم سب کو ایک نفس سے پیدا کیا ہے اور پھر اسی سے اس کا جوڑا بنایا ہے تاکہ اس سے سکون حاصل ہو اس کے بعد شوہر نے زوجہ سے مقاربت کی تو ہلکا سا حمل پید اہوا جسے وہ لئے پھرتی رہی پھر حمل بھاری ہوا اور وقت ولادت قریب آیا تو دونوں نے پروردگار سے دعا کی کہ اگر ہم کو صالح اولاد دے دے گا تو ہم تیرے شکر گزار بندوں میں ہوں گے\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mcxliv{اس کے بعد جب اس نے صُالح فرزند دے دیا تو اللہ کی عطا میں اس کا شریک قرار دے دیا جب کہ خدا ان شریکوں سے کہیں زیادہ بلند و برتر ہے\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mcxlv{کیا یہ لوگ انہیں شریک بناتے ہیں جو کوئی شے خلق نہیں کرسکتے اور خود بھی مخلوق ہیں\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mcxlvi{اور ان کے اختیار میں خود اپنی مدد بھی نہیں ہے اور وہ کسی کی نصرت بھی نہیں کرسکتے ہیں\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mcxlvii{اور اگر آپ انہیں ہدایت کی طرف دعوت دیں تو ساتھ بھی نہ آئیں گے ان کے لئے سب برابر ہے انہیں بلائیں یا چپ رہ جائیں\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mcxlviii{تم لوگ جن لوگوں کو اللہ کو چھوڑ کر پکارتے ہو سب تم ہی جیسے بندے ہیں لہذا تم انہیں بلاؤ اور وہ تمہاری آواز پر لبیک کہیں اگر تم اپنے خیال میں سچےّ ہو\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mcxlix{کیا ان کے پاس چلنے کے قابل پیر -حملہ کرنے کے قابل ہاتھ ,دیکھنے کے قابل آنکھیں اور سننے کے لائق کان ہیں جن سے کام لے سکیں -آپ کہہ دیجئے کہ تم لوگ اپنے شرکائ کو بلاؤ اور جو مکر کرنا چاہتے ہو کرو اور ہرگز مجھے مہلت نہ دو (دیکھوں تم کیا کرسکتے ہو\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mcl{بیشک میرا مالک و مختار وہ خداہے جس نے کتاب نازل کی ہے اور وہ نیک بندوں کا والی و وارث ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mcli{اور اسے چھوڑ کر تم جنہیں پکارتے ہو وہ نہ تمہاری مدد کرسکتے ہیں اور نہ اپنے ہی کام آسکتے ہیں\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mclii{اگر تم ان کو ہدایت کی دعوت دو گے تو سن بھی نہ سکیں گے اور دیکھو گے تو ایسالگے گا جیسے تمہاری ہی طرف دیکھ رہے ہیں حالانکہ دیکھنے کے لائق بھی نہیں ہیں\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mcliii{آپ عفو کا راستہ اختیار کریں نیکی کا حکم دیں اور جاہلوں سے کنارہ کشی کریں\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mcliv{اور اگر شیطان کی طرف سے کوئی غلط خیال پیدا کیا جائے تو خدا کی پناہ مانگیں کہ وہ ہر شے کا سننے والا اور جاننے والا ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mclv{جو لوگ صاحبان هتقویٰ ہیں جب شیطان کی طرف سے کوئی خیال چھونا بھی چاہتا ہے تو خدا کو یاد کرتے ہیں اور حقائق کو دیکھنے لگتے ہیں\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mclvi{اور مشرکین کے برادران شیاطین انہیں گمراہی میں کھینچ رہے ہیں اور اس میں کوئی کوتاہی نہیں کرتے ہیں\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mclvii{اور اگر آپ ان کے پاس کوئی نشانی نہ لائیں تو کہتے ہیں کہ خود آپ کیوں نہیں منتخب کرلیتے تو کہہ دیجئے کہ میں تو صرف وحی پروردگار کا اتباع کرتا ہوں -یہ قران تمہارے پروردگار کی طرف سے دلائل ہدایت اور صاحبان هایمان کے لئے رحمت کی حیثیت رکھتا ہے\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mclviii{اور جب قرآن کی تلاوت کی جائے تو خاموش ہوکر غور سے سنو کہ شاید تم پر رحمت نازل ہوجائے\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mclix{اور خدا کو اپنے دل ہی دل میں تضرع اور خوف کے ساتھ یاد کرو اور قول کے اعتبار سے بھی اسے کم بلند آواز سے صبح و شام یاد کرو اور خبردار غافلوں میں نہ ہوجاؤ\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mclx{جو لوگ اللہ کی بارگاہ میں مقرب ہیں وہ اس کی عبادت سے تکبر نہیں کرتے ہیں اور اسی کی بارگاہ میں سجدہ ریز رہتے ہیں\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mclxi{\basmalahur پیغمبر یہ لوگ آپ سے انفال کے بارے میں سوال کرتے ہیں تو آپ کہہ دیجئے کہ انفال سب اللہ اور رسول کے لئے ہیں لہٰذا تم لوگ اللہ سے ڈرو اور آپس میں اصلاح کرو اور اللہ و رسول کی اطاعت کرو اگر تم اس پر ایمان رکھنے والے ہو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mclxii{صاحبان هایمان درحقیقت وہ لوگ ہیں جن کے سامنے ذکر خدا کیا جائے تو ان کے دلوں میں خورِ خدا پیدا ہو اور اس کی آیتوں کی تلاوت کی جائے تو ان کے ایمان میں اضافہ ہوجائے اور وہ لوگ اللہ ہی پر توکل کرتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mclxiii{وہ لوگ نماز قائم کرتے ہیں اور ہمارے دئیے ہوئے رزق میں سے انفاق بھی کرتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mclxiv{یہی لوگ حقیقتاصاحب هایمان ہیں اور ان ہی کے لئے پروردگار کے یہاں درجات اور مغفرت اور باعزّت روزی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mclxv{جس طرح تمہارے رب نے تمہیں تمہارے گھر سے حق کے ساتھ برآمد کیا اگرچہ مومنین کی ایک جماعت اسے ناپسند کررہی تھی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mclxvi{یہ لوگ آپ سے حق کے واضح ہوجانے کے بعد بھی اس کے بارے میں بحث کرتے ہیں جیسے کہ موت کی طرف ہنکائے جارہے ہوں اور حسرت سے دیکھ رہے ہوں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mclxvii{اور اس وقت کو یاد کرو جب کہ خدا تم سے وعدہ کررہا تھا کہ دو گروہوں میں سے ایک تمہارے لئے بہرحال ہے اور تم چاہتے تھے کہ وہ طاقت والا گروہ نہ ہو اور اللہ اپنے کلمات کے ذریعہ حق کو ثابت کرنا چاہتا ہے اور کفاّر کے سلسلہ کو قطع کردینا چاہتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mclxviii{تاکہ حق ثابت ہوجائے اور باطل فنا ہوجائے چاہے مجرمین اسے کسی قدر اِرا کیوں نہ سمجھیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mclxix{جب تم پروردگار سے فریاد کررہے تھے تو اس نے تمہاری فریاد سن لی کہ میں ایک ہزار ملائکہ سے تمہاری مدد کررہا ہوں جو برابر ایک کے پیچھے ایک آرہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mclxx{اور اسے ہم نے صرف ایک بشارت قرار دیا تاکہ تمہارے دل مطمئن ہوجائیں اور مدد تو صرف اللہ ہی کی طرف سے ہے -اللہ ہی صاحب هعزّت اور صاحب هحکمت ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mclxxi{جس وقت خدا تم پر نیند غالب کررہا تھا جو تمہارے لئے باعث سکون تھی اور آسمان سے پانی نازل کررہا تھا تاکہ تمہیں پاکیزہ بنادے اور تم سے شیطان کی کثافت کو دور کردے اور تمہارے دلوں کو مطمئن بنادے اور تمہارے قدموں کو ثبات عطا کردے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mclxxii{جب تمہارا پروردگار ملائکہ کو وحی کررہاتھا کہ میں تمہارے ساتھ ہوں لہٰذا تم صاحبان هایمان کو ثبات قدم عطا کرو میں عنقریب کفاّ رکے دلوں میں رعب پیداکردوں گا لہذا تم کفاّر کی گردن کو مار دو اور ان کی تمام انگلیوں کے پُور پُور کاٹ دو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mclxxiii{یہ اس لئے ہے کہ ان لوگوں نے خدا و رسول کی مخالفت کی ہے اور جو خدا و رسول کی مخالفت کرے گا تو خدا اس کے لئے سخت عذاب کرنے والا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mclxxiv{یہ تو دنیا کی سزا ہے جسے یہاں چکھو اور اس کے بعد کافروں کے لئے جہّنمکا عذاب بھی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mclxxv{اے ایمان والو جب کفاّر سے میدان هجنگ میں ملاقات کرو تو خبردار انہیں پیٹھ نہ دکھانا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mclxxvi{اور جو آج کے دن پیٹھ دکھائے گا وہ غضب الٰہی کا حق دار ہوگا اور اس کا ٹھکانا جہّنم ّہوگا جو بدترین انجام ہے علاوہ ان لوگوں کے جو جنگی حکمت علمی کی بنا پر پیچھے ہٹ جائیں یا کسی دوسرے گروہ کی پناہ لینے کے لئے اپنی جگہ چھوڑ دیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mclxxvii{پس تم لوگوں نے ان کفاّر کو قتل نہیں کیا بلکہ خدا نے قتل کیا ہے اور پیغمبرآپ نے سنگریزے نہیں پھینکے ہیں بلکہ خدا نے پھینکے ہیں تاکہ صاحبان هایمان پر خوب اچھی طرح احسان کردے کہ وہ سب کی سننے والا اور سب کا حال جاننے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mclxxviii{یہ تو یہ احسان ہے اور خدا کفاّر کے مکر کو کمزور بنانے والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mclxxix{اگر تم لوگ فتح چاہتے ہو تو یہ فتح آگئی اور اگر تم جنگ سے باز آجاؤ تو اس میں تمہارے لئے بھلائی ہے اور اگر دوبارہ ایسا کرو گے تو ہم بھی پلٹ کر آرہے ہیں اور تمہارا گروہ کتنا ہی بڑ اکیوں نہ ہو کام آنے والا نہیں ہے اور اللہ ہمیشہ صاحبان هایمان کے ساتھ ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mclxxx{ایمان والو اللہ و رسول کی اطاعت کرو اور اس سے رو گردانی نہ کرو جب کہ تم صَن بھی رہے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mclxxxi{اور ان لوگوں جیسے نہ ہوجاؤ جو یہ کہتے ہیں کہ ہم نے سنا حالانکہ وہ کچھ نہیں سن رہے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mclxxxii{اللہ کے نزدیک بد ترین زمین پر چلنے والے وہ بہرے اور گونگے ہیں جو عقل سے کام نہیں لیتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mclxxxiii{اور اگر خدا ان میں کسی خیر کو دیکھتا تو انہیں ضرور سناتا اور اگر سنا بھی دیتا تو یہ منہ پھرا لیتے اور اعراض سے کام لیتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mclxxxiv{اے ایمان والو اللہ و رسول کی آواز پر لبیک کہو جب وہ تمہیں اس امر کی طرف دعوت دیں جس میں تمہاری زندگی ہے اور یاد رکھو کہ خدا انسان اور اس کے دل کے درمیان حائل ہوجاتا ہے اور تم سب اسی کی طرف حاضر کئے جاؤ گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mclxxxv{اور اس فتنہ سے بچو جو صرف ظالمین کو پہنچنے والا نہیں ہے اور یاد رکھو کہ اللہ سخت ترین عذاب کا مالک ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mclxxxvi{مسلمانو !اس وقت کو یاد کرو جب تم مکّہ میں قلیل تعداد میں اور کمزور تھے -تم ہر آن ڈرتے تھے کہ لوگ تمہیں اچک لے جائیں گے کہ خد انے تمہیں پناہ دی اور اپنی مدد سے تمہاری تائید کی -تمہیں پاکیزہ روزی عطا کی تاکہ تم اس کا شکریہ ادا کرو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mclxxxvii{ایمان والو خدا و رسول اور اپنی امانتوں کے بارے میں خیانت نہ کرو جب کہ تم جانتے بھی ہو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mclxxxviii{اور جان لو کہ یہ تمہاری اولاد اور تمہارے اموال ایک آزمائش ہیں اور خدا کے پاس اجر عظیم ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mclxxxix{ایمان والو اگر تم تقوٰی الٰہی اختیار کرو گے تو وہ تمہیں حق و باطل میں تفرقہ کی صلاحیت عطا کردے گا -تمہاری برائیوں کی پردہ پوشی کرے گا -تمہارے گناہوں کو معاف کردے گا کہ وہ بڑا فضل کرنے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcxc{اور پیغمبرآپ اس وقت کو یاد کریں جب کفار تدبیریں کرتے تھے کہ آپ کو قید کرلیں یا شہر بدر کردیں یا قتل کردیں اور ان کی تدبیروں کے ساتھ خدا بھی اس کے خلاف انتظام کررہا تھا اور وہ بہترین انتظام کرنے والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcxci{اور ان کا یہ حال ہے کہ جب ہماری آیتوں کی تلاوت کی جاتی ہے تو کہتے ہیں کہ سن لیا -ہم خود بھی چاہیں تو ایسا ہی کہہ سکتے ہیں یہ تو صرف پچھلے لوگوں کی داستانیں ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcxcii{اور اس وقت کو یاد کرو جب انہوں نے کہا کہ خدایا اگر یہ تیری طرف سے حق ہے تو ہم پر آسمان سے پتھر برسادے یا عذاب الیم نازل کردے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcxciii{حالانکہ اللہ ان پر اس وقت تک عذاب نہ کرے گا جب تک« پیغمبر مِ آپ ان کے درمیان ہیں اور خدا ان پر عذاب کرنے والا نہیں ہے اگر یہ توبہ اور استغفار کرنے والے ہوجائیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcxciv{اور ان کے لئے کون سی بات ہے کہ خدا ان پر عذاب نہ کرے جب کہ یہ لوگوں کو مسجد الحرام سے روکتے ہیں اور اس کے متولی بھی نہیں ہیں -اس کے ولی صرف متقی اور پرہیزگار افراد ہیں لیکن ان کی اکثریت اس سے بھی بے خبر ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcxcv{ان کی تو نماز بھی مسجد الحرام کے پاس صرف تالی اور سیٹی ہے لہذا اب تم لوگ اپنے کفر کی بنا پر عذاب کا مزہ چکھو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcxcvi{جن لوگوں نے کفر اختیار کیا یہ اپنے اموال کو صرف اس لئے خرچ کرتے ہیں کہ لوگوں کو راسِ خدا سے روکیں تو یہ خرچ بھی کریں گے اور اس کے بعدیہ بات ان کے لئے حسرت بھی بنے گی اور آخر میں مغلوب بھی ہوجائیں گے اور جن لوگوں نے کفر اختیار کیا یہ سب جہّنم کی طرف لے جائے جائیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcxcvii{تاکہ خدا خبیث کو پاکیزہ سے الگ کردے اور پھر خبیث کو ایک پر ایک رکھ کر ڈھیر بنادے اور سب کو اکٹھا جہّنم میں جھونک دے کہ یہی لوگ خسارہ اور گھاٹے والے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcxcviii{پیغمبر آپ کافروں سے کہہ دیجئے کہ اگر یہ لوگ اپنے کفر سے باز آجائیں تو ان کے گزشتہ گناہ معاف کردئیے جائیں گے لیکن اگر پھر پلٹ گئے تو گزشتہ لوگوں کا طریقہ بھی گزر چکا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcxcix{اور تم لوگ ان کفاّر سے جہاد کرو یہاں تک کہ فتنہ کا وجود نہ رہ جائے اور سارا دین صرف اللہ کے لئے رہ جائے پھر اگر یہ لوگ باز آجائیں تو اللہ ان کے اعمال کا خوب دیکھنے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcc{اور اگر دوبارہ پلٹ جائیں تو یاد رکھو کہ خدا تمہارا مولا اور سرپرست ہے اور وہ بہترین مولا و مالک اور بہترین مددگار ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcci{اور یہ جان لو کہ تمہیں جس چیز سے بھی فائدہ حاصل ہو اس کا پانچواں حصہ اللہ , رسول ,رسول کے قرابتدار ,ایتام ,مساکین اور مسافران هغربت زدہ کے لئے ہے اگر تمہارا ایمان اللہ پر ہے اور اس نصرت پر ہے جو ہم نے اپنے بندے پر حق و باطل کے فیصلہ کے دن جب دو جماعتیں آپس میں ٹکرا رہی تھیں نازل کی تھی اور اللہ ہر شے پر قادر ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mccii{جب کہ تم وادی کے قریبی محاذ پر تھے اور وہ لوگ دور والے محاذ پر تھے اور قافلہ تم سے نشیب میں تھا اور اگر تم پہلے سے جہاد کے وعدہ پر نکلتے تو یقینا اس کے خلاف کرتے لیکن خدا ہونے والے امر کا فیصلہ کرنا چاہتا تھا تاکہ جو ہلاک ہو وہ دلیل کے ساتھ اور جو زندہ رہے وہ بھی دلیل کے ساتھ اور اللہ سب کی سننے والا اور سب کے حال هدل کا جاننے والا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcciii{جب خدا ان کو تمہاری نظروں میں کم کرکے دکھلا رہا تھا کہ اگر زیادہ دکھلا دیتا تو تم سست پڑ جاتے اور آپس ہی میں جھگڑا کرنے لگتے لیکن خدا نے تمہیں اس جھگڑے سے بچالیا کہ وہ دل کے رازوں سے بھی باخبر ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcciv{اور جب خدا مقابلہ کے وقت تمہاری نظروں میں دشمنوں کو کم دکھلا رہا تھا اور ان کی نظروں میں تمہیں کم کرکے دکھلا رہا تھا تاکہ اس امر کا فیصلہ کردے جو ہونے والا تھا اور سارے امور کی بازگشت اللہ ہی کی طرف ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mccv{ایمان والو جب کسی گروہ سے مقابلہ کرو تو ثبات هقدم سے کام لو اور اللہ کو بہت یاد کرو کہ شاید اسی طرح کامیابی حاصل کرلو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mccvi{اور اللہ اور اس کے رسول کی اطاعت کرو اور آپس میں اختلاف نہ کرو کہ کمزور پڑ جاؤ اور تمہاری ہوا بگڑ جائے اور صبر کرو کہ اللہ صبر کرنے والوں کے ساتھ ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mccvii{اور ان لوگوں جیسے نہ ہوجاؤ جو اپنے گھروں سے اتراتے ہوئے اور لوگوں کو دکھانے کے لئے نکلے اور راہ هخدا سے روکتے رہے کہ اللہ ان کے اعمال کا احاطہ کئے ہوئے ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mccviii{اور اس وقت کو یاد کرو جب شیطان نے ان کے لئے ان کے اعمال کو آراستہ کردیا اور کہا کہ آج کوئی تم پر غالب آنے والا نہیں ہے اور میں تمہارا مددگار ہوں -اس کے بعد جب دونوں گروہ آمنے سامنے آئے تو الٹے پاؤں بھاگ نکلا اور کہا کہ میں تم لوگوں سے بری ہوں میں وہ دیکھ رہا ہوں جو تم نہیں دیکھ رہے ہو اور میں اللہ سے ڈرتا ہوں کہ وہ سخت عذاب کرنے والا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mccix{جب منافقین اور جن کے دلوں میں کھوٹ تھا کہہ رہے تھے کہ ان لوگوں کو ان کے دین نے دھوکہ دیا ہے حالانکہ جو شخص اللہ پر اعتماد کرتا ہے تو خد اہر شے پر غالب آنے والا اور بڑی حکمت والا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mccx{کاش تم دیکھتے کہ جب فرشتے ان کی جان نکال رہے تھے اور ان کے منہ اور پیٹھ پر مارتے جاتے تھے کہ اب جہنّم کا مزہ چکھو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mccxi{یہ اس لئے کہ تمہارے پچھلے اعمال کا نتیجہ یہی ہے اور خدا اپنے بندوں پر ظلم کرنے والا نہیں ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mccxii{جو حال آلِ فرعون اور ان کے پہلے والوں کا تھا کہ انہوں نے آیااُ الٰہیہ کا انکار کیا تو خد انے انہیں ان کے گناہوں کی گرفت میں لے لیا کہ اللہ قوی بھی ہے اور شدید عذاب کرنے والا بھی ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mccxiii{یہ اس لئے کہ خدا کسی قوم کو دی ہوئی نعمت کو اس وقت تک نہیں بدلتا جب تک وہ خود اپنے تئیں تغیر نہ پیدا کردیں کہ خدا سننے والا بھی ہے اور جاننے والا بھی ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mccxiv{جس طرح آلِ فرعون اور ان کے پہلے والوں کا انجام ہوا کہ انہوں نے پروردگار کی آیات کا انکار کیا تو ہم نے ان کے گناہوں کی بنا پر انہیں ہلاک کردیا اور آل هفرعون کو غرق کردیا کہ یہ سب کے سب ظالم تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxv{زمین پر چلنے والوں میں بدترین افراد وہ ہیں جنہوں نے کفر اختیار کرلیا اور اب وہ ایمان لانے والے نہیں ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxvi{جن سے آپ نے عہد لیا اور اس کے بعد وہ ہر مرتبہ اپنے عہد کو توڑ دیتے ہیں اور خدا کا خوف نہیں کرتے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxvii{اگر وہ جنگ میں تمہارے قبضہ میں آجائیں تو انہیں اور ان کے پشتیبان سب کو نکال باہر کرو تاکہ عبرت حاصل کریں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxviii{اور اگر کسی قوم سے کسی خیانت یا بدعہدی کا خطرہ ہے تو آپ بھی ان کے عہد کو ان کی طرف پھینک دیں کہ اللہ خیانت کاروں کو دوست نہیں رکھتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxix{اور خبردار کافروں کو یہ خیال نہ ہو کہ وہ آگے بڑھ گئے وہ کبھی مسلمانوں کو عاجز نہیں کرسکتے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxx{اور تم سب ان کے مقابلہ کے لئے امکانی قوت اور گھوڑوں کی صف بندی کا انتظام کرو جس سے اللہ کے دشمن -اپنے دشمن اور ان کے علاوہ جن کو تم نہیں جانتے ہو اور اللہ جانتا ہے سب کو خوفزدہ کردو اور جو کچھ بھی راہ هخدا میں خرچ کرو گے سب پورا پورا ملے گا اور تم پر کسی طرح کا ظلم نہیں کیا جائے گا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxxi{اور اگر وہ صلح کی طرف مائل ہوں تو تم بھی جھک جاؤ اور اللہ پر بھروسہ کرو کہ وہ سب کچھ سننے والا اور جاننے والا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxxii{اور اگر یہ آپ کو دھوکہ دینا چاہیں گے تو خدا آپ کے لئے کافی ہے -اس نے آپ کی تائید ,اپنی نصرت اور صاحبان ه ایمان کے ذریعہ کی ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxxiii{اور ان کے دلوں میں محبّت پیدا کردی ہے کہ اگر آپ ساری دنیا خرچ کردیتے تو بھی ان کے دلوں میں باہمی الفت نہیں پیدا کرسکتے تھے لیکن خدا نے یہ الفت و محبّت پیدا کردی ہے کہ وہ ہر شے پر غالب اور صاحب هحکمت ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxxiv{اے پیغمبر آپ کے لئے خدا اور وہ مومنین کافی ہیں جو آپ کا اتباع کرنے والے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccxxv{اے پیغمبر آپ لوگوں کو جہاد پر آمادہ کریں اگر ان میں بیس بھی صبر کرنے والے ہوں گے تو دو سو پر غالب آجائیں گے اور اگر سو ہوں گے تو ہزاروں کافروں پر غالب آجائیں گے اس لئے کہ کفاّر سمجھدار قوم نہیں ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccxxvi{اب اللہ نے تمہارا بار ہلکا کردیا ہے اور اس نے دیکھ لیا ہے کہ تم میں کمزوری پائی جاتی ہے تو اگرتم میں سو بھی صبر کرنے والے ہوں گے تو دو سو پر غالب آجائیں گے اور اگر ہزار ہوں گے تو بحکم خدا دو ہزار پر غالب آجائیں گے اور اللہ صبر کرنے والوں کے ساتھ ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mccxxvii{کسی نبی کو یہ حق نہیں ہے کہ وہ قیدی بنا کر رکھے جب تک زمین میں جہاد کی سختیوں کا سامنا نہ کرے .تم لوگ تو صرف مال دنیا چاہتے ہو جب کہ اللہ آخرت چاہتا ہے اور وہی صاحبِ عزّت و حکمت ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccxxviii{اگر خدا کی طرف سے پہلے فیصلہ نہ ہوچکا ہوتا تو تم لوگوں نے جو فدیہ لے لیا تھا اس پر عذابِ عظیم نازل ہوجاتا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccxxix{پس اب جو مال غنیمت حاصل کرلیا ہے اسے کھاؤ کہ وہ حلال اور پاکیزہ ہے اور تقوٰی الٰہی اختیار کرو کہ اللہ بہت بخشنے والا اور مہربان ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mccxxx{اے پیغمبر اپنے ہاتھ کے قیدیوں سے کہہ دیجئے کہ اگر خدا تمہارے دلوں میں نیکی دیکھے گا تو جو مال تم سے لے لیا گیا ہے اس سے بہتر نیکی تمہیں عطا کردے گا اور تمہیں معاف کردے گا کہ وہ بڑا بخشنے والا اور مہربان ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mccxxxi{اور اگر یہ آپ سے خیانت کرنا چاہتے ہیں تو اس سے پہلے خدا سے خیانت کرچکے ہیں جس کے بعد خدا نے ان پر قابو عطا کردیا کہ وہ سب کچھ جاننے والا اور صاحبِ حکمت ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mccxxxii{بیشک جو لوگ ایمان لائے اور انہوں نے ہجرت کی اور راسِ خدا میں اپنے جان و مال سے جہاد کیا اور جنہوں نے پناہ دی اور مدد کی یہ سب آپس میں ایک دوسرے کے ولی ہیں اور جن لوگوں نے ایمان اختیار کرکے ہجرت نہیں کی ان کی ولایت سے آپ کا کوئی تعلق نہیں ہے جب تک ہجرت نہ کریں اور اگر دین کے معاملہ میں تم سے مدد مانگیں تو تمہارا فرض ہے کہ مدد کردو علاوہ اس قوم کے مقابلہ کے جس سے تمہارا معاہدہ ہوچکا ہے کہ اللہ تمہارے اعمال کو خوب دیکھنے والا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mccxxxiii{جو لوگ کفر والے ہیں وہ آپس میں ایک دوسرے کے مددگار ہیں اور اگر تم ایمان والوں کی مدد نہ کرو گے تو زمین میں فتنہ اور عظیم فساد برپا ہوجائے گا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mccxxxiv{اور جن لوگوں نے ایمان اختیار کیا اور ہجرت کی اور راسِ خدا میں جہاد کیا اور پناہ دی اور نصرت کی وہی درحقیقت واقعی مومن ہیں اور ان ہی کے لئے مغفرت اور باعزّت رزق ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mccxxxv{اور جو لوگ بعد میں ایمان لے آئے اور ہجرت کی اور آپ کے ساتھ جہاد کیا وہ بھی تم ہی میں سے ہیں اور قرابتدار کتابِ خدا میں سب آپس میں ایک دوسرے سے زیادہ اوّلیت اور قربت رکھتے ہیں بیشک اللہ ہر شے کا بہترین جاننے والا ہے.\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mccxxxvi{\basmalahur مسلمانو جن مشرکین سے تم نے عہد و پیمان کیا تھا اب ان سے خدا و رسول کی طرف سے مکمل بیزاری کا اعلان ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccxxxvii{لہذا کافرو !چار مہینے تک آزادی سے زمین میں سیر کرو اور یہ یاد رکھو کہ خدا سے بچ کر نہیں جاسکتے اور خدا کافروں کو ذلیل کرنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccxxxviii{اور اللہ و رسول کی طرف سے حج اکبر کے دن انسانوں کے لئے اعلانِ عام ہے کہ اللہ اور اس کے رسول دونوں مشرکین سے بیزار ہیں لہذا اگر تم توبہ کرلو گے تو تمہارے حق میں بہتر ہے اور اگر انحراف کیا تو یاد رکھنا کہ تم اللہ کو عاجز نہیں کرسکتے ہو اور پیغمبر آپ کافروں کو دردناک عذاب کی بشارت دے دیجئے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccxxxix{علاوہ ان افراد کے جن سے تم مسلمانوں نے معاہدہ کررکھا ہے اور انہوں نے کوئی کوتاہی نہیں کی ہے اور تمہارے خلاف ایک دوسرے کی مدد نہیں کی ہے تو چار مہینے کے بجائے جو مدّت طے کی ہے اس وقت تک عہد کو پورا کرو کہ خدا تقویٰ اختیار کرنے والوں کو دوست رکھتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccxl{پھر جب یہ محترم مہینے گزر جائیں تو کفاّر کو جہاں پاؤ قتل کردو اور گرفت میں لے لو اور قید کردو اور ہر راستہ اور گزر گاہ پر ان کے لئے بیٹھ جاؤ اور راستہ تنگ کردو -پھر اگر توبہ کرلیں اور نماز قائم کریں اور زکوِٰادا کریں تو ان کا راستہ چھوڑ دو کہ خدا بڑا بخشنے والا اور مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccxli{اور اگر مشرکین میں کوئی تم سے پناہ مانگے تو اسے پناہ دے دو تاکہ وہ کتاب هخدا صَنے اس کے بعد اسے آزاد کرکے جہاں اس کی پناہ گاہ ہو وہاں تک پہنچا دو اور یہ مراعات اس لئے ہے کہ یہ جاہل قوم حقائق سے آشنا نہیں ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccxlii{اللہ و رسول کے نزدیک عہد شکن مشرکین کا کوئی عہد و پیمان کس طرح قائم رہ سکتا ہے ہاں اگر تم لوگوں نے کسی سے مسجد الحرام کے نزدیک عہد کرلیا ہے تو جب تک وہ لوگ اپنے عہد پر قائم رہیں تم بھی قائم رہو کہ اللہ متقی اور پرہیزگار افراد کو دوست رکھتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccxliii{ان کے ساتھ کس طرح رعایت کی جائے جب کہ یہ تم پر غالب آجائیں تو نہ کسی ہمسائگی اور قرابت کی نگرانی کریں گے اور نہ کوئی عہد و پیمان دیکھیں گے - یہ تو صرف زبانی تم کو خوش کررہے ہیں ورنہ ان کا دل قطعی منکر ہے اور ان کی اکثریت فاسق اور بدعہد ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccxliv{انہوں نے آیات هالٰہیہ کے بدلے بہت تھوڑی منفعت کو لے لیا ہے اور اب راہ هخدا سے روک رہے ہیں -یہ بہت برا کام کررہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccxlv{یہ کسی مومن کے بارے میں کسی قرابت یا قول و اقرار کی پرواہ نہیں کرتے ہیں یہ صرف زیادتی کرنے والے لوگ ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccxlvi{پھر بھی اگر یہ توبہ کرلیں اور نماز قائم کریں اور زکوٰ ِ ادا کریں تو دین میں تمہارے بھائی ہیں اور ہم صاحبان هعلم کے لئے اپنی آیات کو تفصیل کے ساتھ بیان کرتے رہتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccxlvii{اور اگر یہ عہد کے بعد بھی اپنی قسموں کو توڑ دیں اور دین میں طعنہ زنی کریں تو کفر کے سربراہوں سے کھل کر جہاد کرو کہ ان کی قسموں کا کوئی اعتبار نہیں ہے شاید یہ اسی طرح اپنی حرکتوں سے باز آجائیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccxlviii{کیا تم اس قوم سے جہاد نہ کرو گے جس نے اپنے عہد و پیمان کو توڑ دیا ہے اور رسول کو وطن سے نکال دینے کا ارادہ بھی کرلیا ہے اور تمہارے مقابلہ میں مظالم کی پہل بھی کی ہے -کیا تم ان سے ڈرتے ہو تو خدا زیادہ حقدار ہے کہ اس کا خوف پیدا کرو اگر تم صاحب ه ایمان ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccxlix{ان سے جنگ کرو اللہ انہیں تمہارے ہاتھوں سے سزا دے گا اور رسوا کرے گا اور تمہیں ان پر فتح عطا کرے گا اور صاحب ایمان قوم کے دلوں کو ٹھنڈا کردے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccl{اور ان کے دلوں کا غصّہ دور کردے گا اور اللہ جس کی توبہ کو چاہتا ہے قبول کرلیتا ہے کہ وہ صاحبِ علم بھی ہے اور صاحب هحکمت بھی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccli{کیا تمہارا خیال یہ ہے کہ تم کو اسی طرح چھوڑ دیا جائے گا جب کہ اللہ نے ابھی یہ بھی نہیں دیکھا ہے کہ تم میں جہاد کرنے والے کون لوگ ہیں جنہوں نے خدا -رسول اور صاحبان ایمان کو چھوڑ کر کسی کو دوست نہیں بنایا ہے اور اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcclii{یہ کام مشرکین کا نہیں ہے کہ وہ مساجد خدا کو آباد کریں جب کہ وہ خود اپنے نفس کے کفر کے گواہ ہیں -ان کے اعمال برباد ہیں اور وہ جہّنم میں ہمیشہ رہنے والے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccliii{اللہ کی مسجدوں کو صرف وہ لوگ آباد کرتے ہیں جن کا ایمان اللہ اور روز آخرت پر ہے اور جنہوں نے نماز قائم کی ہے زکوِٰادا کی ہے اور سوائے خدا کے کسی سے نہیں ڈرے یہی وہ لوگ ہیں جو عنقریب ہدایت یافتہ لوگوں میں شمار کئے جائیں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccliv{کیا تم نے حاجیوں کے پانی پلانے اور مسجد الحرام کی آبادی کو اس کا جیسا سمجھ لیا ہے جو اللہ اور آخرت پر ایمان رکھتا ہے اور راسِ خدا میں جہاد کرتا ہے -ہرگز یہ دونوں اللہ کے نزدیک برابر نہیں ہوسکتے اور اللہ ظالم قوم کی ہدایت نہیں کرتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcclv{بیشک جو لوگ ایمان لے آئے اور انہوں نے ہجرت کی اور راہ خدا میں جان اور مال سے جہاد کیا وہ اللہ کے نزدیک عظیم درجہ کے مالک ہیں اور درحقیقت وہی کامیاب بھی ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcclvi{اللہ ان کو اپنی رحمت ,رضامندی اور باغات کی بشارت دیتا ہے جہاں ان کے لئے دائمی نعمتیں ہوں گی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcclvii{وہ ان ہی باغات میں ہمیشہ رہیں گے کہ اللہ کے پاس عظیم ترین اجر ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcclviii{ایمان والو خبردار اپنے باپ دادا اور بھائیوں کو اپنا دوست نہ بناؤ اگر وہ ایمان کے مقابلہ میں کفر کو دوست رکھتے ہوں اور جو شخص بھی ایسے لوگوں کو اپنا دوست بنائے گا وہ ظالموں میں شمار ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcclix{پیغمبرآپ کہہ دیجئے کہ اگر تمہارے باپ داداً اولادً برادران ,ازواج ,عشیرہ و قبیلہ اور وہ اموال جنہیں تم نے جمع کیا ہے اور وہ تجارت جس کے خسارہ کی طرف سے فکرمند رہتے ہو اور وہ مکانات جنہیں پسند کرتے ہو تمہاری نگاہ میں اللہ ًاس کے رسول اور راہ هخدا میں جہاد سے زیادہ محبوب ہیں تو وقت کا انتظار کرو یہاں تک کہ امر الہی آجائے اور اللہ فاسق قوم کی ہدایت نہیں کرتا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcclx{بیشک اللہ نے کثیر مقامات پر تمہاری مدد کی ہے اور حنین کے دن بھی جب تمہیں اپنی کثرت پر ناز تھا لیکن اس نے تمہیں کوئی فائدہ نہیں پہنچایا اور تمہارے لئے زمین اپنی وسعتوں سمیت تنگ ہوگئی اور اس کے بعد تم پیٹھ پھیر کر بھاگ نکلے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcclxi{پھر اس کے بعد خدا نے اپنے رسول اور صاحبان هایمان پر سکون نازل کیا اور وہ لشکر بھیجے جنہیں تم نے نہیں دیکھا اور کفر اختیار کرنے والوں پر عذاب نازل کیا یہی کافرین کی جزا اور ان کا انجام ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcclxii{اس کے بعد خدا جس کی چاہے گا توبہ قبول کرلے گا وہ بڑا بخشنے والا مہربان ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcclxiii{ایمان والو !مشرکین صررِ نجاست ہیں لہذا خبردار اس سال کے بعد مسجدالحرام میں داخل نہ ہونے پائیں اور اگر تمہیں غربت کا خوف ہے تو عنقریب خدا چاہے گا تو اپنے فضل و کرم سے تمہیں غنی بنادے گا کہ وہ صاحب هعلم بھی ہے اور صاحب هحکمت بھی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcclxiv{ان لوگوں سے جہاد کرو جو خدا اور روز هآخرت پر ایمان نہیں رکھتے اور جس چیز کو خدا و رسول نے حرام قرار دیا ہے اسے حرام نہیں سمجھتے اور اہل کتاب ہوتے ہوئے بھی دین حق کا التزام نہیں کرتے .... یہاں تک کہ اپنے ہاتھوں سے ذلّت کے ساتھ تمہارے سامنے جزیہ پیش کرنے پر آمادہ ہوجائیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcclxv{اور یہودیوں کا کہنا ہے کہ عزیر اللہ کے بیٹے ہیں اور نصارٰی کہتے ہیں کہ مسیح اللہ کے بیٹے ہیں یہ سب ان کی زبانی باتیں ہیں-ان باتوں میں یہ بالکل ان کے مثل ہیں جو ان کے پہلے کفار کہا کرتے تھے ,اللہ ان سب کو قتل کرے یہ کہاں بہکے چلے جارہے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcclxvi{ان لوگوں نے اپنے عالموں اور راہبوں اور مسیح بن مریم کو خدا کو چھوڑ کر اپنا رب بنالیا ہے حالانکہ انہیں صرف خدائے یکتا کی عبادت کا حکم دیا گیا تھا جس کے علاوہ کوئی خدا نہیں ہے وہ واحد و بے نیاز ہے اور ان کے مشرکانہ خیالات سے پاک و پاکیزہ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcclxvii{یہ لوگ چاہتے ہیں کہ نو» خدا کواپنے منہ سے پھونک مار کر بجھا دیں حالانکہ خدا اس کے علاوہ کچھ ماننے کے لئے تیار نہیں ہے کہ وہ اپنے نور کو تمام کردے چاہے کافروں کو یہ کتنا ہی برا کیوںنہ لگے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcclxviii{وہ خدا وہ ہے جس نے اپنے رسول کو ہدایت اور دینِ حق کے ساتھ بھیجا تاکہ اپنے دین کو تمام ادیان پر غالب بنائے چاہے مشرکین کو کتنا ہی ناگوار کیوں نہ ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcclxix{ایمان والو نصارٰی کے بہت سے علمائ اور راہب ,لوگوں کے اموال کو ناجائز طریقہ سے کھاجاتے ہیں اور لوگوں کو راسِ خدا سے روکتے ہیں .... اور جو لوگ سونے چاندی کا ذخیرہ کرتے ہیں اور اسے راہ هخدا میں خرچ نہیں کرتے پیغمبر,آپ انہیں دردناک عذاب کی بشارت دے دیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcclxx{جس دن وہ سونا چاندی آتش هجہنّم میں تپایا جائے گا اور اس سے ان کی پیشانیوں اور ان کے پہلوؤں اور پشت کو داغا جائے گا کہ یہی وہ ذخیرہ ہے جو تم نے اپنے لئے جمع کیا تھا اب اپنے خزانوں اور ذخیروں کا مزہ چکھو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcclxxi{بیشک مہینوں کی تعداد اللہ کے نزدیک کتابِ خدا میں اس دن سے بارہ ہے جس دن اس نے آسمانوں اور زمین کو پیدا کیا ہے -ان میں سے چار مہینے محترم ہیں اور یہی سیدھا اور مستحکم دین ہے لہٰذا خبردار ان مہینوں میں اپنے اوپر ظلم نہ کرنا اور تمام مشرکین سے اسی طرح جہاد کرنا جس طرح وہ تم سے جنگ کرتے ہیں اور یہ یاد رکھنا کہ خدا صرف متقی اور پرہیزگار لوگوں کے ساتھ ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcclxxii{محترم مہینوں میں تقدیم و تاخیر کفر میں ایک قسم کی زیادتی ہے جس کے ذریعہ کفاّر کو گمراہ کیا جاتا ہے کہ وہ ایک سال اسے حلال بنالیتے ہیں اور دوسرے سال حرام کردیتے ہیں تاکہ اتنی تعداد برابر ہوجائے جتنی خدا نے حرام کی ہے اور حرام هخدا حلال بھی ہوجائے -ان کے بدترین اعمال کو ان کی نگاہ میں آراستہ کردیا گیا ہے اور اللہ کافر قوم کی ہدایت نہیں کرتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcclxxiii{ایمان والو تمہیں کیا ہوگیا ہے کہ جب تم سے کہا گیا کہ راہ هخدا میں جہاد کے لئے نکلو تو تم زمین سے چپک کر رہ گئے کیا تم آخرت کے بدلے زندگانی دنیا سے راضی ہوگئے ہو تو یاد رکھو کہ آخرت میں اس متاع هزندگانی دنیا کی حقیقت بہت قلیل ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcclxxiv{اگر تم راہ هخدا میں نہ نکلو گے تو خدا تمہیں دردناک عذا میں مبتلا کرے گا اور تمہارے بدلے دوسری قوم کو لے آئے گا اور تم اسے کوئی نقصان نہیں پہنچا سکتے ہو کہ وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcclxxv{اگر تم پیغمبر کی مدد نہ کرو گے تو ان کی مدد خدا نے کی ہے اس وقت جب کفاّر نے انہیں وطن سے باہر نکال دیا اور وہ ایک شخص کے ساتھ نکلے اور دونوں غار میں تھے تو وہ اپنے ساتھی سے کہہ رہے تھے کہ رنج نہ کرو خدا ہمارے ساتھ ہے پھر خدا نے اپنی طرف سے اپنے پیغمبر پر سکون نازل کردیا اور ان کی تائید ان لشکروں سے کردی جنہیں تم نہ دیکھ سکے اور اللہ ہی نے کفاّر کے کلمہ کو پست بنادیا ہے اور اللہ کا کلمہ درحقیقت بہت بلند ہے کہ وہ صاحب هعزت و غلبہ بھی ہے اور صاحب هحکمت بھی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcclxxvi{مسلمانو !تم ہلکے ہو یا بھاری گھر سے نکل پڑو اور راہ هخدا میں اپنے اموال اور نفوس سے جہاد کرو کہ یہی تمہارے حق میں خیر ہے اگرتم کچھ جانتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcclxxvii{پیغمبر !اگر کوئی قریبی فائدہ یا آسان سفر ہوتا تو یہ ضرور تمہارا اتباع کرتے لیکن ان کے لئے دور کا سفر مشکل بن گیا ہے اور عنقریب یہ خدا کی قسم کھائیں گے کہ اگر ممکن ہوتا تو ہم ضرور آپ کے ساتھ نکل پڑتے -یہ اپنے نفس کو ہلاک کررہے ہیں اور خدا خوب جانتا ہے کہ یہ جھوٹے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcclxxviii{پیغمبر!خدا نے آپ سے درگزر کیا کہ آپ نے کیوں انہیں پیچھے رہ جانے کی اجازت دے دی بغیر یہ معلوم کئے کہ ان میں کون سچاّ ہے اور کون جھوٹا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcclxxix{جو لوگ اللہ اور روز هآخرت پر ایمان رکھتے ہیں وہ ہرگز اپنے جان و مال سے جہاد کرنے کے خلاف اجازت نہ طلب کریں گے کہ خدا صاحبانِ تقوٰی کو خوب جانتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcclxxx{یہ اجازت صرف وہ لوگ طلب کرتے ہیں جن کا ایمان اللہ اور روز آخرت پر نہیں ہے اور ان کے دلوں میں شبہ ہے اور وہ اسی شبہ میں چکّر کاٹ کررہے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcclxxxi{یہ اگر نکلنا چاہتے تو اس کے لئے سامان تیار کرتے لیکن خد اہی کو ان کا نکلنا پسند نہیں ہے اس لئے اس نے ان کے ارادوں کو کمزور رہنے دیا اور ان سے کہا گیا کہ اب تم بیٹھنے والوں کے ساتھ بیٹھے رہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcclxxxii{اگر یہ تمہارے درمیان نکل بھی پڑتے تو تمہاری وحشت میں اضافہ ہی کردیتے اور تمہارے درمیان فتنہ کی تلاش میں گھوڑے دوڑاتے پھرتے اور تم میں ایسے لوگ بھی تھے جو ان کی سننے والے بھی تھے اور اللہ تو ظالمین کو خوب جاننے والا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiii{بیشک انہوں نے اس سے پہلے بھی فتنہ کی کوشش کی تھی اور تمہارے امور کو الٹ پلٹ دینا چاہا تھا یہاں تک کہ حق آگیا اور امر خدا واضح ہوگیا اگرچہ یہ لوگ اسے ناپسند کررہے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcclxxxiv{ان میں وہ لوگ بھی ہیں جو کہتے ہیں کہ ہم کو اجازت دے دیجئے اور فتنہ میں نہ ڈالئے تو آگاہ ہوجاؤ کہ یہ واقعا فتنہ میں گر چکے ہیں اور جہنّم تو کافرین کو ہر طرف سے احاطہ کئے ہوئے ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcclxxxv{ان کا حال یہ ہے کہ آپ تک نیکی آ تی ہے تو انہیں بفِی لگتی ہے اور کوئی مصیبت آجاتی ہے تو کہتے ہیں کہ ہم نے اپنا کام پہلے ہی ٹھیک کرلیا تھا اور خوش و خرم واپس چلے جاتے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvi{آپ کہہ دیجئے کہ ہم تک وہی حالات آتے ہیں جو خدا نے ہمارے حق میں لکھ دیئے ہیں وہی ہمارا مولا ہے اور صاحبان هایمان اسی پر توکّل اور اعتماد رکھتے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcclxxxvii{آپ کہہ دیجئے کہ تم ہمارے بارے میں جس بات کا بھی انتظار کررہے ہو وہ دو میں سے ایک نیکی ہے اور ہم تمہارے بارے میں اس بات کا انتظار کررہے ہیں کہ خدا اپنی طرف سے یا ہمارے ہاتھوں سے تمہیں عذاب میں مبتلا کردے لہٰذا اب عذاب کا انتظار کرو ہم بھی تمہارے ساتھ انتظار کررہے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcclxxxviii{کہہ دیجئے کہ تم بخوشی خرچ کرو یا جبرا تمہارا عمل قبول ہونے والا نہیں ہے کہ تم ایک فاسق قوم ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcclxxxix{اور ان کے نفقات کو قبول ہونے سے صرف اس بات نے روک دیا ہے کہ انہوں نے خدا اور رسول کا انکار کیا ہے اور یہ نمازبھی سستی اور کسلمندی کے ساتھ بجالاتے ہیں اور راسِ خدا میں کراہت اور ناگواری کے ساتھ خرچ کرتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mccxc{تمہیں ان کے اموال اور اولاد حیرت میں نہ ڈال دیں بس اللہ کاارادہ یہی ہے کہ ان ہی کے ذریعہ ان پر زندگانی دنیا میں عذاب کرے اور حالت هکفر ہی میں ان کی جان نکل جائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mccxci{اور یہ اللہ کی قسم کھاتے ہیں کہ یہ تم ہی میں سے ہیں حالانکہ یہ تم میں سے نہیں ہیں یہ لوگ بزدل لوگ ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mccxcii{ان کو کوئی پناہ گاہ یا غار یا گھس بیٹھنے کی جگہ مل جائے تو اس کی طرف بے تحاشہ بھاگ جائیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mccxciii{اور ان ہی میں سے وہ بھی ہیں جو خیرات کے بارے میں الزام لگاتے ہیں کہ انہیں کچھ مل جائے تو راضی ہوجائیں گے اور نہ دیا جائے تو ناراض ہوجائیں گے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mccxciv{حالانکہ اے کاش یہ خدا و رسول کے دئیے ہوئے پر راضی ہوجاتے اور یہ کہتے کہ ہمارے لئے اللہ ہی کافی ہے عنقریب وہ اور اس کا رسول اپنے فضل و احسان سے عطا کردیں گے او رہم تو صرف اللہ کی طرف رغبت رکھنے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mccxcv{صدقات و خیرات بس فقرائ ,مساکین اور ان کے کام کرنے والے اور جن کی تالیف هقلب کی جاتی ہے اور غلاموں کی گردن کی آزادی میں اور قرضداروں کے لئے اور راسِ خدا میں غربت زدہ مسافروں کے لئے ہیں یہ اللہ کی طرف سے فریضہ ہے اور اللہ خوب جاننے والا اور حکمت والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mccxcvi{ان میں سے وہ بھی ہیں جو پیغمبر کو اذیت دیتے ہیں اور کہتے ہیں کہ وہ تو صرف کان ہیں -آپ کہہ دیجئے کہ تمہارے حق میں بہتری کے کان ہیں کہ خدا پر ایمان رکھتے ہیں اور مومنین کی تصدیق کرتے ہیں اور صاحبانِ ایمان کے لئے رحمت ہیں اور جو لوگ رسول خدا کو اذیت دیتے ہیں ان کے واسطے دردناک عذاب ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mccxcvii{یہ لوگ تم لوگوں کو راضی کرنے کے لئے خدا کی قسم کھاتے ہیں حالانکہ خدا و رسول اس بات کے زیادہ حقدار تھے کہ اگر یہ صاحبان هایمان تھے تو واقعا انہیں اپنے اعمال و کردار سے راضی کرتے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mccxcviii{کیا یہ نہیں جانتے ہیں کہ جو خدا و رسول سے مخالفت کرے گا اس کے لئے آتش جہنمّ ہے اور اسی میں ہمیشہ رہنا ہے اور یہ بہت بڑی رسوائی ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mccxcix{منافقین کو یہ خوف بھی ہے کہ کہیں کوئی سورہ نازل ہوکر مسلمانوں کو ان کے دل کے حالات سے باخبر نہ کردے تو آپ کہہ دیجئے کہ تم اور مذاق اڑاؤ اللہ بہرحال اس چیز کو منظر عام پر لے آئے گا جس کا تمہیں خطرہ ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mccc{اور اگر آپ ان سے باز پرس کریں گے تو کہیں گے کہ ہم تو صرف بات چیت اور دل لگی کررہے تھے تو آپ کہہ دیجئے کہ کیا اللہ اور اس کی آیات اور رسول کے بارے میں مذاق اڑارہے تھے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mccci{تو اب معذرت نہ کرو -تم نے ایمان کے بعد کفر اختیار کیا ہے -ہم اگر تم میں کی ایک جماعت کو معاف بھی کردیں تو دوسری جماعت پر ضرور عذاب کریں گے کہ یہ لوگ مجرم ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcccii{منافق مرد اور منافق عورتیں آپس میں سب ایک دوسرے سے ہیں -سب برائیوں کا حکم دیتے ہیں اور نیکیوں سے روکتے ہیں اور اپنے ہاتھوں کو راہ هخدا میں خرچ کرنے سے روکے رہتے ہیں -انہوں نے اللہ کو بھلا دیا ہے تو اللہ نے انہیں بھی نظرانداز کردیا ہے کہ منافقین ہی اصل میں فاسق ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mccciii{اور اللہ نے نےم منافق مردوں اور عورتوں سے اور تمام کافروں سے آتش جہنمّ کا وعدہ کیا ہے جس میں یہ ہمیشہ رہنے والے ہیں -وہی ان کے واسطے کافی ہے اور ان کے لئے ہمیشہ رہنے والا عذاب ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mccciv{تمہاری مثال تم سے پہلے والوں کی ہے جو تم سے زیادہ طاقتور تھے اور تم سے زیادہ مالدار اور صاحب هاولاد بھی تھے -انہوں نے اپنے حصّہ سے خوب فائدہ اٹھایا اور تم نے بھی اسی طرح اپنے نصیب سے فائدہ اٹھایا جس طرح تم سے پہلے والوں نے اٹھایا تھا اور اسی طرح لغویات میں داخل ہوئے جس طرح وہ لوگ داخل ہوئے تھے حالانکہ وہی وہ لوگ ہیں جن کے اعمال دنیا اور آخرت میں برباد ہوگئے اور وہی وہ لوگ ہیں جو حقیقتا خسارہ والے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcccv{کیا ان لوگوں کے پاس ان سے پہلے والے افراد قوم نوح علیھ السّلام ,عاد علیھ السّلام ,ثمود علیھ السّلام ,قوم ابراہیم علیھ السّلام,اصحاب مدین اور الٹ دی جانے والی بستیوں کی خبرنہیں آئی جن کے پاس ان کے رسول واضح نشانیاں لے کر آئے اور انہوں نے انکار کردیا -خدا کسی پر ظلم کرنے والا نہیں ہے لوگ خود اپنے نفس پر ظلم کرتے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcccvi{مومن مرد اور مومن عورتیں آپس میں سب ایک دوسرے کے ولی اور مددگار ہیں کہ یہ سب ایک دوسرے کو نیکیوں کا حکم دیتے ہیں اور برائیوں سے روکتے ہیں,نماز قائم کرتے ہیں -زکوِٰ ادا کرتے ہیں اللہ اور رسول کی اطاعت کرتے ہیں -یہی وہ لوگ ہیں جن پر عنقریب خدا رحمت نازل کرے گا کہ وہ ہر شے پر غالب اور صاحبِ حکمت ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcccvii{اللہ نے مومن مرد اور مومن عورتوں سے ان باغات کا وعدہ کیا ہے جن کی نیچے نہریں جاری ہوں گی -یہ ان میں ہمیشہ رہنے والے ہیں -ان جنااُ عدن میں پاکیزہ مکانات ہیں اور اللہ کی مرضی تو سب سے بڑی چیز ہے اور یہی ایک عظیم کامیابی ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcccviii{پیغمبر !کفار اور منافقین سے جہاد کیجئے اور ان پر سختی کیجئے کہ ان کا انجام جہنّم ہے جو بدترین ٹھکانا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcccix{یہ اپنی باتوں پر اللہ کی قسم کھاتے ہیں کہ ایسا نہیں کہا حالانکہ انہوں نے کلمہ کفر کہا ہے اور اپنے اسلام کے بعد کافر ہوگئے ہیں اور وہ ارادہ کیا تھا جو حاصل نہیں کرسکے اور ان کا غصہّ صرف اس بات پر ہے کہ اللہ اور رسول نے اپنے فضل و کرم سے مسلمانوں کو نواز دیا ہے -بہرحال یہ اب بھی توبہ کرلیں تو ان کے حق میں بہتر ہے اور منہ پھیرلیں تو اللہ ان پر دنیا اور آخرت میں دردناک عذاب کرے گا اور روئے زمین پر کوئی ان کا سرپرست اور مددگار نہ ہوگا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcccx{ان میں وہ بھی ہیں جنہوں نے خدا سے عہد کیا کہ اگر وہ اپنے فضل و کرم سے عطا کردیگا تو اس کی راہ میں صدقہ دیں گے اور نیک بندوں میں شامل ہوجائیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcccxi{اس کے بعد جب خد انے اپنے فضل سے عطا کردیا تو بخل سے کام لیا اور کنارہ کش ہوکر پلٹ گئے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcccxii{تو ان کے بخل نے ان کے دلوں میں نفاق راسخ کردیا اس دن تک کے لئے جب یہ خدا سے ملاقات کریں گے اس لئے کہ انہوں نے خدا سے کئے ہوئے وعدہ کی مخالفت کی ہے اور جھوٹ بولے ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcccxiii{کیا یہ نہیں جانتے کہ خدا ان کے رازِ دل اور ان کی سرگوشیوں کو بھی جانتا ہے اور وہ سارے غیب کا جاننے والا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcccxiv{جو لوگ صدقات میں فراخدلی سے حصّہ لینے والے مومنین اور ان غریبوں پر جن کے پاس ان کی محنت کے علاوہ کچھ نہیں ہے الزام لگاتے ہیں اور پھر ان کا مذاق اڑاتے ہیں خدا ان کا بھی مذاق بنادے گا اور اس کے پاس بڑا دردناک عذاب ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcccxv{آپ ان کے لئے استغفار کریں یا نہ کریں -اگر ستر ّمرتبہ بھی استغفار کریں گے تو خدا انہیں بخشنے والا نہیں ہے اس لئے کہ انہوں نے اللہ اور رسول کا انکار کیا ہے اور خدا فاسق قوم کو ہدایت نہیں دیتا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcccxvi{جو لوگ جنگ تبوک میں نہیں گئے وہ رسول اللہ کے پیچھے بیٹھے رہ جانے پر خوش ہیں اور انہیں اپنے جان و مال سے راسِ خدامیں جہاد ناگوار معلوم ہوتا ہے اور یہ کہتے ہیں کہ تم لوگ گرمی میں نہ نکلو ...._ تو پیغمبر آپ کہہ دیجئے کہ آتش جہنّم اس سے زیادہ گرم ہے اگر یہ لوگ کچھ سمجھنے والے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcccxvii{اب یہ لوگ ہنسیں کم اور روئیں زیادہ کہ یہی ان کے کئے کی جزا ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcccxviii{اس کے بعد اگر خدا آپ کو ان کے کسی گروہ تک میدان سے واپس لائے اور یہ دوبارہ خروج کی اجازت طلب کریں تو آپ کہہ دیجئے تم لوگ کبھی میرے ساتھ نہیں نکل سکتے اور کسی دشمن سے جہاد نہیں کرسکتے تم نے پہلے ہی بیٹھے رہنا پسند کیا تھا تو اب بھی پیچھے رہ جانے والوں کے ساتھ بیٹھے رہو\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcccxix{اور خبردار ان میں سے کوئی مر بھی جائے تو اس کی نماز جنازہ نہ پڑھئے گا اور اس کی قبر پر کھڑے بھی نہ ہویئے گا کہ ان لوگوں نے خدا اور رسول کا انکار کیا ہے اور حالاُ فسق میں دنیا سے گزر گئے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcccxx{اور ان کے اموال و اولاد آپ کو بھلے نہ معلوم ہوں خدا ان کے ذریعہ ان پر دنیا میں عذاب کرنا چاہتا ہے اور چاہتا ہے کہ کفر کی حالت میں ان کا دم نکل جائے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcccxxi{اور جب کوئی سورہ نازل ہوتا ہے کہ اللہ پر ایمان لے آؤاور رسول کے ساتھ جہاد کرو تو ان ہی کے صاحبانِ حیثیت آپ سے اجازت طلب کرنے لگتے ہیں اور کہتے ہیں کہ ہمیں ان ہی بیٹھنے والوں کے ساتھ چھوڑ دیجئے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcccxxii{یہ اس بات پر راضی ہیں کہ پیچھے رہ جانے والوں کے ساتھ رہ جائیں .ان کے دلو ںپر مہر لگ گئی ہے اب یہ کچھ سمجھنے والے نہیں ہیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcccxxiii{لیکن رسول اور ان کے ساتھ ایمان لانے والوں نے راہ ه خدا میں اپنے جان و مال سے جہاد کیا ہے اور ان ہی کے لئے نیکیاں ہیں اور وہی فلاح یافتہ اور کامیاب ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcccxxiv{اللہ نے ان کے لئے وہ باغات مہیا کئے ہیں جن کے نیچے نہریں جاری ہیں اور وہ ان ہی میں ہمیشہ رہنے والے ہیں اور یہی بہت بڑی کامیابی ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcccxxv{اور آپ کے پاس دیہاتی معذرت کرنے والے بھی آگئے کہ انہیں بھی گھر بیٹھنے کی اجازت دے دی جائے اور وہ بھی بیٹھ رہے جنہوں نے خدا و رسول سے غلط بیانی کی تھی تو عنقریب ان میں کے کافروں پر بھی دردناک عذاب نازل ہوگا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcccxxvi{جو لوگ کمزور ہیں یابیمار ہیں یا ان کے پاس راسِ خدا میں خرچ کرنے کے لئے کچھ نہیں ہے ان کے بیٹھے رہنے میں کوئی حرج نہیں ہے بشرطیکہ خدا و رسول کے حق میں اخلاص رکھتے ہوں کہ نیک کردار لوگوں پر کوئی الزام نہیں ہوتا اور اللہ بہت بخشنے والا مہربان ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcccxxvii{اور ان پر بھی کوئی الزام نہیں ہے جو آپ کے پاس آئے کہ انہیں بھی سواری پر لے لیجئے اور آپ ہی نے کہہ دیا کہ ہمارے پاس سواری کا انتظام نہیں ہے اور وہ آپ کے پاس سے اس عالم میں پلٹے کہ ان کی آنکھوں سے آنسو جاری تھے اور انہیں اس بات کا رنج تھا کہ ان کے پاس راہ هخدا میں خرچ کرنے کے لئے کچھ نہیں ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcccxxviii{الزام ان لوگوں پرہے جو غنی اور مالدار ہوکر بھی اجازت طلب کرتے ہیں اور چاہتے ہیں کہ پسماندہ لوگوں میں شامل ہوجائیں اور خدا نے ان کے دلوں پر مہرلگادی ہے اور اب کچھ جاننے والے نہیں ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcccxxix{یہ تخلف کرنے والے منافقین تم لوگوں کی واپسی پر طرح طرح کے عذر بیان کریں گے تو آپ کہہ دیجئے کہ تم لوگ عذر نہ بیان کرنے والے نہیں ہیں اللہ نے ہمیں تمہارے حالات بتادئیے ہیں -وہ یقیناتمہارے اعمال کو دیکھ رہا ہے اور رسول بھی دیکھ رہا ہے اس کے بعد تم حاضر و غیب کے عالم خدا کی بارگاہ میں واپس کئے جاؤ گے اور وہ تمہیں تمہارے اعمال سے باخبر کرے گا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcccxxx{عنقریب یہ لوگ تمہاری واپسی پر خدا کی قسم کھائیں گے کہ تم ان سے درگزر کردو تو تم کنارہ کشی اختیار کرلو -یہ مجسمئہ خباثت ہیں. ان کا ٹھکانا جہّنم ہے جو ان کے کئے کی صحیح سزا ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcccxxxi{یہ تمہارے سامنے قسم کھاتے ہیں کہ تم ان سے راضی ہوجاؤ تو اگر تم راضی بھی ہوجاؤ تو خدا فاسق قوم سے راضی ہونے والا نہیں ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcccxxxii{یہ دیہاتی کفر اور نفاق میں بہت سخت ہیں اور اسی قابل ہیں کہ جو کتاب خدا نے اپنے رسول پر نازل کی ہے اس کے حدود اور احکام کو نہ پہچانیں اور اللہ خوب جاننے والا اور صاحبِ حکمت ہے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiii{ان ہی اعراب میں وہ بھی ہیں جو اپنے انفاق کو گھاٹا سمجھتے ہیں اور آپ کے بارے میں مختلف گردشوں کا انتظار کیا کرتے ہیں تو خود ان کے اوپر اِری گردش کی مار ہے اوراللہ خوب سننے والا اور جاننے والا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcccxxxiv{ان ہی اعراب میں وہ بھی ہیں جو ا للہ اور آخرت پر ایمان رکھتے ہیں اور اپنے انفاق کو خدا کی قربت اور رسول کی دعائے رحمت کا ذریعہ قرار دیتے ہیں اور بیشک یہ ان کے لئے سامانِ قربت ہے عنقریب خدا انہیں اپنی رحمت میں داخل کرلے گا کہ وہ غفور بھی ہے اور رحیم بھی ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcccxxxv{اور مہاجرین و انصار میں سے سبقت کرنے والے اور جن لوگوں نے نیکی میں ان کا اتباع کیا ہے ان سب سے خدا راضی ہوگیا ہے اور یہ سب خدا سے راضی ہیں اور خدا نے ان کے لئے وہ باغات مہیا کئے ہیں جن کے نیچے نہریں جاری ہیں اور یہ ان میں ہمیشہ رہنے والے ہیں اور یہی بہت بڑی کامیابی ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvi{اور تمہارے گرد دیہاتیوں میں بھی منافقین ہیں اور اہل مدینہ میں تو وہ بھی ہیں جو نفاق میں ماہر اور سرکش ہیں تم ان کو نہیں جانتے ہو لیکن ہم خوب جانتے ہیں -عنقریب ہم ان پر دوہرا عذاب کریں گے اس کے بعد یہ عذاب عظیم کی طرف پلٹا دئیے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcccxxxvii{اور دوسرے وہ لوگ جنہوں نے اپنے گناہوں کا اعتراف کیا کہ انہوں نے نیک اور بداعمال مخلوط کردئیے ہیں عنقریب خدا ان کی توبہ قبول کرلے گا کہ وہ بڑا بخشنے والا اور مہربان ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcccxxxviii{پیغمبر آپ ان کے اموال میں سے زکوِٰلے لیجئے کہ اس کے ذریعہ یہ پاک و پاکیزہ ہوجائیں اور انہیں دعائیں دیجئے کہ آپ کی دعا ان کے لئے تسکین قلب کا باعث ہوگی اور خدا سب کا سننے والا اور جاننے والا ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcccxxxix{کیا یہ نہیں جانتے کہ اللہ ہی اپنے بندوں کی توبہ قبول کرتا ہے اور زکوِٰ و خیرات کو وصول کرتا ہے اور وہی بڑا توبہ قبول کرنے والا اور مہربان ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcccxl{اور پیغمبر کہہ دیجئے کہ تم لوگ عمل کرتے رہو کہ تمہارے عمل کواللہ ً رسول اور صاحبانِ ایمان سب دیکھ رہے ہیں اور عنقریب تم اس خدائے عالم الغیب والشہادہ کی طرف پلٹا دئیے جاؤ گے اور وہ تمہیں تمہارے اعمال سے باخبر کرے گا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcccxli{اور کچھ ایسے بھی ہیں جنہیں حکم هخدا کی امید پر چھوڑ دیا گیا ہے کہ یا خدا ان پر عذاب کرے گا یا ان کی توبہ کو قبول کرلے گا وہ بڑا جاننے والا اور صاحبِ حکمت ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcccxlii{اور جن لوگوں نے مسجد ضرار بنائی کہ اس کے ذریعہ اسلام کو نقصان پہنچائیں اور کفر کو تقویت بخشیں اور مومنین کے درمیان اختلاف پیدا کرائیں اور پہلے سے خدا و رسول سے جنگ کرنے والوں کے لئے پناہ گاہ تیار کریں وہ بھی منافقین ہی ہیں اور یہ قسم کھاتے ہیں کہ ہم نے صرف نیکی کے لئے مسجد بنائی ہے حالانکہ یہ خدا گواہی دیتا ہے کہ یہ سب جھوٹے ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcccxliii{خبردار آپ اس مسجد میں کبھی کھڑے بھی نہ ہوں بلکہ جس مسجد کی بنیاد روز اوّل سے تقوٰیٰ پر ہے وہ اس قابل ہے کہ آپ اس میں نماز ادا کریں -اس میں وہ مرد بھی ہیں جو طہارت کو دوست رکھتے ہیں اور خدا بھی پاکیزہ افراد سے محبت کرتا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcccxliv{کیا جس نے اپنی بنیاد خوف خدا اور رضائے الٰہی پر رکھی ہے وہ بہتر ہے یا جس نے اپنی بنیاد اس گرتے ہوئے کگارے کے کنارے پر رکھی ہو کہ وہ ساری عمارت کو لے کر جہّنم میں گر جائے اوراللہ ظالم قوم کی ہدایت نہیں کرتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcccxlv{اور ہمیشہ ان کی بنائی ہوئی عمارت کی بنیاد ان کے دلوں میں شک کا باعث بنی رہے گی مگر یہ کہ ان کے دل کے ٹکڑے ٹکڑے ہوجائیں اور انہیں موت آجائے کہ اللہ خوب جاننے والا اور صاحبِ حکمت ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mcccxlvi{بیشک اللہ نے صاحبانِ ایمان سے ان کے جان و مال کو جنّت کے عوض خریدلیا ہے کہ یہ لوگ راہ هخدا میں جہاد کرتے ہیں اور دشمنوں کو قتل کرتے ہیں اور پھر خود بھی قتل ہوجاتے ہیں یہ وعدئہ برحق توریت ,انجیل اور قرآن ہر جگہ ذکر ہوا ہے اور خدا سے زیادہ اپنی عہد کا پورا کرنے والا کون ہوگا تو اب تم لوگ اپنی اس تجارت پر خوشیاں مناؤ جو تم نے خدا سے کی ہے کہ یہی سب سے بڑی کامیابی ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mcccxlvii{یہ لوگ توبہ کرنے والے ,عبادت کرنے والے ,حمد پروردگار کرنے والے ,راسِ خد امیں سفر کرنے والے ,رکوع کرنے والے ,سجدہ کرنے والے ,نیکیوں کا حکم دینے والے ,برائیوں سے روکنے والے اور حدود الٰہیہ کی حفاظت کرنے والے ہیں اور اے پیغمبر آپ انہیں جنّت کی بشارت دیدیں\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mcccxlviii{نبی اور صاحبانِ ایمان کی شان یہ نہیں ہے کہ وہ مشرکین کے حق میں استغفار کریں چاہے وہ ان کے قرابتدار ہی کیوں نہ ہوں جب کہ یہ واضح ہوچکا ہے کہ یہ اصحاب جہّنم ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mcccxlix{اور ابراہیم کا استغفار ان کے باپ کے لئے صرف اس وعدہ کی بنا پر تھا جو انہوں نے اس سے کیا تھا اس کے بعد جب یہ واضح ہوگیا کہ وہ دشمن خدا ہے تو اس سے بربَت اور بیزاری بھی کرلی کہ ابراہیم بہت زیادہ تضرع کرنے والے اور اِردبار تھے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mcccl{اور اللہ کسی قوم کو ہدایت دینے کے بعد اس وقت تک گمراہ نہیں قرار دیتا جب تک ان پر یہ واضح نہ کردے کہ انہیں کن چیزوں سے پرہیز کرنا ہے -بیشک اللہ ہر شے کا جاننے والا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mcccli{اللہ ہی کے لئے زمین و آسمان کی حکومت ہے اور وہی حیات و موت کا دینے والا ہے اس کے علاوہ تمہارا نہ کوئی سرپرست ہے نہ مددگار\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mccclii{بیشک خدا نے پیغمبر اور ان مہاجرین و انصار پر رحم کیا ہے جنہوں نے تنگی کے وقت میں پیغمبر کا ساتھ دیا ہے جب کہ ایک جماعت کے دلوں میں کجی پیدا ہورہی تھی پھر خدا نے ان کی توبہ کو قبول کرلیا کہ وہ ان پر بڑا ترس کھانے والا اور مہربانی کرنے والا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mcccliii{اوراللہ نے ان تینوں پر بھی رحم کیا جو جہاد سے پیچھے رہ گئے یہاں تک کہ زمین جب اپنی وسعتوں سمیت ان پر تنگ ہوگئی اور ان کے دم پر بن گئی اور انہوں نے یہ سمجھ لیا کہ ا ب اللہ کے علاوہ کوئی پناہ گاہ نہیں ہے تواللہ نے ان کی طرف توجہ فرمائی کہ وہ توبہ کرلیں اس لئے کہ وہ بڑا توبہ قبول کرنے والا اور مہربان ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mcccliv{ایمان والواللہ سے ڈرو اور صادقین کے ساتھ ہوجاؤ\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mccclv{اہل مدینہ یا اس کے اطراف کے دیہاتیوں کو یہ حق نہیں ہے کہ وہ رسول خدا سے الگ ہوجائیں یا اپنے نفس کو ان کے نفس سے زیادہ عزیز سمجھیں اس لئے کہ انہیں کوئی پیاسً تھکن یا بھوک راہ هخدا میں نہیں لگتی ہے اور نہ وہ کّفار کے دل رَکھانے والا کوئی قدم اٹھاتے ہیں نہ کسی بھی دشمن سے کچھ حاصل کرتے ہیں مگر یہ کہ ان کے عمل نیک کو لکھ لیا جاتا ہے کہ خدا کسی بھی نیک عمل کرنے والے کے اجر و ثواب کو ضائع نہیں کرتا ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mccclvi{اور یہ کوئی چھوٹ یا بڑا خرچ راسِ خدا میں نہیں کرتے ہیں اور نہ کسی وادی کو طے کرتے ہیں مگر یہ کہ اسے بھی ان کے حق میں لکھ دیا جاتا ہے تاکہ خدا انہیں ان کے اعمال سے بہتر جزا عطا کرسکے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mccclvii{صاحبان ایمان کا یہ فرض نہیں ہے کہ وہ سب کے سب جہاد کے لئے نکل پڑیں تو ہر گروہ میں سے ایک جماعت اس کام کے لئے کیوں نہیں نکلتی ہے کہ دین کا علم حاصل کرے اور پھر جب اپنی قوم کی طرف پلٹ کر آئے تو اسے عذاب الٰہی سے ڈرائے کہ شاید وہ اسی طرح ڈرنے لگیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mccclviii{ایمان والو اپنے آس پاس والے کفار سے جہاد کرو اور وہ تم میں سختی اور طاقت کا احساس کریں اور یاد رکھو کہ اللہ صرف پرہیز گار افراد کے ساتھ ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mccclix{اور جب کوئی سورہ نازل ہوتا ہے تو ان میں سے بعض یہ طنز کرتے ہیں کہ تم میں سے کس کے ایمان میں اضافہ ہوگیا ہے تو یاد رکھیں کہ جو ایمان والے ہیں ان کے ایمان میں اضافہ ہوتا ہے اور وہ خوش بھی ہوتے ہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mccclx{اور جن کے دلوں میں مرض ہے ان کے مرض میں سورہ ہی سے اضافہ ہوجاتا ہے اور وہ کفر ہی کی حالت میں مرجاتے ہیں\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mccclxi{کیا یہ نہیں دیکھتے ہیں کہ انہیں ہر سال ایک دو مرتبہ بلا میں مبتلا کیا جاتا ہے پھراس کے بعد بھی نہ توبہ کرتے ہیں اور نہ عبرت حاصل کرتے ہیں\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mccclxii{اور جب کوئی سورہ نازل ہوتا ہے تو ایک دوسرے کی طرف دیکھنے لگتا ہے کہ کوئی دیکھ تو نہیں رہا ہے اور پھر پلٹ جاتے ہیں تو خدا نے بھی ان کے قلوب کو پلٹ دیاہے کہ یہ سمجھنے والی قوم نہیں ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mccclxiii{یقینا تمہارے پاس وہ پیغمبر آیا ہے جو تم ہی میں سے ہے اور اس پر تمہاری ہر مصیبت شاق ہوتی ہے وہ تمہاری ہدایت کے بارے میں حرص رکھتا ہے اور مومنین کے حال پر شفیق اور مہربان ہے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mccclxiv{اب اس کے بعد بھی يه لوگ منه پھير ليں تو کہديجئے کہ خدا میرے لیے کافی ہے، اس کے سوا کوئی خدا نہیں، میرا اعتماداسى پر ہے اور وہى عرش اعظم کا پروردگار ہے.\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mccclxv{\basmalahur الۤر -پُر از حکمت کتاب کی آیتیں ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mccclxvi{کیا لوگوں کے لئے یہ بات عجیب ہے کہ انہیں میں سے ایک مرد پر ہم یہ وحی نازل کردیں کہ لوگوں کو عذاب سے ڈراؤ اور صاحبانِ ایمان کو بشارت دے دو کہ ان کے لئے پروردگار کی بارگاہ میں بلند ترین درجہ ہے .... مگر یہ کافر کہتے ہیں کہ یہ کھلا ہوا جادوگر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mccclxvii{بیشک تمہارا پروردگار وہ ہے جس نے زمین و آسمان کو چھ دنوں میں پیدا کیا ہے پھر اس کے بعد عرش پر اپنا اقتدار قائم کیاہے وہ تمام امور کی تدبیر کرنے والا ہے کوئی اس کی اجازت کے بغیر شفاعت کرنے والا نہیں ہے .وہی تمہارا پروردگار ہے اور اسی کی عبادت کرو کیا تمہیں ہوش نہیں آرہا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mccclxviii{اسی کی طرف تم سب کی بازگشت ہے -یہ خدا کا سّچا وعدہ ہے -وہی خلقت کا آغاز کرنے والا ہے اور واپس لے جانے والا ہے تاکہ ایمان اور نیک عمل والوں کو عادلانہ جزا دے سکے اور جو کافر ہوگئے ہیں ان کے لئے تو گرم پانی کا مشروب ہے اور ان کے کفر کی بنا پر دردناک عذاب بھی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mccclxix{اسی خدا نے آفتاب کو روشنی اورچاند کو نور بنایا ہے پھر چاند کی منزلیں مقرر کی ہیں تاکہ ان کے ذریعہ برسوں کی تعداد اور دوسرے حسابات دریافت کرسکو -یہ سب خدا نے صرف حق کے ساتھ پیدا کیا ہے کہ وہ صاحبان هعلم کے لئے اپنی آیتوں کو تفصیل کے ساتھ بیان کرتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mccclxx{بیشک دن رات کی آمدورفت اور جو کچھ خدا نے آسمان و زمین میں پیدا کیا ہے ان سب میں صاحبان هتقویٰ کے لئے اس کی نشانیاں پائی جاتی ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mccclxxi{یقینا جو لوگ ہماری ملاقات کی امید نہیں رکھتے ہیں اور زندگانی دنیا پر ہی راضی اور مطمئن ہوگئے ہیں اور جو لوگ ہماری آیات سے غافل ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mccclxxii{یہ سب وہ ہیں جن کے اعمال کی بنا پر ان کا ٹھکانا جہّنم ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mccclxxiii{بیشک جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے خدا ان کے ایمان کی بنا پر اس منزل کی طرف ان کی رہنمائی کرے گا جہاں نعمتوں کے باغات کے نیچے نہریں جاری ہوں گی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mccclxxiv{وہاں ان کا قول یہ ہوگا کہ خدایا تو پاک اور بے نیاز ہے اور ان کا تحفہ سلام ہوگا اور ان کا آخری بیان یہ ہوگا کہ ساری تعریف خدائے رب العالمین کے لئے ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mccclxxv{اگر خدا لوگوں کے لئے برائی میں بھی اتنی ہی جلدی کردیتا جتنی یہ لوگ بھلائی میں چاہتے ہیں تو اب تک ان کی مدت کا فیصلہ ہوچکا ہوتا - ہم تو اپنی ملاقات کی امید نہ رکھنے والوں کو ان کی سرکشی میں چھوڑ دیتے ہیں کہ یہ یونہی ٹھوکریں کھاتے پھریں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mccclxxvi{انسان کو جب کوئی نقصان پہنچتا ہے تو اٹھتے بیٹھتے کروٹیں بدلتے ہم کو پکارتا ہے اور جب ہم اس نقصان کو دور کردیتے ہیں تو یوں گزر جاتا ہے جیسے کبھی کسی مصیبت میں ہم کو پکارا ہی نہیں تھا بیشک زیادتی کرنے والوں کے اعمال یوں ہی ان کے سامنے آراستہ کردئیے جاتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mccclxxvii{یقینا ہم نے تم سے پہلے والی امتوں کو ہلاک کردیا جب انہوں نے ظلم کیا اور ہمارے پیغمبر ہماری نشانیاں لے کر آئے تو وہ ایمان نہ لاسکے -ہم اسی طرح مجرم قوم کو سزا دیتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mccclxxviii{اس کے بعد ہم نے تم کو روئے زمین پر ان کا جانشین بنادیا تاکہ دیکھیں کہ اب تم کیسے اعمال کرتے ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mccclxxix{اور جب ان کے سامنے ہماری آیات کی تلاوت کی جاتی ہے تو جن لوگوں کو ہماری ملاقات کی امید نہیں ہے وہ کہتے ہیں کہ اس کے علاوہ کوئی دوسرا قرآن لائیے یا اسی کو بدل دیجئے تو آپ کہہ دیجئے کہ مجھے اپنی طرف سے بدلنے کا کوئی اختیار نہیں ہے میں تو صرف اس امر کا اتباع کرتا ہوں جس کی میری طرف وحی کی جاتی ہے میں اپنے پروردگار کی نافرمانی کروں تو مجھے ایک بڑے عظےم دن کے عذاب کا خوف ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mccclxxx{آپ کہہ دیجئے کہ اگر خدا چاہتا تو میں تمہارے سامنے تلاوت نہ کرتا اور تمہیں اس کی اطلاع بھی نہ کرتا -آخر میں اس سے پہلے بھی تمہارے درمیان ایک مدت تک رہ چکا ہوں تو کیا تمہارے پاس اتنی عقل بھی نہیں ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mccclxxxi{اس سے بڑا ظالم کون ہے جو اللہ پر جھوٹا الزام لگائے یا اس کی آیتوں کی تکذیب کرے جب کہ وہ مجرمین کو نجات دینے والا نہیں ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mccclxxxii{اور یہ لوگ خدا کو چھوڑ کر ان کی پرستش کرتے ہیں جو نہ نقصان پہنچاسکتے ہیں اور نہ فائدہ اور یہ لوگ کہتے ہیں کہ یہ خدا کے یہاں ہماری سفارش کرنے والے ہیں تو آپ کہہ دیجئے کہ تم تو خدا کو اس بات کو اطلاع کررہے ہو جس کا علم اسے آسمان و زمین میں کہیں نہیں ہے وہ پاک و پاکیزہ ہے اور ان کے شرک سے بلند و برتر ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiii{سارے انسان فطرتا ایک امت تھے پھر سب آپس میں الگ الگ ہوگئے اور اگر تمہارے رب کی بات پہلے سے طے نہ ہوچکی ہوتی تو یہ جس بات میں اختلاف کرتے ہیں اس کا فیصلہ ہوچکا ہوتا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mccclxxxiv{یہ لوگ کہتے ہیں کہ خدا کی طرف سے ان پر کوئی نشانی کیوں نہیں نازل ہوتی تو آپ کہہ دیجئے کہ تمام غیب کا اختیار پروردگار کو ہے اور تم انتظار کرو اور میں بھی تمہارے ساتھ انتظار کرنے والوں میں ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mccclxxxv{اور جب تکلیف پہنچنے کے بعد ہم نے لوگوں کو ذرا رحمت کا مزہ چکھادیا تو فورا ہماری آیتوں میں مّکاری کرنے لگے تو آپ کہہ دیجئے کہ خدا تم سے تیز تر تدبیریں کرنے والا ہے اور ہمارے نمائندے تمہارے مکر کو برابر لکھ رہے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvi{وہ خدا وہ ہے جو تمہیں خشکی اور سمندر میں سیر کراتا ہے یہاں تک کہ جب تم کشتی میں تھے اور پاکیزہ ہوائیں چلیں اور سارے مسافر خوش ہوگئے تو اچانک ایک تیز ہوا چل گئی اور موجوں نے ہر طرف سے گھیرے میں لے لیا اور یہ خیال پیدا ہوگیا کہ چارں طرف سے کَھرگئے ہیں تو دین خالص کے ساتھ اللہ سے دعا کرنے لگے کہ اگر اس مصیبت سے نجات مل گئی تو ہم یقینا شکر گزاروں میں ہوجائیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mccclxxxvii{اس کے بعد جب اس نے نجات دے دی تو زمین میں ناحق ظلم کرنے لگے -انسانو !یاد رکھو تمہارا ظلم تمہارے ہی خلاف ہوگا یہ صرف چند روزہ زندگی کا مزہ ہے اس کے بعد تم سب کی بازگشت ہماری ہی طرف ہوگی اور پھر ہم تمہیں بتائیں گے کہ تم دنیا میں کیا کررہے تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mccclxxxviii{زندگانی دنیا کی مثال صرف اس بارش کی ہے جسے ہم نے آسمان سے نازل کیا پھر اس سے مل کر زمین سے وہ نباتات برآمد ہوئیں جن کو انسان اورجانور کھاتے ہیں یہاں تک کہ جب زمین نے سبزہ زار سے اپنے کو آراستہ کرلیا اور مالکوں نے خیال کرنا شروع کردیا کہ اب ہم اس زمین کے صاحب هاختیار ہیں تو اچانک ہمارا حکم رات یا دن کے وقت آگیا اور ہم نے اسے بالکل کٹا ہوا کھیت بنادیا گویا اس میں کل کچھ تھا ہی نہیں -ہم اسی طرح اپنی آیتوں کو مفصل طریقہ سے بیان کرتے ہیں اس قوم کے لئے جو صاحبِ فکر و نظر ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mccclxxxix{اللہ ہر ایک کو سلامتی کے گھر کی طرف دعوت دیتا ہے اور جسے چاہتا ہے سیدھے راستہ کی ہدایت دے دیتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcccxc{جن لوگوں نے نیکی کی ہے ان کے واسطے نیکی بھی ہے اور اضافہ بھی اور ان کے چہروں پر نہ سیاہی ہوگی اور نہ ذلت ,وہ جنّت والے ہیں اور وہیں ہمیشہ رہنے والے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcccxci{اور جن لوگوں نے برائیاں کمائی ہیں ان کے لئے ہر برائی کے بدلے ویسی ہی برائی ہے اور ان کے چہروں پر گناہوں کی سیاہی بھی ہوگی اور انہیں عذاب الٰہی سے بچانے والا کوئی نہ ہوگا -ان کے چہرے پر جیسے سیاہ رات کی تاریکی کا پردہ ڈال دیا گیا ہو -وہ اہل جہّنم ہیں اور اسی میں ہمیشہ رہنے والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcccxcii{جس دن ہم سب کو اکٹھا جمع کریں گے اور اس کے بعد شرک کرنے والوں سے کہیں گے کہ تم اور تمہارے شرکائ سب اپنی اپنی جگہ ٹھہرو اور پھر ہم ان کے درمیان جدائی ڈال دیں گے اور ان کے شرکائ کہیں گے کہ تم ہماری عبادت تو نہیں کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcccxciii{اب خدا ہمارے اور تمہارے درمیان گواہی کے لئے کافی ہے کہ ہم تمہاری عبادت سے بالکل غافل تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcccxciv{اس وقت ہر شخص اپنے گزشتہ اعمال کا امتحان کرے گا اور سب مولائے برحق خداوندتعالیٰ کی بارگاہ میں پلٹا دئیے جائیں گے اور جو کچھ افترا کررہے تھے وہ سب بھٹک کر گم ہوجائے گا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcccxcv{پیغمبر ذرا ان سے پوچھئے کہ تمہیں زمین و آسمان سے کون رزق دیتا ہے اور کون تمہاری سماعت و بصارت کا مالک ہے اور کون لَردہ سے زندہ اور زندہ سے لَردہ کو نکالتا ہے اور کون سارے امور کی تدبیرکرتا ہے تو یہ سب یہی کہیں گے کہ اللہ !تو آپ کہئے کہ پھر اس سے کیوں نہیں ڈرتے ہو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcccxcvi{وہی اللہ تمہارا برحق پالنے والا ہے اور حق کے بعد ضلالت کے سوا کچھ نہیں ہے تو تم کس طرح لے جائے جارہے ہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcccxcvii{اسی طرح خدا کا عذاب فاسقوں کے حق میں ثابت ہوگیا کہ وہ ایمان لانے والے نہیں ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcccxcviii{آپ ذرا پوچھئے کہ کیا تمہارے شریکوں میں کوئی ہے جو خلقت کی ابتدا کرے اور پھر دوبارہ اسے پلٹا سکے اور پھر بتائیے کہ اللہ ہی مخلوقات کی ابتدا کرتا ہے اور وہی انہیں پلٹاتا بھی ہے تو تم آخر کدھر چلے جارہے ہو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcccxcix{کہئے کہ کیا تمہارے شرکائ میں کوئی ایسا ہے جو حق کی ہدایت کرسکے اور پھر بتائیے کہ اللہ ہی حق کی ہدایت کرتا ہے اور جو حق کی ہدایت کرتا ہے وہ واقعا قابلِ اتباع ہے یا جو ہدایت کرنے کے قابل بھی نہیں ہے مگر یہ کہ خود اس کی ہدایت کی جائے تو آخر تمہیں کیاہوگیا ہے اور تم کیسے فیصلے کررہے ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcd{اور ان کی اکثریت تو صرف خیالات کا اتباع کرتی ہے جب کہ گمان حق کے بارے میں کوئی فائدہ نہیں پہنچاسکتا بیشک اللہ ان کے اعمال سے خوب واقف ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcdi{اور یہ قرآن کسی غیر خدا کی طرف سے افترا نہیں ہے بلکہ اپنے ماسبق کی کتابوں کی تصدیق اور تفصیل ہے جس میں کسی شک کی گنجائش نہیں ہے یہ رب العالمین کا نازل کردہ ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcdii{کیا یہ لوگ یہ کہتے ہیں کہ اسے پیغمبر نے گڑھ لیا ہے تو کہہ دیجئے کہ تم اس کے جیسا ایک ہی سورہ لے آؤ اور خدا کے علاوہ جسے چاہو اپنی مدد کے لئے بلالو اگر تم اپنے الزام میں سچے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcdiii{درحقیقت ان لوگوں نے اس چیز کی تکذیب کی ہے جس کا مکمل علم بھی نہیں ہے اور اس کی تاویل بھی ان کے پاس نہیں آئی ہے اسی طرح ان کے پہلے والوں نے بھی تکذیب کی تھی اب دیکھو کہ ظلم کرنے والوں کا انجام کیا ہوتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcdiv{ان میں بعض وہ ہیں جو اس پر ایمان لاتے ہیں اور بعض نہیں مانتے ہیں اور آپ کا پروردگار فساد کرنے والوں کو خوب جانتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcdv{اور اگر یہ آپ کی تکذیب کریں تو کہہ دیجئے کہ میرے لئے میرا عمل ہے اور تمہارے لئے تمہارا عمل ہے تم میرے عمل سے بری اور میں تمہارے اعمال سے بیزار ہوں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcdvi{اور ان میں سے بعض ایسے بھی ہیں جو بظاہر کان لگا کر سنتے بھی ہیں لیکن کیا آپ بہروں کو بات سنانا چاہتے ہیں جب کہ وہ سمجھتے بھی نہیں ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcdvii{اور ان میں کچھ ہیں جو آپ کی طرف دیکھ رہے ہیں تو کیا آپ اندھوں کو بھی ہدایت دے سکتے ہیں چاہے وہ کچھ نہ دیکھ پاتے ہوں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcdviii{اللہ انسانوں پر ذرّہ برابر ظلم نہیں کرتا ہے بلکہ انسان خود ہی اپنے اوپر ظلم کیا کرتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcdix{جس دن خدا ان سب کو محشور کرے گا اس طرح کہ جیسے دنیا میں صرف ایک ساعت ٹھہرے ہوں اور وہ آپس میں ایک دوسرے کو پہچانتے ہوں گے یقیناجن لوگوں نے خدا کی ملاقات کا انکار کیا ہے وہ خسارہ میں رہے اور ہدایت یافتہ نہیں ہوسکے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcdx{اور ہم نے جن باتوں کا ان سے وعدہ کیا ہے انہیں آپ کو دکھادیں یا آپ کو پہلے ہی دنیا سے اٹھالیں انہیں تو بہرحال پلٹ کر ہماری ہی بارگاہ میں آنا ہے اس کے بعد خدا خود ان کے اعمال کا گواہ ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcdxi{اور ہر امّت کے لئے ایک رسول ہے اور جب رسول آجاتا ہے تو ان کے درمیان عادلانہ فیصلہ ہوجاتا ہے اور ان پر کسی طرح کا ظلم نہیں ہوتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcdxii{یہ لوگ کہتے ہیں کہ اگر آپ سّچے ہیں تو یہ وعدہ عذاب کب پورا ہوگا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcdxiii{کہہ دیجئے کہ میں اپنے نفس کے نقصان و نفع کا بھی مالک نہیں ہوں جب تک خدا نہ چاہے -ہر قوم کے لئے ایک مّدت معین ہے جس سے ایک ساعت کی بھی نہ تاخیر ہوسکتی ہے اور نہ تقدیم\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcdxiv{کہہ دیجئے کہ تمہارا کیا خیال ہے اگر اس کا عذاب رات کے وقت یا دن میں آجائے تو تم کیا کرو گے آخر یہ مجرمین کس بات کی جلدی کررہے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcdxv{تو کیا تم عذاب کے نازل ہونے کے بعد ایمان لاؤ گے .... اور کیا اب ایمان لاؤ گے جب کہ تم عذاب کی جلدی مچائے ہوئے تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcdxvi{اس کے بعد ظالمین سے کہا جائے گا کہ اب ہمیشگی کا مزہ چکھو -کیا تمہارے اعمال کے علاوہ کسی اور چیز کا بدلہ دیا جائے گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcdxvii{یہ آپ سے دریافت کرتے ہیں کیا یہ عذاب برحق ہے تو فرما دیجئے کہ ہاں بیشک برحق ہے اور تم خدا کو عاجز نہیں بناسکتے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcdxviii{اگر ہر ظلم کرنے والے نفس کو ساری زمین کے خزینے مل جائیں تو وہ اس دن کے عذاب کے بدلے دے دیگا اور عذاب کے دیکھنے کے بعد اندر اندر نادم بھی ہوگا .... لیکن ان کے درمیان انصاف کے ساتھ فیصلہ کردیا جائے گا اور ان پر کسی طرح کا ظلم نہ کیا جائے گا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcdxix{یاد رکھو کہ خدا ہی کے لئے زمین و آسمان کے کل خزانے ہیں اور آگاہ ہوجاؤ کہ خدا کا وعدہ برحق ہے اگرچہ لوگوں کی اکثریت نہیں سمجھتی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcdxx{وہی خدا حیات و موت کا دینے والا ہے اور اسی کی طرف تم سب کو پلٹا کر لے جایا جائے گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcdxxi{ایہاالناس !تمہارے پاس پروردگار کی طرف سے نصیحت اور دلوں کی شفا کا سامان اور ہدایت اور صاحبانِ ایمان کے لئے رحمت قرآن آچکا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcdxxii{پیغمبر کہہ دیجئے کہ یہ قرآن فضل و رحماُ خدا کا نتیجہ ہے لہٰذا انہیں اس پر خوش ہونا چاہئے کہ یہ ان کے جمع کئے ہوئے اموال سے کہیں زیادہ بہتر ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcdxxiii{آپ کہہ دیجئے کہ خدانے تمہارے لئے رزق نازل کیا تو تم نے اس میں بھی حلال و حرام بنانا شروع کردیا تو کیا خدا نے تمہیں اس کی اجازت دی ہے یا تم خدا پر افترا کررہے ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcdxxiv{اور جو لوگ خدا پر جھوٹا الزام لگاتے ہیں ان کا روز هقیامت کے بارے میں کیا خیال ہے -اللہ انسانوں پر فضل کرنے والا ہے لیکن ان کی اکثریت شکر کرنے والی نہیں ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcdxxv{اور پیغمبر آپ کسی حال میں رہیں اور قرآن کے کسی حصہ کی تلاوت کریں اور اے لوگوں تم کوئی عمل کرو ہم تم سب کے گواہ ہوتے ہیں جب بھی کوئی عمل کرتے ہو اور تمہارے پروردگار سے زمین و آسمان کا کوئی ذرّہ دور نہیں ہے اور کوئی شے ذرّہ سے بڑی یا چھوٹی ایسی نہیں ہے جسے ہم نے اپنی کھلی کتاب میں جمع نہ کردیا ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcdxxvi{آگاہ ہوجاؤ کہ اولیائ خدا پر نہ خوف طاری ہوتا ہے اور نہ وہ محزون اور رنجیدہ ہوتے ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcdxxvii{یہ وہ لوگ ہیں جو ایمان لائے اور خدا سے ڈرتے رہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcdxxviii{ان کے لئے زندگانی دنیا اور آخرت دونوں مقامات پر بشارت اور خوشخبری ہے اور کلمات خدا میں کوئی تبدیلی نہیں ہوسکتی ہے اور یہی درحقیقت عظیم کامیابی ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcdxxix{پیغمبر آپ ان لوگوں کی باتوں سے رنجیدہ نہ ہوں -عزت سب کی سب صرف اللہ کے لئے ہے -وہی سب کچھ سننے والا ہے اور جاننے والا ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcdxxx{آگاہ ہوجاؤ کہ اللہ ہی کے لئے زمین و آسمان کی ساری مخلوقات اور کائنات ہے اور جو لوگ خدا کو چھوڑ کر دوسرے شریکوں کو پکارتے ہیں وہ ان کا بھی اتباع نہیں کرتے -یہ صرف اپنے خیالات کا اتباع کرتے ہیں اور یہ صرف اندازوں پر زندگی گزار رہے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcdxxxi{وہ خدا وہ ہے جس نے تمہارے لئے رات بنائی ہے تاکہ اس میں سکون حاصل کرسکو اور دن کو روشنی کا ذریعہ بنایا ہے اور اس میں بھی بات سننے والی قوم کے لئے نشانیاں پائی جاتی ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcdxxxii{یہ لوگ کہتے ہیں کہ اللہ نے اپنا کوئی بیٹا بنایا ہے حالانکہ وہ پاک و بے نیاز ہے اور اس کے لئے زمین و آسمان کی ساری کائنات ہے -تمہارے پاس تو تمہاری بات کی کوئی دلیل بھی نہیں ہے-کیا تم لوگ خدا پر وہ الزام لگاتے ہو جس کا تمہیں علم بھی نہیں ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiii{پیغمبر آپ کہہ دیجئے کہ جو لوگ خدا پر جھوٹا الزام لگاتے ہیں وہ کبھی کامیاب نہیں ہوسکتے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcdxxxiv{اس دنیا میں تھوڑا سا آرام ہے اس کے بعد سب کی بازگشت ہماری ہی طرف ہے -اس کے بعد ہم ان کے کفر کی بنا پر انہیں شدید عذاب کا مزہ چکھائیں گے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcdxxxv{آپ ان کّفار کے سامنے نوح علیھ السّلام کا واقعہ بیان کریں کہ انہوں نے اپنی قوم سے کہا کہ اگر تمہارے لئے میرا قیام اور آیات الٰہٰیہ کا یاد دلانا سخت ہے تو میرا اعتماد اللہ پر ہے. تم بھی اپناارادہ پختہ کرلو اور اپنے شریکوں کو بلالو اور تمہاری کوئی بات تمہارے اوپر مخفی بھی نہ رہے -پھر جو جی چاہے کر گزرو اور مجھے کسی طرح کی مہلت نہ دو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvi{پھر اگر تم انحراف کرو گے تو میں تم سے کوئی اجر بھی نہیں چاہتا -میرا اجر تو صرف اللہ کے ذمہ ہے اور مجھے حکم دیا گیا ہے کہ میں اس کے اطاعت گزاروں میں شامل رہوں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcdxxxvii{پھر قوم نے ان کی تکذیب کی تو ہم نے نوح علیھ السّلام اور ان کے ساتھیوں کو کشتی میں نجات دے دی اور انہیں زمین کا وارث بنادیا اور اپنی آیات کی تکذیب کرنے والوں کو ڈبو دیا تو اب دیکھئے کہ جن کو ڈرایا جاتا ہے ان کے نہ ماننے کا انجام کیا ہوتا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcdxxxviii{اس کے بعد ہم نے مختلف رسول ان کی قوموں کی طرف بھیجے اور وہ ان کے پاس کھلی ہوئی نشانیاں لے کر آئے لیکن وہ لوگ پہلے کے انکار کرنے کی بنا پر ان کی تصدیق نہ کرسکے اور ہم اسی طرح ظالموں کے دل پر مہر لگادیتے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcdxxxix{پھر ہم نے ان رسولوں کے بعد فرعون اور اس کی جماعت کی طرف موسٰی اور ہارون کو اپنی نشانیاں دے کر بھیجا تو ان لوگوں نے بھی انکار کردیا اور وہ سب بھی مجرم لوگ تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcdxl{پھر جب موسٰی ان کے پاس ہماری طرف سے حق لے کر آئے تو انہوں نے کہا کہ یہ توکھلا ہوا جادو ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcdxli{موسٰی نے جواب دیا کہ تم لوگ حق کے آنے کے بعد اسے جادو کہہ رہے ہو کیا یہ تمہارے نزدیک جادو ہے جب کہ جادوگر کبھی کامیاب نہیں ہوتے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcdxlii{ان لوگوں نے کہا تم یہ پیغام اس لئے لائے ہو کہ ہمیں باپ دادا کے راستہ سے منحرف کردو اور تم دونوں کو زمین میں حکومت و اقتدار مل جائے اور ہم ہرگز تمہاری بات مانتے والے نہیں ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcdxliii{اور فرعون نے کہا کہ تمام ہوشیار ماہر جادوگروں کو میرے پاس حاضر کرو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcdxliv{پھر جب جادوگر آگئے تو موسٰی علیھ السّلامنے ان سے کہا جو جو کچھ پھینکنا چاہتے ہو پھینکو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcdxlv{پھر جب ان لوگوں نے رسیوں کو ڈال دیا تو موسٰی نے کہا کہ جو کچھ تم لے آئے ہو یہ جادو ہے اور اللہ اس کو بیکار کردے گا وہ مفسدین کے عمل کو درست نہیں ہونے دیتا ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcdxlvi{اپنے کلمات کے ذریعہ حق کو ثابت کردیتا ہے چاہے مجرمین کو کتنا ہی برا کیوں نہ لگے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcdxlvii{پھر بھی موسٰی پر ایمان نہ لائے مگر ان کی قوم کی ایک نسل اور وہ بھی فرعون اور اس کی جماعت کے خوف کے ساتھ کہ کہیں وہ کسی آزمائش میں نہ مبتلا کردے کہ فرعون بہت اونچا ہے اور وہ اسراف اور زیادتی کرنے والا بھی ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcdxlviii{اور موسٰی نے اپنی قوم سے کہا کہ اگر تم واقعا اللہ پر ایمان لائے ہو تو اسی پر بھروسہ کرو اگر واقعا اس کے اطاعت گزار بندے ہو\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcdxlix{تو ان لوگوں نے کہا کہ بیشک ہم نے خدا پر بھروسہ کیا ہے. خدایا ہمیں ظالموں کے فتنوں اور آزمائشوں کا مرکز نہ قرار دینا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcdl{اور اپنی رحمت کے ذریعہ کافر قوم کے شر سے محفوظ رکھنا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcdli{اور ہم نے موسٰی اور ان کے بھائی کی طرف وحی کی کہ اپنی قوم کے لئے مصر میں گھر بناؤ اور اپنے گھروں کو قبلہ قرار دو اور نماز قائم کرو اور مومنین کو بشار ت دے دو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcdlii{اور موسٰی نے کہا کہ پروردگار تو نے فرعون اور اس کے ساتھیوں کو زندگانی دنیامیں اموال عطا کئے ہیں -خدایا یہ تیرے راستے سے بہکائیں گے -خدایا ان کے اموال کو برباد کردے -ان کے دلوں پر سختی نازل فرما یہ اس وقت تک ایمان نہ لائیں گے جب تک اپنی آنکھوں سے دردناک عذاب نہ دیکھ لیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcdliii{پروردگار نے فرمایا کہ تم دونوں کی دعا قبول کرلی گئی تو اب اپنے راستے پر قائم رہنا اور جاہلوں کے راستے کا اتباع نہ کرنا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcdliv{اور ہم نے بنی اسرائیل کو دریا پار کرادیا تو فرعون اور اس کے لشکر نے ازراہ هظلم و تعدی ان کا پیچھا کیا یہاں تک کہ جب غرقابی نے اسے پکڑلیا تو اس نے آواز دی کہ میں اس خدائے وحدہ لاشریک پر ایمان لے آیا ہوں جس پر بنی اسرائیل ایمان لائے ہیں اور میں اطاعت گزاروں میں ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcdlv{تو آواز آئی .... کہ اب جب کہ تو پہلے نافرمانی کرچکا ہے اور تیرا شمار مفسدوں میں ہوچکا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcdlvi{خیر ... آج ہم تیرے بدن کو بچالیتے ہیں تاکہ تو اپنے بعد والوں کے لئے نشانی بن جائے اگرچہ بہت سے لوگ ہماری نشانیوں سے غافل ہی رہتے ہیں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcdlvii{اور ہم نے بنی اسرائیل کو بہترین منزل عطا کی ہے اور انہیں پاکیزہ رزق عطا کیا ہے تو ان لوگوں نے آپس میں اختلاف نہیں کیا یہاں تک کہ ان کے پاس توریت آگئی تو اب خدا ان کے درمیان روزِ قیامت ان کے اختلافات کا فیصلہ کردے گا\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcdlviii{اب اگر تم کو اس میں شک ہے جو ہم نے نازل کیا ہے تو ان لوگوں سے پوچھو جو اس کے پہلے کتاب توریت و انجیل پڑھتے رہے ہیں یقینا تمہارے پروردگار کی طرف سے حق آچکا ہے تو اب تم شک کرنے والوں میں شامل نہ ہو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcdlix{اور ان لوگوں میں نہ ہو جاؤ جنہوں نے آیات الہٰیہ کی تکذیب کی ہے کہ اس طرح خسارہ والوں میں شمار ہوجاؤ گے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcdlx{بیشک جن لوگوں پر کلمئہ عذابِ الٰہی ثابت ہوچکا ہے وہ ہرگز ایمان لانے والے نہیں ہیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcdlxi{چاہے ان کے پاس تمام نشانیاں کیوں نہ آجائیں جب تک اپنی آنکھوں سے دردناک عذاب نہ دیکھ لیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcdlxii{پس کوئی بستی ایسی کیوں نہیں ہے جو ایمان لے آئے اور اس کا ایمان اسے فائدہ پہنچائے علاوہ قوم یونس کے کہ جب وہ ایمان لے آئے تو ہم نے ان سے زندگانی دنیا میں رسوائی کا عذاب دفع کردیا اور انہیں ایک مّدت تک چین سے رہنے دیا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcdlxiii{اور اگر خدا چاہتا تو روئے زمین پر رہنے والے سب ایمان لے آتے -تو کیا آپ لوگوں پر جبر کریں گے کہ سب مومن بن جائیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcdlxiv{اور کسی نفس کے امکان میں نہیں ہے کہ بغیر اجازت و توفیق پروردگار کے ایمان لے آئے اور وہ ان لوگوں پر خباثت کو لازم قرار دے دیتا ہے جو عقل استعمال نہیں کرتے ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mcdlxv{پیغمبر کہہ دیجئے کہ ذرا آسمان و زمین میں غور و فکر کرو .... اور یاد رکھئے کہ جو ایمان لانے والے نہیں ہیں ان کے حق میں نشانیاں اور ڈراوے کچھ کام آنے والے نہیں ہیں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mcdlxvi{اب کیا یہ لوگ ان ہی اِرے دنوں کا انتظار کررہے ہیں جو ان سے پہلے والوں پر گزر چکے ہیں تو کہہ دیجئے کہ پھر انتظار کرو میں بھی تمہارے ساتھ انتظار کرنے والوں میں ہوں\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mcdlxvii{اس کے بعد ہم اپنے رسولوں اور ایمان والوں کو نجات دیتے ہیں اور یہ ہمارے اوپر ایک حق ہے کہ ہم صاحبان هایمان کو نجات دلائیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mcdlxviii{پیغمبر آپ کہہ دیجئے کہ اگر تم لوگوں کو میرے دین میں شک ہے تو میں ان کی پرستش نہیں کرسکتا جنہیں تم لوگ خدا کو چھوڑ کر پوج رہے ہو -میں تو صرف اس خدا کی عبادت کرتا ہوں جو تم سب کو موت دینے والا ہے اور مجھے حکم دیا گیا ہے کہ میں صاحبان هایمان میں شامل رہوں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mcdlxix{اور آپ اپنا رخ بالکل دین کی طرف رکھیں. باطل سے الگ رہیں اور ہرگز مشرکین کی جماعت میں شمار نہ ہوں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mcdlxx{اور خدا کے علاوہ کسی ایسے کو آواز نہ دیں جو نہ فائدہ پہنچا سکتا ہے اور نہ نقصان ورنہ ایسا کریں گے تو آپ کا شمار بھی ظالمین میں ہوجائے گا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mcdlxxi{اور اگر خدا نقصان پہنچانا چاہے تو اس کے علاوہ کوئی بچانے والا نہیں ہے اور اگر وہ بھلائی کا ارادہ کرلے تو اس کے فضل کا کوئی روکنے والا نہیں ہے وہ جس کو چاہتا ہے اپنے بندوں میں بھلائی عطا کرتا ہے وہ بڑا بخشنے والا اور مہربان ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mcdlxxii{پیغمبر آپ کہہ دیجئے کہ تمہارے پاس پروردگار کی طرف سے حق آچکا ہے اب جو ہدایت حاصل کرے گا وہ اپنے فائدہ کے لئے کرے گا اور جو گمراہ ہوجائے گا اس کا نقصان بھی اسی کو ہوگا اور میں تمہارا ذمہ دار نہیں ہوں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiii{اور آپ صرف اس بات کا اتباع کریں جس کے آپ کی طرف وحی کی جاتی ہے اور صبر کرتے رہیں یہاں تک کہ خدا کوئی فیصلہ کردے اور وہ بہترین فیصلہ کرنے والا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mcdlxxiv{\basmalahur الۤر - یہ وہ کتاب ہے جس کی آیتیں محکم بنائی گئی ہیں اور ایک صاحبِ علم و حکمت کی طرف سے تفصیل کے ساتھ بیان کی گئی ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcdlxxv{کہ اللہ کے علاوہ کسی کی عبادت نہ کرو -میں اسی کی طرف سے ڈرانے والا اور بشارت دینے والا ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvi{اور اپنے رب سے استغفار کرو پھر اس کی طرف متوجہ ہوجاؤ وہ تم کو مقررہ مدّت میں بہترین فائدہ عطا کرے گا اور صاحبِ فضل کو اس کے فضل کا حق دے گا اور میں تمہارے بارے میں ایک بڑے دن کے عذاب سے خوفزدہ ہوں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcdlxxvii{تم سب کی بازگشت خدا ہی کی طرف ہے اور وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcdlxxviii{آگاہ ہوجاؤ کہ یہ لوگ اپنے سینوں کو دہرائے لے رہے ہیں کہ اس طرح پیغمبر سے چھپ جائیں تو آگاہ رہیں کہ یہ جب اپنے کپڑوں کو خوب لپیٹ لیتے ہیں تو اس وقت بھی وہ ان کے ظاہر و باطن دونوں کو جانتا ہے کہ وہ تمام سینوں کے رازوں کا جاننے والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcdlxxix{اور زمین پر چلنے والی کوئی مخلوق ایسی نہیں ہے جس کا رزق خدا کے ذمہ نہ ہو -وہ ہر ایک کے سونپے جانے کی جگہ اور اس کے قرار کی منزل کو جانتا ہے اور سب کچھ کتاب مبین میں محفوظ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcdlxxx{اور وہی وہ ہے جس نے آسمانوں اور زمین کو چھ دنوں میں پیدا کیا ہے اور اس کا تخت اقتدار پانی پر تھا تاکہ تمہیں آزمائے کہ تم میں سب سے بہتر عمل کرنے والا کون ہے اور اگر آپ کہیں گے کہ تم لوگ موت کے بعد پھر اٹھائے جانے والے ہو تو یہ کافر کہیں گے کہ یہ تو صرف ایک کھلا ہوا جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxi{اور اگر ہم ان کے عذاب کو ایک معینہ مدّت کے لئے ٹال دیں تو طنز کریں گے کہ عذاب کو کس چیز نے روک لیا ہے -آگاہ ہوجاؤ کہ جس دن عذاب آجائے گا تو پھر پلٹنے والا نہیں ہے اور پھر وہ عذاب ان کو ہر طرف سے گھیر لے گا جس کا یہ مذاق اڑا رہے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxii{اور اگر ہم انسان کو رحمت دے کر چھین لیتے ہیں تو مایوس ہوجاتا ہے اور کفر کرنے لگتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiii{اور اگر تکلیف پہنچنے کے بعد نعمت اور آرام کا مزہ چکھا دیتے ہیں تو کہتا ہے کہ اب تو ہماری ساری برائیاں چلی گئیں اور وہ خوش ہوکر اکڑنے لگتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiv{علاوہ ان لوگوں کے جو ایمان لائے ہیں اور انہوں نے نیک اعمال کئے ہیں کہ ان کے لئے مغفرت ہے اور بہت بڑا اجر بھی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxv{پس کیا تم ہماری وحی کے بعض حصوں کو اس لئے ترک کرنے والے ہو یا اس سے تمہارا سینہ اس لئے تنگ ہوا ہے کہ یہ لوگ کہیں گے کہ ان کے اوپر خزانہ کیوں نہیں نازل ہوا یا ان کے ساتھ َمُلک کیوں نہیں آیا ...تو آپ صرف عذاب الٰہی سے ڈرانے والے ہیں اور اللہ ہر شئے کا نگراں اور ذمہ دار ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvi{کیا یہ لوگ کہتے ہیں کہ یہ قرآن بندے نے گڑھ لیا ہے تو کہہ دیجئے کہ اس کے جیسے دس سورہ گڑھ کر تم بھی لے آؤ اور اللہ کے علاوہ جس کو چاہو اپنی مدد کے لئے بلالو اگر تم اپنی بات میں سچے ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvii{پھر اگر یہ آپ کی بات قبول نہ کریں تو تم سب سمجھ لو کہ جو کچھ نازل کیا گیا ہے سب خدا کے علم سے ہے اور اس کے علاوہ کوئی خدا نہیں ہے تو کیا اب تم اسلام لانے والے ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxviii{جو شخص زندگانی دنیا اور اس کی زینت ہی چاہتا ہے ہم اس کے اعمال کا پورا پورا حساب یہیں کردیتے ہیں اور کسی طرح کی کمی نہیں کرتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcdlxxxix{اور یہی وہ ہیں جن کے لئے آخرت میں جہنم ّکے علاوہ کچھ نہیں ہے اور ان کے سارے کاروبار برباد ہوگئے ہیں اور سارے اعمال باطل و بے اثر ہوگئے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcdxc{کیا جو شخص اپنے رب کی طرف سے کھلی دلیل رکھتا ہے اور اس کے پیچھے اس کا گواہ بھی ہے اور اس کے پہلے موسٰی کی کتاب گواہی دے رہی ہے جو قوم کے لئے پیشوا اور رحمت تھی -وہ افترا کرے گا بیشک صاحبانِ ایمان اسی پر ایمان رکھتے ہیں اور جو لوگ اس کا انکار کرتے ہیں ان کاٹھکانہ جہنم ّہے تو خبردار تم اس قرآن کی طرف سے شک میں مبتلا نہ ہونا -یہ خدا کی طرف سے برحق ہے اگرچہ اکثر لوگ اس پر ایمان نہیں لاتے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcdxci{اور اس سے بڑا ظالم کون ہے جو اللہ پر جھوٹا الزام لگاتا ہے. یہی وہ لوگ ہیں جو خدا کے سامنے پیش کئے جائیں گے تو سارے گواہ گواہی دیں گے کہ ان لوگوں نے خدا کے بارے میں غلط بیانی سے کام لیا ہے تو آگاہ ہوجاؤ کہ ظالمین پر خدا کی لعنت ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcdxcii{جو راسِ خدا سے روکتے ہیں اور اس میں کجی پیدا کرنا چاہتے ہیں اور آخرت کے بارے میں کفر اور انکار کرنے والے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcdxciii{یہ لوگ نہ روئے زمین میں خدا کو عاجز کرسکتے ہیں اور نہ خد اکے علاوہ ان کا کوئی ناصر و مددگار ہے ان کا عذاب دگنا کردیا جائے گا کہ یہ نہ حق بات سن سکتے تھے اور نہ اس کے منظر عام کو دیکھ سکتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcdxciv{یہی وہ لوگ ہیں جنہوں نے خود اپنے نفس کو خسارہ میں مبتلا کیا اور ان سے وہ بھی گم ہوگئے جن کا افترا کیا کرتے تھے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcdxcv{یقینا یہ لوگ آخرت میں بہت بڑا گھاٹا اٹھانے والے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcdxcvi{بیشک جو لوگ ایمان لے آئے اور انہوں نے نیک اعمال انجام دئیے اور اپنے رب کی بارگاہ میں عاجزی سے پیش آئے وہی اہل جّنت ہیں اور اس میں ہمیشہ رہنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcdxcvii{کافر اور مسلمان کی مثال اندھے بہرے اور دیکھنے سننے والے کی ہے تو کیا یہ دونوں مثال کے اعتبار سے برابر ہوسکتے ہیں تمہیں ہوش کیوں نہیں آتا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcdxcviii{اور ہم نے نوح کو ان کی قوم کی طرف اس پیغام کے ساتھ بھیجاکہ میں تمہارے لئے کھلے ہوئے عذاب الٰہی سے ڈرانے والا ہوں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcdxcix{اور یہ کہ خبردار تم اللہ کے علاوہ کسی کی عبادت نہ کرنا کہ میں تمہارے بارے میں دردناک دن کے عذاب کا خوف رکھتا ہوں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@md{تو ان کی قوم کے بڑے لوگ جنہوں نے کفر اختیار کرلیا تھا -انہوں نے کہا کہ ہم تو تم کو اپنا ہی جیسا ایک انسان سمجھ رہے ہیں اور تمہارے اتباع کرنے والوں کو دیکھتے ہیں کہ وہ ہمارے پست طبقہ کے سادہ لوح افراد ہیں. ہم تم میں اپنے اوپر کوئی فضیلت نہیں دیکھتے ہیں بلکہ تمہیں جھوٹا خیال کرتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdi{انہوں نے جواب دیا کہ اے قوم تمہارا کیا خیال ہے کہ اگر میں اپنے پروردگار کی طرف سے دلیل رکھتا ہوں اور وہ مجھے اپنی طرف سے وہ رحمت عطا کردے جو تمہیں دکھائی نہ دے تو کیا میں ناگواری کے باوجود زبردستی تمہارے اوپر لادسکتا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdii{اے قوم میں تم سے کوئی مال تو نہیں چاہتا ہوں -میرا اجر تو اللہ کے ذمہ ہے اور میں صاحبان هایمان کو نکال بھی نہیں سکتا ہوں کہ وہ لوگ اپنے پروردگار سے ملاقات کرنے والے ہیں البتہ میں تم کو ایک جاہل قوم تصور کررہا ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdiii{اے قوم میں ان لوگوں کو نکال باہر کردوں تو اللہ کی طرف سے میرا مددگار کون ہوگا کیا تمہیں ہوش نہیں آتا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdiv{اور میں تم سے یہ بھی نہیں کہتا ہوں کہ میرے پاس تمام خدائی خزانے موجود ہیں اور نہ ہر غیب کے جاننے کا دعوٰی کرتا ہوں اور نہ یہ کہتا ہوں کہ میں فرشتہ ہوں اور نہ جو لوگ تمہارے نگاہوں میں ذلیل ہیں ان کے بارے میں یہ کہتا ہوں کہ خدا انہیں خیر نہ دے گا -اللہ ان کے دلوں سے خوب باخبر ہے -میں ایسا کہہ دوں گا تو ظالموں میں شمار ہوجاؤں گا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdv{ان لوگوں نے کہا کہ نوح آپ نے ہم سے جھگڑا کیا اور بہت جھگڑا کیا تو اب جس چیز کا وعدہ کررہے تھے اسے لے آؤ اگر تم اپنے دعوٰی میں سچے ہو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdvi{نوح نے کہا کہ وہ تو خدا لے آئے گا اگر چاہے گا اور تم اسے عاجز بھی نہیں کرسکتے ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdvii{اور میں تمہیں نصیحت بھی کرنا چاہوں تو میری نصیحت تمہارے کام نہیں آئے گی اگر خدا ہی تم کو گمراہی میں چھوڑ دینا چاہے -وہی تمہارا پروردگار ہے اور اسی کی طرف تم پلٹ کر جانے والے ہو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdviii{کیا یہ لوگ یہ کہتے ہیں کہ انہوں نے اپنے پاس سے گڑھ لیا ہے تو آپ کہہ دیجئے کہ اگر میں نے گڑھا ہے تو اس کا جرم میرے ذمہ ہے اور میں تمہارے جرائم سے بری اور بیزار ہوں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdix{اور نوح کی طرف یہ وحی کی گئی کہ تمہاری قوم میں سے اب کوئی ایمان نہ لائے گا علاوہ ان کے جو ایمان لاچکے لہذا تم ان کے افعال سے رنجیدہ نہ ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdx{اور ہماری نگاہوں کے سامنے ہماری وحی کی نگرانی میں کشتی تیار کرو اور ظالموں کے بارے میں مجھ سے بات نہ کرو کہ یہ سب غرق ہوجانے والے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdxi{اور نوح کشتی بنارہے تھے اور جب بھی قوم کی کسی جماعت کا گزر ہوتا تھا تو ان کا مذاق اڑاتے تھے -نوح نے کہا کہ اگر تم ہمارا مذاق اڑاؤ گے تو کل ہم اسی طرح تمہارا بھی مذاق اڑائیں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdxii{پھر عنقریب تمہیں معلوم ہوجائے گا کہ جس کے پاس عذاب آتا ہے اسے رسوا کردیا جاتا ہے اور پھر وہ عذاب دائمی ہی ہوجاتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdxiii{یہاں تک کہ جب ہمارا حکم آگیا اور تنور سے پانی ابلنے لگا تو ہم نے کہا کہ نوح اپنے ساتھ ہر جوڑے میں سے دو کو لے لو اور اپنے اہل کو بھی لے لو علاوہ ان کے جن کے بارے میں ہلاکت کا فیصلہ ہوچکا ہے اور صاحبان هایمان کو بھی لے لو اور ان کے ساتھ ایمان والے بہت ہی کم تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdxiv{نوح نے کہا کہ اب تم سب کشتی میں سوار ہوجاؤ خدا کے نام کے سہارے اس کا بہاؤ بھی ہے اور ٹھہراؤ بھی اور بیشک میرا پروردگار بڑا بخشنے والا مہربان ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdxv{اور وہ کشتی انہیں لے کر پہاڑوں جیسی موجوں کے درمیان چلی جارہی تھی کہ نوح نے اپنے فرزند کو آواز دی جو الگ جگہ پر تھا کہ فرزند ہمارے ساتھ کشتی میں سوار ہوجا اور کافروں میں نہ ہوجا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdxvi{اس نے کہا کہ میں عنقریب پہاڑ پر پناہ لے لوں گا وہ مجھے پانی سے بچالے گا -نوح نے کہا کہ آج حکم خدا سے کوئی بچانے والا نہیں ہے سوائے اس کے جس پر خود خدا رحم کرے اور پھر دونوں کے درمیان موج حائل ہوگئی اور وہ ڈوبنے والوں میں شامل ہوگیا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdxvii{اور قدرت کا حکم ہوا کہ اے زمین اپنے پانی کو نگل لے اور اے آسمان اپنے پانی کو روک لے .اور پھر پانی گھٹ گیا اور کام تمام کردیا گیا اور کشتی کوئہ جودی پر ٹھہر گئی اور آواز آئی کہ ہلاکت قوم هظالمین کے لئے ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdxviii{اور نوح نے اپنے پروردگار کو پکارا کہ پروردگار میرا فرزند میرے اہل میں سے ہے اور تیرا وعدہ اہل کو بچانے کا برحق ہے اور تو بہترین فیصلہ کرنے والا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdxix{ارشاد ہوا کہ نوح یہ تمہارے اہل سے نہیں ہے یہ عمل هغیر صالح ہے لہذا مجھ سے اس چیز کے بارے میں سوال نہ کرو جس کا تمہیں علم نہیں ہے -میں تمہیں نصیحت کرتا ہوں کہ تمہارا شمار جاہلوں میں نہ ہوجائے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdxx{نوح نے کہا کہ خدایا میں اس بات سے پناہ مانگتا ہوں کہ اس چیز کا سوال کروں جس کا علم نہ ہو اور اگر تو مجھے معاف نہ کرے گا اور مجھ پر رحم نہ کرے گا تو میں خسارہ والوں میں ہوجاؤں گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdxxi{ارشاد ہوا کہ نوح ہماری طرف سے سلامتی اور برکتوں کے ساتھ کشتی سے اترو یہ سلامتی اور برکت تمہارے ساتھ کی قوم پر ہے اور کچھ قومیں ہیں جنہیں ہم پہلے راحت دیں گے اس کے بعد ہماری طرف سے دردناک عذاب ملے گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdxxii{پیغمبر علیھ السّلامیہ غیب کی خبریں ہیں جن کی ہم آپ کی طرف وحی کررہے ہیں جن کا علم نہ آپ کو تھا اور نہ آپ کی قوم کو لہذا آپ صبر کریں کہ انجام صاحبان هتقویٰ کے ہاتھ میں ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdxxiii{اور ہم نے قوم عاد کی طرف ان کے بھائی ہود کو بھیجا تو انہوں نے کہا قوم والو اللہ کی عبادت کرو-اس کے علاوہ تمہارا کوئی معبود نہیں ہے.تم صرف افترا کرنے والے ہو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdxxiv{قوم والو میں تم سے کسی اجرت کا سوال نہیں کرتا میرا اجر تو اس پروردگار کے ذمہ ہے جس نے مجھے پیدا کیا ہے کیا تم عقل استعمال نہیں کرتے ہو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdxxv{اے قوم خدا سے استغفار کرو اس کے بعد اس کی طرف ہمہ تن متوجہ ہوجاؤ وہ آسمان سے موسلادھار پانی برسائے گا اور تمہاری موجودہ قوت میں قوت کا اضافہ کردے گا اور خبردار مجرموں کی طرح منہ نہ پھیرلینا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdxxvi{ان لوگوں نے کہا اے ہود تم کوئی معجزہ تو لائے نہیں اور ہم صرف تمہارے کہنے پر اپنے خداؤں کو چھوڑنے والے اور تمہاری بات پر ایمان لانے والے نہیں ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdxxvii{ہم صرف یہ کہنا چاہتے ہیں کہ ہمارے خداؤں میں سے کسی نے آپ کو دیوانہ بنادیا ہے -ہود نے کہا کہ میں خدا کو گواہ بناکر کہتا ہوں اور تم بھی گواہ رہنا کہ میں تمہارے شرک سے بیزار ہوں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdxxviii{لہذا تم سب مل کر میرے ساتھ مکاری کرو اور مجھے مہلت نہ دو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdxxix{میرا اعتماد پروردگار پر ہے جو میرا اور تمہارا سب کا خدا ہے اور کوئی زمین پر چلنے والا ایسا نہیںہے جس کی پیشانی اس کے قبضہ میں نہ ہو میرے پروردگار کا راستہ بالکل سیدھا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdxxx{اس کے بعد بھی انحراف کرو تو میں نے خدائی پیغام کو پہنچادیا ہے اب خدا تمہاری جگہ پر دوسری قوموں کو لے آئے گا اور تم اس کا کچھ نہیں بگاڑ سکتے ہو بیشک میرا پروردگار ہر شے کا نگراں ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdxxxi{اور جب ہمارا حکم آگیا تو ہم نے ہود اور ان کے ساتھ ایمان لانے والوں کو اپنی رحمت سے بچالیااور انہیں سخت عذاب سے نجات دے دی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdxxxii{یہ قوم عاد ہے جس نے پروردگار کی آیتوں کا انکار کیا اس کے رسولوں کی نافرمانی کی اور ہر ظالم و سرکش کا اتباع کرلیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdxxxiii{اور اس دنیا میں بھی اور قیامت میں بھی ان کے پیچھے لعنت لگادی گئی ہے -آگاہ ہوجاؤ کہ عاد نے اپنے پررودگار کا کفر کیا تو اب ہود کی قوم عاد کے لئے ہلاکت ہی ہلاکت ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdxxxiv{اور ہم نے قوم ثمود کی طرف ان کے بھائی صالح کو بھیجا اور انہوں نے کہا کہ اے قوم اللہ کی عبادت کرو اس کے علاوہ کوئی خدا نہیں ہے اس نے تمہیںزمین سے پیدا کیا ہے اور اس میں آباد کیا ہے اب اس سے استغفار کرو اور اس کی طرف متوجہ ہوجاؤ کہ میرا پروردگار قریب تر اور دعاؤں کا قبول کرنے والا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdxxxv{ان لوگوں نے کہا کہ اے صالح اس سے پہلے تم سے بڑی امیدیں وابستہ تھیں کیا تم اس بات سے روکتے ہو کہ ہم اپنے بزرگوں کے معبودوں کی پرستش کریں -ہم یقینا تمہاری دعوت کی طرف سے شک اور شبہ میں ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdxxxvi{انہوں نے کہا اے قوم تمہارا کیا خیال ہے کہ اگر میں اپنے پروردگار کی طرف سے دلیل رکھتا ہوں اور اس نے مجھے رحمت عطا کی ہے تو اگر میں اس کی نافرمانی کروں گا تو اس کے مقابلہ میں کون میری مدد کرسکے گا تم تو گھاٹے میں اضافہ کے علاوہ کچھ نہیں کرسکتے ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdxxxvii{اے قوم یہ ناقہ اللہ کی طرف سے ایک نشانی ہے اسے آزاد چھوڑ دو تاکہ زمین هخدا میں چین سے کھائے اور اسے کسی طرح کی تکلیف نہ دینا کہ تمہیں جلدی ہی کوئی عذاب اپنی گرفت میں لے لے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdxxxviii{اس کے بعد بھی ان لوگوں نے اس کی کونچیں کاٹ دیں تو صالح نے کہا کہ اب اپنے گھروں میں تین دن تک اور آرام کرو کہ یہ وعدہ الٰہی ہے جو غلط نہیں ہوسکتا ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdxxxix{اس کے بعد جب ہمارا حکم عذاب آپہنچا تو ہم نے صالح اور ان کے ساتھ کے صاحبانِ ایمان کو اپنی رحمت سے اپنے عذاب اور اس دن کی رسوائی سے بچالیا کہ تمہارا پروردگار صاحب هقوت اور سب پر غالب ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdxl{اور ظلم کرنے والوں کو ایک چنگھاڑنے اپنی لپیٹ میں لے لیا تو وہ اپنے دیار میں اوندھے پڑے رہ گئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdxli{جیسے کبھی یہاں بسے ہی نہیں تھے -آگاہ ہوجاؤ کہ ثمود نے اپنے رب کی نافرمانی کی ہے اور ہوشیار ہوجاؤ کہ ثمود کے لئے ہلاکت ہی ہلاکت ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdxlii{اور ابراہیم کے پاس ہمارے نمائندے بشارت لے کر آئے اور آکر سلام کیا تو ابراہیم نے بھی سلام کیا اور تھوڑی دیر نہ گزری تھی کہ بھنا ہوا بچھڑا لے آئے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdxliii{اور جب دیکھا کہ ان لوگوں کے ہاتھ ادھر نہیں بڑھ رہے ہیں تو تعجب کیا اور ان کی طرف سے خوف محسوس کیا انہوں نے کہا کہ آپ ڈریں نہیں ہم قوم لوط کی طرف بھیجے گئے ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdxliv{ابراہیم کی زوجہ اسی جگہ کھڑی تھیں یہ سن کر ہنس پڑیں تو ہم نے انہیں اسحاق کی بشارت دے دی اور اسحاق کے بعد پھر یعقوب کی بشارت دی\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdxlv{تو انہوں نے کہا کہ یہ مصیبت اب میرے یہاں بچہ ہوگا جب کہ میں بھی بوڑھی ہوں اور میرے میاں بھی بوڑھے ہیں یہ تو بالکل عجیب سی بات ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdxlvi{فرشتوں نے کہا کہ کیا تمہیں حکم الٰہی میں تعجب ہورہا ہے اللہ کی رحمت اور برکت تم گھر والوں پر ہے وہ قابلِ حمد اور صاحب همجد و بزرگی ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdxlvii{اس کے بعد جب ابراہیم کا خوف برطرف ہوا اور ان کے پاس بشارت بھی آچکی تو انہوں نے ہم سے قوم لوط کے بارے میں اصرار کرنا شروع کردیا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdxlviii{بیشک ابراہیم بہت ہی دردمند اور خدا کی طرف رجوع کرنے والے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdxlix{ابراہیم اس بات سے اعراض کرو -اب حکم خدا آچکا ہے اور ان لوگوں تک وہ عذاب آنے والا ہے جو پلٹایا نہیں جاسکتا\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdl{اور جب ہمارے فرستادے لوط کے پاس پہنچے تو وہ ان کے خیال سے رنجیدہ ہوئے اور تنگ دل ہوگئے اور کہا کہ یہ بڑا سخت دن ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdli{اور ان کی قوم دوڑتی ہوئی آگئی اور اس کے پہلے بھی یہ لوگ ایسے برے کام کررہے تھے لوط نے کہا اے قوم یہ ہماری لڑکیاں تمہارے لئے زیادہ پاکیزہ ہیں خدا سے ڈرو اور مہمانوں کے بارے میں مجھے شرمندہ نہ کرو کیا تم میں کوئی سمجھدار آدمی نہیں ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdlii{ان لوگوں نے کہا کہ آپ جانتے ہیں کہ ہمیں آپ کی لڑکیوں میں کوئی دلچسپی نہیں ہے اور آپ کو معلوم ہے کہ ہم کیا چاہتے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdliii{لوط نے کہا کاش میرے پاس قوت ہوتی یا میں کسی مضبوط قلعہ میں پناہ لے سکتا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdliv{تو فرشتوں نے کہا کہ ہم آپ کے پروردگار کے نمائندے ہیں یہ ظالم آپ تک ہرگز نہیں پہنچ سکتے ہیں -آپ اپنے گھر والوں کو لے کر رات کے کسے حّصے میں چلے جائیے اور کوئی شخص کسی کی طرف مڑ کر بھی نہ دیکھے سوائے آپ کی زوجہ کے کہ اس تک وہی عذاب آنے والا ہے جو قوم تک آنے والا ہے ان کا وقت مقرر ہنگام هصبح ہے اور کیا صبح قریب نہیں ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdlv{پھر جب ہمارا عذاب آگیا تو ہم نے زمین کو تہ و بالا کردیا اور ان پر مسلسل کھرنجے دار پتھروں کی بارش کردی\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdlvi{جن پر خدا کی طرف سے نشان لگے ہوئے تھے اور وہ بستی ان ظالموں سے کچھ دور نہیں ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdlvii{اور ہم نے مدین کی طرف ان کے بھائی شعیب کو بھیجا تو انہوں نے کہا کہ اے قوم اللہ کی عبادت کر کہ اس کہ علاوہ تیرا کوئی خدا نہیں ہے اور خبردار ناپ تول میں کمی نہ کرنا کہ میں تمہیں بھلائی میں دیکھ رہا ہوں اور میں تمہارے بارے میں اس دن کے عذاب سے ڈرتا ہوں جو سب کو احاطہ کرلے گا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdlviii{اے قوم ناپ تول میں انصاف سے کام لو اور لوگوں کو کم چیزیں مت دو اور روئے زمین میں فساد مت پھیلاتے پھرو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdlix{اللہ کی طرف کا ذخیرہ تمہارے حق میں بہت بہتر ہے اگر تم صاحبِ ایمان ہو اور میں تمہارے معاملات کا نگراں اور ذمہ دار نہیں ہوں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdlx{ان لوگوں نے طنز کیا کہ شعیب کیا تمہاری نماز تمہیں یہ حکم دیتی ہے کہ ہم اپنے بزرگوں کے معبودوں کو چھوڑ دیں یا اپنے اموال میں اپنی مرضی کے مطابق تصرف نہ کریں تم تو بڑے بردبار اور سمجھ دار معلوم ہوتے ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdlxi{شعیب نے کہا کہ اے قوم والو تمہارا کیا خیال ہے کہ اگر میں خدا کی طرف سے روشن دلیل رکھتا ہوں اور اس نے مجھے بہترین رزق عطا کردیا ہے اور میں یہ بھی نہیں چاہتا ہوں کہ جس چیز سے تم کو روکتا ہوں خود اسی کی خلاف ورزی کروں میں تو صرف اصلاح چاہتا ہوں جہاں تک میرے امکان میں ہو -میری توفیق صرف اللہ سے وابستہ ہے اسی پر میرا اعتماد ہے اور اسی کی طرف میں توجہ کررہا ہوں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdlxii{اور اے قوم کہیں میری مخالفت تم پر ایسا عذاب نازل نہ کرادے جیسا عذاب قوم نوح علیھ السّلام,قوم ہود علیھ السّلامیا قوم صالح علیھ السّلام پر نازل ہوا تھا اور قوم لوط بھی تم سے کچھ دور نہیں ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdlxiii{اور اپنے پروردگار سے استغفار کرو اس کے بعد اس کی طرف متوجہ ہوجاؤ کہ بیشک میرا پروردگار بہت مہربان اور محبت کرنے والا ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdlxiv{ان لوگوں نے کہا کہ اے شعیب آپ کی اکثر باتیں ہماری سمجھ میں نہیں آتی ہیں اور ہم توآپ کو اپنے درمیان کمزور ہی پارہے ہیں کہ اگر آپ کا قبیلہ نہ ہوتا تو ہم آپ کو سنگسار کردیتے اور آپ ہم پر غالب نہیں آسکتے تھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdlxv{شعیب نے کہا کہ کیا میرا قبیلہ تمہاری نگاہ میں اللہ سے زیادہ عزیز ہے اور تم نے اللہ کو بالکل پس پشت ڈال دیا ہے جب کہ میرا پروردگار تمہارے اعمال کا خوب احاطہ کئے ہوئے ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdlxvi{اور اے قوم تم اپنی جگہ پر اپنا کام کرو میں اپنا کام کررہا ہوں عنقریب جان لو گے کہ کس کے پاس عذاب آکر اسے رسوا کردیتا ہے اور کون جھوٹا ہے اور انتظار کرو کہ میں بھی تمہارے ساتھ انتظار کرنے والا ہوں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdlxvii{اور جب ہمارا حکم (عذاب)آگیا تو ہم نے شعیب اور ان کے ساتھ ایمان لانے والوں کو اپنی رحمت سے بچالیا اور ظلم کرنے والوں کو ایک چنگھاڑنے پکڑ لیا تو وہ اپنے دیار ہی میں الٹ پلٹ ہوگئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdlxviii{جیسے کبھی یہاں بسے ہی نہیں تھے اور آگاہ ہوجاؤ کہ قوم مدین کے لئے ویسے ہی ہلاکت ہے جیسے قوم ثمود ہلاک ہوگئی تھی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdlxix{اور ہم نے موسٰی کو اپنی نشانیوں اور روشن دلیل کے ساتھ بھیجا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdlxx{فرعون اور اس کی قوم کی طرف تو لوگوں نے فرعون کے حکم کا اتباع کرلیا جب کہ فرعون کا حکم عقل و ہوش والا حکم نہیں تھا\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdlxxi{وہ روزِ قیامت اپنی قوم کے آگے آگے چلے گا اور انہیں جہّنم ّمیں وارد کردے گا جو بدترین وارد ہونے کی جگہ ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdlxxii{ان لوگوں کے پیچھے اس دنیا میں بھی لعنت لگادی گئی ہے اور روز قیامت بھی یہ بدترین عطیہ ہے جو انہیں دیا جائے گا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdlxxiii{یہ چند بستیوں کی خبریں ہیں جو ہم آپ سے بیان کررہے ہیں -ان میں سے بعض باقی رہ گئی ہیں اور بعض کٹ پٹ کر برابر ہو گئی ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdlxxiv{اور ہم نے ان پر کوئی ظلم نہیں کیا ہے بلکہ انہوں نے خود اپنے اوپر ظلم کیا ہے تو عذاب کے آجانے کے بعد ان کے وہ خدا بھی کام نہ آئے جنہیں وہ خدا کو چھوڑ کر پکار رہے تھے اور ان خداؤں نے مزید ہلاکت کے علاوہ انہیں کچھ نہیں دیا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdlxxv{اور اسی طرح تمہارے پروردگار کی گرفت ہوتی ہے جب وہ ظلم کرنے والی بستیوں کو اپنی گرفت میں لے لیتا ہے کہ اس کی گرفت بہت ہی سخت اور دردناک ہوتی ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdlxxvi{اس بات میں ان لوگوں کے لئے نشانی پائی جاتی ہے جو عذاب آخرت سے ڈرنے والے ہیں -وہ دن جس دن تمام لوگ جمع کئے جائیں گے اور وہ سب کی حاضری کا دن ہوگا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdlxxvii{اور ہم اپنے عذاب کو صرف ایک معینہ مدّت کے لئے ٹال رہے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdlxxviii{اس کے بعد جس دن وہ آجائے گا تو کوئی شخص بھی ِذنِ خدا کے بغیر کسی سے بات بھی نہ کرسکے گا -اس دن کچھ بدبخت ہوں گے اور کچھ نیک بخت\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdlxxix{پس جو لوگ بدبخت ہوں گے وہ جہّنم میں رہیں گے جہاں اُن کے لئے صرف ہائے وائے اور چیخ پکار ہوگی\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdlxxx{وہ وہیں ہمیشہ رہنے والے ہیں جب تک آسمان و زمین قائم ہیں مگر یہ کہ آپ کا پروردگار نکالنا چاہے کہ وہ جو بھی چاہے کرسکتا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdlxxxi{اور جو لوگ نیک بخت ہیں وہ جنت میں ہوں گے اور وہیں ہمیشہ رہیں گے جب تک کہ آسمان و زمین قائم ہیں مگر یہ کہ پروردگار اس کے خلاف چاہے ...._یہ خدا کی ایک عطا ہے جو ختم ہونے والی نہیں ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdlxxxii{لہذا خدا کے علاوہ جس کی بھی یہ پرستش کرتے ہیں اس کی طرف سے آپ کسی شبہ میں نہ پڑیں یہ اسی طرح پرستش کررہے ہیں جس طرح ان کے باپ دادا کررہے تھے اور ہم انہیں پورا پورا حّصہ بغیر کسی کمی کے دیں گے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiii{اور ہم نے موسٰی علیھ السّلام کو کتاب دی تو اس میں بھی اختلاف پیدا کردیا گیا اور اگر تمہارے پروردگار کی طرف سے پہلے بات نہ ہوگئی ہوتی تو ان کے درمیان فیصلہ کردیا جاتا اور یہ لوگ اس عذاب کی طرف سے شک میں پڑے ہوئے ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdlxxxiv{اور یقیناتمہارا پروردگار سب کے اعمال کا پورا پورا بدلہ دے گا اور وہ ان سب کے اعمال سے خوب باخبر ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdlxxxv{لہذا آپ کو جس طرح حکم دیا گیا ہے اسی طرح استقامت سے کام لیں اور وہ بھی جنہوں نے آپ کے ساتھ توبہ کرلی ہے اور کوئی کسی طرح کی زیادتی نہ کرے کہ خدا سب کے اعمال کو خوب دیکھنے والا ہے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvi{اور خبردار تم لوگ ظالموں کی طرف جھکاؤ اختیار نہ کرنا کہ جہّنم کی آگ تمہیں چھولے گی اور خدا کے علاوہ تمہارا کوئی سرپرست نہیں ہوگا اور تمہاری مدد بھی نہیں کی جائے گی\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mdlxxxvii{اور پیغمبر آپ دن کے دونوں حصّو ں میں اور رات گئے نماز قائم کریں کہ نیکیاں برائیوں کو ختم کردینے والی ہیں اور یہ ذک» خدا کرنے والوں کے لئے ایک نصیحت ہے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mdlxxxviii{اور آپ صبر سے کام لیں کہ خدا نیک عمل کرنے والوں کے اجر کو ضائع نہیں کرتا ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mdlxxxix{تو تمہارے پہلے والے زمانوں اور نسلوں میں ایسے صاحبان عقل کیوں نہیں پیدا ہوئے ہیں جو لوگوں کو زمین میں فساد پھیلانے سے روکتے علاوہ ان چند افراد کے جنہیں ہم نے نجات دے دی اور ظالم تو اپنے عیش ہی کے پیچھے پڑے رہے اور یہ سب کے سب مجرم تھے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mdxc{اور آپ کے پروردگار کا کام یہ نہیں ہے کہ کسی قریہ کو ظلم کرکے تباہ کردے جب کہ اس کے رہنے والے اصلاح کرنے والے ہوں\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mdxci{اور اگر آپ کا پروردگار چاہ لیتا تو سارے انسانوں کو ایک قوم بنادیتا (لیکن وہ جبر نہیں کرتاہے) لہذا یہ ہمیشہ مختلف ہی رہیں گے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mdxcii{علاوہ ان کے جن پر خدا نے رحم کردیا ہو اور اسی لئے انہیں پیدا کیا ہے اور آپ کے پروردگار کی یہ بات قطعی حق ہے کہ ہم جہنم ّکو انسانوں اور جنوں سے بھر کر رہیں گے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mdxciii{اور ہم قدیم رسولوں کے واقعات آپ سے بیان کررہے ہیں کہ ان کے ذریعہ آپ کے دل کو مضبوط رکھیں اور ان واقعات میں حق ,نصیحت اور صاحبان هایمان کے لئے سامانِ عبرت بھی ہے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mdxciv{اور آپ ان بے ایمانوں سے کہہ دیں کہ تم اپنی جگہ پر کام کرو اور ہم اپنی جگہ پر اپنا کام کررہے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mdxcv{اور پھر انتظار کرو کہ ہم بھی انتظار کرنے والے ہیں\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mdxcvi{اور اللہ ہی کے لئے آسمان اور زمین کا کل غیب ہے اور اسی کی طرف تمام امور کی بازگشت ہے لہذا آپ اسی کی عبادت کریں اور اسی پر اعتماد کریں کہ آپ کا رب لوگوں کے اعمال سے غافل نہیں ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mdxcvii{\basmalahur آلر-یہ کتاب مبین کی آیتیں ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdxcviii{ہم نے اسے عربی قرآن بناکر نازل کیا ہے کہ شاید تم لوگوں کو عقل آجائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdxcix{پیغمبر ہم آپ کے سامنے ایک بہترین قصہ بیان کررہے ہیں جس کی وحی اس قرآن کے ذریعہ آپ کی طرف کی گئی ہے اگرچہ اس سے پہلے آپ اس کی طرف سے بے خبر لوگوں میں تھے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdc{اس وقت کو یاد کرو جب یوسف نے اپنے والد سے کہا کہ بابا میں نے خواب میں گیارہ ستاروں اور آفتاب و ماہتاب کو دیکھا ہے اور یہ دیکھا ہے کہ یہ سب میرے سامنے سجدہ کررہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdci{یعقوب نے کہا کہ بیٹا خبردار اپنا خواب اپنے بھائیوں سے بیان نہ کرنا کہ وہ لوگ الٹی سیدھی تدبیروں میں لگ جائیں گے کہ شیطان انسان کا بڑا کھلا ہوا دشمن ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcii{اور اسی طرح تمہارا پروردگار تمہیں منتخب کرے گا اور تمہیں باتوں کی تاویل سکھائے گا اور تم پر اور یعقوب کی دوسری اولاد پر اپنی نعمت کو تمام کرے گا جس طرح تمہارے دادا پرداد ابراہیم اور اسحاق پر تمام کرچکا ہے بیشک تمہارا پروردگار بڑا جاننے والا ہے اور صاحب هحکمت ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdciii{یقینا یوسف اور ان کے بھائیوں کے واقعہ میں سوال کرنے والوں کے لئے بڑی نشانیاں پائی جاتی ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdciv{جب ان لوگوں نے کہا کہ یوسف اور ان کے بھائی (ابن یامین)ہمارے باپ کی نگاہ میں زیادہ محبوب ہیں حالانکہ ہماری ایک بڑی جماعت ہے یقیناہمارے ماں باپ ایک کھلی ہوئی گمراہی میں مبتلا ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcv{تم لوگ یوسف کو قتل کردو یا کسی زمین میں پھینک دو تو باپ کا رخ تمہاری ہی طرف ہوجائے گا اور تم سب ان کے بعد صالح قوم بن جاؤ گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcvi{ان میں سے ایک شخص نے کہا کہ یوسف کو قتل نہ کرو بلکہ کسی اندھے کنویں میں ڈال دو تاکہ کوئی قافلہ اٹھالے جائے اگر تم کچھ کرنا ہی چاہتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcvii{ان لوگوں نے یعقوب سے کہا کہ بابا کیا بات ہے کہ آپ یوسف کے بارے میں ہم پر بھروسہ نہیں کرتے ہیں حالانکہ ہم ان پر شفقت کرنے والے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcviii{کل ہمارے ساتھ بھیج دیجئے کچھ کھائے پئے اور کھیلے اور ہم تو اس کی حفاظت کرنے والے موجود ہی ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcix{یعقوب نے کہا کہ مجھے اس کالے جانا تکلیف پہنچاتا ہے اور میں ڈرتا ہوں کہ کہیں اسے بھیڑیا نہ کھاجائے اور تم غافل ہی رہ جاؤ\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcx{اور ان لوگوں نے کہا کہ اگر اسے بھیڑیا کھاگیا اور ہم سب اس کے بھائی ہی ہیں تو ہم بڑے خسارہ والوں میں ہوجائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcxi{اس کے بعد جب وہ سب یوسف کو لے گئے اور یہ طے کرلیا کہ انہیں اندھے کنویں میں ڈال دیں اور ہم نے یوسف کی طرف وحی کردی کہ عنقریب تم ان کو اس سازش سے باخبر کرو گے اور انہیں خیال بھی نہ ہوگا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcxii{اور وہ لوگ رات کے وقت باپ کے پاس روتے پیٹے آئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcxiii{کہنے لگے بابا ہم دوڑ لگانے چلے گئے اور یوسف کو اپنے سامان کے پاس چھوڑ دیا تو ایک بھیڑیا آکر انہیں کھاگیا اور آپ ہماری بات کا یقین نہ کریں گے چاہے ہم کتنے ہی سچے کیوں نہ ہوں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcxiv{اور یوسف کے کرتے پر جھوٹا خون لگاکر لے آئے -یعقوب نے کہا کہ یہ بات صرف تمہارے دل نے گڑھی ہے لہذا میرا راستہ صبر جمیل کا ہے اور اللہ تمہارے بیان کے مقابلہ میں میرا مددگارہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcxv{اور وہاں ایک قافلہ آیا جس کے پانی نکالنے والے نے اپنا ڈول کنویں میں ڈالا تو آواز دی ارے واہ یہ تو بچہ ہے اور اسے ایک قیمتی سرمایہ سمجھ کر چھپالیا اور اللہ ان کے اعمال سے خوب باخبر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcxvi{اور ان لوگوں نے یوسف کو معمولی قیمت پر بیچ ڈالا چند درہم کے عوض اور وہ لوگ تو ان سے بیزار تھے ہی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcxvii{اور مصر کے جس شخص نے انہیں خریدا تھا اس نے اپنی بیوی سے کہاکہ اسے عزّت و احترام کے ساتھ رکھو شاید یہ ہمیں کوئی فائدہ پہنچائے یا ہم اسے اپنا فرزند بنالیں اور اس طرح ہم نے یوسف کو زمین میں اقتدار دیا اور تاکہ اس طرح انہیں خوابوں کی تعبیر کا علم سکھائیں اور اللہ اپنے کام پر غلبہ رکھنے والا ہے یہ اور بات ہے کہ اکثر لوگوں کو اس کا علم نہیں ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcxviii{اور جب یوسف اپنی جوانی کی عمر کو پہنچے تو ہم نے انہیں حکم اور علم عطا کردیا کہ ہم اسی طرح نیک عمل کرنے والوں کو جزا دیا کرتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcxix{اور اس نے ان سے اظہار همحبتّ کیا جس کے گھر میں یوسف رہتے تھے اور دروازے بند کردیئے اور کہنے لگی لو آؤ یوسف نے کہا کہ معاذ اللہ وہ میرا مالک ہے اس نے مجھے اچھی طرح رکھا ہے اور ظلم کرنے والے کبھی کامیاب نہیں ہوتے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcxx{اور یقینااس عورت نے ان سے برائی کا ارادہ کیااور وہ بھی ارادہ کربیٹھتے اگر اپنے رب کی دلیل نہ دیکھ لیتے یہ تو ہم نے اس طرح کا انتظام کیا کہ ان سے برائی اور بدکاری کا رخ موڑ دیں کہ وہ ہمارے مخلص بندوں میں سے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcxxi{اور دونوں نے دروازے کی طرف سبقت کی اور اس نے ان کا کرتا پیچھے سے پھاڑ دیا اور دونوں نے اس کے سردار کو دروازہ ہی پر دیکھ لیا -اس نے گھبرا کر فریاد کی کہ جو تمہاری عورت کے ساتھ برائی کا ارادہ کرے اس کی سزا اس کے علاوہ کیا ہے کہ اسے قیدی بنادیاجائے یا اس پر دردناک عذاب کیا جائے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcxxii{یوسف نے کہا کہ اس نے خود مجھ سے اظہار محبت ّکیا ہے اور اس پر اس کے گھر والوں میں سے ایک گواہ نے گواہی بھی دے دی کہ اگر ان کا دامن سامنے سے پھٹا ہے تو وہ سچی ہے اور یہ جھوٹوں میں سے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcxxiii{اور اگر ان کا کرتا پیچھے سے پھٹا ہے تو وہ جھوٹی ہے یہ سچوں میںسے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcxxiv{پھر جو دیکھاکہ ان کا کرتا پیچھے سے پھٹا ہے توا س نے کہا کہ یہ تم عورتوں کی مّکاری ہے تمہارا مکر بہت عظیم ہوتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcxxv{یوسف اب تم اس سے اعراض کرو اور زلیخا تو اپنے گناہ کے لئے استغفار کر کہ تو خطاکاروں میں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcxxvi{اور پھر شہر کی عورتوں نے کہنا شروع کردیا کہ عزیز مصر کی عورت اپنے جوان کو اپنی طرف کھینچ رہی تھی اور اسے اس کی محبت نے مدہوش بنادیا تھا ہم یہ دیکھ رہے ہیں کہ یہ عورت بالکل ہی کھلی ہوئی گمراہی میں ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcxxvii{پھر جب زلیخا نے ان عورتوں کی مکاری اور تشہیر کا حال سنا تو بلا بھیجا اور ان کے لئے پرتکلف دعوت کا انتطام کرکے مسند لگادی اور سب کو ایک ایک چھری دے دی اور یوسف سے کہا کہ تم ان کے سامنے سے نکل جاؤ پھر جیسے ہی ان لوگوں نے دیکھا تو بڑا حسین و جمیل پایا اور اپنے ہاتھ کاٹ ڈالے اور کہا کہ ماشائ اللہ یہ تو آدمی نہیں ہے بلکہ کوئی محترم فرشتہ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcxxviii{زلیخا نے کہا کہ یہی وہ ہے جس کے بارے میں تم لوگوں نے میری ملامت کی ہے اور میں نے اسے کھینچنا چاہا تھا کہ یہ بچ کر نکل گیا اور جب میری بات نہیں مانی تو اب قید کیا جائے گا اور ذلیل بھی ہوگا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcxxix{یوسف نے کہا کہ پروردگار یہ قید مجھے اس کام سے زیادہ محبوب ہے جس کی طرف یہ لوگ دعوت دے رہی ہیں اور اگر تو ان کے مکر کو میری طرف سے موڑ نہ دے گا تو میں ان کی طرف مائل ہوسکتا ہوں اور میرا شمار بھی جاہلوں میں ہوسکتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcxxx{تو ان کے پروردگار نے ان کی بات قبول کرلی اور ان عورتوں کے مکر کو پھیر دیا کہ وہ سب کی سننے والا اور سب کا جاننے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcxxxi{اس کے بعد ان لوگوں کو تمام نشانیاں دیکھنے کے بعد بھی یہ خیال آگیا کہ کچھ مدّت کے لئے یوسف کو قیدی بنا دیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcxxxii{اور قید خانہ میں ان کے ساتھ دو جوان اور داخل ہوئے ایک نے کہا کہ میں نے خواب میں اپنے کو شراب نچوڑتے دیکھا ہے اور دوسرے نے کہا میں نے دیکھا ہے کہ میں اپنے سر پر روٹیاں لادے ہوں اور پرندے اس میں سے کھارہے ہیں -ذرا اس کی تاوہل تو بتاؤ کہ ہماری نظر میں تم نیک کردار معلوم ہوتے ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiii{یوسف نے کہا کہ جو کھانا تم کو دیا جاتا ہے وہ نہ آنے پائے گا اور میں تمہیں تعبیر بتادوں گا -یہ تعبیر مجھے میرے پروردگار نے بتائی ہے اور میں نے اس قوم کے راستے کو چھوڑ دیا ہے جس کا ایمان اللہ پر نہیں ہے اور وہ روز هآخرت کا بھی انکار کرنے والی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcxxxiv{میں اپنے باپ دادا ابراہیم -اسحاق اور یعقوب کے طریقے کا پیرو ہوں -میرے لئے ممکن نہیں ہے کہ میں کسی چیز کو بھی خدا کا شریک بناؤں -یہ تو میرے اوپر اور تمام انسانوں پر خدا کا فضل و کرم ہے لیکن انسانوں کی اکثریت شکر خدا نہیں کرتی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcxxxv{میرے قید خانے کے ساتھیو !ذرا یہ تو بتاؤ کہ متفرق قسم کے خدا بہتر ہوتے ہیں یا ایک خدائے واحدُ و قہار\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvi{تم اس خدا کو چھوڑ کر صرف ان ناموں کی پرستش کرتے ہو جنہیں تم نے خود رکھ لیا ہے یا تمہارے آبائ و اجداد نے -اللہ نے ان کے بارے میں کوئی دلیل نازل نہیں کی ہے جب کہ حکم کرنے کا حق صرف خدا کو ہے اور اسی نے حکم دیا ہے کہ اس کے علاوہ کسی کی عبادت نہ کی جائے کہ یہی مستحکم اور سیدھا دین ہے لیکن اکثر لوگ اس بات کو نہیں جانتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcxxxvii{میرے قید خانے کے ساتھیو تم سے ایک اپنے مالک کو شراب پلائے گا اور دوسرا سولی پر لٹکادیا جائے گا اور پرندے اس کے سر سے نوچ نوچ کر کھائیں گے یہ اس بات کے بارے میں فیصلہ ہوچکا ہے جس کے بارے میں تم سوال کررہے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcxxxviii{اور پھر جس کے بارے میں خیال تھا کہ وہ نجات پانے والا ہے اس سے کہا کہ ذرا اپنے مالک سے میرا بھی ذکر کردینا لیکن شیطان نے اسے مالک سے ذکر کرنے کو بھلا دیا اور یوسف چند سال تک قید خانے ہی میں پڑے رہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcxxxix{اور پھر ایک دن بادشاہ نے لوگوں سے کہا کہ میں نے خواب میں سات موٹی گائیں دیکھی ہیں جنہیں سات پتلی گائیں کھائے جارہی ہیں اور سات ہری تازی بالیاں دیکھی ہیں اور سات خشک بالیاں دیکھی ہیں تم سب میرے خواب کے بارے میں رائے دو اگر تمہیں خواب کی تعمبیر دینا آتا ہو تو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcxl{ان لوگوں نے کہا کہ یہ تو ایک خوابِ پریشاں ہے اور ہم ایسے خوابوں کی تاویل سے باخبر نہیں ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcxli{اور پھر دونوں قیدیوں میں سے جو بچ گیا تھا اور جسے ایک مدت کے بعد یوسف کا پیغام یاد آیا اس نے کہا کہ میں تمہیں اس کی تعبیر سے باخبر کرتا ہوں لیکن ذرا مجھے بھیج تو دو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcxlii{یوسف اے مرد صدیق !ذرا ان سات موٹی گایوں کے بارے میں جنہیں سات دبلی گائیں کھارہی ہیں اور سات ہری بالیوں اور سات خشک بالیوں کے بارے میں اپنی رائے تو بتاؤ شاید میں لوگوں کے پاس باخبر واپس جاؤں تو شاید انہیں بھی علم ہوجائے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcxliii{یوسف نے کہا کہ تم لوگ سات برس تک مسلسل زراعت کرو گے تو جو غلہ پیدا ہو اسے بالیوں سمیت رکھ دینا علاوہ تھوڑی مقدار کے کہ جو تمہارے کھانے کے کام میں آئے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcxliv{اس کے بعد سات سخت سال آئیں گے جو تمہارے سارے ذخیرہ کو کھاجائیں گے علاوہ اس تھوڑے مال کے جو تم نے بچا کر رکھا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcxlv{اس کے بعد ایک سال آئے گاجس میں لوگوں کی فریاد رسی اور بارش ہوگی اور لوگ خوب انگورنچوڑیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdcxlvi{تو بادشاہ نے یہ سن کر کہا کہ ذرا اسے یہاں تو لے آؤ پس جب نمائندہ آیا تو یوسف نے کہا کہ اپنے مالک کے پاس پلٹ کر جاؤ اور پوچھو کہ ان عورتوں کے بارے میں کیا خیال ہے جنہوں نے اپنے ہاتھ کاٹ ڈالے تھے کہ میرا پروردگار ان کے مکر سے خوب باخبر ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcxlvii{بادشاہ نے ان عورتوں سے دریافت کیا کہ آخر تمہارا کیا معاملہ تھا جب تم نے یوسف سے اظہار تعلق کیا تھا ان لوگوں نے کہا کہ ماشائ اللہ ہم نے ہرگز ان میں کوئی برائی نہیں دیکھی -تو عزیز مصر کی بیوی نے کہا کہ اب حق بالکل واضح ہوگیا ہے کہ میں نے خود انہیں اپنی طرف مائل کرنے کی کوشش کی تھی اور وہ صادقین میں سے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcxlviii{یوسف نے کہا کہ یہ ساری بات اس لئے ہے کہ بادشاہ کو یہ معلوم ہوجائے کہ میں نے اس کی عدم موجودگی میں کوئی خیانت نہیں کی ہے اور خدا خیانت کاروں کے مکر کو کامیاب نہیں ہونے دیتا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdcxlix{اور میں اپنے نفس کو بھی بری نہیں قرار دیتا کہ نفس بہرحال برائیوں کا حکم دینے والا ہے مگر یہ کہ میرا پروردگار رحم کرے کہ وہ بڑا بخشنے والا مہربان ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdcl{اور بادشاہ نے کہا کہ ذرا انہیں لے آؤ میں اپنے ذاتی امور میں ساتھ رکھوں گا اس کے بعد جب ان سے بات کی تو کہا کہ تم آج سے ہمارے دربار میں باوقار امین کی حیثیت سے رہو گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdcli{یوسف نے کہا کہ مجھے زمین کے خزانوں پر مقرر کردو کہ میں محافظ بھی ہوں اور صاحب هعلم بھی\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdclii{اور اس طرح ہم نے یوسف کو زمین میں اختیار دے دیا کہ وہ جہاں چاہیں رہیں -ہم اپنی رحمت سے جس کو بھی چاہتے ہیں مرتبہ دے دیتے ہیں اور کسی نیک کردار کے اجر کو ضائع نہیں کرتے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdcliii{اور آخرت کا اجر تو ان لوگوں کے لئے بہترین ہے جو صاحبانِ ایمان ہیں اور خدا سے ڈرنے والے ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdcliv{اور جب یوسف کے بھائی مصر آئے اور یوسف کے پاس پہنچے تو انہوں نے سب کو پہچان لیا اور وہ لوگ نہیں پہچان سکے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdclv{پھر جب ان کا سامان تیار کردیا تو ان سے کہا کہ تمہارا ایک بھائی اور بھی ہے اسے بھی لے آؤ کیا تم نہیں دیکھتے ہو کہ میں سامان کی ناپ تول بھی برابر رکھتا ہوں اور مہمان نوازی بھی کرنے والا ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdclvi{اب اگر اسے نہ لے آئے تو آئندہ تمہیں بھی غلہ نہ دوں گا اور نہ میرے پاس آنے پاؤ گے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdclvii{ان لوگوں نے کہا کہ ہم اس کے باپ سے بات چیت کریں گے اور ضرور کریں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdclviii{اور یوسف نے اپنے جوانوں سے کہا کہ ان کی پونجی بھی ان کے سامان میں رکھ دو شاید جب گھر پلٹ کر جائیں تو اسے پہچان لیں اور اس طرح شاید دوبارہ پلٹ کر ضرور آئیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdclix{اب جو پلٹ کر باپ کی خدمت میں آئے اور کہا کہ بابا جان آئندہ ہمیں غلہ سے روک دیا گیا ہے لہذا ہمارے ساتھ ہمارے بھائی کو بھی بھیج دیجئے تاکہ ہم غلہ حاصل کرلیں اور اب ہم اس کی حفاظت کے ذمہ دار ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdclx{یعقوب نے کہا کہ ہم اس کے بارے میں تمہارے اوپر اسی طرح بھروسہ کریں جس طرح پہلے اس کے بھائی یوسف کے بارے میں کیا تھا -خیر خدا بہترین حفاظت کرنے والا ہے اور وہی سب سے زیادہ رحم کرنے والا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdclxi{پھر جب ان لوگوں نے اپنا سامان کھولا تو دیکھا کہ ان کی بضاعت (قیمت)واپس کردی گئی ہے تو کہنے لگا بابا جان اب ہم کیا چاہتے ہیں یہ ہماری پونجی بھی واپس کردی گئی ہے اب ہم اپنے گھر والوں کے لئے غلّہ ضرور لائیں گے اور اپنے بھائی کی حفاظت بھی کریں گے اور ایک اونٹ کا بار اور بڑھوالیں گے کہ یہ بات اس کی موجودگی میں آسان ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdclxii{یعقوب نے کہا کہ میں اسے ہرگز تمہارے ساتھ نہ بھیجوں گا جب تک کہ خدا کی طرف سے عہد نہ کرو گے کہ اسے واپس ضرور لاؤ گے مگر یہ کہ تم ہی کو گھیر لیا جائے -اس کے بعد جب ان لوگوں نے عہد کرلیا تو یعقوب نے کہا کہ اللہ ہم لوگوں کے قول و قرار کا نگراں اور ضامن ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdclxiii{اور پھر کہا کہ میرے فرزندو د یکھو سب ایک دروازے سے داخل نہ ہونا اور متفرق دروازوں سے داخل ہونا کہ میں خدا کی طرف سے آنے والی بلاؤں میں تمہارے کام نہیں آسکتا حکم صرف اللہ کے ہاتھ میں ہے اور اسی پر میرا اعتماد ہے اور اسی پر سارے توکل کرنے والوں کو بھروسہ کرنا چاہئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdclxiv{اور جب وہ لوگ اسی طرح داخل ہوئے جس طرح ان کے والد نے کہا تھا اگرچہ وہ خدائی بلا کو ٹال نہیں سکتے تھے لیکن یہ ایک خواہش تھی جو یعقوب کے دل میں پیدا ہوئی جسے انہوں نے پورا کرلیا اور وہ ہمارے دئیے ہوئے علم کی بنا پر صاحبِ علم بھی تھے اگرچہ اکثر لوگ اس حقیقت سے بھی ناواقف ہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdclxv{اور جب وہ لوگ یوسف کے سامنے حاضر ہوئے تو انہوں نے اپنے بھائی کو اپنے پاس پناہ دی اور کہا کہ میں تمہارا بھائی «یوسف,, ہوں لہذا جو برتاؤ یہ لوگ کرتے رہے ہیں اب اس کی طرف سے رنج نہ کرنا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdclxvi{اس کے بعد جب یوسف نے ان کا سامان تیار کرادیا تو پیالہ کو اپنے بھائی کے سامان میں رکھوادیا اس کے بعد منادی نے آواز دی کہ قافلے والو تم سب چور ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdclxvii{ان لوگوں نے مڑ کر دیکھا اور کہا کہ آخر تمہاری کیا چیز گم ہوگئی ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdclxviii{ملازمین نے کہا کہ بادشاہ کا پیالہ نہیں مل رہا ہے اور جو اسے لے کر آئے گا اسے ایک اونٹ کا بار غلہ انعام ملے گا اور میں اس کا ذمہ دار ہوں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdclxix{ان لوگوں نے کہا کہ خدا کی قسم تمہیں تو معلوم ہے کہ ہم زمین میں فساد کرنے کے لئے نہیں آئے ہیں اور نہ ہم چور ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdclxx{ملازموں نے کہا کہ اگر تم جھوٹے ثابت ہوئے تو اس کی سزا کیا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdclxxi{ان لوگوں نے کہا کہ اس کی سزا خود وہ شخص ہے جس کے سامان میں سے پیالہ برآمد ہو ہم اسی طرح ظلم کرنے والوں کو سزادیتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdclxxii{اس کے بعد بھائی کے سامان سے پہلے دوسرے بھائیوں کے سامان کی تلاشی لی اور آخر میں بھائی کے سامان میں سے پیالہ نکال لیا .... اور اس طرح ہم نے یوسف کے حق میں تدبیر کی کہ وہ بادشاہ کے قانون سے اپنے بھائی کو نہیں لے سکتے تھے مگر یہ کہ خدا خود چاہے ہم جس کو چاہتے ہیں اس کے درجات کو بلند کردیتے ہیں اور ہر صاحب هعلم سے برتر ایک صاحب هعلم ہوتا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdclxxiii{ان لوگوں نے کہا کہ اگر اس نے چوری کی ہے تو کیا تعجب ہے اس کا بھائی اس سے پہلے چوری کرچکا ہے -یوسف نے اس بات کو اپنے دل میں حُھپالیا اور ان پر اظہار نہیں کیا .... کہاکہ تم بڑے برے لوگ ہو اور اللہ تمہارے بیانات کے بارے میں زیادہ بہتر جاننے والا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdclxxiv{ان لوگوں نے کہا کہ اے عزیز مصر اس کے والد بہت ضعیف العمر ہیں لہذا ہم میں سے کسی ایک کو اس کی جگہ پر لے لیجئے اور اسے چھوڑ دیجئے کہ ہم آپ کو احسان کرنے والا سمجھتے ہیں\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdclxxv{یوسف نے کہا کہ خدا کی پناہ کہ ہم جس کے پاس اپنا سامان پائیں اس کے علاوہ کسی دوسرے کو گرفت میں لے لیں اور اس طرح ظالم ہوجائیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdclxxvi{اب جب وہ لوگ یوسف کی طرف سے مایوس ہوگئے تو الگ جاکر مشورہ کرنے لگے تو سب سے بڑے نے کہا کہ کیا تمہیں نہیں معلوم کہ تمہارے باپ نے تم سے خدائی عہد لیا ہے اور اس سے پہلے بھی تم یوسف کے بارے میں کوتاہی کرحُکے ہو تو اب میں تو اس سرزمین کو نہ چھوڑوں گا یہاں تک کہ والد محترم اجازت دے دیں یا خدا میرے حق میں کوئی فیصلہ کردے کہ وہ بہترین فیصلہ کرنے والا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdclxxvii{ہاں تم لوگ باپ کی خدمت میں جاؤ اور عرض کرو کہ آپ کے فرزند نے چوری کی ہے اور ہم اسی بات کی گواہی دے رہے ہیں جس کا ہمیں علم ہے اور ہم غیب کی حفاظت کرنے والے نہیں ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdclxxviii{آپ اس بستی سے دریافت کرلیں جس میں ہم تھے اور اس قافلے سے پوچھ لیں جس میں ہم آئے ہیں اور ہم بالکل سچےّ ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdclxxix{یعقوب نے کہا کہ یہ تمہارے دل نے ایک نئی بات گڑھ لی ہے میں پھر بھی صبرجمیل اختیار کروں گا کہ شائد خدا ان سب کو لے آئے کہ وہ ہر شئے کا جاننے والا اور صاحب هحکمت ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdclxxx{ےہ کہہ کر انہوں نے سب سے منھ پھےر لیااور کہا کہ افسوس ہے یوسف کے حال پر اوراتناروئے کہ آنکھیں سفیدہو گئیںاور غم کے گھونٹ پیتے رہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdclxxxi{ان لوگوں نے کہا کہ آپ اسی طرح یوسف کویاد کرتے رہیںگے یہاں تک کہ بیمار ہوجائیں یا ہلاک ہونے والوںمیں شامل ہو جائیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdclxxxii{یعقوب نے کہا کہ میں اپنے حزن و غم اور اپنی بےقراری کی فریاد اللہ کی بارگاہ میں کر رہا ہوں اورا س کی طرف سے وہ سب جانتا ہوںجو تم نہیں جانتے ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiii{میرے فرزندو جاؤ یوسف اور ان کے بھائی کو خوب تلاش کرو اور رحمت خدا سے مایوس نہ ہونا کہ اس کی رحمت سے کافر قوم کے علاوہ کوئی مایوس نہیں ہوتا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdclxxxiv{اب جو وہ لوگ دوبارہ یوسف کے پاس گئے تو کہنے لگے کہ اے عزیز ہم کو اور ہمارے گھر والوں کو بڑی تکلیف ہے اور ہم ایک حقیر سی پونجی لے کر آئے ہیں آپ ہمیں پورا پورا غلہ دے دیں اور ہم پر احسان کریں کہ خدا کا»خیر کرنے والوں کو جزائے خیر دیتا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdclxxxv{اس نے کہا کہ تمہیں معلوم ہے کہ تم نے یوسف اور ان کے بھائی کے ساتھ کیا برتاؤ کیا ہے جب کہ تم بالکل جاہل تھے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvi{ان لوگوں نے کہا کہ کیا آپ ہی یوسف ہیں?انہوں نے کہا کہ بیشک میں یوسف ہوں اور یہ میرا بھائی ہے -اللہ نے ہمارے اوپر احسان کیا ہے اور جو کوئی بھی تقوٰی اور صبر اختیار کرتاہے اللہ نیک عمل کرنے والوں کے اجر کو ضائع نہیں کرتا ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdclxxxvii{ان لوگوں نے کہا کہ خدا کی قسم خدا نے آپ کو فضیلت اور امتیاز عطا کیا ہے اور ہم سب خطاکار تھے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdclxxxviii{یوسف نے کہا کہ آج تمہارے اوپر کوئی الزام نہیںہے .خدا تمہیں معاف کردے گا کہ وہ بڑا رحم کرنے والا ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdclxxxix{جاؤ میری قمیض لے کر جاؤ اور بابا کے چہرہ پر ڈال دو کہ ان کی بصارت پلٹ آئے گی اور اس مرتبہ اپنے تمام گھر والوں کو ساتھ لے کر آنا\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcxc{اب جو قافلہ مصر سے روانہ ہوا تو ان کے پدر بزرگوار نے کہا کہ میں یوسف کی خوشبو محسوس کررہا ہوں اگر تم لوگ مجھے سٹھیایا ہوا نہ کہو\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcxci{ان لوگوں نے کہا کہ خدا کی قسم آپ ابھی تک اپنی پرانی گمراہی میں مبتلا ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcxcii{اس کے بعد جب بشیر نے آکر قمیض کو یعقوب کے چہرہ پر ڈال دیا تو دوبارہ صاحب هبصارت ہوگئے اور انہوں نے کہا کہ میں نے تم سے نہ کہا تھا کہ میں خدا کی طرف سے وہ جانتا ہوں جو تم نہیں جانتے ہو\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcxciii{ان لوگوں نے کہا بابا جان اب آپ ہمارے گناہوں کے لئے استغفار کریں ہم یقینا خطاکار تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mdcxciv{انہوں نے کہا کہ میں عنقریب تمہارے حق میں استغفار کروں گا کہ میرا پروردگار بہت بخشنے والا اور مہربان ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mdcxcv{اس کے بعد جب وہ لوگ سب یوسف کے یہاں حاضر ہوئے تو انہوں نے ماں باپ کو اپنے پہلو میں جگہ دی اور کہا کہ آپ لوگ مصر میں انشائ اللہ بڑے اطمینان و سکون کے ساتھ داخل ہوں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mdcxcvi{اور انہوں نے والدین کو بلند مقام پر تخت پر جگہ دی اور سب لوگ یوسف کے سامنے سجدہ میں گر پڑے یوسف نے کہا کہ بابا یہ میرے پہلے خواب کی تعبیر ہے جسے میرے پروردگار نے سچ کر دکھایا ہے اور اس نے میرے ساتھ احسان کیا ہے کہ مجھے قید خانہ سے نکال لیا اور آپ لوگوں کو گاؤں سے نکال کر مصر میں لے آیا جب کہ شیطان میرے اور میرے بھائیوں کے درمیان فساد پیدا کرچکا تھا -بیشک میرا پروردگار اپنے ارادوں کی بہترین تدبیر کرنے والا اور صاحب هعلم اور صاحب هحکمت ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mdcxcvii{پروردگار تو نے مجھے ملک بھی عطا کیا اور خوابوں کی تعبیر کا علم بھی دیا -تو زمین و آسمان کا پیدا کرنے والا ہے اور دنیا وآخرت میں میرا ولی اور سرپرست ہے مجھے دنیا سے فرمانبردار اٹھانا اور صالحین سے ملحق کردینا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mdcxcviii{پیغمبر !سب غیب کی خبریں ہیں جنہیں ہم وحی کے ذریعہ آپ تک پہنچا رہے ہیں ورنہ آپ تو اس وقت نہ تھے جب وہ لوگ اپنے کام پر اتفاق کررہے تھے اور یوسف کے بارے میں بفِی تدبیریں کررہے تھے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mdcxcix{اور آپ کسی قدر کیوں نہ چاہیں انسانوں کی اکثریت ایمان لانے والی نہیں ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mdcc{اور آپ ان سے تبلیغ رسالت کی اجرت تو نہیں مانگتے ہیں یہ قرآن تو عالمین کے لئے ایک ذکر اور نصیحت ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mdcci{اور زمین و آسمان میں بہت سی نشانیاں ہیں جن سے لوگ گزر جاتے ہیں اور کنارہ کش ہی رہتے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mdccii{اور ان میںکی اکثریت خدا پر ایمان بھی لاتی ہے تو شرک کے ساتھ\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mdcciii{تو کیا یہ لوگ اس بات کی طرف سے مطمئن ہوگئے ہیں کہ کہیں ان پر عذاب الٰہی آکر چھاجائے یا اچانک قیامت آجائے اور یہ غافل ہی رہ جائیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mdcciv{آپ کہہ دیجئے کہ یہی میرا راستہ ہے کہ میں بصیرت کے ساتھ خدا کی طرف دعوت دیتا ہوں اور میرے ساتھ میرا اتباع کرنے والا بھی ہے اور خدا پاک و بے نیازہے اور میں مشرکین میں سے نہیں ہوں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mdccv{اور ہم نے آپ سے پہلے ان ہی مذِدوں کو رسول بنایا ہے جو آبادیوں میں رہنے والے تھے اور ہم نے ان کی طرف وحی بھی کی ہے تو کیا یہ لوگ زمین میں سیر نہیں کرتے کہ دیکھیں کہ ان سے پہلے والوں کا انجام کیا ہوا ہے اور دا» آخرت صرف صاحبانِ تقوٰی کے لئے بہترین منزل ہے -کیا تم لوگ عقل سے کام نہیں لیتے ہو\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mdccvi{یہاں تک کہ جب ان کے انکار سے مرسلین مایوس ہونے لگے اور ان لوگوں نے سمجھ لیاکہ ان سے جھوٹا وعدہ کیا گیا ہے تو ہماری مدد مرسلین کے پاس آگئی اور ہم نے جن لوگوں کو چاہا انہیں نجات دے دی اور ہمارا عذاب مجرم قوم سے پلٹایا نہیں جاسکتا ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mdccvii{یقینا ان کے واقعات میں صاحبانِ عقل کے لئے سامان هعبرت ہے اور یہ کوئی ایسی بات نہیں ہے جسے گڑھ لیا جائے یہ قرآن پہلے کی تمام کتابوں کی تصدیق کرنے والا ہے اور اس میں ہر شے کی تفصیل ہے اور یہ صاحبِ ایمان قوم کے لئے ہدایت اور رحمت بھی ہے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mdccviii{\basmalahur المۤرۤ -یہ کتاب هخدا کی آیتیں ہیں اور جو کچھ بھی آپ کے پروردگار کی طرف سے نازل کیا گیا ہے وہ سب برحق ہے لیکن لوگوں کی اکثریت ایمان لانے والی نہیں ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccix{اللہ ہی وہ ہے جس نے آسمانوں کو بغیر کسی ستون کے بلند کردیا ہے جیسا کہ تم دیکھ رہے ہو اس کے بعد اس نے عر ش پر اقتدار قائم کیا اور آفتاب و ماہتاب کو لَسخر بنایا کہ سب ایک معینہ مدّت تک چلتے رہیں گے وہی تمام امور کی تدبیر کرنے والا ہے اور اپنی آ یات کو مفصل طور سے بیان کرتا ہے کہ شاید تم لوگ پروردگار کی ملاقات کا یقین پیدا کرلو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccx{وہ خدا وہ ہے جس نے زمین کو پھیلایا اور اس میں ا ٹل قسم کے پہا ڑ قرار دئیے اور نہریں جاری کیں اور ہر پھل کا جوڑا قرار دیا وہ رات کے پردے سے دن کو ڈھانک دیتا ہے اور اس میں صاحبانِ فکر و نظر کے لئے بڑ ی نشانیاں پائی جاتی هہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccxi{اور زمین کے متعدد ٹکڑے آپس میں ایک دوسرے سے ملے ہوئے ہیں اور انگور کے باغات ہیں اور زرا عت ہے اور کھجوریں ہیں جن میں بعض دو شاخ کی ہیں اور بعض ایک شاخ کی ہیں اور سب ایک ہی پانی سے سینچے جاتے ہیں اور ہم بعض کو بعض پر کھانے میں ترجیح دیتے ہیں اور اس میں بھی صاحبانِ عقل کے لئے بڑی نشانیاں پائی جاتی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdccxii{اور اگر تمہیں کسی بات پر تعّجب ہے تو تّعجب کی بات ان لوگوں کا یہ قول ہے کہ کیا ہم خاک ہوجانے کے بعد بھی نئے سرے سے دوبارہ پیدا کئے جائیں گے .یہی وہ لوگ ہیں جنہوں نے اپنے پروردگار کا انکار کیا ہے اور ان ہی کی گردنوں میں طوق ڈالے جائیں گے اور یہی اہل هجہّنم ہیں اور اسی میں ہمیشہ رہنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdccxiii{اور اے رسول یہ لوگ آپ سے بھلائی سے پہلے ہی برائی (عذاب)چاہتے ہیں جب کہ ان کے پہلے بہت سی عذاب کی نظریں گزر چکی ہیں اور آپ کا پروردگار لوگوں کے لئے ان کے ظلم پر بخشنے والا بھی ہے اور بہت سخت عذاب کرنے والا بھی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdccxiv{اور یہ کافر کہتے ہیں کہ ان کے اوپر کوئی نشانی (ہماری مطلوبہ)کیوں نہیں نازل ہوتی تو آپ کہہ دیجئے کہ میں صرف ڈرانے والا ہوں اور ہر قوم کے لئے ایک ہادی اور رہبر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdccxv{اللہ بہتر جانتا ہے کہ ہر عورت کے شکم میں کیا ہے اور اس کے رحم میں کیا کمی اور زیادتی ہوتی رہتی ہے اور ہر شے کی اس کے نزدیک ایک مقدار معین ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdccxvi{وہ غائب و حاضر سب کا جاننے والا بزرگ و بالاتر ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdccxvii{اس کے نزدیک تم میں کے سب برابر ہیں جو بات آہستہ کہے اور جو بلند آواز سے کہے اور جو رات میں چھپارہے اور دن میں چلتا رہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdccxviii{اس کے لئے سامنے اور پیچھے سے محافظ طاقتیں ہیں جو حکم هخدا سے اس کی حفاظت کرتی ہیں اور خدا کسی قوم کے حالات کو اس وقت تک نہیں بدلتا جب تک وہ خود اپنے کو تبدیل نہ کرلے اور جب خدا کسی قوم پر عذاب کا ارادہ کرلیتا ہے تو کوئی ٹال نہیں سکتا ہے اور نہ اس کے علاوہ کوئی کسی کا والی و سرپرست ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdccxix{وہی خدا ہے جو تمہیں ڈرانے اور لالچ دلانے کے لئے بجلیاں دکھاتا ہے اور پانی سے لدے ہوئے بوجھل بادل ایجاد کرتا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdccxx{گرج اس کی حمد کی تسبیح کرتی ہے اور فرشتے اس کے خوف سے حمد و ثنا کرتے رہتے ہیں اور بجلیوں کو بھیجتا ہے تو جس تک چاہتا ہے پہنچا دیتا ہے اور یہ لوگ اللہ کے بارے میں کج بحثی کررہے ہیں جب کہ وہ بہت مضبوط قوت اور عظیم طاقت والا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdccxxi{برحق پکارنا صرف خدا ہی کا پکارنا ہے اور جو لوگ اس کے علاوہ دوسروں کو پکارتے ہیں وہ ان کی کوئی بات قبول نہیں کرسکتے سوائے اس شخص کے مانند جو پانی کی طرف ہتھیلی پھیلائے ہو کہ منہ تک پہنچ جائے اور وہ پہنچنے والا نہیں ہے اور کافروں کی دعا ہمیشہ گمراہی میں رہتی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdccxxii{اللہ ہی کے لئے زمین و آسمان والے ہنسی خوشی یا زبردستی سجدہ کررہے ہیں اور صبح و شام ان کے سائے بھی سجدہ کناں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdccxxiii{پیغمبر کہہ دیجئے کہ بتاؤ کہ زمین و آسمان کا پروردگار کون ہے اور بتادیجئے کہ اللہ ہی ہے اور کہہ دیجئے کہ تم لوگوں نے اس کو چھوڑ کر ایسے سرپرست اختیار کئے ہیں جو خود اپنے نفع و نقصان کے مالک نہیں ہیں اور کہئے کہ کیا اندھے اور بینا ایک جیسے ہوسکتے ہیں یا نورو ظلمت برابر ہوسکتے ہیں یا ان لوگوں نے اللہ کے لئے ایسے شریک بنائے ہیں جنہوں نے اسی کی طرح کی کائنات خلق کی ہے اور ان پر خلقت مشتبہ ہوگئی ہے. کہہ دیجئے کہ اللہ ہی ہر شے کا خالق ہے اور وہی یکتا اور سب پر غالب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdccxxiv{اس نے آسمان سے پانی برسایا تو وادیوں میں بقدر ظرف بہنے لگا اور سیلاب میں جوش کھا کر جھاگ آگیا اور اس دھات سے بھی جھاگ پیدا ہوگیا جسے آگ پر زیور یا کوئی دوسرا سامان بنانے کے لئے پگھلاتے ہیں. اسی طرح پروردگار حق و باطل کی مثال بیان کرتا ہے کہ جھاگ خشک ہوکر فنا ہوجاتا ہے اور جو لوگوں کو فائدہ پہنچانے والا ہے وہ زمین میں باقی رہ جاتا ہے اور خدا اسی طرح مثالیں بیان کرتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdccxxv{جو لوگ پروردگار کی بات کو قبول کرلیتے ہیں ان کے لئے نیکی ہے اور جو اس کی بات کو قبول نہیں کرتے انہیں زمین کے سارے خزانے بھی مل جائیں اور اسی قدر اور بھی مل جائے تو یہ بطور فدیہ دے دیں گے لیکن ان کے لئے بدترین حساب ہے اور ان کا ٹھکانا جہّنم ہے اور وہ بہت بفِا ٹھکانا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdccxxvi{) کیا وہ شخص جو یہ جانتا ہے کہ جو کچھ آپ کے پروردگار کی طرف سے نازل ہوا سب برحق ہے وہ اس کے جیسا ہوسکتا ہے جو بالکل اندھا ہے (ہرگز نہیں)اس بات کو صرف صاحبانِ عقل ہی سمجھ سکتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdccxxvii{جو عہدُ خدا کو پورا کرتے ہیں اور عہد شکنی نہیں کرتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdccxxviii{اور جو ان تعلقات کو قائم رکھتے ہیں جنہیں خدا نے قائم رکھنے کا حکم دیا ہے اور اس سے ڈرتے رہتے ہیں اور بدترین حساب سے خوفزدہ رہتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdccxxix{اور جنہوں نے مرضی خدا حاصل کرنے کے لئے صبر کیا ہے اور نماز قائم کی ہے اور ہمارے رزق میں سے خفیہ و علانیہ انفاق کیا ہے اور جو نیکی کے ذریعہ برائی کو دفع کرتے رہتے ہیں آخرت کا گھر ان ہی کے لئے ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdccxxx{یہ ہمیشہ رہنے والے باغات ہیں جن میں یہ خود اور ان کے آبائ و اجداد اور ازواج و اولاد میں سے سارے نیک بندے داخل ہوں گے اور ملائکہ ان کے پاس ہر دروازے سے حاضری دیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdccxxxi{کہیں گے کہ تم پر سلامتی ہو کہ تم نے صبر کیا ہے اور اب آخرت کا گھر تمہاری بہترین منزل ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdccxxxii{اور جو لوگ عہدُ خدا کو توڑ دیتے ہیں اور جن سے تعلقات کا حکم دیا گیا ہے اان سے قطع تعلقات کرلیتے ہیں اور زمین میں فساد برپا کرتے ہیں ان کے لئے لعنت اور بدترین گھر ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiii{اللہ جس کے لئے چاہتا ہے رزق کو وسیع یا تنگ کردیتا ہے اور یہ لوگ صرف زندگانی دنیا پر خوش ہوگئے ہیں حالانکہ آخرت کے مقابلہ میں زندگانی دنیا صرف ایک وقتی لذّت کا درجہ رکھتی ہے اور بس\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdccxxxiv{اور یہ کافر کہتے ہیں کہ ان کے اوپر ہماری پسند کی نشانی کیوں نہیں نازل ہوتی تو پیغمبر کہہ دیجئے کہ اللہ جس کو چاہتا ہے گمراہی میں چھوڑ دیتا ہے اور جو اس کی طرف متوجہ ہوجاتے ہیں انہیں ہدایت دے دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdccxxxv{یہ وہ لوگ ہیں جو ایمان لائے ہیں اور ان کے دُلوں کو یادُ خدا سے اطمینان حاصل ہوتا ہے اور آگاہ ہوجاؤ کہ اطمینان یادُ خدا سے ہی حاصل ہوتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvi{جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ان کے لئے بہترین جگہ (بہشت)اور بہترین بازگشت ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdccxxxvii{اسی طرح ہم نے آپ کو ایک ایسی قوم کے درمیان بھیجا ہے جس سے پہلے بہت سی قومیں گزر چکیِ ہیں تاکہ آپ ان چیزوں کی تلاوت کریں جنہیں ہم نے آپ کی طرف بذریعہ وحی نازل کیا ہے حالانکہ وہ لوگ رحمان کا انکار کرنے والے ہیں آپ ان سے کہئے کہ وہ میرا رب ہے اور اس کے علاوہ کوئی خدا نہیں ہے اسی پر میرا اعتماد ہے اور اسی کی طرف بازگشت ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdccxxxviii{اور اگر کوئی قرآن ایسا ہو جس سے پہاڑوں کو اپنی جگہ سے چلایا جاسکے یا زمین طے کی جاسکے یا لَردوں سے کلام کیا جاسکے -تو وہ یہی قرآن ہے- بلکہ تمام امور اللہ کے لئے ہیں تو کیا ایمان والوں پر واضح نہیں ہوا کہ اگر خدا جبرا چاہتا تو سارے انسانوں کو ہدایت دے دیتا اور ان کافروں پر ان کے کرتوت کی بنا پر ہمیشہ کوئی نہ کوئی مصیبت پڑتی رہے گی یا ان کے دیار کے آس پاس مصیبت آتی رہے گی یہاں تک کہ وعدہ الٰہی کا وقت آجائے کہ اللہ اپنے وعدہ کے خلاف نہیں کرتا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdccxxxix{پیغمبر آپ سے پہلے بہت سے رسولوں کا مذاق اڑایا گیا ہے تو ہم نے کافروں کو تھوڑی دیر کی مہلت دیدی اور اس کے بعد اپنی گرفت میں لے لیا تو کیسا سخت عذاب ہوا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdccxl{کیا وہ ذات جو ہر نفس کے اعمال کی نگراں ہے اور انہوں نے اس کے لئے شریک فرض کرلئے ہیں تو کہئے کہ ذرا شرکائ کے نام تو بتاؤ تم خدا کو ان شرکائ کی خبر دے رہے ہو جن کی ساری زمین میں اسے بھی خبر نہیں ہے یا فقط یہ ظاہری الفاظ ہیں اور سچ تو یہ ہے کہ کافروں کے لئے ان کا مکر آراستہ ہوگیا ہے اور انہیں راہ حق سے روک دیا گیا ہے اور جسے خدا ہدایت نہ دے اس کا کوئی ہدایت کرنے والا نہیں ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdccxli{ان کے لئے زندگانی دنیا میں بھی عذاب ہے اور آخرت کا عذاب تو اور زیادہ سخت ہے اور پھر اللہ سے بچانے والا کوئی نہیں ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdccxlii{جس جنت کا صاحبانِ تقویٰ سے وعدہ کیا گیا ہے اس کی مثال یہ ہے کہ اس کے نیچے نہریں جاری ہوں گی اور اس کے پھل دائمی ہوں گے اور سایہ بھی ہمیشہ رہے گا -یہ صاحبان هتقوٰی کی عاقبت ہے اور کفار کا انجام کار بہرحال جّہنم ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdccxliii{اور جن لوگوں کو ہم نے کتاب دی ہے وہ اس تنزیل سے خوش ہیں اور بعض گروہ وہ ہیں جو بعض باتوں کا انکار کرتے ہیں تو آپ کہہ دیجئے کہ مجھے یہ حکم دیا گیا ہے کہ میں اللہ کی عبادت کروں اور کسی کو اس کا شریک نہ بناؤں میں اسی کی طرف دعوت دیتا ہوں اور اسی کی طرف سب کی بازگشت ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdccxliv{اور اسی طرح ہم نے اس قرآن کو عربی زبان کا فرمان بناکر نازل کیا ہے اور اگر آپ علم کے آجانے کے بعد ان کی خواہشات کا اتباع کرلیں گے تو اللہ کے مقابلے میں کوئی کسی کا سرپرست اور بچانے والا نہ ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdccxlv{ہم نے آپ سے پہلے بھی بہت سے رسول بھیجے ہیں اور ان کے لئے ازواج اور اولاد قرار دی ہے اور کسی رسول کے لئے یہ ممکن نہیں ہے وہ اللہ کی اجازت کے بغیر کوئی نشانی لے آئے کہ ہر مدّت اور معیاد کے لئے ایک نوشتہ مقرر ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdccxlvi{اللہ جس چیز کو چاہتا ہے مٹادیتا ہے یا برقر ار رکھتا ہے کہ اصل کتاب اسی کے پاس ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxlvii{اور اے پیغمبر ہم کفار سے کئے وعدہ عذاب کو تمہیں دکھلادیں یا تمہیں اٹھالیں تمہارا کام تو صرف احکام کا پہنچا دینا ہے حساب کی ذمہ داری ہماری اپنی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxlviii{کیا ان لوگوں نے نہیں دیکھا کہ ہم کس طرح زمین کی طرف آکر اس کو اطراف سے کم کردیتے ہیں اور اللہ ہی حکم دینے والا ہے کوئی اس کے حکم کا ٹالنے والا نہیں ہے اور وہ بہت تیز حساب کرنے والا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxlix{اور ان کے پہلے والوں نے بھی مکر کیا ہے لیکن ساری تدبیریں اللہ ہی کے اختیار میں ہیں وہ ہر نفس کے کاروبار کو جانتا ہے اور عنقریب کفار بھی جان لیں گے کہ آخرت کا گھر کس کے لئے ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccl{اور یہ کافر کہتے ہیں کہ آپ رسول نہیں ہیں کہہ دیجئے کہ ہمارے اور تمہارے درمیان رسالت کی گواہی کے لئے خدا کافی ہے اور وہ شخص کافی ہے جس کے پاس پوری کتاب کا علم ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccli{\basmalahur الۤر -یہ کتاب ہے جسے ہم نے آپ کی طرف نازل کیا ہے تاکہ آپ لوگوں کو حکم خدا سے تاریکیوں سے نکال کر نور کی طرف لے آئیں اور خدائے عزیز و حمید کے راستے پر لگادیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdcclii{وہ اللہ وہ ہے جس کے لئے زمین و آسمان کی ہر شے ہے اور کافروں کے لئے تو سخت ترین اور افسوس ناک عذاب ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdccliii{وہ لوگ جو زندگانی دنیا کو آخرت کے مقابلے میں پسند کرتے ہیں اور لوگوں کو راسِ خدا سے روکتے ہیں اور اس میں کجی پیدا کرنا چاہتے ہیں یہ گمراہی میں بہت دور تک چلے گئے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdccliv{اور ہم نے جس رسول کو بھی بھیجا اسی کی قوم کی زبان کے ساتھ بھیجا تاکہ وہ لوگوں پر باتوں کو واضح کرسکے اس کے بعد خدا جس کو چاہتا ہے گمراہی میں چھوڑ دیتا ہے اور جس کو چاہتا ہے ہدایت دے دیتا ہے وہ صاحب هعزّت بھی ہے اور صاحبِ حکمت بھی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcclv{اور ہم نے موسٰی کو اپنی نشانیوں کے ساتھ بھیجا کہ اپنی قوم کو ظلمتوں سے نور کی طرف نکال کر لائیں اور انہیں خدائی دنوں کی یاد دلائیں کہ بیشک اس میں تمام صبر کرنے والے اور شکر کرنے والے کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcclvi{اور اس وقت کو یاد کرو جب موسٰی نے اپنی قوم سے کہا کہ تم لوگ اللہ کی اس نعمت کو یاد کرو کہ اس نے تمہیں فرعون والوں سے نجات دلائی جب کہ وہ بدترین عذاب میں مبتلا کررہے تھے کہ تمہارے لڑکوں کو ذبح کررہے تھے اور تمہاری لڑکیوں کو (کنیزی کے لئے)زندہ رکھتے تھے اور اس میں تمہارے پروردگار کی طرف سے بڑا سخت امتحان تھا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcclvii{اور جب تمہارے پروردگار نے اعلان کیا کہ اگر تم ہمارا شکریہ اد اکرو گے تو ہم نعمتوں میں اضافہ کردیں گے اور اگر کفرانِ نعمت کرو گے تو ہمارا عذاب بھی بہت سخت ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcclviii{اور موسٰی نے یہ بھی کہہ دیا کہ اگر تم سب اور روئے زمین کے تمام بسنے والے بھی کافر ہوجائیں تو ہمارا اللہ سب سے بے نیاز ہے اور وہ قابلِ حمد و ستائش ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcclix{کیا تمہارے پاس اپنے سے پہلے والوں قوم نوح اور قوم عاد و ثمود اور جو ان کے بعد گزرے ہیں اور جنہیں خدا کے علاوہ کوئی نہیں جانتا ہے کی خبر نہیں آئی ہے کہ ان کے پاس اللہ کے رسول معجزات لے کر آئے اور انہوں نے ان کے ہاتھوں کو ان ہی کے منہ کی طرف پلٹا دیا اور صاف کہہ دیا کہ ہم تمہارے لائے ہوئے پیغام کے منکر ہیں اور ہمیں اس بات کے بارے میں واضح شک ہے جس کی طرف تم ہمیں دعوت دے رہے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcclx{تو رسولوں نے کہا کہ کیا تمہیں اللہ کے بارے میں بھی شک ہے جو زمین و آسمان کا پیدا کرنے والا ہے اور تمہیں اس لئے بلاتا ہے کہ تمہارے گناہوں کو معاف کردے اور ایک معینہ مدّت تک زمین میں چین سے رہنے دے ....تو ان لوگوں نے جواب دیا کہ تم سب بھی ہمارے ہی جیسے بشر ہو اور چاہتے ہو کہ ہمیں ان چیزوں سے روک دو جن کی ہمارے باپ دادا عبادت کیا کرتے تھے تو اب کوئی کھلی ہوئی دلیل لے آؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcclxi{ان سے رسولوں نے کہا کہ یقینا ہم تمہارے ہی جیسے بشر ہیں لیکن خدا جس بندے پر چاہتا ہے مخصوص احسان بھی کرتا ہے اور ہمارے اختیار میں یہ بھی نہیں ہے کہ ہم بلااذنِ خدا کوئی دلیل یا معجزہ لے آئیں اور صاحبان هایمان تو صرف اللہ ہی پر بھروسہ کرتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcclxii{اور ہم کیوں نہ اللہ پر بھروسہ کریں جب کہ اسی نے ہمیں ہمارے راستوں کی ہدایت دی ہے اور ہم یقینا تمہاری اذیتوں پر صبر کریں گے اور بھروسہ کرنے والے تو اللہ ہی پر بھروسہ کرتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcclxiii{اور کافروں نے اپنے رسولوں سے کہا کہ ہم تم کو اپنی سرزمین سے نکال باہر کردیں گے یا تم ہمارے مذہب کی طرف پلٹ آؤ گے تو پروردگار نے ان کی طرف وحی کی کہ خبردار گھبراؤ نہیں ہم یقینا ظالمین کو تباہ و برباد کردیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcclxiv{اور تمہیں ان کے بعد زمین میں آباد کردیں گے اور یہ سب ان لوگوں کے لئے ہے جو ہمارے مقام اور مرتبہ سے ڈرتے ہیں اور ہمارے عذاب کا خوف رکھتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcclxv{اور پیغمبروں نے ہم سے فتح کا مطالبہ کیا اور ان سے عناد رکھنے والے سرکش افراد ذلیل اور رسوا ہوگئے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcclxvi{ان کے پیچھے جہّنم ہے اور انہیں پیپ دار پانی پلایا جائے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcclxvii{جسے گھونٹ گھونٹ پئیں گے اور وہ انہیں گوارا نہ ہوگا اور انہیں موت ہر طرف سے گھیر لے گی حالانکہ وہ مرنے والے نہیں ہیں اور ان کے پیچھے بہت سخت عذاب لگا ہوا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcclxviii{جن لوگوں نے اپنے پروردگار کا انکار کیا ان کے اعمال کی مثال اس راکھ کی ہے جسے اندھڑ کے دن کی تند ہوا اڑا لے جائے کہ وہ اپنے حاصل کئے ہوئے پر بھی کوئی اختیار نہ رکھیں گے اور یہی بہت دور تک پھیلی ہوئی گمراہی ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcclxix{کیا تم نے نہیں دیکھا کہ اللہ نے زمین اور آسمانوں کو برحق پیدا کیا ہے وہ چاہے تو تم کو فنا کرکے ایک نئی مخلوق کو لاسکتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcclxx{اور اللہ کے لئے یہ بات کوئی مشکل نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcclxxi{اور قیامت کے دن سب اللہ کے سامنے حاضر ہوں گے تو کمزور لوگ مستکبرین سے کہیں گے کہ ہم تو آپ کے پیروکار تھے تو کیا آپ عذاب الٰہی کے مقابلہ میں ہمارے کچھ کام آسکتے ہیں تو وہ جواب دیں گے کہ اگر خدا ہمیں ہدایت دے دیتا تو ہم بھی تمہیں ہدایت دے دیتے -اب تو ہمارے لئے سب ہی برابر ہے چاہے فریاد کریں یا صبر کریں کہ اب کوئی چھٹکارا ملنے والا نہیں ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcclxxii{اور شیطان تمام امور کا فیصلہ ہوجانے کے بعد کہے گا کہ اللہ نے تم سے بالکل برحق وعدہ کیا تھا اور میں نے بھی ایک وعدہ کیا تھا پھر میں نے اپنے وعدہ کی مخالفت کی اور میرا تمہارے اوپر کوئی زور بھی نہیں تھا سوائے اس کے کہ میں نے تمہیں دعوت دی اور تم نے اسے قبول کرلیا تو اب تم میری ملامت نہ کرو بلکہ اپنے نفس کی ملامت کرو کہ نہ میں تمہاری فریاد رسی کرسکتا ہوں نہ تم میری فریاد کو پہنچ سکتے ہو میں تو پہلے ہی سے اس بات سے بیزار ہوں کہ تم نے مجھے اس کا شریک بنا دیا اور بیشک ظالمین کے لئے بہت بڑا دردناک عذاب ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiii{اور صاحبان ه ایمان و عمل صالح کو ان جنتوں میں داخل کیا جائے گا جن کے نیچے نہریں جاری ہوں گے وہ ہمیشہ حکم خدا سے وہیں رہیں گے اور ان کی ملاقات کا تحفہ سلام ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcclxxiv{کیا تم نے نہیں دیکھا کہ اللہ نے کس طرح کلمہ طیبہ کی مثال شجرہ طیبہ سے بیان کی ہے جس کی اصل ثابت ہے اور اس کی شاخ آسمان تک پہنچی ہوئی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcclxxv{یہ شجرہ ہر زمانہ میں حکم پروردگار سے پھل دیتا رہتا ہے اور خدا لوگوں کے لئے مثال بیان کرتا ہے کہ شاید اسی طرح ہوش میں آجائیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvi{اور کلمہ خبیثہ کی مثال اس شجرہ خبیثہ کی ہے جو زمین کے اوپر ہی سے اکھاڑ کر پھینک دیا جائے اور اس کی کوئی بنیاد نہ ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcclxxvii{اللہ صاحبان هایمان کو قول ثابت کے ذریعہ دنیا اور آخرت میں ثابت قدم رکھتا ہے اور ظالمین کو گمراہی میں چھوڑ دیتا ہے اور وہ جو بھی چاہتا ہے انجام دیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcclxxviii{کیا تم نے ان لوگوں کو نہیں دیکھا جنہوں نے اللہ کی نعمت کو کفرانِ نعمت سے تبدیل کردیا اور اپنی قوم کو ہلاکت کی منزل تک پہنچادیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcclxxix{وہ جہنم ّجس میں سب واصل ہوں گے اور وہ بدترین قرار گاہ ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcclxxx{اور ان لوگوں نے اللہ کے لئے مثل قرار دیئے تاکہ اس کے ذریعہ لوگوں کو بہکا سکیں تو آپ کہہ دیجئے کہ تھوڑے دن اور مزے کرلو پھر تو تمہارا انجام جہّنم ہی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxi{اور آپ میرے ایماندار بندوں سے کہہ دیجئے کہ نمازیں قائم کریں اور ہمارے رزق میں سے خفیہ اور علانیہ ہماری راہ میں انفاق کریں قبل اس کے کہ وہ دن آجائے جب نہ تجارت کام آئے گی اور نہ دوستی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxii{اللہ ہی وہ ہے جس نے آسمان و زمین کو پیدا کیا ہے اور آسمان سے پانی برسا کر اس کے ذریعہ تمہاری روزی کے لئے پھل پیدا کئے ہیں اور کشتیوں کو مسخر کردیا ہے کہ سمندر میں اس کے حکم سے چلیں اور تمہارے لئے نہروں کو بھی مسخر کردیا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiii{اور تمہارے لئے حرکت کرنے والے آفتاب و ماہتاب کو بھی مسخر کردیا ہے اور تمہارے لئے رات اور دن کو بھی مسخر کردیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiv{اور جو کچھ تم نے مانگا اس میں سے کچھ نہ کچھ ضرور دیا اور اگر تم اس کی نعمتوں کو شمار کرنا چاہو گے تو ہرگز شمار نہیں کرسکتے -بیشک انسان بڑا ظالم اور انکار کرنے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxv{اور اس وقت کو یاد کرو جب ابراہیم نے کہا کہ پروردگار اس شہر کو محفوظ بنادے اور مجھے اور میری اولاد کو بت پرستی سے بچائے رکھنا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvi{پروردگار ان بتوں نے بہت سے لوگوں کو گمراہ کردیا ہے تو اب جو میرا اتباع کرے گا وہ مجھ سے ہوگا اور جو معصیت کرے گا اس کے لئے توِ بڑا بخشنے والا اور مہربان ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvii{پروردگار میں نے اپنی ذریت میں سے بعض کو تیرے محترم مکان کے قریب بے آب و گیاہ وادی میں چھوڑ دیا ہے تاکہ نمازیں قائم کریں اب تو لوگوں کے دلوں کو ان کی طرف موڑ دے اور انہیں پھلوں کا رزق عطا فرما تاکہ وہ تیرے شکر گزار بندے بن جائیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxviii{پروردگار ہم جس بات کا اعلان کرتے ہیں یا جس کو چھپاتے ہیں تو سب سے باخبر ہے اور اللہ پر زمین و آسمان میں کوئی چیز مخفی نہیں رہ سکتی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcclxxxix{شکر ہے اس خدا کا جس نے مجھے بڑھاپے میں اسماعیل و اسحاق جیسی اولاد عطا کی ہے کہ بیشک میرا پروردگار دعاؤں کا سننے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdccxc{پروردگار مجھے اور میری ذریت میں نماز قائم کرنے والے قرار دے اور پروردگار میری دعا کو قبول کرلے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdccxci{پروردگار مجھے اور میرے والدین کو اور تمام مومنین کو اس دن بخش دینا جس دن حساب قائم ہوگا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdccxcii{اور خبردار خدا کو ظالمین کے اعمال سے غافل نہ سمجھ لینا کہ وہ انہیں اس دن کے لئے مہلت دے رہا ہے جس دن آنکھیں خوف سے پتھرا جائیں گی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdccxciii{سر اٹھائے بھاگے چلے جارہے ہوں گے اور پلکیں بھی نہ پلٹتی ہوں گی اور ان کے دل دہشت سے ہوا ہورہے ہوں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdccxciv{اور آپ لوگوں کو اس دن سے ڈرائیں جس دن ان تک عذاب آجائے گا تو ظالمین کہیں گے کہ پروردگار ہمیں تھوڑی مدّت کے لئے پلٹا دے کہ ہم تیری دعوت کو قبول کرلیں اور تیرے رسولوں کا اتباع کرلیں تو جواب ملے گا کہ کیا تم نے اس سے پہلے قسم نہیں کھائی تھی کہ تمہیں کسی طرح کا زوال نہ ہوگا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdccxcv{اور تم تو ان ہی لوگوں کے مکانات میں ساکن تھے جنہوں نے اپنے اوپر ظلم کیا تھا اور تم پر واضح تھا کہ ہم نے ان کے ساتھ کیا برتاؤ کیا ہے اور ہم نے تمہارے لئے مثالیں بھی بیان کردی تھیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdccxcvi{اور ان لوگوں نے اپنا سارا مکر صرف کردیا اور خدا کی نگاہ میں ان کا سارا مکر ہے اگرچہ ان کا مکر ایسا تھا کہ اس سے پہاڑ بھی اپنی جگہ سے ہٹ جائیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdccxcvii{تو خبردار تم یہ خیال بھی نہ کرنا کہ خدا اپنے رسولوں سے کئے ہوئے وعدہ کی خلاف ورزی کرے گا اللہ سب پر غالب اور بڑا انتقام لینے والا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdccxcviii{اس دن جب زمین دوسری زمین میں تبدیل ہوجائے گی اور آسمان بھی بدل دیئے جائیں گے اور سب خدائے واحد و قہار کے سامنے پیش ہوں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdccxcix{اور تم اس دن مجرمین کو دیکھو گے کہ کس طرح زنجیروں میں جکڑے ہوئے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccc{ان کے لباس قطران کے ہوں گے اور ان کے چہروں کو آگ ہر طرف سے ڈھانکے ہوئے ہوگی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdccci{تاکہ خدا ہر نفس کو اس کے کئے کا بدلہ دے دے کہ وہ بہت جلد حساب کرنے والا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccii{بیشک یہ قرآن لوگوں کے لئے ایک پیغام ہے تاکہ اسی کے ذریعہ انہیں ڈرایا جائے اور انہیں معلوم ہوجائے کہ خدا ہی خدائے واحد و یکتا ہے اور پھر صاحبانِ عقل نصیحت حاصل کرلیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccciii{\basmalahur الرۤ - یہ کتابِ خدا اور قرآنِ مبین کی آیات ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mdccciv{ایک دن آنے والا ہے جب کفار بھی یہ تمنا کریں گے کہ کاش ہم بھی مسلمانِ ہوتے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mdcccv{انہیں ان کے حال پر چھوڑ دو کھائیں پئیں اور مزے اڑائیں اور امیدیں انہیں غفلت میں ڈالے رہیں عنقریب انہیں سب کچھ معلوم ہوجائے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mdcccvi{اور ہم نے کسی قریہ کو ہلاک نہیں کیا مگر یہ کہ اس کے لئے ایک میعاد مقرر کردی تھی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mdcccvii{کوئی امّت نہ اپنے وقت سے آگے بڑھ سکتی ہے اور نہ پیچھے ہٹ سکتی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mdcccviii{اور ان لوگوں نے کہا کہ اے وہ شخص جس پر قرآن نازل ہوا ہے تو دیوانہ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mdcccix{اگر تو اپنے دعوٰی میں سچا ہے تو فرشتوں کو کیوں سامنے نہیں لاتاہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mdcccx{حالانکہ ہم فرشتوں کو حق کے فیصلہ کے ساتھ ہی بھیجا کرتے ہیں اور اس کے بعد پھر کسی کو مہلت نہیں دی جاتی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mdcccxi{ہم نے ہی اس قرآن کو نازل کیا ہے اور ہم ہی اس کی حفاظت کرنے والے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mdcccxii{اور ہم نے آپ سے پہلے بھی مختلف قوموں میں رسول بھیجے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mdcccxiii{اور جب ان کے پاس رسول آتے ہیں تو یہ صرف ان کا مذاق اڑاتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mdcccxiv{اور ہم اسی طرح اس گمراہی کو مجرمین کے دل میں ڈال دیتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mdcccxv{یہ کبھی ایمان نہ لائیں گے کہ ان سے پہلے والوں کا طریقہ بھی ایسا ہی رہ چکا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mdcccxvi{ہم اگر آسمان میں ان کے لئے کوئی دروازہ کھول دیں اور یہ لوگ دن دھاڑے اسی دروازے سے چڑھ جائیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mdcccxvii{تو بھی کہیں گے کہ ہماری آنکھوں کو مدہوش کردیا گیا ہے اور ہم پر جادو کردیا گیا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mdcccxviii{اور ہم نے آسمان میں برج بنائے اور انہیں دیکھنے والوں کے لئے ستاروں سے آراستہ کردیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mdcccxix{اور ہر شیطان رجیم سے محفوظ بنادیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mdcccxx{مگر یہ کہ کوئی شیطان وہاں کی بات چر اَانا چاہے تو اس کے پیچھے دہکتا ہوا شعلہ لگادیا گیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mdcccxxi{اور ہم نے زمین کو پھیلادیا ہے اور اس میں پہاڑوں کے لنگر ڈال دیئے ہیں اور ہر چیز کو معینہ مقدار کے مطابق پیدا کیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mdcccxxii{اور اس میں تمہارے لئے بھی اسبابِ معیشت قرار دئے ہیں اور ان کے لئے بھی جن کے تم رازق نہیں ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiii{اور کوئی شے ایسی نہیں ہے جس کے ہمارے پاس خزانے نہ ہوں اور ہم ہر شے کو ایک معین مقدار میں ہی نازل کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mdcccxxiv{اور ہم نے ہواؤں کو بادلوں کا بوجھ اٹھانے والا بناکر چلایا ہے پھر آسمان سے پانی برسایا ہے جس سے تم کو سیراب کیا ہے اور تم اس کے خزانہ دار نہیں تھے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mdcccxxv{اور ہم ہی حیات و موت کے دینے والے ہیں اور ہم ہی سب کے والی و وارث ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvi{اور ہم تم سے پہلے گزر جانے والوں کو بھی جانتے ہیں اور بعد میں آنے والوں سے بھی باخبر ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mdcccxxvii{اور تمہارا پروردگار ہی سب کو ایک جگہ جمع کرے گا کہ وہ صاحبِ علم بھی ہے اور صاحب هحکمت بھی\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mdcccxxviii{اور ہم نے انسان کو سیاہی مائل نرم مٹی سے پیدا کیا ہے جو سوکھ کر کھن کھن بولنے لگی تھی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mdcccxxix{اور جناّت کو اس سے پہلے زہریلی آگ سے پیدا کیا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mdcccxxx{اور اس وقت کو یاد کرو کہ جب تمہارے پروردگار نے ملائکہ سے کہا تھا کہ میں سیاہی مائل نرم کھنکھناتی ہوئی مٹی سے ایک بشر پیدا کرنے والا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxi{پھر جب مکمل کرلوں اور اس میں اپنی روح حیات پھونک دوں تو سب کے سب سجدہ میں گر پڑنا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxii{تو تمام ملائکہ نے اجتماعی طور پر سجدہ کرلیا تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiii{علاوہ ابلیس کے کہ وہ سجدہ گزاروں کے ساتھ نہ ہوسکا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiv{اللہ نے کہا کہ اے ابلیس تجھے کیا ہوگیا ہے کہ تو سجدہ گزاروں میں شامل نہ ہوسکا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxv{اس نے کہا کہ میں ایسے بشر کو سجدہ نہیں کرسکتا جسے تو نے سیاہی مائل خشک مٹی سے پیدا کیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvi{ارشاد ہوا کہ تو یہاں سے نکل جا کہ تو مردود ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvii{اور تجھ پر قیامت کے دن تک لعنت ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxviii{اس نے کہا کہ پروردگار مجھے روز حشر تک کی مہلت دیدے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mdcccxxxix{جواب ملا کہ تجھے مہلت دیدی گئی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mdcccxl{ایک معلوم اور معین وقت کے لئے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mdcccxli{اس نے کہا کہ پروردگار جس طرح تو نے مجھے گمراہ کیا ہے میں ان بندوں کے لئے زمین میں ساز و سامان آراستہ کروں گا اور سب کو اکٹھا گمراہ کروں گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mdcccxlii{علاوہ تیرے ان بندوں کے جنہیں تو نے خالص بنا لیا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mdcccxliii{ارشاد ہوا کہ یہی میرا سیدھا راستہ ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mdcccxliv{میرے بندوں پر تیرا کوئی اختیار نہیں ہے علاوہ ان کے جو گمراہوں میں سے تیری پیروی کرنے لگیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mdcccxlv{اور جہنم ّایسے تمام لوگوں کی آخری وعدہ گاہ ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvi{اس کے سات دروازے ہیں اور ہر دروازے کے لئے ایک حصہ تقسیم کردیا گیا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mdcccxlvii{بیشک صاحبان ه تقوٰی باغات اور چشموں کے درمیان رہیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mdcccxlviii{انہیں حکم ہوگا کہ تم ان باغات میں سلامتی اور حفاظت کے ساتھ داخل ہو جاؤ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mdcccxlix{اور ہم نے ان کے سینوں سے ہر طرح کی کدورت نکال لی ہے اور وہ بھائیوں کی طرح آمنے سامنے تخت پر بیٹھے ہوں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mdcccl{نہ انہیں کوئی تکلیف چھو سکے گی اور نہ وہاں سے نکالے جائیں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mdcccli{میرے بندوں کو خبر کردو کہ میں بہت بخشنے والا اور مہربان ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mdccclii{اور میرا عذاب بھی بڑا دردناک عذاب ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mdcccliii{اور انہیں ابراہیم کے مہمانوں کے بارے میں اطلاع دیدو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mdcccliv{جب وہ لوگ ابراہیم کے پاس وارد ہوئے اور سلام کیا تو انہوں نے کہا کہ ہم آپ سے خوفزدہ ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mdccclv{انہوں نے کہا کہ آپ ڈریں نہیں ہم آپ کو ایک فرزند دانا کی بشارت دینے کے لئے آئے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mdccclvi{ابراہیم نے کہا کہ اب جب کہ بڑھاپا چھاگیا ہے تو مجھے کس چیز کی بشارت دے رہے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mdccclvii{انہوں نے کہا کہ ہم آپ کو بالکل سچی بشارت دے رہے ہیں خبردر آپ مایوسوں میں سے نہ ہوجائیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mdccclviii{ابراہیم علیھ السّلام نے کہا کہ رحمت خدا سے سوائے گمراہوں کے کون مایوس ہوسکتا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mdccclix{پھر کہا کہ مگر یہ تو بتائیے کہ آپ لوگوں کا مقصد کیا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mdccclx{انہوں نے کہا کہ ہم ایک مجرم قوم کی طرف بھیجے گئے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mdccclxi{علاوہ لوط کے گھر والوں کے کہ ان میں کے ہر ایک کو نجات دینے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mdccclxii{علاوہ ان کی بیوی کے کہ اس کے لئے ہم نے طے کردیا ہے کہ وہ عذاب میں رہ جانے والوں میں سے ہوگی\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mdccclxiii{پھر جب فرشتے آل لوط کے پاس آئے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mdccclxiv{اور لوط نے کہا کہ تم تو اجنبی قسم کے لوگ معلوم ہوتے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mdccclxv{تو انہوں نے کہا ہم وہ عذاب لے کر آئے ہیں جس میں آپ کی قوم شک کیا کرتی تھی\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mdccclxvi{اب ہم وہ برحق عذاب لے کر آئے ہیں اور ہم بالکل سچے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mdccclxvii{آپ رات گئے اپنے اہل کو لے کر نکل جائیں اور خود پیچھے پیچھے سب کی نگرانی کرتے چلیں اور کوئی پیچھے کی طرف مڑ کر بھی نہ دیکھے اور جدھر کا حکم دیا گیا ہے سب ادھر ہی چلے جائیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mdccclxviii{اور ہم نے اس امر کا فیصلہ کرلیا ہے کہ صبح ہوتے ہوتے اس قوم کی جڑیں تک کاٹ دی جائیں گی\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mdccclxix{اور ادھر شہر والے نئے مہمانوں کو دیکھ کر خوشیاں مناتے ہوئے آگئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mdccclxx{لوط نے کہا کہ یہ ہمارے مہمان ہیں خبردار ہمیں بدنام نہ کرنا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mdccclxxi{اور اللہ سے ڈرو اور رسوائی کا سامان نہ کرو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mdccclxxii{ان لوگوں نے کہا کہ کیا ہم نے آپ کو سب کے آنے سے منع نہیں کردیا تھا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiii{لوط نے کہا کہ یہ ہماری قوم کی لڑکیاں حاضر ہیں اگر تم ایسا ہی کرنا چاہتے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mdccclxxiv{آپ کی جان کی قسم یہ لوگ گمراہی کے نشہ میں اندھے ہورہے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mdccclxxv{نتیجہ یہ ہوا کہ صبح ہوتے ہی انہیں ایک چیخ نے اپنی گرفت میں لے لیا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvi{پھر ہم نے انہیں تہ و بالا کردیا اور ان کے اوپر کھڑنجے اور پتھروں کی بارش کردی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mdccclxxvii{ان باتوں میں صاحبان هہوش کے لئے بڑی نشانیاں پائی جاتی ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mdccclxxviii{اور یہ بستی ایک مستقل چلنے والے راستہ پر ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mdccclxxix{اور بیشک اس میں بھی صاحبانِ ایمان کے لئے نشانیاں ہیں\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mdccclxxx{اور اگرچہ ایکہ والے ظالم تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxi{تو ہم نے ان سے بھی انتقام لیا اور یہ دونوں بستیاں واضح شاہراہ پر ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxii{اور اصحاب حجر نے بھی مرسلین کی تکذیب کی\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiii{اور ہم نے انہیں بھی اپنی نشانیاں دیں تو وہ اعراض کرنے والے ہی رہ گئے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiv{اور یہ لوگ پہاڑ کو تراش کر محفوظ قسم کے مکانات بناتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxv{تو انہیں بھی صبح سویرے ہی ایک چنگھاڑ نے پکڑلیا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvi{تو انہوں نے جس قدر بھی حاصل کیا تھا کچھ کام نہ آیا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvii{اور ہم نے آسمان و زمین اور ان کے درمیان جو کچھ بھی ہے سب کو برحق پیدا کیا ہے اور قیامت بہرحال آنے والی ہے لہذا آپ ان سے خوبصورتی کے ساتھ درگزر کردیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxviii{بیشک آپ کا پروردگار سب کا پیدا کرنے والا اور سب کا جاننے والا ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mdccclxxxix{اور ہم نے آپ کو سبع مثانی اور قرآن عظیم عطا کیا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mdcccxc{لہذا آپ ان کفار میں بعض افراد کو ہم نے جو کچھ نعمااُ دنیا عطا کردی ہیں ان کی طرف نگاہ اٹھا کر بھی نہ دیکھیں اور اس کے بارے میں ہرگز رنجیدہ بھی نہ ہوں بس آپ اپنے شانوں کو صاحبانِ ایمان کے لئے جھکائے رکھیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mdcccxci{اور یہ کہہ دیں کہ میں تو بہت واضح انداز سے ڈرانے والا ہوں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mdcccxcii{جس طرح کہ ہم نے ان لوگوں پر عذاب نازل کیا ہے جو کتاب خدا کا حصہ ّبانٹ کرنے والے تھے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mdcccxciii{جن لوگوں نے قرآن کو ٹکڑے کردیا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mdcccxciv{لہذا آپ کے پروردگار کی قسم کہ ہم ان سے اس بارے میں ضرور سوال کریں گے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mdcccxcv{جو کچھ وہ کیا کرتے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvi{پس آپ اس بات کا واضح اعلان کردیں جس کا حکم دیا گیا ہے اور مشرکین سے کنارہ کش ہوجائیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mdcccxcvii{ہم ان استہزائ کرنے والوں کے لئے کافی ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mdcccxcviii{جو خدا کے ساتھ دوسرا خدا قرار دیتے ہیں اور عنقریب انہیں ان کا حال معلوم ہوجائے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mdcccxcix{اور ہم جانتے ہیں کہ آپ ان کی باتوں سے دل تنگ دل ہورہے ہیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcm{تو اب اپنے پروردگار کے حمدکی تسبیح کیجئے اور سجدہ گزاروں میں شامل ہوجایئے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mcmi{اور اس وقت تک اپنے رب کی عبادت کرتے رہئے جب تک کہ موت نہ آجائے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mcmii{\basmalahur امر الٰہی آگیا ہے لہذا اب بلاوجہ جلدی نہ مچاؤ کہ خدا ان کے شرک سے پاک و پاکیزہ اور بلند و بالا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mcmiii{وہ جس بندے پر چاہتا ہے اپنے حکم سے ملائکہ کو روح کے ساتھ نازل کردیتا ہے کہ ان بندوں کو ڈراؤ اورسمجھاؤ کہ میرے علاوہ کوئی خدا نہیں ہے لہذا مجھی سے ڈریں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mcmiv{اسی خدا نے زمین و آسمان کو حق کے ساتھ پیدا کیا ہے اور وہ ان کے شریکوں سے بہت بلند و بالاتر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mcmv{اس نے انسان کو ایک قطرہ نجس سے پیدا کیا ہے مگر پھر بھی وہ کّھلم کھلّا جھگڑا کرنے والا ہوگیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mcmvi{اور اسی نے چوپایوں کو بھی پیدا کیا ہے جن میں تمہارے لئے گرم لباس اور دیگر منافع کا سامان ہے اور بعض کو تو تم کھاتے بھی ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mcmvii{اور تمہارے لئے ان ہی جانوروں میں سے زینت کا سامان ہے جب تم شام کو انہیں واپس لاتے ہو اور صبح کو چراگاہ کی طرف لے جاتے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mcmviii{اور یہ حیوانات تمہارے بوجھ کو اٹھا کر ان شہروں تک لے جاتے ہیں جہاں تک تم جان جونکھوں میں ڈالے بغیرنہیں پہنچ سکتے تھے بیشک تمہارا پروردگار بڑا شفیق اور مہربان ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mcmix{اور اس نے گھوڑے خچر اور گدھے کو پیدا کیا تاکہ اس پر سواری کرو اور اسے زینت بھی قرار دو اور وہ ایسی چیزوں کو بھی پیدا کرتا ہے جن کا تمہیں علم بھی نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mcmx{اور درمیانی راستہ کی ہدایت خدا کی اپنی ذمہ داری ہے اور بعض راستے کج بھی ہوتے ہیں اور وہ چاہتا تو تم سب کو زبردستی راہ راست پر لے آتا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mcmxi{وہ وہی خدا ہے جس نے آسمان سے پانی نازل کیا ہے جس کا ایک حصّہ پینے والا ہے اور ایک حصّے سے درخت پیدا ہوتے ہیں جن سے تم جانوروں کو چراتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mcmxii{وہ تمہارے لئے زراعت,زیتون,خرمے,انگور اور تمام پھل اسی پانی سے پیدا کرتا ہے - اس امر میں بھی صاحبانِ فکر کے لئے اس کی قدرت کی نشانیاں پائی جاتی ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mcmxiii{اور اسی نے تمہارے رات دن اور آفتاب و ماہتاب سب کو مسخر کردیا ہے اور ستارے بھی اسی کے حکم کے تابع ہیں بیشک اس میں بھی صاحبانِ عقل کے لئے قدرت کی بہت سی نشانیاں پائی جاتی ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mcmxiv{اور جو کچھ تمہارے لئے اس زمین کے اندر مختلف رنگوں میں پیدا کیا ہے اس میں بھی عبرت حاصل کرنے والی قوم کے لئے اس کی نشانیاں پائی جاتی ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mcmxv{اور وہی وہ ہے جس نے سمندروں کو مّسخردیا ہے تاکہ تم اس میں سے تازہ گوشت کھاسکو اور پہننے کے لئے زینت کا سامان نکال سکو اور تم تو دیکھ رہے ہو کہ کشتیاں کس طرح اس کے سینے کو چیرتی ہوئی چلی جارہی ہیں اور یہ سب اس لئے بھی ہے کہ تم اس کے فضل و کرم کو تلاش کرسکو اور شاید اسی طرح اس کے شکر گزار بندے بھی بن جاؤ\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mcmxvi{اور اس نے زمین میں پہاڑوں کے لنگر ڈال دئے تاکہ تمہیں لے کر اپنی جگہ سے ہٹ نہ جائے اور نہریں اور راستے بنادئے تاکہ منزل سفر میں ہدایت پاسکو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mcmxvii{اور علامات معین کردیں اور لوگ ستاروں سے بھی راستے دریافت کرلیتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mcmxviii{کیا ایسا پیدا کرنے والا ان کے جیسا ہوسکتا ہے جو کچھ نہیں پیدا کرسکتے آخر تمہیں ہوش کیوں نہیں آرہا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mcmxix{اور تم اللہ کی نعمتوں کو شمار بھی کرنا چاہو تو نہیں کرسکتے ہو بیشک اللہ بڑا مہربان اور بخشنے والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mcmxx{اور اللہ ہی تمہارے باطن و ظاہر دونوں سے باخبر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mcmxxi{اور اس کے علاوہ جنہیں یہ مشرکین پکارتے ہیں وہ خود ہی مخلوق ہیں اور وہ کسی چیز کو خلق نہیں کرسکتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mcmxxii{وہ تو مفِدہ ہیں ان میں زندگی بھی نہیں ہے اور نہ انہیں یہ خبر ہے کہ مفِدے کب اٹھائے جائیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mcmxxiii{تمہارا خدا صرف ایک ہے اور جو لوگ آخرت پر ایمان نہیں رکھتے ہیں ان کے دل منکر قسم کے ہیں اور وہ خود مغرور و متکّبر ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mcmxxiv{یقینا اللہ ان تمام باتوں کو جانتا ہے جنہیں یہ حُھپاتے ہیں یا جن کا اظہار کرتے ہیں وہ متکبرین کو ہرگز پسند نہیں کرتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mcmxxv{اور جب ان سے پوچھا جاتا ہے کہ تمہارے پروردگار نے کیا کیا نازل کیا ہے تو کہتے ہیں کہ یہ سب پچھلے لوگوں کے افسانے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mcmxxvi{تاکہ یہ مکمل طور پر اپنا بھی بوجھ اٹھائیں اور اپنے ان مریدوں کا بھی بوجھ اٹھائیں جنہیں بلاعلم و فہم کے گمراہ کرتے رہے ہیں - بیشک یہ بڑا بدترین بوجھ اٹھانے والے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mcmxxvii{یقینا ان سے پہلے والوں نے بھی مکاریاں کی تھیں تو عذاب الٰہی ان کی تعمیرات تک آیا اور اسے جڑ سے اکھاڑ پھینک دیا اور ان کے سروں پر چھت گر پڑی اور عذاب ایسے انداز سے آیا کہ انہیں شعور بھی نہ پیدا ہوسکا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mcmxxviii{اس کے بعد وہ روزِ قیامت انہیں رسوا کرے گا اور پوچھے گا کہاں ہیں وہ میرے شریک جن کے بارے میں تم جھگڑا کیا کرتے تھے - اس وقت صاحبان هعلم کہیں گے کہ آج رسوائی اور برائی ان کافروں کے لئے ثابت ہوگئی ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mcmxxix{جنہیں ملائکہ اس عالم میں اٹھاتے ہیں کہ وہ اپنے نفس کے ظالم ہوتے ہیں تو اس وقت اطاعت کی پیشکش کرتے ہیں کہ ہم تو کوئی برائی نہیں کرتے تھے. بیشک خدا خوب جانتا ہے کہ تم کیا کیا کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mcmxxx{جاؤ اب جہنمّ کے دروازوں سے داخل ہوجاؤ اور ہمیشہ وہیں رہو کہ متکبرین کا ٹھکانا بہت برا ہوتا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mcmxxxi{اور جب صاحبان هتقوٰی سے کہا گیا کہ تمہارے پروردگار نے کیا نازل کیا ہے تو انہوں نے کہا کہ سب خیر ہے - بیشک جن لوگوں نے اس دنیا میں نیک اعمال کئے ہیں ان کے لئے نیکی ہے اور آخرت کا گھر تو بہرحال بہتر ہے اور وہ لَتقّین کا بہترین مکان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mcmxxxii{وہاں ہمیشہ رہنے والے باغات ہیں جن میں یہ لوگ داخل ہوں گے اور ان کے نیچے نہریں جاری ہوں گی وہ جو کچھ چاہیں گے سب ان کے لئے حاضر ہوگا کہ اللہ اسی طرح ان صاحبان ه تقوٰی کو جزا دیتا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiii{جنہیں ملائکہ اس عالم میں اٹھاتے ہیں کہ وہ پاک و پاکیزہ ہوتے ہیں اور ان سے ملائکہ کہتے ہیں کہ تم پر سلام ہو اب تم اپنے نیک اعمال کی بنا پر جنّت میں داخل ہوجاؤ\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mcmxxxiv{کیا یہ لوگ صرف اس بات کا انتظار کررہے ہیں کہ ان کے پاس ملائکہ آجائیں یا حکم پروردگار آجائے تو یہی ان کے پہلے والوں نے بھی کیا تھا اور اللہ نے ان پر کوئی ظلم نہیں کیا ہے بلکہ یہ خود ہی اپنے نفس پر ظلم کرتے رہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mcmxxxv{نتیجہ یہ ہوا کہ ان کے اعمال کے بفِے اثرات ان تک پہنچ گئے اور جن باتوں کا یہ مذاق اڑایا کرتے تھے ان ہی باتوں نے انہیں اپنے گھیرے میں لے لیا اور پھر تباہ و برباد کردیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvi{اور مشرکین کہتے ہیں کہ اگر خدا چاہتا تو ہم یا ہمارے بزرگ اس کے علاوہ کسی کی عبادت نہ کرتے اور نہ اس کے حکم کے بغیر کسی شے کو حرام قرار دیتے - اسی طرح ان کے پہلے والوں نے بھی کیا تھا تو کیا رسولوں کی ذمہ دری واضح اعلان کے علاوہ کچھ اور بھی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mcmxxxvii{اوریقینا ہم نے ہر امّت میں ایک رسول بھیجا ہے کہ تم لوگ اللہ کی عبادت کرو اور طاغوت سے اجتناب کرو پھر ان میں بعض کو خدا نے ہدایت دے دی اور بعض پر گمراہی ثابت ہوگئی تو اب تم لوگ روئے زمین میں سیر کرو اور دیکھو کہ تکذیب کرنے والوں کا انجام کیا ہوتا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mcmxxxviii{اگر آپ کو خواہش ہے کہ یہ ہدایت پاجائیں تو اللہ جس کو گمراہی میں چھوڑ چکا ہے اب اسے ہدایت نہیں دے سکتا اور نہ ان کا کوئی مدد کرنے والا ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mcmxxxix{ان لوگوں نے واقعی اللہ کی قسم کھائی تھی کہ اللہ مرنے والوں کو دوبارہ زندہ نہیں کرسکتا ہے حالانکہ یہ اس کا برحق وعدہ ہے یہ اور بات ہے کہ اکثر لوگ اس حقیقت سے باخبر نہیں ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mcmxl{وہ چاہتا ہے کہ لوگوں کے لئے اس امر کو واضح کردے جس میں وہ اختلاف کررہے ہیں اور کفار کو یہ معلوم ہوجائے کہ وہ واقعی جھوٹ بولا کرتے تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mcmxli{ہم جس چیز کا ارادہ کرلیتے ہیں اس سے فقط اتنا کہتے ہیں کہ ہوجا اور پھر وہ ہوجاتی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mcmxlii{اور جن لوگوں نے ظلم سہنے کے بعد راہ هخدا میں ہجرت اختیار کی ہے ہم عنقریب دنیا میں بھی ان کو بہترین مقام عطا کریں گے اور آخرت کا اجر تو یقینا بہت بڑا ہے .اگر یہ لوگ اس حقیقت سے باخبر ہوں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mcmxliii{یہی وہ لوگ ہیں جنہوں نے صبر کیا ہے اور اپنے پروردگار پر بھروسہ کرتے رہے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mcmxliv{اور ہم نے آپ سے پہلے بھی مذِدوں ہی کو رسول بنا کر بھیجا ہے اور ان کی طرف بھی وحی کرتے رہے ہیں تو ان سے کہئے کہ اگر تم نہیں جانتے ہو تو جاننے والوں سے دریافت کرو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mcmxlv{اور ہم نے ان رسولوں کو معجزات اور کتابوں کے ساتھ بھیجا ہے اور آپ کی طرف بھی ذکر کو (قرآن)نازل کیا ہے تاکہ ان کے لئے ان احکام کو واضح کردیں جو ان کی طرف نازل کئے گئے ہیں اور شاید یہ اس بارے میں کچھ غور و فکر کریں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mcmxlvi{کیا یہ برائیوں کی تدبیریں کرنے والے کفار اس بات سے مطمئن ہوگئے ہیں کہ اللہ اچانک انہیں زمین میں دھنسادے یا ان تک اس طرح عذاب آجائے کہ انہیں اس کا شعور بھی نہ ہو\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mcmxlvii{یا انہیں چلتے پھرتے گرفتار کرلیا جائے کہ یہ اللہ کو عاجز نہیں کرسکتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mcmxlviii{یا پھر انہیں ڈرا ڈرا کر دھیرے دھیرے گرفت میں لیا جائے کہ تمہارا پروردگار بڑا شفیق اور مہربان ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mcmxlix{کیا ان لوگوں نے ان مخلوقات کو نہیں دیکھا ہے جن کا سایہ داہنے بائیں پلٹتا رہتا ہے کہ سب اسی کی بارگاہ میں تواضع و انکسار کے ساتھ سجدہ ریز ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mcml{اور اللہ ہی کے لئے آسمان کی تمام چیزیں اور زمین کے تمام چلنے والے اور ملائکہ سجدہ ریز ہیں اور کوئی استکبار کرنے والا نہیں ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mcmli{یہ سب اپنے پروردگار کی برتری اور عظمت سے خوفزدہ ہیں اور اسی کے امر کے مطابق کام کررہے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mcmlii{اور اللہ نے کہہ دیا ہے کہ خبردار دو خدا نہ بناؤ کہ اللہ صرف خدائے واحد ہے لہذا مجھ ہی سے ڈرو\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mcmliii{اور اسی کے لئے زمین و آسمان کی ہر شے ہے اور اسی کے لئے دائمی اطاعت بھی ہے تو کیا تم غیر خدا سے بھی ڈرتے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mcmliv{اور تمہارے پاس جو بھی نعمت ہے وہ سب اللہ ہی کی طرف سے ہے اور اس کے بعد بھی جب تمہیں کوئی تکلیف چھولیتی ہے تو تم اسی سے فریاد کرتے ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mcmlv{اور جب وہ تکلیف کو دور کردیتاہے تو تم میں سے ایک گروہ اپنے پروردگار کا شریک بنانے لگتا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mcmlvi{تاکہ ان نعمتوں کا انکار کردیں جو ہم نے انہیں عطا کی ہیں خیر چند روز اور مزے کرلو اس کے بعد انجام معلوم ہی ہوجائے گا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mcmlvii{اور یہ ہمارے دئے ہوئے رزق میں سے ان کا بھی حصہ ّقرار دیتے ہیں جنہیں جانتے بھی نہیں ہیں تو عنقریب تم سے تمہارے افترا کے بارے میں بھی سوال کیا جائے گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mcmlviii{اور یہ اللہ کے لئے لڑکیاں قرار دیتے ہیں جب کہ وہ پاک اور بے نیاز ہے اور یہ جو کچھ چاہتے ہیں وہ سب ان ہی کے لئے ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mcmlix{اور جب خود ان میں سے کسی کو لڑکی کی بشارت دی جاتی ہے تو اس کا چہرہ سیاہ پڑ جاتا ہے اور وہ خون کے گھونٹ پینے لگتا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mcmlx{قوم سے منہ حُھپاتا ہے کہ بہت بفِی خبر سنائی گئی ہے اب اس کی ذلّت سمیت زندہ رکھے یا خاک میں ملادے یقینا یہ لوگ بہت بفِا فیصلہ کررہے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mcmlxi{جن لوگوں کو آخرت پرایمان نہیں ہے ان کی مثال بدترین مثال ہے اور اللہ کے لئے بہترین مثال ہے کہ وہی صاحب هعزّت اور صاحب هحکمت ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mcmlxii{اگر خدا لوگوں سے ان کے ظلم کا مواخذہ کرنے لگتا تو روئے زمین پر ایک رینگنے والے کو بھی نہ چھوڑتا لیکن وہ سب کو ایک معین مدّت تک کے لئے ڈھیل دیتا ہے اس کے بعد جب وقت آجائے گا تو پھر نہ ایک ساعت کی تاخیر ہوگی اور نہ تقدیم\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mcmlxiii{یہ خدا کے لئے وہ قرار دیتے ہیں جو خود اپنے لئے ناپسند کرتے ہیں اور ان کی زبانیں یہ غلط بیانی بھی کرتی ہیں کہ آخرت میں ان کے لئے نیکی ہے حالانکہ یقینی طور پر ان کے لئے جہّنم اور یہ سب سے پہلے ہی ڈالے جائیں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mcmlxiv{اللہ کی اپنی قسم کہ ہم نے تم سے پہلے مختلف قوموں کی طرف رسول بھیجے تو شیطان نے ان کے کاروبار کو ان کے لئے آراستہ کردیا اور وہی آج بھی ان کا سرپرست ہے اور ان کے لئے بہت بڑا دردناک عذاب ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mcmlxv{اور ہم نے آپ پر کتاب صرف اس لئے نازل کی ہے کہ آپ ان مسائل کی وضاحت کردیں جن میں یہ اختلاف کئے ہوئے ہیں اور یہ کتاب صاحبان هایمان کے لئے مجسمئہ ہدایت اور رحمت ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mcmlxvi{اور اللہ ہی نے آسمان سے پانی برسایا ہے اور اس کے ذریعہ زمین کو مردہ ہونے کے بعد دوبارہ زندہ کیا ہے اس میں بھی بات سننے والی قوم کے لئے نشانیاں پائی جاتی ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mcmlxvii{اور تمہارے لئے حیوانات میں بھی عبرت کا سامان ہے کہ ہم ان کے شکم سے گوبر اور خون کے درمیان سے خالص دودھ نکالتے ہیں جو پینے والوں کے لئے انتہائی خوشگوار معلوم ہوتا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mcmlxviii{اور پھر خرمہ اور انگور کے پھلوں سے وہ شیرہ نکالتے ہیں جس سے تم نشہ اور بہترین رزق سب کچھ تیار کرلیتے ہو اس میں بھی صاحبان هعقل کے لئے نشانیاں پائی جاتی ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mcmlxix{اور تمہارے پروردگار نے شہد کی مکھی کو اشارہ دیا کہ پہاڑوں اور درختوں اور گھروں کی بلندیوں میں اپنے گھر بنائے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mcmlxx{اس کے بعد مختلف پھلوں سے غذا حاصل کرے اور نرمی کے ساتھ خدائی راستہ پر چلے جس کے بعد اس کے شکم سے مختلف قسم کے مشروب برآمد ہوں گے جس میں پورے عالم انسانیت کے لئے شفا کا سامان ہے اور اس میں بھی فکر کرنے والی قوم کے لئے ایک نشانی ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mcmlxxi{اور اللہ ہی نے تمہیں پیدا کیا ہے پھر وہ ہی وفات دیتا ہے اور بعض لوگوں کو اتنی بدترین عمر تک پلٹا دیا جاتا ہے کہ علم کے بعد بھی کچھ جاننے کے قابل نہ رہ جائیں. بیشک اللہ ہر شے کا جاننے والا اور ہر شے پر قدرت رکھنے والا ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mcmlxxii{اور اللہ ہی نے بعض کو رزق میں بعض پر فضیلت دی ہے تو جن کو بہتر بنایا گیا ہے وہ اپنا بقیہ رزق ان کی طرف نہیں پلٹا دیتے ہیں جو ان کے ہاتھوں کی ملکیت ہیں حالانکہ رزق میں سب برابر کی حیثیت رکھنے والے ہیں تو کیا یہ لوگ اللہ ہی کی نعمت کا انکار کررہے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiii{اور اللہ نے تم ہی میں سے تمہارا جوڑا بنایا ہے پھر اس جوڑے سے اولاد قرار دی ہے اور سب کو پاکیزہ رزق دیا ہے تو کیا یہ لوگ باطل پر ایمان رکھتے ہیں اور اللہ ہی کی نعمت سے انکار کرتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mcmlxxiv{اور یہ لوگ اللہ کو چھوڑ کر ان کی عبادت کرتے ہیں جو نہ آسمان و زمین میں کسی رزق کے مالک ہیں اور نہ کسی چیز کی طاقت ہی رکھتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mcmlxxv{تو خبردار اللہ کے لئے مثالیں بیان نہ کرو کہ اللہ سب کچھ جانتا ہے اور تم کچھ نہیں جانتے ہو\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvi{اللہ نے خود اس غلام مملوک کی مثال بیان کی ہے جو کسی چیز کا اختیار نہیں رکھتا ہے اور اس آزاد انسان کی مثال بیان کی ہے جسے ہم نے بہترین رزق عطا کیا ہے اور وہ اس میں سے خفیہ اور علانیہ انفاق کرتا رہتا ہے تو کیا یہ دونوں برابر ہوسکتے ہیں ساری تعریف صرف اللہ کے لئے ہی ہے مگر ان لوگوں کی اکثریت کچھ نہیں جانتی ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mcmlxxvii{اور اللہ نے ایک اور مثال ان دو انسانوں کی بیان کی ہے جن میں سے ایک گونگا ہے اور اس کے بس میں کچھ نہیں ہے بلکہ وہ خود اپنے مولا کے سر پر ایک بوجھ ہے کہ جس طرف بھی بھیج دے کوئی خیر لے کر نہ آئے گا تو کیا وہ اس کے برابر ہوسکتا ہے جو عدل کا حکم دیتا ہے اور سیدھے راستہ پر گامزن ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mcmlxxviii{آسمان و زمین کا سارا غیب اللہ ہی کے لئے ہے اور قیامت کا حکم تو صرف ایک پلک جھپکنے کے برابر یا اس سے بھی قریب تر ہے اور یقینا اللہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mcmlxxix{اور اللہ ہی نے تمہیں شکم مادر سے اس طرح نکالا ہے کہ تم کچھ نہیں جانتے تھے اور اسی نے تمہارے لئے کان آنکھ اور دل قرار دئے ہیں کہ شاید تم شکر گزار بن جاؤ\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mcmlxxx{کیا ان لوگوں نے پرندوں کی طرف نہیں دیکھا کہ وہ کس طرح فضائے آسمان میں مسخر ہیں کہ اللہ کے علاوہ انہیں کوئی روکنے والا اور سنبھالنے والا نہیںہے بیشک اس میں بھی اس قوم کے لئے بہت سی نشانیاں ہیں جو ایمان رکھنے والی قوم ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxi{اور اللہ ہی نے تمہارے لئے تمہارے گھروں کو وجہ سکون بنایا ہے اور تمہارے لئے جانوروں کی کھالوں سے ایسے گھر بنادئے ہیں جن کو تم روزِ سفر بھی ہلکاسمجھتے ہو اور روزِ اقامت بھی ہلکا محسوس کرتے ہو اور پھر ان کے اون, روئیں اور بالوں سے مختلف سامان هزندگی اور ایک مدّت کے لئے کارآمد چیزیں بنادیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxii{اور اللہ ہی نے تمہارے لئے مخلوقات کا سایہ قرار دیا ہے اور پہاڑوں میں چھپنے کی جگہیں بنائی ہیں اور ایسے پیراہن بنائے ہیں جو گرمی سے بچاسکیں اور پھر ایسے پیراہن بنائے ہیں جو ہتھیاروں کی زد سے بچاسکیں. وہ اسی طرح اپنی نعمتوں کو تمہارے اوپر تمام کردیتا ہے کہ شاید تم اطاعت گزار بن جاؤ\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiii{پھر اس کے بعد بھی اگر یہ ظالم منہ پھیر لیں تو آپ کا کام صرف واضح پیغام کا پہنچا دینا ہے اور بس\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiv{یہ لوگ اللہ کی نعمت کو پہچانتے ہیں اور پھر انکار کرتے ہیں اور ان کی اکثریت کافر ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxv{اور قیامت کے دن ہم ہر امّت میں سے ایک گواہ لائیں گے اور اس کے بعد کافروں کو کسی طرح کی اجازت نہ دی جائے گی اور نہ ان کا عذر ہی سناُ جائے گا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvi{اور جب ظالمین عذاب کو دیکھ لیں گے تو پھر اس میں کوئی تخفیف نہ ہوگی اور نہ انہیں کسی قسم کی مہلت دی جائے گی\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvii{اور جب مشرکین اپنے شرکائ کو دیکھیں گے تو کہیں گے پروردگار یہی ہمارے شرکائ تھے جنہیں ہم تجھے چھوڑ کر پکارا کرتے تھے پھر وہ شرکائ اس بات کو ان ہی کی طرف پھینک دیں گے کہ تم لوگ بالکل جھوٹے ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxviii{اور پھر اس دن اللہ کی بارگاہ میں اطاعت کی پیشکش کریں گے اور جن باتوں کا افتراکیا کرتے تھے وہ سب غائب اور بے کار ہوجائیں گی\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mcmlxxxix{جن لوگوں نے کفر اختیار کیا اور راہ خدا میں رکاوٹ پیدا کی ہم نے ان کے عذاب میں مزید اضافہ کردیا کہ یہ لوگ فساد برپا کیا کرتے تھے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mcmxc{اور قیامت کے دن ہم ہر گروہ کے خلاف ان ہی میں کا ایک گواہ اٹھائیں گے اور پیغمبر آپ کو ان سب کا گواہ بناکر لے آئیں گے اور ہم نے آپ پر کتاب نازل کی ہے جس میں ہر شے کی وضاحت موجود ہے اور یہ کتاب اطاعت گزاروں کے لئے ہدایت ,رحمت اور بشارت ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mcmxci{بیشک اللہ عدل ,احسان اور قرابت داروں کے حقوق کی ادائیگی کا حکم دیتا ہے اور بدکاری ,ناشائستہ حرکات اور ظلم سے منع کرتا ہے کہ شاید تم اسی طرح نصیحت حاصل کرلو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mcmxcii{اور جب کوئی عہد کرو تو اللہ کے عہد کو پورا کرو اور اپنی قسموں کو ان کے استحکام کے بعد ہرگز مت توڑو جب کہ تم اللہ کو کفیل اور نگراں بناچکے ہو کہ یقینا اللہ تمہارے افعال کو خوب جانتا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mcmxciii{اور خبردار اس عورت کے مانند نہ ہوجاؤ جس نے اپنے دھاگہ کو مضبوط کاتنے کے بعد پھر اسے ٹکڑے ٹکڑے کرڈالا-کیا تم اپنے معاہدے کو اس چالاکی کا ذریعہ بناتے ہو کہ ایک گروہ دوسرے گروہ سے زیادہ فائدہ حاصل کرے-اللہ تمہیں ان ہی باتوں کے ذریعے آزما رہا ہے اور یقینا روزِ قیامت اس امر کی وضاحت کردے گا جس میںتم آپس میں اختلاف کررہے تھے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mcmxciv{اور اگر پروردگار چاہتا تو جبراتم سب کو ایک قوم بنادیتا لیکن وہ اختیار دے کر جسے چاہتا ہے گمراہی میں چھوڑ دیتا ہے اور جسے چاہتا ہے منزل ہدایت تک پہنچادیتاہے اور تم سے یقینا ان اعمال کے بارے میں سوال کیا جائے گا جوتم دنیا میں انجام دے رہے تھے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mcmxcv{اور خبردار اپنی قسموں کو فساد کا ذریعہ نہ بناؤ کہ نو مسلم افراد کے قدم ثابت ہونے کے بعد پھر اکھڑ جائیں اور تمہیں راہ هخدا سے روکنے کی پاداش میں بڑے عذاب کا مزہ چکھنا پڑے اور تمہارے لئے عذابِ عظیم ہوجائے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mcmxcvi{اور خبردار اللہ کے عہدے کے عوض معمولی قیمت (مال دنیا) نہ لو کہ جو کچھ اللہ کے پاس ہے وہی تمہارے حق میں بہتر ہے اگر تم کچھ جانتے بوجھتے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mcmxcvii{جو کچھ تمہارے پاس ہے وہ سب خرچ ہوجائے گا اور جو کچھ اللہ کے پاس ہے وہی باقی رہنے والا ہے اور ہم یقینا صبر کرنے والوں کو ان کے اعمال سے بہتر جزا عطا کریں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mcmxcviii{جو شخص بھی نیک عمل کرے گا وہ مرد ہو یا عورت بشرطیکہ صاحب هایمان ہو ہم اسے پاکیزہ حیات عطا کریں گے اور انہیں ان اعمال سے بہتر جزا دیں گے جو وہ زندگی میں انجام دے رہے تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mcmxcix{لہذا جب آپ قرآن پڑھیں تو شیطان هرجیم کے مقابلہ کے لئے اللہ سے پناہ طلب کریں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mm{شیطان ہرگز ان لوگوں پر غلبہ نہیں پاسکتا جو صاحبان هایمان ہیں اور جن کا اللہ پر توکل اور اعتماد ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmi{اس کا غلبہ صرف ان لوگوں پر ہوتا ہے جو اسے سرپرست بناتے ہیں اور اللہ کے بارے میں شرک کرنے والے ہیں\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmii{اور ہم جب ایک آیت کی جگہ پر دوسری آیت تبدیل کرتے ہیں تو اگرچہ خدا خوب جانتا ہے کہ وہ کیا نازل کررہا ہے لیکن یہ لوگ یہی کہتے ہیں کہ محمد تم افترا کرنے والے ہو حالانکہ ان کی اکثریت کچھ نہیں جانتی ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmiii{تو آپ کہہ دیجئے کہ اس قرآن کوروح القدس جبرئیل نے تمہارے پروردگار کی طرف سے حق کے ساتھ نازل کیا ہے تاکہ صاحبانِ ایمان کو ثبات و استقلال عطاکرے اور یہ اطاعت گزاروں کے لئے ایک ہداےت اور بشارت ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmiv{اور ہم خوب جانتے ہیں کہ یہ مشرکین یہ کہتے ہیں کہ انہیں کوئی انسان اس قرآن کی تعلیم دے رہا ہے-حالانکہ جس کی طرف یہ نسبت دیتے ہیں وہ عجمی ہے اور یہ زبان عربی واضح و فصیح ہے\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmv{بیشک جو لوگ اللہ کی نشانیوں پر ایمان نہیں لاتے ہیں خدا انہیں ہدایت بھی نہیں دیتا ہے اور ان کے لئے دردناک عذاب بھی ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmvi{یقینا غلط الزام لگانے والے صرف وہی افراد ہوتے ہیں جو اللہ کی آیتوں پر ایمان نہیں رکھتے ہیں اور وہی جھوٹے بھی ہوتے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmvii{جو شخص بھی ایمان لانے کے بعد کفر اختیار کرلے .... علاوہ اس کے کہ جو کفر پر مجبور کردیا جائے اور اس کا دل ایمان کی طرف سے مطمئن ہو ....اور کفر کے لئے سینہ کشادہ رکھتا ہو اس کے اوپر خدا کا غضب ہے اور اس کے لئے بہت بڑا عذاب ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmviii{یہ اس لئے کہ ان لوگوں نے زندگانی دنیا کو آخرت پر مقدم کیا ہے اور اللہ ظالم قوموں کو ہرگز ہدایت نہیں دیتا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmix{یہی وہ لوگ ہیں جن کے دلوں پر اور آنکھ کان پر کفر کی چھاپ لگا دی گئی ہے اور یہی وہ لوگ ہیں جوحقیقتا حقائق سے غافل ہیں\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmx{اور یقینا یہی لوگ آخرت میں گھاٹا اٹھانے والوں میں ہیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmxi{اس کے بعد تمہارا پروردگار ان لوگوں کے لئے جنہوں نے فتنوں میں مبتلا ہونے کے بعد ہجرت کی ہے اور پھر جہاد بھی کیا ہے اور صبر سے بھی کام لیا ہے یقینا تمہارا پروردگار بہت زیادہ بخشنے والا اور مہربان ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmxii{قیامت کا دن وہ دن ہوگا جب ہر انسان اپنے نفس کی طرف سے دفاع کرنے کے لئے حاضر ہوگا اور نفس کو اس کے عمل کا پورا پورا بدلہ دیا جائے گا اور کسی پر ظلم نہیں کیا جائے گا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmxiii{اور اللہ نے اس قریہ کی بھی مثال بیان کی ہے جو محفوظ اور مطمئن تھی اور اس کا رزق ہر طرف سے باقاعدہ آرہا تھا لیکن اس قریہ کے رہنے والوں نے اللہ کی نعمتوں کا انکار کیا تو خدا نے انہیں بھوک اور خوف کے لباس کا مزہ چکھادیا صرف ان کے ان اعمال کی بنا پر کہ جو وہ انجام دے رہے تھے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmxiv{اور یقینا ان کے پاس رسول آیا تو انہوں نے اس کی تکذیب کردی تو پھر ان تک عذاب آپہنچا کہ یہ سب ظلم کرنے والے تھے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmxv{لہذا اب تم اللہ کے دئے ہوئے رزق حلال و پاکیزہ کو کھاؤ اور اس کی عبادت کرنے والے ہو تو اس کی نعمتوں کا شکریہ بھی ادا کرتے رہو\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmxvi{اس نے تمہارے لئے صرف اَمفِدار ,خون ,سور کا گوشت اور جو غیر خدا کے نام پر ذبح کیا جائے اسے حرام کردیا ہے اور اس میں بھی اگر کوئی شخص مضطر و مجبور ہوجائے اور نہ بغاوت کرے نہ حد سے تجاوز کرے تو خدا بہت بڑا بخشنے والا اور مہربان ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmxvii{اور خبردار جو تمہاری زبانیں غلط بیانی سے کام لیتی ہیں اس کی بنا پر یہ نہ کہو کہ یہ حلال ہے اور یہ حرام ہے کہ اس طرح خدا پر جھوٹا بہتان باندھنے والے ہوجاؤ گے اور جو اللہ پر جھوٹا بہتان باندھتے ہیں ان کے لئے فلاح اور کامیابی نہیں ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmxviii{یہ دنیا صرف ایک مختصر لذّت ہے اور اس کے بعد ان کے لئے بڑا دردناک عذاب ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmxix{اور ہم نے یہودیوں کے لئے ان تمام چیزوں کو حرام کردیا ہے جن کا تذکرہ ہم پہلے کرچکے ہیں اور یہ ہم نے ظلم نہیں کیا ہے بلکہ وہ خود اپنے نفس پر ظلم کرنے والے تھے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmxx{اس کے بعد تمہارا پروردگار ان لوگوں کے لئے جنہوں نے نادانی میں برائیاں کی ہیں اور اس کے بعد توبہ بھی کرلی ہے اور اپنے کو سدھار بھی لیا ہے تمہارا پروردگار ان باتوں کے بعد بہت بڑا بخشنے والا اور مہربان ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmxxi{بیشک ابراہیم علیھ السّلامایک مستقل امّت اور اللہ کے اطاعت گزار اور باطل سے کترا کر چلنے والے تھے اور مشرکین میں سے نہیں تھے\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmxxii{وہ اللہ کی نعمتوں کے شکر گزار تھے خدا نے انہیں منتخب کیا تھا اور سیدھے راستہ کی ہدایت دی تھی\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmxxiii{اور ہم نے انہیں دنیا میں بھی نیکی عطا کی اور آخرت میں بھی ان کا شمار نیک کردار لوگوں میں ہوگا\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmxxiv{اس کے بعد ہم نے آپ کی طرف وحی کی کہ ابراہیم علیھ السّلام حنیف کے طریقہ کا اتباع کریں کہ وہ مشرکین میں سے نہیں تھے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmxxv{ہفتہ کے دن کی تعظیم صرف ان لوگوں کے لئے قرار دی گئی تھی جو اس کے بارے میں اختلاف کررہے تھے اور آپ کا پروردگار روز قیامت ان تمام باتوں کا فیصلہ کردے گا جن میں یہ لوگ اختلاف کررہے ہیں\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmxxvi{آپ اپنے رب کے راستے کی طرف حکمت اور اچھی نصیحت کے ذریعہ دعوت دیں اور ان سے اس طریقہ سے بحث کریں جو بہترین طریقہ ہے کہ آپ کا پروردگار بہتر جانتا ہے کہ کون اس کے راستے سے بہک گیا ہے اور کون لوگ ہدایت پانے والے ہیں\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmxxvii{اور اگر تم ان کے ساتھ سختی بھی کرو تو اسی قدر جس قدر انہوں نے تمہارے ساتھ سختی کی ہے اور اگر صبر کرو تو صبر بہرحال صبر کرنے والوں کے لئے بہترین ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmxxviii{اور آپ صبر ہی کریں کہ آپ کا صبر بھی اللہ ہی کی مدد سے ہوگا اور ان کے حال پر رنجیدہ نہ ہوں اور ان کی مکاّریوں کی وجہ سے تنگدلی کا بھی شکار نہ ہوں\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmxxix{بیشک اللہ ان لوگوں کے ساتھ ہے جنہوں نے تقوٰی اختیار کیا ہے اور جو نیک عمل انجام دینے والے ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmxxx{\basmalahur پاک و پاکیزہ ہے وہ پروردگار جو اپنے بندے کو راتوں رات مسجد الحرام سے مسجد اقصٰی تک لے گیا جس کے اطراف کو ہم نے بابرکت بنایا ہے تاکہ ہم اسے اپنی بعض نشانیاں دکھلائیں بیشک وہ پروردگار سب کی سننے والا اور سب کچھ دیکھنے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmxxxi{اور ہم نے موسٰی کو کتاب عنایت کی اور اس کتاب کو بنی اسرائیل کے لئے ہدایت بنا دیا کہ خبردار میرے علاوہ کسی کو اپنا کارساز نہ بنانا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmxxxii{یہ بنی اسرائیل ان کی اولاد ہیں جن کو ہم نے نوح کے ساتھ کشتی میں اٹھایاتھا جو ہمارے شکر گزار بندے تھے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmxxxiii{اور ہم نے بنی اسرائیل کو کتاب میں یہ اطلاع بھی دے دی تھی کہ تم زمین میں دو مرتبہ فساد کرو گے اور خوب بلندی حاصل کرو گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmxxxiv{اس کے بعد جب پہلے وعدہ کا وقت آگیا تو ہم نے تمہارے اوپر اپنے ان بندوں کو مسلّط کردیا جو بہت سخت قسم کے جنگجو تھے اور انہوں نے تمہارے دیار میں چن چن کر تمہیں مارا اور یہ ہمارا ہونے والا وعدہ تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmxxxv{اس کے بعد ہم نے تمہیں دوبار ان پر غلبہ دیا اور اموال و اولاد سے تمہاری مدد کی اور تمہیں بڑے گروہ والا بنادیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmxxxvi{اب تم نیک عمل کرو گے تو اپنے لئے اور برا کرو گے تو اپنے لئے کرو گے-اس کے بعد جب دوسرے وعدہ کا وقت آگیا تو ہم نے دوسری قوم کو مسلّط کردیا تاکہ تمہاری شکلیں بگاڑ دیں اور مسجد میں اس طرح داخل ہوں جس طرح پہلے داخل ہوئے تھے اور جس چیز پر بھی قابو پالیں اسے باقاعدہ تباہ و برباد کردیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmxxxvii{امید ہے کہ تمہارا پروردگار تم پر رحم کردے لیکن اگر تم نے دوبارہ فساد کیا تو ہم پھر سزا دیں گے اور ہم نے جہنم ّکو کافروں کے لئے ایک قید خانہ بنادیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmxxxviii{بیشک یہ قرآن اس راستہ کی ہدایت کرتا ہے جو بالکل سیدھا ہے اور ان صاحبان هایمان کو بشارت دیتا ہے جو نیک اعمال بجالاتے ہیں کہ ان کے لئے بہت بڑا اجر ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmxxxix{اور جو لوگ آخرت پر ایمان نہیں رکھتے ہیں ان کے لئے ہم نے ایک دردناک عذاب مہیا ّکر رکھا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmxl{اور انسان کبھی کبھی اپنے حق میں بھلائی کی طرح برائی کی دعا مانگنے لگتا ہے کہ انسان بہت جلد باز واقع ہوا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmxli{اور ہم نے رات اور دن کو اپنی نشانی قرار دیا ہے پھر ہم رات کی نشانی کو مٹا دیتے ہیں اور دن کی نشانی کو روشن کردیتے ہیں تاکہ تم اپنے پروردگار کے فضل و انعام کو طلب کرسکو اور سال اور حساب کے اعداد معلوم کرسکو اور ہم نے ہر شے کو تفصیل کے ساتھ بیان کردیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmxlii{اور ہم نے ہر انسان کے نامئہ اعمال کو اس کی گردن میں آویزاں کردیا ہے اور روز قیامت اسے ایک کھلی ہوئی کتاب کی طرح پیش کردیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmxliii{کہ اب اپنی کتاب کو پڑھ لو آج تمہارے حساب کے لئے یہی کتاب کافی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmxliv{جو شخص بھی ہدایت حاصل کرتا ہے وہ اپنے فائدہ کے لئے کرتا ہے اور جو گمراہی اختیار کرتا ہے وہ بھی اپنا ہی نقصان کرتا ہے اور کوئی کسی کا بوجھ اٹھانے والا نہیں ہے اور ہم تو اس وقت تک عذاب کرنے والے نہیں ہیں جب تک کہ کوئی رسول نہ بھیج دیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmxlv{اور ہم نے جب بھی کسی قریہ کو ہلاک کرنا چاہا تو اس کے ثروت مندوں پر احکام نافذ کردئے اور انہوں نے ان کی نافرمانی کی تو ہماری بات ثابت ہوگئی اور ہم نے اسے مکمل طور پر تباہ کردیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmxlvi{اور ہم نے نوح کے بعد بھی کتنی اّمتوں کو ہلاک کردیا ہے اور تمہارا پروردگار بندوں کے گناہوں کا بہترین جاننے والا اور دیکھنے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmxlvii{جو شخص بھی دنیا کا طلب گار ہے ہم اس کے لئے جلد ہی جو چاہتے ہیں دے دیتے ہیں پھر اس کے بعد اس کے لئے جہنمّ ہے جس میں وہ ذلّت و رسوائی کے ساتھ داخل ہوگا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmxlviii{اور جو شخص آخرت کا چاہنے والا ہے اور اس کے لئے ویسی ہی سعی بھی کرتا ہے اور صاحب هایمان بھی ہے تو اس کی سعی یقینا مقبول قرار دی جائے گی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmxlix{ہم آپ کے پروردگار کی عطا و بخشش سے ِن کی اور اُن کی سب کی مدد کرتے ہیں اور آپ کے پروردگار کی عطا کسی پر بند نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mml{آپ دیکھئے کہ ہم نے کس طرح بعض کو بعض پر فضیلت دی ہے اور پھر آخرت کے درجات اور وہاں کی فضیلتیں تو اور زیادہ بزرگ و برتر ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmli{خبردار اپنے پروردگار کے ساتھ کوئی دوسرا خدا قرار نہ دینا کہ اس طرح قابل همذمّت اور لاوارث بیٹھے رہ جاؤ گے اور کوئی خدا کام نہ آئے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmlii{اور آپ کے پروردگار کا فیصلہ ہے کہ تم سب اس کے علاوہ کسی کی عبادت نہ کرنا اور ماں باپ کے ساتھ اچھا برتاؤ کرنا اور اگر تمہارے سامنے ان دونوں میں سے کوئی ایک یا دونوں بوڑھے ہوجائیں تو خبردار ان سے اُف بھی نہ کہنا اور انہیں جھڑکنا بھی نہیں اور ان سے ہمیشہ شریفانہ گفتگو کرتے رہنا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmliii{اور ان کے لئے خاکساری کے ساتھ اپنے کاندھوں کو جھکا دینا اور ان کے حق میں دعا کرتے رہنا کہ پروردگار اُن دونوں پر اسی طرح رحمت نازل فرما جس طرح کہ انہوں نے بچپنے میں مجھے پالا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmliv{تمہارا پروردگار تمہارے دلوں کے حالات سے خوب باخبر ہے اور اگر تم صالح اور نیک کردار ہو تو وہ توبہ کرنے والوں کے لئے بہت بخشنے والا بھی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmlv{اور دیکھو قرابتداروں کو اور مسکین کو اور مسافر غربت زدہ کو اس کا حق دے دو اور خبردار اسراف سے کام نہ لینا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmlvi{اسراف کرنے والے شیاطین کے بھائی بند ہیں اور شیطان تو اپنے پروردگار کا بہت بڑا انکار کرنے والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmlvii{اگر تم کو اپنے رب کی رحمت کے انتظار میں جس کے تم امیدوار ہو ان افراد سے کنارہ کش بھی ہونا پڑے تو ان سے نرم انداز سے گفتگو کرنا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmlviii{اور خبردار نہ اپنے ہاتھوں کو گردنوں سے بندھا ہوا قرار دو اور نہ بالکل پھیلا دو کہ آخر میں قابلِ ملامت اور خالی ہاتھ بیٹھے رہ جاؤ\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmlix{تمہارا پروردگار جس کے لئے چاہتا ہے رزق کو وسیع یا تنگ بنا دیتا ہے وہ اپنے بندوں کے حالات کا خوب جاننے والا اور دیکھنے والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmlx{اور خبردار اپنی اولاد کو فاقہ کے خوف سے قتل نہ کرنا کہ ہم انہیں بھی رزق دیتے ہیں اور تمہیں بھی رزق دیتے ہیں بیشک ان کا قتل کردینا بہت بڑا گناہ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmlxi{اور دیکھو زنا کے قریب بھی نہ جانا کہ یہ بدکاری ہے اور بہت بفِا راستہ ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmlxii{اور کسی نفس کو جس کو خدا نے محترم بنایا ہے بغیر حق کے قتل بھی نہ کرنا کہ جو مظلوم قتل ہوتا ہے ہم اس کے ولی کو بدلہ کا اختیار دے دیتے ہیں لیکن اسے بھی چاہئے کہ قتل میں حد سے آگے نہ بڑھ جائے کہ ِس کی بہرحال مدد کی جائے گی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmlxiii{اور یتیم کے مال کے قریب بھی نہ جانا مگر اس طرح جو بہترین طریقہ ہے یہاں تک کہ وہ توانا ہوجائے اور اپنے عہدوں کو پورا کرنا کہ عُہد کے بارے میں سوال کیا جائے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmlxiv{اور جب ناپو تو پورا ناپو اور جب تولو تو صحیح ترازو سے تولو کہ یہی بہتری اور بہترین انجام کا ذریعہ ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmlxv{اور جس چیز کا تمہیں علم نہیں ہے اس کے پیچھے مت جانا کہ روزِ قیامت سماعتً بصارت اور قواُ قلب سب کے بارے میں سوال کیا جائے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmlxvi{اور روئے زمین پر اکڑ کر نہ چلنا کہ نہ تم زمین کو شق کرسکتے ہو اور نہ سر اٹھا کر پہاڑوں کی بلندیوں تک پہنچ سکتے ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmlxvii{یہ سب باتیں وہ ہیں جن کی برائی تمہارے پروردگار کے نزدیک سخت ناپسند ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmlxviii{یہ وہ حکمت ہے جس کی وحی تمہارے پروردگار نے تمہاری طرف کی ہے اور خبردار خدا کے ساتھ کسی اور کو خدا نہ قرار دینا کہ جہنمّ میں ملامت اور ذلّت کے ساتھ ڈال دیئے جاؤ\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmlxix{کیا تمہارے پروردگار نے تم لوگوں کے لئے لڑکوں کو پسند کیا ہے اور اپنے لئے ملائکہ میں سے لڑکیاں بنائی ہیں یہ تم بہت بڑی بات کہہ رہے ہو\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmlxx{اور ہم نے اس قرآن میں سب کچھ طرح طرح سے بیان کردیا ہے کہ یہ لوگ عبرت حاصل کریں لیکن ان کی نفرت ہی میں اضافہ ہورہا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmlxxi{تو آپ کہہ دیجئے کہ ان کے کہنے کے مطابق اگر خدا کے ساتھ کچھ اور خدا بھی ہوتے تو اب تک صاحب هعرش تک پہنچنے کی کوئی راہ نکال لیتے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmlxxii{وہ پاک اور بے نیاز ہے اور ان کی باتوں سے بہت زیادہ بلند و بالا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmlxxiii{ساتوں آسمان اور زمین اور جو کچھ ان کے درمیان ہے سب اس کی تسبیح کررہے ہیں اور کوئی شے ایسی نہیں ہے جو اس کی تسبیح نہ کرتی ہو یہ اور بات ہے کہ تم ان کی تسبیح کو نہیں سمجھتے ہو. پروردگار بہت برداشت کرنے والا اور درگذر کرنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmlxxiv{اور جب تم قرآن پڑھتے ہو تو ہم تمہارے اور آخرت پر ایمان نہ رکھنے والوں کے درمیان حجاب قائم کردیتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmlxxv{اور ان کے دلوں پر پردے ڈال دیتے ہیں کہ کچھ سمجھ نہ سکیں اور ان کے کانوں کو بہرہ بنادیتے ہیں اور جب تم قرآن میں اپنے پروردگار کا تنہا ذکر کرتے ہو تو یہ الٹے پاؤ ںمتنفر ہوکر بھاگ جاتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmlxxvi{ہم خوب جانتے ہیں کہ یہ لوگ آپ کی طرف کان لگا کر سنتے ہیں تو کیا سنتے ہیں اور جب یہ باہم راز داری کی باتیں کرتے ہیں تو ہم اسے بھی جانتے ہیں یہ ظالم آپس میں کہتے ہیں کہ تم لوگ ایک جادو زدہ انسان کی پیروی کررہے ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmlxxvii{ذرا دیکھو کہ انہوں نے تمہارے لئے کیسی مثالیں بیان کی ہیں اور اس طرح ایسے گمراہ ہوگئے ہیں کہ کوئی راستہ نہیں مل رہا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmlxxviii{اور یہ کہتے ہیں کہ جب ہم ہڈی اور خاک ہوجائیں گے تو کیا دوبارہ نئی مخلوق بناکر اٹھائے جائیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmlxxix{آپ کہہ دیجئے کہ تم پتھر یا لوہا بن جاؤ\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmlxxx{یا تمہارے خیال میں جو اس سے بڑی مخلوق ہوسکتی ہو وہ بن جاؤ پس عنقریب یہ لوگ کہیں گے کہ ہمیں کون دوبارہ واپس لاسکتا ہے تو کہہ دیجئے کہ جس نے تمہیں پہلی مرتبہ پیدا کیا ہے پھر یہ لوگ استہزائ میں سر ہلائیں گے اور کہیں گے کہ یہ سب کب ہوگا تو کہہ دیجئے کہ شاید قریب ہی ہوجائے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmlxxxi{جس دن وہ تمہیں بلائے گا اور تم سب اس کی تعریف کرتے ہوئے لبیک کہو گے اور خیال کرو گے کہ بہت تھوڑی دیر دنیا میں رہے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmlxxxii{اور میرے بندوں سے کہہ دیجئے کہ صرف اچھی باتیں کیا کریں ورنہ شیطان یقینا ان کے درمیان فساد پیدا کرنا چاہے گا کہ شیطان انسان کا کِھلا ہوا دشمن ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiii{تمہارا پروردگار تمہارے حالات سے بہتر واقف ہے وہ چاہے گا تو تم پر رحم کرے گا اور چاہے گا تو عذاب کرے گا اور پیغمبر ہم نے آپ کو ان کا ذمہ دار بناکر نہیں بھیجا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmlxxxiv{اور آپ کا پروردگار زمین و آسمان کی ہر شے سے باخبر ہے اور ہم نے بعض انبیائ کو بعض پر فضیلت دی ہے اور داؤد کو زبور عطا کی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmlxxxv{اور ان لوگوں سے کہہ دیجئے کہ خدا کے علاوہ جن کا بھی خیال ہے سب کو بلالیں کوئی نہ ان کی تکلیف کو دور کرنے کا اختیار رکھتا ہے اور نہ ان کے حالات کے بدلنے کا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvi{یہ جن کو خدا سمجھ کر پکارتے ہیں وہ خود ہی اپنے پروردگار کے لئے وسیلہ تلاش کررہے ہیں کہ کون زیادہ قربت رکھنے والا ہے اور سب اسی کی رحمت کے امیدوار اور اسی کے عذاب سے خوفزدہ ہیں یقینا آپ کے پروردگار کا عذاب ڈرنے کے لائق ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmlxxxvii{اور کوئی نافرمان آبادی ایسی نہیں ہے جسے ہم قیامت سے پہلے برباد نہ کردیں یا اس پرشدید عذاب نہ نازل کردیں کہ یہ بات کتاب میں لکھ دی گئی ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmlxxxviii{اور ہمارے لئے منہ مانگی نشانیاں بھیجنے سے صرف یہ بات مانع ہے کہ پہلے والوں نے تکذیب کی ہے اور ہلاک ہوگئے ہیں اور ہم نے قوم ثمود کو ان کی خواہش کے مطابق اونٹنی دے دی جو ہماری قدرت کو روشن کرنے والی تھی لیکن ان لوگوں نے اس پر ظلم کیا اور ہم تو نشانیوں کو صرف ڈرانے کے لئے بھیجتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmlxxxix{اور جب ہم نے کہہ دیا کہ آپ کا پروردگار تمام لوگوں کے حالات سے باخبر ہے اور جو خواب ہم نے آپ کو دکھلایا ہے وہ صرف لوگوں کی آزمائش کا ذریعہ ہے جس طرح کہ قرآن میں قابل هلعنت شجرہ بھی ایسا ہی ہے اور ہم لوگوں کو ڈراتے رہتے ہیں لیکن ان کی سرکشی بڑھتی ہی جارہی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmxc{اور جب ہم نے ملائکہ سے کہا کہ آدم کو سجدہ کرو تو سب نے سجدہ کرلیا سوائے ابلیس کے کہ اس نے کہا کہ کیا میں اسے سجدہ کروں جسے تو نے مٹی سے بنایا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmxci{کیا تو نے دیکھا ہے کہ یہ کیا شے ہے جسے میرے اوپر فضیلت د ے دی ہے اب اگر تو نے مجھے قیامت تک کی مہلت دے دی تو میں ان کی ذریت میں چند افراد کے علاوہ سب کا گلا گھونٹتا رہوں گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmxcii{جواب ملا کہ جا اب جو بھی تیرا اتباع کرے گا تم سب کی جزا مکمل طور پر جہنمّ ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmxciii{جا جس پر بھی بس چلے اپنی آواز سے گمراہ کر اور اپنے سوار اور پیادوں سے حملہ کردے اور ان کے اموال اور اولاد میں شریک ہوجا اور ان سے خوب وعدے کر کہ شیطان سوائے دھوکہ دینے کے اور کوئی سچا وعدہ نہیں کرسکتا ہے (\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmxciv{بیشک میرے اصلی بندوں پر تیرا کوئی بس نہیں ہے اور آپ کا پروردگار ان کی نگہبانی کے لئے کافی ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmxcv{اور آپ کا پروردگار ہی وہ ہے جو تم لوگوں کے لئے سمندر میں کشتیاں چلاتا ہے تاکہ تم اس کے فضل و کرم کو تلاش کرسکو کہ وہ تمہارے حال پر بڑا مہربان ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmxcvi{اور جب دریا میں تمہیں کوئی تکلیف پہنچی تو خدا کے علاوہ سب غائب ہوگئے جنہیں تم پکار رہے تھے اور پھر جب خدا نے تمہیں بچا کر خشکی تک پہنچا دیا تو تم پھر کنارہ کش ہوگئے اور انسان تو بڑا ناشکرا ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmxcvii{کیا تم اس بات سے محفوظ ہوگئے ہو کہ وہ تمہیں خشکی ہی میں دھنسادے یا تم پر پتھروں کی بوچھاڑ کردے اور اس کے بعد پھر کوئی کارساز نہ ملے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmxcviii{یا اس بات سے محفوظ ہوگئے ہو کہ وہ دوبارہ تمہیں سمندر میں لے جائے اور پھر تیز آندھیوں کو بھیج کر تمہارے کفر کی بنا پر تمہیں غرق کردے اور اس کے بعد کوئی ایسا نہ پاؤ جو ہمارے حکم کا پیچھا کرسکے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmxcix{اور ہم نے بنی آدم کو کرامت عطا کی ہے اور انہیں خشکی اور دریاؤں میں سواریوں پر اٹھایا ہے اور انہیں پاکیزہ رزق عطا کیا ہے اور اپنی مخلوقات میں سے بہت سوں پر فضیلت دی ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmc{قیامت کا دن وہ ہوگا جب ہم ہر گروہ انسانی کو اس کے پیشوا کے ساتھ بلائیں گے اور اس کے بعد جن کا نامئہ اعمال ان کے داہنے ہاتھ میں دیا جائے گا وہ اپنے صحیفہ کو پڑھیں گے اور ان پر ریشہ برابر ظلم نہیں ہوگا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmci{اور جو اسی دنیا میں اندھا ہے وہ قیامت میں بھی اندھا اور بھٹکا ہوا رہے گا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcii{اور یہ ظالم اس بات کے کوشاں تھے کہ آپ کو ہماری وحی سے ہٹا کر دوسری باتوں کے افترا پر آمادہ کردیں اور اس طرح یہ آپ کو اپنا دوست بنالیتے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmciii{اور اگر ہماری توفیق خاص نے آپ کو ثابت قدم نہ رکھا ہوتا تو آپ (بشری طور پر) کچھ نہ کچھ ان کی طرف مائل ضرور ہوجاتے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmciv{اور پھر ہم زندگانی دنیا اور موت دونوں مرحلوں پر رَہرا مزہ چکھاتے اور آپ ہمارے خلاف کوئی مددگار اور کمک کرنے والا بھی نہ پاتے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcv{اور یہ لوگ آپ کو زمین مکہّ سے دل برداشتہ کررہے تھے کہ وہاں سے نکال دیں حالانکہ آپ کے بعد یہ بھی تھوڑے دنوں سے زیادہ نہ ٹھہر سکے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcvi{یہ آپ سے پہلے بھیجے جانے والے رسولوں میں ہمارا طریقہ کار رہا ہے اور آپ ہمارے طریقہ کار میں کوئی تغیر نہ پائیں گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcvii{آپ زوال آفتاب سے رات کی تاریکی تک نماز قائم کریں اور نماز صبح بھی کہ نماز صبح کے لئے گواہی کا انتظام کیا گیا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcviii{اور رات کے ایک حصہ میں قرآن کے ساتھ بیدار رہیں یہ آپ کے لئے اضافہ خیر ہے عنقریب آپ کا پروردگار اسی طرح آپ کو مقام محمود تک پہنچادے گا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcix{اور یہ کہئے کہ پروردگار مجھے اچھی طرح سے آبادی میں داخل کر اور بہترین انداز سے باہر نکال اور میرے لئے ایک طاقت قرار دے دے جو میری مددگار ثابت ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcx{اور کہہ دیجئے کہ حق آگیا اور باطل فنا ہوگیا کہ باطل بہرحال فنا ہونے والا ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcxi{اور ہم قرآن میں وہ سب کچھ نازل کررہے ہیں جو صاحبان هایمان کے لئے شفا اور رحمت ہے اور ظالمین کے لئے خسارہ میں اضافہ کے علاوہ کچھ نہ ہوگا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcxii{اور ہم جب انسان پر کوئی نعمت نازل کرتے ہیں تو وہ پہلو بچا کر کنارہ کش ہوجاتا ہے اور جب تکلیف ہوتی ہے تو مایوس ہوجاتا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcxiii{آپ کہہ دیجئے کہ ہر ایک اپنے طریقہ پر عمل کرتا ہے تو تمہارا پروردگار بھی خوب جانتا ہے کہ کون سب سے زیادہ سیدھے راستہ پر ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcxiv{اور پیغمبر یہ آپ سے روح کے بارے میں دریافت کرتے ہیں تو کہہ دیجئے کہ یہ میرے پروردگار کا ایک امر ہے اور تمہیں بہت تھوڑا سا علم دیا گیا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcxv{اور اگر ہم چاہیں تو جو کچھ آپ کو وحی کے ذریعہ دیا گیا ہے اسے اُٹھالیں اور اس کے بعد ہمارے مقابلہ میں کوئی سازگار اور ذمہ دار نہ ملے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcxvi{مگر یہ کہ آپ کے پروردگار کی مہربانی ہوجائے کہ اس کا فضل آپ پر بہت بڑا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcxvii{آپ کہہ دیجئے کہ اگر انسان اور جنات سب اس بات پر متفق ہوجائیں کہ اس قرآن کا مثل لے آئیں تو بھی نہیں لاسکتے چاہے سب ایک دوسرے کے مددگار اور پشت پناہ ہی کیوں نہ ہوجائیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcxviii{اور ہم نے اس قرآن میں ساری مثالیں اُلٹ پلٹ کر بیان کردی ہیں لیکن اس کے بعد پھر بھی اکثر لوگوں نے کفر کے علاوہ ہر بات سے انکار کردیا ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcxix{اور ان لوگوں نے کہنا شروع کردیا کہ ہم تم پر ایمان نہ لائیں گے جب تک ہمارے لئے زمین سے چشمہ نہ جاری کردو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcxx{یا تمہارے پاس کھجور اور انگور کے باغ ہوں جن کے درمیان تم نہریں جاری کردو\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcxxi{یا ہمارے اوپر اپنے خیال کے مطابق آسمان کو ٹکڑے ٹکڑے کرکے گرادو یا اللہ اور ملائکہ کو ہمارے سامنے لاکر کھڑا کردو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcxxii{یا تمہارے پاس سونے کا کوئی مکان ہو یا تم آسمان کی بلندی پر چڑھ جاؤ اور اس بلندی پر بھی ہم ایمان نہ لائیں گے جب تک کوئی ایسی کتاب نازل نہ کردو جسے ہم پڑھ لیں آپ کہہ دیجئے کہ ہمارا پروردگار بڑا بے نیاز ہے اور میں صرف ایک بشر ہوں جسے رسول بناکر بھیجا گیا ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcxxiii{اور ہدایت کے آجانے کے بعد لوگوں کے لئے ایمان لانے سے کوئی شے مانع نہیں ہوئی مگر یہ کہ کہنے لگے کہ کیا خدا نے کسی بشر کو رسول بناکر بھیج دیا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcxxiv{تو آپ کہہ دیجئے کہ اگر زمین میں ملائکہ اطمینان سے ٹہلتے ہوتے تو ہم آسمان سے ملک ہی کو رسول بناکر بھیجتے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcxxv{کہہ دیجئے کہ ہمارے اور تمہارے درمیان گواہ بننے کے لئے خدا کافی ہے کہ وہی اپنے بندوں کے حالات سے باخبر ہے اور ان کی کیفیات کا دیکھنے والا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcxxvi{اور جس کو خدا ہدایت د ے دے وہی ہدایت یافتہ ہے اور جس کو گمراہی میں چھوڑ دے اس کے لئے اس کے علاوہ کوئی مددگار نہ پاؤ گے اور ہم انہیں روز قیامت منہ کے بل گونگے اندھے بہرے محشور کریں گے اور ان کا ٹھکانا جہنم ّہوگا کہ جس کی آگ بجھنے بھی لگے گی تو ہم شعلوں کو مزید بھڑکا دیں گے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcxxvii{یہ اس بات کی سزا ہے کہ انہوں نے ہماری نشانیوں کا انکار کیا ہے اور یہ کہا ہے کہ ہم ہڈیاں اور مٹی کا ڈھیر بن جائیں گے تو کیا دوبارہ ازسر هنو پھر پیدا کئے جائیں گے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcxxviii{کیا ان لوگوں نے یہ نہیں دیکھا ہے کہ جس نے آسمان و زمین کو پیدا کیا ہے وہ اس کا جیسا دوسرا بھی پیدا کرنے پر قادر ہے اور اس نے ان کے لئے ایک مدّت مقرر کردی ہے جس میں کسی شک کی گنجائش نہیں ہے مگر ظالموں نے کفر کے علاوہ ہر چیز سے انکار کردیا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcxxix{آپ کہہ دیجئے کہ اگر تم لوگ میرے پروردگار کے خزانوں کے مالک ہوتے تو خرچ ہوجانے کے خوف سے سب روک لیتے اور انسان تو تنگ دل ہی واقع ہوا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcxxx{اور ہم نے موسٰی کو نوکِھلی ہوئی نشانیاں دی تھیں تو بنی اسرائیل سے پوچھو کہ جب موسٰی ان کے پاس آئے تو فرعون نے ان سے کہہ دیا کہ میں تو تم کو سحر زدہ خیال کررہا ہوں\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcxxxi{موسٰی نے کہا کہ تمہیں معلوم ہے کہ سب معجزات آسمان و زمین کے مالک نے بصیرت کا سامان بناکر نازل کئے ہیں اور اے فرعون میں خیال کررہا ہوں کہ تیری شامت آگئی ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcxxxii{فرعون نے چاہا کہ ان لوگوں کو اس سرزمین سے نکال باہر کردے لیکن ہم نے اس کو اس کے ساتھیوں سمیت دریا میں غرق کردیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiii{اور اس کے بعد بنی اسرائیل سے کہہ دیا کہ اب زمین میں آباد ہوجاؤ پھر جب آخرت کے وعدہ کا وقت آجائے گا تو ہم تم سب کو سمیٹ کر لے آئیں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcxxxiv{اور ہم نے اس قرآن کو حق کے ساتھ نازل کیاہے اور یہ حق ہی کے ساتھ نازل ہوا ہے اور ہم نے آپ کو صرف بشارت دینے والا اورڈرانے والا بناکر بھیجا ہے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcxxxv{اور ہم نے قرآن کو متفرق بناکر نازل کیا ہے تاکہ تم تھوڑا تھوڑا لوگوں کے سامنے پڑھو اور ہم نے خود اسے تدریجا نازل کیا ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvi{آپ کہہ دیجئے کہ تم ایمان لاؤ یا نہ لاؤ جن کو اس کے پہلے علم دے دیا گیا ہے ان پرتلاوت ہوتی ہے تو منہ کے بل سجدہ میں گر پڑتے ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcxxxvii{اور کہتے ہیں کہ ہمارا رب پاک و پاکیزہ ہے اور اس کا وعدہ یقینا پورا ہونے والا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcxxxviii{اور وہ منہ کے بل گر پڑتے ہیں روتے ہیں اوروہ قرآن ان کے خشوع میں اضافہ کردیتا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcxxxix{آپ کہہ دیجئے کہ اللہ کہہ کر پکارو یا رحمٰن کہہ کر پکارو جس طرح بھی پکارو گے اس کے تمام نام بہترین ہیں اور اپنی نمازوں کو نہ چلاکر پڑھو اورنہ بہت آہستہ آہستہ بلکہ دونوں کا درمیانی راستہ نکالو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcxl{اور کہو کہ ساری حمد اس اللہ کے لئے ہے جس نے نہ کسی کو فرزند بنایا ہے اورنہ کوئی اس کے ملک میں شریک ہے اور نہ کوئی اس کی کمزوری کی بنا پر اس کاسرپرست ہے اورپھر باقاعدہ اس کی بزرگی کا اعلان کرتے رہو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcxli{\basmalahur ساری حمد اس خدا کے لئے ہے جس نے اپنے بندے پر کتاب نازل کی ہے اور اس میں کسی طرح کی کجی نہیں رکھی ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcxlii{اسے بالکل ٹھیک رکھا ہے تاکہ اس کی طرف سے آنے والے سخت عذاب سے ڈرائے اورجو مومنین نیک اعمال کرتے ہیں انہیں بشارت دے دوکہ ان کے لئے بہترین اجر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcxliii{وہ اس میں ہمیشہ رہنے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcxliv{اورپھر ان لوگوں کو عذاب الٰہی سے ڈرایئے جو یہ کہتے ہیں کہ اللہ نے کسی کو اپنا فرزند بنایا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcxlv{اس سلسلے میں نہ انہیں کوئی علم ہے اور نہ ان کے باپ دادا کو-یہ بہت بڑی بات ہے جو ان کے منہ سے نکل رہی ہے کہ یہ جھوٹ کے علاوہ کوئی بات ہی نہیں کرتے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcxlvi{تو کیا آپ شدّت هافسوس سے ان کے پیچھے اپنی جان خطرہ میں ڈال دیں گے اگر یہ لوگ اس بات پرایمان نہ لائے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcxlvii{بیشک ہم نے روئے زمین کی ہر چیز کو زمین کی زینت قرار دے دیا ہے تاکہ ان لوگوں کا امتحان لیں کہ ان میں عمل کے اعتبار سے سب سے بہتر کون ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcxlviii{اور ہم آخرکار روئے زمین کی ہر چیز کو چٹیل میدان بنادینے والے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcxlix{کیا تمہارا خیال یہ ہے کہ کہف و رقیم والے ہماری نشانیوں میں سے کوئی تعجب خیز نشانی تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcl{جبکہ کچھ جوانوں نے غار میں پناہ لی اور یہ دعا کی کہ پروردگار ہم کو اپنی رحمت عطا فرما اور ہمارے لئے ہمارے کام میں کامیابی کا سامان فراہم کردے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcli{تو ہم نے غار میں ان کے کانوں پر چند برسوں کے لئے پردے ڈال دیئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmclii{پھر ہم نے انہیں دوبارہ اٹھایا تاکہ یہ دیکھیں کہ دونوں گروہوں میں اپنے ٹھہرنے کی مدّت کسے زیادہ معلوم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcliii{ہم آپ کو ان کے واقعات بالکل سچے سچے بتارہے ہیں-یہ چند جوان تھے جو اپنے پروردگار پر ایمان لائے تھے اور ہم نے ان کی ہدایت میں اضافہ کردیا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcliv{اوران کے دلوں کو مطمئن کردیا تھا اس وقت جب یہ سب یہ کہہ کر اٹھے کہ ہمارا پروردگار آسمانوں اور زمین کا مالک ہے ہم اس کے علاوہ کسی خدا کو نہ پکاریں گے کہ اس طرح ہم بے عقلی کی بات کے قائل ہوجائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmclv{یہ ہماری قوم ہے جس نے خدا کو چھوڑ کر دوسرے خدا اختیار کرلئے ہیں آخر یہ لوگ ان خداؤں کے لئے کوئی واضح دلیل کیوں نہیں لاتے ...._ پھر اس سے زیادہ ظالم کون ہے جو پروردگار پر افترا کرے اور اس کے خلاف الزام لگائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmclvi{اور جب تم نے ان سے اور خدا کے علاوہ ان کے تمام معبودوں سے علیحدگی اختیار کرلی ہے تو اب غارمیں پناہ لے لو تمہارا پروردگار تمہارے لئے اپنی رحمت کا دامن پھیلادے گا اور اپنے حکم سے آسانیوں کا سامان فراہم کردے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmclvii{اور تم دیکھو گے کہ آفتاب جب طلوع کرتا ہے تو ان کے غارسے داہنی طرف کترا کر نکل جاتا ہے اور جب ڈوبتا ہے توبائیں طرف جھک کر نکل جاتا ہے اور وہ وسیع مقام پر آرام کررہے ہیں-یہ اللہ کی نشانیوں میں سے ایک نشانی ہے جس کو خدا ہدایت دے دے وہی ہدایت هیافتہ ہے اور جس کو وہ گمراہی میں چھوڑ دے اس کے لئے کوئی راہنما اور سرپرست نہ پاؤ گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmclviii{اور تمہارا خیال ہے کہ وہ جاگ رہے ہیں حالانکہ وہ عالهِ خواب میں ہیں اورہم انہیں داہنے بائیں کروٹ بھی بدلوارہے ہیں اور ان کا کتا ّڈیوڑھی پر دونوں ہاتھ پھیلائے ڈٹا ہوا ہے اگر تم ان کی کیفیت پر مطلع ہوجاتے تو اُلٹے پاؤں بھاگ نکلتے اورتمہارے دل میں دہشت سما جاتی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmclix{اور اس طرح ہم نے انہیں دوبارہ زندہ کیا تاکہ آپس میں ایک دوسرے سے سوال کریں تو ایک نے کہا کہ تم نے کتنی مدت توقف کیا ہے تو سب نے کہا کہ ایک دن یا اس کا ایک حصہّ ان لوگوں نے کہا کہ تمہارا پروردگار اس مدّت سے بہتر باخبر ہے اب تم اپنے سکے دے کر کسی کو شہر کی طرف بھیجو وہ دیکھے کہ کون سا کھانا بہتر ہے اور پھر تمہارے لئے رزق کا سامان فراہم کرے اور وہ آہستہ جائے اورکسی کو تمہارے بارے میں خبر نہ ہونے پائے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmclx{یہ اگرتمہارے بارے میں باخبر ہوگئے تو تمہیں سنگسار کردیں گے یا تمہیں بھی اپنے مذہب کی طرف پلٹا لیں گے اور اس طرح تم کبھی نجات نہ پاسکو گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmclxi{اور اس طرح ہم نے قوم کو ان کے حالات پر مطلع کردیا تاکہ انہیں معلوم ہوجائے کہ اللہ کا وعدہ سچاّ ہے اور قیامت میں کسی طرح کا شبہ نہیں ہے جب یہ لوگ آپس میں ان کے بارے میں جھگڑا کررہے تھے اور یہ طے کررہے تھے کہ ان کے غار پر ایک عمارت بنادی جائے-خدا ان کے بارے میں بہتر جانتا ہے اور جو لوگ دوسروں کی رائے پر غالب آئے انہوں نے کہا کہ ہم ان پر مسجد بنائیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmclxii{عنقریب یہ لوگ کہیں گے کہ وہ تین تھے اور چوتھا ان کا کتاّ تھا اور بعض کہیں گے کہ پانچ تھے اور چھٹا ان کا کتا تھا اور یہ سب صرف غیبی اندازے ہوں گے اور بعض تو یہ بھی کہیں گے کہ وہ سات تھے اور آٹھواں ان کا کتا تھا-آپ کہہ دیجئے کہ خدا ان کی تعداد کو بہتر جانتا ہے اورچند افراد کے علاوہ کوئی نہیں جانتا ہے لہذا آپ ان سے ظاہری گفتگو کے علاوہ واقعا کوئی بحث نہ کریں اور ان کے بارے میں کسی سے دریافت بھی نہ کریں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmclxiii{اور کسی شے کے لئے یہ نہ کہیں کہ میں یہ کام کل کرنے والا ہوں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmclxiv{مگر جب تک خدا نہ چاہے اور بھول جائیں تو خدا کو یاد کریں اور یہ کہیں کہ عنقریب میرا خدا مجھے واقعیت سے قریب تر امر کی ہدایت کردے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmclxv{اور یہ لوگ اپنے غار میں تین سو برس رہے اور اس پر نو دن کا اضافہ بھی ہوگیا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmclxvi{آپ کہہ دیجئے کہ اللہ ان کی مدّاُ قیام سے زیادہ باخبر ہے اسی کے لئے آسمان و زمین کا سارا غیب ہے اور اس کی سماعت وبصارت کا کیا کہنا ان لوگوں کے لئے اس کے علاوہ کوئی سرپرست نہیں ہے اورنہ وہ کسی کو اپنے حکم میں شریک کرتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmclxvii{اور جو کچھ کتاب پروردگار سے وحی کے ذریعہ آپ تک پہنچایا گیا ہے آپ اسی کی تلاوت کریں کہ کوئی اس کے کلمات کو بدلنے والا نہیں ہے اور اس کو چھوڑ کر کوئی دوسرا ٹھکانا بھی نہیں ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmclxviii{اور اپنے نفس کو ان لوگوں کے ساتھ صبر پر آمادہ کرو جو صبح و شام اپنے پروردگار کو پکارتے ہیں اور اسی کی مرضی کے طلب گار ہیں اور خبردار تمہاری نگاہیں ان کی طرف سے پھر نہ جائیں کہ زندگانی دنیا کی زینت کے طلب گار بن جاؤ اور ہرگز اس کی اطاعت نہ کرنا جس کے قلب کو ہم نے اپنی یاد سے محروم کردیا ہے اور وہ اپنی خواہشات کا پیروکار ہے اور اس کا کام سراسر زیادتی کرنا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmclxix{اور کہہ دو کہ حق تمہارے پروردگار کی طرف سے ہے اب جس کا جی چاہے ایمان لے آئے اورجس کا جی چاہے کافر ہوجائے ہم نے یقینا کافرین کے لئے اس آگ کا انتظام کردیا ہے جس کے پردے چاروں طرف سے گھیرے ہوں گے اور وہ فریاد بھی کریں گے تو پگھلے ہوئے تانبے کی طرح کے کھولتے ہوئے پانی سے ان کی فریاد رسی کی جائے گی جو چہروں کو بھون ڈالے گا یہ بدترین مشروب ہے اور جہنم ّبدترین ٹھکانا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmclxx{یقینا جو لوگ ایمان لے آئے اور انہوں نے نیک اعمال کئے ہم ان لوگوں کے اجر کو ضائع نہیں کرتے ہیں جو اچھے اعمال انجام دیتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmclxxi{ان کے لئے وہ دائمی جنتیں ہیں جن کے نیچے نہریں جاری ہوں گی انہیں سونے کے کنگنپہنائے جائیں گے اور یہ باریک اور دبیز ریشم کے سبز لباس میں ملبوس اور تختوں پر تکیے لگائے بیٹھے ہوں گے یہی ان کے لئے بہترین ثواب اورحسین ترین منزل ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmclxxii{اور ان کفار کے لئے ان دو انسانوں کی مثال بیان کردیجئے جن میں سے ایک کے لئے ہم نے انگور کے دو باغ قرار دیئے اور انہیں کھجوروں سے گھیر دیا اور ان کے درمیان زراعت بھی قرار دے دی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmclxxiii{پھر دونوں باغات نے خوب پھل دیئے اور کسی طرح کی کمی نہیں کی اور ہم نے ان کے درمیان نہر بھی جاری کردی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmclxxiv{اور اس کے پاس پھل بھی تھے تو اس نے اپنے غریب ساتھی سے بات کرتے ہوئے کہا کہ میں تم سے مال کے اعتبار سے بڑھا ہوا ہوں اور افراد کے اعتبار سے بھی زیادہ باعزت ہوں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmclxxv{وہ اسی عالم میں اپنے نفس پر ظلم کررہا تھا اپنے باغ میں داخل ہوا اور کہنے لگا کہ میں تو خیال بھی کرتا ہوں کہ یہ کبھی تباہ بھی نہیں ہوسکتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmclxxvi{اور میرا گمان بھی نہیں ہے کہ کبھی قیامت قائم ہوگی اورپھر اگر میں پروردگار کی بارگاہ میں واپس بھی گیا تو اس سے بہتر منزل حاصل کرلوں گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmclxxvii{اس کے ساتھی نے گفتگو کرتے ہوئے کہا کہ تو نے اس کا انکار کیا ہے جس نے تجھے خاک سے پیدا کیا ہے پھر نطفہ سے گزارا ہے اور پھر ایک باقاعدہ انسان بنادیا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmclxxviii{لیکن میرا ایمان یہ ہے کہ اللہ میرا رب ہے اور میں کسی کو اس کا شریک نہیں بناسکتا ہوں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmclxxix{اور ایسا کیوں نہ ہوا کہ جب تو اپنے باغ میں داخل ہوتا تو کہتا ماشائ اللہ اس کے علاوہ کسی کے پاس کوئی قوت نہیں ہے اگر تو یہ دیکھ رہا ہے کہ میں مال اور اولاد کے اعتبار سے تجھ سے کم تر ہوں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmclxxx{تو امیدوار ہوں کہ میرا پروردگار مجھے بھی تیرے باغات سے بہتر باغات عنایت کردے اور ان باغات پر آسمان سے ایسی آفت نازل کردے جو سب کو خاک کردے اور چٹیل میدان بنادے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmclxxxi{یا ان باغات کا پانی خشک ہوجائے اور تو اس کے طلب کرنے پر بھی قادر نہ ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmclxxxii{اور پھر اس کے باغ کے پھل آفت میں گھیر دیئے گئے تو وہ ان اخراجات پر ہاتھ ملنے لگا جو اس نے باغ کی تیاری پر صرف کئے تھے جب کہ باغ اپنی شاخوں کے بل اُلٹا پڑا ہوا تھا اور وہ کہہ رہا تھا کہ اے کاش میں کسی کو اپنے پروردگار کا شریک نہ بناتا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiii{اور اب اس کے پاس وہ گروہ بھی نہیں تھا جو خدا کے مقابلہ میں اس کی مدد کرتا اور وہ بدلہ بھی نہیں لے سکتا تھا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmclxxxiv{اس وقت ثابت ہوا کہ قیامت کی نصرت صرف خدائے برحق کے لئے ہے وہی بہترین ثواب دینے والا ہے اور وہی انجام بخیر کرنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmclxxxv{اور انہیں زندگانی دنیا کی مثال اس پانی کی بتائیے جسے ہم نے آسمان سے نازل کیا تو زمین کی روئیدگی اس سے مل جل گئی پھر آخر میں وہ ریزہ ریزہ ہوگئی جسے ہوائیں اڑادیتی ہیں اور اللہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvi{مال اور اولاد زندگانی دنیا کی زینت ہیں اور باقی رہ جانے والی نیکیاں پروردگار کے نزدیک ثواب اور امید دونوں کے اعتبار سے بہتر ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmclxxxvii{اور قیامت کا دن وہ ہوگا جب ہم پہاڑوں کو حرکت میں لائیں گے اور تم زمین کو بالکل کھلا ہوا دیکھو گے اور ہم سب کو اس طرح جمع کریں گے کہ کسی ایک کو بھی نہیں چھوڑیں گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmclxxxviii{اور سب تمہارے پروردگارکے سامنے صف بستہ پیش کئے جائیں گے اورارشاد ہوگا کہ تم آج اسی طرح آئے ہو جس طرح ہم نے پہلی مرتبہ تمہیں پیدا کیا تھا لیکن تمہارا خیال تھا کہ ہم تمہارے لئے کوئی وعدہ گاہ نہیں قرار دیں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmclxxxix{اور جب نامئہ اعمال سامنے رکھا جائے گا تو دیکھو گے کہ مجرمین اس کے مندرجات کو دیکھ کر خوفزدہ ہوں گے اور کہیں گے کہ ہائے افسوس اس کتاب نے تو چھوٹا بڑا کچھ نہیں چھوڑا ہے اور سب کو جمع کرلیا ہے اور سب اپنے اعمال کو بالکل حاضر پائیں گے اور تمہارا پروردگار کسی ایک پر بھی ظلم نہیں کرتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcxc{اور جب ہم نے ملائکہ سے کہا کہ آدم کو سجدہ کرو تو ابلیس کے علاوہ سب نے سجدہ کرلیا کہ وہ جناّت میں سے تھا پھر تو اس نے حکم خدا سے سرتابی کی تو کیا تم لوگ مجھے چھوڑ کر شیطان اور اس کی اولاد کو اپنا سرپرست بنا رہے ہو جب کہ وہ سب تمہارے دشمن ہیں یہ تو ظالمین کے لئے بدترین بدل ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcxci{ہم نے ان شیاطین کو نہ زمین و آسمان کی خلقت کا گواہ بنایا ہے اور نہ خود ان ہی کی خلقت کا اور نہ ہم ظالمین کو اپنا قوت بازو اور مددگار بناسکتے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcxcii{اور اس دن خدا کہے گا کہ میرے ان شریکوں کو بلاؤ جن کی شرکت کا تمہیں خیال تھا اور وہ پکاریں گے لیکن وہ لوگ جواب بھی نہیں دیں گے اور ہم نے تو ان کے درمیان ہلاکت کی منزل قرار دے دی ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcxciii{اور مجرمین جب جہنمّ کی آگ کو دیکھیں گے تو انہیں یہ خیال پیدا ہوگا کہ وہ اس میں جھونکے جانے والے ہیں اور اس وقت اس آگ سے بچنے کی کوئی راہ نہ پاسکیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcxciv{اورہم نے اس قرآن میں لوگوں کے لئے ساری مثالیں اُلٹ پلٹ کر بیان کردی ہیں اور انسان تو سب سے زیادہ جھگڑا کرنے والاہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcxcv{اور لوگوں کے لئے ہدایت کے آجانے کے بعد کون سی شے مانع ہوگئی ہے کہ یہ ایمان نہ لائیں اوراپنے پروردگار سے استغفار نہ کریں مگر یہ کہ ان تک بھی اگلے لوگوں کا طریقہ آجائے یا ان کے سامنے سے بھی عذاب آجائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcxcvi{اور ہم تو رسولوں کو صرف بشارت دینے والا اور عذاب سے ڈرانے والا بناکر بھیجتے ہیں اور کفاّر باطل کے ذریعہ جھگڑا کرتے ہیں کہ اس کے ذریعہ کو برباد کردیں اور انہوں نے ہماری نشانیوں کو اور جس بات سے ڈرائے گئے تھے سب کو ایک مذاق بنالیا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcxcvii{اور اس سے بڑا ظالم کون ہوگا جسے آیات هالٰہٰیہ کی یاد دلائی جائے اور پھر اس سے اعراض کرے اور اپنے سابقہ اعمال کو بھول جائے ہم نے ان کے دلوں پر پردے ڈال دیئے ہیں کہ یہ حق کو سمجھ سکیں اور ان کے کانوں میں بہراپن ہے اور اگر آپ انہیں ہدایت کی طرف بلائیں گے بھی تو یہ ہرگز ہدایت حاصل نہ کریں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcxcviii{آپ کا پروردگار بڑا بخشنے والا اور صاحبِ رحمت ہے وہ اگر ان کے اعمال کا مواخذہ کرلیتا تو فورا ہی عذاب نازل کردیتا لیکن اس نے ان کے لئے ایک وقت مقرر کردیا ہے جس وقت اس کے علاوہ یہ کوئی پناہ نہ پائیں گے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcxcix{اور یہ وہ بستیاں ہیں جنہیں ہم نے ان کے ظلم کی بنا پر ہلاک کردیا ہے اور ان کی ہلاکت کا ایک وقت مقرر کردیا تھا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcc{اور اس وقت کو یاد کرو جب موسٰی نے اپنے جوان سے کہا کہ میں چلنے سے باز نہ آؤں گا یہاں تک کہ دو دریاؤں کے ملنے کی جگہ پر پہنچ جاؤں یا یوں ہی برسوں چلتا رہوں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcci{پھر جب دونوں مجمع البحرین تک پہنچ گئے تو اپنی مچھلی چھوڑ گئے اور اس نے سمندر میں سرنگ بناکر اپنا راستہ نکال لیا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmccii{پھر جب دونوں مجمع البحرین سے آگے بڑھ گئے تو موسٰی نے اپنے جوان صالح سے کہا کہ اب ہمارا کھانا لاؤ کہ ہم نے اس سفر میں بہت تکان برداشت کی ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcciii{اس جوان نے کہا کہ کیا آپ نے یہ دیکھا ہے کہ جب ہم پتھر کے پاس ٹھہرے تھے تو میں نے مچھلی وہیں چھوڑ دی تھی اور شیطان نے اس کے ذکر کرنے سے بھی غافل کردیا تھا اور اس نے دریا میں عجیب طرح سے راستہ بنالیا تھا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcciv{موسٰی نے کہا کہ پس وہی جگہ ہے جسے ہم تلاش کررہے تھے پھر دونوں نشان قدم دیکھتے ہوئے الٹے پاؤں واپس ہوئے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmccv{تو اس جگہ پر ہمارے بندوں میں سے ایک ایسے بندے کو پایا جسے ہم نے اپنی طرف سے رحمت عطا کی تھی اور اپنے علم خاص میں سے ایک خاص علم کی تعلیم دی تھی\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmccvi{موسٰی نے اس بندے سے کہا کہ کیا میں آپ کے ساتھ رہ سکتا ہوں کہ آپ مجھے اس علم میں سے کچھ تعلیم کریں جو رہنمائی کا علم آپ کو عطا ہوا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmccvii{اس بندہ نے کہا کہ آپ میرے ساتھ صبر نہ کرسکیں گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmccviii{اور اس بات پر کیسے صبر کریں گے جس کی آپ کو اطلاع نہیں ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmccix{موسٰی نے کہا کہ آپ انشائ اللہ مجھے صابر پائیں گے اور میں آپ کے کسی حکم کی مخالفت نہ کروں گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmccx{اس بندہ نے کہا کہ اگر آپ کو میرے ساتھ رہنا ہے تو بس کسی بات کے بارے میں اس وقت تک سوال نہ کریں جب تک میں خود اس کا ذکر نہ شروع کردوں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmccxi{پس دونوں چلے یہاں تک کہ جب کشتی میں سوار ہوئے تو اس بندہ خدا نے اس میں سوراخ کردیا موسٰی نے کہا کہ کیا آپ نے اس لئے سوراخ کیا ہے کہ سواریوں کو ڈبو دیں یہ تو بڑی عجیب و غریب بات ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmccxii{اس بندہ خدا نے کہا کہ میں نے نہ کہا تھا کہ آپ میرے ساتھ صبر نہ کرسکیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmccxiii{موسٰی نے کہا کہ خیر جو فروگزاشت ہوگئی اس کا مواخذہ نہ کریں اور معاملات میں اتنی سختی سے کام نہ لیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmccxiv{پھر دونوں آگے بڑھے یہاں تک کہ ایک نوجوان نظر آیا اور اس بندہ خدا نے اسے قتل کردیا موسٰی نے کہا کہ کیا آپ نے ایک پاکیزہ نفس کو بغیر کسی نفس کے قتل کردیا ہے یہ تو بڑی عجیب سی بات ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmccxv{بندہ صالح نے کہا کہ میں نے کہا تھا کہ آپ میرے ساتھ صبر نہیں کرسکتے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmccxvi{موسٰی نے کہا کہ اس کے بعد میں کسی بات کا سوال کروں تو آپ مجھے اپنے ساتھ نہ رکھیں کہ آپ میری طرف سے منزل عذر تک پہنچ چکے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmccxvii{پھر دونوں آگے چلتے رہے یہاں تک کہ ایک قریہ والوں تک پہنچے اور ان سے کھانا طلب کیا ان لوگوں نے مہمان بنانے سے انکار کردیا پھر دونوں نے ایک دیوار دیکھی جو قریب تھا کہ گر پڑتی - بندہ صالح نے اسے سیدھا کردیا تو موسٰی نے کہا کہ آپ چاہتے تو اس کی اجرت لے سکتے تھے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmccxviii{بندہ صالح نے کہا کہ یہ میرے اور تمہارے درمیان جدائی کا موقع ہے عنقریب میں تمہیں ان تمام باتوں کی تاویل بتادوں گا جن پر تم صبر نہیں کرسکے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmccxix{یہ کشتی چند مساکین کی تھی جو سمندر میں باربرداری کا کام کرتے تھے میں نے چاہا کہ اسے عیب دار بنادوں کہ ان کے پیچھے ایک بادشاہ تھا جو ہر کشتی کو غصب کرلیا کرتا تھا\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmccxx{اور یہ بچّہ .... اس کے ماں باپ مومن تھے اور مجھے خوف معلوم ہوا کہ یہ بڑا ہوکر اپنی سرکشی اور کفر کی بنا پر ان پر سختیاں کرے گا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmccxxi{تو میں نے چاہا کہ ان کا پروردگار انہیں اس کے بدلے ایسا فرزند دیدے جو پاکیزگی میں اس سے بہترہو اور صلئہ رحم میں بھی\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmccxxii{اور یہ دیوار شہر کے دو یتیم بچوں کی تھی اور اس کے نیچے ان کا خزانہ دفن تھا اور ان کا باپ ایک نیک بندہ تھا تو آپ کے پروردگار نے چاہا کہ یہ دونوں طاقت و توانائی کی عمر تک پہنچ جائیں اور اپنے خزانے کو نکال لیں- یہ سب آپ کے پروردگار کی رحمت ہے اور میں نے اپنی طرف سے کچھ نہیں کیا ہے اور یہ ان باتوں کی تاویل ہے جن پر آپ صبر نہیں کرسکے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmccxxiii{اور اے پیغمبر علیھ السّلامیہ لوگ آپ سے ذوالقرنین کے بارے میں سوال کرتے ہیں تو آپ کہہ دیجئے کہ میں عنقریب تمہارے سامنے ان کا تذکرہ پڑھ کر صَنادوں گا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmccxxiv{ہم نے ان کو زمین میں اقتدار دیا اور ہر شے کا سازوسامان عطا کردیا\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmccxxv{پھر انہوں نے ان وسائل کو استعمال کیا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmccxxvi{یہاں تک کہ جب وہ غروب آفتاب کی منزل تک پہنچے تو دیکھا کہ وہ ایک کالی کیچڑ والے چشمہ میں ڈوب رہا ہے اور اس چشمہ کے پاس ایک قوم کو پایا تو ہم نے کہا کہ تمہیں اختیار ہے چاہے ان پر عذاب کرو یا ان کے درمیان حسن سلوک کی روش اختیار کرو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmccxxvii{ذوالقرنین نے کہا کہ جس نے ظلم کیا ہے اس پر بہرحال عذاب کروں گا یہاں تک کہ وہ اپنے رب کی بارگاہ میں پلٹایا جائے گا اور وہ اسے بدترین سزا دے گا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmccxxviii{اور جس نے ایمان اور عمل صالح اختیار کیا ہے اس کے لئے بہترین جزا ہے اور میں بھی اس سے اپنے امور میں آسانی کے بارے میں کہوں گا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmccxxix{اس کے بعد انہوں نے دوسرے وسائل کا پیچھا کیا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmccxxx{یہاں تک کہ جب طلوع آفتاب کی منزل تک پہنچے تو دیکھا کہ وہ ایک ایسی قوم پر طلوع کررہا ہے جس کے لئے ہم نے آفتاب کے سامنے کوئی پردہ بھی نہیں رکھا تھا\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmccxxxi{یہ ہے ذوالقرنین کی داستان اور ہمیں اس کی مکمل اطلاع ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmccxxxii{اس کے بعد انہوں نے پھر ایک ذریعہ کو استعمال کیا\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiii{یہاں تک کہ جب وہ دو پہاڑوں کے درمیان پہنچ گئے تو ان کے قریب ایک قوم کو پایا جو کوئی بات نہیں سمجھتی تھی\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmccxxxiv{ان لوگوں نے کسی طرح کہا کہ اے ذوالقرنین یاجوج وماجوج زمین میں فساد برپا کررہے ہیں تو کیا یہ ممکن ہے کہ ہم آپ کے لئے اخراجات فراہم کردیں اور آپ ہمارے اور ان کی درمیان ایک رکاوٹ قرار دیدیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmccxxxv{انہوں نے کہا کہ جو طاقت مجھے میرے پروردگار نے دی ہے وہ تمہارے وسائل سے بہتر ہے اب تم لوگ قوت سے میری امداد کرو کہ میں تمہارے اور ان کے درمیان ایک روک بنادوں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvi{چند لوہے کی سلیں لے آؤ- یہاں تک کہ جب دونوں پہاڑوں کے برابر ڈھیر ہوگیا تو کہا کہ آگ پھونکو یہاں تک کہ جب اسے بالکل آگ بنادیا تو کہا آؤ اب اس پر تانبا پگھلا کر ڈال دیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmccxxxvii{جس کے بعد نہ وہ اس پر چڑھ سکیں اور نہ اس میں نقب لگا سکیں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmccxxxviii{ذوالقرنین نے کہا کہ یہ پروردگار کی ایک رحمت ہے اس کے بعد جب وعدہ الٰہی آجائے گا تو اس کو ریزہ ریزہ کردے گا کہ وعدہ رب بہرحال برحق ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmccxxxix{اور ہم نے انہیں اس طرح چھوڑ دیا ہے کہ ایک دوسرے کے معاملات میں دخل اندازی کرتے رہیں اور پھر جب شُور پھونکا جائے گا تو ہم سب کو ایک جگہ اکٹھا کرلیں گے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmccxl{اور اس د ن جہّنم کو کافرین کے سامنے باقاعدہ پیش کیا جائے گا\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmccxli{وہ کافر جن کی نگاہیں ہمارے ذکر کی طرف سے پردہ میں تھیں اور وہ کچھ صَننا بھی نہیں چاہتے تھے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmccxlii{تو کیا کافروں کا خیال یہ ہے کہ یہ ہمیں چھوڑ کر ہمارے بندوں کو اپنا سرپرست بنالیں گے تو ہم نے جہنمّ کو کافرین کے لئے بطور منزل مہیّا کردیا ہے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmccxliii{پیغمبر کیا ہم آپ کو ان لوگوں کے بارے میں اطلاع دیں جو اپنے اعمال میں بدترین خسارہ میں ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmccxliv{یہ وہ لوگ ہیں جن کی کوشش زندگانی دنیا میں بہک گئی ہے اور یہ خیال کرتے ہیں کہ یہ اچھے اعمال انجام دے رہے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmccxlv{یہی وہ لوگ ہیں جنہوں نے آیات پروردگار اور اس کی ملاقات کا انکار کیا ہے تو ان کے اعمال برباد ہوگئے ہیں اور ہم قیامت کے دن ان کے لئے کوئی وزن قائم نہیں کریں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmccxlvi{ان کی جزا ان کے کفر کی بنا پر جہنم ّہے کہ انہوں نے ہمارے رسولوں اور ہماری آیتوں کو مذاق بنا لیا ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmccxlvii{یقینا جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ان کی منزل کے لئے جنّت الفردوس ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmccxlviii{وہ ہمیشہ اس جنّت میں رہیں گے اور اس کی تبدیلی کی خواہش بھی نہ کریں گے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmccxlix{آپ کہہ دیجئے کہ اگر میرے پروردگار کے کلمااُ کے لئے سمندر بھی روشنی جائیں تو کلمات رب کے ختم ہونے سے پہلے ہی سارے سمندر ختم ہوجائیں گے چاہے ان کی مدد کے لئے ہم ویسے ہی سمندر اور بھی لے ائیں\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmccl{آپ کہہ دیجئے کہ میں تمہارا ہی جیسا ایک بشر ہوں مگر میری طرف وحی آتی ہے کہ تمہارا خدا ایک اکیلا ہے لہذا جو بھی اس کی ملاقات کا امیدوار ہے اسے چاہئے کہ عمل صالح کرے اور کسی کو اپنے پروردگار کی عبادت میں شریک نہ بنائے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmccli{\basmalahur کۤھیعۤصۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcclii{یہ زکریا کے ساتھ تمہارے پروردگار کی مہربانی کا ذکر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmccliii{جب انہوں نے اپنے پروردگار کو دھیمی آواز سے پکارا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccliv{کہا کہ پروردگار میری ہڈیاں کمزور ہوگئی ہیں اور میرا سر بڑھاپے کی آگ سے بھڑک اٹھا ہے اور میں تجھے پکارنے سے کبھی محروم نہیں رہا ہوں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcclv{اور مجھے اپنے بعد اپنے خاندان والوں سے خطرہ ہے اور میری بیوی بانجھ ہے تو اب مجھے ایک ایسا ولی اور وارث عطا فرمادے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcclvi{جو میرا اور آل یعقوب کا وارث ہو اور پروردگار اسے اپنا پسندیدہ بھی قرار دے دے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcclvii{زکریا ہم تم کو ایک فرزند کی بشارت دیتے ہیں جس کا نام یحیٰی ہے اور ہم نے اس سے پہلے ان کا ہمنام کوئی نہیں بنایا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcclviii{زکریا نے عرض کی پروردگار میرے فرزند کس طرح ہوگا جب کہ میری بیوی بانجھ ہے اور میں بھی بڑھاپے کی آخری حد کو پہنچ گیا ہوں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcclix{ارشاد ہوا اسی طرح تمہارے پروردگار کا فرمان ہے کہ یہ بات میرے لئے بہت آسان ہے اور میں نے اس سے پہلے خود تمہیں بھی پیدا کیا ہے جب کہ تم کچھ نہیں تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcclx{انہوں نے کہا کہ پروردگار اس ولادت کی کوئی علامت قرار دے دے ارشاد ہوا کہ تمہاری نشانی یہ ہے کہ تم تین دنوں تک برابر لوگوں سے کلام نہیں کرو گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcclxi{اس کے بعد زکریا محرابِ عبادت سے قوم کی طرف نکلے اور انہیں اشارہ کیا کہ صبح و شام اپنے پروردگار کی تسبیح کرتے رہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcclxii{یحیٰی علیھ السّلام! کتاب کو مضبوطی سے پکڑ لو اور ہم نے انہیں بچپنے ہی میں نبوت عطا کردی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcclxiii{اور اپنی طرف سے مہربانی اور پاکیزگی بھی عطا کردی اور وہ خورِ خدا رکھنے والے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcclxiv{اور اپنے ماں باپ کے حق میں نیک برتاؤ کرنے والے تھے اور سرکش اور نافرمان نہیں تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcclxv{ان پر ہمار اسلام جس دن پیدا ہوئے اور جس دن انہیں موت آئی اور جس دن وہ دوبارہ زندہ اٹھائے جائیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcclxvi{اور پیغمبر علیھ السّلام اپنی کتاب میں مریم کا ذکر کرو کہ جب وہ اپنے گھر والوں سے الگ مشرقی سمت کی طرف چلی گئیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcclxvii{اور لوگوں کی طرف پردہ ڈال دیا تو ہم نے اپنی روح کو بھیجا جو ان کے سامنے ایک اچھا خاصا آدمی بن کر پیش ہوا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcclxviii{انہوں نے کہا کہ اگر تو خوف خدا رکھتا ہے تو میں تجھ سے خدا کی پناہ مانگتی ہوں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcclxix{اس نے کہاکہ میں آپ کے رب کا فرستادہ ہوں کہ آپ کو ایک پاکیزہ فرزند عطا کردوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcclxx{انہوں نے کہا کہ میرے یہاں فرزند کس طرح ہوگا جب کہ مجھے کسی بشر نے چھوا بھی نہیں ہے اور میں کوئی بدکردار نہیں ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcclxxi{اس نے کہا کہ اسی طرح آپ کے پروردگار کا ارشاد ہے کہ میرے لئے یہ کام آسان ہے اور اس لئے کہ میں اسے لوگوں کے لئے نشانی بنادوں اور اپنی طرف سے رحمت قرار دیدوں اور یہ بات طے شدہ ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcclxxii{پھر وہ حاملہ ہوگئیں اور لوگوں سے دور ایک جگہ چلی گئیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiii{پھر وضع حمل کا وقت انہیں ایک کھجور کی شاخ کے قریب لے آیا تو انہوں نے کہا کہ اے کاش میں اس سے پہلے ہی مر گئی ہوتی اور بالکل فراموش کردینے کے قابل ہوگئی ہوتی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcclxxiv{تو اس نے نیچے سے آواز دی کہ آپ پریشان نہ ہوں خدا نے آپ کے قدموں میں چشمہ جاری کردیا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcclxxv{اور خرمے کی شاخ کو اپنی طرف ہلائیں اس سے تازہ تازہ خرمے گر پڑیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvi{پھر اسے کھائیے اور پیجئے اور اپنی آنکھوں کو ٹھنڈی رکھئے پھر اس کے بعد کسی انسان کو دیکھئے تو کہہ دیجئے کہ میں نے رحمان کے لئے روزہ کی نذر کرلی ہے لہذا آج میں کسی انسان سے بات نہیں کرسکتی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcclxxvii{اس کے بعد مریم بچہ کو اٹھائے ہوئے قوم کے پاس آئیں تو لوگوں نے کہا کہ مریم یہ تم نے بہت بفِا کام کیا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcclxxviii{ہارون کی بہن نہ تمہارا باپ بفِا آدمی تھا اور نہ تمہاری ماں بدکردار تھی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcclxxix{انہوں نے اس بچہ کی طرف اشارہ کردیا تو قوم نے کہا کہ ہم اس سے کیسے بات کریں جو گہوارے میں بچہ ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcclxxx{بچہ نے آواز دی کہ میں اللہ کا بندہ ہوں اس نے مجھے کتاب دی ہے اور مجھے نبی بنایا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxi{اور جہاں بھی رہوں بابرکت قرار دیا ہے اور جب تک زندہ رہوں نماز اور زکوِٰکی وصیت کی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxii{اور اپنی والدہ کے ساتھ حَسن سلوک کرنے والا بنایا ہے اور ظالم و بدنصیب نہیں بنایا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiii{اور سلام ہے مجھ پر اس دن جس دن میں پیدا ہوا اور جس دن مروں گا اور جس دن دوبارہ زندہ اٹھایا جاؤں گا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiv{یہ ہے عیسٰی بن مریم کے بارے میں قول حق جس میں یہ لوگ شک کررہے تھے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxv{اللہ کے لئے مناسب نہیں ہے کہ وہ کسی کو اپنا فرزند بنائے وہ پاک و بے نیاز ہے جس کسی بات کا فیصلہ کرلیتا ہے تو اس سے کہتا ہے کہ ہوجا اور وہ چیز ہوجاتی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvi{اور اللہ میرا اور تمہارا دونوں کا پروردگار ہے لہذا اس کی عبادت کرو اور یہی صراط همستقیم ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvii{پھر مختلف گروہوں نے آپس میں اختلاف کیا اور ویل ان لوگوں کے لئے ہے جنہوں نے کفر اختیار کیا اور انہیں بڑے سخت دن کا سامنا کرنا ہوگا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxviii{اس دن جب ہمارے پاس آئیں گے تو خوب سنیں اور دیکھیں گے لیکن یہ ظالم آج کھلی ہوئی گمراہی میں مبتلا ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcclxxxix{اور ان لوگوں کو اس حسرت کے دن سے ڈرائیے جب قطعی فیصلہ ہوجائے گا اگرچہ یہ لوگ غفلت کے عالم میں پڑے ہوئے ہیں اور ایمان نہیں لارہے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccxc{بیشک ہم زمین اور جو کچھ زمین پر ہے سب کے وارث ہیں اور سب ہماری ہی طرف پلٹا کر لائے جائیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccxci{اور کتاب هخدا میں ابراہیم علیھ السّلام کا تذکرہ کرو کہ وہ ایک صدیق پیغمبر تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmccxcii{جب انہوں نے اپنے پالنے والے باپ سے کہا کہ آپ ایسے کی عبادت کیوں کرتے ہیں جو نہ کچھ سنتا ہے نہ دیکھتا ہے اور نہ کسی کام آنے والا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmccxciii{میرے پاس وہ علم آچکا ہے جو آپ کے پاس نہیں آیا ہے لہذا آپ میرا اتباع کریں میں آپ کو سیدھے راستہ کی ہدایت کردوں گا\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmccxciv{بابا شیطان کی عبادت نہ کیجئے کہ شیطان رحمان کی نافرمانی کرنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmccxcv{بابا مجھے یہ خوف ہے کہ آپ کو رحمان کی طرف سے کوئی عذاب اپنی گرفت میں لے لے اور آپ شیطان کے دوست قرار پاجائیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmccxcvi{اس نے جواب دیا کہ ابراہیم علیھ السّلامکیا تم میرے خداؤں سے کنارہ کشی کرنے والے ہو تو یاد رکھو کہ اگر تم اس روش سے باز نہ آئے تو میں تمہیں سنگسار کردوں گا اور تم ہمیشہ کے لئے مجھ سے دور ہوجاؤ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmccxcvii{ابراہیم علیھ السّلامنے کہا کہ خدا آپ کو سلامت رکھے میں عنقریب اپنے رب سے آپ کے لئے مغفرت طلب کروں گا کہ وہ میرے حال پر بہت مہربان ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmccxcviii{اور آپ کو آپ کے معبودوں سمیت چھوڑ کر الگ ہوجاؤں گا اور اپنے رب کو آواز دوں گا کہ اس طرح میں اپنے پروردگار کی عبادت سے محروم نہ رہوں گا\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmccxcix{پھر جب ابراہیم علیھ السّلامنے انہیں اور ان کے معبودوں کو چھوڑ دیا تو ہم نے انہیں اسحاق علیھ السّلامو یعقوب علیھ السّلام جیسی اولاد عطا کی اور سب کو نبی قرار دے دیا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmccc{اور پھر انہیں اپنی رحمت کا ایک حصہ ّبھی عطا کیا اور ان کے لئے صداقت کی بلند ترین زبان بھی قرار دے دی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmccci{اور اپنی کتاب میں موسٰی علیھ السّلام کا بھی تذکرہ کرو کہ وہ میرے مخلص بندے اور رسول و نبی تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcccii{اور ہم نے انہیں کوسِ طور کے داہنے طرف سے آواز دی اور راز و نیاز کے لئے اپنے سے قریب بلالیا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmccciii{اور پھر انہیں اپنی رحمت خاص سے ان کے بھائی ہارون علیھ السّلام پیغمبر کو عطا کردیا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmccciv{اور اپنی کتاب میں اسماعیل علیھ السّلام کا تذکرہ کرو کہ وہ وعدے کے سچے ّاور ہمارے بھیجے ہوئے پیغمبر علیھ السّلامتھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcccv{اور وہ اپنے گھر والوں کو نماز اور زکوِٰ کا حکم دیتے تھے اور اپنے پروردگار کے نزدیک پسندیدہ تھے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcccvi{اور کتاب خدا میں ادریس علیھ السّلامکا بھی تذکرہ کرو کہ وہ بہت زیادہ سچے پیغمبر علیھ السّلامتھے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcccvii{اور ہم نے ان کو بلند جگہ تک پہنچادیا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcccviii{یہ سب وہ انبیائ ہیں جن پر اللہ نے نعمت نازل کی ہے ذرّیت آدم میں سے اور ان کی نسل میں سے جن کو ہم نے نوح علیھ السّلامکے ساتھ کشتی میں اٹھایا ہے اور ابراہیم علیھ السّلام و اسرائیل علیھ السّلامکی ذرّیت میں سے اور ان میں سے جن کو ہم نے ہدایت دی ہے اور انہیں منتخب بنایا ہے کہ جب ان کے سامنے رحمان کی آیتیں پڑھی جاتی ہیں تو روتے ہوئے سجدہ میں گر پڑتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcccix{پھر ان کے بعد ان کی جگہ پر وہ لوگ آئے جنہوں نے نماز کو برباد کردیا اور خواہشات کا اتباع کرلیا پس یہ عنقریب اپنی گمراہی سے جاملیں گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcccx{علاوہ ان کے جنہوں نے توبہ کرلی, ایمان لے آئے اور عمل صالح کیا کہ وہ جنّت میں داخل ہوں گے اور ان پر کسی طرح کا ظلم نہیں کیا جائے گا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcccxi{ہمیشہ رہنے والی جنّت جس کا رحمان نے اپنے بندوں سے غیبی وعدہ کیا ہے اور یقینا اس کا وعدہ سامنے آنے والا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcccxii{اس جنّت میں سلام کے علاوہ کوئی لغو آواز سننے میں نہ آئے گی اور انہیں صبح و شام رزق ملتا رہے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcccxiii{یہی وہ جنّت ہے جس کا وارث ہم اپنے بندوں میں متقی افراد کو قرار دیتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcccxiv{اور اے پیغمبر علیھ السّلامہم فرشتے آپ کے پروردگار کے حکم کے بغیر نازل نہیں ہوتے ہیں ہمارے سامنے یا پس پشت یا اس کے درمیان جو کچھ ہے سب اس کے اختیار میں ہے اور آپ کا پروردگار بھولنے والا نہیں ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcccxv{وہ آسمان و زمین اور جو کچھ ان کے درمیان ہے سب کا مالک ہے لہذا اس کی عبادت کرو اور اس عبادت کی راہ میں صبر کرو کیا تمہارے علم میں اس کا کوئی ہمنام ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcccxvi{اور انسان یہ کہتا ہے کہ کیا جب ہم مرجائیں گے تو دوبارہ زندہ کرکے نکالے جائیں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcccxvii{کیا یہ اس بات کو یاد نہیں کرتا ہے کہ پہلے ہم نے ہی اسے پیدا کیا ہے جب یہ کچھ نہیں تھا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcccxviii{اور آپ کے رب کی قسم ہم ان سب کو اور ان کے شیاطین کو ایک جگہ اکٹھا کریں گے پھر سب کوجہّنم کے اطراف گھٹنوں کے بل حاضر کریں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcccxix{پھر ہر گروہ سے ایسے افراد کو الگ کرلیں گے جو رحمان کے حق میں زیادہ نافرمان تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcccxx{پھر ہم ان لوگوں کو بھی خوب جانتے ہیں جو جہّنم میں جھونکے جانے کے زیادہ سزاوار ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcccxxi{اور تم میں سے کوئی ایسا نہیں ہے جسے جہّنم کے کنارے حاضر نہ ہونا ہو کہ یہ تمہارے رب کا حتمی فیصلہ ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcccxxii{اس کے بعد ہم متقی افراد کو نجات دے دیں گے اور ظالمین کوجہّنم میں چھوڑ دیں گے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiii{اور جب ان کے سامنے ہماری کِھلی ہوئی آیتیں پیش کی جاتی ہیں تو ان میں کے کافر صاحبان ایمان سے کہتے ہیں کہ ہم دونوں میں کس کی جگہ بہتر اور کس کی منزل زیادہ حسن ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcccxxiv{اور ہم نے ان سے پہلے کتنی ہی جماعتوں کوہلاک کُردیا ہے جو سازوسامان اور نام و نمود میں ان سے کہیں زیادہ بہتر تھے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcccxxv{آپ کہہ دیجئے کہ جو شخص گمراہی میں پڑا رہے گا خدا اسے اور ڈھیل دیتا رہے گا یہاں تک کہ یہ وعدہ الٰہی کو دیکھ لیں .... یا عذاب کی یا قیامت کی شکل میں .... پھر انہیں معلوم ہوجائے گا کہ جگہ کے اعتبار سے بدترین اور مددگاروں کے اعتبار سے کمزور ترین کون ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvi{اور اللہ ہدایت یافتہ افراد کی ہدایت میں اضافہ کردیتا ہے اور باقی رہنے والی نیکیاں آپ کے پروردگار کے نزدیک ثواب اور بازگشت کے اعتبار سے بہترین اور بلند ترین ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcccxxvii{کیا تم نے اس شخص کو بھی دیکھا ہے جس نے ہماری آیات کا انکار کیا اور یہ کہنے لگا کہ ہمیں قیامت میں بھی مال اور اولاد سے نوازا جائے گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcccxxviii{یہ غیب سے باخبر ہوگیا ہے یا اس نے رحمان سے کوئی معاہدہ کرلیا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcccxxix{ہرگز ایسا نہیں ہے ہم اس کی باتوں کو درج کررہے ہیں اور اس کے عذاب میں اور بھی اضافہ کردیں گے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcccxxx{اور اس کے مال و اولاد کے ہم ہی مالک ہوں گے اور یہ تو ہماری بارگاہ میں اکیلا حاضر ہوگا\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxi{اور ان لوگوں نے خدا کو چھوڑ کر دوسرے خدا اختیار کرلئے ہیں تاکہ وہ ان کے لئے باعث عزّت بنیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxii{ہرگز نہیں عنقریب یہ معبود خود ہی ان کی عبادت سے انکار کردیں گے اور ان کے مخالف ہوجائیں گے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiii{کیا تم نے نہیں دیکھا کہ ہم نے شیاطین کو کافروں پر مسلّط کردیا ہے اور وہ ان کو بہکاتے رہتے ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiv{آپ ان کے بارے میں عذاب کی جلدی نہ کریں ہم ان کے دن خود ہی شمار کررہے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxv{قیامت کے دن ہم صاحبان هتقویٰ کو رحمان کی بارگاہ میں مہمانوں کی طرح جمع کریں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvi{اور مجفِمین کوجہّنم کی طرف پیاسے جانوروں کی طرح دھکیل دیں گے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvii{اس وقت کوئی شفاعت کا صاحب هاختیار نہ ہوگا مگر وہ جس نے رحمان کی بارگاہ میں شفاعت کا عہد لے لیا ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxviii{اور یہ لوگ کہتے ہیں کہ رحمان نے کسی کو اپنا فرزند بنالیا ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcccxxxix{یقینا تم لوگوں نے بڑی سخت بات کہی ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcccxl{قریب ہے کہ اس سے آسمان پھٹ پڑے اور زمین شگافتہ ہوجائے اور پہاڑ ٹکڑے ٹکڑے ہوکر گر پڑیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcccxli{کہ ان لوگوں نے رحمان کے لئے بیٹا قرار دے دیا ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcccxlii{جب کہ یہ رحمان کے شایانِ شان نہیں ہے کہ وہ کسی کو اپنا بیٹا بنائے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcccxliii{زمین و آسمان میں کوئی ایسا نہیں ہے جو اس کی بارگاہ میں بندہ بن کر حاضر ہونے والا نہ ہو\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcccxliv{خدا نے سب کا احصائ کرلیا ہے اور سب کو باقاعدہ شمار کرلیا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcccxlv{اور سب ہی کل روز هقیامت اس کی بارگاہ میں حاضر ہونے والے ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvi{بیشک جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے عنقریب رحمان لوگوں کے دلوں میں ان کی محبت پیدا کردے گا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcccxlvii{بس ہم نے اس قرآن کو تمہاری زبان میں اس لئے آسان کردیا ہے کہ تم متقین کو بشارت دے سکو اور جھگڑالو قوم کو عذاب الٰہی سے ڈرا سکو\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcccxlviii{اور ہم نے ان سے پہلے کتنی ہی نسلوں کو برباد کردیا ہے کیا تم ان میں سے کسی کو دیکھ رہے ہو یا کسی کی آہٹ بھی سن رہے ہو\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcccxlix{\basmalahur طہۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcccl{ہم نے آپ پر قرآن اس لئے نہیں نازل کیا ہے کہ آپ اپنے کو زحمت میں ڈال دیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcccli{یہ تو ان لوگوں کی یاد دہانی کے لئے ہے جن کے دلوں میں خوف خدا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmccclii{یہ اس خدا کی طرف سے نازل ہوا ہے جس نے زمین اور بلند ترین آسمانوں کو پیدا کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcccliii{وہ رحمان عرش پر اختیار و اقتدار رکھنے والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcccliv{اس کے لئے وہ سب کچھ ہے جو آسمانوں میں ہے یا زمین میں ہے یا دونوں کے درمیان ہے اور زمینوں کی تہ میں ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmccclv{اگر تم بلند آواز سے بھی بات کرو تو وہ راز سے بھی مخفی تر باتوں کو جاننے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmccclvi{وہ اللہ ہے جس کے علاوہ کوئی خدا نہیں ہے اس کے لئے بہترین نام ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmccclvii{کیا تمہارے پاس موسٰی کی داستان آئی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmccclviii{جب انہوں نے آگ کو دیکھا اور اپنے اہل سے کہا کہ تم اسی مقام پر ٹھہرو میں نے آگ کو دیکھا ہے شاید میں اس میں سے کوئی انگارہ لے آؤں یا اس منزل پر کوئی رہنمائی حاصل کرلوں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmccclix{پھر جب موسٰی اس آگ کے قریب آئے تو آواز دی گئی کہ اے موسٰی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmccclx{میں تمہارا پروردگار ہوں لہذا اپنی جوتیوں کو اتار دو کہ تم طویٰ نام کی ایک مقدس اور پاکیزہ وادی میں ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmccclxi{اور ہم نے تم کو منتخب کرلیا ہے لہذا جو وحی کی جارہی ہے اسے غور سے سنو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmccclxii{میں اللہ ہوں میرے علاوہ کوئی خدا نہیں ہے میری عبادت کرو اور میری یاد کے لئے نماز قائم کرو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmccclxiii{یقینا وہ قیامت آنے والی ہے اور میں اسے چھپائے رہوں گا تاکہ ہر نفس کو اس کی کوشش کا بدلہ دیا جاسکے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmccclxiv{اور خبردار تمہیں قیامت کے خیال سے وہ شخص روک نہ دے جس کا ایمان قیامت پر نہیں ہے اور جس نے اپنے خواہشات کی پیروی کی ہے کہ اس طرح تم ہلاک ہوجاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmccclxv{اور اے موسٰی یہ تمہارے داہنے ہاتھ میں کیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmccclxvi{انہوں نے کہا کہ یہ میرا عصا ہے جس پر میں تکیہ کرتا ہوں اور اس سے اپنی بکریوں کے لئے درختوں کی پتیاں جھاڑتا ہوں اور اس میں میرے اور بہت سے مقاصد ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmccclxvii{ارشاد ہوا تو موسٰی اسے زمین پر ڈال دو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmccclxviii{اب جو موسٰی نے ڈال دیا تو کیا دیکھا کہ وہ سانپ بن کر دوڑ رہا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmccclxix{حکم ہوا کہ اسے لے لو اور ڈرو نہیں کہ ہم عنقریب اسے اس کی پرانی اصل کی طرف پلٹا دیں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmccclxx{اور اپنے ہاتھ کو سمیٹ کر بغل میں کرلو یہ بغیر بیماری کے سفید ہوکر نکلے گا اور یہ ہماری دوسری نشانی ہوگی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmccclxxi{تاکہ ہم تمہیں اپنی بڑی نشانیاں دکھاسکیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmccclxxii{جاؤ فرعون کی طرف جاؤ کہ وہ سرکش ہوگیا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiii{موسٰی نے عرض کی پروردگار میرے سینے کو کشادہ کردے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmccclxxiv{میرے کام کو آسان کردے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmccclxxv{اور میری زبان کی گرہ کو کھول دے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvi{کہ یہ لوگ میری بات سمجھ سکیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmccclxxvii{اور میرے اہل میں سے میرا وزیر قرار دے دے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmccclxxviii{ہارون کو جو میرا بھائی بھی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmccclxxix{اس سے میری پشت کو مضبوط کردے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmccclxxx{اسے میرے کام میں شریک بنادے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxi{تاکہ ہم تیری بہت زیادہ تسبیح کرسکیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxii{اور تیرا بہت زیادہ ذکر کرسکیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiii{یقینا تو ہمارے حالات سے بہتر باخبر ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiv{ارشاد ہوا موسٰی ہم نے تمہاری مراد تمہیں دے دی ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxv{اور ہم نے تم پر ایک اور احسان کیا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvi{جب ہم نے تمہاری ماں کی طرف ایک خاص وحی کی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvii{کہ اپنے بچہ کو صندوق میں رکھ دو اور پھر صندوق کو دریا کے حوالے کردو موجیں اسے ساحل پر ڈال دیں گی اور ایک ایسا شخص اسے اٹھالے گا جو میرا بھی دشمن ہے اور موسٰی کا بھی دشمن ہے اور ہم نے تم پر اپنی محبت کا عکس ڈال دیا تاکہ تمہیں ہماری نگرانی میں پالا جائے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxviii{اس وقت کو یاد کرو جب تمہاری بہن جارہی تھیں کہ فرعون سے کہیں کہ کیا میں کسی ایسے کا پتہ بتاؤں جو اس کی کفالت کرسکے اور اس طرح ہم نے تم کو تمہاری ماں کی طرف پلٹا دیا تاکہ ان کی آنکھیں ٹھنڈی ہوجائیں اور وہ رنجیدہ نہ ہوں اور تم نے ایک شخص کو قتل کردیا تو ہم نے تمہیں غم سے نجات دے دی اور تمہارا باقاعدہ امتحان لے لیا پھر تم اہل مدین میں کئی برس تک رہے اس کے بعد تم ایک منزل پر آگئے اے موسٰی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmccclxxxix{اور ہم نے تم کو اپنے لئے منتخب کرلیا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcccxc{اب تم اپنے بھائی کے ساتھ میری نشانیاں لے کر جاؤ اور میری یاد میں سستی نہ کرنا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcccxci{تم دونوں فرعون کی طرف جاؤ کہ وہ سرکش ہوگیا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcccxcii{اس سے نرمی سے بات کرنا کہ شاید وہ نصیحت قبول کرلے یا خوف زدہ ہوجائے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcccxciii{ان دونوں نے کہا کہ پروردگار ہمیں یہ خوف ہے کہ کہیں وہ ہم پر زیادتی نہ کرے یا اور سرکش نہ ہوجائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcccxciv{ارشاد ہوا تم ڈرو نہیں میں تمہارے ساتھ ہوں سب کچھ سن بھی رہا ہوں اور دیکھ بھی رہا ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcccxcv{فرعون کے پاس جاکر کہو کہ ہم تیرے پروردگار کے فرستادہ ہیں بنی اسرائیل کو ہمارے حوالے کردے اور ان پر عذاب نہ کر کہ ہم تیرے پاس تیرے پروردگار کی نشانی لے کر آئے ہیں اور ہمارا سلام ہو اس پر جو ہدایت کا اتباع کرے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvi{بیشک ہماری طرف یہ وحی کی گئی ہے کہ تکذیب کرنے والے اور منہ پھیرنے والے پر عذاب ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcccxcvii{اس نے کہا کہ موسٰی تم دونوں کا رب کون ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcccxcviii{موسٰی نے کہا کہ ہمارا رب وہ ہے جس نے ہر شے کو اس کی مناسب خلقت عطا کی ہے اور پھر ہدایت بھی دی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcccxcix{اس نے کہا کہ پھر ان لوگوں کا کیا ہوگا جو پہلے گزر چکے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcd{موسٰی نے کہا کہ ان باتوں کاعلم میرے پروردگار کے پاس اس کی کتاب میں محفوظ ہے وہ نہ بہکتا ہے اور نہ بھولتا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcdi{اس نے تمہارے لئے زمین کو گہوارہ بنایا ہے اور اس میں تمہارے لئے راستے بنائے ہیں اور آسمان سے پانی برسایا ہے جس کے ذریعہ ہم نے مختلف قسم کے نباتات کا جوڑا پیدا کیا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcdii{کہ تم خود بھی کھاؤ اور اپنے جانوروں کو بھی چراؤ بے شک اس میں صاحبان هعقل کے لئے بڑی نشانیاں پائی جاتی ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcdiii{اسی زمین سے ہم نے تمہیں پیدا کیا ہے اور اسی میں پلٹا کرلے جائیں گے اور پھر دوبارہ اسی سے نکالیں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcdiv{اور ہم نے فرعون کو اپنی ساری نشانیاں دکھلادیں لیکن اس نے تکذیب کی اور انکار کردیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcdv{اس نے کہا کہ موسٰی تم اس لئے آئے ہو کہ ہم کو ہمارے علاقہ سے اپنے جادو کے ذریعہ باہر نکال دو\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcdvi{اب ہم بھی ایسا ہی جادو لے آئیں گے لہذا اپنے اور ہمارے درمیان ایک وقت مقرر کردو جس کی نہ ہم مخالفت کریں اور نہ تم اور وہ وعدہ گاہ بھی ایک صاف کھلے میدان میں ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcdvii{موسٰی نے کہا کہ تمہارا وعدہ کا دن زینت (عید) کا دن ہے اور اس دن تمام لوگ وقت چاشت اکٹھا کئے جائیں گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcdviii{اس کے بعد فرعون واپس چلا گیا اور اپنے مکر کو اکٹھا کرنے لگا اور اس کے بعد پھر سامنے آیا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcdix{موسٰی نے ان لوگوں سے کہا کہ تم پر وائے ہو اللہ پر افترا نہ کرو کہ وہ تم کو عذاب کے ذریعہ تباہ و برباد کردے گا اور جس نے اس پر بہتان باندھا وہ یقینا رسوا ہوا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcdx{اس پر وہ لوگ آپس میں جھگڑا کرنے لگے اور سرگوشیوں میں مصروف ہوگئے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcdxi{ان لوگوں نے کہا کہ یہ دونوں جادوگر ہیں جو تم لوگوں کو اپنے جادو کے زور پر تمہاری سرزمین سے نکال دینا چاہتے ہیں اور تمہارے اچھے خاصے طریقہ کو مٹا دینا چاہتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcdxii{لہذا تم لوگ اپنی تدبیروں کو جمع کرو اور پرا باندھ کر ان کے مقابلے پر آجاؤ جو آج کے دن غالب آجائے گا وہی کامیاب کہا جائے گا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcdxiii{ان لوگوں نے کہا کہ موسٰی تم اپنے جادو کو پھینکو گے یا ہم لوگ پہل کریں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcdxiv{موسٰی نے کہا کہ نہیں تم ابتدا کرو ایک مرتبہ کیا دیکھا کہ ان کی رسیاں اور لکڑیاں جادو کی بنا پر ایسی لگنے لگیں جیسے سب دوڑ رہی ہوں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcdxv{تو موسٰی نے اپنے دل میں (قوم کی گمراہی کا) خوف محسوس کیا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcdxvi{ہم نے کہا کہ موسٰی ڈرو نہیں تم بہرحال غالب رہنے والے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcdxvii{اور جو کچھ تمہارے ہاتھ میں ہے اسے ڈال دو یہ ان کے سارے کئے دھرے کو چن لے گا ان لوگوں نے جو کچھ کیا ہے وہ صرف جادوگر کی چال ہے اور بس اور جادوگر جہاں بھی جائے کبھی کامیاب نہیں ہوسکتا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcdxviii{یہ دیکھ کر سارے جادوگر سجدہ میں گر پڑے اور آواز دی کہ ہم موسٰی اور ہارون کے پروردگار پر ایمان لے آئے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcdxix{فرعون نے کہا کہ تم میری اجازت کے بغیر ہی ایمان لے آئے تو یہ تم سے بھی بڑا جادوگر ہے جس نے تمہیں جادو سکھایا ہے اب میں تمہارے ایک طرف کے ہاتھ اور دوسری طرف کے پاؤں کاٹ دوں گا اور تمہیں خرمہ کی شاخ پر سولی دے دوں گا اور تمہیں خوب معلوم ہوجائے گا کہ زیادہ سخت عذاب کرنے والا اور دیر تک رہنے والا کون ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcdxx{ان لوگوں نے کہا کہ ہمارے پاس جو کھلی نشانیاں آچکی ہیں اور جس نے ہم کو پیدا کیا ہے ہم اس پر تیری بات کو مقدم نہیں کرسکتے اب تجھے جو فیصلہ کرنا ہو کرلے تو فقط اس زندگانی دنیا ہی تک فیصلہ کرسکتا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcdxxi{ہم اپنے پروردگار پر ایمان لے آئے ہیں کہ وہ ہماری خطاؤں کو معاف کردے اور اس جادو کو بخش دے جس پر تو نے ہمیں مجبور کیا تھا اور اللہ سب سے بہتر ہے ا ورہی باقی رہنے والا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcdxxii{یقینا جو اپنے رب کی بارگاہ میں مجرم بن کر آئے گا اس کے لئے وہ جہنم ّہے جس میں نہ مرسکے گا اور نہ زندہ رہ سکے گا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiii{اور جو اس کے حضور صاحب هایمان بن کر حاضر ہوگا اور اس نے نیک اعمال کئے ہوں گے اس کے لئے بلند ترین درجات ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcdxxiv{ہمیشہ رہنے والی جنت ّجس کے نیچے نہریں جاری ہوں گی اور وہ اس میں ہمیشہ رہیں گے کہ یہی پاکیزہ کردار لوگوں کی جزا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcdxxv{اور ہم نے موسٰی کی طرف وحی کی کہ میرے بندوں کو لے کر راتوں رات نکل جاؤ پھر ان کے لئے دریا میں عصا مار کر خشک راستہ بنادو تمہیں نہ فرعون کے پالینے کا خطرہ ہے اور نہ ڈوب جانے کا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvi{تب فرعون نے اپنے لشکر سمیت ان لوگوں کا پیچھا کیا اور دریا کی موجوں نے انہیں باقاعدہ ڈھانک لیا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmcdxxvii{اور فرعون نے درحقیقت اپنی قوم کو گمراہ ہی کیا ہے ہدایت نہیں دی ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmcdxxviii{بنی اسرائیل ! ہم نے تم کو تمہارے دشمن سے نجات دلائی ہے اور طور کی داہنی طرف سے توریت دینے کا وعدہ کیا ہے اور من و سلویٰ بھی نازل کیا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmcdxxix{تم ہمارے پاکیزہ رزق کو کھاؤ اور اس میں سرکشی اور زیادتی نہ کرو کہ تم پر میرا غضب نازل ہوجائے کہ جس پر میرا غضب نازل ہوگیا وہ یقینا برباد ہوگیا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmcdxxx{اور میں بہت زیادہ بخشنے والا ہوں اس شخص کے لئے جو توبہ کرلے اور ایمان لے آئے اور نیک عمل کرے اور پھر راسِ ہدایت پر ثابت قدم رہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxi{اور اے موسٰی تمہیں قوم کو چھوڑ کر جلدی آنے پر کس شے نے آمادہ کیا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxii{موسٰی نے عرض کی کہ وہ سب میرے پیچھے آرہے ہیں اور میں نے راہ هخیر میں اس لئے عجلت کی ہے کہ تو خوش ہوجائے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiii{ارشاد ہوا کہ ہم نے تمہارے بعد تمہاری قوم کا امتحان لیا اور سامری نے انہیں گمراہ کردیا ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiv{یہ سن کر موسٰی اپنی قوم کی طرف محزون اور غصہّ میں بھرے ہوئے پلٹے اور کہا کہ اے قوم کیا تمہارے رب نے تم سے بہترین وعدہ نہیں کیا تھا اور کیا اس عہد میں کچھ زیادہ طول ہوگیا ہے یا تم نے یہی چاہا کہ تم پر پروردگار کا غضب وارد ہوجائے اس لئے تم نے میرے وعدہ کی مخالفت کی\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxv{قوم نے کہا کہ ہم نے اپنے اختیار سے آپ کے وعدہ کی مخالفت نہیں کی ہے بلکہ ہم پر قوم کے زیورات کا بوجھ لاد دیا گیا تھا تو ہم نے اسے آگ میں ڈال دیا اور اس طرح سامری نے بھی اپے زیورات کو ڈال دیا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvi{پھر سامری نے ان کے لئے ایک مجسمہ گائے کے بچے کا نکالا جس میں آواز بھی تھی اور کہا کہ یہی تمہارا اور موسٰی کا خدا ہے جس سے موسٰی غافل ہوکر اسے طور پر ڈھونڈنے چلے گئے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvii{کیا یہ لوگ اتنا بھی نہیں دیکھتے کہ یہ نہ ان کی بات کا جواب دے سکتا ہے اور نہ ان کے کسی نقصان یا فائدہ کا اختیار رکھتا ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxviii{اور ہارون نے ان لوگوں سے پہلے ہی کہہ دیا کہ اے قوم اس طرح تمہارا امتحان لیا گیا ہے اور تمہارا رب رحمان ہی ہے لہذا میرا اتباع کرو اور میرے امر کی اطاعت کرو\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmcdxxxix{ان لوگوں نے کہا کہ ہم اس کے گرد جمع رہیں گے یہاں تک کہ موسٰی ہمارے درمیان واپس آجائیں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmcdxl{موسٰی نے ہارون سے خطاب کرکے کہا کہ جب تم نے دیکھ لیا تھا کہ یہ قوم گمراہ ہوگئی ہے تو تمہیں کون سی بات آڑے آگئی تھی\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmcdxli{کہ تم نے میرا اتباع نہیں کیا, کیا تم نے میرے امر کی مخالفت کی ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmcdxlii{ہارون نے کہا کہ بھیّا آپ میری داڑھی اور میرا سر نہ پکڑیں مجھے تو یہ خوف تھا کہ کہیں آپ یہ نہ کہیں کہ تم نے بنی اسرائیل میں اختلاف پیدا کردیا ہے اور میری بات کا انتظار نہیں کیا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmcdxliii{پھر موسٰی نے سامری سے کہا کہ تیرا کیا حال ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmcdxliv{اس نے کہا کہ میں نے وہ دیکھا ہے جو ان لوگوں نے نہیں دیکھا ہے تو میں نے نمائندہ پروردگار کے نشانِ قدم کی ایک مٹھی خاک اٹھالی اور اس کو گوسالہ کے اندر ڈال دیا اور مجھے میرے نفس نے اسی طرح سمجھایا تھا\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmcdxlv{موسٰی نے کہا کہ اچھا جا دور ہوجا اب زندگانی دنیا میں تیری سزا یہ ہے کہ ہر ایک سے یہی کہتا پھرے گا کہ مجھے چھونا نہیں اور آخرت میں ایک خاص وعدہ ہے جس کی مخالفت نہیں ہوسکتی اور اب دیکھ اپنے خدا کو جس کے گرد تو نے اعتکاف کر رکھا ہے کہ میں اسے جلاکر خاکستر کردوں گا اور اس کی راکھ دریا میں اڑادوں گا\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvi{یقینا تم سب کا خدا صرف اللہ ہے جس کے علاوہ کوئی خدا نہیں ہے اور وہی ہر شے کا وسیع علم رکھنے والا ہے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmcdxlvii{اور ہم اسی طرح گزشتہ دور کے واقعات آپ سے بیان کرتے ہیں اور ہم نے اپنی بارگاہ سے آپ کو قرآن بھی عطا کردیا ہے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmcdxlviii{جو اس سے اعراض کرے گا وہ قیامت کے دن اس انکار کا بوجھ اٹھائے گا\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmcdxlix{اور پھر اسی حال میں رہے گا اور قیامت کے دن یہ بہت بڑا بوجھ ہوگا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmcdl{جس دن صور پھونکا جائے گا اور ہم تمام مجرمین کو بدلے ہوئے رنگ میں اکٹھا کریں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmcdli{یہ سب آپس میں یہ بات کررہے ہوں گے کہ ہم دنیا میں صرف دس ہی دن تو رہے ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmcdlii{ہم ان کی باتوں کو خوب جانتے ہیں جب ان کا سب سے ہوشیار یہ کہہ رہا تھا کہ تم لوگ صرف ایک دن رہے ہو\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmcdliii{اور یہ لوگ آپ سے پہاڑوں کے بارے میں پوچھتے ہیں کہ قیامت میں ان کا کیا ہوگا تو کہہ دیجئے کہ میرا پروردگار انہیں ریزہ ریزہ کرکے اڑادے گا\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmcdliv{پھر زمین کو چٹیل میدان بنادے گا\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmcdlv{جس میں تم کسی طرح کی کجی ناہمواری نہ دیکھو گے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmcdlvi{اس دن سب داعی پروردگار کے پیچھے دوڑ پڑیں گے اور کسی طرح کی کجی نہ ہوگی اور ساری آوازیں رحمان کے سامنے دب جائیں گی کہ تم گھنگھناہٹ کے علاوہ کچھ نہ سنو گے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmcdlvii{اس دن کسی کی سفارش کام نہ آئے گی سوائے ان کے جنہیں خدا نے اجازت دے دی ہو اور وہ ان کی بات سے راضی ہو\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmcdlviii{وہ سب کے سامنے اور پیچھے کے حالات سے باخبر ہے اور کسی کا علم اس کی ذات کو محیط نہیں ہے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmcdlix{اس دن سارے چہرے خدائے حی و قیوم کے سامنے جھکے ہوں گے اور ظلم کا بوجھ اٹھانے والا ناکام اور رسوا ہوگا\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmcdlx{اور جو نیک اعمال کرے گا اور صاحبِ ایمان ہوگا وہ نہ ظلم سے ڈرے گا اور نہ نقصان سے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmcdlxi{اور اسی طرح ہم نے قرآن کو عربی زبان میں نازل کیا ہے اور اس میں طرح طرح سے عذاب کا تذکرہ کیا ہے کہ شاید یہ لوگ پرہیز گار بن جائیں یا قرآن ان کے اندر کسی طرح کی عبرت پیدا کردے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmcdlxii{پس بلند و برتر ہے وہ خدا جو بادشاہ هبرحق ہے اور آپ وحی کے تمام ہونے سے پہلے قرآن کے بارے میں عجلت سے کام نہ لیا کریں اور یہ کہتے رہیں کہ پروردگار میرے علم میں اضافہ فرما\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiii{اور ہم نے آدم سے اس سے پہلے عہد لیا مگر انہوں نے اسے ترک کردیا اور ہم نے ان کے پاس عزم و ثبات نہیں پایا\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmcdlxiv{اور جب ہم نے ملائکہ سے کہا کہ تم سب آدم کے لئے سجدہ کرو تو ابلیس کے علاوہ سب نے سجدہ کرلیا اور اس نے انکار کردیا\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmcdlxv{تو ہم نے کہا کہ آدم یہ تمہارا اور تمہاری زوجہ کا دشمن ہے کہیں تمہیں جنت ّسے نکال نہ دے کہ تم زحمت میں پڑجاؤ\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvi{بیشک یہاں جنتّ میں تمہارا فائدہ یہ ہے کہ نہ بھوکے رہو گے اور نہ برہنہ رہو گے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmcdlxvii{اور یقینا یہاں نہ پیاسے رہو گے اور نہ دھوپ کھاؤ گے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmcdlxviii{پھر شیطان نے انہیں وسوسہ میں مبتلا کرنا چاہا اور کہا کہ آدم میں تمہیں ہمیشگی کے درخت کی طرف رہنمائی کردوں اور ایسا لَلک بتادوں جو کبھی زائل نہ ہو\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmcdlxix{تو ان دونوں نے درخت سے کھالیا اور اور ان کے لئے ان کا آ گا پیچھا ظاہر ہوگیا اور وہ اسے جنتّ کے پتوں سے چھپانے لگے اور آدم نے اپنے پروردگار کی نصیحت پر عمل نہ کیا تو راحت کے راستہ سے بے راہ ہوگئے\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmcdlxx{پھر خدا نے انہیں چن لیا اور ان کی توبہ قبول کرلی اور انہیں راستہ پر لگادیا\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxi{اور حکم دیا کہ تم دونوں یہاں سے نیچے اتر جاؤ سب ایک دوسرے کے دشمن ہوں گے اس کے بعد اگر میری طرف سے ہدایت آجائے تو جو میری ہدایت کی پیروی کرے گا وہ نہ گمراہ ہوگا اور نہ پریشان\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxii{اور جو میرے ذکر سے اعراض کرے گا اس کے لئے زندگی کی تنگی بھی ہے اور ہم اسے قیامت کے دن اندھا بھی محشور کریں گے\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiii{وہ کہے گا کہ پروردگار یہ تو نے مجھے اندھا کیوں محشور کیا ہے جب کہ میں دا» دنیا میں صاحبِ بصارت تھا\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiv{ارشاد ہوگا کہ اسی طرح ہماری آیتیں تیرے پاس آئیں اور تونے انہیں بھلا دیا تو آج تو بھی نظر انداز کردیا جائے گا\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxv{اور ہم زیادتی کرنے والے اور اپنے رب کی نشانیوں پر ایمان نہ لانے والوں کو اسی طرح سزا دیتے ہیں اور آخرت کا عذاب یقینا سخت ترین اور ہمیشہ باقی رہنے والا ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvi{کیا انہیں اس بات نے رہنمائی نہیں دی کہ ہم نے ان سے پہلے کتنی نسلوں کو ہلاک کردیا جو اپنے علاقہ میں نہایت اطمینان سے چل پھر رہے تھے بیشک اس میں صاحبان هعقل کے لئے بڑی نشانیاں ہیں\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvii{اور اگر آپ کے رب کی طرف سے بات طے نہ ہوچکی ہوتی اور وقت مقرر نہ ہوتا تو عذاب لازمی طور پر آچکا ہوتا\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxviii{لہذا آپ ان کی باتوں پر صبر کریں اور آفتاب نکلنے سے پہلے اور اس کے ڈوبنے کے بعد اپنے رب کی تسبیح کرتے رہیں اور رات کے اوقات میں اور دن کے اطراف میں بھی تسبیح پروردگار کریں کہ شاید آپ اس طرح راضی اور خوش ہوجائیں\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxix{اور خبردار ہم نے ان میں سے بعض لوگوں کو جو زندگانی دنیا کی رونق سے مالا مال کردیا ہے اس کی طرف آپ نظر اٹھا کر بھی نہ دیکھیں کہ یہ ان کی آزمائش کا ذریعہ ہے اور آپ کے پروردگار کا رزق اس سے کہیں زیادہ بہتر اور پائیدار ہے\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxx{اور اپنے اہل کو نماز کا حکم دیں اور اس پر صبر کریں ہم آپ سے رزق کے طلبگار نہیں ہیں ہم تو خود ہی رزق دیتے ہیں اور عاقبت صرف صاحبانِ تقویٰ کے لئے ہے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxi{اور یہ لوگ کہتے ہیں کہ یہ اپنے رب کی طرف سے کوئی نشانی کیوں نہیں لاتے ہیں تو کیا ان کے پاس اگلی کتابوں کی گواہی نہیں آئی ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxii{اور اگر ہم نے رسول سے پہلے انہیں عذاب کرکے ہلاک کردیا ہوتا تو یہ کہتے پروردگار تو نے ہماری طرف رسول کیوں نہیں بھیجا کہ ہم ذلیل اور رسوا ہونے سے پہلے ہی تیری نشانیوں کا اتباع کرلیتے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiii{آپ کہہ دیجئے کہ سب اپنے اپنے وقت کا انتظار کررہے ہیں تم بھی انتظار کرو عنقریب معلوم ہوجائے گا کہ کون لوگ سیدھے راستہ پر چلنے والے اور ہدایت یافتہ ہیں\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiv{\basmalahur لوگوں کے لئے حساب کا وقت آپہنچا ہے اور وہ ابھی غفلت ہی میں پڑے ہوئے ہیں اور کنارہ کشی کئے جارہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxv{ان کے پاس ان کے پروردگار کی طرف سے کوئی نئی یاد دہانی نہیں آتی مگر یہ کہ کان لگا کر سوُ لیتے ہیں اور پھر کھیل تماشے میں لگ جاتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvi{ان کے دل بالکل غافل ہوگئے ہیں اور یہ ظالم اس طرح آپس میں راز و نیاز کی باتیں کیا کرتے ہیں کہ یہ بھی تو تمہارے ہی طرح کے ایک انسان ہیں کیا تم دیدہ و دانستہ ان کے جادو کے چکر میں آرہے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvii{تو پیغمبر نے جواب دیا کہ میرا پروردگار آسمان و زمین کی تمام باتوں کو جانتا ہے وہ خوب سننے والا اور جاننے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxviii{بلکہ یہ لوگ کہتے ہیں کہ یہ تو سب خواب ه پریشاں کا مجموعہ ہے بلکہ یہ خود پیغمبر کی طرف سے افترائ ہے بلکہ یہ شاعر ہیں اور شاعری کررہے ہیں ورنہ ایسی نشانی لے کر آتے جیسی نشانی لے کر پہلے پیغمبر علیھ السّلامبھیجے گئے تھے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxix{ان سے پہلے ہم نے جن بستیوں کو سرکشی کی بنا پر تباہ کر ڈالا وہ تو ایمان لائے نہیں یہ کیا ایمان لائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcdxc{اور ہم نے آپ سے پہلے بھی جن رسولوں علیھ السّلامکو بھیجا ہے وہ سب مرد ہی تھے جن کی طرف ہم وحی کیا کرتے تھے-تو تم لوگ اگر نہیں جانتے ہو تو جاننے والوں سے دریافت کرلو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcdxci{اور ہم نے ان لوگوں کے لئے بھی کوئی ایسا جسم نہیں بنایا تھا جو کھانا نہ کھاتا ہو اور وہ بھی ہمیشہ رہنے والے نہیں تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcdxcii{پھر ہم نے ان کے وعدہ کو سچ کر دکھایا اور انہیں اور ان کے ساتھ جن کو چاہا بچالیا اور زیادتی کرنے والوں کو تباہ و برباد کردیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcdxciii{بیشک ہم نے تمہاری طرف وہ کتاب نازل کی ہے جس میں خود تمہارا بھی ذکر ہے تو کیا تم اتنی بھی عقل نہیں رکھتے ہو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcdxciv{اور ہم نے کتنی ہی ظالم بستیوں کو تباہ کردیا اور ان کے بعد ان کی جگہ پر دوسری قوموں کو ایجاد کردیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcdxcv{پھر جب ان لوگوں نے عذاب کی آہٹ محسوس کی تو اسے دیکھ کر بھاگنا شروع کردیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvi{ہم نے کہا کہ اب بھاگو نہیں اور اپنے گھروں کی طرف اور اپنے سامان عیش و عشرت کی طرف پلٹ کر جاؤ کہ تم سے اس کے بارے میں پوچھ گچھ کی جائے گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcdxcvii{ان لوگوں نے کہا کہ ہائے افسوس ہم واقعا ظالم تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcdxcviii{اور یہ کہہ کر فریاد کرتے رہے یہاں تک کہ ہم نے انہیں کٹی ہوئی کھیتی کی طرح بنا کر ان کے سارے جوش کو ٹھنڈا کردیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcdxcix{اور ہم نے آسمان و زمین اور ان کے درمیان کی تمام چیزوں کو کھیل تماشے کے لئے نہیں بنایا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmd{ہم کھیل ہی بنانا چاہتے تو اپنی طرف ہی سے بنالیتے اگر ہمیں ایسا کرنا ہوتا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdi{بلکہ ہم تو حق کو باطل کے سر پر دے مارتے ہیں اور اس کے دماغ کو کچل دیتے ہیں اور وہ تباہ و برباد ہوجاتا ہے اور تمہارے لئے ویل ہے کہ تم ایسی بے ربط باتیں بیان کررہے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdii{اور اسی خدا کے لئے زمین و آسمان کی کل کائنات ہے اور جو افراد اس کی بارگاہ میں ہیں وہ نہ اس کی عبادت سے اکڑ کر انکار کرتے ہیں اور نہ تھکتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdiii{دن رات اسی کی تسبیح کرتے ہیں اور سستی کا بھی شکار نہیں ہوتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdiv{کیا ان لوگوں نے زمین میں ایسے خدا بنا لئے ہیں جو ان کو زندہ کرنے والے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdv{یاد رکھو اگر زمین و آسمان میں اللہ کے علاوہ اور خدا بھی ہوتے تو زمین و آسمان دونوں برباد ہوجاتے عرش کا مالک پروردگار ان کے بیانات سے بالکل پاک و پاکیزہ ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdvi{اس سے باز پرس کرنے والا کوئی نہیں ہے اور وہ ہر ایک کا حساب لینے والا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdvii{کیا ان لوگوں نے اس کے علاوہ اور خدا بنالئے ہیں تو آپ کہہ دیجئے کہ ذرا اپنی دلیل تو لاؤ-یہ میرے ساتھ والوں کا ذکر اور مجھ سے پہلے والوں کا ذکر سب موجود ہے لیکن ان کی اکثریت حق سے ناواقف ہے اور اسی لئے کنارہ کشی کررہی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdviii{اور ہم نے آپ سے پہلے کوئی رسول نہیں بھیجا مگر یہ کہ اس کی طرف یہی وحی کرتے رہے کہ میرے علاوہ کوئی خدا نہیں ہے لہذا سب لوگ میری ہی عبادت کرو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdix{اور لوگوں نے یہ کہنا شروع کردیا کہ اللہ نے کسی کو بیٹا بنالیا ہے حالانکہ وہ اس امر سے پاک و پاکیزہ ہے بلکہ وہ سب اس کے محترم بندے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdx{جو کسی بات پر اس پر سبقت نہیں کرتے ہیں اور اس کے احکام پر برابر عمل کرتے رہتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdxi{وہ ان کے سامنے اور ان کے پس پشت کی تمام باتوں کو جانتا ہے اور فرشتے کسی کی سفارش بھی نہیں کرسکتے مگر یہ کہ خدا اس کو پسند کرے اور وہ اس کے خوف سے برابر لرزتے رہتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdxii{اور اگر ان میں سے بھی کوئی یہ کہہ دے کہ خدا کے علاوہ میں بھی خدا ہوں تو ہم اس کو بھی جہنّم کی سزا دیں گے کہ ہم اسی طرح ظالموں کو سزا دیا کرتے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdxiii{کیا ان کافروں نے یہ نہیں دیکھا کہ یہ زمین و آسمان آپس میں جڑے ہوئے تھے اور ہم نے ان کو الگ کیا ہے اور ہر جاندار کو پانی سے قرار دیا ہے پھر کیا یہ لوگ ایمان نہ لائیں گے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdxiv{اور ہم نے زمین میں پہاڑ قرار دیئے ہیں کہ وہ ان لوگوں کو لے کر کسی طرف جھک نہ جائے اور پھر اس میں وسیع تر راستے قرار دیئے ہیں کہ اس طرح یہ منزل مقصود تک پہنچ سکیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdxv{اور ہم نے آسمان کو ایک محفوظ چھت کی طرح بنایا ہے اور یہ لوگ اس کی نشانیوں سے برابر اعراض کررہے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdxvi{وہ وہی خدا ہے جس نے رات دن اور آفتاب و ماہتاب سب کو پید اکیا ہے اور سب اپنے اپنے فلک میں تیر رہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdxvii{اور ہم نے آپ سے پہلے بھی کسی بشر کے لئے ہمیشگی نہیں قرار دی ہے تو کیا اگر آپ مرجائیں گے تو یہ لوگ ہمیشہ رہنے والے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdxviii{ہر نفس موت کا مزہ چکھنے والا ہے اور ہم تو اچھائی اور برائی کے ذریعہ تم سب کو آزمائیں گے اور تم سب پلٹا کر ہماری ہی بارگاہ میں لائے جاؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdxix{اور جب بھی یہ کفّار آپ کو دیکھتے ہیں تو اس بات کا مذاق اُڑاتے ہیں کہ یہی وہ شخص ہے جو تمہارے خداؤں کا ذکر کیا کرتا ہے اور یہ لوگ خود تو رحمان کے ذکر سے انکار ہی کرنے والے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdxx{انسان کے خمیر میں عِجلت شامل ہوگئی ہے اور عنقریب ہم تمہیں اپنی نشانیاں دکھائیں گے تو پھر تم لوگ جلدی نہیں کرو گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdxxi{اور یہ لوگ کہتے ہیں کہ اگر تم سچے ّ ہو تو اس وعدہ قیامت کا وقت آخر کب آئے گا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdxxii{کاش یہ کافر یہ جانتے کہ وہ ایسا وقت ہوگا جب یہ جہنمّ کی آگ کو نہ اپنے سامنے سے ہٹاسکیں گے اور نہ پشت سے اور نہ ان کی کوئی مدد کی جاسکے گی\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdxxiii{بلکہ یہ قیامت ان تک اچانک آجائے گی اور انہیں مبہوت کردے گی پھر یہ نہ اسے رد کرسکیں گے اور نہ انہیں کوئی مہلت دی جائے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdxxiv{اور پیغمبر آپ سے پہلے بھی بہت سے رسولوں کا مذاق اڑایا گیا ہے جس کے بعد ان کفاّر کو اس عذاب نے گھیر لیا جس کا یہ مذاق اُڑارہے تھے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdxxv{آپ ان سے کہہ دیجئے کہ انہیں رات یا دن میں رحمان کے عذاب سے بچانے کے لئے کون پہرہ دے سکتا ہے مگر یہ ہیں کہ رحمان کی یاد سے مسلسل منہ موڑے ہوئے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdxxvi{کیا ان کے پاس ایسے خدا موجود ہیں جو ہمارے بغیر انہیں بچا سکیں گے یہ بیچارے تو خود اپنی بھی مدد نہیں کرسکتے ہیں اور نہ انہیں خود بھی عذاب سے پناہ دی جائے گی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdxxvii{بلکہ ہم نے انہیں اور ان کے باپ دادا کو تھوڑی سی لّذت دنیا دے دی ہے یہاں تک کہ ان کا زمانہ طویل ہوگیا تو کیا یہ نہیں دیکھتے ہیں کہ ہم برابر زمین کی طرف آتے جارہے ہیں اور اس کو چاروں طرف سے کم کرتے جارہے ہیں کیا اس کے بعد بھی یہ ہم پر غالب آجانے والے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdxxviii{آپ کہہ دیجئے کہ میں تم لوگوں کو وحی کے مطابق ڈراتا ہوں اور بہرہ کو جب بھی ڈرایا جاتا ہے وہ آواز کو سنتا ہی نہیں ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdxxix{حالانکہ انہیں عذاب الٰہی کی ہوا بھی چھوجائے تو کہہ اُٹھیں گے کہ افسوس ہم واقعی ظالم تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdxxx{اور ہم قیامت کے دن انصاف کی ترازو قائم کریں گے اور کسی نفس پر ادنیٰ ظلم نہیں کیا جائے گا اور کسی کا عمل رائی کے دانہ کے برابر بھی ہے تو ہم اسے لے آئیں گے اور ہم سب کا حساب کرنے کے لئے کافی ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdxxxi{اور ہم نے موسٰی علیھ السّلام اور ہارون علیھ السّلام کو حق و باطل میں فرق کرنے والی وہ کتاب عطا کی ہے جو ہدایت کی روشنی اور ان صاحبانِ تقویٰ کے لئے یاد الٰہی کا ذریعہ ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdxxxii{جو ازغیب اپنے پروردگار سے ڈرنے والے ہیں اور قیامت کے خوف سے لرزاں ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiii{اور یہ قرآن ایک مبارک ذکر ہے جسے ہم نے نازل کیا ہے تو کیا تم لوگ اس کا بھی انکار کرنے والے ہو\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdxxxiv{اور ہم نے ابراہیم علیھ السّلامکو اس سے پہلے ہی عقل سلیم عطا کردی تھی اور ہم ان کی حالت سے باخبر تھے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdxxxv{جب انہوں نے اپنے مربی باپ اور اپنی قوم سے کہا کہ یہ مورتیاں کیا ہیں جن کے گرد تم حلقہ باندھے ہوئے ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvi{ان لوگوں نے کہا کہ ہم نے اپنے باپ دادا کو بھی ان ہی کی عبادت کرتے ہوئے دیکھا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdxxxvii{ابراہیم علیھ السّلامنے کہا کہ یقینا تم اور تمہارے باپ دادا سب کھلی ہوئی گمراہی میں ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdxxxviii{ان لوگوں نے کہا کہ آپ کوئی حق بات لے کر آئے ہیں یا خالی کھیل تماشہ ہی کرنے والے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdxxxix{ابراہیم علیھ السّلامنے کہا کہ تمہارا واقعی رب وہی ہے جو آسمان و زمین کا رب ہے اور اسی نے ان سب کو پیدا کیا ہے اور میں اسی بات کے گواہوں میں سے ایک گواہ ہوں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdxl{اور خدا کی قسم میں تمہارے بتوں کے بارے میں تمہارے چلے جانے کے بعد کوئی تدبیر ضرور کروں گا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdxli{پھر ابراہیم علیھ السّلامنے ان کے بڑے کے علاوہ سب کو حُور چوِر کردیا کہ شاید یہ لوگ پلٹ کر اس کے پاس آئیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdxlii{ان لوگوں نے کہا کہ ہمارے خداؤں کے ساتھ یہ برتاؤ کس نے کیا ہے وہ یقینا ظالمین میں سے ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdxliii{لوگوں نے بتایا کہ ایک جو ان ہے جوان کا ذکر کیا کرتا ہے اور اسے ابراہیم کہا جاتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdxliv{ان لوگوں نے کہا کہ اسے لوگوں کے سامنے لے آؤ شاید لوگ گواہی دے سکیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdxlv{پھر ان لوگوں نے ابراہیم علیھ السّلام سے کہا کہ کیا تم نے ہمارے خداؤں کے ساتھ یہ برتاؤ کیا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdxlvi{ابراہیم علیھ السّلامنے کہا کہ یہ ان کے بڑے نے کیا ہے تم ان سے دریافت کرکے دیکھو اگر یہ بول سکیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdxlvii{اس پر ان لوگوں نے اپنے دلوں کی طرف رجوع کیا اور آپس میں کہنے لگے کہ یقینا تم ہی لوگ ظالم ہو\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdxlviii{اس کے بعد ان کے سر شرم سے جھکا دئیے گئے اور کہنے لگے ابراہیم تمہیں تو معلوم ہے کہ یہ بولنے والے نہیں ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdxlix{ابراہیم نے کہا کہ پھر تم خدا کو چھوڑ کر ایسے خداؤں کی عبادت کیوں کرتے ہو جو نہ کوئی فائدہ پہنچاسکتے ہیں اور نہ نقصان\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdl{حیف ہے تمہارے اوپر اور تمہارے ان خداؤں پر جنہیں تم نے خدائے برحق کو چھوڑ کر اختیار کیا ہے کیا تم اتنا بھی نہیں سمجھتے ہو\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdli{ان لوگوں نے کہا کہ ابراہیم کو آگ میں جلادو اور اگر کچھ کرنا چاہتے ہو تو اس طرح اپنے خداؤں کی مدد کرو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdlii{تو ہم نے بھی حکم دیا کہ اے آگ ابراہیم علیھ السّلامکے لئے سرد ہوجا اور سلامتی کاسامان بن جا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdliii{اور ان لوگوں نے ایک مکر کا ارادہ کیا تھا تو ہم نے بھی انہیں خسارہ والا اور ناکام قرار دے دیا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdliv{اور ابراہیم علیھ السّلام اور لوط علیھ السّلام کو نجات دلاکر اس سرزمین کی طرف لے آئے جس میں عالمین کے لئے برکت کا سامان موجود تھا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdlv{اور پھر ابراہیم علیھ السّلامکو اسحاق علیھ السّلاماور ان کے بعد یعقوب علیھ السّلامعطا کئے اور سب کو صالح اور نیک کردار قرار دیا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdlvi{اور ہم نے ان سب کو پیشوا قرار دیا جو ہمارے حکم سے ہدایت کرتے تھے اور ان کی طرف کارخیر کرنے نماز قائم کرنے اور زکوِٰادا کرنے کی وحی کی اور یہ سب کے سب ہمارے عبادت گزار بندے تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdlvii{اور لوط علیھ السّلام کو یاد کرو جنہیں ہم نے قوت فیصلہ اور علم عطا کیا اور اس بستی سے نجات دلادی جو بدکاریوں میں مبتلا تھی کہ یقینا یہ لوگ بڑے بڑے اور فاسق تھے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdlviii{اور ہم نے انہیں اپنی رحمت میں داخل کرلیا کہ وہ یقینا ہمارے نیک کردار بندوں میں سے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdlix{اور نوح علیھ السّلامکو یاد کرو کہ جب انہوں نے پہلے ہی ہم کو آواز دی اور ہم نے ان کی گزارش قبول کرلی اور انہیں اور ان کے اہل کو بہت بڑے کرب سے نجات دلادی\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdlx{اور ان لوگوں کے مقابلہ میں ان کی مدد کی جو ہماری آیتوں کی تکذیب کیا کرتے تھے کہ یہ لوگ بہت بری قوم تھے تو ہم نے ان سب کو غرق کردیا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdlxi{اور داؤد علیھ السّلاماور سلیمان علیھ السّلام کو یاد کرو جب وہ دونوں ایک کھیتی کے بارے میں فیصلہ کررہے تھے جب کھیت میں قوم کی بکریاں گھصَ گئی تھیں اور ہم ان کے فیصلہ کو دیکھ رہے تھے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdlxii{پھر ہم نے سلیمان علیھ السّلام کو صحیح فیصلہ سمجھا دیا اور ہم نے سب کو قوت فیصلہ اور علم عطا کیا تھا اور داؤد علیھ السّلام کے ساتھ پہاڑوں کو لَسّخر کردیا تھا کہ وہ تسبیح پروردگار کریں اور طیور کو بھی لَسّخر کردیا تھا اور ہم ایسے کام کرتے رہتے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdlxiii{اور ہم نے انہیں زرہ بنانے کی صنعت تعلیم دے دی تاکہ وہ تم کو جنگ کے خطرات سے محفوظ رکھ سکے تو کیا تم ہمارے شکر گزار بندے بنو گے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdlxiv{اور سلیماوُ کے لئے تیز و تند ہواؤں کو لَسّخر کردیا جو ان کے حکم سے اس سرزمین کی طرف چلتی تھیں جس میں ہم نے برکتیں رکھی تھیں اور ہم ہر شے کے جاننے والے ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdlxv{اور بعض جناّت کو بھی لَسّخر کردیا جو سمندر میں غوطے لگایا کرتے تھے اور اس کے علاوہ دوسرے کام بھی انجام دیا کرتے تھے اور ہم ان سب کے نگہبان تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdlxvi{اور ایوب علیھ السّلام کو یاد کرو جب انہوں نے اپنے پروردگار کو پکارا کہ مجھے بیماری نے چھولیا ہے اور تو بہترین رحم کرنے والا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdlxvii{تو ہم نے ان کی دعا کو قبول کرلیا اور ان کی بیماری کو دور کردیا اور انہیں ان کے اہل وعیال دے دیئے اور ویسے ہی اور بھی دے دیئے کہ یہ ہماری طرف سے خاص مہربانی تھی اور یہ عبادت گزار بندوں کے لئے ایک یاد دہانی ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdlxviii{اور اسماعیل علیھ السّلام و ادریس علیھ السّلام و ذوالکفل علیھ السّلام کو یاد کرو کہ یہ سب صبر کرنے والوں میں سے تھے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdlxix{اور سب کو ہم نے اپنی رحمت میں داخل کرلیا تھا اور یقینا یہ سب ہمارے نیک کردار بندوں میں سے تھے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdlxx{اور یونس علیھ السّلامکو یاد کرو کہ جب وہ غصّہ میں آکر چلے اور یہ خیال کیا کہ ہم ان پر روزی تنگ نہ کریں گے اور پھر تاریکیوں میں جاکر آواز دی کہ پروردگار تیرے علاوہ کوئی خدا نہیں ہے تو پاک و بے نیاز ہے اور میں اپنے نفس پر ظلم کرنے والوں میں سے تھا\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdlxxi{تو ہم نے ان کی دعا کو قبول کرلیا اور انہیں غم سے نجات دلادی کہ ہم اسی طرح صاحبان هایمان کو نجات دلاتے رہتے ہیں\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdlxxii{اور زکریا علیھ السّلام کو یاد کرو کہ جب انہوں نے اپنے رب کو پکارا کہ پروردگار مجھے اکیلا نہ چھوڑ دینا کہ تو تمام وارثوں سے بہتر وارث ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiii{تو ہم نے ان کی دعا کو بھی قبول کرلیا اور انہیں یحیٰی علیھ السّلام جیسا فرزند عطا کردیا اور ان کی زوجہ کو صالحہ بنادیا کہ یہ تمام وہ تھے جو نیکیوں کی طرف سبقت کرنے والے تھے اور رغبت اور خوف کے ہر عالم میں ہم ہی کو پکارنے والے تھے اور ہماری بارگاہ میں گڑ گڑا کر الِتجا کرنے والے بندے تھے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdlxxiv{اور اس خاتون کو یاد کرو جس نے اپنی شرم کی حفاظت کی تو ہم نے اس میں اپنی طرف سے روح پھونک دی اور اسے اور اس کے فرزند کو تمام عالمین کے لئے اپنی نشانی قرار دے دیا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdlxxv{بیشک یہ تمہارا دین ایک ہی دین اسلام ہے اور میں تم سب کا پروردگار ہوں لہذا میری ہی عبادت کیا کرو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvi{اور ان لوگوں نے تو اپنے دین کو بھی آپس میں ٹکڑے ٹکڑے کرلیا ہے حالانکہ یہ سب پلٹ کر ہماری ہی بارگاہ میں آنے والے ہیں\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdlxxvii{پھر جو شخص صاحب هایمان رہ کر نیک عمل کرے گا اس کی کوشش برباد نہ ہوگی اور ہم اس کی کوشش کو برابر لکھ رہے ہیں\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdlxxviii{اور جس بستی کو ہم نے تباہ کردیا ہے اس کے لئے بھی ناممکن ہے کہ قیامت کے دن ہمارے پاس پلٹ کر نہ آئے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdlxxix{یہاں تک کہ یاجوج ماجوج آزاد کردیئے جائیں گے اور زمین کی ہر بلندی سے دوڑتے ہوئے نکل پڑیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdlxxx{اور اللہ کا سچا وعدہ قریب آجائے گا تو سب دیکھیں گے کہ کفار کی آنکھیں پتھرا گئی ہیں اور وہ کہہ رہے ہیں کہ وائے بر حال ماہم اس طرف سے بالکل غفلت میں پڑے ہوئے تھے بلکہ ہم اپنے نفس پر ظلم کرنے والے تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxi{یاد رکھو کہ تم لوگ خود اور جن چیزوں کی تم پرستش کررہے ہو سب کو جہنمّ کا ایندھن بنایا جائے گا اور تم سب اسی میں وارد ہونے والے ہو\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxii{اگر یہ سب واقعا خدا ہوتے تو کبھی جہنمّ میں وارد نہ ہوتے حالانکہ یہ سب اسی میں ہمیشہ ہمیشہ رہنے والے ہیں\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiii{جہنمّ میں ان کے لئے چیخ پکار ہوگی اور وہ کسی کی بات سننے کے قابل نہ ہوں گے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiv{بیشک جن لوگوں کے حق میں ہماری طرف سے پہلے ہی نیکی مقدر ہوچکی ہے وہ اس جہنمّ سے دور رکھے جائیں گے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxv{اور اس کی بھنک بھی نہ سنیں گے اور اپنی حسب خواہش نعمتوں میں ہمیشہ ہمیشہ آرام سے رہیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvi{انہیں قیامت کا بڑے سے بڑا ہولناک منظر بھی رنجیدہ نہ کرسکے گا اور ان سے ملائکہ اس طرح ملاقات کریں گے کہ یہی وہ دن ہے جس کا تم سے وعدہ کیا گیا تھا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvii{اس دن ہم تمام آسمانوں کو اس طرح لپیٹ دیں گے جس طرح خطوں کا طومار لپیٹا جاتا ہے اور جس طرح ہم نے تخلیق کی ابتدائ کی ہے اسی طرح انہیں واپس بھی لے آئیں گے یہ ہمارے ذمہ ایک وعدہ ہے جس پر ہم بہرحال عمل کرنے والے ہیں\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxviii{اور ہم نے ذکر کے بعد زبور میں بھی لکھ دیا ہے کہ ہماری زمین کے وارث ہمارے نیک بندے ہی ہوں گے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdlxxxix{یقینا اس میں عبادت گزار قوم کے لئے ایک پیغام ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdxc{اور ہم نے آپ کو عالمین کے لئے صرف رحمت بناکر بھیجا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdxci{آپ کہہ دیجئے کہ ہماری طرف صرف یہ وحی آتی ہے کہ تمہارا خدا ایک ہے تو کیا تم اسلام لانے والے ہو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdxcii{پھر اگر یہ منہ موڑ لیں تو کہہ دیجئے کہ ہم نے تم سب کو برابر سے آگاہ کردیا ہے .اب مجھے نہیں معلوم کہ جس عذاب کا وعدہ کیا گیا ہے وہ قریب ہے یا دور ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdxciii{بیشک وہ خدا ان باتوں کو بھی جانتا ہے جن کا اظہار کیا جاتا ہے اور ان باتوں کو بھی جانتا ہے جن کو یہ لوگ چھپارہے ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdxciv{اور میں کچھ نہیں جانتا شاید یہ تاخیر عذاب بھی ایک طرح کا امتحان ہو یا ایک مدّت معین تک کا آرام ہو\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdxcv{پھر پیغمبر نے دعا کی کہ پروردگار ہمارے درمیان حق کے ساتھ فیصلہ کردے اور ہمارا رب یقینا مہربان اور تمہاری باتوں کے مقابلہ میں قابل استعانت ہے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdxcvi{\basmalahur لوگو ! اپنے پروردگار سے ڈرو کہ قیامت کا زلزلہ بہت بڑی شے ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdxcvii{جس دن تم دیکھو گے کہ دودھ پلانے والی عورتیں اپنے دودھ پیتے بچوّں سے غافل ہوجائیں گی اور حاملہ عورتیں اپنے حمل کو گرادیں گی اور لوگ نشہ کی حالت میں نظر آئیں گے حالانکہ وہ بدمست نہیں ہوں گے بلکہ اللہ کا عذاب ہی بڑا سخت ہوگا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdxcviii{اور لوگوں میں کچھ ایسے بھی ہیں جو بغیر جانے بوجھے خدا کے بارے میں جھگڑا کرتے ہیں اور ہر سرکش شیطان کا اتباع کرلیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdxcix{ان کے بارے میں یہ لکھ دیا گیا ہے کہ جو شیطان کو اپنا دوست بنائے گا شیطان اسے گمراہ کردے گا اور پھر جہنمّ کے عذاب کی طرف رہنمائی کردے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdc{اے لوگو اگر تمہیں دوبارہ اٹھائے جانے میں شبہ ہے تو یہ سمجھ لو کہ ہم نے ہی تمہیں پہلے خاک سے بنایا ہے پھر نطفہ سے پھر جمے ہوئے خون سے پھر گوشت کے لوتھڑے سے جس میں سے کوئی مکمل ہوجاتا ہے اور کوئی ناقص ہی رہ جاتا ہے تاکہ ہم تمہارے اوپر اپنی قدرت کو واضح کردیں ہم جس چیز کو جب تک چاہتے ہیں رحم میں رکھتے ہیں اس کے بعد تم کو بچہ بناکر باہر لے آتے ہیں پھر زندہ رکھتے ہیں تاکہ جوانی کی عمر تک پہنچ جاؤ اور پھر تم میں سے بعض کو اٹھالیا جاتا ہے اور بعض کو پست ترین عمر تک باقی رکھا جاتا ہے تاکہ علم کے بعد پھر کچھ جاننے کے قابل نہ رہ جائے اور تم زمین کو مردہ دیکھتے ہو پھر جب ہم پانی برسادیتے ہیں تو وہ لہلہانے لگتی ہے اور ابھرنے لگتی ہے اور ہر طرح کی خوبصورت چیز اگانے لگتی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdci{یہ اس لئے ہے کہ وہ اللہ خدائے برحق ہے اور وہی مفِدوں کو زندہ کرتا ہے اور وہی ہر شے پر قدرت رکھنے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdcii{اور قیامت یقینا آنے والی ہے اس میں کسی شک کی گنجائش نہیں ہے اور اللہ قبروں سے مفِدوں کو اٹھانے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdciii{اور لوگوں میں ایسے بھی ہیں جو علم و ہدایت اور کتابِ لَنیر کے بغیر بھی خدا کے بارے میں بحث کرتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdciv{وہ غرور سے منہ پھرائے ہوئے ہیں تاکہ دوسرے لوگوں کو بھی راسِ خدا سے گمراہ کرسکیں تو ایسے اشخاص کے لئے دنیا میں رسوائی ہے اور آخرت میں ہم انہیں جہنمّ کا مزہ چکھائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdcv{یہ اس بات کی سزا ہے جو تم پہلے کرچکے ہو اور خدا اپنے بندوں پر ہرگز ظلم کرنے والا نہیں ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcvi{اور لوگوں میں کچھ ایسے بھی ہیں جو خدا کی عبادت ایک ہی رخ پراور مشروط طریقہ سے کرتے ہیں کہ اگر ان تک خیر پہنچ گیا تو مطمئن ہوجاتے ہیں اور اگر کوئی مصیبت چھوگئی تو دین سے پلٹ جاتے ہیں یہ دنیا اور آخرت دونوں میں خسارہ میں ہیں اور یہی خسارہ کھلا ہوا خسارہ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdcvii{یہ اللہ کو چھوڑ کر انہیں پکارتے ہیں جو نہ انہیں نقصان پہنچاسکتے ہیں اور نہ فائدہ اور یہی دراصل بہت دور تک پھیلی ہوئی گمراہی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdcviii{یہ ان کو پکارتے ہیں جن کا نقصان ان کے فائدے سے زیادہ قریب تر ہے وہ ان کے بدترین سرپرست اور بدترین ساتھی ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcix{بیشک اللہ ایمان والوں اور نیک عمل کرنے والوں کو ان جنتوں میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی کہ اللہ جو چاہتا ہے انجام دیتا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcx{جس شخص کا خیال یہ ہے کہ اللہ دنیا اور آخرت میں اس کی مدد نہیں کرے گا اسے چاہئے کہ ایک رسی کے ذریعہ آسمان کی طرف بڑھے اور پھر اس رسی کو کاٹ دے اور پھر دیکھے کہ اس کی ترکیب اس چیز کو دور کرسکتی ہے یا نہیں جس کے غصّہ میں وہ مبتلا تھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcxi{اور اسی طرح ہم نے اس قرآن کو واضح نشانیوں کی شکل میں نازل کیا ہے اور اللہ جس کو چاہتاہے ہدایت دے دیتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxii{بیشک جو لوگ ایمان لائے اور جنہوں نے یہودیت اختیار کی یا ستارہ پرست ہوگئے یا نصرانی اور آتش پرست ہوگئے یا مشرک ہوگئے ہیں خدا قیامت کے دن ان سب کے درمیان یقینی فیصلہ کردے گا کہ اللہ ہر شے کا نگراں اور گواہ ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxiii{کیا تم نے نہیں دیکھا کہ زمین و آسمان میں جس قدر بھی صاحبانِ عقل و شعور ہیں اور آفتاب و ماہتاب اور ستارے ,پہاڑ ,درخت ,چوپائے اور انسانوں کی ایک کثرت سب ہی اللہ کے لئے سجدہ گزار ہیں اور ان میں سے بہت سے ایسے بھی ہیں جن پر عذاب ثابت ہوچکا ہے اور ظاہر ہے کہ جسے خدا ذلیل کرنا چاہے اسے کوئی عزّت دینے والا نہیں ہے کہ یقینا اللہ جو چاہتا ہے وہ کرسکتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxiv{یہ مومن و کافر دو باہمی دشمن ہیں جنہوں نے پروردگار کے بارے میں آپس میں اختلاف کیا ہے پھر جو لوگ کافر ہیں ان کے واسطے آگ کے کپڑے قطع کئے جائیں گے اور ان کے سروں پر گرما گرم پانی انڈیلا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxv{جس سے ان کے پیٹ کے اندر جو کچھ ہے اور ان کی جلدیں سب گل جائیں گی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxvi{اور ان کے لئے لوہے کے گرز مہیاّ کئے گئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxvii{جب یہ جہنمّ کی تکلیف سے نکل بھاگنا چاہیں گے تو دوبارہ اسی میں پلٹا دیئے جائیں گے کہ ابھی اور جہنمّ کا مزہ چکّھو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxviii{بیشک اللہ صاحبان هایمان اور نیک عمل کرنے والوں کو ان جنتوں میں داخل کرتا ہے جن کے نیچے نہریں جاری ہوتی ہیں انہیں ان جنتوں میں سونے کے کنگن اور موتی پہنائے جائیں گے اور ان کا لباس اس جنّت میں ریشم کا لباس ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxix{اور انہیں پاکیزہ قول کی طرف ہدایت دی گئی ہے اور انہیں خدائے حمید کے راستہ کی طرف رہنمائی کی گئی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxx{بیشک جن لوگوں نے کفر اختیار کیا اور لوگوں کو اللہ کے راستے اور مسجد الحرام سے روکتے ہیں جسے ہم نے تمام انسانوں کے لئے برابر سے قرار دیا ہے چاہے وہ مقامی ہوں یا باہر والے اور جو بھی اس مسجد میں ظلم کے ساتھ الحاد کا ارادہ کرے گا ہم اسے دردناک عذاب کا مزہ چکھائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxxi{اور اس وقت کو یاد دلائیں جب ہم نے ابراہیم علیھ السّلامکے لئے بیت اللہ کی جگہ مہیا کی کہ خبردار ہمارے بارے میں کسی طرح کا شرک نہ ہونے پائے اور تم ہمارے گھر کو طواف کرنے والے ,قیام کرنے والے اور رکوع و سجود کرنے والوں کے لئے پاک و پاکیزہ بنادو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcxxii{اور لوگوں کے درمیان حج کا اعلان کردو کہ لوگ تمہاری طرف پیدل اور لاغر سواریوں پر دور دراز علاقوں سے سوار ہوکر آئیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiii{تاکہ اپنے منافع کا مشاہدہ کریں اور چند معین دنوں میں ان چوپایوں پر جو خدا نے بطور رزق عطا کئے ہیں خدا کا نام لیں اور پھر تم اس میں سے کھاؤ اور بھوکے محتاج افراد کو کھلاؤ\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcxxiv{پھر لوگوں کو چاہئے کہ اپنے بدن کی کثافت کو دور کریں اور اپنی نذروں کو پورا کریں اور اس قدیم ترین مکان کا طواف کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcxxv{یہ ایک حکم خدا ہے اور جو شخص بھی خدا کی محترم چیزوں کی تعظیم کرے گا وہ اس کے حق میں پیش پروردگار بہتری کا سبب ہوگی اور تمہارے لئے تمام جانور حلال کردیئے گئے ہیں علاوہ ان کے جن کے بارے میں تم سے بیان کیا جائے گا لہذا تم ناپاک بتوں سے پرہیز کرتے رہو اور لغو اور مہمل باتوں سے اجتناب کرتے رہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvi{اللہ کے لئے مخلص اور باطل سے کترا کر رہو اور کسی طرح کا شرک اختیار نہ کرو کہ جو کسی کو اس کا شریک بناتا ہے وہ گویا آسمان سے گر پڑتا ہے اور اسے پرندہ اچک لیتا ہے یا ہوا کسی دور دراز جگہ پر لے جاکر پھینک دیتی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcxxvii{یہ ہمارا فیصلہ ہے اور جو بھی اللہ کی نشانیوں کی تعظیم کرے گا یہ تعظیم اس کے دل کے تقویٰ کا نتیجہ ہوگی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcxxviii{تمہارے لئے ان قربانی کے جانوروں میں ایک مقررہ مدّت تک فائدے ہی فائدے ہیں اس کے بعد ان کی جگہ خانہ کعبہ کے پاس ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcxxix{اور ہم نے ہر قوم کے لئے قربانی کا طریقہ مقرر کردیا ہے تاکہ جن جانوروں کا رزق ہم نے عطا کیا ہے ان پر نام خدا کا ذکر کریں پھر تمہارا خدا صرف خدائے واحد ہے تم اسی کے اطاعت گزار بنو اور ہمارے گڑگڑانے والے بندوں کو بشارت دے دو\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcxxx{جن کے سامنے ذکر خدا آتا ہے تو ان کے دل لرز جاتے ہیں اور وہ جو مصیبت پر صبر کرنے والے اور نماز قائم کرنے والے ہیں اور ہم نے جو رزق دیا ہے اس میں سے ہماری راہ میں خرچ کرنے والے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxi{اور ہم نے قربانیوں کے اونٹ کو بھی اپنی نشانیوں میں سے قرار دیا ہے اس میں تمہارے لئے خیر ہے لہذا اس پر کھڑے ہونے کی حالت ہی میں نام خدا کا ذکر کرو اور اس کے بعد جب اس کے تمام پہلو گر جائیں تو اس میں سے خود بھی کھاؤ اور قناعت کرنے والے اور مانگنے والے سب غریبوں کو کھلاؤ کہ ہم نے انہیں تمہارے لئے لَسّخر کردیا ہے تاکہ تم شکر گزار بندے بن جاؤ\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxii{خدا تک ان جانوروں کا گوشت جانے والا ہے اور نہ خون ... اس کی بارگاہ میں صرف تمہارا تقویٰ جاتا ہے اور اسی طرح ہم نے ان جانوروں کو تمہارا تابع بنادیا ہے کہ خدا کی دی ہوئی ہدایت پر اس کی کبریائی کا اعلان کرو اور نیک عمل والوں کو بشارت دے دو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiii{بیشک اللہ صاحبانِ ایمان کی طرف سے دفاع کرتا ہے اور یقینا اللہ خیانت کرنے والے کافروں کو ہرگز دوست نہیں رکھتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiv{جن لوگوں سے مسلسل جنگ کی جارہی ہے انہیں ان کی مظلومیت کی بنائ پر جہاد کی اجازت دے دی گئی ہے اور یقینا اللہ ان کی مدد پر قدرت رکھنے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxv{یہ وہ لوگ ہیں جو اپنے گھروں سے بلا کسی حق کے نکال دیئے گئے ہیں علاوہ اس کے کہ وہ یہ کہتے ہیں کہ ہمارا پروردگار اللہ ہے اور اگر خدا بعض لوگوں کو بعض کے ذریعہ نہ روکتا ہوتا تو تمام گرجے اور یہودیوں کے عبادت خانے اور مجوسیوں کے عبادت خانے اور مسجدیں سب منہدم کردی جاتیں اور اللہ اپنے مددگاروں کی یقینا مدد کرے گا کہ وہ یقینا صاحبِ قوت بھی ہے اور صاحبِ عزّت بھی ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvi{یہ وہ لوگ ہیں جنہیں ہم نے زمین میں اختیار دیا تو انہوں نے نماز قائم کیً اور زکوِٰ ادا کی اور نیکیوں کا حکم دیا اور برائیوں سے روکا اور یہ طے ہے کہ جملہ امور کا انجام خدا کے اختیار میں ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvii{اور پیغمبر علیھ السّلام اگر یہ لوگ آپ کو جھٹلاتے ہیں تو ان سے پہلے قوم نوح ,قوم عاد اور قوم ثمود نے یہی کام کیا تھا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxviii{اور قوم ابراہیم اور قوم لوط نے بھی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcxxxix{اور اصحاب مدین نے بھی اور موسٰی کو بھی جھٹلایا گیا ہے تو ہم نے کفار کو مہلت دے دی اور پھر اس کے بعد انہیں اپنی گرفت میں لے لیا تو سب نے دیکھ لیا کہ ہمارا عذاب کیسا ہوتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcxl{غرض کتنی ہی بستیاں ہیں جنہیں ہم نے تباہ و برباد کردیا کہ وہ ظالم تھیں تو اب وہ اپنی چھتوں کے بل الٹی پڑی ہیں اور ان کے کنویں معطل پڑے ہیں اور ان کے مضبوط محل بھی مسمار ہوگئے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcxli{کیا ان لوگوں نے زمین میں سیر نہیں کی ہے کہ ان کے پاس ایسے دل ہوتے جو سمجھ سکتے اور ایسے کان ہوتے جو سن سکتے اس لئے کہ درحقیقت آنکھیں اندھی نہیں ہوتی ہیں بلکہ وہ دل اندھے ہوتے ہیں جو سینوں کے اندر پائے جاتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcxlii{پیغمبر علیھ السّلام یہ لوگ آپ سے عذاب میں عجلت کا تقاضا کررہے ہیں حالانکہ خدا اپنے وعدہ کے خلاف ہرگز نہیں کرسکتا ہے اور آپ کے پروردگار کے نزدیک ایک دن بھی ان کے شمار کے ہزار سال کے برابر ہوتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcxliii{اور کتنی ہی بستیاں تھیں جنہیں ہم نے مہلت دی حالانکہ وہ ظالم تھیں پھر ہم نے انہیں اپنی گرفت میں لے لیا اور بالآخر سب کی بازگشت ہماری ہی طرف ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcxliv{آپ کہہ دیجئے کہ انسانو ! میں تمہارے لئے صرف واضح طور پر ڈرانے والا ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcxlv{پھر جو لوگ ایمان لے آئے اور انہوں نے نیک اعمال کئے ہیں ان کے لئے مغفرت اور بہترین رزق ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvi{اور جن لوگوں نے ہماری نشانیوں کے بارے میں کوشش کی کہ ہم کو عاجز کردیں وہ سب کے سب جہنمّ میں جانے والے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcxlvii{اور ہم نے آپ سے پہلے کوئی ایسا رسول یا نبی نہیں بھیجا ہے کہ جب بھی اس نے کوئی نیک آرزو کی تو شیطان نے اس کی آرزو کی راہ میں رکاوٹ ڈال دی تو پھر خدا نے شیطان کی ڈالی ہوئی رکاوٹ کو مٹا دیا اور پھر اپنی آیات کو مستحکم بنادیا کہ وہ بہت زیادہ جاننے والا اور صاحبِ حکمت ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcxlviii{تاکہ وہ شیطانی القائ کو ان لوگوں کے لئے آزمائش بنادے جن کے قلوب میں مرض ہے اور جن کے دل سخت ہوگئے ہیں اور ظالمین یقینا بہت دور رس نافرمانی میں پڑے ہوئے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcxlix{اور اس لئے بھی کہ صاحبانِ علم کو معلوم ہوجائے کہ یہ وحی پروردگار کی طرف سے برحق ہے اور اس طرح وہ ایمان لے آئیں اور پھر ان کے دل اس کی بارگاہ میں عاجزی کا اظہار کریں اور یقینا اللہ ایمان لانے والوں کو سیدھے ر استہ کی طرف ہدایت کرنے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcl{اور یہ کفر اختیار کرنے والے ہمیشہ اس کی طرف سے شبہ ہی میں رہیں گے یہاں تک کہ اچانک ان کے پاس قیامت آجائے یا کسی منحوس دن کا عذاب وارد ہوجائے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcli{آج کے دن ملک اللہ کے لئے ہے اور وہی ان سب کے درمیان فیصلہ کرے گا پھر جو لوگ ایمان لے آئے اور انہوں نے نیک اعمال کئے وہ نعمتوں والی جنّت میں رہیں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdclii{اور جن لوگوں نے کفر اختیار کیا اور ہماری آیتوں کی تکذیب کی ان کے لئے نہایت درجہ کا رسوا کن عذاب ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcliii{اور جن لوگوں نے راسِ خدا میں ہجرت کی اور پھر قتل ہوگئے یا انہیں موت آگئی تو یقینا خدا انہیں بہترین رزق عطا کرے گا کہ وہ بیشک بہترین رزق دینے والا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcliv{وہ انہیں ایسی جگہ پہنچائے گا جسے وہ پسند کرتے ہوں گے اور اللہ بہت زیادہ جاننے والا اور برداشت کرنے والا ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdclv{یہ سب اپنے مقام پر ہے لیکن اس کے بعد جو دشمن کو اتنی ہی سزادے جتنا کہ اسے ستایا گیا ہے اور پھربھی اس پر ظلم کیا جائے تو خدا اس کی مدد ضرور کرے گا کہ وہ یقینا بہت معاف کرنے والا اور بخشنے والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdclvi{یہ سب اس لئے ہے کہ خدا رات کو دن میں داخل کرتا ہے اور دن کو رات میں داخل کرتا ہے اور اللہ بہت زیادہ سننے والا اور دیکھنے والا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdclvii{یہ اس لئے ہے کہ خدا ہی یقینا برحق ہے اور اس کے علاوہ جس کو بھی یہ لوگ پکارتے ہیں وہ سب باطل ہیں اور اللہ بہت زیادہ بلندی والا اور بزرگی اور عظمت والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdclviii{کیا تم نے نہیں دیکھا کہ اللہ نے آسمان سے پانی برسایا تو اس سے زمین سرسبز وشاداب ہوجاتی ہے یقینا اللہ بہت زیادہ مہربان اور حالات کی خبر رکھنے والا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdclix{آسمانوں اور زمین میں جو کچھ بھی ہے سب اسی کے لئے ہے اور یقینا وہ سب سے بے نیاز اور قابلِ حمد و ستائش ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdclx{کیا تم نے نہیں دیکھا کہ اللہ نے تمہارے لئے زمین کی تمام چیزوں کو لَسّخر کردیا ہے اور کشتیاں بھی دریا میں اسی کے حکم سے چلتی ہیں اور وہی آسمانوں کو روکے ہوئے ہے کہ اس کی اجازت کے بغیر زمین پر نہیں گر سکتا ہے-اللہ اپنے بندوں پر بڑا شفیق اور مہربان ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdclxi{وہی خدا ہے جس نے تم کو حیات دی ہے اور پھر موت دے گا اور پھر زندہ کرے گا مگر انسان بڑا انکار کرنے والا اور ناشکرا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdclxii{ہر امّت کے لئے ایک طریقہ عبادت ہے جس پر وہ عمل کررہی ہے لہذا اس امر میں ان لوگوں کو آپ سے جھگڑا نہیں کرنا چاہئے اور آپ انہیں اپنے پروردگار کی طرف دعوت دیں کہ آپ بالکل سیدھی ہدایت کے راستہ پر ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdclxiii{اور اگر یہ آپ سے جھگڑا کریں تو کہہ دیجئے کہ اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdclxiv{اللہ ہی تمہارے درمیان روزِ قیامت ان باتوں کا فیصلہ کرے گا جن باتوں میں تم اختلاف کررہے ہو\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdclxv{کیا تمہیں نہیں معلوم ہے کہ اللہ زمین اور آسمان کی تمام باتوں کو خوب جانتا ہے اور یہ سب باتیں کتاب میں محفوظ ہیں اور سب باتیں خدا کے لئے بہت آسان ہیں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdclxvi{اور یہ لوگ خدا کو چھوڑ کر ان کی پرستش کرتے ہیں جن کے بارے میں نہ خدا نے کوئی دلیل نازل کی ہے اور نہ خود انہیں کوئی علم ہے اور ظالمین کے لئے واقعا کوئی مددگار نہیں ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdclxvii{اور جب ان کے سامنے ہماری واضح آیتیں پڑھ کر سنائی جاتی ہیں تو تم دیکھتے ہو کہ کفر اختیار کرنے والوں کے چہرہ پر ناگواری کے آثار ظاہر ہوجاتے ہیں اور قریب ہوتا ہے کہ وہ ان تلاوت کرنے والوں پر حملہ کربیٹھیں تو کہہ دیجئے کہ میں اس سے بدتر بات کے بارے میں بتلا رہا ہوں اور وہ جہنمّ ہے جس کا خدا نے کافروں سے وعدہ کیا ہے اور وہ بہت برا انجام ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdclxviii{انسانوں تمہارے لئے ایک مثل بیان کی گئی ہے لہذا اسے غور سے سنو-یہ لوگ جنہیں تم خدا کو چھوڑ کر آواز دیتے ہو یہ سب مل بھی جائیں تو ایک مکھی نہیں پیدا کرسکتے ہیں اور اگر مکھی ان سے کوئی چیز چھین لے تو یہ اس سے چھڑا بھی نہیں سکتے ہیں کہ طالب اور مطلوب دونوں ہی کمزور ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdclxix{افسوس کہ ان لوگوں نے خدا کی واقعی قدر نہیں پہچانی اور بیشک اللہ بڑا قدرت والا اور سب پر غالب ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdclxx{اللہ ملائکہ اور انسانوں میں سے اپنے نمائندے منتخب کرتا ہے اور وہ بڑا سننے والا اور خوب دیکھنے والا ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdclxxi{وہ ان کے سامنے اور پبُ پشت کی تمام باتوں کو جانتا ہے اور تمام امور اسی کی طرف پلٹ کر جانے والے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdclxxii{ایمان والو ! رکوع کروً سجدہ کرو اور اپنے رب کی عبادت کرو اور کارخیر انجام دو کہ شاید اسی طرح کامیاب ہوجاؤ اور نجات حاصل کرلو\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiii{اور اللہ کے بارے میں اس طرح جہاد کرو جو جہاد کرنے کا حق ہے کہ اس نے تمہیں منتخب کیا ہے اور دین میں کوئی زحمت نہیں قرار دی ہے یہی تمہارے بابا ابراہیم علیھ السّلام کا دین ہے اس نے تمہارا نام پہلے بھی اور اس قرآن میں بھی مسلم اور اطاعت گزار رکھا ہے تاکہ رسول تمہارے اوپر گواہ رہے اور تم لوگوں کے اعمال کے گواہ رہو لہذا اب تم نماز قائم کرو زکوِٰ اداکرو اور اللہ سے باقاعدہ طور پر وابستہ ہوجاؤ کہ وہی تمہارا مولا ہے اور وہی بہترین مولا اور بہترین مددگار ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdclxxiv{\basmalahur یقینا صاحبانِ ایمان کامیاب ہوگئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdclxxv{جو اپنی نمازوں میں گڑگڑانے والے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvi{اور لغو باتوں سے اعراض کرنے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdclxxvii{اور زکوِ ادا کرنے والے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdclxxviii{اور اپنی شرمگاہوں کی حفاظت کرنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdclxxix{علاوہ اپنی بیویوں اور اپنے ہاتھوں کی ملکیت کنیزوں کے کہ ان کے معاملہ میں ان پر کوئی الزام آنے والا نہیں ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdclxxx{پھر اس کے علاوہ جو کوئی اور راستہ تلاش کرے گا وہ زیادتی کرنے والا ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxi{اور جو مومنین اپنی امانتوں اور اپنے وعدوں کا لحاظ رکھنے والے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxii{اور جو اپنی نمازوں کی پابندی کرنے والے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiii{درحقیقت یہی وہ وارثان هجنتّ ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiv{جو فردوس کے وارث بنیں گے اور اس میں ہمیشہ ہمیشہ رہنے والے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxv{اور ہم نے انسان کو گیلی مٹی سے پیدا کیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvi{پھر اسے ایک محفوظ جگہ پر نطفہ بناکر رکھا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvii{پھر نطفہ کوعلقہ بنایا ہے اور پھر علقہ سے مضغہ پیدا کیا ہے اور پھر مضغہ سے ہڈیاں پیدا کی ہیں اور پھر ہڈیوں پر گوشت چڑھایا ہے پھر ہم نے اسے ایک دوسری مخلوق بنادیا ہے تو کس قدر بابرکت ہے وہ خدا جو سب سے بہتر خلق کرنے والا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxviii{پھر اس کے بعد تم سب مرجانے والے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdclxxxix{پھر اس کے بعد تم روز هقیامت دوبارہ اٹھائے جاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcxc{اور ہم نے تمہارے اوپر تہ بہ تہ سات آسمان بنائے ہیں اور ہم اپنی مخلوقات سے غافل نہیں ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcxci{اور ہم نے آسمان سے ایک مخصوص مقدار میں پانی نازل کیا ہے اور پھر اسے زمین میں ٹھہرا دیا ہے جب کہ ہم اس کے واپس لے جانے پر بھی قادر تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcxcii{پھر ہم نے اس پانی سے تمہارے لئے خرمے اور انگور کے باغات پیدا کئے ہیں جن میں بہت زیادہ میوے پائے جاتے ہیں اور تم ان ہی میں سے کچھ کھا بھی لیتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcxciii{اور وہ درخت پیدا کیا ہے جو طور سینا میں پیدا ہوتا ہے اس سے تیل بھی نکلتا ہے اور وہ کھانے والوں کے لئے سالن بھی ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcxciv{اور بیشک تمہارے لئے ان جانوروں میں بھی عبرت کا سامان ہے کہ ہم ان کے شکم میں سے تمہارے سیراب کرنے کا انتظام کرتے ہیںاور تمہارے لئے ان میں بہت سے فوائد ہیں اور ان میں سے بھی تم کھاتے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcxcv{اور تمہیں ان جانوروں پر اور کشتیوں پر سوار کیا جاتا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvi{اور ہم نے نوح کو ان کی قوم کی طرف بھیجا تو انہوں نے کہا کہ قوم والو خدا کی عبادت کرو کہ تمہارے لئے اس کے علاوہ کوئی خدا نہیں ہے تو تم اس سے کیوں نہیں ڈرتے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcxcvii{ان کی قوم کے کافر رؤسائ نے کہا کہ یہ نوح تمہارے ہی جیسے انسان ہیں جو تم پر برتری حاصل کرنا چاہتے ہیں حالانکہ خدا چاہتا تو ملائکہ کو بھی نازل کرسکتا تھا. یہ تو ہم نے اپنے باپ دادا سے کبھی نہیں سنا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcxcviii{درحقیقت یہ ایک ایسے انسان ہیں جنہیں جنون ہوگیا ہے لہذا چند دن ان کے حالات کا انتظار کرو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcxcix{تو نوح نے دعا کی کہ پروردگار ان کی تکذیب کے مقابلہ میں میری مدد فرما\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcc{تو ہم نے ان کی طرف وحی کی کہ ہماری نگاہ کے سامنے اور ہمارے اشارہ کے مطابق کشتی بناؤ اور پھر جب ہمارا حکم آجائے اور تنور ابلنے لگے تو اسی کشتی میں ہر جوڑے میں سے دو دو کو لے لینا اور اپنے اہل کو لے کر روانہ ہوجانا علاوہ ان افراد کے جن کے بارے میں پہلے ہی ہمارا فیصلہ ہوچکا ہے اور مجھ سے ظلم کرنے والوں کے بارے میں گفتگو نہ کرنا کہ یہ سب غرق کردیئے جانے والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcci{اس کے بعد جب تم اپنے ساتھیوں سمیت کشتی پر اطمینان سے بیٹھ جانا تو کہنا کہ شکر ہے اس پروردگار کا جس نے ہم کو ظالم قوم سے نجات دلادی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccii{اور یہ کہنا کہ پروردگار ہم کو بابرکت منزل پر اتارنا کہ تو بہترین اتارنے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcciii{اس امر میں ہماری بہت سی نشانیاں ہیں اور ہم تو بس امتحان لینے والے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcciv{اس کے بعد پھر ہم نے دوسری قوموں کو پیدا کیا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccv{اور ان میں بھی اپنے رسول کو بھیجا کہ تم سب اللہ کی عبادت کرو کہ اس کے علاوہ تمہارا کوئی خدا نہیں ہے تو کیا تم پرہیزگار نہ بنو گے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccvi{تو ان کی قوم کے ان رؤسائ نے جنہوں نے کفر اختیار کیا تھا اور آخرت کی ملاقات کا انکار کردیا تھا اور ہم نے انہیں زندگانی دنیا میں عیش و عشرت کا سامان دے دیا تھا وہ کہنے لگے کہ یہ تو تمہارا ہی جیسا ایک بشر ہے جو تم کھاتے ہو وہی کھاتا ہے اور جو تم پیتے ہو وہی پیتا بھی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccvii{اور اگر تم نے اپنے ہی جیسے بشر کی اطاعت کرلی تو یقینا خسارہ اٹھانے والے ہوجاؤ گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdccviii{کیا یہ تم سے اس بات کا وعدہ کرتا ہے کہ جب تم مرجاؤ گے اور خاک اور ہڈی ہوجاؤ گے تو پھر دوبارہ نکالے جاؤ گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdccix{حیف صد حیف تم سے کس بات کا وعدہ کیا جارہا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdccx{یہ تو صرف ایک زندگانی دنیا ہے جہاں ہم مریں گے اور جئیں گے اور دوبارہ زندہ ہونے والے نہیں ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdccxi{یہ ایک ایسا آدمی ہے جو خدا پر بہتان باندھتا ہے اور ہم اس پر ایمان لانے والے نہیں ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdccxii{اس رسول نے کہا کہ پروردگار تو ہماری مدد فرما کہ یہ سب ہماری تکذیب کررہے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdccxiii{ارشاد ہوا کہ عنقریب یہ لوگ پشیمان ہوجائیں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdccxiv{نتیجہ یہ ہوا کہ انہیں ایک برحق چنگھاڑنے اپنی گرفت میں لے لیا اور ہم نے انہیں کوڑا کرکٹ بنادیا کہ ظالم قوم کے لئے ہلاکت اور بربادی ہی ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdccxv{پھر اس کے بعد ہم نے دوسری قوموں کو ایجاد کیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdccxvi{کوئی امتّ نہ اپنے مقررہ وقت سے آگے بڑھ سکتی ہے اور نہ پیچھے ہٹ سکتی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdccxvii{اس کے بعد ہم نے مسلسل رسول بھیجے اور جب کسی امتّ کے پاس کوئی رسول آیا تو اس نے رسول کی تکذیب کی اور ہم نے بھی سب کو عذاب کی منزل میں ایک کے پیچھے ایک لگادیا اور سب کو ایک افسانہ بناکر چھوڑ دیا کہ ہلاکت اس قوم کے لئے ہے جو ایمان نہیں لاتی ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdccxviii{پھر ہم نے موسٰی اور ان کے بھائی ہارون کو اپنی نشانیوں اور واضح دلیل کے ساتھ بھیجا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdccxix{فرعون اور اس کے زعمائ مملکت کی طرف تو ان لوگوں نے بھی استکبار کیا اور وہ تو تھے ہی اونچے قسم کے لوگ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdccxx{تو ان لوگوں نے کہہ دیا کہ کیا ہم اپنے ہی جیسے دو آدمیوں پر ایمان لے آئیں جب کہ ان کی قوم خود ہماری پرستش کررہی ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdccxxi{یہ کہہ کر دونوں کو جھٹلا دیا اور اس طرح ہلاک ہونے والوں میں شامل ہوگئے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdccxxii{اور ہم نے موسٰی کو کتاب دی کہ شاید اس طرح لوگ ہدایت حاصل کرلیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiii{اور ہم نے ابن مریم اور ان کی والدہ کو بھی اپنی نشانی قرار دیا اور انہیں ایک بلندی پر جہاں ٹھہرنے کی جگہ بھی تھی اور چشمہ بھی تھا پناہ دی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdccxxiv{اے میرے رسولو ! تم پاکیزہ غذائیں کھاؤ اور نیک کام کرو کہ میں تمہارے اعمال سے خوب باخبر ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdccxxv{اور تمہارا سب کا دین ایک دین ہے اور میں ہی سب کا پروردگار ہوں لہذا بس مجھ سے ڈرو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvi{پھر یہ لوگ آپس میں ٹکڑے ٹکڑے ہوگئے اور ہر گروہ جو کچھ بھی اس کے پاس ہے اسی پر خوش اور مگن ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdccxxvii{اب آپ انہیں ایک مدتّ کے لئے اسی گمراہی میں چھوڑ دیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdccxxviii{کیا ان کا خیال یہ ہے کہ ہم جو کچھ مال اور اولاد دے رہے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdccxxix{یہ ان کی نیکیوں میں عجلت کی جاری ہے . نہیں ہرگز نہیں انہیں تو حقیقت کا شعور بھی نہیں ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdccxxx{بیشک جو لوگ خوف پروردگار سے لرزاں رہتے ہیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxi{اور جو اپنے پروردگار کی نشانیوں پر ایمان رکھتے ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxii{اور جو کسی کو بھی اپنے رب کا شریک نہیں بناتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiii{اور وہ لوگ جو بقدر امکان راسِ خدا میں دیتے رہتے ہیں اور انہیں یہ خوف لگا رہتا ہے کہ پلٹ کر اسی کی بارگاہ میں جانے والے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiv{یہی وہ لوگ ہیں جو نیکیوں میں سبقت کرنے والے ہیں اور سب کے آگے نکل جانے والے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxv{اور ہم کسی نفس کو اس کی وسعت سے زیادہ تکلیف نہیں دیتے ہیں اور ہمارے پاس وہ کتاب ہے جو حق کے ساتھ بولتی ہے اور ان پر کوئی ظلم نہیں کیا جاتا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvi{بلکہ ان کے قلوب اس کی طرف سے بالکل جہالت میں ڈوبے ہوئے ہیں اور ان کے پاس دوسرے قسم کے اعمال ہیں جنہیں وہ انجام دے رہے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvii{یہاں تک کہ جب ہم نے ان کے مالداروں کو عذاب کی گرفت میں لے لیا تو اب سب فریاد کررہے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxviii{اب آج واویلا نہ کرو آج ہماری طرف سے کوئی مدد نہیں کی جائے گی\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmdccxxxix{جب ہماری آیتیں تمہارے سامنے پڑھی جاتی تھیں تو تم الٹے پاؤں واپس چلے جارہے تھے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmdccxl{اکڑتے ہوئے اور قصہّ کہتے اور بکتے ہوئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmdccxli{کیا ان لوگوں نے ہماری بات پر غور نہیں کیا یا ان کے پاس کوئی چیز آگئی ہے جو ان کے باپ دادا کے پاس بھی نہیں آئی تھی\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmdccxlii{یا انہوں نے اپنے رسول کو پہچانا ہی نہیں ہے اور اسی لئے انکار کررہے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmdccxliii{یا ان کا کہنا یہ ہے کہ رسول میں جنون پایا جاتا ہے جب کہ وہ ان کے پاس حق لے کر آیا ہے اور ان کی اکثریت حق کو ناپسند کرنے والی ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmdccxliv{اور اگر حق ان کی خواہشات کا اتباع کرلیتا تو آسمان و زمین اور ان کے مابین جو کچھ بھی ہے سب برباد ہوجاتا بلکہ ہم نے ان کو ان ہی کا ذکر عطا کیا ہے اور یہ اپنے ہی ذکر سے اعراض کئے ہوئے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmdccxlv{تو کیا آپ ان سے اپنا خرچ مانگ رہے ہیں ہرگز نہیں خدا کا دیا ہوا خراج آپ کے لئے بہت بہتر ہے اور وہ بہترین رزق دینے والا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvi{اور آپ تو انہیں سیدھے راستہ کی دعوت دینے والے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmdccxlvii{اور جو لوگ آخرت پر ایمان نہیں لاتے ہیں وہ سیدھے راستہ سے ہٹے ہوئے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmdccxlviii{اور اگر ہم ان پر رحم کریں اور ان کی تکلیف کو دور بھی کردیں تو بھی یہ اپنی سرکشی پر اڑے رہیں گے اور گمراہ ہی ہوتے جائیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmdccxlix{اور ہم نے انہیں عذاب کے ذریعہ پکڑا بھی مگر یہ نہ اپنے پروردگار کے سامنے جھکے اور نہ ہی گڑگڑاتے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmdccl{یہاں تک کہ ہم نے شدید عذاب کا دروازہ کھول دیا تو اسی میں مایوس ہوکر بیٹھ رہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmdccli{وہ وہی خدا ہے جس نے تمہارے لئے کان اور آنکھیں اور دل بنائے ہیں مگر تم بہت کم شکریہ ادا کرتے ہو\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmdcclii{اور اسی نے تمہیں ساری زمین میں پھیلادیا ہے اور اسی کی بارگاہ میں تم اکٹھا کئے جاؤ گے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmdccliii{وہی وہ ہے جو حیات وموت کا دینے والا ہے اور اسی کے اختیار میں دن اور رات کی آمدورفت ہے تو تم عقل کیوں نہیں استعمال کرتے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmdccliv{بلکہ ان لوگوں نے بھی وہی کہہ دیا جو ان کے پہلے والوں نے کہا تھا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmdcclv{کہ اگر ہم مرگئے اور مٹی اور ہڈی ہوگئے تو کیا ہم دوبارہ اٹھائے جانے والے ہیں\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmdcclvi{بیشک ایسا ہی وعدہ ہم سے بھی کیا گیا ہے اور ہم سے پہلے والوں سے بھی کیا گیا ہے لیکن یہ صرف پرانے لوگوں کی کہانیاں ہیں\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmdcclvii{تو ذرا آپ پوچھئے کہ یہ زمین اور اس کی مخلوقات کس کے لئے ہے اگر تمہارے پاس کچھ بھی علم ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmdcclviii{یہ فورا کہیں گے کہ اللہ کے لئے ہے تو کہئے کہ پھر سمجھتے کیوں نہیں ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmdcclix{پھر مزید کہئے کہ ساتوں آسمان اور عرش اعظم کامالک کون ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmdcclx{تو یہ پھر کہیں گے کہ اللہ ہی ہے تو کہئے کہ آخر اس سے ڈرتے کیوں نہیں ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmdcclxi{پھر کہئے کہ ہر شے کی حکومت کس کے اختیار میں ہے کہ وہی پناہ دیتا ہے اور اسی کے عذاب سے کوئی پناہ دینے والا نہیں ہے اگر تمہارا پاس کوئی بھی علم ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmdcclxii{تو یہ فورا جواب دیں گے کہ یہ سب اللہ کے لئے ہے تو کہئے کہ آخر پھر تم پر کون سا جادو کیا جارہا ہے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiii{بلکہ ہم ان کے پاس حق لے کر آئے ہیں اور یہ سب جھوٹے ہیں\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmdcclxiv{یقینا خدا نے کسی کو فرزند نہیں بنایا ہے اور نہ اس کے ساتھ کوئی دوسرا خدا ہے ورنہ ہر خدا اپنی مخلوقات کو لے کر الگ ہوجاتا اور ہر ایک دوسرے پر برتری کی فکر کرتا اور کائنات تباہ و برباد ہوجاتی-اللرُ ان تمام باتوں سے پاک و پاکیزہ ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmdcclxv{وہ حاضر و غائب سب کا جاننے والا ہے اور ان سب کے شرک سے بلند و بالاتر ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvi{اور آپ کہئے کہ پروردگار اگر جس عذاب کا ان سے وعدہ کیا ہے مجھے دکھا بھی دینا\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmdcclxvii{تو پروردگار مجھے اس ظالم قوم کے ساتھ نہ قرار دینا\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmdcclxviii{اور ہم جس عذاب کا ان سے وعدہ کررہے ہیں اسے آپ کو دکھادینے کی قدرت بھی رکھتے ہیں\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmdcclxix{اور آپ برائی کو اچھائی کے ذریعہ رفع کیجئے کہ ہم ان کی باتوں کو خوب جانتے ہیں\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmdcclxx{اور کہئے کہ پروردگار میں شیطانوں کے وسوسوں سے تیری پناہ چاہتا ہوں\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxi{اور اس بات سے پناہ مانگتا ہوں کہ شیاطین میرے پاس آجائیں\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxii{یہاں تک کہ جب ان میں سے کسی کی موت آگئی تو کہنے لگا کہ پروردگار مجھے پلٹا دے\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiii{شاید میں اب کوئی نیک عمل انجام دوں. ہرگز نہیں یہ ایک بات ہے جو یہ کہہ رہا ہے اور ان کے پیچھے ایک عالم ه برزخ ہے جو قیامت کے دن تک قائم رہنے والا ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiv{پھر جب صور پھونکا جائے گا تو نہ رشتہ داریاں ہوں گی اور نہ آپس میں کوئی ایک دوسرے کے حالات پوچھے گا\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxv{پھر جن کی نیکیوں کا پلہّ بھاری ہوگا وہ کامیاب اور نجات پانے والے ہوں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvi{اور جن کی نیکیوں کا پلہّ ہلکا ہوگا وہ وہی لوگ ہوں گے جنہوں نے اپنے نفس کو خسارہ میں ڈال دیا ہے اور وہ جہنم ّ میں ہمیشہ ہمیشہ رہنے والے ہیں\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvii{جہنمّ کی آگ ان کے چہروں کو جھلس دے گی اور وہ اسی میں منہ بنائے ہوئے ہوں گے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxviii{کیا ایسا نہیں ہے کہ جب ہماری آیتیں تمہاری سامنے پڑھی جاتی تھیں تو تم ان کی تکذیب کیا کرتے تھے\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxix{وہ لوگ کہیں گے کہ پروردگار ہم پر بدبختی غالب آگئی تھی اور ہم گمراہ ہوگئے تھے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxx{پروردگار اب ہمیں جہنمّ سے نکال دے اس کے بعد دوبارہ گناہ کریں تو ہم واقعی ظالم ہیں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxi{ارشاد ہوگا کہ اب اسی میں ذلتّ کے ساتھ پڑے رہو اور بات نہ کرو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxii{ہمارے بندوں میں ایک گروہ ایسا بھی تھا جن کا کہنا تھا کہ پروردگار ہم ایمان لائے ہیں لہذا ہمارے گناہوں کو معاف کردے اور ہم پر رحم فرما کہ تو بہترین رحم کرنے والا ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiii{تو تم لوگوں نے ان کو بالکل مذاق بنالیا تھا یہاں تک کہ اس مذاق نے تمہیں ہماری یاد سے بالکل غافل بنادیا اور تم ان کا مضحکہ ہی اڑاتے رہ گئے\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiv{آج کے دن ہم نے ان کو یہ جزا دی ہے کہ وہ سراسر کامیاب ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxv{پھر خدا پوچھے گا کہ تم روئے زمین پر کتنے سال رہے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvi{وہ جواب دیں گے کہ ایک دن یا اس کا بھی ایک ہی حصہّ اسے تو شمار کرنے والوں سے دریافت کرلے\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvii{ارشاد ہوگا کہ بیشک تم بہت مختصر رہے ہو اور کاش تمہیں اس کا ادراک ہوتا\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxviii{کیا تمہارا خیال یہ تھا کہ ہم نے تمہیں بیکار پیدا کیا ہے اور تم ہماری طرف پلٹا کر نہیں لائے جاؤ گے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxix{پس بلند و بالا ہے وہ خدا جو بادشاہ برحق ہے اور اس کے علاوہ کوئی خدا نہیں ہے اور وہ عرش کریم کا پروردگار ہے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmdccxc{اور جو اللہ کے ساتھ کسی اور خدا کو پکارے گا جس کی کوئی دلیل بھی نہیں ہے تو اس کا حساب پروردگار کے پاس ہے اور کافروں کے لئے نجات بہرحال نہیں ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmdccxci{اور پیغمبر علیھ السّلام آپ کہئے کہ پروردگار میری مغفرت فرما اور مجھ پر رحم کر کہ تو بہترین رحم کرنے والا ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmdccxcii{\basmalahur یہ ایک سورہ ہے جسے ہم نے نازل کیا ہے اور فرض کیا ہے اور اس میں کھلی ہوئی نشانیاں نازل کی ہیں کہ شاید تم لوگ نصیحت حاصل کرسکو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccxciii{زناکار عورت اور زنا کار مرد دونوں کو سو سوکوڑے لگاؤ اور خبردار دین خدا کے معاملہ میں کسی مروت کا شکار نہ ہوجانا اگر تمہارا ایمان اللہ اور روزآخرت پر ہے اور اس سزا کے وقت مومنین کی ایک جماعت کو حاضر رہنا چاہئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccxciv{زانی مرد اور زانیہ یا مشرکہ عورت ہی سے نکاح کرے گا اور زانیہ عورت زانی مرد یا مشرک مرد ہی سے نکاح کرے گی کہ یہ صاحبان هایمان پر حرام ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccxcv{اور جو لوگ پاک دامن عورتوں پر زنا کی تہمت لگاتے ہیں اور چار گواہ فراہم نہیں کرتے ہیں انہیں اسیّ کوڑے لگاؤ اور پھر کبھی ان کی گواہی قبول نہ کرنا کہ یہ لوگ سراسر فاسق ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvi{علاوہ ان افراد کے جو اس کے بعد توبہ کرلیں اور اپنے نفس کی اصلاح کرلیں کہ اللہ بہت زیادہ بخشنے والا اور مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccxcvii{اور جو لوگ اپنی بیویوں پر تہمت لگاتے ہیں اور ان کے پاس اپنے علاوہ کوئی گواہ نہیں ہوتا ہے تو ان کی اپنی گواہی چار گواہیوں کے برابر ہوگی اگر وہ چار مرتبہ قسم کھاکر کہیں کہ وہ سچےّ ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccxcviii{اور پانچویں مرتبہ یہ کہیں کہ اگر وہ جھوٹے ہیں تو ان پر خدا کی لعنت ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccxcix{پھر عورت سے بھی حد برطرف ہوسکتی ہے اگر وہ چار مرتبہ قسم کھاکر یہ کہے کہ یہ مرد جھوٹوں میں سے ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccc{اور پانچویں مرتبہ یہ کہے کہ اگر وہ صادقین میں سے ہے تو مجھ پر خدا کا غضب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccci{اور اگر تم پر خدا کا فضل اور اس کی رحمت نہ ہوتی اور وہ توبہ قبول کرنے والا صاحب هحکمت نہ ہوتا تو اس تہمت کا انجام بہت برا ہوتا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdcccii{بیشک جن لوگوں نے زنا کی تہمت لگائی وہ تم ہی میں سے ایک گروہ تھا تم اسے اپنے حق میں شر نہ سمجھو یہ تمہارے حق میں خیر ہے اور ہر شخص کے لئے اتنا ہی گناہ ہے جو اس نے خود کمایا ہے اور ان میں سے جس نے بڑا حصہّ لیا ہے اس کے لئے بڑا عذاب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccciii{آخر ایسا کیوں نہ ہوا کہ جب تم لوگوں نے اس تہمت کو سناُ تھا تو مومنین و مومنات اپنے بارے میں خیر کا گمان کرتے اور کہتے کہ یہ تو کھلا ہوا بہتان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccciv{پھر ایسا کیوں نہ ہوا کہ یہ چار گواہ بھی لے آتے اور جب گواہ نہیں لے آئے تو یہ اللہ کے نزدیک بالکل جھوٹے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdcccv{اور اگر خدا کا فضل دنیا و آخرت میں اور اس کی رحمت نہ ہوتی تو جو چرچا تم نے کیا تھا اس میں تمہیں بہت بڑا عذاب گرفت میں لے لیتا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdcccvi{جب تم اپنی زبان سے چرچا کررہے تھے اور اپنے منہ سے وہ بات نکال رہے تھے جس کا تمہیں علم بھی نہیں تھا اور تم اسے بہت معمولی بات سمجھ رہے تھے حالانکہ اللہ کے نزدیک وہ بہت بڑی بات تھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdcccvii{اور کیوں نہ ایسا ہوا کہ جب تم لوگوں نے اس بات کو سنا تھا تو کہتے کہ ہمیں ایسی بات کہنے کا کوئی حق نہیں ہے خدایا تو پاک و بے نیاز ہے اور یہ بہت بڑا بہتان ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdcccviii{اللرُتم کو نصیحت کرتا ہے کہ اگر تم صاحبِ ایمان ہو تو اب ایسی حرکت دوبارہ ہرگز نہ کرنا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdcccix{اور اللہ تمہارے لئے اپنی نشانیوں کو واضح کرکے بیان کرتا ہے اور وہ صاحبِ علم بھی ہے اور صاحبِ حکمت بھی ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdcccx{جو لوگ یہ چاہتے ہیں کہ صاحبانِ ایمان میں بدکاری کا چرچا پھیل جائے ان کے لئے بڑا دردناک عذاب ہے دنیا میں بھی اور آخرت میں بھی اور اللہ سب کچھ جانتا ہے صرف تم نہیں جانتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdcccxi{اور اگر اللہ کا فضل اور اس کی رحمت تمہارے شامل حال نہ ہوتی اور وہ شفیق اور مہربان نہ ہوتا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdcccxii{ایمان والو شیطان کے نقش قدم پر نہ چلنا کہ جو شیطان کے قدم بہ قدم چلے گا اسے شیطان ہر طرح کی برائی کا حکم دے گا اور اگر تم پر اللہ کا فضل اور اس کی رحمت نہ ہوتی تو تم میں کوئی بھی پاکباز نہ ہوتا لیکن اللہ جسے چاہتا ہے پاک و پاکیزہ بنادیتا ہے اور وہ ہر ایک کی سننے والا اور ہر ایک کے حال هه دل کا جاننے والا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiii{اور خبردار تم میں سے کوئی شخص بھی جسے خدا نے فضل اور وسعت عطا کی ہے یہ قسم نہ کھالے کہ قرابتداروں اور مسکینوں اور راسِ خدا میں ہجرت کرنے والوں کے ساتھ کوئی سلوک نہ کرے گا. ہر ایک کو معاف کرنا چاہئے اور درگزر کرنا چاہئے کیا تم یہ نہیں چاہتے ہو کہ خدا تمہارے گناہوں کو بخش دے اور اللہ بیشک بڑا بخشنے والا اور مہربان ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdcccxiv{یقینا جو لوگ پاکباز اور بے خبر مومن عورتوں پر تہمت لگاتے ہیں ان پر دنیا اور آخرت دونوں جگہ لعنت کی گئی ہے اور ان کے لئے عذابِ عظیم ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdcccxv{قیامت کے دن ان کے خلاف ان کی زبانیں اور ان کے ہاتھ پاؤں سب گواہی دیں گے کہ یہ کیا کررہے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvi{اس دن خدا سب کو پورا پورا بدلہ دے گا اور لوگوں کو معلوم ہوجائے گا کہ خدا یقینا برحق اور حق کا ظاہر کرنے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdcccxvii{خبیث چیزیں خبیث لوگوں کے لئے ہیں اور خبیث افراد خبیث باتوں کے لئے ہیں اور پاکیزہ باتیں پاکیزہ لوگوں کے لئے ہیں اور پاکیزہ افراد پاکیزہ باتوں کے لئے ہیں یہ پاکیزہ لوگ خبیث لوگوں کے اتہامات سے پاک و پاکیزہ ہیں اور ان کے لئے مغفرت اور باعزّت رزق ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdcccxviii{ایمان والو خبردار اپنے گھروں کے علاوہ کسی کے گھر میں داخل نہ ہونا جب تک کہ صاحبِ خانہ سے اجازت نہ لے لو اور انہیں سلام نہ کرلو یہی تمہارے حق میں بہتر ہے کہ شاید تم اس سے نصیحت حاصل کرسکو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdcccxix{پھر اگر گھر میں کوئی نہ ملے تو اس وقت تک داخل نہ ہونا جب تک اجازت نہ مل جائے اور اگر تم سے کہا جائے کہ واپس چلے جاؤ تو واپس چلے جانا کہ یہی تمہارے لئے زیادہ پاکیزہ امر ہے اور اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdcccxx{تمہارے لئے کوئی حرج نہیں ہے کہ تم ایسے مکانات میں جو غیر آباد ہیں اور جن میں تمہارا کوئی سامان ہے داخل ہوجاؤ اور اللہ اس کو بھی جانتا ہے جس کا تم اظہار کرتے ہو اور اس کو بھی جانتا ہے جس کی تم پردہ پوشی کرتے ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxi{اور پیغمبر علیھ السّلام آپ مومنین سے کہہ دیجئے کہ اپنی نگاہوں کو نیچی رکھیں اور اپنی شرمگاہوں کی حفاظت کریں کہ یہی زیادہ پاکیزہ بات ہے اور بیشک اللہ ان کے کاروبار سے خوب باخبر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxii{اور مومنات سے کہہ دیجئے کہ وہ بھی اپنی نگاہوں کو نیچا رکھیں اور اپنی عفت کی حفاظت کریں اور اپنی زینت کا اظہار نہ کریں علاوہ اس کے جو ازخود ظاہر ہے اور اپنے دوپٹہ کو اپنے گریبان پر رکھیں اور اپنی زینت کو اپنے باپ دادا.شوہر. شوہر کے باپ دادا .اپنی اولاد ,اور اپنے شوہر کی اولاد اپنے بھائی اور بھائیوں کی اولاد اور بہنوں کی اولاد اور اپنی عورتوں اور اپنے غلام اور کنیزوں اور ایسے تابع افراد جن میں عورت کی طرف سے کوئی خواہش نہیں رہ گئی ہے اور وہ بچےّ جو عورتوں کے پردہ کی بات سے کوئی سروکار نہیں رکھتے ہیں ان سب کے علاوہ کسی پر ظاہر نہ کریں اور خبردار اپنے پاؤں پٹک کر نہ چلیں کہ جس زینت کو چھپائے ہوئے ہیں اس کا اظہار ہوجائے اور صاحبانِ ایمان تم سب اللہ کی بارگاہ میں توبہ کرتے رہو کہ شاید اسی طرح تمہیں فلاح اور نجات حاصل ہوجائے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiii{اور اپنے غیر شادی شدہ آزاد افراد اور اپنے غلاموں اور کنیزوں میں سے باصلاحیت افراد کے نکاح کا اہتمام کرو کہ اگر وہ فقیر بھی ہوں گے تو خدا اپنے فضل و کرم سے انہیں مالدار بنادے گا کہ خدا بڑی وسعت والا اور صاحب هعلم ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiv{اور جو لوگ نکاح کی وسعت نہیں رکھتے ہیں وہ بھی اپنی عفت کا تحفظ کریں یہاں تک کہ خدا اپنے فضل سے انہیں غنی بنا دے اور جو غلام و کنیز مکاتبت کے طلبگار ہیں ان میں خیر دیکھو تو ان سے مکاتبت کرلو بلکہ جو مال خدا نے تمہیں دے رکھا ہے اس میں سے کچھ انہیں بھی دے دو اور خبردار اپنی کنیزوں کو اگر وہ پاکدامنی کی خواہشمند ہیں تو زنا پر مجبور نہ کرنا کہ ان سے زندگانی دنیا کا فائدہ حاصل کرنا چاہو کہ جو بھی انہیں مجبور کرے گا خدا مجبوری کے بعد ان عورتوں کے حق میں بہت زیادہ بخشنے والا اور مہربان ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxv{اور ہم نے تمہاری طرف اپنی کھلیِ ہوئی نشانیاں اور تم سے پہلے گزر جانے والوں کی مثال اور صاحبانِ تقویٰ کے لئے نصیحت کا سامان نازل کیا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvi{اللرُ آسمانوں اور زمین کا نور ہے .اس کے نور کی مثال اس طاق کی ہے جس میں چراغ ہو اور چراغ شیشہ کی قندیل میں ہو اور قندیل ایک جگمگاتے ستارے کے مانند ہو جو زیتون کے بابرکت درخت سے روشن کیا جائے جو نہ مشرق والا ہو نہ مغرب والا اور قریب ہے کہ اس کا روغن بھڑک اٹھے چاہے اسے آگ مس بھی نہ کرے یہ نور بالائے نور ہے اور اللہ اپنے نور کے لئے جسے چاہتا ہے ہدایت دے دیتا ہے اور اسی طرح مثالیں بیان کرتا ہے اور وہ ہر شے کا جاننے والا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvii{یہ چراغ ان گھروں میں ہے جن کے بارے میں خدا کا حکم ہے کہ ان کی بلندی کا اعتراف کیا جائے اور ان میں اس کے نام کا ذکر کیا جائے کہ ان گھروں میں صبح و شام اس کی تسبیح کرنے والے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxviii{وہ مرد جنہیں کاروبار یا دیگر خرید و فروخت ذکر خدا, قیام نماز اور ادائے زکٰوِ سے غافل نہیں کرسکتی یہ اس دن سے ڈرتے ہیں جس دن کے ہول سے دل اور نگاہیں سب الٹ جائیں گی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxix{تاکہ خدا انہیں ان کے بہترین اعمال کی جزا دے سکے اور اپنے فضل سے مزید اضافہ کرسکے اور خدا جسے چاہتا ہے رزق بے حساب عطا کرتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxx{اور جن لوگوں نے کفر اختیار کرلیا ان کے اعمال اس ریت کے مانند ہیں جو چٹیل میدان میں ہو اور پیاسا اسے دیکھ کر پانی تصور کرے اور جب اس کے قریب پہنچے تو کچھ نہ پائے بلکہ اس خدا کو پائے جو اس کا پورا پورا حساب کردے کہ اللہ بہت جلد حساب کرنے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxi{یا ان اعمال کی مثال اس گہرے دریا کی تاریکیوں کی ہے جسے ایک کے اوپر ایک لہر ڈھانک لے اور اس کے اوپر تہ بہ تہ بادل بھی ہوں کہ جب وہ اپنے ہاتھ کو نکالے تو تاریکی کی بنا پر کچھ نظر نہ آئے اور جس کے لئے خدا نور نہ قرار دے اس کے لئے کوئی نور نہیں ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxii{کیا تم نے نہیں دیکھا کہ اللہ کے لئے زمین و آسمان کی تمام مخلوقات اور فضا کے صف بستہ طائر سب تسبیح کررہے ہیں اور سب اپنی اپنی نماز اور تسبیح سے باخبر ہیں اور اللہ بھی ان کے اعمال سے خوب باخبر ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiii{اور اللہ ہی کے لئے زمین و آسمان کی ملکیت ہے اور اسی کی طرف سب کی بازگشت ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiv{کیا تم نے نہیں دیکھا کہ خدا ہی ابر کو چلاتا ہے اور پھر انہیں آپس میں جوڑ کر تہ بہ تہ بنا دیتاہے پھر تم دیکھو گے کہ اس کے درمیان سے بارش نکل رہی ہے اور وہ اسے آسمان سے برف کے پہاڑوں کے درمیان سے برساتا ہے پھر جس تک چاہتا ہے پہنچادیتا ہے اور جس کی طرف سے چاہتا ہے موڑ دیتا ہے اس کی بجلی کی چمک اتنی تیز ہے کہ قریب ہے کہ آنکھوں کی بینائی ختم کردے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxv{اللرُ ہی رات اور دن کو الٹ پلٹ کرتا رہتا ہے اور یقینا اس میں صاحبانِ بصارت کے لئے سامانِ عبرت ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvi{اور اللہ ہی نے ہر زمین پر چلنے والے کو پانی سے پیدا کیا ہے پھر ان میں سے بعض پیٹ کے بل چلتے ہیں اور بعض دو پیروں میں چلتے ہیں اور بعض چاروں ہاتھ پیر سے چلتے ہیں اور اللہ جو چاہتا ہے پیدا کرتا ہے کہ وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvii{یقینا ہم نے واضح کرنے والی آیتیں نازل کی ہیں اور اللہ جسے چاہتا ہے صراظُ مستقیم کی ہدایت دیدیتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxviii{اور یہ لوگ کہتے ہیں کہ ہم اللہ اور رسول پر ایمان لے آئے ہیں اور ان کی اطاعت کی ہے اور اس کے بعد ان میں سے ایک فریق منہ پھیرلیتا ہے اور یہ واقعا صاحبانِ ایمان نہیں ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxix{اور جب انہیں خدا و رسول کی طرف بلایا جاتا ہے کہ وہ ان کے درمیان فیصلہ کردیں تو ان میں سے ایک فریق کنارہ کش ہوجاتا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmdcccxl{حالانکہ اگر حق ان کے ساتھ ہوتا تو یہ سر جھکائے ہوئے چلے آتے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmdcccxli{تو کیا ان کے دلوں میں کفر کی بیماری ہے یا یہ شک میں مبتلا ہوگئے ہیں یا انہیں یہ خوف ہے کہ خدا اور رسول ان پر ظلم کریں گے حالانکہ حقیقت یہ ہے کہ یہ لوگ خود ہی ظالمین ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlii{مومنین کو تو خدا اور رسول کی طرف بلایا جاتا ہے کہ وہ فیصلہ کریں گے تو ان کا قول صرف یہ ہوتا ہے کہ ہم نے سنا اور اطاعت کی اور یہی لوگ درحقیقت فلاح پانے والے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliii{اور جو بھی اللہ اور رسول کی اطاعت کرے گا اور اس کے دل میں خوف هخدا ہوگا اور وہ پرہیزگاری اختیار کرے گا تو وہی کامیاب کہا جائے گا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmdcccxliv{اور ان لوگوں نے باقاعدہ قسم کھائی ہے کہ آپ حکم دے دیں گے تو یہ گھر سے باہر نکل جائیں گے تو آپ کہہ دیجئے کہ قسم کی ضرورت نہیں ہے عمومی قانون کے مطابق اطاعت کافی ہے کہ یقینا اللرُ ان اعمال سے باخبر ہے جو تم لوگ انجام دے رہے ہو\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlv{آپ کہہ دیجئے کہ اللہ اور اس کے رسول کی اطاعت کرو پھر اگر انحراف کرو گے تو رسول پر وہ ذمہ داری ہے جو اس کے ذمہ رکھی گئی ہے اور تم پر وہ مسئولیت ہے جو تمہارے ذمہ رکھی گئی ہے اور اگر تم اطاعت کرو گے تو ہدایت پاجاؤ گے اور رسول کے ذمہ واضح تبلیغ کے سوا اور کچھ نہیں ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvi{اللرُ نے تم میں سے صاحبان هایمان و عمل صالح سے وعدہ کیا ہے کہ انہیں روئے زمین میں اسی طرح اپنا خلیفہ بنائے گا جس طرح پہلے والوں کو بنایا ہے اور ان کے لئے اس دین کو غالب بنائے گا جسے ان کے لئے پسندیدہ قرار دیا ہے اور ان کے خوف کو امن سے تبدیل کردے گا کہ وہ سب صرف میری عبادت کریں گے اور کسی طرح کا شرک نہ کریں گے اور اس کے بعد بھی کوئی کافر ہوجائے تو درحقیقت وہی لوگ فاسق اور بدکردار ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvii{اور نماز قائم کرو زکٰوِ ادا کرو اور رسول کی اطاعت کرو کہ شاید اسی طرح تمہارے حال پر رحم کیا جائے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlviii{خبردار یہ خیال نہ کرنا کہ کفر اختیار کرنے والے زمین میں ہم کو عاجز کردینے والے ہیں ان کا ٹھکانا جہنمّ ہے اور وہ بدترین انجام ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmdcccxlix{ایمان والو تمہارے غلام و کنیز اور وہ بچے ّجو ابھی سن بلوغ کو نہیں پہنچے ہیں ان سب کو چاہئے کہ تمہارے پاس داخل ہونے کے لئے تین اوقات میں اجازت لیں نماز صبح سے پہلے اور دوپہر کے وقت جب تم کپڑے اتار کر آرام کرتے ہو اور نماز عشائ کے بعد یہ تین اوقات پردے کے ہیں اس کے بعد تمہارے لئے یا ان کے لئے کوئی حرج نہیں ہے کہ ایک دوسرے کے پاس چکر لگاتے رہیں کہ اللہ اسی طرح اپنی آیتوں کو واضح کرکے بیان کرتا ہے اور بیشک اللہ ہر شے کا جاننے والا اور صاحبِ حکمت ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmdcccl{اور جب تمہارے بّچے حد بلوغ کو پہنچ جائیں تو وہ بھی اسی طرح اجازت لیں جس طرح پہلے والے اجازت لیا کرتے تھے پروردگار اسی طرح تمہارے لئے اپنی آیتوں کو واضح کرکے بیان کرتا ہے کہ وہ صاحب هعلم بھی ہے اور صاحبِ حکمت بھی ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmdcccli{اور ضعیفی سے بیٹھ رہنے والی عورتیں جنہیں نکاح سے کوئی دلچسپی نہیں ہے ان کے لئے کوئی حرج نہیں ہے کہ وہ اپنے ظاہری کپڑوں کو الگ کردیں بشرطیکہ زینت کی نمائش نہ کریں اور وہ بھی عفت کا تحفظ کرتی رہیں کہ یہی ان کے حق میں بھی بہتر ہے اور اللہ سب کی سننے والا اور سب کا حال جاننے والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmdccclii{نابینا کے لئے کوئی حرج نہیں ہے اور لنگڑے آدمی کے لئے بھی کوئی حرج نہیں ہے اور مریض کے لئے بھی کوئی عیب نہیں ہے اور خود تمہارے لئے بھی کوئی گناہ نہیں ہے کہ اپنے گھروں سے یا اپنے باپ دادا کے گھروں سے یا اپنی ماں اور نانی دادی کے گھروں سے یا اپنے بھائیوں کے گھروں سے یا اپنی بہنوں کے گھروں سے یا اپنے چچاؤں کے گھروں سے یا اپنی پھوپھیوں کے گھروں سے یا اپنے ماموؤں کے گھروں سے یا اپنی خالاؤں کے گھروں سے یا جن گھروں کی کنجیاں تمہارے اختیار میں ہیں یا اپنے دوستوں کے گھروں سے کھانا کھالو .... اور تمہارے لئے اس میں بھی کوئی حرج نہیں ہے کہ سب مل کر کھاؤ یا متفرق طریقہ سے کھاؤ بس جب گھروں میں داخل ہو تو کم از کم اپنے ہی اوپر سلام کرلو کہ یہ پروردگار کی طرف سے نہایت ہی مبارک اور پاکیزہ تحفہ ہے اور پروردگار اسی طرح اپنی آیتوں کو واضح طریقہ سے بیان کرتا ہے کہ شاید تم عقل سے کام لے سکو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmdcccliii{مومنین صرف وہ افراد ہیں جو خدا اور رسول پر ایمان رکھتے ہوں اور جب کسی اجتماعی کام میں مصروف ہوں تو اس وقت تک کہیں نہ جائیں جب تک اجازت حاصل نہ ہوجائے بیشک جو لوگ آپ سے اجازت حاصل کرتے ہیں وہی اللہ اور رسول پر ایمان رکھتے ہیں لہذا جب آپ سے کسی خاص حالت کے لئے اجازت طلب کریں تو آپ جس کو چاہیں اجازت دے دیں اور ان کے حق میں اللہ سے استغفار بھی کریں کہ اللہ بڑا غفور اور رحیم ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmdcccliv{مسلمانو ! خبردار رسول کو اس طرح نہ پکارا کرو جس طرح آپس میں ایک دوسرے کو پکارتے ہو اللہ ان لوگوں کو خوب جانتا ہے جو تم میں سے خاموشی سے کھسک جاتے ہیں لہذا جو لوگ حکهِ خدا کی مخالفت کرتے ہیں وہ اس امر سے ڈریں کہ ان تک کوئی فتنہ پہنچ جائے یا کوئی دردناک عذاب نازل ہوجائے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmdccclv{اور یاد رکھو کہ اللہ ہی کے لئے زمین و آسمان کی کل کائنات ہے اور وہ تمہارے حالات کو خوب جانتا ہے اور جس دن سب اس کی بارگاہ میں پلٹا کر لائے جائیں گے وہ سب کو ان کے اعمال کے بارے میں بتادے گا کہ وہ ہر شے کا جاننے والا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmdccclvi{\basmalahur بابرکت ہے وہ خدا جس نے اپنے بندے پر فرقان نازل کیا ہے تاکہ وہ سارے عالمین کے لئے عذاب الٰہی سے ڈرانے والا بن جائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmdccclvii{آسمان و زمین کا سارا ملک اسی کے لئے ہے اور اس نے نہ کوئی فرزند بنایا ہے اور نہ کوئی اس کے ملک میں شریک ہے اس نے ہر شے کو خلق کیا ہے اور صحیح اندازے کے مطابق درست بنایا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmdccclviii{اور ان لوگوں نے خدا کو چھوڑ کر ایسے خدا بنالئے ہیں جو کسی بھی شے کے خالق نہیں ہیں بلکہ خود ہی مخلوق ہیں اور خود اپنے واسطے بھی کسی نقصان یا نفع کے مالک نہیں ہیں اور نہ ان کے اختیار میں موت و حیات یا حشر و نشر ہی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmdccclix{اور یہ کفار کہتے ہیں کہ یہ قرآن صرف ایک جھوٹ ہے جسے انہوں نے گڑھ لیا ہے اور ایک دوسری قوم نے اس کام میں ان کی مدد کی ہے حالانکہ ان لوگوں نے خود ہی بڑا ظلم اور فریب کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmdccclx{اور یہ لوگ کہتے ہیں کہ یہ تو صرف اگلے لوگوں کے افسانے ہیں جسے انہوں نے لکھوالیا ہے اور وہی صبح و شام ان کے سامنے پڑھے جاتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmdccclxi{آپ کہہ دیجئے کہ اس قرآن کو اس نے نازل کیا ہے جو آسمانوں اور زمین کے رازوں سے باخبر ہے اور یقینا وہ بڑا بخشنے والا اور مہربان ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmdccclxii{اور یہ لوگ کہتے ہیں کہ اس رسول کو کیا ہوگیا ہے کہ یہ کھانا بھی کھاتا ہے اور بازاروں میں چکر بھی لگاتا ہے اور اس کے پاس کوئی ملک کیوں نہیں نازل کیا جاتا جو اس کے ساتھ مل کر عذاب هالٰہی سے ڈرانے والا ثابت ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiii{یا اس کی طرف کوئی خزانہ ہی گرادیا جاتا یا اس کے پاس کوئی باغ ہی ہوتا جس سے کھاتا پیتا اور پھر یہ ظالم کہتے ہیں کہ تم لوگ تو ایک جادو زدہ آدمی کا اتباع کررہے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmdccclxiv{دیکھو ان لوگوں نے تمہارے لئے کیسی کیسی مثالیں بیان کی ہیں یہ تو بالکل گمراہ ہوگئے ہیں اور اب راستہ نہیں پاسکتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmdccclxv{بابرکت ہے وہ ذات جو اگر چاہے تو تمہارے لئے اس سے بہتر سامان فراہم کردے ایسی جنتیں جن کے نیچے نہریں جاری ہوں اور پھر تمہارے لئے بڑے بڑے محل بھی بنادے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvi{حقیقت یہ ہے کہ ان لوگوں نے قیامت کا انکار کیا ہے اور ہم نے قیامت کا انکار کرنے والوں کے لئے جہنم ّمہیاّ کردیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmdccclxvii{جب آتش جہنم ان لوگوں کو دور سے دیکھے گی تو یہ لوگ اس کے جوش و خروش کی آوازیں سنیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmdccclxviii{اور جب انہیں زنجیروں میں جکڑ کر کسی تنگ جگہ میں ڈال دیا جائے تو وہاں موت کی رَہائی دیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmdccclxix{اس وقت ان سے کہا جائے گا کہ ایک موت کو نہ پکارو بلکہ بہت سی موتوں کو آواز دو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmdccclxx{پیغمبر علیھ السّلامآپ ان سے پوچھئے کہ یہ عذاب زیادہ بہتر ہے یا وہ ہمیشگی کی جنت ّجس کا صاحبان هتقویٰ سے وعدہ کیا گیا ہے اور وہی ان کی جزا بھی ہے اور ان کا ٹھکانا بھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxi{ان کے لئے وہاں ہر خواہش کا سامان موجود ہے اور وہ اس میں ہمیشہ رہنے والے ہیں اور یہ پروردگار کے ذمہ ایک لازمی وعدہ ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxii{اور جس دن بھی خدا ان کو اور ان کے خداؤں کو جنہیں یہ خدا کو چھوڑ کر پکارا کرتے تھے سب کو ایک منزل پر جمع کرے گا اور پوچھے گا کہ تم نے میرے بندوں کو گمراہ کیا تھا یا یہ ازخود بھٹک گئے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiii{تو یہ سب کہیں گے کہ تو پاک اور بے نیاز ہے اور ہمیں کیا حق ہے کہ تیرے علاوہ کسی اور کو اپنا سرپرست بنائیں اصل بات یہ ہے کہ تو نے انہیں اور ان کے بزرگوں کو عزّت دنیا عطا کردی تو یہ تیری یاد سے غافل ہوگئے اس لئے کہ یہ ہلاک ہونے والے لوگ ہی تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiv{دیکھا تم لوگوں نے کہ تمہیں وہ بھی جھٹلا رہے ہیں جنہیں تم نے خدا بنایا تھا تو اب نہ تم عذاب کو ٹال سکتے ہو اور نہ اپنی مدد کرسکتے ہو اور جو بھی تم میں سے ظلم کرے گا اسے ہم بڑے سخت عذاب کا مزہ چکھائیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxv{اور ہم نے آپ سے پہلے بھی جن رسولوں کو بھیجا ہے وہ بھی کھانا کھایا کرتے تھے اور بازاروں میں چلتے تھے اور ہم نے بعض افراد کو بعض کے لئے وجہ آزمائش بنادیا ہے تو مسلمانو ! کیا تم صبر کرسکو گے جب کہ تمہارا پروردگار بہت بڑی بصیرت رکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvi{اور جو لوگ ہماری ملاقات کی امید نہیں رکھتے وہ کہتے ہیں کہ آخر ہم پر فرشتے کیوں نہیں نازل ہوتے یا ہم خدا کو کیوں نہیں دیکھتے درحقیقت یہ لوگ اپنی جگہ پر بہت مغرور ہوگئے ہیں اور انتہائی درجہ کی سرکشی کررہے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvii{جس دن یہ ملائکہ کو دیکھیں گے اس دن مجرمین کے لئے کوئی بشارت نہ ہوگی اور فرشتے کہیں گے کہ تم لوگ دور ہوجاؤ\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxviii{پھر ہم ان کے اعمال کی طرف توجہ کریں گے اور سب کو اڑتے ہوئے خاک کے ذرّوں کے مانند بنا دیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxix{اس دن صرف جنت ّ والے ہوں گے جن کے لئے بہترین ٹھکانہ ہوگا اور بہترین آرام کرنے کی جگہ ہوگی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxx{اور جس دن آسمان بادلوں کی وجہ سے پھٹ جائے گا اور ملائکہ جوق درجوق نازل کئے جائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxi{اس دن درحقیقت حکومت پروردگار کے ہاتھ میں ہوگی اور وہ دن کافروں کے لئے بڑا سخت دن ہوگا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxii{اس دن ظالم اپنے ہاتھوں کو کاٹے گا اور کہے گا کہ کاش میں نے رسول کے ساتھ ہی راستہ اختیار کیا ہوتا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiii{ہائے افسوس-کاش میں نے فلاں شخص کو اپنا دوست نہ بنایا ہوتا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiv{اس نے تو ذکر کے آنے کے بعد مجھے گمراہ کردیا اور شیطان تو انسان کا رسوا کرنے والا ہے ہی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxv{اور اس دن ر سول آواز دے گا کہ پروردگار اس میری قوم نے اس قرآن کو بھی نظر انداز کردیا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvi{اور اسی طرح ہم نے ہر نبی کے لئے مجرمین میں سے کچھ دشمن قرار دیدیئے ہیں اور ہدایت اور امداد کے لئے تمہارا پروردگار بہت کافی ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvii{اور یہ کافر یہ بھی کہتے ہیں کہ آخر انِ پر یہ قرآن ایک دفعہ کِل کاکِل کیوں نہیں نازل ہوگیا-ہم اسی طرح تدریجا نازل کرتے ہیں تاکہ تمہارے دل کو مطمئن کرسکیں اور ہم نے اسے ٹھہر ٹھہر کر نازل کیا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxviii{اوریہ لوگ کوئی بھی مثال نہ لائیں گے مگر یہ کہ ہم اس کے جواب میں حق اور بہترین بیان لے آئیں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxix{وہ لوگ جو جہنم ّکی طرف منہ کے بل کھینچ کر لائے جائیں گے ان کا ٹھکانا بدترین ہے اور وہ بہت زیادہ بہکے ہوئے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmdcccxc{اور ہم نے موسیٰ کو کتاب عطا کی اور ان کے ساتھ ان کے بھائی ہارون کو ان کا وزیر بنادیا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmdcccxci{پھر ہم نے کہا کہ اب تم دونوں اس قوم کی طرف جاؤ جس نے ہماری آیتوں کی تکذیب کی ہے اور ہم نے انہیں تباہ و برباد کردیا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcii{اور قوم نوح کو بھی جب انہوں نے رسولوں کو جھٹلایا تو ہم نے انہیں بھی غرق کردیا اور لوگوں کے لئے ایک نشانی بنا دیا اور ہم نے ظالمین کے لئے بڑا دردناک عذاب مّہیا کررکھا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciii{اور عاد و ثمود اور اصحاب رس اور ان کے درمیان بہت سی نسلوں اور قوموں کو بھی تباہ کردیا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmdcccxciv{اور ان سب کے لئے ہم نے مثالیں بیان کیں اور سب کو ہم نے نیست و نابود کردیا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcv{اور یہ لوگ اس بستی کی طرف آئے جس پر ہم نے پتھروں کی بوچھار کی تھی تو کیا ان لوگوں نے اسے نہیں دیکھاحقیقت یہ ہے کہ یہ لوگ قیامت کی امید ہی نہیں رکھتے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvi{اور جب آپ کو دیکھتے ہیں تو صرف مذاق بنانا چاہتے ہیں کہ کیا یہی وہ ہے جسے خدا نے رسول بناکر بھیجا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvii{قریب تھا کہ یہ ہمیں ہمارے خداؤں سے منحرف کردے اگر ہم لوگ ان خداؤں پر صبر نہ کرلیتے اور عنقریب ان لوگوں کو معلوم ہوجائے گا جب یہ عذاب کو دیکھیں گے کہ زیادہ بہکاہوا کون ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcviii{کیا آپ نے اس شخص کو دیکھا ہے جس نے اپنی خواہشات ہی کو اپنا خدا بنالیا ہے کیا آپ اس کی بھی ذمہ داری لینے کے لئے تیار ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmdcccxcix{کیا آپ کا خیال یہ ہے کہ ان کی اکثریت کچھ سنتی اور سمجھتی ہے ہرگز نہیں یہ سب جانوروں جیسے ہیں بلکہ ان سے بھی کچھ زیادہ ہی گم کردہ راہ ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcm{کیا آپ نے نہیں دیکھا کہ آپ کے پروردگار نے کس طرح سایہ کو پھیلا دیا ہے اور وہ چاہتا تو ایک ہی جگہ ساکن بنا دیتا پھر ہم نے آفتاب کو اس کی دلیل بنادیا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmi{پھر ہم نے تھوڑا تھوڑا کرکے اسے اپنی طرف کھینچ لیا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmii{اور وہی وہ خدا ہے جس نے رات کو تمہارا پردہ اور نیند کو تمہاری راحت اور دن کو تمہارے اٹھ کھڑے ہونے کا وقت قرار دیا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmiii{اور وہی وہ ہے جس نے ہواؤں کو رحمت کی بشارت کے لئے رواں کردیا ہے اور ہم نے آسمان سے پاک و پاکیزہ پانی برسایا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmiv{تاکہ اس کے ذریعہ مردہ شہر کو زندہ بنائیں اور اپنی مخلوقات میں سے جانوروں اور انسانوں کی ایک بڑی تعداد کو سیراب کریں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmv{اور ہم نے ان کے درمیان پانی کو طرح طرح سے تقسیم کیا ہے تاکہ یہ لوگ نصیحت حاصل کریں لیکن انسانوں کی اکثریت نے ناشکری کے علاوہ ہر بات سے انکار کردیا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmvi{اور ہم چاہتے تو ہر قریہ میں ایک ڈرانے والا بھیج دیتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmvii{لہذا آپ کافروں کے کہنے میں نہ آئیں اور ان سے آخر دم تک جہاد کرتے رہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmviii{اور وہی خدا ہے جس نے دونوں دریاؤں کو جاری کیا ہے اس کا پانی مزیدار اور میٹھا ہے اور یہ نمکین اور کڑواہے اور دونوں کے درمیان حدُ فاصل اور مضبوط رکاوٹ بنا دی ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmix{اور وہی وہ ہے جس نے پانی سے انسان کو پیدا کیا ہے اور پھر اس کو خاندان اور سسرال والا بنا دیا ہے اور آپ کا پروردگار بہت زیادہ قدرت والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmx{اور یہ لوگ پروردگار کو چھوڑ کر ایسوں کی عبادت کرتے ہیں جو نہ فائدہ پہنچا سکتے ہیں اور نہ نقصان اور کافر تو ہمیشہ پروردگار کے خلاف ہی پشت پناہی کرتا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmxi{اور ہم نے آپ کو صرف بشارت دینے والا اور ڈرانے والا بنا کر بھیجا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmxii{آپ کہہ دیجئے کہ میں تم لوگوں سے کوئی اجر نہیں چاہتا مگر یہ کہ جو چاہے وہ اپنے پروردگار کا راستہ اختیار کرے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxiii{اور آپ اس خدائے حق و قیوم پر اعتماد کریں جسے موت آنے والی نہیں ہے اور اسی کی حمد کی تسبیح کرتے رہیں کہ وہ اپنے بندوں کے گناہوں کی اطلاع کے لئے خود ہی کافی ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxiv{اس نے آسمان و زمین اور اس کے درمیان کی مخلوقات کو چھ دنوں کے اندر پیدا کیا ہے اور اس کے بعد عرش پر اپنا اقتدار قائم کیا ہے وہ رحمان ہے اس کی تخلیق کے بارے میں اسی باخبر سے دریافت کرو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxv{اور جب ان سے کہا جاتا ہے کہ رحمان کو سجدہ کرو تو کہتے ہیں کہ یہ رحمان کیا ہے کیا ہم اسے سجدہ کرلیں جس کے بارے میں تم حکم دے رہو اور اس طرح ان کی نفرت میں اور اضافہ ہوجاتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxvi{بابرکت ہے وہ ذات جس نے آسمان میں برج بنائے ہیں اور اس میں چراغ اور چمکتا ہوا چاند قرار دیا ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxvii{اور وہی وہ ہے جس نے رات اور دن میں ایک کو دوسرے کاجانشین بنایا ہے اس انسان کے لئے جو عبرت حاصل کرنا چاہے یا شکر پروردگار ادا کرنا چاہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxviii{اور اللہ کے بندے وہی ہیں جو زمین پر آہستہ چلتے ہیں اور جب جاہل ان سے خطاب کرتے ہیں توسلامتی کا پیغام دے دیتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxix{یہ لوگ راتوں کو اس طرح گزارتے ہیں کہ اپنے رب کی بارگاہ میں کبھی سربسجود رہتے ہیں اور کبھی حالت قیام میں رہتے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxx{اور یہ کہتے ہیں کہ پروردگار ہم سے عذاب جہنمّ کو پھیر دے کہ اس کا عذاب بہت سخت اور پائیدار ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxxi{وہ بدترین منزل اور محل اقامت ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxxii{اور یہ لوگ جب خرچ کرتے ہیں تو نہ اسراف کرتے ہیں اور نہ کنجوسی سے کام لیتے ہیں بلکہ ان دونوں کے درمیان اوسط درجے کا راستہ اختیار کرتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiii{اور وہ لوگ خدا کے ساتھ کسی اور خدا کو نہیں پکارتے ہیں اور کسی بھی نفس کو اگر خدا نے محترم قرار دیدیا ہے تو اسے حق کے بغیر قتل نہیں کرتے اور زنا بھی نہیں کرتے ہیں کہ جو ایسا عمل کرے گا وہ اپنے عمل کی سزا بھی برداشت کرے گا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmcmxxiv{جسے روز قیامت رَگنا کردیا جائے گا اور وہ اسی میں ذلّت کے ساتھ ہمیشہ ہمیشہ پڑا رہے گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmcmxxv{علاوہ اس شخص کے جو توبہ کرلے اور ایمان لے آئے اور نیک عمل بھی کرے کہ پروردگار اس کی برائیوں کو اچھائیوں سے تبدیل کردے گا اور خدا بہت زیادہ بخشنے والا اور مہربان ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvi{اور جو توبہ کرلے گا اور عمل صالح انجام دے گا وہ اللہ کی طرف واقعا رجوع کرنے والا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmcmxxvii{اور وہ لوگ جھوٹ اور فریب کے پاس حاضر بھی نہیں ہوتے ہیں اور جب لغو کاموں کے قریب سے گزرتے ہیں تو بزرگانہ انداز سے گزرجاتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmcmxxviii{اور ان لوگوں کوجب آیات الہٰیہ کی یاد دلائی جاتی ہے توبہرے اوراندھے ہوکر گر نہیں پڑتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmcmxxix{اور وہ لوگ برابر دعا کرتے رہتے ہیں کہ خدایا ہمیں ہماری ازواج اور اولاد کی طرف سے خنکی چشم عطا فرما اور ہمیں صاحبان هتقویٰٰ کا پیشوا بنا دے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmcmxxx{یہی وہ لوگ ہیں جنہیں ان کے صبر کی بنائ پر جنتّ کے بالا خانے عطا کئے جائیں گے اور وہاں انہیں تعظیم اور سلام کی پیشکش کی جائے گی\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxi{وہ انہی مقامات پرہمیشہ ہمیشہ رہیں گے کہ وہ بہترین مستقر اور حسین ترین محلِ اقامت ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxii{پیغمبر آپ کہہ دیجئے کہ اگر تمہاری دعائیں نہ ہوتیں تو پروردگار تمہاری پروا بھی نہ کرتا تم نے اس کے رسول کی تکذیب کی ہے تو عنقریب اس کا عذاب بھی برداشت کرنا پڑے گا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiii{\basmalahur طسم ۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiv{یہ ایک واضح کتاب کی آیتیں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxv{کیا آپ اپنے نفس کو ہلاکت میں ڈال دیں گے کہ یہ لوگ ایمان نہیں لارہے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvi{اگر ہم چاہتے تو آسمان سے ایسی آیت نازل کردیتے کہ ان کی گردنیں خضوع کے ساتھ جھک جاتیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvii{لیکن ان کی طرف جب بھی خدا کی طرف سے کوئی نیا ذکر آتاہے تو یہ اس سے اعراض ہی کرتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxviii{یقینا انہوں نے تکذیب کی ہے تو عنقریب ان کے پاس اس بات کی خبریں آجائیں گی جس کا یہ لوگ مذاق اڑا رہے تھے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmcmxxxix{کیا ان لوگوں نے زمین کی طرف نہیں دیکھا کہ ہم نے کس طرح عمدہ عمدہ چیزیں اُگائی ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmcmxl{اس میں ہماری نشانی ہے لیکن ان کی اکثریت ایمان لانے والی نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmcmxli{اور آپ کاپروردگار صاحبِ عزت بھی ہے اور صاحب هحکمت بھی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmcmxlii{اور اس وقت کو یاد کرو جب آپ کے پروردگار نے موسیٰ کو آواز دی کہ اس ظالم قوم کے پاس جاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmcmxliii{یہ فرعون کی قوم ہے کیا یہ متقی نہ بنیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmcmxliv{موسیٰ نے کہا کہ پروردگار میں ڈرتا ہوں کہ یہ میری تکذیب نہ کریں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmcmxlv{میرا دل تنگ ہورہا ہے اور میری زبان رواں نہیں ہے یہ پیغام ہارون کے پاس بھیج دے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvi{اور میرے اوپر ان کاایک جرم بھی ہے تو مجھے خوف ہے کہ یہ مجھے قتل نہ کردیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmcmxlvii{ارشاد ہوا کہ ہرگز نہیںتم دونوں ہی ہماری نشانیوں کو لے کر جاؤ اور ہم بھی تمہارے ساتھ سب سن رہے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmcmxlviii{فرعون کے پاس جاؤ اور کہو کہ ہم دونوں رب العالمین کے فرستادہ ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmcmxlix{کہ بنی اسرائیل کو میرے ساتھ بھیج دے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmcml{اس نے کہا کیا ہم نے تمہیں بچپنے میں پالا نہیں ہے اور کیا تم نے ہمارے درمیان اپنی عمر کے کئی سال نہیں گزارے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmcmli{اور تم نے وہ کام کیا ہے جو تم کرگئے ہو اور تم شکریہ ادا کرنے والوں میں سے نہیں ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmcmlii{موسیٰ نے کہا کہ وہ قتل میں نے اس وقت کیا تھا جب میں قتل سے غافل تھا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmcmliii{پھر میں نے تم لوگوں کے خوف سے گریز اختیار کیا تو میرے رب نے مجھے نبوت عطا فرمائی اور مجھے اپنے نمائندوں میں سے قرار دے دیا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmcmliv{یہ احسان جو تربیت کے سلسلہ میں تو جتا رہا ہے تو تونے بڑا غضب کیا تھاکہ بنی اسرائیل کو غلام بنا لیا تھا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmcmlv{فرعون نے کہا کہ یہ ربّ العالمین کیا چیز ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmcmlvi{موسیٰ نے کہا کہ زمین و آسمان اور اس کے مابین جو کچھ ہے سب کا پروردگار اگر تم یقین کرسکو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmcmlvii{فرعون نے اپنے اطرافیوں سے کہا کہ تم کچھ سن رہے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmcmlviii{موسیٰ نے کہا کہ وہ تمہارا بھی رب ہے اور تمہارے باپ دادا کا بھی رب ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmcmlix{فرعون نے کہا کہ یہ رسول جو تمہاری طرف بھیجا گیا ہے یہ بالکل دیوانہ ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmcmlx{موسیٰ نے کہا وہ مشرق و مغرب اور جو کچھ اس کے درمیان ہے سب کا پرودگار ہے اگر تمہارے پاس عقل ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmcmlxi{فرعون نے کہا کہ تم نے میرے علاوہ کسی خدا کو بھی اختیار کیا تو تمہیں قیدیوں میں شامل کردوں گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmcmlxii{موسیٰ نے جواب دیا کہ چاہے میں کھلی ہوئی دلیل ہی پیش کردوں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiii{فرعون نے کہا وہ دلیل کیا ہے اگر تم سچےّ ہو تو پیش کرو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmcmlxiv{موسیٰ نے اپنا عصا ڈال دیا اور وہ سانپ بن کر رینگنے لگا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmcmlxv{اور گریبان سے ہاتھ نکالا تو وہ سفید چمک دار نظر آنے لگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvi{فرعون نے اپنے اطراف والوں سے کہا کہ یہ تو بڑا ہوشیار جادوگر معلوم ہوتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmcmlxvii{اس کا مقصد یہ ہے کہ جادو کے زور پر تمہیں تمہاری زمین سے نکال باہر کردے تو اب تمہاری رائے کیا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmcmlxviii{لوگوں نے کہا کہ انہیں اور ان کے بھائی کو روک لیجئے اور شہروں میں جادوگروں کو اکٹھاکرنے والوں کو روانہ کردیجئے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmcmlxix{وہ لوگ ایک سے ایک ہوشیار جادوگرلے آئیں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmcmlxx{غرض وقت مقرر پر تمام جادوگر اکٹھا کئے گئے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxi{اور ان لوگوں سے کہا گیا کہ تم سب اس بات پر اجتماع کرنے والے ہو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxii{شاید ہم لوگ ان ساحروں کا اتباع کرلیں اگر وہ غالب آگئے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiii{اس کے بعد جب جادوگر اکٹھا ہوئے تو انہوں نے فرعون سے کہا کہ اگر ہم غالب آگئے تو کیا ہماری کوئی اجرت ہوگی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiv{فرعون نے کہا کہ بے شک تم لوگ میرے مقربین میں شمار ہوگے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxv{موسیٰ نے ان لوگوں سے کہا کہ جو کچھ پھینکنا چاہتے ہو پھینکو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvi{تو ان لوگوں نے اپنی رسیوں اور چھڑیوں کو پھینک دیا اور کہا کہ فرعون کی عزّت و جلال کی قسم ہم لوگ غالب آنے والے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvii{پھر موسیٰ نے بھی اپنا عصا ڈال دیا تو لوگوں نے اچانک کیا دیکھا کہ وہ سب کے جادو کو نگلے جارہا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxviii{یہ دیکھ کر جادوگر سجدہ میں گر پڑے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxix{اور ان لوگوں نے کہا کہ ہم تو رب العالمین پر ایمان لے آئے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxx{جو موسیٰ اور ہارون دونوں کا رب ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxi{فرعون نے کہا کہ تم لوگ میری اجازت سے پہلے ہی ایمان لے آئے یہ تم سے بھی بڑا جادوگر ہے جس نے تم لوگوں کو جادو سکھایا ہے میں تم لوگوں کے ہاتھ پاؤں مختلف سمتوں سے کاٹ دوں گا اور تم سب کو سولی پر لٹکا دوں گا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxii{ان لوگوں نے کہا کہ کوئی حرج نہیں ہم سب پلٹ کر اپنے رب کی بارگاہ میں پہنچ جائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiii{ہم تو صرف یہ چاہتے ہیں کہ ہمارا پروردگار ہماری خطاؤں کو معاف کردے کہ ہم سب سے پہلے ایمان لانے والے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiv{اور ہم نے موسیٰ کی طرف وحی کی کہ میرے بندوں کو لے کر راتوں رات نکل جاؤ کہ تمہارا پیچھا کیا جانے والا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxv{پھر فرعون نے مختلف شہروں میں لشکر جمع کرنے والے روانہ کردیئے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvi{کہ یہ تھوڑے سے افراد کی ایک جماعت ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvii{اور ان لوگوں نے ہمیں غصہ دلا دیا ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxviii{اور ہم سب سارے سازوسامان کے ساتھ ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxix{نتیجہ میں ہم نے ان کو باغات اور چشموں سے نکال باہر کردیا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmcmxc{اور خزانوں اور باعزّت جگہوں سے بھی\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmcmxci{اور ہم اسی طرح سزا دیتے ہیں اور ہم نے زمین کا وارث بنی اسرائیل کو بنادیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmcmxcii{پھر ان لوگوں نے موسیٰ اور ان کے ساتھیوں کا صبح سویرے پیچھا کیا\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmcmxciii{پھر جب دونوں ایک دوسرے کو نظر آنے لگے تو اصحاب موسیٰ نے کہا کہ اب تو ہم گرفت میںآجائیں گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmcmxciv{موسیٰ نے کہا کہ ہرگز نہیں ہمارے ساتھ ہمارا پروردگار ہے وہ ہماری راہنمائی کرے گا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmcmxcv{پھر ہم نے موسیٰ کی طرف وحی کی کہ اپنا عصا دریا میں مار دیں چنانچہ دریا شگافتہ ہوگیا اور ہر حصہّ ایک پہاڑ جیسا نظر آنے لگا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvi{اور دوسرے فریق کو بھی ہم نے قریب کردیا\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmcmxcvii{اور ہم نے موسیٰ اور ان کے تمام ساتھیوں کو نجات دے دی\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmcmxcviii{پھر باقی لوگوں کو غرق کردیا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmcmxcix{اس میں بھی ہماری ایک نشانی ہے اور بنی اسرائیل کی اکثریت ایمان لانے والی نہیں تھی\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmm{اور تمہارا پروردگار صاحبِ عزّت بھی ہے اور مہربان بھی\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmi{اور انہیں ابراہیم کی خبر پڑھ کر سناؤ\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmii{جب انہوںنے اپنے مربی باپ اور قوم سے کہا کہ تم لوگ کس کی عبادت کررہے ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmiii{ان لوگوں نے کہا کہ ہم بتوں کی عبادت کرتے ہیں اور انہی کی مجاوری کرتے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmiv{تو ابراہیم نے کہا کہ جب تم ان کو پکارتے ہو تو یہ تمہاری آواز سنتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmv{یہ کوئی فائدہ یا نقصان پہنچاتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmvi{ان لوگوں نے جواب دیا کہ ہم نے اپنے باپ داداکو ایسا ہی کرتے دیکھا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmvii{ابراہیم نے کہا کہ کیا تم کو معلوم ہے کہ جن کی تم عبادت کرتے ہو\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmviii{تم اور تمہارے تمام بزرگان خاندان\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmix{یہ سب میرے دشمن ہیں. رب العالمین کے علاوہ\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmx{کہ جس نے مجھے پیدا کیا ہے اور پھر وہی ہدایت بھی دیتا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmxi{وہی کھانادیتا ہے اور وہی پانی پلاتا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmxii{اور جب بیمار ہوجاتا ہوں تو وہی شفا بھی دیتا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmxiii{وہی موت دیتا ہے اور پھر وہی زندہ کرتا ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmxiv{اور اسی سے یہ امید ہے کہ روزِ حساب میری خطاؤں کو معاف کردے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmxv{خدایا مجھے علم و حکمت عطا فرما اور مجھے صالحین کے ساتھ ملحق کردے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmxvi{اور میرے لئے آئندہ نسلوں میں سچی زبان اور ذکر خیر قرار دے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmxvii{اور مجھے جنت کے وارثوں میں سے قرار دے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmxviii{اور میرے مربی کو بخش دے کہ وہ گمراہوں میں سے ہے\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmxix{اور مجھے اس دن رسوا نہ کرنا جب سب قبروں سے اٹھائے جائیں گے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmxx{جس دن مال اور اولاد کوئی کام نہ آئے گا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmxxi{مگر وہ جو قلب سلیم کے ساتھ اللہ کی بارگاہ میں حاضر ہو\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmxxii{اور جس دن جنتّ پرہیزگاروں سے قریب تر کردی جائے گی\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmxxiii{اور جہنمّ کو گمراہوں کے سامنے کردیا جائے گا\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmxxiv{اور جہنّمیوں سے کہا جائے گا کہ کہاں ہیں وہ جن کی تم عبادت کیا کرتے تھے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmxxv{خدا کو چھوڑ کر وہ تمہاری مدد کریں گے یا اپنی مدد کریں گے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmxxvi{پھر وہ سب مع تمام گمراہوں کے جہنّم میں منہ کے بل ڈھکیل دیئے جائیں گے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmxxvii{اور ابلیس کے تمام لشکر والے بھی\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmxxviii{اور وہ سب جہنمّ میں آپس میں جھگڑا کرتے ہوئے کہیں گے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmxxix{کہ خدا کی قسم ہم سب کھلی ہوئی گمراہی میں تھے\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmxxx{جب تم کو رب العالمین کے برابر قرار دے رہے تھے\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmxxxi{اور ہمیں مجرموں کے علاوہ کسی نے گمراہ نہیں کیا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmxxxii{اب ہمارے لئے کوئی شفاعت کرنے والا بھی نہیں ہے\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiii{اور نہ کوئی دل پسند دوست ہے\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmxxxiv{پس اے کاش ہمیں واپسی نصیب ہوجاتی تو ہم سب بھی صاحب هایمان ہوجاتے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmxxxv{اس میں بھی ہماری ایک نشانی ہے اور ان کی اکثریت بہرحال مومن نہیں تھی\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvi{اور تمہارا پروردگار سب پر غالب بھی ہے اور مہربان بھی ہے\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmxxxvii{اور نوح کی قوم نے بھی مرسلین کی تکذیب کی\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmxxxviii{جب ان کے بھائی نوح نے ان سے کہا کہ تم پرہیزگاری کیوں نہیں اختیار کرتے ہو\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmxxxix{میں تمہارے لئے امانت دار نمائندہ پروردگار ہوں\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmxl{پس اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmxli{اور میں اس تبلیغ کی کوئی اجر بھی نہیں چاہتا ہوں میری اجر ت تو رب العالمین کے ذمہ ہے\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmxlii{لہذا تم اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmxliii{ان لوگوں نے کہا کہ ہم آپ پر کس طرح ایمان لے آئیں جبکہ آپ کے سارے پیروکار پست طبقہ کے لوگ ہیں\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmxliv{نوح نے کہا کہ میں کیا جانوں کہ یہ کیا کرتے تھے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmxlv{ان کا حساب تو میرے پروردگار کے ذمہ ہے اگر تم اس بات کا شعور رکھتے ہو\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmxlvi{اور میں مومنین کو ہٹانے ولا نہیں ہوں\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmxlvii{میں تو صرف واضح طور پر عذاب الٰہی سے ڈرانے والا ہوں\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmxlviii{ان لوگوں نے کہا کہ نوح اگر تم ان باتوں سے باز نہ آئے تو ہم تمہیں سنگسار کردیں گے\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmxlix{نوح نے یہ سن کر فریاد کی کہ پروردگار میری قوم نے مجھے جھٹلا دیا ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmml{اب میرے اور ان کے درمیان کھلا ہوا فیصلہ فرما دے اور مجھے اور میرے ساتھی صاحبانِ ایمان کو نجات دے دے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmli{پھر ہم نے انہیں اور ان کے ساتھیوں کو ایک بھری ہوئی کشتی میں نجات دے دی\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmlii{اس کے بعد باقی سب کو غرق کردیا\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmliii{یقینا اس میں بھی ہماری ایک نشانی ہے اور ان کی اکثریت ایمان لانے والی نہیں تھی\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmliv{اور تمہارا پروردگار ہی سب پر غالب اور مہربان ہے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmlv{اورقوم عاد نے بھی مرسلین کی تکذیب کی ہے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmlvi{جب ان کے بھائی ہود نے کہا کہ تم خورِ خدا کیوں نہیں پیدا کرتے ہو\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmlvii{میں تمہارے لئے ایک امانتدار پیغمبر ہوں\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmlviii{لہذا اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmlix{اور میں تو تم سے تبلیغ کا کوئی اجر بھی نہیں چاہتا ہوں میرا اجر صرف رب العالمین کے ذمہ ہے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmlx{کیا تم کھیل تماشے کے لئے ہر اونچی جگہ پر ایک یادگار بناتے ہو\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmlxi{اور بڑے بڑے محل تعمیر کرتے ہو کہ شاید اسی طرح ہمیشہ دنیا میں رہ جاؤ\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmlxii{اور جب حملہ کرتے ہو تو نہایت جابرانہ حملہ کرتے ہو\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmlxiii{اب اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmlxiv{اور اس کا خوف پیدا کرو جس نے تمہاری ان تمام چیزوں سے مدد کی ہے جنہیں تم خوب جانتے ہو\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmlxv{تمہاری امداد جانوروں اور اولاد سے کی ہے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmlxvi{اور باغات اور چشموں سے کی ہے\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmlxvii{میں تمہارے بارے میں بڑے سخت دن کے عذاب سے خوفزدہ ہوں\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmlxviii{ان لوگوں نے کہا کہ ہمارے لئے سب برابر ہے چاہے تم ہمیں نصیحت کرو یا تمہارا شمارنصیحت کرنے والوں میں نہ ہو\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmlxix{یہ ڈرانا دھمکانا تو پرانے لوگوں کی عادت ہے\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmlxx{اور ہم پر عذاب ہونے والا نہیں ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmlxxi{پس قوم نے تکذیب کی اور ہم نے اسے ہلاک کردیا کہ اس میں بھی ہماری ایک نشانی ہے ا ور ان کی اکثریت بہرحا ل مومن نہیں تھی\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmlxxii{اور تمہارا پروردگار غالب بھی ہے اور مہربان بھی ہے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiii{او قوم ثمود نے بھی مرسلین کی تکذیب کی\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmlxxiv{جب ان کے بھائی صالح نے کہا کہ تم لوگ خدا سے کیوں نہیں ڈرتے ہو\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmlxxv{میں تمہارے لئے ایک امانتدار پیغمبر ہوں\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvi{لہذا اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmlxxvii{اور میں تم سے اس کام کی اجرت بھی نہیں چاہتا ہوں میری اجرت تو خدائے رب العالمین کے ذمہ ہے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmlxxviii{کیا تم یہاں کی نعمتوں میں اسی آرام سے چھوڑ دیئے جاؤ گے\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmlxxix{انہی باغات اور چشموں میں\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmlxxx{اور انہی کھیتوں اور خرمے کے درختوں کے درمیان جن کی کلیاں نرم و نازک ہیں\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxi{اور جو تم پہاڑوں کو کاٹ کر آسائشی مکانات تعمیر کررہے ہو\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxii{ایسا ہرگز نہیں ہوگا لہذا اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiii{اور زیادتی کرنے والوں کی بات نہ مانو\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiv{جو زمین میں فساد برپا کرتے ہیںاور اصلاح نہیں کرتے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxv{ان لوگوں نے کہا کہ تم پر تو صرف جادو کردیا گیا ہے اور بس\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvi{تم ہمارے ہی جیسے ایک انسان ہو لہذا اگر سچےّ ہو تو کوئی نشانی اور معجزہ لے آؤ\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvii{صالح نے کہا کہ یہ ایک اونٹنی ہے ایک دن کا پانی اس کے لئے ہے اورایک مقرر دن کا پانی تمہارے لئے ہے\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxviii{اور خبردار اسے کوئی تکلیف نہ پہنچانا ورنہ تمہیں سخت دن کا عذاب گرفتار کرلے گا\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmlxxxix{پھر ان لوگوں نے اس کے پیرکاٹ دیئے او بعد میں بہت شرمند ہوئے\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmxc{کہ عذاب نے انہیں گھیر لیا اور یقینا اس میں بھی ہماری ایک نشانی ہے اور ان کی اکثریت ایمان والی نہیں تھی\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmxci{اور تمہارا پروردگار سب پرغالب آنے والا اور صاحبِ رحمت بھی ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmxcii{اور قوم لوط نے بھی مرسلین کو جھٹلایا\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmxciii{جب ان سے ان کے بھائی لوط نے کہا کہ تم خدا سے کیوں نہیں ڈرتے ہو\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmxciv{میں تمہارے حق میں ایک امانتدار پیغمبر ہوں\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmxcv{اللرُ سے ڈرو اور میری اطاعت کرو\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmxcvi{اور میں تم سے اس امر کی کوئی اجرت بھی نہیں چاہتا ہوں میرا اجر تو صرف پروردگار کے ذمہ ہے جو عالمین کا پالنے والا ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmxcvii{کیا تم لوگ ساری دنیا میں صرف مُردوں ہی سے جنسی تعلقات پیدا کرتے ہو\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmxcviii{اور ان ازواج کو چھوڑ دیتے ہو جنہیں پروردگار نے تمہارے لئے پیدا کیا ہے حقیقتا تم بڑی زیادتی کرنے والے لوگ ہو\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmxcix{ان لوگوں نے کہا کہ لوط اگر تم اس تبلیغ سے باز نہ آئے تو اس بستی سے نکال باہر کردیئے جاؤ گے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmc{انہوں نے کہا کہ بہرحال میں تمہارے عمل سے بیزار ہوں\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmci{پروردگار ! مجھے اور میرے اہل کو ان کے اعمال کی سزا سے محفوظ رکھنا\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcii{تو ہم نے انہیں اور ان کے اہل سب کو نجات دے دی\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmciii{سوائے اس ضعیفہ کے کہ جو پیچھے رہ گئی\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmciv{پھر ہم نے ان لوگوں کو تباہ و برباد کردیا\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcv{اور ان کے اوپر زبردست پتھروں کی بارش کردی جو ڈرائے جانے والوں کے حق میں بدترین بارش ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcvi{اور اس میں بھی ہماری ایک نشانی ہے اور ان کی اکثریت بہرحال مومن نہیں تھی\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcvii{اور تمہارا پروردگار عزیز بھی ہے اور رحیم بھی ہے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcviii{اور جنگل کے رہنے والوں نے بھی مرسلین کو جھٹلایا\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcix{جب ان سے شعیب نے کہا کہ تم خدا سے ڈرتے کیوں نہیں ہو\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcx{میں تمہارے لئے ایک امانتدار پیغمبر ہوں\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcxi{لہذا اللہ سے ڈرو اور میری اطاعت کرو\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcxii{اور میں تم سے اس کام کی کوئی اجرت بھی نہیں چاہتا ہوں کہ میرا اجر تو صرف رب العالمین کے ذمہ ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcxiii{اور دیکھو ناپ تول کو ٹھیک رکھو اور لوگوں کو خسارہ دینے والے نہ بنو\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcxiv{اور وزن کرو تو صحیح اور سچیّ ترازو سے تولو\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcxv{اور لوگوں کی چیزوں میں کمی نہ کیا کرو اور روئے زمین میں فساد نہ پھیلاتے پھرو\qt@no{(183)}}%
\qt@newcmd\qurantrans@ur@mmmcxvi{اور اس خدا سے ڈرو جس نے تمہیں اور تم سے پہلے والی نسلوں کو پیدا کیا ہے\qt@no{(184)}}%
\qt@newcmd\qurantrans@ur@mmmcxvii{ان لوگوں نے کہا کہ تم تو صرف جادو زدہ معلوم ہوتے ہو\qt@no{(185)}}%
\qt@newcmd\qurantrans@ur@mmmcxviii{اور تم ہمارے ہی جیسے ایک انسان ہو اور ہمیں تو جھوٹے بھی معلوم ہوتے ہو\qt@no{(186)}}%
\qt@newcmd\qurantrans@ur@mmmcxix{اور اگر واقعا سچے ہو تو ہمارے اوپر آسمان کا کوئی ٹکڑا نازل کردو\qt@no{(187)}}%
\qt@newcmd\qurantrans@ur@mmmcxx{انہوں نے کہا کہ ہمارا پروردگار تمہارے اعمال سے خوب باخبر ہے\qt@no{(188)}}%
\qt@newcmd\qurantrans@ur@mmmcxxi{پھر ان لوگوں نے تکذیب کی تو انہیں سایہ کے دن کے عذاب نے اپنی گرفت میں لے لیا کہ یہ بڑے سخت دن کا عذاب تھا\qt@no{(189)}}%
\qt@newcmd\qurantrans@ur@mmmcxxii{بیشک اس میں بھی ہماری ایک نشانی ہے اور ان کی اکثریت ایمان لانے والی نہیں تھی\qt@no{(190)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiii{اور تمہارا پروردگار بہت بڑا عزت والا اور مہربان ہے\qt@no{(191)}}%
\qt@newcmd\qurantrans@ur@mmmcxxiv{اور یہ قرآن رب العالمین کی طرف سے نازل ہونے والا ہے\qt@no{(192)}}%
\qt@newcmd\qurantrans@ur@mmmcxxv{اسے جبریل امین لے کر نازل ہوئے ہیں\qt@no{(193)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvi{یہ آپ کے قلب پر نازل ہوا ہے تاکہ آپ لوگوں کو عذاب الٰہی سے ڈرائیں\qt@no{(194)}}%
\qt@newcmd\qurantrans@ur@mmmcxxvii{یہ واضح عربی زبان میں ہے\qt@no{(195)}}%
\qt@newcmd\qurantrans@ur@mmmcxxviii{اور اس کا ذکر سابقین کی کتابوں میں بھی موجود ہے\qt@no{(196)}}%
\qt@newcmd\qurantrans@ur@mmmcxxix{کیا یہ نشانی ان کے لئے کافی نہیں ہے کہ اسے بنی اسرائیل کے علمائ بھی جانتے ہیں\qt@no{(197)}}%
\qt@newcmd\qurantrans@ur@mmmcxxx{اور اگر ہم اسے کسی عجمی آدمی پر نازل کردیتے\qt@no{(198)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxi{اور وہ انہیں پڑھ کر سناتا تو یہ کبھی ایمان لانے والے نہیں تھے\qt@no{(199)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxii{اور اس طرح ہم نے اس انکار کو مجرمین کے دلوں تک جانے کا رستہ دے دیا ہے\qt@no{(200)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiii{کہ یہ ایمن لانے والے نہیں ہیں جب تک کہ دردناک عذاب نہ دیکھ لیں\qt@no{(201)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiv{کہ یہ عذاب ان پر اچانک نازل ہوجائے اور انہیں شعور تک نہ ہو\qt@no{(202)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxv{اس وقت یہ کہیں گے کہ کیا ہمیں مہلت دی جاسکتی ہے\qt@no{(203)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvi{تو کیا لوگ ہمارے عذاب کی جلدی کررہے ہیں\qt@no{(204)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvii{کیا تمہیں نہیں معلوم کہ ہم انہیں کئی سال کی مہلت دے دیں\qt@no{(205)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxviii{اور اس کے بعد وہ عذاب آئے جس کا وعدہ کیا گیا ہے\qt@no{(206)}}%
\qt@newcmd\qurantrans@ur@mmmcxxxix{تو بھی جو ان کو آرام دیا گیا تھا وہ ان کے کام نہ آئے گا\qt@no{(207)}}%
\qt@newcmd\qurantrans@ur@mmmcxl{اور ہم نے کسی بستی کو ہلاک نہیں کیا مگر یہ کہ اس کے لئے ڈرانے والے بھیج دیئے تھے\qt@no{(208)}}%
\qt@newcmd\qurantrans@ur@mmmcxli{یہ ایک یاد دہانی تھی اور ہم ہرگز ظلم کرنے والے نہیں ہیں\qt@no{(209)}}%
\qt@newcmd\qurantrans@ur@mmmcxlii{اور اس قرآن کو شیاطین لے کر حاضر نہیں ہوئے ہیں\qt@no{(210)}}%
\qt@newcmd\qurantrans@ur@mmmcxliii{یہ بات ان کے لئے مناسب بھی نہیں ہے اور ان کے بس کی بھی نہیں ہے\qt@no{(211)}}%
\qt@newcmd\qurantrans@ur@mmmcxliv{وہ تو وحی کے سننے سے بھی محروم ہیں\qt@no{(212)}}%
\qt@newcmd\qurantrans@ur@mmmcxlv{لہذا تم اللہ کے ساتھ کسی اور خدا کو مت پکارو کہ مبتلائے عذاب کردیئے جاؤ\qt@no{(213)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvi{اور پیغمبر آپ اپنے قریبی رشتہ داروں کو ڈرایئے\qt@no{(214)}}%
\qt@newcmd\qurantrans@ur@mmmcxlvii{اور جو صاحبانِ ایمان آپ کا اتباع کرلیں ان کے لئے اپنے شانوں کو جھکا دیجئے\qt@no{(215)}}%
\qt@newcmd\qurantrans@ur@mmmcxlviii{پھر یہ لوگ آپ کی نافرمانی کریں تو کہہ دیجئے کہ میں تم لوگوں کے اعمال سے بیزار ہوں\qt@no{(216)}}%
\qt@newcmd\qurantrans@ur@mmmcxlix{اور خدائے عزیز و مہربان پر بھروسہ کیجئے\qt@no{(217)}}%
\qt@newcmd\qurantrans@ur@mmmcl{جو آپ کو اس وقت بھی دیکھتا ہے جب آپ قیام کرتے ہیں\qt@no{(218)}}%
\qt@newcmd\qurantrans@ur@mmmcli{اور پھر سجدہ گزاروں کے درمیان آپ کا اٹھنا بیٹھنا بھی دیکھتا ہے\qt@no{(219)}}%
\qt@newcmd\qurantrans@ur@mmmclii{وہ سب کچھ سننے والا اور جاننے والا ہے\qt@no{(220)}}%
\qt@newcmd\qurantrans@ur@mmmcliii{کیا ہم آپ کو بتائیں کہ شیاطین کس پر نازل ہوتے ہیں\qt@no{(221)}}%
\qt@newcmd\qurantrans@ur@mmmcliv{وہ ہر جھوٹے اور بدکردار پر نازل ہوتے ہیں\qt@no{(222)}}%
\qt@newcmd\qurantrans@ur@mmmclv{جو فرشتوں کی باتوں پر کان لگائے رہتے ہیں اور ان میں کے اکثر لوگ جھوٹے ہیں\qt@no{(223)}}%
\qt@newcmd\qurantrans@ur@mmmclvi{اور شعرائ کی پیروی وہی لوگ کرتے ہیں جو گمراہ ہوتے ہیں\qt@no{(224)}}%
\qt@newcmd\qurantrans@ur@mmmclvii{کیا تم نہیں دیکھتے ہو کہ وہ ہر وادئی خیال میں چکر لگاتے رہتے ہیں\qt@no{(225)}}%
\qt@newcmd\qurantrans@ur@mmmclviii{اور وہ کچھ کہتے ہیں جو کرتے نہیں ہیں\qt@no{(226)}}%
\qt@newcmd\qurantrans@ur@mmmclix{علاوہ ان شعرائ کے جو ایمان لائے اور انہوں نے نیک اعمال کئے اور بہت سارا ذکر خدا کیا اور ظلم سہنے کے بعد اس کا انتقام لیا اور عنقریب ظالمین کو معلوم ہوجائے گا کہ وہ کس جگہ پلٹا دیئے جائیں گے\qt@no{(227)}}%
\qt@newcmd\qurantrans@ur@mmmclx{\basmalahur طسۤ یہ قرآن اور روشن کتاب کی آیتیں ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmclxi{یہ صاحبانِ ایمان کے لئے ہدایت اور بشارت ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmclxii{جو نماز قائم کرتے ہیں زکوِٰ ا دا کرتے ہیں اور آخرت پر یقین رکھتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmclxiii{بیشک جو لوگ آخرت پر ایمان نہیں رکھتے ہیں ہم نے ان کے اعمال کو ان کے لئے آراستہ کردیا ہے اور وہ ان ہی اعمال میں بھٹک رہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmclxiv{ا ن ہی لوگوں کے لئے بدترین عذاب ہے اور یہ آخرت میں خسارہ والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmclxv{اور آپ کو یہ قرآن خدائے علیم و حکیم کی طرف سے عطا کیا جارہا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmclxvi{اس وقت کو یاد کرو جب موسیٰ نے اپنے اہل سے کہا تھا کہ میں نے ایک آگ دیکھی ہے اور عنقریب میں اس سے راستہ کی خبر لاؤں گا یا آگ ہی کا کوئی انگارہ لے آؤں گا کہ تم تاپ سکو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmclxvii{اس کے بعد جب آگ کے پاس آئے تو آواز آئی کہ بابرکت ہے وہ خدا جو آگ کے اندر اور اس کے اطراف میں اپنا جلوہ دکھاتا ہے اور پاک و پاکیزہ ہے وہ پروردگار جو عالمین کا پالنے والا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmclxviii{موسیٰ! میں وہ خدا ہوں جو سب پر غالب اور صاحبِ حکمت ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmclxix{اب تم اپنے عصا کو زمین پر ڈال دو اس کے بعد موسیٰ نے جب دیکھا تو کیا دیکھا کہ وہ سانپ کی طرح لہرا رہا ہے موسیٰ الٹے پاؤں پلٹ پڑے اور مڑ کر بھی نہ دیکھا آواز آئی کہ موسیٰ ڈرو نہیں میری بارگاہ میں مرسلین نہیں ڈرا کرتے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmclxx{ہاں کوئی شخص گناہ کرکے پھر توبہ کرلے اور اس برائی کو نیکی سے بدل دے تو میں بہت بخشنے والا مہربان ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmclxxi{اور اپنے ہاتھ کو گریبان میں ڈال کر نکالو تو دیکھو گے کہ بغیر کسی بیماری کے سفید چمکدار نکلتا ہے یہ ان نو معجزات میں سے ایک ہے جنہیں فرعون اور اس کی قوم کے لئے دیا گیا ہے کہ یہ بڑی بدکار قوم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmclxxii{مگر جب بھی ان کے پاس واضح نشانیاں آئیں تو انہوں نے کہہ دیا کہ یہ کِھلا ہوا جادو ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiii{ان لوگوں نے ظلم اور غرور کے جذبہ کی بنائ پر انکار کردیا تھا ورنہ ان کے دل کو بالکل یقین تھا پھر دیکھو کہ ایسے مفسدین کا انجام کیا ہوتا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmclxxiv{اور ہم نے داؤد اور سلیمان کو علم عطا کیا تو دونوں نے کہا کہ خدا کا شکر ہے کہ اس نے ہمیں بہت سے بندوں پر فضیلت عطا کی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmclxxv{اور پھر سلیمان داؤد کے وارث ہوئے اور انہوں نے کہا کہ لوگو مجھے پرندوں کی باتوں کا علم دیا گیا ہے اور ہر فضیلت کا ایک حصہ عطا کیا گیا ہے اور یہ خدا کا کھلا ہوا فضل و کرم ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvi{اور سلیمان کے لئے ان کا تمام لشکر جنات انسان اور پرندے سب اکٹھا کئے جاتے تھے تو بالکل مرتب منظم کھڑے کر دیئے جاتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmclxxvii{یہاں تک کہ جب وہ لوگ وادئی نمل تک آئے تو ایک چیونٹی نے آواز دی کہ چیونٹیوں سب اپنے اپنے سوراخوں میں داخل ہوجاؤ کہ سلیمان اور ان کا لشکر تمہیں پامال نہ کر ڈالے اور انہیں اس کا شعور بھی نہ ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmclxxviii{سلیمان اس کی بات پر مسکرادیئے اور کہا کہ پروردگار مجھے توفیق دے کہ میں تیری اس نعمت کا شکریہ ادا کروں جو تو نے مجھے اور میرے والدین کو عطا کی ہے اور ایسا نیک عمل کروں کہ تو راضی ہوجائے اور اپنی رحمت سے مجھے اپنے نیک بندوں میں شامل کرلے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmclxxix{اور سلیمان نے ہد ہد کو تلاش کیا اور وہ نظر نہ آیا تو کہا کہ آخر مجھے کیا ہوگیا ہے کہ میں ہد ہد کو نہیں دیکھ رہا ہوں کیا وہ غائب ہوگیا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmclxxx{میں اسے سخت ترین سزادوں گا یا پھر ذبح کر ڈالوں گا یا یہ کہ وہ میرے پاس کوئی واضح دلیل لے آئے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxi{پھر تھوڑی دیر نہ گزری تھی کہ ہد ہد آگیا اور اس نے کہا کہ مجھے ایک ایسی بات معلوم ہوئی ہے جو آپ کو بھی معلوم نہیں ہے اور میں ملک سبا سے ایک یقینی خبر لے کر آیا ہوں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxii{میں نے ایک عورت کو دیکھا ہے جو سب پر حکومت کررہی ہے اور اسے دنیا کی ہر چیز حاصل ہے اور اس کے پاس بہت بڑا تخت بھی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiii{میں نے دیکھا ہے کہ وہ اور اس کی قوم سب سورج کی پوجا کررہے ہیں اور شیطان نے ان کی نظروں میں اس عمل کو حسن بنادیا ہے اور انہیں صحیح راستہ سے روک دیا ہے کہ اب وہ یہ بھی نہیں سمجھتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiv{کہ کیوں نہ اس خدا کا سجدہ کریں جو آسمان و زمین کے پوشیدہ اسرار کو ظاہر کرنے والا ہے اور لوگ جو کچھ چھپاتے ہیں یا ظاہر کرتے ہیں سب کا جاننے والا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxv{وہ اللہ ہے جس کے علاوہ کوئی خدا نہیں ہے اور وہ عرش عظیم کا پروردگار ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvi{سلیمان نے کہا کہ میں ابھی دیکھتا ہوں کہ تو نے سچ کہا ہے یا تیرا شمار بھی جھوٹوں میں ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvii{یہ میرا خط لے کر جا اور ان لوگوں کے سامنے ڈال دے پھر ان کے پاس سے ہٹ جا اور یہ دیکھ کہ وہ کیا جواب دیتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxviii{اس عورت نے کہا کہ میرے زعمائ سلطنت میری طرف ایک بڑا محترم خط بھیجا گیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmclxxxix{جو سلیمان کی طرف سے ہے اور اس کا مضمون یہ ہے کہ شروع کرتا ہوں خدا کے نام سے جو بڑا رحمٰن و رحیم ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcxc{دیکھو میرے مقابلہ میں سرکشی نہ کرو اور اطاعت گزار بن کر چلے آؤ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcxci{زعمائ مملکت! میرے مسئلہ میں رائے دو کہ میں تمہاری رائے کے بغیر کوئی حتمی فیصلہ نہیں کرسکتی\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcxcii{ان لوگوں نے کہا کہ ہم صاحبانِ قوت اور ماہرین جنگ و جدال ہیں اور اختیار بہرحال آپ کے ہاتھ میں ہے آپ بتائیں کہ آپ کا حکلَ کیا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcxciii{اس نے کہا کہ بادشاہ جب کسی علاقہ میں داخل ہوتے ہیں تو بستی کو ویران کردیتے ہیں اور صاحبانِ عزّت کو ذلیل کردیتے ہیں اور ان کا یہی طریقہ کار ہوتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcxciv{اور میں ان کی طرف ایک ہدیہ بھیج رہی ہوں اور پھر دیکھ رہی ہوں کہ میرے نمائندے کیا جواب لے کر آتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcxcv{اس کے بعد جب قاصد سلیمان کے پاس آیا تو انہوں نے کہا کہ تم اپنے مال سے میری امداد کرنا چاہتے ہو جب کہ جو کچھ خدا نے مجھے دیا ہے وہ تمہارے مال سے کہیں زیادہ بہتر ہے جاؤ تم خود ہی اپنے ہدیہ سے خوش رہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvi{جاؤ تم واپس جاؤ اب میں ایک ایسا لشکر لے کر آؤں گا جس کا مقابلہ ممکن نہ ہوگا اور پھر سب کو ذلّت و رسوائی کے ساتھ ملک سے باہر نکالوں گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcxcvii{پھر اعلان کیا کہ میرے اشراف هسلطنت ! تم میں کون ہے جو اس کے تخت کو لے کر آئے قبل اس کے کہ وہ لوگ اطاعت گزار بن کر حاضر ہوں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcxcviii{تو جّنات میں سے ایک دیو نے کہا کہ میں اتنی جلدی لے آؤں گا کہ آپ اپنی جگہ سے بھی نہ اٹھیں گے میں بڑا صاحبِ قوت اور ذمہ دار ہوں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcxcix{اور ایک شخص نے جس کے پاس کتاب کا ایک حصہّ علم تھا اس نے کہا کہ میں اتنی جلدی لے آؤں گا کہ آپ کی پلک بھی نہ جھپکنے پائے اس کے بعد سلیمان نے تخت کو اپنے سامنے حاضر دیکھا تو کہنے لگے یہ میرے پروردگار کا فضل و کرم ہے وہ میرا امتحان لینا چاہتا ہے کہ میں شکریہ ادا کرتا ہوں یا کفرانِ نعمت کرتا ہوں اور جو شکریہ ادا کرے گا وہ اپنے ہی فائدہ کے لئے کرے گا اور جو کفران هنعمت کرے گا اس کی طرف سے میرا پروردگار بے نیاز اور کریم ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcc{سلیمان نے کہا کہ اس کے تخت کو ناقابل شناخت بنادیا جائے تاکہ ہم دیکھیں کہ وہ سمجھ پاتی ہے یا ناسمجھ لوگوں میں ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcci{جب وہ آئی تو سلیمان نے کہا کہ کیا تمہارا تخت ایسا ہی ہے اس نے کہا کہ بالکل ایسا ہی ہے بلکہ شاید یہی ہے اور مجھے تو پہلے ہی علم ہوگیا تھا اور میں اطاعت گزار ہوگئی تھی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccii{اور اسے اس معبود نے روک رکھا تھا جسے خدا کو چھوڑ کر معبود بنائے ہوئے تھی کہ وہ ایک کافر قوم سے تعلق رکھتی تھی\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcciii{پھر اس سے کہا گیا کہ قصر میں داخل ہوجائے اب جو اس نے دیکھا تو سمجھی کہ کوئی گہرا پانی ہے اور اپنی پنڈلیاں کھول دیں سلیمان نے کہا کہ یہ ایک قلعہ ہے جسے شیشوں سے منڈھ دیا گیا ہے اور بلقیس نے کہا کہ میں نے اپنے نفس پر ظلم کیا تھا اور اب میں سلیمان کے ساتھ اس خدا پر ایمان لے آئی ہوں جو عالمین کا پالنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcciv{اور ہم نے قوم ثمود کی طرف ان کے بھائی صالح کو بھیجا کہ تم لوگ اللہ کی عبادت کرو تو دونوں فریق آپس میں جھگڑا کرنے لگے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccv{صالح نے کہا کہ قوم والو آخر بھلائی سے پہلے برائی کی جلدی کیوں کررہے ہو تم لوگ اللہ سے استغفار کیوں نہیں کرتے کہ شاید تم پر رحم کردیا جائے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccvi{ان لوگوں نے کہا کہ ہم نے تم سے اور تمہارے ساتھیوں سے براشگون ہی پایا ہے انہوں نے کہا کہ تمہاری بدقسمتی اللہ کے پاس مقدر ہے اور یہ درحقیقت تمہاری آزمائش کی جارہی ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccvii{اور اس شہر میں نو افراد تھے جو زمین میں فساد برپا کرتے تھے اور اصلاح نہیں کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccviii{ان لوگوں نے کہا کہ تم سب آپس میں خدا کی قسم کھاؤ کہ صالح اور ان کے گھر والوں پر راتوں رات حملہ کردو گے اور بعد میں ان کے وارثوں سے کہہ دو گے کہ ہم ان کے گھر والوں کی ہلاکت کے وقت موجود ہی نہیں تھے اور ہم اپنے بیان میں بالکل سچےّ ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmccix{اور پھر انہوں نے اپنی چال چلی اور ہم نے بھی اپنا انتظام کیا کہ انہیں خبر بھی نہ ہوسکی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccx{پھر اب دیکھو کہ ان کی مکاّری کا انجام کیا ہوا کہ ہم نے ان رؤسائ کو ان کی قوم سمیت بالکل تباہ وبرباد کردیا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccxi{اب یہ ان کے گھر ہیں جو ظلم کی بنائ پر خالی پڑے ہوئے ہیں اور یقینا اس میں صاحبانِ علم کے لئے ایک نشانی پائی جاتی ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmccxii{اور ہم نے ان لوگوں کو نجات د ے دی جو ایمان والے تھے اور تقویٰ الٰہی اختیار کئے ہوئے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmccxiii{اور لوط کو یاد کرو جب انہوں نے اپنی قوم سے کہا کہ کیا تم آنکھیں رکھتے ہوئے بدکاری کا ارتکاب کر رہے ہو\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmccxiv{کیا تم لوگ ازراہ هشہوت همذِدوں سے تعلقات پیدا کررہے ہو اور عورتوں کو چھوڑے دے رہے ہو اور درحقیقت تم لوگ بالکل جاہل قوم ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmccxv{تو ان کی قوم کا کوئی جواب نہیں تھا سوائے اس کے کہ لوط والوں کو اپنی بستی سے نکال باہر کردو کہ یہ لوگ بہت پاکباز بن رہے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmccxvi{تو ہم نے لوط اور ان کے خاندان والوں کو زوجہ کے علاوہ سب کو نجات دے دی کہ وہ پیچھے رہ جانے والوں میں تھی\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmccxvii{اور ہم نے ان پر عجیب و غریب قسم کی بارش کردی کہ جن لوگوں کو ڈرایا جاتا ہے ان پر بارشِ عذاب بھی بہت بری ہوتی ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmccxviii{آپ کہئے ساری تعریف اللہ کے لئے ہے اور سلام ہے اس کے ان بندوں پر جنہیں اس نے منتخب کرلیا ہے آیا خدا زیادہ بہتر ہے یا جنہیں یہ شریک بنارہے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmccxix{بھلا وہ کون ہے جس نے آسمان و زمین کو پیدا کیا ہے اور تمہارے لئے آسمان سے پانی برسایا ہے پھر ہم نے اس سے خوشنما باغ اگائے ہیں کہ تم ان کے درختوں کو نہیں اگا سکتے تھے کیا خدا کے ساتھ کوئی اور خدا ہے ... نہیں بلکہ یہ لوگ خود اپنی طرف سے دوسروں کو خدا کے برابر بنارہے ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmccxx{بھلا وہ کون ہے جس نے زمین کو قرار کی جگہ بنایا اور پھر اس کے درمیان نہریں جاری کیں اور اس کے لئے پہاڑ بنائے اور دو دریاؤں کے درمیان حد فاصل قرار دی کیا خدا کے ساتھ کوئی اور بھی خدا ہے ہرگز نہیں اصل یہ ہے کہ ان کی اکثریت جاہل ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmccxxi{بھلا وہ کون ہے جو مضطر کی فریاد کو سنتا ہے جب وہ اس کو آواز دیتا ہے اور اس کی مصیبت کو دور کردیتا ہے اور تم لوگوں کو زمین کا وارث بناتا ہے کیا خدا کے ساتھ کوئی اور خدا ہے - نہیں - بلکہ یہ لوگ بہت کم نصیحت حاصل کرتے ہیں\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmccxxii{بھلا وہ کون ہے جو خشکی اور تری کی تاریکیوں میں تمہاری رہنمائی کرتا ہے اور بارش سے پہلے بشارت کے طور پر ہوائیں چلاتا ہے کیا اللہ کے ساتھ کوئی اور خدا ہے - یقینا وہ خدا تمام مخلوقات سے کہیں زیادہ بلند و بالا ہے جنہیں یہ لوگ اس کا شریک بنارہے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiii{یا کون ہے جو خلق کی ابتدا کرتا ہے اور پھر دوبارہ بھی وہی پیدا کرے گا اور کون ہے جو آسمان اور زمین سے رزق عطا کرتا ہے کیا خدا کے ساتھ کوئی اور بھی معبود ہے آپ کہہ دیجئے کہ اگر تم اپنے دعویٰ میں سچے ہو تو اپنی دلیل لے آؤ\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmccxxiv{کہہ دیجئے کہ آسمان و زمین میں غیب کا جاننے والا اللہ کے علاوہ کوئی نہیں ہے اور یہ لوگ نہیں جانتے ہیں کہ انہیں کب دوبارہ اٹھایا جائے گا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmccxxv{بلکہ آخرت کے بارے میں ان کا علم ناقص رہ گیا ہے بلکہ یہ اس کی طرف سے شک میں مبتلا ہیں بلکہ یہ بالکل اندھے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvi{اورکفّار یہ کہتے ہیں کہ کیا جب ہم اور ہمارے باپ دادا سب مٹی ہوجائیں گے تو پھر دوبارہ نکالے جائیں گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmccxxvii{ایسا وعدہ ہم سے اور ہمارے باپ دادا سے بہت پہلے سے کیا جارہا ہے اور یہ سب اگلے لوگوں کی کہانیاں ہیں اور بس\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmccxxviii{آپ ان سے کہہ دیجئے کہ روئے زمین میں سیر کرو اور پھر دیکھو کہ مجرمین کا انجام کیسا ہوا ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmccxxix{اور آپ ان کے حال پر رنجیدہ نہ ہوں اور یہ جو چالیں چل رہے ہیں ان کی طرف سے بھی دل تنگ نہ ہوں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmccxxx{اور یہ لوگ کہتے ہیں کہ اگر تم سچے ہو تو یہ وعدہ آخر کب پورا ہونے والا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxi{تو کہہ دیجئے کہ بہت ممکن ہے کہ جس عذاب کی تم جلدی کررہے ہو اس کا کوئی حصّہ تمہارے پیچھے ہی لگاہوا ہو\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxii{اور آپ کا پروردگار بندوں کے حق میں بہت زیادہ مہربان ہے لیکن ان کی اکثریت شکریہ نہیں ادا کرتی ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiii{اور آپ کا پروردگار وہ سب جانتا ہے جسے ان کے دل چھپائے ہوئے ہیں یا جس کا یہ اعلان کررہے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiv{اور آسمان و زمین میں کوئی پوشیدہ چیز ایسی نہیں ہے جس کا ذکر کتاب مبین میں نہ ہو\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxv{بیشک یہ قرآن بنی اسرائیل کے سامنے ان بہت سی باتوں کی حکایت کرتا ہے جن کے بارے میں وہ آپس میں اختلاف کررہے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvi{اور یہ قرآن صاحبان هایمان کے لئے ہدایت اور رحمت ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvii{آپ کا پروردگار ان کے درمیان اپنے حکم سے فیصلہ کرتا ہے اور وہ سب پر غالب بھی ہے اور سب سے باخبر بھی ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxviii{لہٰذا آپ اسی پر اعتماد کریں کہ آپ واضح حق کے راستہ پر ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmccxxxix{آپ مفِدوں کو اور بہروں کو اپنی آواز نہیں سنا سکتے اگر وہ منہ پھیر کر بھاگ کھڑے ہوں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmccxl{اور آپ اندھوں کو بھی ان کی گمراہی سے راہ هراست پر نہیں لاسکتے ہیں آپ اپنی آواز صرف ان لوگوں کو سناسکتے ہیں جو ہماری آیتوں پر ایمان رکھتے ہیں اور ہمارے اطاعت گزار ہیں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmccxli{اور جب ان پر وعدہ پورا ہوگا تو ہم زمین سے ایک چلنے والا نکال کر کھڑا کردیں گے جو ان سے یہ بات کرے کہ کون لوگ ہماری آیات پر یقین نہیں رکھتے تھے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmccxlii{اور اس دن ہم ہر امت میں سے وہ فوج اکٹھا کریں گے جو ہماری آیتوں کی تکذیب کیا کرتے تھے اور پھر الگ الگ تقسیم کردیئے جائیں گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmccxliii{یہاں تک کہ جب سب آجائیں گے تو ارشاد احدیت ہوگا کہ کیا تم لوگوں نے میری آیتوں کی تکذیب کی تھی حالانکہ تمہیں ان کا مکمل علم نہیں تھا یا تم کیا کررہے تھے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmccxliv{اور ان کے ظلم کی بنا پر ان پر بات ثابت ہوجائے گی اور وہ بولنے کے قابل بھی نہ ہوں گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmccxlv{کیا ان لوگوں نے نہیں دیکھا کہ ہم نے رات کو پیدا کیا تاکہ یہ سکون حاصل کرسکیں اور دن کو روشنی کا ذریعہ بنایا اس میں صاحبان ه ایمان کے لئے ہماری بڑی نشانیاں ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvi{اور جس دن صور پھونکا جائے گا تو زمین و آسمان میں جو بھی ہے سب لرز جائیں گے علاوہ ان کے جن کو خدا چاہے اور سب اس کی بارگاہ میں سر جھکائے حاضر ہوں گے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmccxlvii{اور تم دیکھو گے تو سمجھو گے کہ جیسے پہاڑ اپنی جگہ پر جامد ہیں حالانکہ یہ بادلوں کی طرح چل رہے ہوں گے .یہ اس خدا کی صنعت ہے جس نے ہر چیز کو محکم بنایا ہے اور وہ تمہارے تمام اعمال سے باخبر ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmccxlviii{جو کوئی نیکی کرے گا اسے اس سے بہتر اجر ملے گا اور وہ لوگ روزِ قیامت کے خوف سے محفوظ بھی رہیں گے\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmccxlix{اور جو لوگ برائی کریں گے انہیں منہ کے بھل جہّنم میں ڈھکیل دیا جائے گا کہ کیا تمہیں تمہارے اعمال کے علاوہ بھی کوئی معاوضہ دیا جاسکتا ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmccl{مجھے تو صرف یہ حکم دیا گیا ہے کہ میں اس شہر کے مالک کی عبادت کروں جس نے اسے محترم بنایا ہے اور ہر شے اسی کی ملکیت ہے اور مجھے یہ حکم دیا گیا ہے کہ میں اطاعت گزاروں میں شامل ہوجاؤں\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmccli{اور یہ کہ میں قرآن کو پڑھ کر صَناؤں اب اس کے بعد جو ہدایت حاصل کرلے گا وہ اپنے فائدہ کے لئے کرے گا اور جو بہک جائے گا اس سے کہہ دیجئے کہ میں تو صرف ڈرانے والوں میں سے ہوں\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmcclii{اور یہ کہئے کہ ساری حمد صرف اللہ کے لئے ہے اور وہ عنقریب تمہیں اپنی نشانیاں دکھلائے گا اور تم پہچان لو گے اور تمہارا پروردگار تمہارے اعمال سے سے غافل نہیں ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmccliii{\basmalahur طۤسۤم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmccliv{یہ کتابِ مبین کی آیتیں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcclv{ہم آپ کو موسٰی اور فرعون کی سّچی خبر سنارہے ہیں ان لوگوں کے لئے جو ایمان لانے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcclvi{فرعون نے روئے زمین پر بلندی اختیار کی اور اس نے اہلِ زمین کو مختلف حصوں میں تقسیم کردیا کہ ایک گروہ نے دوسرے کو بالکل کمزور بنادیا وہ لڑکوں کو ذبح کردیا کرتا تھا اور عورتوں کو زندہ رکھا کرتا تھا. وہ یقینا مفسدین میں سے تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcclvii{اور ہم یہ چاہتے ہیں کہ جن لوگوں کو زمین میں کمزور بنادیا گیا ہے ان پر احسان کریں اور انہیں لوگوں کا پیشوا بنائیں اور زمین کا وارث قرار دیدیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcclviii{اور انہی کو روئے زمین کا اقتدار دیں اور فرعون وہامان اور ان کے لشکروں کو ان ہی کمزوروں کے ہاتھوں سے وہ منظر دکھلائیں جس سے یہ ڈر رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcclix{اور ہم نے مادر موسٰی کی طرف وحی کی کہ اپنے بچّہ کو دودھ پلاؤ اور اس کے بعد جب اس کی زندگی کا خوف پیدا ہو تو اسے دریا میں ڈال دو اور بالکل ڈرو نہیں اور پریشان نہ ہو کہ ہم اسے تمہاری طرف پلٹا دینے والے اور اسے مرسلین میں سے قرار دینے والے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcclx{پھر فرعون والوںنے اسے اٹھالیا کہ انجام کار ان کا دشمن اور ان کے لئے باعث هرنج و الم بنے .بیشک فرعون اور ہامان اور ان کے لشکر والے سب غلطی پر تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcclxi{اور فرعون کی زوجہ نے کہا کہ یہ تو ہماری اور تمہاری آنکھوں کی ٹھنڈک ہے لہٰذا اسے قتل نہ کرو کہ شاید یہ ہمیں فائدہ پہنچائے اور ہم اسے اپنا فرزند بنالیں اور وہ لوگ کچھ نہیں سمجھ رہے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcclxii{اور موسٰی کی ماں کا دل بالکل خالی ہوگیا کہ قریب تھا کہ وہ اس راز کو فاش کردیتیں اگر ہم ان کے دل کو مطمئن نہ بنادیتے تاکہ وہ ایمان لانے والوں میں شامل ہوجائیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiii{اور انہوں نے اپنی بہن سے کہا کہ تم بھی ان کا پیچھا کرو تو انہوں نے دور سے موسٰی کو دیکھا جب کہ ان لوگوں کو اس کا احساس بھی نہیں تھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcclxiv{اور ہم نے موسٰی پر دودھ پلانے والیوں کا دودھ پہلے ہی سے حرام کردیا تو موسٰی کی بہن نے کہا کہ کیا میں تمہیں ایسے گھر والوں کا پتہ بتاؤں جو اس کی کفالت کرسکیں اور وہ اس کے خیر خواہ بھی ہوں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcclxv{پھر ہم نے موسٰی کو ان کی ماں کی طرف پلٹا دیا تاکہ ان کی آنکھ ٹھنڈی ہوجائے اور وہ پریشان نہ رہیں اور انہیں معلوم ہوجائے کہ اللہ کا وعدہ بہرحال سچا ّہے اگرچہ لوگوں کی اکثریت اسے نہیں جانتی ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvi{اور جب موسٰی جوانی کی توانائیوں کو پہنچے اور تندرست ہوگئے تو ہم نے انہیں علم اور حکمت عطا کردی اور ہم اسی طرح نیک عمل والوں کو جزا دیا کرتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcclxvii{اور موسٰی شہر میں اس وقت داخل ہوئے جب لوگ غفلت کی نیند میں تھے تو انہوں نے دو آدمیوں کو لڑتے ہوئے دیکھا ایک ان کے شیعوں میں سے تھا اور ایک دشمنوں میں سے تو جو ان کے شیعوں میں سے تھا اس نے دشمن کے ظلم کی فریاد کی تو موسٰی نے اسے ایک گھونسہ مار کر اس کی زندگی کا فیصلہ کردیا اور کہا کہ یہ یقینا شیطان کے عمل سے تھا اور یقینا شیطان دشمن اور کھنَا ہوا گمراہ کرنے والا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcclxviii{موسٰی نے کہا کہ پروردگار میں نے اپنے نفس کے لئے مصیبت مول لے لی لہذا مجھ معاف کردے تو پروردگار نے معاف کردیا کہ وہ بہت بخشنے والا اور مہربان ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcclxix{موسٰی نے کہا کہ پروردگار تونے میری مدد کی ہے لہذا میں کبھی مجرموں کا ساتھی نہیں بنوں گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcclxx{پھر صبح کے وقت موسٰی شہر میں داخل ہوئے تو خوفزدہ اور حالات کی نگرانی کرتے ہوئے کہ اچانک دیکھا کہ جس نے کل مدد کے لئے پکارا تھا وہ پھر فریاد کررہا ہے موسٰی نے کہا کہ یقینا تو کھنَا ہوا گمراہ ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxi{پھر جب موسٰی نے چاہا کہ اس پر حملہ آور ہوں جو دونوں کا دشمن ہے تو اس نے کہا کہ موسٰی تم اسی طرح مجھے قتل کرنا چاہتے ہو جس طرح تم نے کل ایک بے گناہ کو قتل کیا ہے تم صرف روئے زمین میں سرکش حاکم بن کر رہنا چاہتے ہو اور یہ نہیں چاہتے ہو کہ تمہارا شمار اصلاح کرنے والوں میں ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxii{اور ادھر آخ» شہر سے ایک شخص دوڑتا ہوا آیا اور اس نے کہا کہ موسٰی شہر کے بڑے لوگ باہمی مشورہ کررہے ہیں کہ تمہیں قتل کردیں لہذا تم شہر سے باہر نکل جاؤ میں تمہارے لئے نصیحت کرنے والوں میں سے ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiii{تو موسٰی شہر سے باہر نکلے خوفزدہ اور دائیں بائیں دیکھتے ہوئے اور کہا کہ پروردگار مجھے ظالم قوم سے محفوظ رکھنا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiv{اور جب موسٰی نے مدین کا رخ کیا تو کہا کہ عنقریب پروردگار مجھے سیدھے راستہ کی ہدایت کردے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxv{اور جب مدین کے چشمہ پروارد ہوئے تو لوگوں کی ایک جماعت کو دیکھا جو جانوروں کو پانی پلارہی تھی اور ان سے الگ دو عورتیں تھیں جو جانوروں کو روکے کھڑی تھیں .موسٰی نے پوچھا کہ تم لوگوں کا کیا مسئلہ ہے ان دونوں نے کہا کہ ہم اس وقت تک پانی نہیں پلاتے ہیں جب تک ساری قوم ہٹ نہ جائے اور ہمارے بابا ایک ضعیف العمر آدمی ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvi{موسٰی نے دونوں کے جانوروں کو پانی پلادیا اور پھر ایک سایہ میں آکر پناہ لے لی عرض کی پروردگار یقینا میں اس خیر کا محتاج ہوں جو تو میری طرف بھیج دے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvii{اتنے میں دونوں میں سے ایک لڑکی کمال شرم و حیا کے ساتھ چلتی ہوئی آئی اور اس نے کہا کہ میرے بابا آپ کو بلارہے ہیں کہ آپ کے پانی پلانے کی اجرت دے دیں پھر جو موسٰی ان کے پاس آئے اور اپنا قصّہ بیان کیا تو انہوں نے کہا کہ ڈرو نہیں اب تم ظالم قوم سے نجات پاگئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxviii{ان دونوں میں سے ایک لڑکی نے کہا کہ بابا آپ انہیں نوکر رکھ لیجئے کہ آپ جسے بھی نوکر رکھنا چاہیں ان میں سب سے بہتر وہ ہوگا جو صاحبِ قوت بھی ہو اور امانتدار بھی ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxix{انہوں نے کہا کہ میں ان دونوں میں سے ایک بیٹی کا عقد آپ سے کرنا چاہتا ہوں بشرطیکہ آپ آٹھ سال تک میری خدمت کریں پھر اگر دس سال پورے کردیں تو یہ آپ کی طرف سے ہوگا اور میں آپ کو کوئی زحمت نہیں دینا چاہتا ہوں انشائ اللہ آپ مجھے نیک بندوں میں سے پائیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxx{موسٰی نے کہا کہ یہ میرے اور آپ کے درمیان کا معاہدہ ہے میں جو مدّت بھی پوری کردوں میرے اوپر کوئی ذمہ داری نہیں ہوگی اور میں جو کچھ بھی کہہ رہاہوں اللہ اس کا گواہ ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxi{پھر جب موسٰی مدّت کو پورا کرچکے اور اپنے اہل کو لے کر چلے تو طور کی طرف سے ایک آگ نظر آئی انہوں نے اپنے اہل سے کہا کہ تم لوگ ٹھہرو میں نے ایک آگ دیکھی ہے شاید اس میں سے کوئی خبر لے آؤں یا کوئی چنگاری ہی لے آؤں کہ تم لوگ اس سے تاپنے کا کام لے سکو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxii{پھر جو اس آگ کے قریب آئے تو وادی کے داہنے رخ سے ایک مبارک مقام پر ایک درخت سے آوز آئی موسٰی میں عالمین کا پالنے والا خدا ہوں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiii{اور تم اپنے عصا کو زمین پر ڈال دو اور جو موسٰی نے دیکھا تو وہ سانپ کی طرح لہرا رہا تھا یہ دیکھ کر موسٰی پیچھے ہٹ گئے اور پھر مڑ کر بھی نہ دیکھا تو پھر آواز آئی کہ موسٰی آگے بڑھو اور ڈرو نہیں کہ تم بالکل مامون و محفوظ ہو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiv{ذرا اپنے ہاتھ کو گریبان میں داخل کرو وہ بغیر کسی بیماری کے سفید اور چمکدار بن کر برآمد ہوگا اور خوف سے اپنے بازوؤں کو اپنی طرف سمیٹ لو - تمہارے لئے پروردگار کی طرف سے فرعون اور اس کی قوم کے سرداروں کی طرف یہ دو دلیلیں ہیں کہ یہ لوگ سب فاسق اور بدکار ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxv{موسٰی نے کہا کہ پروردگار میں نے ان کے ایک آدمی کو مار ڈالا ہے تو مجھے خوف ہے کہ یہ مجھے قتل کردیں گے اور کار تبلیغ رک جائے گا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvi{اور میرے بھائی ہارون مجھ سے زیادہ فصیح زبان کے مالک ہیں لہٰذا انہیں میرے ساتھ مددگار بنادے جو میری تصدیق کرسکیں کہ میں ڈرتا ہوں کہ کہیں یہ لوگ میری تکذیب نہ کردیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvii{ارشاد ہوا کہ ہم تمہارے بازؤں کو تمہارے بھائی سے مضبوط کردیں گے اور تمہارے لئے ایسا غلبہ قرار دیں گے کہ یہ لوگ تم تک پہنچ ہی نہ سکیں اور ہماری نشانیوں کے سہارے تم اور تمہارے پیروکار ہی غالب رہیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxviii{پھر جب موسٰی ان کے پاس ہماری کھلی ہوئی نشانیاں لے کر آئے تو ان لوگوں نے کہہ دیا کہ یہ تو صرف ایک گڑھا ہوا جادو ہے اور ہم نے اپنے گزشتہ بزرگوں سے اس طرح کی کوئی بات نہیں سنی ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxix{اور موسٰی نے کہا کہ میرا پروردگار بہتر جانتا ہے کہ کون اس کی طرف سے ہدایت لے کر آیا ہے اور کس کے لئے آخرت کا گھر ہے یقینا ظالمین کے لئے فلاح نہیں ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccxc{اور فرعون نے کہا کہ میرے زعما ئ مملکت! میرے علم میں تمہارے لئے میرے علاوہ کوئی خدا نہیں ہے لہٰذا ہامان! تم میرے لئے مٹی کا پجاوا لگاؤ اور پھر ایک قلعہ تیار کرو کہ میں اس پر چڑھ کر موسٰی کے خدا کی خبر لے آؤں اور میرا خیال تو یہ ہی ہے کہ موسٰی جھوٹے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccxci{اور فرعون اور اس کے لشکر نے ناحق غرور سے کام لیا اور یہ خیال کرلیا کہ وہ پلٹا کر ہماری بارگاہ میں نہیں لائے جائیں گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccxcii{تو ہم نے فرعون اور اس کے لشکروں کو اپنی گرفت میں لے لیا اور سب کو دریا میں ڈال دیا تو دیکھو کہ ظالمین کا انجام کیسا ہوتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccxciii{اور ہم نے ان لوگوں کوجہّنم کی طرف دعوت دینے والا پیشوا قرار د ے دیا ہے اور قیامت کے دن ان کی کوئی مدد نہیں کی جائے گی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccxciv{اور دنیا میں بھی ہم نے ان کے پیچھے لعنت کو لگادیا ہے اور قیامت کے دن بھی ان کا شمار ان لوگوں میں ہوگا جن کے چہرے بگاڑ دیئے جائیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccxcv{اور ہم نے پہلی نسلوں کو ہلاک کردینے کے بعد موسٰی کو کتاب عطا کی جو لوگوں کے لئے بصیرت کا سامان اور ہدایت و رحمت ہے اور شاید اسی طرح یہ لوگ نصیحت حاصل کرلیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvi{اور آپ اس وقت طور کے مغربی رخ پر نہ تھے جب ہم نے موسٰی کی طرف اپنا حکم بھیجا اور آپ اس واقعہ کے حاضرین میں سے بھی نہیں تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccxcvii{لیکن ہم نے بہت سی قوموں کو پیدا کیا پھر ان پر ایک طویل زمانہ گزر گیا اور آپ تو اہل مدین میں بھی مقیم نہیں تھے کہ انہیں ہماری آیتیں پڑھ کر سناتے لیکن ہم رسول بنانے والے توتھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccxcviii{اور آپ طِور کے کسی جانب اس وقت نہیں تھے جب ہم نے موسٰی کو آواز دی لیکن آپ کے پروردگار کی رحمت ہے کہ آپ اس قوم کو ڈرائیں جس کی طرف آپ سے پہلے کوئی پیغمبر نہیں آیا ہے کہ شاید وہ اس طرح عبرت اور نصیحت حاصل کرلیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccxcix{اور اگر ایسا نہ ہوتا کہ جب ان پر گذشتہ اعمال کی بنا پر کوئی مصیبت نازل ہوتی تو یہی کہتے کہ پروردگار تو نے ہماری طرف کوئی رسول کیوں نہیں بھیجا ہے کہ ہم تیری نشانیوں کی پیروی کرتے اور صاحبان ایمان میں شامل ہوجاتے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccc{پھر اس کے بعد جب ہماری طرف سے حق آگیا تو کہنے لگے کہ انہیں وہ سب کیوں نہیں دیا گیا ہے جو موسٰی کو دیا گیا تھا تو کیا ان لوگوں نے اس سے پہلے موسٰی کا انکار نہیں کیا اور اب تو کہتے ہیں کہ توریت اور قرآن جادو ہے جو ایک دوسرے کی تائید کرتے ہیں اور ہم دونوں ہی کا انکار کرنے والے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccci{تو آپ کہہ دیجئے کہ اچھا تم پروردگار کی طرف سے کوئی کتاب لے آؤ جو دونوں سے زیادہ صحیح ہو اور میں اس کا اتباع کرلوں اگر تم اپنی بات میں سچے ہو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccii{پھر اگر قبول نہ کریں تو سمجھ لیجئے کہ یہ صرف اپنی خواہشات کا اتباع کرنے والے ہیں اور اس سے زیادہ گمراہ کون ہے جو خدائی ہدایت کے بغیر اپنی خواہشات کا اتباع کرلے جب کہ اللہ ظالم قوم کی ہدایت کرنے والا نہیں ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmccciii{اور ہم نے مسلسل ان لوگوں تک اپنی باتیں پہنچائیں کہ شاید اسی طرح نصیحت حاصل کرلیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmccciv{جن لوگوں کو ہم نے اس سے پہلے کتاب دی ہے وہ اس قرآن پر ایمان رکھتے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccv{اور جب ان کے سامنے اس کی تلاوت کی جاتی ہے تو کہتے ہیں کہ ہم ایمان لے آئے یہ ہمارے رب کی طرف سے برحق ہے اور ہم تو پہلے ہی سے تسلیم کئے ہوئے تھے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccvi{یہی وہ لوگ ہیں جن کو دہری جزا دی جائے گی کہ انہوں نے صبر کیا ہے اور یہ نیکیوں کے ذریعہ برائیوں کو دفع کرتے ہیں اور ہم نے جو رزق دیا ہے اس میں سے خرچ کرتے ہیں\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccvii{اور جب لغو بات سنتے ہیں تو کنارہ کشی اختیار کرتے ہیں اور کہتے ہیں کہ ہمارے لئے ہمارے اعمال ہیں اور تمہارے لئے تمہارے اعمال ہیں تم پر ہمارا سلام کہ ہم جاہلوں کی صحبت پسند نہیں کرتے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccviii{پیغمبر بیشک آپ جسے چاہیں اسے ہدایت نہیں دے سکتے ہیں بلکہ اللہ جسے چاہتا ہے ہدایت دے دیتا ہے اور وہ ان لوگوں سے خوب باخبر ہے جو ہدایت پانے والے ہیں\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccix{اور یہ کفاّر کہتے ہیں کہ ہم آپ کے ساتھ حق کی پیروی کریں گے تو اپنی زمین سے اچک لئے جائیں گے تو کیا ہم نے انہیں ایک محفوظ حرم پر قبضہ نہیں دیا ہے جس کی طرف ہر شے کے پھل ہماری دی ہوئی روزی کی بنا پر چلے آرہے ہیں لیکن ان کی اکثریت سمجھتی ہی نہیں ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccx{اور ہم نے کتنی ہی بستیوں کو ان کی معیشت کے غرور کی بنا پر ہلاک کردیا اب یہ ان کے مکانات ہیں جو ان کے بعد پھر آباد نہ ہوسکے مگر بہت کم اور درحقیقت ہم ہی ہر چیز کے وارث اور مالک ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxi{اور آپ کا پروردگار کسی بستی کو ہلاک کرنے والا نہیں ہے جب تک کہ اس کے مرکزمیں کوئی رسول نہ بھیج دے جو ان کے سامنے ہماری آیات کی تلاوت کرے اور ہم کسی بستی کے تباہ کرنے والے نہیں ہیں مگر یہ کہ اس کے رہنے والے ظالم ہوں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcccxii{اور جو کچھ بھی تمہیں عطا کیا گیا ہے یہ چند روزہ لذت هدنیا اور زینت هدنیا ہے اور جو کچھ بھی خدا کی بارگاہ میں ہے وہ خیر اور باقی رہنے والا ہے کیا تم اتنا بھی نہیں سمجھتے ہو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiii{کیا وہ بندہ جس سے ہم نے بہترین وعدہ کیا ہے اور وہ اسے پا بھی لے گا اس کے مانند ہے جسے ہم نے دنیا میں تھوڑی سی لذّت دے دی ہے اور پھر وہ روزہ قیامت خدا کی بارگاہ میں کھینچ کر حاضر کیا جائے گا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcccxiv{جس دن خدا ان لوگوں کو آواز دے گا کہ میرے وہ شرکائ کہاں ہیں جن کی شرکت کا تمہیں خیال تھا\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcccxv{تو جن شرکائ پر عذاب ثابت ہوچکا ہوگا وہ کہیں گے کہ پروردگار یہ ہیں وہ لوگ جن کو ہم نے گمراہ کیا ہے اور اسی طرح گمراہ کیا ہے جس طرح ہم خود گمراہ ہوئے تھے لیکن اب ان سے برائت چاہتے ہیں یہ ہماری عبادت تو نہیں کررہے تھے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvi{تو کہا جائے گا کہ اچھا اپنے شرکائ کو پکارو تو وہ پکاریں گے لیکن کوئی جواب نہ پائیں گے بلکہ عذاب ہی کو دیکھیں گے تو کاش یہ دنیا ہی میں ہدایت یافتہ ہوجاتے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcccxvii{اور جس دن خدا ان سے پکار کر کہے گا کہ تم نے ہمارے رسولوں کو کیا جواب دیا تھا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcccxviii{تو ان پر ساری خبریں تاریک ہوجائیں گی اور وہ آپس میں ایک دوسرے سے سوال بھی نہ کرسکیں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcccxix{لیکن جس نے توبہ کرلی اور ایمان لے آیا اور نیک عمل کیا وہ یقینا فلاح پانے والوں میں شمار ہوجائے گا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcccxx{اور آپ کا پروردگار جسے چاہتا ہے پیدا کرتا ہے اور پسندکرتا ہے - ان لوگوں کو کسی کا انتخاب کرنے کا کوئی حق نہیں ہے - خدا ان کے شرک سے پاک اور بلند و برتر ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxi{اور آپ کا پروردگار ان چیزوں کو بھی جانتا ہے جو یہ اپنے سینوں میں چھپائے ہوئے ہیں اور انہیں بھی جانتا ہے جن کا یہ اعلان و اظہار کرتے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxii{وہ اللہ ہے جس کے علاوہ کوئی دوسرا خدا نہیں ہے اور اول و آخر اور دنیا و آخرت میں ساری حمد اسی کے لئے ہے اسی کے لئے حکم ہے اور اسی کی طرف تم سب کو واپس جانا پڑے گا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiii{آپ کہئے کہ تمہارا کیا خیال ہے اگر خدا تمہارے لئے رات کو قیامت تک کے لئے ابدی بنادے تو کیا اس کے علاوہ اور کوئی معبود ہے جو تمہارے لئے روشنی کو لے آسکے تو کیا تم بات سنتے نہیں ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiv{اور کہئے کہ اگر وہ دن کو قیامت تک کے لئے دائمی بنادے تو اس کے علاوہ کون معبود ہے - جوتمہارے لئے وہ رات لے آئے گا جس میں سکون حاصل کرسکو کیا تم دیکھتے نہیں ہو\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxv{یہ اس کی رحمت کا ایک حصہّ ہے کہ اس نے تمہارے لئے رات اور دن دونوں بنائے ہیں تاکہ آرام بھی کرسکو اور رزق بھی تلاش کرسکو اور شاید اس کا شکریہ بھی ادا کرسکو\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvi{اور قیامت کے دن خدا انہیں آواز دے گا کہ میرے وہ شریک کہاں ہیں جن کی شرکت کا تمہیں خیال تھا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvii{اور ہم ہر قوم میں سے ایک گواہ نکال کر لائیں گے اور منکرین سے کہیں گے کہ تم بھی اپنی دلیل لے آؤ تب انہیں معلوم ہوگا کہ حق اللہ ہی کے لئے ہے اور پھر وہ جو افترا پردازیاں کیا کرتے تھے وہ سب گم ہوجائیں گی\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxviii{بیشک قارون موسٰی کی قوم میں سے تھا مگر اس نے قوم پر ظلم کیا اور ہم نے بھی اسے اتنے خزانے دے دیئے تھے کہ ایک طاقت ور جماعت سے بھی اس کی کنجیاں نہیں اٹھ سکتی تھیں پھر جب اس سے قوم نے کہا کہ اس قدر نہ اتراؤ کہ خدا اترانے والوں کو دوست نہیں رکھتا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxix{اور جو کچھ خدا نے دیا ہے اس سے آخرت کے گھر کا انتظام کرو اور دنیا میں اپنا حصّہ بھول نہ جاؤ اور نیکی کرو جس طرح کہ خدا نے تمہارے ساتھ نیک برتاؤ کیا ہے اور زمین میں فساد کی کوشش نہ کرو کہ اللہ فساد کرنے والوں کو دوست نہیں رکھتا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxx{قارون نے کہا کہ مجھے یہ سب کچھ میرے علم کی بنا پر دیا گیا ہے تو کیا اسے یہ معلوم نہیں ہے کہ اللہ نے اس سے پہلے بہت سی نسلوں کو ہلاک کردیا ہے جو اس سے زیادہ طاقتور اور مال کے اعتبار سے دولت مند تھیں اور ایسے مجرموں سے تو ان کے گناہوں کے بارے میں سوال بھی نہیں کیا جاتا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxi{پھر قارون اپنی قوم کے سامنے زیب و زینت کے ساتھ برآمد ہوا تو جن لوگوں کے دل میں زندگانی دنیا کی خواہش تھی انہوںنے کہنا شروع کردیا کہ کاش ہمارے پاس بھی یہ ساز و سامان ہوتا جو قارون کو دیا گیا ہے یہ تو بڑے عظیم حصہ ّ کا مالک ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxii{اور جنہیں علم دیا گیا تھا انہوں نے کہا کہ افسوس تمہارے حال پر - اللرُ کا ثواب صاحبان هایمان و عمل صالح کے لئے اس سے کہیں زیادہ بہتر ہے اور وہ ثواب صبر کرنے والوں کے علاوہ کسی کو نہیں دیا جاتا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiii{پھر ہم نے اسے اور اس کے گھر بار کو زمین میں دھنسا دیا اور نہ کوئی گروہ خدا کے علاوہ بچانے والا پیدا ہوا اور نہ وہ خود اپنا بچاؤ کرنے والا تھا\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiv{اور جن لوگوں نے کل اس کی جگہ کی تمناّ کی تھی وہ کہنے لگے کہ معاذ اللہ یہ تو خدا جس بندے کے لئے چاہتا ہے اس کے رزق میں وسعت پیدا کردیتا ہے اور جس کے یہاں چاہتا ہے تنگی پیدا کردیتا ہے اور اگر اس نے ہم پر احسان نہ کردیا ہوتا تو ہمیں بھی دھنسا دیا ہوتا معاذاللرُ کافروں کے لئے واقعا فلاح نہیں ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxv{یہ دا» آخرت وہ ہے جسے ہم ان لوگوں کے لئے قرار دیتے ہیں جو زمین میں بلندی اور فساد کے طلبگار نہیں ہوتے ہیں اور عاقبت تو صرف صاحبانِ تقویٰ کے لئے ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvi{جو کوئی نیکی کرے گا اسے اس سے بہتر اجر ملے گا اور جو کوئی برائی کرے گا تو برائی کرنے والوں کو اتنی ہی سزادی جائے گی جیسے اعمال وہ کرتے رہے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvii{بیشک جس نے آپ پر قرآن کا فریضہ عائد کیا ہے وہ آپ کو آپ کی منزل تک ضرور واپس پہنچائے گا .آپ کہہ دیجئے کہ میرا پروردگار بہتر جانتا ہے کہ کون ہدایت لے کر آیا ہے اور کون کھلی ہوئی گمراہی میں ہے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxviii{اور آپ تو اس بات کے امیدوار نہیں تھے کہ آپ کی طرف کتاب نازل کی جائے یہ تو رحمت هپروردگار ہے لہذا خبردار آپ کافروں کا ساتھ نہ دیجئے گا\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxix{اور ہرگز یہ لوگ آیات کے نازل ہونے کے بعد ان کی تبلیغ سے آپ کو روکنے نہ پائیں اور آپ اپنے رب کی طرف دعوت دیجئے اور خبردار مشرکین میں سے نہ ہوجایئے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmcccxl{اور اللہ کے ساتھ کسی دوسرے خدا کو مت پکارو کہ اس کے علاوہ کوئی معبود نہیں ہے . اس کی ذات کے ماسوا ہر شے ہلاک ہونے والی ہے اور تم سب اسی کی بارگاہ کی طرف پلٹائے جاؤ گے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmcccxli{\basmalahur المۤ ۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlii{کیا لوگوں نے یہ خیال کر رکھا ہے کہ وہ صرف اس بات پر چھوڑ دیئے جائیں گے کہ وہ یہ کہہ دیں کہ ہم ایمان لے آئے ہیں اور ان کا امتحان نہیں ہوگا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliii{بیشک ہم نے ان سے پہلے والوں کا بھی امتحان لیا ہے اور اللہ تو بہرحال یہ جاننا چاہتا ہے کہ ان میں کون لوگ سچے ہیں اور کون جھوٹے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcccxliv{کیا برائی کرنے والوں کا خیال یہ ہے کہ ہم سے آگے نکل جائیں گے یہ بہت غلط فیصلہ کررہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlv{جو بھی اللہ کی ملاقات کی امید رکھتا ہے اسے معلوم رہے کہ وہ مدّت یقینا آنے والی ہے اور وہ خدا سمیع بھی ہے اور علیم بھی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvi{اور جس نے بھی جہاد کیا ہے اس نے اپنے لئے جہاد کیا ہے اور اللہ تو سارے عالمین سے بے نیاز ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvii{اور جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ہم یقینا ان کے گناہوں کی پردہ پوشی کریں گے اور انہیں ان کے اعمال کی بہترین جزا عطا کریں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlviii{اور ہم نے انسان کو ماں باپ کے ساتھ نیک برتاؤ کرنے کی نصیحت کی ہے اور بتایا ہے کہ اگر وہ کسی ایسی شے کو میرا شریک بنانے پر مجبور کریں جس کا تمہیں علم نہیں ہے تو خبردار ان کی اطاعت نہ کرنا کہ تم سب کی بازگشت میری ہی طرف ہے پھر میں بتاؤں گا کہ تم لوگ کیا کررہے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcccxlix{اور جن لوگوں نے ایمان اختیار کیا اور نیک اعمال کئے ہم یقینا انہیں نیک بندوں میں شامل کرلیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcccl{اور بعض لوگ ایسے ہیں جو کہتے ہیں کہ ہم اللہ پر ایمان لے آئے اس کے بعد جب راسِ خدا میں کوئی تکلیف ہوئی تو لوگوں کے فتنہ کو عذابِ خدا جیسا قرار دے دیا حالانکہ آپ کے پروردگار کی طرف سے کوئی مدد آجاتی تو فورا کہہ دیتے کہ ہم تو آپ ہی کے ساتھ تھے تو کیا خدا ان باتوں سے باخبر نہیں ہے جو عالمین کے دلوں میں ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcccli{اور وہ یقینا انہیں بھی جاننا چاہتا ہے جو صاحبانِ ایمان ہیں اور انہیں بھی جاننا چاہتا ہے جو منافق ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmccclii{اور یہ کفّار ایمان لانے والوں سے کہتے ہیں کہ تم ہمارے راستہ کا اتباع کرلو ہم تمہارے گناہوں کے ذمہ دار ہیں حالانکہ وہ کسی کے گناہوں کا بوجھ اٹھانے والے نہیں ہیں اور سراسر جھوٹے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcccliii{اور انہیں ایک دن اپنا بوجھ بھی اٹھانا ہی پڑے گا اور اس کے ساتھ ان لوگوں کا بھی اور روز ه قیامت ان سے ان باتوں کے بارے میں سوال بھی کیا جائے گا جن کا یہ افترا کیا کرتے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcccliv{اور ہم نے نوح علیھ السّلامکو ان کی قوم کی طرف بھیجا اور وہ ان کے درمیان پچاس سال کم ایک ہزار سال رہے پھر قوم کو طوفان نے اپنی گرفت میں لے لیا کہ وہ لوگ ظالم تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmccclv{پھر ہم نے نوح علیھ السّلام کو اور ان کے ساتھ کشتی والوں کو نجات دے دی اور اسے عالمین کے لئے ایک نشانی قرار دے دیا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmccclvi{اور ابراہیم کو یاد کرو جب انہوں نے اپنی قوم سے کہا کہ اللہ کی عبادت کرو اور اس سے ڈرو کہ اسی میں تمہارے لئے بہتری ہے اگر تم کچھ جانتے ہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmccclvii{تم خدا کو چھوڑ کر صرف بتوں کی پرستش کرتے ہو اور اپنے پاس سے جھوٹ گڑھتے ہو یاد رکھو کہ خدا کے علاوہ جن کی بھی پرستش کرتے ہو وہ تمہارے رزق کے مالک نہیں ہیں رزق خدا کے پاس تلاش کرو اور اسی کی عبادت کرو اسی کا شکریہ ادا کرو کہ تم سب اسی کی بارگاہ میں واپس لے جائے جاؤ گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmccclviii{اور اگر تم تکذیب کرو گے تو تم سے پہلے بہت سی قومیں یہ کام کرچکی ہیں اور رسول کی ذمہ داری تو صرف واضح طور پر پیغام کا پہنچا دینا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmccclix{کیا ان لوگوں نے نہیں دیکھا کہ خدا کس طرح مخلوقات کو ایجاد کرتا ہے اور پھر دوبارہ واپس لے جاتا ہے یہ سب اللہ کے لئے بہت آسان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmccclx{آپ کہہ دیجئے کہ تم لوگ زمین میں سیر کرو اور دیکھو کہ خدا نے کس طرح خلقت کا آغاز کیا ہے اس کے بعد وہی آخرت میں دوبارہ ایجاد کرے گا بیشک وہی ہر شے پر قدرت رکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmccclxi{وہ جس پر چاہتا ہے عذاب کرتا ہے اور جس پر چاہتا ہے رحم کرتا ہے اور تم سب اسی کی طرف پلٹائے جاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmccclxii{اور تم زمین یا آسمان میں اسے عاجز کرسکنے والے نہیں ہو اور اس کے علاوہ تمہارا کوئی سرپرست یا مددگار بھی نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiii{اور جو لوگ خدا کی نشانیوں اور اس کی ملاقات کا انکار کرتے ہیں وہ میری رحمت سے مایوس ہیں اور ان کے لئے دردناک عذاب ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmccclxiv{تو ان کی قوم کا جواب اس کے علاوہ کچھ نہ تھا کہ انہیں قتل کردو یا آگ میں جلا دو ...._ تو پروردگار نے انہیں اس آگ سے نجات دلادی بیشک اس میں بھی صاحبان هایمان کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmccclxv{اور ابراہیم نے کہا کہ تم نے صرف زندگانی دنیا کی محبتوں کو برقرار رکھنے کے لئے خدا کو چھوڑ کر بتوں کو اختیار کرلیا ہے اس کے بعد روز هقیامت تم میں سے ہر ایک دوسرے کا انکار کرے گا اور ایک دوسرے پر لعنت کرے گا جب کہ تم سب کا انجام جہّنم ہوگا اور تمہارا کوئی مددگار نہ ہوگا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvi{پھر لوط ابراہیم پر ایمان لے آئے اور انہوں نے کہا کہ میں اپنے رب کی طرف ہجرت کررہا ہوں کہ وہی صاحب هعزّت اور صاحب حکمت ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmccclxvii{اور ہم نے انہیں اسحاق اور یعقوب جیسی اولاد عطا کی اور پھر ان کی ذریت میں کتاب اور نبوت قرار دی اور انہیں دنیا میں بھی ان کا اجر عطا کیا اور آخرت میں بھی ان کا شمار نیک کردار لوگوں میں ہوگا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmccclxviii{اور پھر لوط کو یاد کرو جب انہوں نے اپنی قوم سے کہا کہ تم لوگ ایسی بدکاری کررہے ہو جو سارے عالم میں تم سے پہلے کبھی کسی نے بھی نہیں کی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmccclxix{تم لوگ مذِدوں سے جنسی تعلّقات پیدا کررہے ہو اور راستے قطع کررہے ہو اور اپنی محفلوں میں برائیوں کو انجام دے رہے ہو .... تو ان کی قوم کے پاس اس کے علاوہ کوئی جواب نہ تھا کہ اگر تم صادقین میں سے ہو تو وہ عذاب هالٰہی لے آؤ جس کی خبر دے رہے ہو\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmccclxx{تو لوط نے کہا پروردگار تو اس فساد پھیلانے والی قوم کے مقابلہ میں میری مدد فرما\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxi{اور جب ہمارے نمائندہ فرشتے ابراہیم کے پاس بشارت لے کر آئے اور انہوں نے یہ خبر سنائی کہ ہم اس بستی والوں کو ہلاک کرنا چاہتے ہیں کہ اس بستی کے لوگ بڑے ظالم ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxii{تو ابراہیم نے کہا کہ اس میں تو لوط بھی ہیں - انہوں نے جواب دیا کہ ہم سب سے باخبر ہیں - ہم انہیں اور ان کے گھر والوں کو نجات دے دیں گے علاوہ ان کی زوجہ کے کہ وہ پیچھے رہ جانے والوں میں ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiii{پھر جب ہمارے فرشتے لوط کے پاس آئے تو وہ پریشان ہوگئے اور ان کی مہمانی کی طرف سے دل تنگ ہونے لگے ان لوگوں نے کہا کہ آپ ڈریں نہیں اور پریشان نہ ہوں ہم آپ کو اور آپ کے گھر والوں کو بچالیں گے صرف آپ کی زوجہ کو نہیں کہ وہ پیچھے رہ جانے والوں میں ہوگئی ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiv{ہم اس بستی پر آسمان سے عذاب نازل کرنے والے ہیں کہ یہ لوگ بڑی بدکاری کررہے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxv{اور ہم نے اس بستی میں سے صاحبانِ عقل و ہوش کے لئے کِھلی ہوئی نشانی باقی رکھی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvi{اور ہم نے مدین کی طرف ان کے بھائی شعیب کو بھیجا تو انہوں نے کہا کہ لوگو اللہ کی عبادت کرو اور روزِ آخرت سے امیدیں وابستہ کرو اور خبردار زمین میں فساد نہ پھیلاتے پھرو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvii{تو ان لوگوں نے انہیں جھٹلادیا اور نتیجہ میں انہیں ایک زلزلے نے اپنی گرفت میں لے لیا اور وہ اپنے گھروں میں اوندھے زانو کے بل پڑے رہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxviii{اور عاد و ثمود کو یاد کرو کہ تم لوگوں کے لئے ان کے گھر بھی س»راہ واضح ہوچکے ہیں اور شیطان نے ان کے لئے ان کے اعمال کو آراستہ کردیا تھا اور انہیں راستہ سے روک دیا تھا حالانکہ وہ لوگ بہت ہوشیار تھے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxix{اور قارون فرعون و ہامان کو بھی یاد دلاؤ جن کے پاس موسٰی کھنَی جوئی نشانیاں لے کر آئے تو ان لوگوں نے زمین میں استکبار سے کام لیا حالانکہ وہ ہم سے آگے جانے والے نہیں تھے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxx{پھر ہم نے ہر ایک کو اس کے گناہ میں گرفتار کرلیا کسی پر آسمان سے پتھروں کی بارش کردی کسی کو ایک آسمانی چیخ نے پکڑ لیا اور کسی کو زمین میں دھنسا دیا اور کسی کو پانی میں غرق کردیا اور اللہ کسی پر ظلم کرنے والا نہیں ہے بلکہ یہ لوگ خود اپنے نفس پر ظلم کررہے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxi{اور جن لوگوں نے خدا کو چھوڑ کر دوسرے سرپرست بنالئے ہیں ان کی مثال مکڑی جیسی ہے کہ اس نے گھر تو بنالیا لیکن سب سے کمزور گھر مکڑی کا گھر ہوتا ہے اگر ان لوگوں کے پاس علم و ادراک ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxii{بیشک اللہ خوب جانتا ہے کہ اسے چھوڑ کر یہ لوگ کسے پکار رہے ہیں اور وہ بڑی عزّت والا اور صاحبِ حکمت ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiii{اور یہ مثالیں ہم تمام عالم هانسانیت کے لئے بیان کر رہے ہیں لیکن انہیں صاحبانِ علم کے علاوہ کوئی نہیں سمجھ سکتا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiv{اللرُ نے آسمان اور زمین کو حق کے ساتھ پیدا کیا ہے اور اس میں صاحبان هایمان کے لئے اس کی قدرت کی نشانی پائی جاتی ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxv{آپ جس کتاب کی آپ کی طرف وحی کی گئی ہے اسے پڑھ کر سنائیں اور نماز قائم کریں کہ نماز ہر برائی اور بدکاری سے روکنے والی ہے اور اللہ کا ذکر بہت بڑی شے ہے اور اللہ تمہارے کاروبار سے خوب باخبر ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvi{اور اہلِ کتاب سے مناطرہ نہ کرو مگر اس انداز سے جو بہترین انداز ہے علاوہ ان سے جو ان میں سے ظالم ہیں اور یہ کہو کہ ہم اس پر ایمان لائے ہیں جو ہماری اور تمہاری دونوں کی طرف نازل ہوا ہے اور ہمارا اور تمہارا خدا ایک ہی ہے اور ہم سب اسی کے اطاعت گزار ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvii{اور اسی طرح ہم نے آپ کی طرف کتاب نازل کی تو جن لوگوں کو ہم نے کتاب دی ہے وہ اس کتاب پر ایمان رکھتے ہیں اور ِن میں سے بھی بعض لوگ ایمان رکھتے ہیں اور ہماری آیات کا انکار کافروں کے علاوہ کوئی نہیں کرتا ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxviii{اور اے پیغمبر آپ اس قرآن سے پہلے نہ کوئی کتاب پڑھتے تھے اور نہ اپنے ہاتھ سے کچھ لکھتے تھے ورنہ یہ اہل باطل شبہ میں پڑ جاتے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxix{درحقیقت یہ قرآن چند کھلی ہوئی آیتوں کا نام ہے جو ان کے سینوں میں محفوظ ہیں جنہیں علم دیا گیا ہے اور ہماری آیات کا انکار ظالموں کے علاوہ کوئی نہیں کرتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcccxc{اور یہ لوگ کہتے ہیں کہ آخر ان پر پروردگار کی طرف سے آیات کیوں نہیں نازل ہوتی ہیں تو آپ کہہ دیجئے کہ آیات سب اللہ کے پاس ہیں اور میں تو صرف واضح طور پر عذاب هالہٰی سے ڈرانے والا ہوں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcccxci{کیا ان کے لئے یہ کافی نہیں ہے کہ ہم نے آپ پر کتاب نازل کی ہے جس کی ان کے سامنے تلاوت کی جاتی ہے اور یقینا اس میںرحمت اور ایماندار قوم کے لئے یاددہانی کا سامان موجود ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcii{آپ کہہ دیجئے کہ ہمارے اور تمہارے درمیان گواہی کے لئے خدا کافی ہے جو آسمان اور زمین کی ہر چیز سے باخبر ہے اور جو لوگ باطل پر ایمان رکھتے ہیں اور اللہ کا انکار کرتے ہیں وہ یقینا خسارہ اٹھانے والے لوگ ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciii{اور یہ لوگ عذاب کی جلدی کررہے ہیں حالانکہ اگر اس کا وقت معین نہ ہوتا تو اب تک عذاب آچکا ہوتا اور وہ اچانک ہی آئے گا جب انہیں شعور بھی نہ ہوگا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcccxciv{یہ عذاب کی جلدی کررہے ہیں حالانکہ جہّنم یقینا کافروں کو اپنے گھیرے میں لینے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcv{جس دن عذاب انہیں اوپر سے اور نیچے سے ڈھانک لے گا اور کہے گا کہ اب اپنے اعمال کا مزہ چکھو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvi{میرے ایماندار بندو! میری زمین بہت وسیع ہے لہٰذامیری ہی عبادت کرو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvii{ہر نفس موت کا مزہ چکھنے والاہے اس کے بعد تم سب ہماری بارگاہ میں پلٹا کر لائے جاؤ گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcviii{اور جو لوگ ایمان لائے ہیں اور انہوں نے نیک اعمال کئے ہیں انہیں ہم جنّت کے جھروکوں میں جگہ دیں گے جن کے نیچے نہریں جاری ہوں گی اور وہ ہمیشہ ان ہی میں رہیں گے کہ یہ ان عمل کرنے والوں کا بہترین اجر ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcccxcix{جن لوگوں نے صبر کیا ہے اور اپنے پروردگار پر بھروسہ کرتے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcd{اور زمین پر چلنے والے بہت سے ایسے بھی ہیں جو اپنی روزی کا بوجھ نہیں اٹھاسکتے ہیں لیکن خدا انہیں اور تمہیں سب کو رزق دے رہا ہے وہ سب کی سننے والا اور سب کے حالات کا جاننے والا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdi{اور اگر آپ ان سے پوچھیں گے کہ آسمان و زمین کو کس نے پیدا کیا ہے اور آفتاب و ماہتاب کو کس نے لَسخّر کیا ہے تو فورا کہیں گے کہ اللہ,تو یہ کدھر بہکے چلے جارہے ہیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmcdii{اللرُ ہی جس کے رزق میں چاہتا ہے وسعت پیدا کردیتا ہے اور جس کے رزق کو چاہتا ہے تنگ کردیتا ہے وہ ہر شے کا خوب جاننے والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmcdiii{اور اگر آپ ان سے پوچھیں گے کس نے آسمان سے پانی برسایا ہے اور پھر زمین کو مفِدہ ہونے کے بعد زندہ کیا ہے تو یہ کہیں گے کہ اللہ ہی ہے تو پھر کہہ دیجئے کہ ساری حمد اللہ کے لئے ہے اور ان کی اکثریت عقل استعمال نہیں کررہی ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmcdiv{اور یہ زندگانی دنیا ایک کھیل تماشے کے سوا کچھ نہیں ہے اور آخرت کا گھر ہمیشہ کی زندگی کا مرکز ہے اگر یہ لوگ کچھ جانتے اور سمجھتے ہوں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmcdv{پھر جب یہ لوگ کشتی میں سوار ہوتے ہیں تو ایمان و عقیدہ کے پورے اخلاص کے ساتھ خدا کو پکارتے ہیں پھر جب وہ نجات دے کر خشکی تک پہنچادیتا ہے تو فورا شرک اختیار کرلیتے ہیں\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmcdvi{تاکہ جو کچھ ہم نے عطا کیا ہے اس کا انکار کردیں اور دنیا میں مزے اُڑائیں تو عنقریب انہیں اس کا انجام معلوم ہوجائے گا\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmcdvii{کیا ان لوگوں نے نہیں دیکھا کہ ہم نے ان کے واسطے ایک محفوظ حرم بنادیا ہے جس کے چاروں طرف لوگ اچک لئے جاتے ہیں تو کیا یہ باطل پر ایمان رکھتے ہیں اور اللہ کی نعمت کا انکار کردیتے ہیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmcdviii{اور اُس سے بڑا ظالم کون ہے جو اللہ کی طرف جھوٹی باتوں کی نسبت دے یا حق کے آجانے کے بعد بھی اس کا انکار کردے تو کیا جہّنم میں کفار کا ٹھکانا نہیں ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmcdix{اور جن لوگوں نے ہمارے حق میں جہاد کیا ہے ہم انہیں اپنے راستوں کی ہدایت کریں گے اور یقینا اللرُحسن عمل والوں کے ساتھ ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmcdx{\basmalahur الۤمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdxi{روم والے مغلوب ہوگئے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdxii{قریب ترین علاقہ میں لیکن یہ مغلوب ہوجانے کے بعد عنقریب پھر غالب ہوجائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiii{چند سال کے اندر ,اللہ ہی کے لئے اوّل و آخر ہر زمانہ کا اختیار ہے اور اسی دن صاحبانِ ایمان خوشی منائیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdxiv{اللرُکی نصرت و امداد کے سہارے کہ وہ جس کی امداد چاہتا ہے کردیتا ہے اور وہ صاحب هعزّت بھی ہے اور مہربان بھی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdxv{یہ اللہ کا وعدہ ہے اور اللہ اپنے وعدہ کے خلاف نہیں کرتا ہے مگر لوگوں کی اکثریت اس حقیقت سے بھی بے خبر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvi{یہ لوگ صرف زندگانی دنیا کے ظاہر کو جانتے ہیں اور آخرت کی طرف سے بالکل غافل ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdxvii{کیا ان لوگوں نے اپنے اندر فکر نہیں کی ہے کہ خدا نے آسمان و زمین اور اس کے درمیان کی تمام مخلوقات کو برحق ہی پیدا کیا ہے اور ایک معین مدّت کے ساتھ لیکن لوگوں کی اکثریت اپنے پروردگار کی ملاقات سے انکار کرنے والی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdxviii{اور کیا ان لوگوں نے زمین میں سیر نہیں کی ہے کہ دیکھتے کہ ان سے پہلے والوں کا کیا انجام ہوا ہے جو طاقت میں ان سے زیادہ مضبوط تھے اور انہوں نے زراعت کرکے زمین کو ان سے زیادہ آباد کرلیا تھا اور ان کے پاس ہمارے نمائندے زیادہ کِھلی ہوئی نشانیاں بھی لے کر آئے تھے یقینا خدا اپنے بندوں پر ظلم نہیں کرتا ہے بلکہ یہ لوگ خود ہی اپنے اوپر ظلم کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdxix{اس کے بعد برائی کرنے والوں کا انجام برا ہوا کہ انہوں نے خدا کی نشانیوں کو جھٹلادیا اور برابر ان کا مذاق اڑاتے رہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdxx{اللرُ ہی تخلیق کی ابتدائ کرتا ہے اور پھر پلٹا بھی دیتا ہے اور پھر تم سب اسی کی بارگاہ میں واپس لے جائے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxi{اور جس دن قیامت قائم کی جائے گی اس دن سارے مجرمین مایوس ہوجائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxii{اور ان کے شرکائ میں کوئی سفارش کرنے والا نہ ہوگا اور یہ خود بھی اپنے شرکائ کا انکار کرنے والے ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiii{اور جس دن قیامت قائم ہوگی سب لوگ آپس میں گروہوں میں تقسیم ہوجائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiv{پس جو ایمان والے اور نیک عمل والے ہوں گے وہ باگُ جنّت میں نہال اور خوشحال ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxv{اور جن لوگوں نے کفر اختیار کیا اور ہماری آیات اور روز آخرت کی ملاقات کی تکذیب کی وہ عذاب میں ضرور گرفتار کئے جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvi{لہذا تم لوگ تسبیح پروردگار کرو اس وقت جب شام کرتے ہو اور جب صبح کرتے ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvii{اور زمین و آسمان میں ساری حمد اسی کے لئے ہے اور عصر کے ہنگام اور جب دوپہر کرتے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxviii{وہ خدا زندہ کو مفِدہ سے اور مفِدہ کو زندہ سے نکالتا ہے اور زمین کو مردہ ہوجانے کے بعد پھر زندہ کرتا ہے اور اسی طرح ایک دن تمہیں بھی نکالا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxix{اور اس کی نشانیوں میں سے ایک یہ بھی ہے کہ اس نے تمہیں خاک سے پیدا کیا ہے اور اس کے بعد تم بشر کی شکل میں پھیل گئے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxx{اور اس کی نشانیوں میں سے یہ بھی ہے کہ اس نے تمہارا جوڑا تم ہی میں سے پیدا کیاہے تاکہ تمہیں اس سے سکون حاصل ہو اورپھر تمہارے درمیان محبت اور رحمت قرار دی ہے کہ اس میں صاحبانِ فکر کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxi{اور اس کی نشانیوں میں سے آسمان و زمین کی خلقت اور تمہاری زبانوں اور تمہارے رنگوں کا اختلاف بھی ہے کہ اس میں صاحبانِ علم کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxii{اور اس کی نشانیوں میں سے یہ بھی ہے کہ تم رات اور دن کو آرام کرتے ہو اور پھر فضل خدا کو تلاش کرتے ہو کہ اس میں بھی سننے والی قوم کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiii{اور اس کی نشانیوں میں سے یہ بھی ہے کہ وہ بجلی کو خوف اور امید کا مرکز بنا کر دکھلاتا ہے اور آسمان سے پانی برساتا ہے پھر اس کے ذریعہ مردہ زمین کو زندہ بناتا ہے بیشک اس میں بھی اس قوم کے لئے بہت سی نشانیاں ہیں جو عقل رکھنے والی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiv{اور اس کی نشانیوں میں سے یہ بھی ہے کہ آسمان و زمین اسی کے حکم سے قائم ہیں اور اس کے بعد وہ جب تم سب کو طلب کرے گا تو سب زمین سے یکبارگی برآمد ہوجائیں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxv{آسمان و زمین میں جو کچھ بھی ہے سب اسی کی ملکیت ہے اور سب اسی کے تابع فرمان ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvi{اور وہی وہ ہے جو خلقت کی ابتدا ئ کرتا ہے اور پھر دوبارہ بھی پیدا کرے گا اور یہ کام اس کے لئے بے حد آسان ہے اور اسی کے لئے آسمان اور زمین میں سب سے بہترین مثال ہے اور وہی سب پر غالب آنے والا اور صاحب هحکمت ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvii{اس نے تمہارے لئے تمہاری ہی مثال بیان کی ہے کہ جو رزق ہم نے تم کو عطا کیا ہے کیا اس میں تمہارے مملوک غلام و کنیز میں کوئی تمہارا شریک ہے کہ تم سب برابر ہوجاؤ اور تمہیں ان کا خوف اسی طرح ہو جس طرح اپنے نفوس کے بارے میں خوف ہوتا ہے ...._ بیشک ہم اپنی نشانیوں کو صاحب هعقل قوم کے لئے اسی طرح واضح کرکے بیان کرتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxviii{حقیقت یہ ہے کہ ظالموں نے بغیر جانے بوجھے اپنی خواہشات کا اتباع کرلیا ہے تو جس کو خدا گمراہی میں چھوڑ دے اسے کون ہدایت دے سکتا ہے اور ان کا تو کوئی ناصر و مددگار بھی نہیں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxix{آپ اپنے رخ کو دین کی طرف رکھیں اور باطل سے کنارہ کش رہیں کہ یہ دین وہ فطرت الہیۤ ہے جس پر اس نے انسانوں کو پیدا کیا ہے اور خلقت الہٰی میں کوئی تبدیلی نہیں ہوسکتی ہے یقینا یہی سیدھا اور مستحکم دین ہے مگر لوگوں کی اکثریت اس بات سے بالکل بے خبر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmcdxl{تم سب اپنی توجہ خدا کی طرف رکھو اور اسی سے ڈرتے رہو - نماز قائم کرو اور خبردار مشرکین میں سے نہ ہوجانا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmcdxli{ان لوگوں میں سے جنہوں نے دین میں تفرقہ پیدا کیا ہے اور گروہوں میں بٹ گئے ہیں پھر ہر گروہ جو کچھ اس کے پاس ہے اسی پر مست اور مگن ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlii{اور لوگوں کو جب بھی کوئی مصیبت چھوجاتی ہے تو وہ پروردگار کو پوری توجہ کے ساتھ پکارتے ہیں اس کے بعد جب وہ رحمت کا مزہ چکھا دیتا ہے تو ان میں سے ایک گروہ شرک کرنے لگتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliii{تاکہ جو کچھ ہم نے عطا کیا ہے اس کا انکار کردے تو تم مزے کرو اس کے بعد تو سب کو معلوم ہی ہوجائے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmcdxliv{کیا ہم نے ان کے اوپر کوئی دلیل نازل کی ہے جو ان سے ان کے شرک کے جواز کو بیان کرتی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlv{اور جب ہم انسانوں کو رحمت کا مزہ چکھادیتے ہیں تو وہ خوش ہوجاتے ہیں اور جب انہیں ان کے سابقہ کردار کی بنا پر کوئی تکلیف پہنچ جاتی ہے تو وہ مایوسی کا شکار ہوجاتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvi{تو کیا ان لوگوں نے نہیں دیکھا کہ خدا جس کے رزق میں چاہتا ہے وسعت پیدا کردیتا ہے اور جس کے یہاں چاہتا ہے کمی کردیتا ہے اور اس میں بھی صاحبِ ایمان قوم کے لئے اس کی نشانیاں ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvii{اور تم قرابتدار مسکین اور غربت زدہ مسافر کو اس کا حق دے دو کہ یہ ان لوگوں کے حق میں خیر ہے جو رضائے الہٰی کے طلب گار ہیں اور وہی حقیقتا نجات حاصل کرنے والے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlviii{اور تم لوگ جوبھی سود دیتے ہو کہ لوگوں کے مال میں اضافہ ہوجائے تو خدا کے یہاں کوئی اضافہ نہیں ہوتا ہے ہاں جو زکوِٰ دیتے ہو اور اس میں رضائے خدا کا ارادہ ہوتا ہے تو ایسے لوگوں کو دگنا چوگنا دے دیا جاتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmcdxlix{اللرُ ہی وہ ہے جس نے تم سب کو خلق کیا ہے پھر روزی دی ہے پھر موت دیتا ہے پھر زندہ کرتا ہے کیا تمہارے شرکائ میں کوئی ایسا ہے جو ان میں سے کوئی کام انجام دے سکے خدا ان تمام چیزوں سے جنہیں یہ سب شریک بنارہے ہیں پاک و پاکیزہ اور بلند و برتر ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmcdl{لوگوں کے ہاتھوں کی کمائی کی بنا پر فساد خشکی اور تری ہر جگہ غالب آگیا ہے تاکہ خدا ان کے کچھ اعمال کا مزہ چکھا دے تو شاید یہ لوگ پلٹ کر راستے پر آجائیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmcdli{آپ کہہ دیجئے کہ ذرا زمین میں سیر کرکے دیکھو کہ تم سے پہلے والوں کا کیا انجام ہوا ہے جن کی اکثریت مشرک تھی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmcdlii{اور آپ اپنے رخ کو مستقیم اور مستحکم دین کی طرف رکھیں قبل اس کے کہ وہ دن آجائے جس کی واپسی کا کوئی امکان نہیں ہے اور جس دن لوگ پریشان ہوکر الگ الگ ہوجائیں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmcdliii{جو کفر کرے گا وہ اپنے کفر کا ذمہ دار ہوگا اور جو لوگ نیک عمل کررہے ہیں وہ اپنے لئے راہ ہموار کررہے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmcdliv{تاکہ خدا ایمان اور نیک عمل کرنے والوں کو اپنے فضل سے جزا دے سکے کہ وہ کافروں کو دوست نہیں رکھتا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmcdlv{اور اس کی نشانیوں میں سے ایک یہ بھی ہے کہ وہ ہواؤں کو خوش خبری دینے والا بناکر بھیجتا ہے اور اس لئے بھی کہ تمہیں اپنی رحمت کا مزہ چکھائے اور اس کے حکم سے کشتیاں چلیں اور تم اپنا رزق حاصل کرسکو اور شاید اس طرح شکر گزار بھی بن جاؤ\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvi{اور ہم نے تم سے پہلے بہت سے رسول ان کی قوموں کی طرف بھیجے ہیں جو ان کے پاس کھلی ہوئی نشانیاں لے کر آئے پھر ہم نے مجرمین سے انتقام لیا اور ہمارا فرض تھا کہ ہم صاحبانِ ایمان کی مدد کریں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmcdlvii{اللرُ ہی وہ ہے جو ہواؤں کو چلاتا ہے تو وہ بادلوں کو اڑاتی ہیں پھر وہ ان بادلوں کو جس طرح چاہتا ہے آسمان میں پھیلادیتا ہے اور اسے ٹکڑے کردیتا ہے اور اس کے درمیان سے پانی برساتا ہے پھر یہ پانی ان بندوں تک پہنچ جاتا ہے جن تک وہ پہنچانا چاہتا ہے تو وہ خوش ہوجاتے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmcdlviii{اگرچہ وہ اس بارش کے نازل ہونے سے پہلے مایوسی کا شکار ہوگئے تھے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmcdlix{اب تم رحماُ خدا کے ان آثار کو دیکھو کہ وہ کس طرح زمین کو مردہ ہوجانے کے بعد زندہ کردیتا ہے بیشک وہی مفِدوں کو زندہ کرنے والا ہے اور وہی ہر شے پر قدرت رکھنے والا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmcdlx{اور اگر ہم زہریلی ہوا چلا دیتے اور یہ ہر طرف موسم خزاں جیسی زردی دیکھ لیتے تو بالکل ہی کفر اختیار کرلیتے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxi{تو آپ مفِدوں کو اپنی آواز نہیں سناسکتے ہیں اور بہروں کو بھی نہیں سناسکتے ہیں جب وہ منہ پھیر کر چل دیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxii{اور آپ اندھوں کو بھی ان کی گمراہی سے ہدایت نہیں کرسکتے ہیں آپ تو صرف ان لوگوں کو سناسکتے ہیں جو ہماری آیتوں پر ایمان رکھتے ہیں اور مسلمان ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiii{اللرُ ہی وہ ہے جس نے تم سب کو کمزوری سے پیدا کیا ہے اور پھر کمزوری کے بعد طاقت عطا کی ہے اور پھر طاقت کے بعد کمزوری اور ضعیفی قرار دی ہے وہ جو چاہتا ہے پیدا کردیتا ہے کہ وہ صاحب هعلم بھی ہے اور صاحب قدرت بھی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiv{اور جس دن قیامت قائم ہوگی اس دن مجرمین قسم کھاکر کہیں گے کہ وہ ایک ساعت سے زیادہ دنیا میں نہیںٹہرے ہیں درحقیقت یہ اسی طرح دنیا میں بھی افترا پردازیاں کیا کرتے تھے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxv{اور جن لوگوں کو علم اور ایمان دیا گیا ہے وہ کہیں گے کہ تم لوگ کتاب خدا کے مطابق قیامت کے دن تک ٹہرے رہے تو یہ قیامت کا دن ہے لیکن تم لوگ بے خبر بنے ہوئے ہو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvi{پھر آج ظالموں کو نہ کوئی معذرت فائدہ پہنچائے گی اور نہ ان کی کوئی بات سنی جائے گی\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvii{اور ہم نے اس قرآن میں ہر طرح کی مثال بیان کردی ہے اور اگر آپ ساری نشانیاں لے کر بھی آجائیں تو کافر یہی کہیں گے کہ آپ لوگ صرف اہل ه باطل ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxviii{بیشک اسی طرح خدا ان لوگوں کے دلوں پر مہفِ لگادیتا ہے جو علم رکھنے والے نہیں ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxix{لہٰذاآپ صبر سے کام لیں کہ خدا کا وعدہ برحق ہے اور خبردار جو لوگ یقین اس امر کا نہیں رکھتے ہیں وہ آپ کو ہلکانہ بنادیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxx{\basmalahur الۤمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxi{یہ حکمت سے بھری ہوئی کتاب کی آیتیں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxii{جو ان نیک کردار لوگوں کے لئے ہدایت اور رحمت ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiii{جو نماز قائم کرتے ہیں اور زکوِٰادا کرتے ہیں اور آخرت پر یقین رکھتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiv{یہی لوگ اپنے پروردگار کی طرف سے ہدایت پر ہیں اور یہی فلاح پانے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxv{لوگوں میں ایسا شخص بھی ہے جو مہمل باتوں کو خریدتا ہے تاکہ ان کے ذریعہ بغیر سمجھے بوجھے لوگوں کو راسِ خدا سے گمراہ کرے اور آیااُ الہٰیہ کا مذاق اڑائے درحقیقت ایسے ہی لوگوں کے لئے دردناک عذاب ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvi{اور جب اس کے سامنے آیات الہٰیہ کی تلاوت کی جاتی ہے تو اکڑ کر منہ پھیرلیتا ہے جیسے اس نے کچھ سنا ہی نہیں ہے اور جیسے اس کے کان میں بہرا پن ہے .ایسے شخص کو درناک عذاب کی بشارت دے دیجئے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvii{بیشک جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ان کے لئے نعمتوں سے بھری ہوئی جنّت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxviii{وہ اسی میں ہمیشہ رہنے والے ہیں کہ یہ خدا کا برحق وعدہ ہے اور وہ صاحبِ عزّت بھی ہے اور صاحبِ حکمت بھی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxix{اسی نے آسمانوں کو بغیر ستون کے پیدا کیا ہے تم دیکھ رہے ہو اور زمین میں بڑے بڑے پہاڑ ڈال دیئے ہیں کہ تم کو لے کر جگہ سے ہٹنے نہ پائے اور ہر طرح کے جانور پھیلادیئے ہیں اور ہم نے آسمان سے پانی برسایا ہے اور اس کے ذریعہ زمین میں ہر قسم کا نفیس جوڑا پیدا کردیا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxx{یہ خدا کی تخلیق ہے تو کافرو اب تم دکھلاؤ کہ اس کے علاوہ تمہارے خداؤں نے کیا پیدا کیا ہے اور حقیقت یہ ہے کہ یہ ظالمین کھلی ہوئی گمراہی میں مبتلا ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxi{اور ہم نے لقمان کو حکمت عطا کی کہ پروردگار کا شکریہ ادا کرو اور جو بھی شکریہ ادا کرتا ہے وہ اپنے ہی فائدہ کے لئے کرتا ہے اور جو کفرانِ نعمت کرتا ہے اسے معلوم رہے کہ خدا بے نیاز بھی ہے اور قابل حمدوثنا بھی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxii{اور اس وقت کو یاد کرو جب لقمان نے اپنے فرزند کو نصیحت کرتے ہوئے کہا کہ بیٹا خبردار کسی کو خدا کا شریک نہ بنانا کہ شرک بہت بڑا ظلم ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiii{اور ہم نے انسان کو ماں باپ کے بارے میں نصیحت کی ہے کہ اس کی ماں نے دکھ پر دکھ سہہ کر اسے پیٹ میں رکھا ہے اور اس کی دودھ بڑھائی بھی دوسال میں ہوئی ہے ...._ کہ میرا اور اپنے ماں باپ کا شکریہ ادا کرو کہ تم سب کی بازگشت میری ہی طرف ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiv{اور اگر تمہارے ماں باپ اس بات پر زور دیں کہ کسی ایسی چیز کو میرا شریک بناؤ جس کا تمہیں علم نہیں ہے تو خبردار ان کی اطاعت نہ کرنا لیکن دنیا میں ان کے ساتھ نیکی کا برتاؤ کرنا اور اس کے راستے کو اختیار کرنا جو میری طرف متوجہ ہو پھر اس کے بعد تم سب کی بازگشت میری ہی طرف ہے اور اس وقت میں بتاؤں گا کہ تم لوگ کیا کررہے تھے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxv{بیٹا نیکی یا بدی ایک رائی کے دانہ کے برابر ہو اور کسی پتھر کے اندر ہو یا آسمانوں پر ہو یا زمینوں کی گہرائیوں میں ہو تو خدا روزِ قیامت ضرور اسے سامنے لائے گا کہ وہ لطیف بھی ہے اور باخبر بھی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvi{بیٹا نماز قائم کرو, نیکیوں کا حکم دو, برائیوں سے منع کرو, اور اس راہ میں جو مصیبت پڑے اس پر صبر کرو کہ یہ بہت بڑی ہمت کا کام ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvii{اور خبردار لوگوں کے سامنے اکڑ کر منہ نہ پُھلا لینا اور زمین میں غرور کے ساتھ نہ چلنا کہ خدا اکڑنے والے اور مغرور کو پسند نہیں کرتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxviii{اور اپنی رفتار میں میانہ روی سے کام لینا اور اپنی آواز کو دھیما رکھنا کہ سب سے بدتر آواز گدھے کی آواز ہوتی ہے (جو بلاسبب بھونڈے انداز سے چیختا رہتا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxix{کیا تم لوگوں نے نہیں دیکھا کہ اللہ نے زمین و آسمان کی تمام چیزوں کو تمہارے لئے لَسخّر کردیا ہے اور تمہارے لئے تمام ظاہری اور باطنی نعمتوں کو مکمل کردیا ہے اور لوگوں میں بعض ایسے بھی ہیں جو علم و ہدایت اور روشن کتاب کے بغیر بھی خدا کے بارے میں بحث کرتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcdxc{اور جب ان سے کہا جاتا ہے کہ جو کچھ اللہ نے نازل کیا ہے اس کا اتباع کرو تو کہتے ہیں کہ ہم اس کا اتباع کرتے ہیں جس پر اپنے باپ دادا کو عمل کرتے دیکھا ہے چاہے شیطان ان کو عذاب جہّنم کی طرف دعوت دے رہا ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcdxci{اور جو اپنا روئے حیات خدا کی طرف موڑ دے اور وہ نیک کردار بھی ہو تو اس نے ریسمان ہدایت کو مضبوطی سے پکڑ لیا ہے اور تمام امور کا انجام اللہ کی طرف ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcii{اور جو کفر اختیار کرلے اس کے کفر سے تم کو رنجیدہ نہیں ہونا چاہئے کہ سب کی بازگشت ہماری ہی طرف ہے اور اس وقت ہم بتائیں گے کہ انہوں نے کیا کیا ہے بیشک اللہ دلوں کے رازوں کو بھی جانتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciii{ہم انہیں تھوڑے دن تک آرام دیں گے اور پھر سخت ترین عذاب کی طرف کھینچ کر لے آئیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcdxciv{اور اگر آپ ان سے سوال کریں کہ زمین و آسمان کا خالق کون ہے تو کہیں گے کہ اللہ تو پھر کہئے کہ ساری حمد اللہ کے لئے ہے اور ان کی اکثریت بالکل جاہل ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcv{اللرُہی کے لئے زمین و آسمان کی تمام چیزیں ہیں اور وہی بے نیاز بھی ہے اور قابل ستائش بھی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvi{اور اگر روئے زمین کے تمام درخت قلم بن جائیں اور سمندر کا سہارا دینے کے لئے سات سمندر اور آ جائیں تو بھی کلمات الہٰی تمام ہونے والے نہیں ہیں بیشک اللہ صاحبِ عزت ّبھی ہے اور صاحب حکمت بھی ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvii{تم سب کی خلقت اور تم سب کا دوبارہ زندہ کرنا سب ایک ہی آدمی جیسا ہے اور اللہ یقینا سب کچھ سننے والا اور دیکھنے والا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcviii{کیا تم نے نہیں دیکھا کہ خدا ہی رات کو دن میں اور دن کو رات میں داخل کرتا ہے اور اس نے چاند اور سورج کو لَسخّر کردیا ہے کہ سب ایک معیّن مدّت تک چلتے رہیں گے اور اللہ تمہارے تمام اعمال سے باخبر ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmcdxcix{یہ سب اسی لئے ہے کہ خدا معبود برحق ہے اور اس کے علاوہ جس کو بھی یہ لوگ پکارتے ہیں وہ سب باطل ہیں اور اللہ بلند و بالا اور بزرگ و برتر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmd{کیا تم نے نہیں دیکھا کہ نعمت خدا ہی سے کشتیاں دریا میں چل رہی ہیں تاکہ وہ تمہیں اپنی نشانیاں دکھلائے کہ اس میں تمام صبر و شکر کرنے والوں کے لئے بڑی نشانیاں پائی جاتی ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdi{اور جب سائبانوں کی طرح کوئی موج انہیں ڈھانکنے لگتی ہے تو دین کے پورے اخلاص کے ساتھ خدا کو آواز دیتے ہیں اور جب وہ نجات دے کر خشکی تک پہنچا دیتا ہے تو اس میں سے کچھ ہی اعتدال پر رہ جاتے ہیں اور ہماری آیات کا انکار غدار اور ناشکرے افراد کے علاوہ کوئی نہیں کرتا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdii{انسانو! اپنے پروردگار سے ڈرو اور اس دن سے ڈرو جس دن نہ باپ بیٹے کے کام آئے گا اور نہ بیٹا باپ کے کچھ کام آسکے گا بیشک اللہ کا وعدہ برحق ہے لہٰذا تمہیں زندگانی دنیا دھوکہ میں نہ ڈال دے اور خبردار کوئی دھوکہ دینے والا بھی تمہیں دھوکہ نہ دے سکے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdiii{یقینا اللہ ہی کے پاس قیامت کا علم ہے اور وہی پانی برساتا ہے اور شکم کے اندر کا حال جانتا ہے اور کوئی نفس یہ نہیں جانتا ہے کہ وہ کل کیا کمائے گا اور کسی کو نہیں معلوم ہے کہ اسے کس زمین پر موت آئے گی بیشک اللہ جاننے والا اور باخبر ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdiv{\basmalahur الۤمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdv{بیشک اس کتاب کی تنزیل عالمین کے پروردگار کی طرف سے ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdvi{کیا ان لوگوں کا کہنا یہ ہے کہ یہ رسول کا افترائ ہے, ہرگز نہیں یہ آپ کے پروردگار کی طرف سے برحق ہے تاکہ آپ اس قوم کو ڈرائیں جس کی طرف سے آپ سے پہلے کوئی ڈرانے والا رسول علیھ السّلامنہیں آیا ہے کہ شاید یہ ہدایت یافتہ ہوجائیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdvii{اللرُہی وہ ہے جس نے آسمان و زمین اور اس کی تمام درمیانی مخلوقات کو چھ دن کے اندر پیدا کیا ہے اور اس کے بعد عرش پر اپنا اقتدار قائم کیا ہے اور تمہارے لئے اس کو چھوڑ کر کوئی سرپرست یا سفارش کرنے والا نہیں ہے کیا تمہاری سمجھ میں یہ بات نہیں آرہی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdviii{وہ خدا آسمان سے زمین تک کے اُمور کی تدبیر کرتا ہے پھر یہ امر اس کی بارگاہ میں اس دن پیش ہوگا جس کی مقدار تمہارے حساب کے مطابق ہزار سال کے برابر ہوگی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdix{وہ خدا حاضر و غائب سب کا جاننے والا اور صاحبِ عزّت و مہربان ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdx{اس نے ہر چیز کو حسوُ کے ساتھ بنایا ہے اور انسان کی خلقت کا آغاز مٹی سے کیا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxi{اس کے بعد اس کی نسل کو ایک ذلیل پانی سے قرار دیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxii{اس کے بعد اسے برابر کرکے اس میں اپنی روح پھونک دی ہے اور تمہارے لئے کان, آنکھ اور دل بنادیئے ہیں مگر تم بہت کم شکریہ ادا کرتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxiii{اور یہ کہتے ہیں کہ اگر ہم زمین میں گم ہوگئے تو کیا نئی خلقت میں پھر ظاہر کئے جائیں گے - بات یہ ہے کہ یہ اپنے پروردگار کی ملاقات کے منکر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxiv{آپ کہہ دیجئے کہ تم کو وہ ملک الموت زندگی کی آخری منزل تک پہنچائے گا جو تم پر تعینات کیا گیا ہے اس کے بعد تم سب پروردگار کی بارگاہ میں پیش کئے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxv{اور کاش آپ دیکھتے جب مجرمین پروردگار کی بارگاہ میں سر جھکائے کھڑے ہوں گے - پروردگار ہم نے سب دیکھ لیا اور سن لیا اب ہمیں دوبارہ واپس کردے کہ ہم نیک عمل کریں بیشک ہم یقین کرنے والوں میں ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxvi{اور ہم چاہتے تو جبرا ہرنفس کو اس کی ہدایت دے دیتے لیکن ہماری طرف سے یہ بات طے ہوچکی ہے کہ ہم جہّنم کو جنات اور تمام گمراہ انسانوں سے بھردیں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxvii{لہذا تم لوگ اس بات کا مزہ چکھو کہ تم نے آج کے دن کی ملاقات کو اِھلا دیا تھا تو ہم نے بھی تم کو نظرانداز کردیا ہے اب اپنے گزشتہ اعمال کے بدلے دائمی عذاب کا مزہ چکھو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxviii{ہماری آیتوں پر ایمان لانے والے افراد بس وہ ہیں جنہیں آیات کی یاد دلائی جاتی ہے تو سجدہ میں گر پڑتے ہیں اور اپنے رب کی حمدوثنا کی تسبیح کرتے ہیں اور تکبر نہیں کرتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxix{ان کے پہلو بستر سے الگ رہتے ہیں اور وہ اپنے پروردگار کو خوف اور طمع کی بنیاد پر پکارتے رہتے ہیں اور ہمارے دیئے ہوئے رزق سے ہماری راہ میں انفاق کرتے رہتے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdxx{پس کسی نفس کو نہیں معلوم ہے کہ اس کے لئے کیا کیا خنکی چشم کا سامان چھپا کر رکھا گیا ہے جو ان کے اعمال کی جزا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdxxi{کیا وہ شخص جو صاحبِ ایمان ہے اس کے مثل ہوجائے گا جو فاسق ہے ہرگز نہیں دونوں برابر نہیں ہوسکتے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdxxii{جو لوگ ایمان لائے ہیں اور انہوں نے نیک اعمال کئے ہیں ان کے لئے آرام کرنے کی جنتیں ہیں جو ان کے اعمال کی جزا ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiii{اور جن لوگوں نے فسق اختیار کیا ہے ان کا ٹھکاناجہّنم ہے کہ جب اس سے نکلنے کا ارادہ کریں گے تو دوبارہ پلٹا دیئے جائیں گے اور کہا جائے گا کہ اس جہنمّ کی آگ کا مزہ چکھو جس کا تم انکار کیا کرتے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdxxiv{اور ہم یقینا بڑے عذاب سے پہلے انہیں معمولی عذاب کا مزہ چکھائیں گے کہ شاید اسی طرح راہ راست پر پلٹ آئیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdxxv{اور اس سے بڑا ظالم کون ہے جسے آیات هالہٰیہ کی یاد دلائی جائے اور پھر اس سے اعراض کرے تو ہم یقینا مجرمین سے انتقام لینے والے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvi{اور ہم نے موسٰی علیھ السّلام کو بھی کتاب عطا کی ہے لہذا آپ کو اپنے قرآن کے منجانب اللہ ہونے میں شک نہیں ہونا چاہئے اور ہم نے کتاب هموسٰی علیھ السّلام کو بنی اسرائیل کے لئے ہدایت قرار دیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdxxvii{اور ہم نے ان میں سے کچھ لوگوں کو امام اور پیشوا قرار دیا ہے جو ہمارے امر سے لوگوں کی ہدایت کرتے ہیں اس لئے کہ انہوں نے صبر کیا ہے اور ہماری آیتوں پر یقین رکھتے تھے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdxxviii{بیشک آپ کا پروردگار ان کے درمیان روزِ قیامت ان تمام باتوں کا فیصلہ کردے گا جن میں یہ آپس میں اختلاف رکھتے تھے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdxxix{تو کیا ان کی ہدایت کے لئے یہ کافی نہیں ہے کہ ہم نے ان سے پہلے بہت سی قوموں کو ہلاک کردیا ہے جن کی بستیوں میں یہ چل پھررہے ہیں اور اس میں ہماری بہت سی نشانیاں ہیں تو کیا یہ سنتے نہیں ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdxxx{کیا ان لوگوں نے یہ نہیں دیکھا ہے کہ ہم پانی کو چٹیل میدان کی طرف بہالے جاتے ہیں اور اس کے ذریعہ زراعت پیدا کرتے ہیں جسے یہ خود بھی کھاتے ہیں اور ان کے جانور بھی کھاتے ہیں تو کیا یہ دیکھتے نہیں ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxi{اور یہ لوگ کہتے ہیں کہ آخر وہ فتح کا دن کب آئے گا اگر آپ لوگ سچےّ ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxii{تو کہہ دیجئے کہ فتح کے دن پھر کفر اختیار کرنے والوں کا ایمان کام نہیں آئے گا اور نہ انہیں مہلت ہی دی جائے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiii{لہذا آپ ان سے کنارہ کش رہیں اور وقت کا انتظار کریں کہ یہ بھی انتظار کرنے والے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiv{\basmalahur اے پیغمبر خدا سے ڈرتے رہئیے اور خبردار کافروں اور منافقوں کی اطاعت نہ کیجئے گا یقینا اللہ ہر شے کا جاننے والا اور صاحب ه حکمت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxv{اور جو کچھ آپ کے پروردگار کی طرف سے وحی کی جاتی ہے اسی کا اتباع کرتے رہیں کہ اللہ تم لوگوں کے اعمال سے خوب باخبر ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvi{اور اپنے خدا پر اعتماد کیجئے کہ وہ نگرانی کے لئے بہت کافی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvii{اور اللہ نے کسی مرد کے سینے میں دو دل نہیں قرار دیئے ہیں اور تمہاری وہ بیویاں جن سے تم ا ظہار کرتے ہو انہیں تمہاری واقعی ماں نہیں قرار دیا ہے اور نہ تمہاری منہ بولی اولاد کواولادقرار دیا ہے یہ سب تمہاری زبانی باتیں ہیں اور اللہ تو صرف حق کی بات کہتا ہے اور سیدھے راستے کی طرف ہدایت کرتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxviii{ان بچوں کو ان کے باپ کے نام سے پکارو کہ یہی خدا کی نظر میں انصاف سے قریب تر ہے اور اگر ان کے باپ کو نہیں جانتے ہو تو یہ دین میں تمہارے بھائی اور دوست ہیں اور تمہارے لئے اس بات میں کوئی حرج نہیں ہے جو تم سے غلطی ہوگئی ہے البتہ تم اس بات کے ضرور ذمہ دار ہو جو تمہارے دلوں سے قصداانجام دی ہے اور اللہ بہت بخشنے والا اور مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdxxxix{بیشک نبی تمام مومنین سے ان کے نفس کے بہ نسبت زیادہ اولیٰ ہے اور ان کی بیویاں ان سب کی مائیں ہیں اور مومنین و مہاجرین میں سے قرابتدار ایک دوسرے سے زیادہ اولویت اور قربت رکھتے ہیں مگر یہ کہ تم اپنے دوستوں کے ساتھ نیک برتاؤ کرنا چاہو تو کوئی بات نہیں ہے یہ بات کتابِ خدا میں لکھی ہوئی موجود ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdxl{اوراس وقت کو یاد کیجئے جب ہم نے تمام انبیائ علیھ السّلامسے اور بالخصوص آپ سے اور نوح علیھ السّلام, ابراہیم علیھ السّلام ,موسیٰ علیھ السّلام اور عیسٰی بن علیھ السّلام مریم سے عہد لیا اور سب سے بہت سخت قسم کا عہد لیا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdxli{تاکہ صادقین سے ان کی صداقت تبلیغ کے بارے میں سوال کیا جائے اور خدا نے کافروں کے لئے بڑا دردناک عذاب مہیاّ کر رکھا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdxlii{ایمان والو! اس وقت اللہ کی نعمت کو یاد کرو جب کفر کے لشکر تمہارے سامنے آگئے اور ہم نے ان کے خلاف تمہاری مدد کے لئے تیز ہوا اور ایسے لشکر بھیج دیئے جن کو تم نے دیکھا بھی نہیں تھا اور اللہ تمہارے اعمال کوخوب دیکھنے والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdxliii{اس وقت جب کفار تمہارے اوپر کی طرف سے اور نیچے کی سمت سے آگئے اور دہشت سے نگاہیں خیرہ کرنے لگیں اور کلیجے منہ کو آنے لگے اور تم خدا کے بارے میں طرح طرح کے خیالات میں مبتلا ہوگئے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdxliv{اس وقت مومنین کا باقاعدہ امتحان لیا گیا اور انہیں شدید قسم کے جھٹکے دیئے گئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdxlv{اور جب منافقین اور جن کے دلوں میں مرض تھا یہ کہہ رہے تھے کہ خدا و رسول نے ہم سے صرف دھوکہ دینے والا وعدہ کیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvi{اور جب ان کے ایک گروہ نے کہہ دیا کہ مدینہ والو اب یہاں ٹھکانا نہیں ہے لہذا واپس بھاگ چلو اور ان میں سے ایک گروہ نبی سے اجازت مانگ رہا تھا کہ ہمارے گھر خالی پڑے ہوئے ہیں حالانکہ وہ گھر خالی نہیں تھے بلکہ یہ لوگ صرف بھاگنے کا ارادہ کررہے تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdxlvii{حالانکہ اگر ان پر چاروں طرف سے لشکر داخل کردیئے جاتے اور پھر ان سے فتنہ کا سوال کیا جاتا تو فورا حاضر ہوجاتے اور تھوڑی دیر سے زیادہ نہ ٹہرتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdxlviii{اور ان لوگوں نے اللہ سے یقینی عہد کیا تھا کہ ہرگز پیٹھ نہ پھرائیں گے اور اللہ کے عہد کے بارے میں بہرحال سوال کیا جائے گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdxlix{آپ کہہ دیجئے کہ اگر تم قتل یا موت کے خوف سے بھاگنا بھی چاہو تو فرار کام آنے والا نہیں ہے اور دنیا میں تھوڑا ہی آرام کرسکو گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdl{کہہ دیجئے کہ اگر خدا برائی کا ارادہ کرلے یا بھلائی ہی کرنا چاہے تو تمہیں اس سے کون بچاسکتا ہے اور یہ لوگ اس کے علاوہ نہ کوئی سرپرست پاسکتے ہیں اور نہ مددگار\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdli{خدا ان لوگوں کو بھی خوب جانتا ہے جو جنگ سے روکنے والے ہیں اور اپنے بھائیوں سے یہ کہنے والے ہیں کہ ہماری طرف آجاؤ اور یہ خود میدان جنگ میں بہت کم آتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdlii{یہ تم سے جان چراتے ہیں اور جب خوف سامنے آجائے گا تو آپ دیکھیں گے کہ آپ کی طرف اس طرح دیکھیں گے کہ جیسے ان کی آنکھیں یوں پھر رہی ہیں جیسے موت کی غشی طاری ہو اور جب خوف چلا جائے گا تو آپ پر تیز تر زبانوں کے ساتھ حملہ کریں گے اور انہیں مال غنیمت کی حرص ہوگی یہ لوگ شروع ہی سے ایمان نہیں لائے ہیں لہٰذا خدا نے ان کے اعمال کو برباد کردیا ہے اور خدا کے لئے یہ کام بڑا آسان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdliii{یہ لوگ ابھی تک اس خیال میں ہیں کہ کفار کے لشکر گئے نہیں ہیں اور اگر دوبارہ لشکر آجائیں تو یہ یہی چاہیں گے کہ اے کاش دیہاتیوں کے ساتھ صحراؤں میں آباد ہوگئے ہوتے اور وہاں سے تمہاری خبریں دریافت کرتے رہتے اور اگر تمہارے ساتھ رہتے بھی تو بہت کم ہی جہاد کرتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdliv{مسلمانو! تم میں سے اس کے لئے رسول کی زندگی میں بہترین نمونہ عمل ہے جو شخص بھی اللہ اور آخرت سے امیدیں وابستہ کئے ہوئے ہے اور اللہ کو بہت زیادہ یاد کرتا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdlv{اور صاحبانِ ایمان کا یہ عالم ہے کہ جب انہوں نے کفر کے لشکروں کو دیکھا تو پکار اٹھے کہ یہ وہی بات ہے جس کا خدا اور رسول نے وعدہ کیا تھا اور خدا و رسول کا وعدہ بالکل سچا ہے اور اس ہجوم نے ان کے ایمان اور جذبہ تسلیم میں مزید اضافہ ہی کردیا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdlvi{مومنین میں ایسے بھی مردُ میدان ہیں جنہوں نے اللہ سے کئے وعدہ کو سچ کر دکھایا ہے ان میں بعض اپنا وقت پورا کرچکے ہیں اور بعض اپنے وقت کا انتظار کررہے ہیں اور ان لوگوں نے اپنی بات میں کوئی تبدیلی نہیں پیدا کی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdlvii{تاکہ خدا صادقین کو ان کی صداقت کا بدلہ دے اور منافقین کو چاہے تو ان پر عذاب نازل کرے یا ان کی توبہ قبول کرلے کہ اللہ یقینا بہت بخشنے والا اور مہربان ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdlviii{اور خدا نے کفّار کو ان کے غصّہ سمیت واپس کردیا کہ وہ کوئی فائدہ حاصل نہ کرسکے اور اللہ نے مومنین کو جنگ سے بچالیا اور اللہ بڑی قوت والا اور صاحبِ عزّت ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdlix{اور اس نے کفار کی پشت پناہی کرنے والے اہل کتاب کو ان کے قلعوں سے نیچے اتار دیا اور ان کے دلوں میں ایسا رعب ڈال دیا کہ تم ان میں سے کچھ کو قتل کررہے تھے اور کچھ کو قیدی بنارہے تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdlx{اور پھر تمہیں ان کی زمین, ان کے دیار اور ان کے اموال اور زمینوں کا بھی وارث بنادیا جن میں تم نے قدم بھی نہیں رکھا تھا اور بیشک اللہ ہر شے پر قادر ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdlxi{پیغمبر آپ اپنی بیویوں سے کہہ دیجئے کہ اگر تم لوگ زندگانی دنیا اور اس کی زینت کی طلبگار ہو تو آؤ میں تمہیں متاغِ دنیا دے کر خوبصورتی کے ساتھ رخصت کردوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdlxii{اور اگر اللہ اور رسول اور آخرت کی طلبگار ہو تو خدا نے تم میں سے نیک کردار عورتوں کے لئے بہت بڑا اجر فراہم کر رکھا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiii{اے زنان هپیغمبر جو بھی تم میں سے کِھلی ہوئی برائی کا ارتکاب کرے گی اس کا عذاب بھی دہرا کردیا جائے گا اور یہ بات خد اکے لئے بہت آسان ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdlxiv{اور جو بھی تم میں سے خدا اور رسول کی اطاعت کرے اور نیک اعمال کرے اسے دہرا اجر عطا کریں گے اور ہم نے اس کے لئے بہترین رزق فراہم کیا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdlxv{اے زنانِ پیغمبر تم اگر تقویٰ اختیار کرو تو تمہارا مرتبہ کسی عام عورت جیسا نہیں ہے لہٰذا کسی آدمی سے لگی لپٹی بات نہ کرنا کہ جس کے دل میں بیماری ہو اسے لالچ پیدا ہوجائے اور ہمیشہ نیک باتیں کیا کرو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvi{اور اپنے گھر میں بیٹھی رہو اور پہلی جاہلیت جیسا بناؤ سنگھار نہ کرو اور نماز قائم کرو اور زکوِٰادا کرو اوراللہ اور اس کے رسول کی اطاعت کرو - بس اللہ کا ارادہ یہ ہے اے اہلبیت علیھ السّلام کہ تم سے ہر برائی کو دور رکھے اور اس طرح پاک و پاکیزہ رکھے جو پاک و پاکیزہ رکھنے کا حق ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdlxvii{اور ازواج پیغمبر تمہارے گھروں میں جن آیات الٰہی اور حکمت کی باتوں کی تلاوت کی جاتی ہے انہیں یاد رکھنا کہ خدا بڑا باریک بین اور ہر شے کی خبر رکھنے والا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdlxviii{بیشک مسلمان مرد اور مسلمان عورتیں اور مومن مرد اور مومن عورتیں اور اطاعت گزار مرد اور اطاعت گزار عورتیں اور سچے مرد اور سچی عورتیں اور صابر مرد اور صابر عورتیں اور فروتنی کرنے والے مرد اور فروتنی کرنے والی عورتیں اور صدقہ دینے والے مرد اور صدقہ دینے والی عورتیں روزہ رکھنے والے مرد اور روزہ رکھنے والی عورتیں اور اپنی عفّت کی حفاظت کرنے والے مرد اور عورتیں اور خدا کا بکثرت ذکر کرنے والے مرد اور عورتیں.اللہ نے ان سب کے لئے مغفرت اور عظیم اجر مہّیاکررکھا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdlxix{اور کسی مومن مرد یا عورت کو اختیار نہیں ہے کہ جب خدا و رسول کسی امر کے بارے میں فیصلہ کردیں تو وہ بھی اپنے امر کے بارے میں صاحبِ اختیار بن جائے اور جو بھی خدا و رسول کی نافرمانی کرے گا وہ بڑی کھاَلی ہوئی گمراہی میں مبتلا ہوگا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdlxx{اور اس وقت کو یاد کرو جب تم اس شخص سے جس پر خدا نے بھی نعمت نازل کی اور تم نے بھی احسان کیا یہ کہہ رہے تھے کہ اپنی زوجہ کو روک کر رکھو اوراللہ سے ڈرو اور تم اپنے دل میں اس بات کو چھپائے ہوئے تھے جسے خدا ظاہر کرنے والا تھا اور تمہیں لوگوں کے طعنوں کا خوف تھا حالانکہ خدا زیادہ حقدار ہے کہ اس سے ڈرا جائے اس کے بعد جب زید نے اپنی حاجت پوری کرلی تو ہم نے اس عورت کا عقد تم سے کردیا تاکہ مومنین کے لئے منہ بولے بیٹوں کی بیویوں سے عقد کرنے میں کوئی حرج نہ رہے جب وہ لوگ اپنی ضرورت پوری کرچکیں اوراللہ کا حکم بہرحال نافذ ہوکر رہتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxi{نبی کے لئے خدا کے فرائض میں کوئی حرج نہیں ہے یہ گزشتہ انبیائ کے دور سے سنّت الہٰیّہ چلی آرہی ہے اوراللہ کا حکم صحیح اندازے کے مطابق مقرر کیا ہوا ہوتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxii{وہ لوگ ا للہ کے پیغام کو پہنچاتے ہیں اور دل میں اس کا خوف رکھتے ہیں اور اس کے علاوہ کسی سے نہیں ڈرتے ہیںاوراللہ حساب کرنے کے لئے کافی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiii{محمد تمہارے مُردوں میں سے کسی ایک کے باپ نہیں ہیں لیکن و ہ اللہ کے رسول اور سلسلہ انبیائ علیھ السّلامکے خاتم ہیں اوراللہ ہر شے کا خوب جاننے والا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiv{ایمان والواللہ کا ذکر بہت زیادہ کیا کرو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxv{اور صبح و شام اس کی تسبیح کیا کرو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvi{وہی وہ ہے جو تم پر رحمت نازل کرتا ہے اور اس کے فرشتے بھی تاکہ تمہیں تاریکیوں سے نکال کر نور کی منزل تک لے آئے اور وہ صاحبان هایمان پر بہت زیادہ مہربان ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvii{ان کی مدارات جس دن پروردگار سے ملاقات کریں گے سلامتی سے ہوگی اور ان کے لئے اس نے بہترین اجر مہّیا کر رکھا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxviii{اے پیغمبر ہم نے آپ کو گواہ, بشارت دینے والا, عذاب الہٰی سے ڈرانے والا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxix{اور خدا کی طرف اس کی اجازت سے دعوت دینے والا اور روشن چراغ بناکر بھیجا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxx{اور مومنین کو بشارت دے دیجئے کہ ان کے لئے اللہ کی طرف سے بہت بڑا فضل و کرم ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxi{اور خبردار کفّار اور منافقین کی اطاعت نہ کیجئے گا اور ان کی اذیت کا خیال ہی چھوڑ دیجئے اوراللہ پر اعتماد کیجئے کہ وہ نگرانی کرنے کے لئے بہت کافی ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxii{ایمان والو جب مومنات سے نکاح کرنا اور ان کو ہاتھ لگائے بغیر طلاق دے دینا تو تمہارے لئے کوئی حق نہیں ہے کہ ان سے و عدہ کا مطالبہ کرو لہٰذا کچھ عطیہ دے کر خوبصورتی کے ساتھ رخصت کردینا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiii{اے پیغمبر ہم نے آپ کے لئے آپ کی بیویوں کو جن کا مہر دے دیا ہے اور کنیزوں کو جنہیں خدا نے جنگ کے بغیر عطا کردیا ہے اور آپ کے چچا کی بیٹیوں کو اور آپ کی پھوپھی کی بیٹیوں کو اور آپ کے ماموں کی بیٹیوں کو اور آپ کی خالہ کی بیٹیوں کو جنہوں نے آپ کے ساتھ ہجرت کی ہے اور اس مومنہ عورت کو جو اپنا نفس نبی کو بخش دے اگر نبی اس سے نکاح کرنا چاہے تو حلال کردیا ہے لیکن یہ صرف آپ کے لئے ہے باقی مومنین کے لئے نہیں ہے. ہمیں معلوم ہے کہ ہم نے ان لوگوں پر ان کی بیویوں اور کنیزوں کے بارے میں کیا فریضہ قرار دیا ہے تاکہ آپ کے لئے کوئی زحمت اور مشقّت نہ ہو اوراللہ بہت زیادہ بخشنے والا اور مہربان ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiv{ان میں سے جس کو آپ چاہیں الگ کرلیں اور جس کو چاہیں اپنی پناہ میں رکھیں اور جن کو الگ کردیا ہے ان میں سے بھی کسی کو چاہیں تو کوئی حرج نہیں ہے - یہ سب اس لئے ہے تاکہ ان کی آنکھیں ٹھنڈی رہیں اور یہ رنجیدہ نہ ہوں اور جو کچھ آپ نے دیدیا ہے اس سے خوش رہیں اوراللہ تمہارے دلوں کا حال خوب جانتا ہے اور وہ ہر شے کا جاننے والا اور صاحبِ حکمت ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxv{اس کے بعد آپ کے لئے دوسری عورتیں حلال نہیں ہیں اور نہ یہ جائز ہے کہ ان بیویوں کو بدل لیں چاہے دوسری عورتوں کا حسن کتنا ہی اچھا کیوں نہ لگے علاوہ ان عورتوں کے جو آپ کے ہاتھوں کی ملکیت ہیں اور خدا ہر شے کی نگرانی کرنے والا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvi{اے ایمان والو خبردار پیغمبر کے گھروں میں اس وقت تک داخل نہ ہونا جب تک تمہیں کھانے کے لئے اجازت نہ دے دی جائے اور اس وقت بھی برتنوں پر نگاہ نہ رکھنا ہاں جب دعوت دے دی جائے تو داخل ہوجاؤ اور جب کھالو تو فورا منتشر ہوجاؤ اور باتوں میں نہ لگ جاؤ کہ یہ بات پیغمبر کو تکلیف پہنچاتی ہے اور وہ تمہارا خیال کرتے ہیں حالانکہ اللہ حق کے بارے میں کسی بات کی شرم نہیں رکھتا اور جب ازواج پیغمبر سے کسی چیز کا سوال کرو تو پردہ کے پیچھے سے سوال کرو کہ یہ بات تمہارے اور ان کے دونوں کے دلوں کے لئے زیادہ پاکیزہ ہے اور تمہیں حق نہیں ہے کہ خدا کے رسول کو اذیت دو یا ان کے بعد کبھی بھی ان کی ازواج سے نکاح کرو کہ یہ بات خدا کی نگاہ میں بہت بڑی بات ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvii{تم کسی شے کا اظہار کرو یا اس کی پردہ داری کرواللہ بہرحال ہر شے کا جاننے والا ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxviii{اور عورتوں کے لئے کوئی حرج نہیں ہے اگر اپنے باپ دادا, اپنی اولاد, اپنے بھائی, اپنے بھتیجے اور اپنے بھانجوں کے سامنے بے حجاب آئیں یا اپنی عورتوں اور اپنی کنیزوں کے سامنے آئیں لیکن تم سب اللہ سے ڈرتی رہو کہ اللہ ہر شے پر حاضر و ناظر ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxix{بیشک اللہ اور اس کے ملائکہ رسول پر صلٰوات بھیجتے ہیں تو اے صاحبانِ ایمان تم بھی ان پر صلٰوات بھیجتے رہو اور سلام کرتے رہو\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdxc{یقینا جو لوگ خدا اور اس کے رسول کو ستاتے ہیں ان پر دنیا اور آخرت میں خدا کی لعنت ہے اور خدا نے ان کے لئے رسوا کن عذاب مہیاّ کر رکھا ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdxci{اور جو لوگ صاحبانِ ایمان مرد یا عورتوں کو بغیر کچھ کئے دھرے اذیت دیتے ہیں انہوں نے بڑے بہتان اور کھلے گناہ کا بوجھ اپنے سر پر اٹھا رکھا ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdxcii{اے پیغمبر آپ اپنی بیویوں, بیٹیوں, اور مومنین کی عورتوں سے کہہ دیجئے کہ اپنی چادر کو اپنے اوپر لٹکائے رہا کریں کہ یہ طریقہ ان کی شناخت یا شرافت سے قریب تر ہے اور اس طرح ان کو اذیت نہ دی جائے گی اور خدا بہت بخشنے والا اور مہربان ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdxciii{پھر اگر منافقین اور جن کے دلوں میں بیماری ہے اور مدینہ میںافواہ پھیلانے والے اپنی حرکتوں سے باز نہ آئے تو ہم آپ ہی کو ان پر مسلّط کردیں گے اور پھر یہ آپ کے ہمسایہ میں صرف چند ہی دن رہ پائیں گے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdxciv{یہ لعنت کے مارے ہوئے ہوں گے کہ جہاں مل جائیں گرفتار کرلئے جائیں اور ان کے ٹکڑے ٹکڑے کردیئے جائیں\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdxcv{یہ خدائی سّنت ان لوگوں کے بارے میں رہ چکی ہے جو گزر چکے ہیں اور خدائی سّنت میں تبدیلی نہیں ہوسکتی ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvi{پیغمبر یہ لوگ آپ سے قیامت کے بارے میں سوال کرتے ہیں تو کہہ دیجئے کہ اس کا علم خدا کے پاس ہے اور تم کیا جانو شائد وہ قریب ہی ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdxcvii{بیشک اللہ نے کّفار پر لعنت کی ہے اور ان کے لئے جہّنم کا انتظام کیا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdxcviii{وہ اس میں ہمیشہ ہمیشہ رہیں گے اور انہیں کوئی سرپرست یا مددگار نہیں ملے گا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdxcix{جس دن ان کے چہرے جہنمّ کی طرف موڑدیئے جائیں گے اور یہ کہیں گے کہ اے کاش ہم نے اللہ اور رسول کی اطاعت کی ہوتی\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdc{اور کہیں گے کہ ہم نے اپنے سرداروں اور بزرگوں کی اطاعت کی تو انہوں نے راستہ سے بہکادیا\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdci{پروردگار اب ان پر دہرا عذاب نازل کر اور ان پر بہت بڑی لعنت کر\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcii{ایمان والو خبردار ان کے جیسے نہ بن جاؤ جنہوں نے موسٰی علیھ السّلام کو اذیت دی تو خدا نے انہیں ان کے قول سے بری ثابت کردیا اور و ہ اللہ کے نزدیک ایک باوجاہت انسان تھے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdciii{ایمان والو اللہ سے ڈرو اور سیدھی بات کرو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdciv{تاکہ وہ تمہارے اعمال کی اصلاح کردے اور تمہارے گناہوں کو بخش دے اور جو بھی خدا اور اس کے رسول کی اطاعت کرے گا وہ عظیم کامیابی کے درجہ پر فائز ہوگا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcv{بیشک ہم نے امانت کو آسمانً زمین اور پہاڑ سب کے سامنے پیش کیا اور سب نے اس کے اٹھانے سے انکار کیا اور خوف ظاہر کیا بس انسان نے اس بوجھ کو اٹھالیا کہ انسان اپنے حق میں ظالم اور نادان ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcvi{تاکہ خدا منافق مرد اور منافق عورت اور مشرک مرد اور مشرک عورت سب پر عذاب نازل کرے اور صاحبِ ایمان مرد اور صاحبِ ایمان عورتوں کی توبہ قبول کرے کہ خدا بہت بخشنے والا اور مہربان ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcvii{\basmalahur ساری تعریف اس اللہ کے لئے ہے جس کے اختیار میں آسمان اور زمین کی تمام چیزیں ہیں اور اسی کے لئے آخرت میں بھی حمد ہے اور وہی صاحبِ حکمت اور ہر بات کی خبر رکھنے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdcviii{وہ جانتا ہے کہ زمین میں کیا چیز داخل ہوتی ہے اور کیا چیز اس سے نکلتی ہے اور کیا چیز آسمان سے نازل ہوتی ہے اور کیا اس میں بلند ہوتی ہے اور وہ مہربان اور بخشنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdcix{اور کفّار کہتے ہیں کہ قیامت آنے والی نہیں ہے تو آپ کہہ دیجئے کہ میرے پروردگار کی قسم وہ ضرور آئے گی وہ عالم الغیب ہے اس کے علم سے آسمان و زمین کا کوئی ذرّہ دور نہیں ہے اور نہ اس سے چھوٹا اور نہ بڑا بلکہ سب کچھ اس کی روشن کتاب میں محفوظ ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdcx{تاکہ وہ ایمان لانے والے اور نیک اعمال انجام دینے والوں کو جزا دے کہ ان کے لئے مغفرت اور باعزّت رزق ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdcxi{اور جن لوگوں نے ہماری آیتوں کے مقابلہ میں دوڑ دھوپ کی ان کے لئے دردناک سزا کا عذاب معّین ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdcxii{اور جن لوگوں کو علم دیا گیا ہے وہ جانتے ہیں کہ جو کچھ آپ کی طرف پروردگار کی طرف سے نازل کیا گیا ہے سب بالکل حق ہے اور خدائے غالب و قابلِ حمد و ثنا کی طرف ہدایت کرنے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiii{اور جن لوگوں نے کفر اختیار کیا ان کا کہنا ہے کہ ہم تمہیں ایسے آدمی کا پتہ بتائیں جو یہ خبر دیتا ہے کہ جب تم مرنے کے بعد ٹکڑے ٹکڑے ہوجاؤ گے تو تمہیں نئی خلقت کے بھیس میں لایا جائے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdcxiv{اس نے اللہ پر جھوٹا الزام باندھا ہے یا اس میں جنون پایا جاتا ہے نہیں بلکہ جو لوگ آخرت پر ایمان نہیں رکھتے وہ عذاب اور گمراہی میں مبتلا ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdcxv{کیا انہوں نے آسمان و زمین میں اپنے سامنے اور پس پشت کی چیزوں کو نہیں دیکھا ہے کہ ہم چاہیں تو انہیں زمین میں دھنسا دیں یا ان کے اوپر آسمان کو ٹکڑے ٹکڑے کرکے گرادیں. اس میں ہر رجوع کرنے والے بندہ کے لئے قدرت کی نشانی پائی جاتی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvi{اور ہم نے داؤد کو یہ فضل عطا کیا کہ پہاڑو تم ان کے ساتھ تسبیح پروردگار کیا کرو اور پرندوں کو لَسخّر کردیا اور لوہے کو نرم کردیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdcxvii{کہ تم کشادہ اور مکمل زرہیں بناؤ اور کڑیوں کے جوڑنے میں اندازہ کا خیال رکھو اور تم لوگ سب نیک عمل کرو کہ میں تم سب کے اعمال کا دیکھنے والا ہوں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdcxviii{اور ہم نے سلیمان علیھ السّلامکے ساتھ ہواؤں کو مسخر کردیا کہ ان کی صبح کی رفتار ایک ماہ کی مسافت تھی اور شام کی رفتار بھی ایک ماہ کے برابر تھی اور ہم نے ان کے لئے تانبے کا چشمہ جاری کردیا اور جنّات میں ایسے افراد بنادیئے جو خدا کی اجازت سے ان کے سامنے کام کرتے تھے اور جس نے ہمارے حکم سے انحراف کیا ہم اسے آتش جہّنم کا مزہ چکھائیں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdcxix{یہ جنات سلیمان کے لئے جو وہ چاہتے تھے بنادیتے تھے جیسے محرابیں, تصویریں اور حوضوں کے برابر پیالے اور بڑی بڑی زمین میں گڑی ہوئی دیگیں آل داؤد شکر ادا کرو اور ہمارے بندوں میں شکر گزار بندے بہت کم ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcxx{پھر جب ہم نے ان کی موت کا فیصلہ کردیا تو ان کی موت کی خبر بھی جنات کو کسی نے نہ بتائی سوائے دیمک کے جو ان کے عصا کو کھارہی تھی اور وہ خاک پر گرے تو جنات کو معلوم ہوا کہ اگر وہ غیب کے جاننے والے ہوتے تو اس ذلیل کرنے والے عذاب میں مبتلا نہ رہتے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxi{اور قوم سبا کے لئے ان کے وطن ہی میں ہماری نشانی تھی کہ داہنے بائیں دونوں طرف باغات تھے. تم لوگ اپنے پروردگار کا دیا رزق کھاؤ اور اس کا شکر ادا کرو تمہارے لئے پاکیزہ شہر اور بخشنے والا پروردگار ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxii{مگر ان لوگوں نے انحراف کیا تو ہم نے ان پر بڑے زوروں کا سیلاب بھیج دیا اور ان کے دونوں باغات کو ایسے دو باغات میں تبدیل کردیا جن کے پھل بے مزہ تھے اور ان میں جھاؤ کے درخت اور کچھ بیریاں بھی تھیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiii{یہ ہم نے ان کی ناشکری کی سزادی ہے اور ہم ناشکروں کے علاوہ کس کو سزادیتے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiv{اور جب ہم نے ان کے اور ان بستیوں کے درمیان جن میں ہم نے برکتیں رکھی ہیں کچھ نمایاں بستیاں قرار دیں اور ان کے درمیان سیر کو معّین کردیا کہ اب دن و رات جب چاہو سفر کرو محفوظ رہوگے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxv{تو انہوں نے اس پر بھی یہ کہا کہ پروردگار ہمارے سفر دور دراز بنادے اوراس طرح اپنے نفس پر ظلم کیا تو ہم نے انہیں کہانی بناکر چھوڑ دیا اور انہیں ٹکڑے ٹکڑے کردیا کہ یقینا اس میں صبر و شکر کرنے والوں کے لئے بڑی نشانیاں پائی جاتی ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvi{اور ان پر ابلیس نے اپنے گمان کو سچا کردکھایا تو مومنین کے ایک گروہ کو چھوڑ کر سب نے اس کا اتباع کرلیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvii{اور شیطان کو ان پر اختیار حاصل نہ ہوتا مگر ہم یہ جاننا چاہتے ہیں کون آخرت پر ایمان رکھتا ہے اور کون اس کی طرف سے شک میں مبتلا ہے اور آپ کا پروردگار ہر شے کا نگراں ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxviii{آپ کہہ دیجئے کہ تم لوگ انہیں پکارو جن کااللہ کو چھوڑ کر تمہیں خیال تھا تو دیکھو گے کہ یہ آسمان و زمین میں ایک ذرہ ّ برابر اختیار نہیں رکھتے ہیں اور ان کا آسمان و زمین میں کوئی حصہّ ہے اور نہ ان میں سے کوئی ان لوگوں کا پشت پناہ ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxix{اس کے یہاں کسی کی سفارش بھی کام آنے والی نہیں ہے مگر وہ جس کو وہ خود اجازت دیدے یہاں تک کہ جب ان کے دلوں کی ہیبت دور کردی جائے گی تو پوچھیں گے کہ تمہارے پروردگار نے کیا کہا ہے تو وہ جواب دیں گے کہ جو کچھ کہا ہے حق کہا ہے اور وہ بلند و بالا اور بزرگ و برتر ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxx{آپ کہئے کہ تمہیں آسمان و زمین سے روزی کون دیتا ہے اور پھر بتائیے کہ اللہ اور کہئے کہ ہم یا تم ہدایت پر ہیں یا کھلی ہوئی گمراہی میں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxi{انہیں بتائیے کہ ہم جو خطا کریں گے اس کے بارے میں تم سے سوال نہ کیا جائے گا اور تم جو کچھ کرو گے اس کے بارے میں ہم سے سوال نہ ہوگا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxii{کہئے کہ ایک دن خدا ہم سب کو جمع کرے گا اور پھر ہمارے درمیان حق کے ساتھ فیصلہ کرے گا اور وہ بہترین فیصلہ کرنے والا ہے اور جاننے والاہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiii{ان سے کہئے کہ ذرا ان شرکائ کو دکھلاؤ جن کو خدا سے ملادیا ہے - یہ ہرگز نہیں دکھا سکیں گے بلکہ خدا صرف خدائے عزیز و حکیم ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiv{اور پیغمبر ہم نے آپ کو تمام لوگوں کے لئے صرف بشیر و نذیر بناکر بھیجا ہے یہ اور بات ہے کہ اکثر لوگ اس حقیقت سے باخبر نہیں ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxv{اور کہتے ہیں کہ اگر تم سچے ہو تو یہ وعدہ قیامت کب پورا ہوگا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvi{کہہ دیجئے کہ تمہارے لئے ایک دن کا وعدہ مقرر ہے جس سے ایک ساعت پیچھے ہٹ سکتے ہو اور نہ آ گے بڑھ سکتے ہو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvii{اور کفاّر یہ کہتے ہیں کہ ہم نہ اس قرآن پر ایمان لائیں گے اور نہ اس سے پہلے والی کتابوں پر تو کاش آپ دیکھتے جب ان ظالموں کو پروردگار کے حضور کھڑا کیا جائے گا اور ہر ایک بات کو دوسرے کی طرف پلٹائے گا اور جن لوگوں کو کمزور سمجھ لیا گیا ہے وہ اونچے بن جانے والوں سے کہیں گے کہ اگر تم درمیان میں نہ آگئے ہوتے تو ہم صاحب هایمان ہوگئے ہوتے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxviii{تو بڑے لوگ کمزور لوگوں سے کہیں گے کہ کیا ہم نے تمہیں ہدایت کے آنے کے بعد اس کے قبول کرنے سے روکا تھا ہرگز نہیں تم خود مجرم تھے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxix{اور کمزور لوگ بڑے لوگوں سے کہیں گے کہ یہ تمہاری دن رات کی مکاری کا اثر ہے جب تم ہمیں حکم دیتے تھے کہ خدا کا انکار کریں اور اس کے لئے مثل قرار دیں اور عذاب دیکھنے کے بعد لوگ اپنے دل ہی دل میں شرمندہ بھی ہوں گے اور ہم کفر اختیار کرنے والوں کی گردن میں طوق بھی ڈال دیں گے کیا ان کو اس کے علاوہ کوئی بدلہ دیا جائے گا جو اعمال یہ کرتے رہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxl{اور ہم نے کسی بستی میں کوئی ڈرانے والا نہیں بھیجا مگر یہ کہ اس کے بڑے لوگوں نے یہ کہہ دیا کہ ہم تمہارے پیغام کا انکار کرنے والے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxli{اور یہ بھی کہہ دیا کہ ہم اموال اور اولاد کے اعتبار سے تم سے بہتر ہیں اور ہم پر عذاب ہونے والا نہیں ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlii{آ پ کہہ دیجئے کہ میرا پروردگار جس کے رزق میں چاہتا ہے کمی یا زیادتی کردیتا ہے لیکن اکثر لوگ نہیں جانتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliii{اور تمہارے اموال اور اولاد میں کوئی ایسا نہیں ہے جو تمہیں ہماری بارگاہ میں قریب بناسکے علاوہ ان کے جو ایمان لائے اور انہوں نے نیک اعمال کئے تو ان کے لئے ان کے اعمال کا دہرا بدلہ دیا جائے گا اور وہ جھروکوں میں امن وامان کے ساتھ بیٹھے ہوں گے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxliv{اور جو لوگ ہماری نشانیوں کے مقابلہ میں دوڑ دھوپ کررہے ہیں وہ جہّنم کے عذاب میں جھونک دیئے جائیں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlv{بیشک ہمارا پروردگار اپنے بندوں میں جس کے رزق میں چاہتا ہے وسعت پیدا کرتا ہے اور جس کے رزق میں چاہتا ہے تنگی پیدا کرتا ہے اور جو کچھ اس کی راہ میں خرچ کرو گے وہ اس کا بدلہ بہرحال عطا کرے گا اور وہ بہترین رزق دینے والا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvi{اور جس دن خدا سب کو جمع کرے گا اور پھر ملائکہ سے کہے گا کہ کیا یہ لوگ تمہاری ہی عبادت کرتے تھے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvii{تو وہ عرض کریں گے کہ تو پاک و بے نیاز اور ہمارا ولی ہے یہ ہمارے کچھ نہیں ہیں اور یہ جنّات کی عبادت کرتے تھے اور ان کی اکثریت ان ہی پر ایمان رکھتی تھی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlviii{پھر آج کوئی کسی کے نفع اور نقصان کا مالک نہیں ہوگا اور ہم ظلم کرنے والوں سے کہیں گے کہ اس جہّنم کے عذاب کا مزہ چکھو جس کی تکذیب کیا کرتے تھے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcxlix{اور جب ان کے سامنے ہماری روشن آیتوں کی تلاوت کی جاتی ہے تو کہتے ہیں کہ یہ شخص صرف یہ چاہتا ہے کہ تمہیں ان سب سے روک دے جن کی تمہارے آبائ و اجداد پرستش کیا کرتے تھے اور یہ صرف ایک گڑھی ہوئی داستان ہے اور کفاّر تو جب بھی ان کے سامنے حق آتا ہے یہی کہتے ہیں کہ یہ ایک کھلا ہوا جادو ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcl{اور ہم نے انہیں ایسی کتابیں نہیں عطا کی ہیں جنہیں یہ پڑھتے ہوں اور نہ ان کی طرف آپ سے پہلے کوئی ڈرانے والا بھیجا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcli{اور ان کے پہلے والوں نے بھی انبیائ علیھ السّلامکی تکذیب کی ہے حالانکہ ان کے پاس اس کا دسواں حصّہ بھی نہیں ہے جتنا ہم نے ان لوگوں کو عطا کیا تھا مگر انہوں نے بھی رسولوں کی تکذیب کی تو تم نے دیکھا کہ ہمارا عذاب کتنا بھیانک تھا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdclii{پیغمبر آپ کہہ دیجئے کہ میں تمہیں صرف اس بات کی نصیحت کرتا ہوں کہ اللہ کے لئے ایک ایک دو دو کرکے اٹھو اور پھر یہ غور کرو کہ تمہارے ساتھی میں کسی طرح کاجنون نہیں ہے - وہ صرف آنے والے شدید عذاب کے پیش آنے سے پہلے تمہارا ڈرانے والا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcliii{کہہ دیجئے کہ میں جو اجر مانگ رہا ہوں وہ بھی تمہارے ہی لئے ہے میرا حقیقی اجر تو پروردگار کے ذمہ ہے اور وہ ہر شے کا گواہ ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcliv{کہہ دیجئے کہ میرا پروردگار حق کو برابر دل میں ڈالتا رہتا ہے اور وہ برابر غیب کا جاننے والا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdclv{آپ کہہ دیجئے کہ حق آگیا ہے اور باطل نہ کچھ ایجاد کرسکتا ہے اور نہ دوبارہ پلٹا سکتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdclvi{کہہ دیجئے کہ میں گمراہ ہوں گا تو اس کا اثر میرے ہی اوپر ہوگا اور اگر ہدایت حاصل کرلوں گا تو یہ میرے رب کی وحی کا نتیجہ ہوگا وہ سب کی سننے والا اور سب سے قریب تر ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdclvii{اور کاش آپ دیکھئے کہ یہ گھبرائے ہوئے ہوں گے اور بچ نہ سکیں گے اور بہت قریب سے پکڑلئے جائیں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdclviii{اور وہ کہیں گے کہ ہم ایمان لے آئے حالانکہ اتنی دور دراز جگہ سے ایمان تک دسترس کہاں ممکن ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdclix{اور یہ پہلے انکار کرچکے ہیں اور ازغیب باتیں بہت دور تک چلاتے رہے ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdclx{اور اب تو ان کے اور ان چیزوں کے درمیان جن کی یہ خواہش رکھتے ہیں پردے حائل کردیئے گئے ہیں جس طرح ان کے پہلے والوں کے ساتھ کیا گیا تھا کہ وہ لوگ بھی بڑے بے چین کرنے والے شک میں پڑے ہوئے تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdclxi{\basmalahur تمام تعریفیں اس خدا کے لئے ہیں جو آسمان و زمین کا پیدا کرنے والا اور ملائکہ کو اپنا پیغامبر بنانے والا ہے وہ ملائکہ جن کے پر دو دو تین تین اور چار چار ہیں اور وہ خلقت میں جس قدر چاہتا ہے اضافہ کردیتا ہے کہ بیشک وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdclxii{اللرُ انسانوں کے لئے جو رحمت کا دروازہ کھول دے اس کا کوئی روکنے والا نہیں ہے اور جس کو روک دے اس کا کوئی بھیجنے والا نہیں ہے وہ ہر شے پر غالب اور صاحبِ حکمت ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiii{انسانو! اپنے اوپراللہ کی نعمت کو یاد کرو کیا اس کے علاوہ بھی کوئی خالق ہے وہی تمہیں آسمان اور زمین سے روزی دیتا ہے اس کے علاوہ کوئی خدا نہیں ہے تو تم کس طرف بہکے چلے جارہے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdclxiv{اور اگر یہ لوگ آپ کو جھٹلاتے ہیں تو آپ سے پہلے بہت سے رسولوں کو جھٹلایا جاچکا ہے اور تمام امور کی بازگشت خدا ہی کی طرف ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdclxv{انسانو! اللرُ کا وعدہ سچا ہے لہٰذا زندگانی دنیا تم کو دھوکہ میں نہ ڈال دے اور دھوکہ دینے والا تمہیں دھوکہ نہ دے دے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvi{بیشک شیطان تمہارا دشمن ہے تو اسے دشمن سمجھو وہ اپنے گروہ کو صرف اس بات کی طرف دعوت دیتا ہے کہ سب جہنمیوں میں شامل ہوجائیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdclxvii{جن لوگوں نے کفر اختیار کیا ان کے لئے سخت عذاب ہے اور جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ان کے لئے مغفرت اور بہت بڑا اجر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdclxviii{تو کیا وہ شخص جس کے بفِے اعمال کو اس طرح آراستہ کردیا گیا کہ وہ اسے اچھا سمجھنے لگا کسی مومن کے برابر ہوسکتا ہے - اللرُجس کو چاہتا ہے گمراہی میں چھوڑ دیتا ہے اور جس کو چاہتا ہے ہدایت دے دیتا ہے تو آپ افسوس کی بنا پر ان کے پیچھے اپنی جان نہ دے دیںاللہ ان کے کاروبار سے خوب باخبر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdclxix{اللرُ ہی وہ ہے جس نے ہواؤں کو بھیجا تو وہ بادلوں کو منتشر کرتی ہیں اور پھر ہم انہیں مفِدہ شہر تک لے جاتے ہیں اور زمین کے لَردہ ہوجانے کے بعد اسے زندہ کردیتے ہیں اور اسی طرح مفِدے دوبارہ اٹھائے جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdclxx{جو شخص بھی عزّت کا طلبگار ہے وہ سمجھ لے کہ عزّت سب پروردگار کے لئے ہے - پاکیزہ کلمات اسی کی طرف بلند ہوتے ہیں اور عمل صالح انہیں بلند کرتا ہے اور جو لوگ برائیوں کی تدبیریں کرتے ہیں ان کے لئے شدید عذاب ہے اور ان کا مکر بہرحال ہلاک اور تباہ ہونے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxi{اوراللہ ہی نے تم کو خاک سے پیدا کیا پھر نطفہ سے بنایا پھر تمہیں جوڑا قرار دیا اور جو کچھ عورت اپنے شکم میں اٹھاتی ہے یا پیدا کرتی ہے سب اس کے علم سے ہوتا ہے اور کسی بھی طویل العمر کو جو عمر دی جاتی ہے یا عمر میں کمی کی جاتی ہے یہ سب کتاب الٰہی میں مذکور ہے اوراللہ کے لئے یہ سب کام بہت آسان ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxii{اور دو سمندر ایک جیسے نہیں ہوسکتے ایک کا پانی میٹھا اور خوشگوار ہے اور ایک کا کھارا اور کڑوا ہے اور تم دونوں سے تازہ گوشت کھاتے ہو اور ایسے زیورات برآمد کرتے ہو جو تمہارے پہننے کے کام آتے ہیں اور تم کشتیوں کو دیکھتے ہو کہ سمندر کا سینہ چیرتی چلی جاتی ہیں تاکہ تم فضل خدا تلاش کرسکو اور شاید اسی طرح شکر گزار بھی بن سکو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiii{وہ خدا رات کو دن میں داخل کرتا ہے اور دن کو رات میں اس نے سورج اور چاند کو تابع بنادیا ہے اور سب اپنے مقررہ وقت کے مطابق سیر کررہے ہیں وہی تمہارا پروردگار ہے اسی کے اختیار میں سارا ملک ہے اور اس کے علاوہ تم جنہیں آواز دیتے ہووہ خرمہ کی گٹھلی کے چھلکے کے برابر بھی اختیار کے مالک نہیں ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiv{تم انہیں پکارو گے تو تمہاری آواز کو نہ سوُ سکیں گے اور صَن لیں گے تو تمہیں جواب نہ دے سکیں گے اور قیامت کے دن تو تمہاری شرکت ہی کا انکار کردیں گے اور ان کی باتوں کی اطلاع ایک باخبر ہستی کی طرح کوئی دوسرا نہیں کرسکتا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxv{انسانو تم سب اللہ کی بارگاہ کے فقیر ہو اوراللہ صاحب هدولت اور قابلِ حمد و ثنا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvi{وہ چاہے تو تم سب کو اٹھالے جائے اور تمہارے بدلے دوسری مخلوقات لے آئے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvii{اوراللہ کے لئے یہ کوئی مشکل کام نہیں ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxviii{اور کوئی شخص کسی دوسرے کے گناہوں کا بوجھ نہیں اٹھائے گا اور اگر کسی کو اٹھانے کے لئے بلایا بھی جائے گا تو اس میں سے کچھ بھی نہ اٹھایا جاسکے گا چاہے وہ قرابتدار ہی کیوں نہ ہو آپ صرف ان لوگوں کو ڈراسکتے ہیں جو ازغیب خدا سے ڈرنے والے ہیں اور نماز قائم کرنے والے ہیں اور جو بھی پاکیزگی اختیار کرے گا وہ اپنے فائدہ کے لئے کرے گا اور سب کی بازگشت خدا ہی کی طرف ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxix{اور اندھے اور بینا برابر نہیں ہوسکتے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxx{اور تاریکیاں اور نور دونوں برابر نہیں ہوسکتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxi{اور سایہ اور دھوپ دونوں برابر نہیں ہوسکتے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxii{اور زندہ اور مفِدے برابر نہیں ہوسکتے اللہ جس کو چاہتا ہے اپنی بات صَنا دیتا ہے اور آپ انہیں نہیں سناسکتے جو قبروں کے اندر رہنے والے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiii{آپ تو صرف ڈرانے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiv{ہم نے آپ کو حق کے ساتھ بشارت دینے والا اور ڈرانے والا بناکر بھیجا ہے اور کوئی قوم ایسی نہیں ہے جس میں کوئی ڈرانے والا نہ گزرا ہو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxv{اور اگر یہ لوگ آپ کی تکذیب کرتے ہیں تو ان کے پہلے والوں نے بھی یہی کیا ہے جب ان کے پاس مرسلین معجزات, صحیفے اور روشن کتاب لے کر آئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvi{تو ہم نے کافروں کو اپنی گرفت میں لے لیا پھر ہمارا عذاب کیسا بھیانک ہوا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvii{کیا تم نے نہیں دیکھا کہ خدا نے آسمان سے پانی نازل کیا پھر ہم نے اس سے مختلف رنگ کے پھل پیدا کئے اور پہاڑوں میں بھی مختلف رنگوں کے سفید اور سرخ راستے بنائے اور بعض بالکل سیاہ رنگ تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxviii{اور انسانوں اور چوپایوں اور جانوروں میں بھی مختلف رنگ کی مخلوقات پائی جاتی ہیں لیکن اللہ سے ڈرنے والے اس کے بندوں میں صرف صاحبانِ معرفت ہیں بیشک اللہ صاحب هعزّت اور بہت بخشنے والا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxix{یقینا جو لوگ اللہ کی کتاب کی تلاوت کرتے ہیں اور انہوں نے نماز قائم کی ہے اور جو کچھ ہم نے بطور رزق دیا ہے اس میں سے ہماری راہ میں خفیہ اور اعلانیہ خرچ کیا ہے یہ لوگ ایسی تجارت کے امیدوار ہیں جس میں کسی طرح کی تباہی نہیں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcxc{تاکہ خدا ان کا پورا پورا اجر دے اور اپنے فضل و کرم سے اضافہ بھی کردے یقینا وہ بہت زیادہ بخشنے والا اور قدر کرنے والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcxci{اور جس کتاب کی وحی ہم نے آپ کی طرف کی ہے وہ برحق ہے اور اپنے پہلے والی کتابوں کی تصدیق کرنے والی ہے اور بیشک اللہ اپنے بندوں کے حالات سے باخبر اور خوب دیکھنے والا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcii{پھر ہم نے اس کتاب کا وارث ان افراد کو قرار دیا جنہیں اپنے بندوں میں سے چن لیا کہ ان میں سے بعض اپنے نفس پر ظلم کرنے والے ہیں اور بعض اعتدال پسند ہیں اور بعض خدا کی اجازت سے نیکیوں کی طرف سبقت کرنے والے ہیں اور درحقیقت یہی بہت بڑا فضل و شرف ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciii{یہ لوگ ہمیشہ رہنے والی جنّت میں داخل ہوں گے انہیں سونے کے کنگن اور موتی کے زیورات پہنائے جائیں گے اور ان کا لباس جنّت میں ریشم کا ہوگا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcxciv{اور یہ کہیں گے کہ خدا کا شکر ہے کہ اس نے ہم سے رنج و غم کو دور کر دیا اور بیشک ہمارا پروردگار بہت زیادہ بخشنے والا اور قدرداں ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcv{اس نے ہمیں اپنے فضل و کرم سے ایسی رہنے کی جگہ پر وارد کیا ہے جہاں نہ کوئی تھکن ہمیں چھو سکتی ہے اور نہ کوئی تکلیف ہم تک پہنچ سکتی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvi{اور جن لوگوں نے کفر اختیار کیا ان کے لئے آتش جہّنم ہے اور نہ ان کی قضا ہی آئے گی کہ مرجائیں اور نہ عذاب ہی میں کوئی تخفیف کی جائے گی ہم اسی طرح ہر کفر کرنے والے کو سزا دیا کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvii{اور یہ وہاں فریاد کریں گے کہ پروردگار ہمیں نکال لے ہم اب نیک عمل کریں گے اس کے برخلاف جو پہلے کیا کرتے تھے تو کیا ہم نے تمہیں اتنی عمر نہیں دی تھی جس میں عبرت حاصل کرنے والے عبرت حاصل کرسکتے تھے اور تمہارے پاس تو ڈرانے والا بھی آیا تھا لہٰذا اب عذاب کا مزہ چکھو کہ ظالمین کا کوئی مددگار نہیں ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcviii{بیشک اللہ آسمان و زمین کے غیب کا جاننے والا ہے اور وہ دُلوں کے چھپے ہوئے اسرار کو بھی جانتا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcxcix{وہی وہ خدا ہے جس نے تم کو زمین میں اگلوں کا جانشین بنایا ہے اب جو کفر کرے گا وہ اپنے کفر کا ذمہ دار ہوگا اور کفر پروردگار کی نظر میں کافروں کے لئے سوائے غضب الہٰی اور خسارہ کے کسی شے میں اضافہ نہیں کرسکتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcc{آپ کہہ دیجئے کہ کیا تم لوگوں نے ان شرکائ کو دیکھا ہے جنہیں خدا کو چھوڑ کر پکارتے ہو ذرا مجھے بھی دکھلاؤ کہ انہوں نے زمین میں کس چیز کو پیدا کیا ہے یا ان کی کوئی شرکت آسمان میں ہے یا ہم نے انہیں کوئی کتاب دی ہے کہ اس کی طرف سے وہ کسی دلیل کے حامل ہیں - یہ کچھ نہیں ہے اصل یہ ہے کہ ظالمین آپس میں ایک دوسرے سے بھی پرفریب وعدہ ہی کرتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcci{بیشک اللہ زمین و آسمان کو زائل ہونے سے روکے ہوئے ہے اور اس کے علاوہ دوسرا کوئی سنبھالنے والا ہوتا تو اب تک دونوں زائل ہوچکے ہوتے وہ بڑا اَبردبار اور بخشنے والا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccii{اور ان لوگوں نے باقاعدہ قسمیں کھائیں کہ اگر ہمارے پاس کوئی ڈرانے والا آگیا تو ہم تمام اُمّتوں سے زیادہ ہدایت یافتہ ہوں گے لیکن جب وہ ڈرانے والا آگیا تو سوائے نفرت کے کسی شے میں اضافہ نہیں ہوا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcciii{یہ زمین میں استکبار اور بڑی چالوں کا نتیجہ ہے حالانکہ بڑی چالیں چالباز ہی کو اپنے گھیرے میں لے لیتی ہیں تو اب یہ گزشتہ لوگوں کے بارے میں خدا کے طریقہ کار کے علاوہ کسی چیز کا انتظار نہیں کررہے ہیں اور خدا کا طریقہ کار بھی نہ بدلنے والا ہے اور نہ اس میں کسی طرح کا تغیر ہوسکتا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcciv{تو کیا ان لوگوں نے زمین میں سیر نہیں کی کہ دیکھیں ان سے پہلے والوں کا انجام کیا ہوا ہے جب کہ وہ ان سے زیادہ طاقتور تھے اور خدا ایسا نہیں ہے کہ زمین و آسمان کی کوئی شے اسے عاجز بناسکے وہ یقینا ہر شے کا جاننے والا اور اس پر قدرت رکھنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccv{اور اگراللہ تمام انسانوں سے ان کے اعمال کا مواخذہ کرلیتا تو روئے زمین پر ایک رینگنے والے کو بھی نہ چھوڑتا لیکن وہ ایک مخصوص اور معین مدّت تک ڈھیل دیتا ہے اس کے بعد جب وہ وقت آجائے گا تو پروردگار اپنے بندوں کے بارے میں خوب بصیرت رکھنے والا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccvi{\basmalahur یٰسۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccvii{قرآن حکیم کی قسم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccviii{آپ مرسلین میں سے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccix{بالکل سیدھے راستے پر ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccx{یہ قرآن خدائے عزیز و مہربان کا نازل کیا ہوا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxi{تاکہ آپ اس قوم کو ڈرائیں جس کے باپ دادا کو کسی پیغمبر کے ذریعہ نہیں ڈرایا گیا تو سب غافل ہی رہ گئے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxii{یقینا ان کی اکثریت پر ہمارا عذاب ثابت ہوگیا تو وہ ایمان لانے والے نہیں ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiii{ہم نے ان کی گردن میں طوق ڈال دیئے ہیں جو ان کی ٹھڈیوں تک پہنچے ہوئے ہیں اور وہ سر اٹھائے ہوئے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxiv{اور ہم نے ایک دیوار ان کے سامنے اور ایک دیوار ان کے پیچھے بنادی ہے اور پھر انہیں عذاب سے ڈھانک دیا ہے کہ وہ کچھ دیکھنے کے قابل نہیں رہ گئے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxv{اور ان کے لئے سب برابر ہے آپ انہیں ڈرائیں یا نہ ڈرائیں یہ ایمان لانے والے نہیں ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvi{آپ صرف ان لوگوں کو ڈراسکتے ہیں جو نصیحت کا اتباع کریں اور بغیر دیکھے ازغیب خدا سے ڈرتے رہیں ان ہی لوگوں کو آپ مغفرت اور باعزت اجر کی بشارت دے دیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccxvii{بیشک ہم ہی مفِدوں کو زندہ کرتے ہیں اور ان کے گزشتہ اعمال اور ان کے آثار کولکھتے جاتے ہیں اور ہم نے ہر شے کو ایک روشن امام میں جمع کردیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccxviii{اور پیغمبر آپ ان سے بطور مثال اس قریہ والوں کا تذکرہ کریں جن کے پاس ہمارے رسول آئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdccxix{اس طرح کہ ہم نے دو رسولوں کو بھیجا تو ان لوگوں نے جھٹلادیا تو ہم نے ان کی مدد کو تیسرا رسول بھی بھیجا اور سب نے مل کر اعلان کیا کہ ہم سب تمہاری طرف بھیجے گئے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccxx{ان لوگوں نے کہا تم سب ہمارے ہی جیسے بشر ہو اور رحمٰن نے کسی شے کو نازل نہیں کیا ہے تم صرف جھوٹ بولتے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxi{انہوں نے جواب دیا کہ ہمارا پروردگار جانتا ہے کہ ہم تمہاری طرف بھیجے گئے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxii{اور ہماری ذمہ داری صرف واضح طور پر پیغام پہنچادینا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiii{ان لوگوں نے کہا کہ ہمیں تم منحوس معلوم ہوتے ہو اگر اپنی باتوں سے باز نہ آؤ گے تو ہم سنگسار کردیں گے اور ہماری طرف سے تمہیں سخت سزا دی جائے گی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiv{ان لوگوں نے جواب دیا کہ تمہاری نحوست تمہارے ساتھ ہے کیا یہ یاد دہانی کوئی نحوست ہے حقیقت یہ ہے کہ تم زیادتی کرنے والے لوگ ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxv{اور شہر کے ایک سرے سے ایک شخص دوڑتا ہوا آیا اور اس نے کہا کہ قوم والو مرسلین کا اتباع کرو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvi{ان کا اتباع کرو جو تم سے کسی طرح کی اجرت کا سوال نہیں کرتے ہیں اور ہدایت یافتہ ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvii{اور مجھے کیا ہوگیا ہے کہ میں اس کی عبادت نہ کروں جس نے مجھے پیدا کیا ہے اور تم سب اسی کی بارگاہ میں پلٹائے جاؤ گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxviii{کیا میں اس کے علاوہ دوسرے خدا اختیار کرلو ں جب کہ وہ مجھے نقصان پہنچانا چاہے تو کسی کی سفارش کام آنے والی نہیں ہے اور نہ کوئی بچاسکتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxix{میں تو اس وقت کھلی ہوئی گمراہی میں ہوجاؤں گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxx{میں تمہارے پروردگار پر ایمان لایا ہوں لہٰذا تم میری بات سنو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxi{نتیجہ میں اس بندہ سے کہا گیا کہ جنّت میں داخل ہوجا تو اس نے کہا کہ اے کاش میری قوم کو بھی معلوم ہوتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxii{کہ میرے پروردگار نے کس طرح بخش دیا ہے اور مجھے باعزّت لوگوں میں قرار دیا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiii{اور ہم نے اس کی قوم پر اس کے بعد نہ آسمان سے کوئی لشکر بھیجا ہے اور نہ ہم لشکر بھیجنے والے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiv{وہ تو صرف ایک چنگھاڑ تھی جس کے بعد سب کا شعلہ حیات سرد پڑگیا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxv{کس قدر حسرتناک ہے ان بندوں کا حال کہ جب ان کے پاس کوئی رسول آتا ہے تو اس کا مذاق اُڑانے لگتے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvi{کیا ان لوگوں نے نہیں دیکھا کہ ہم نے ان سے پہلے کتنی قوموں کو ہلاک کردیا ہے جو اب ان کی طرف پلٹ کر آنے والی نہیں ہیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvii{اور پھر سب ایک دن اکٹھا ہمارے پاس حاضر کئے جائیں گے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxviii{اور ان کے لئے ہماری ایک نشانی یہ مردہ زمین بھی ہے جسے ہم نے زندہ کیا ہے اور اس میں دانے نکالے ہیں جن میں سے یہ لوگ کھارہے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxix{اور اسی زمین میں اَخرمے اور انگور کے باغات پیدا کئے ہیں اور چشمے جاری کئے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdccxl{تاکہ یہ اس کے پھل کھائیں حالانکہ یہ سب ان کے ہاتھوں کا عمل نہیں ہے پھر آخر یہ ہمارا شکریہ کیوں نہیں ادا کرتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdccxli{پاک و بے نیاز ہے وہ خدا جس نے تمام جوڑوں کو پیدا کیا ہے ان چیزوں میں سے جنہیں زمین اگاتی ہے اور ان کے نفوس میں سے اور ان چیزوں میں سے جن کا انہیں علم بھی نہیں ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlii{اور ان کے لئے ایک نشانی رات ہے جس میں سے ہم کھینچ کر دن کو نکال لیتے ہیں تو یہ سب اندھیرے میں چلے جاتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliii{اور آفتاب اپنے ایک مرکز پر دوڑ رہا ہے کہ یہ خدائے عزیز و علیم کی معین کی ہوئی حرکت ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdccxliv{اور چاند کے لئے بھی ہم نے منزلیں معین کردی ہیں یہاں تک کہ وہ آخر میں پلٹ کر کھجور کی سوکھی ٹہنی جیسا ہوجاتا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlv{نہ آفتاب کے بس میں ہے کہ چاند کو پکڑ لے اور نہ رات کے لئے ممکن ہے کہ وہ دن سے آگے بڑھ جائے .... اور یہ سب کے سب اپنے اپنے فلک اور مدار میں تیرتے رہتے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvi{اور ان کے لئے ہماری ایک نشانی یہ بھی ہے کہ ہم نے ان کے بزرگوں کو ایک بھری ہوئی کشتی میں اٹھایا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvii{اور اس کشتی جیسی اور بہت سی چیزیں پیدا کی ہیں جن پر یہ سوار ہوتے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlviii{اور اگر ہم چاہیں تو سب کو غرق کردیں پھر نہ کوئی ان کافریاد رس پیدا ہوگا اور نہ یہ بچائے جاسکیں گے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdccxlix{مگر یہ کہ خود ہماری رحمت شامل حال ہوجائے اور ہم ایک مدّت تک آرام کرنے دیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdccl{اور جب ان سے کہا جاتا ہے کہ اس عذاب سے ڈرو جو سامنے یا پیچھے سے آسکتا ہے شاید کہ تم پر رحم کیا جائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdccli{تو ان کے پاس خدا کی نشانیوں میں سے کوئی نشانی نہیں آتی ہے مگر یہ کہ یہ کنارہ کشی اختیار کرلیتے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcclii{اور جب کہا جاتا ہے کہ جو رزق خدا نے دیا ہے اس میں سے اس کی راہ میں خرچ کرو تو یہ کفّار صاحبانِ ایمان سے طنزیہ طور پر کہتے ہیں کہ ہم انہیں کیوں کھلائیں جنہیں خدا چاہتا تو خود ہی کھلادیتا تم لوگ تو کِھلی ہوئی گمراہی میں مبتلا ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdccliii{اور پھر کہتے ہیں کہ آخر یہ وعدہ قیامت کب پورا ہوگا اگر تم لوگ اپنے وعدہ میں سچّے ہو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdccliv{درحقیقت یہ صرف ایک چنگھاڑ کا انتظار کررہے ہیں جو انہیں اپنی گرفت میں لے لے گی اور یہ جھگڑا ہی کرتے رہ جائیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcclv{پھر نہ کوئی وصیّت کر پائیں گے اور نہ اپنے اہل کی طرف پلٹ کر ہی جاسکیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvi{اور پھر جب صور پھونکا جائے گا تو سب کے سب اپنی قبروں سے نکل کر اپنے پروردگار کی طرف چل کھڑے ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcclvii{کہیں گے کہ آخر یہ ہمیں ہماری خواب گاہ سے کس نے اٹھادیا ہے .... بیشک یہی وہ چیز ہے جس کا خدا نے وعدہ کیا تھا اور اس کے رسولوں نے سچ کہا تھا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcclviii{قیامت تو صرف ایک چنگھاڑ ہے اس کے بعد سب ہماری بارگاہ میں حاضر کردیئے جائیں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcclix{پھر آج کے دن کسی نفس پر کسی طرح کا ظلم نہیں کیا جائے گا اور تم کو صرف ویسا ہی بدلہ دیا جائے گا جیسے اعمال تم کررہے تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcclx{بیشک اہل جنّت آج کے دن طرح طرح کے مشاغل میں مزے کررہے ہوں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxi{وہ اور ان کی بیویاں سب جنّت کی چھاؤں میں تخت پر تکیئے لگائے آرام کررہے ہوں گے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxii{ان کے لئے تازہ تازہ میوے ہوں گے اور اس کے علاوہ جو کچھ بھی وہ چاہیں گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiii{ان کے حق میں ان کے مہربان پروردگار کا قول صرف سلامتی ہوگا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiv{اور اے مجرمو تم ذرا ان سے الگ تو ہوجاؤ\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxv{اولاد آدم کیا ہم نے تم سے اس بات کا عہد نہیں لیا تھا کہ خبردار شیطان کی عبادت نہ کرنا کہ وہ تمہارا کِھلا ہوا دشمن ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvi{اور میری عبادت کرنا کہ یہی صراط مستقیم اور سیدھا راستہ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvii{اس شیطان نے تم میں سے بہت سی نسلوں کو گمراہ کردیا ہے تو کیا تم بھی عقل استعمال نہیں کرو گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxviii{یہی وہ جہّنم ہے جس کا تم سے دنیا میں وعدہ کیا جارہا تھا\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxix{آج اسی میں چلے جاؤ کہ تم ہمیشہ کفر اختیار کیا کرتے تھے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxx{آج ہم ان کے منہ پرلَہر لگادیں گے اور ان کے ہاتھ بولیں گے اوران کے پاؤں گواہی دیں گے کہ یہ کیسے اعمال انجام دیا کرتے تھے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxi{اور ہم اگر چاہیں تو ان کی آنکھوں کو مٹا دیں پھر یہ راستہ کی طرف قدم بڑھاتے رہیں لیکن کہاں دیکھ سکتے ہیں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxii{اور ہم چاہیں تو خود ان ہی کو بالکل مسخ کردیں جس کے بعد نہ آگے قدم بڑھاسکیں اور نہ پیچھے ہی پلٹ کر واپس آسکیں\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiii{اور ہم جسے طویل عمر دیتے ہیں اسے خلقت میں بچپنے کی طرف واپس کر دیتے ہیں کیا یہ لوگ سمجھتے نہیں ہیں\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiv{اور ہم نے اپنے پیغمبر کو شعر کی تعلیم نہیں دی ہے اور نہ شاعری اس کے شایان شان ہے یہ تو ایک نصیحت اور کِھلا ہوا روشن قرآن ہے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxv{تاکہ اس کے ذریعہ زندہ افراد کو عذاب الہٰی سے ڈرائیں اور کفاّر پر حجّت تمام ہوجائے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvi{کیا ان لوگوں نے نہیں دیکھا کہ ہم نے ان کے فائدے کے لئے اپنے دست قدرت سے چوپائے پیدا کردیئے ہیں تو اب یہ ان کے مالک کہے جاتے ہیں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvii{اور پھر ہم نے ان جانوروں کو رام کردیا ہے تو بعض سے سواری کا کام لیتے ہیں اور بعض کو کھاتے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxviii{اور ان کے لئے ان جانوروں میں بہت سے فوائد ہیں اور پینے کی چیزیں بھی ہیں تو یہ شکر خدا کیوں نہیں کرتے ہیں\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxix{اور ان لوگوں نے خدا کو چھوڑ کر دوسرے خدا بنالئے ہیں کہ شائد ان کی مدد کی جائے گی\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxx{حالانکہ یہ ان کی مدد کی طاقت نہیں رکھتے ہیں اور یہ ان کے ایسے لشکر ہیں جنہیں خود بھی خدا کی بارگاہ میں حاضر کیا جائے گا\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxi{لہٰذا پیغمبر آپ ان کی باتوں سے رنجیدہ نہ ہوں ہم وہ بھی جانتے ہیں جو یہ چھپا رہے ہیں اور وہ بھی جانتے ہیں جس کا یہ اظہار کررہے ہیں\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxii{تو کیا انسان نے یہ نہیں دیکھا کہ ہم نے اسے نطفہ سے پیدا کیا ہے اور وہ یکبارگی ہمارا کھلا ہوا دشمن ہوگیا ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiii{اور ہمارے لئے مثل بیان کرتا ہے اور اپنی خلقت کو بھول گیا ہے کہتا ہے کہ ان بوسیدہ ہڈیوں کو کون زندہ کرسکتا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiv{آپ کہہ دیجئے کہ جس نے پہلی مرتبہ پیدا کیا ہے وہی زندہ بھی کرے گا اور وہ ہر مخلوق کا بہتر جاننے والا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxv{اس نے تمہارے لئے ہرے درخت سے آگ پیدا کردی ہے تو تم اس سے ساری آگ روشن کرتے رہے ہو\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvi{تو کیا جس نے زمین و آسمان کو پیدا کیا ہے وہ اس بات پر قادر نہیں ہے کہ ان کا مثل دوباہ پیدا کردے یقینا ہے اور وہ بہترین پیدا کرنے والا اور جاننے والا ہے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvii{اس کا امر صرف یہ ہے کہ کسی شے کے بارے میں یہ کہنے کا ارادہ کرلے کہ ہوجا اور وہ شے ہوجاتی ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxviii{پس پاک و بے نیاز ہے وہ خدا جس کے ہاتھوں میں ہر شے کا اقتدار ہے اور تم سب اسی کی بارگاہ میں پلٹا کر لے جائے جاؤ گے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxix{\basmalahur باقاعدہ طور پر صفیں باندھنے والوں کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmdccxc{پھر مکمل طریقہ سے تنبیہ کرنے والوں کی قسم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmdccxci{پھر ذکر خدا کی تلاوت کرنے والوں کی قسم\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcii{بیشک تمہارا خدا ایک ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciii{وہ آسمان و زمین اور ان کے مابین کی تمام چیزوں کا پروردگار اور ہر مشرق کا مالک ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmdccxciv{بیشک ہم نے آسمان دنیا کو ستاروں سے مزین بنادیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcv{اور انہیں ہر سرکش شیطان سے حفاظت کا ذریعہ بنادیا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvi{کہ اب شیاطین عالم بالا کیباتیں سننے کی کوشش نہیں کرسکتے اور وہ ہر طرف سے مارے جائیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvii{ہنکانے کے لئے اور ان کے لئے ہمیشہ ہمیشہ کا عذاب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcviii{علاوہ اس کے جو کوئی بات اچک لے تو اس کے پیچھے آگ کا شعلہ لگ جاتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmdccxcix{اب ذرا ان سے دریافت کرو کہ یہ زیادہ دشوار گزار مخلوق ہیں یا جن کو ہم پیدا کرچکے ہیں ہم نے ان سب کو ایک لسدار مٹی سے پیدا کیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmdccc{بلکہ تم تعجب کرتے ہو اور یہ مذاق اڑاتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmdccci{اور جب نصیحت کی جاتی ہے تو قبول نہیں کرتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmdcccii{اور جب کوئی نشانی دیکھ لیتے ہیں تو مسخرا پن کرتے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmdccciii{اور کہتے ہیں کہ یہ تو ایک کھلا ہوا جادو ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmdccciv{کیا جب ہم مرجائیں گے اور مٹی اور ہڈی ہوجائیں گے تو کیا دوبارہ اٹھائیں جائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmdcccv{اور کیا ہمارے اگلے باپ دادا بھی زندہ کئے جائیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvi{کہہ دیجئے کہ بیشک اور تم ذلیل بھی ہوگے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmdcccvii{یہ قیامت تو صرف ایک للکار ہوگی جس کے بعد سب دیکھنے لگیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmdcccviii{اور کہیں گے کہ ہائے افسوس یہ تو قیامت کا دن ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmdcccix{بیشک یہی وہ فیصلہ کا دن ہے جسے تم لوگ جھٹلایا کرتے تھے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmdcccx{فرشتو ذرا ان ظلم کرنے والوں کو اور ان کے ساتھیوں کو اور خدا کے علاوہ جن کی یہ عبادت کیا کرتے تھے سب کو اکٹھا تو کرو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxi{اور ان کے تمام معبودوں کو اور ان کو جہّنم کا راستہ تو بتادو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxii{اور ذرا ان کو ٹہراؤ کہ ابھی ان سے کچھ سوال کیا جائے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiii{اب تمہیں کیا ہوگیا ہے کہ ایک دوسرے کی مدد کیوں نہیں کرتے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiv{بلکہ آج تو سب کے سب سر جھکائے ہوئے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxv{اور ایک دوسرے کی طرف رخ کرکے سوال کررہے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvi{کہتے ہیں کہ تم ہی تو ہو جو ہماری داہنی طرف سے آیا کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvii{وہ کہیں گے کہ نہیں تم خود ہی ایمان لانے والے نہیں تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxviii{اور ہماری تمہارے اوپر کوئی حکومت نہیں تھی بلکہ تم خود ہی سرکش قوم تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxix{اب ہم سب پر خدا کا عذاب ثابت ہوگیا ہے اور سب کو اس کا مزہ چکھنا ہوگا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxx{ہم نے تم کو گمراہ کیا کہ ہم خود ہی گمراہ تھے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxi{تو آج کے دن سب ہی عذاب میں برابر کے شریک ہوں گے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxii{اور ہم اسی طرح مجرمین کے ساتھ برتاؤ کیا کرتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiii{ان سے جب کہا جاتا تھا کہ اللہ کے علاوہ کوئی خدا نہیں ہے تو اکڑ جاتے تھے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiv{اور کہتے تھے کہ کیا ہم ایک مجنون شاعر کی خاطر اپنے خداؤں کو چھوڑ دیں گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxv{حالانکہ وہ حق لے کر آیا تھا اور تمام رسولوں کی تصدیق کرنے والا تھا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvi{بیشک تم سب دردناک عذاب کا مزہ چکھنے والے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvii{اور تمہیں تمہارے اعمال کے مطابق ہی بدلہ دیا جائے گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxviii{علاوہ اللہ کے مخلص بندوں کے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxix{کہ ان کے لئے معین رزق ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxx{میوے ہیں اور وہ باعزت طریقہ سے رہیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxi{نعمتوں سے بھری ہوئی جنّت میں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxii{آمنے سامنے تخت پر بیٹھے ہوئے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiii{ان کے گرد صاف شفاف شراب کا دور چل رہا ہوگا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiv{سفید رنگ کی شراب جس میں پینے والے کو لطف آئے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxv{اس میں نہ کوئی درد سر ہو اور نہ ہوش و حواس گم ہونے پائیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvi{اور ان کے پاس محدود نظر رکھنے والی کشادہ چشم حوریں ہوں گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvii{جن کا رنگ و روغن ایسا ہوگا جیسے چھپائے ہوئے انڈے رکھے ہوئے ہوں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxviii{پھر ایک دوسرے کی طرف رخ کرکے سوال کریں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxix{تو ان میں کا ایک کہے گا کہ دار دنیا میں ہمارا ایک ساتھی بھی تھا\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxl{وہ کہا کرتا تھا کہ کیاتم بھی قیامت کی تصدیق کرنے والوں میں ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxli{کیا جب مرکر مٹی اور ہڈی ہوجائیں گے تو ہمیں ہمارے اعمال کا بدلہ دیا جائے گا\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlii{کیا تم لوگ بھی اسے دیکھو گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliii{یہ کہہ کہ نگاہ ڈالی تو اسے بیچ جہّنم میں دیکھا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliv{کہا کہ خدا کی قسم قریب تھا کہ تو مجھے بھی ہلاک کردیتا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlv{اور میرے پروردگار کا احسان نہ ہوتا تو میں بھی یہیں حاضر کردیا جاتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvi{کیا یہ صحیح نہیں ہے کہ ہم اب مرنے والے نہیں ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvii{سوائے پہلی موت کے اور ہم پر عذاب ہونے والا بھی نہیں ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlviii{یقینا یہ بہت بڑی کامیابی ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlix{اسی دن کے لئے عمل کرنے والوں کو عمل کرنا چاہئے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmdcccl{ذرا بتاؤ کہ یہ ن نعمتیں مہمانی کے واسطے بہتر ہیں یا تھوہڑ کا درخت\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmdcccli{جسے ہم نے ظالمین کی آزمائش کے لئے قرار دیا ہے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmdccclii{یہ ایک درخت ہے جوجہّنم کی تہہ سے نکلتا ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliii{اس کے پھل ایسے بدنما ہیں جیسے شیطانوں کے سر\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmdcccliv{مگر یہ جہنّمی اسی کو کھائیں گے اور اسی سے پیٹ بھریں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmdccclv{پھر ان کے پینے کے لئے گرما گرم پانی ہوگا جس میں پیپ وغیرہ کی آمیزش ہوگی\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvi{پھر ان سب کا آخری انجام جہّنم ہوگا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmdccclvii{انہوں نے اپنے باپ دادا کو گمراہ پایا تھا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmdccclviii{تو ان ہی کے نقش قدم پر بھاگتے چلے گئے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmdccclix{اور یقینا ان سے پہلے بزرگوں کی ایک بڑی جماعت گمراہ ہوچکی ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmdccclx{اور ہم نے ان کے درمیان ڈرانے والے پیغمبر علیھ السّلام بھیجے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxi{تو اب دیکھو کہ جنہیں ڈرایا جاتا ہے ان کے نہ ماننے کا انجام کیا ہوتا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxii{علاوہ ان لوگوں کے جو اللہ کے مخلص بندے ہوتے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiii{اور یقینا نوح علیھ السّلامنے ہم کو آواز دی تو ہم بہترین قبول کرنے والے ہیں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiv{اور ہم نے انہیں اور ان کے اہل کو بہت بڑے کرب سے نجات دے دی ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxv{اور ہم نے ان کی اولاد ہی کو باقی رہنے والوں میں قرار دیا\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvi{اور ان کے تذکرہ کو آنے والی نسلوں میں برقرار رکھا\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvii{ساری خدائی میں نوح علیھ السّلام پر ہمارا سلام\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxviii{ہم اسی طرح نیک عمل کرنے والوں کو جزا دیتے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxix{وہ ہمارے ایماندار بندوں میں سے تھے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxx{پھر ہم نے باقی سب کو غرق کردیا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxi{اور یقینا نوح علیھ السّلام ہی کے پیروکاروں میں سے ابراہیم علیھ السّلام بھی تھے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxii{جب اللہ کی بارگاہ میں قلب سلیم کے ساتھ حاضر ہوئے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiii{جب اپنے مربّی باپ اور اپنی قوم سے کہا کہ تم لوگ کس کی عبادت کررہے ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiv{کیا خدا کو چھوڑ کر ان خود ساختہ خداؤں کے طلب گار بن گئے ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxv{تو پھر رب العالمین کے بارے میں تمہارا کیا خیال ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvi{پھر ابراہیم علیھ السّلام نے ستاروں میں وقت نظر سے کام لیا\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvii{اور کہا کہ میں بیمار ہوں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxviii{تو وہ لوگ منہ پھیر کر چلے گئے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxix{اور ابراہیم علیھ السّلام نے ان کے خداؤں کی طرف رخ کرکے کہا کہ تم لوگ کچھ کھاتے کیوں نہیں ہو\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxx{تمہیں کیا ہوگیا ہے کہ بولتے بھی نہیں ہو\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxi{پھر ان کی مرمت کی طرف متوجہ ہوگئے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxii{تو وہ لوگ دوڑتے ہوئے ابراہیم علیھ السّلام کے پاس آئے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiii{تو ابراہیم علیھ السّلامنے کہا کہ کیا تم لوگ اپے ہاتھوں کے تراشیدہ بتوں کی پرستش کرتے ہو\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiv{جب کہ خدا نے تمہیں اور ان کو سبھی کو پیدا کیا ہے\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxv{ان لوگوں نے کہا کہ ایک عمارت بناکر کر آگ جلا کر انہیں آگ میں ڈال دو\qt@no{(97)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvi{ان لوگوں نے ایک چال چلنا چاہی لیکن ہم نے انہیں پست اور ذلیل کردیا\qt@no{(98)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvii{اور ابراہیم علیھ السّلامنے کہا کہ میں اپنے پروردگار کی طرف جارہا ہوں کہ وہ میری ہدایت کردے گا\qt@no{(99)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxviii{پروردگار مجھے ایک صالح فرزند عطا فرما\qt@no{(100)}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxix{پھر ہم نے انہیں ایک نیک دل فرزند کی بشارت دی\qt@no{(101)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxc{پھر جب وہ فرزند ان کے ساتھ دوڑ دھوپ کرنے کے قابل ہوگیا تو انہوں نے کہا کہ بیٹا میں خواب میں دیکھ رہا ہوں کہ میں تمہیں ذبح کررہا ہوں اب تم بتاؤ کہ تمہارا کیا خیال ہے فرزند نے جواب دیا کہ بابا جو آپ کو حکم دیا جارہا ہے اس پر عمل کریں انشائ اللہ آپ مجھے صبر کرنے والوں میں سے پائیں گے\qt@no{(102)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxci{پھر جب دونوں نے سر تسلیم خم کردیا اور باپ نے بیٹے کو ماتھے کے بل لٹادیا\qt@no{(103)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcii{اور ہم نے آواز دی کہ اے ابراہیم علیھ السّلام\qt@no{(104)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciii{تم نے اپنا خواب سچ کر دکھایا ہم اسی طرح حسن عمل والوں کو جزا دیتے ہیں\qt@no{(105)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciv{بیشک یہ بڑا کھلا ہوا امتحان ہے\qt@no{(106)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcv{اور ہم نے اس کا بدلہ ایک عظیم قربانی کو قرار دے دیا ہے\qt@no{(107)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvi{اور اس کا تذکرہ آخری دور تک باقی رکھا ہے\qt@no{(108)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvii{سلام ہو ابراہیم علیھ السّلامپر\qt@no{(109)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcviii{ہم اسی طرح حَسن عمل والوں کو جزا دیا کرتے ہیں\qt@no{(110)}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcix{بیشک ابراہیم علیھ السّلامہمارے مومن بندوں میں سے تھے\qt@no{(111)}}%
\qt@newcmd\qurantrans@ur@mmmcm{اور ہم نے انہیں اسحاق علیھ السّلامکی بشارت دی جو نبی اور نیک بندوں میں سے تھے\qt@no{(112)}}%
\qt@newcmd\qurantrans@ur@mmmcmi{اور ہم نے ان پر اور اسحاق علیھ السّلامپر برکت نازل کی اور ان کی اولاد میں بعض نیک کردار اور بعض کِھلم کِھلا اپنے نفس پر ظلم کرنے والے ہیں\qt@no{(113)}}%
\qt@newcmd\qurantrans@ur@mmmcmii{اور ہم نے موسٰی علیھ السّلام اور ہارون علیھ السّلامپر بھی احسان کیا ہے\qt@no{(114)}}%
\qt@newcmd\qurantrans@ur@mmmcmiii{اور انہیں اور ان کی قوم کو عظیم کرب سے نجات دلائی ہے\qt@no{(115)}}%
\qt@newcmd\qurantrans@ur@mmmcmiv{اور ان کی مدد کی ہے تو وہ غلبہ حاصل کرنے والوں میں ہوگئے ہیں\qt@no{(116)}}%
\qt@newcmd\qurantrans@ur@mmmcmv{اور ہم نے انہیں واضح مطالب والی کتاب عطا کی ہے\qt@no{(117)}}%
\qt@newcmd\qurantrans@ur@mmmcmvi{اور دونوں کو سیدھے راستہ کی ہدایت بھی دی ہے\qt@no{(118)}}%
\qt@newcmd\qurantrans@ur@mmmcmvii{اور ان کا تذکرہ بھی اگلی نسلوں میں باقی رکھا ہے\qt@no{(119)}}%
\qt@newcmd\qurantrans@ur@mmmcmviii{سلام ہو موسٰی علیھ السّلاماور ہارون علیھ السّلامپر\qt@no{(120)}}%
\qt@newcmd\qurantrans@ur@mmmcmix{ہم اسی طرح نیک عمل کرنے والوں کو بدلہ دیا کرتے ہیں\qt@no{(121)}}%
\qt@newcmd\qurantrans@ur@mmmcmx{بیشک وہ دونوں ہمارے مومن بندوں میں سے تھے\qt@no{(122)}}%
\qt@newcmd\qurantrans@ur@mmmcmxi{اور یقینا الیاس علیھ السّلام بھی مرسلین میں سے تھے\qt@no{(123)}}%
\qt@newcmd\qurantrans@ur@mmmcmxii{جب انہوں نے اپنی قوم سے کہا کہ تم لوگ خدا سے کیوں نہیں ڈرتے ہو\qt@no{(124)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiii{کیا تم لوگ بعل کو آواز دیتے ہو اور بہترین خلق کرنے والے کو چھوڑ دیتے ہو\qt@no{(125)}}%
\qt@newcmd\qurantrans@ur@mmmcmxiv{جب کہ وہ اللہ تمہارے اور تمہارے باپ داد کا پالنے والا ہے\qt@no{(126)}}%
\qt@newcmd\qurantrans@ur@mmmcmxv{پھر ان لوگوں نے رسول کی تکذیب کی تو سب کے سب جہنمّ میں گرفتار کئے جائیں گے\qt@no{(127)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvi{علاوہ اللہ کے مخلص بندوں کے\qt@no{(128)}}%
\qt@newcmd\qurantrans@ur@mmmcmxvii{اور ہم نے ان کا تذکرہ بھی بعد کی نسلوں میں باقی رکھ دیا ہے\qt@no{(129)}}%
\qt@newcmd\qurantrans@ur@mmmcmxviii{سلام ہو آل یاسین علیھ السّلامپر\qt@no{(130)}}%
\qt@newcmd\qurantrans@ur@mmmcmxix{ہم اسی طرح حسوُ عمل والوں کو جزا دیا کرتے ہیں\qt@no{(131)}}%
\qt@newcmd\qurantrans@ur@mmmcmxx{بیشک وہ ہمارے باایمان بندوں میں سے تھے\qt@no{(132)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxi{اور لوط بھی یقینا مرسلین میں تھے\qt@no{(133)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxii{تو ہم نے انہیں اور ان کے تمام گھروالوں کو نجات دے دی\qt@no{(134)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiii{علاوہ ان کی زوجہ کے کہ وہ پیچھے رہ جانے والوں میں شامل ہوگئی تھی\qt@no{(135)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiv{پھر ہم نے سب کو تباہ و برباد بھی کردیا\qt@no{(136)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxv{تم ان کی طرف سے برابر صبح کو گزرتے رہتے ہو\qt@no{(137)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvi{اور رات کے وقت بھی تو کیا تمہیں عقل نہیں آرہی ہے\qt@no{(138)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvii{اور بیشک یونس علیھ السّلام بھی مرسلین میں سے تھے\qt@no{(139)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxviii{جب وہ بھاگ کر ایک بھری ہوئی کشتی کی طرف گئے\qt@no{(140)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxix{اور اہل کشتی نے قرعہ نکالا تو انہیں شرمندگی کا سامنا کرنا پڑا\qt@no{(141)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxx{پھر انہیں مچھلی نے نگل لیا جب کہ وہ خود اپنے نفس کی ملامت کررہے تھے\qt@no{(142)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxi{پھر اگر وہ تسبیح کرنے والوں میں سے نہ ہوتے\qt@no{(143)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxii{تو روزِ قیامت تک اسی کے شکم میں رہ جاتے\qt@no{(144)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiii{پھر ہم نے ان کو ایک میدان میں ڈال دیا جب کہ وہ مریض بھی ہوگئے تھے\qt@no{(145)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiv{اور ان پر ایک کدو کا درخت اُگادیا\qt@no{(146)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxv{اور انہیں ایک لاکھ یا اس سے زیادہ کی قوم کی طرف نمائندہ بناکر بھیجا\qt@no{(147)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvi{تو وہ لوگ ایمان لے آئے اور ہم نے بھی ایک مدّت تک انہیں آرام بھی دیا\qt@no{(148)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvii{پھر اے پیغمبر ان کفار سے پوچھئے کہ کیا تمہارے پروردگار کے پاس لڑکیاں ہیں اور تمہارے پاس لڑکے ہیں\qt@no{(149)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxviii{یا ہم نے ملائکہ کو لڑکیوں کی شکل میں پیدا کیا ہے اور یہ اس کے گواہ ہیں\qt@no{(150)}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxix{آگاہ ہوجاؤ کہ یہ لوگ اپنی من گھڑت کے طور پر یہ باتیں بناتے ہیں\qt@no{(151)}}%
\qt@newcmd\qurantrans@ur@mmmcmxl{کہ اللہ کے یہاں فرزند پیدا ہوا ہے اور یہ لوگ بالکل جھوٹے ہیں\qt@no{(152)}}%
\qt@newcmd\qurantrans@ur@mmmcmxli{کیا اس نے اپنے لئے بیٹوں کے بجائے بیٹیوں کا انتخاب کیا ہے\qt@no{(153)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlii{آخر تمہیں کیا ہوگیا ہے تم کیسا فیصلہ کررہے ہو\qt@no{(154)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliii{کیا تم غور و فکر نہیں کررہے ہو\qt@no{(155)}}%
\qt@newcmd\qurantrans@ur@mmmcmxliv{یا تمہارے پاس اس کی کوئی واضح دلیل ہے\qt@no{(156)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlv{تو اپنی کتاب کو لے آؤ اگر تم اپنے دعویٰ میں سچے ہو\qt@no{(157)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvi{اور انہوں نے خدا اور جّنات کے درمیان بھی رشتہ قرار دے دیا حالانکہ جّنات کو معلوم ہے کہ انہیں بھی خدا کی بارگاہ میں حاضر کیا جائے گا\qt@no{(158)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvii{خدا ان سب کے بیانات سے بلند و برتر اور پاک و پاکیزہ ہے\qt@no{(159)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlviii{علاوہ خدا کے نیک اور مخلص بندوں کے\qt@no{(160)}}%
\qt@newcmd\qurantrans@ur@mmmcmxlix{پھر تم اور جس کی تم پرستش کررہے ہو\qt@no{(161)}}%
\qt@newcmd\qurantrans@ur@mmmcml{سب مل کر بھی اس کے خلاف کسی کو بہکا نہیں سکتے ہو\qt@no{(162)}}%
\qt@newcmd\qurantrans@ur@mmmcmli{علاوہ اس کے جس کو جہّنم میں جانا ہی ہے\qt@no{(163)}}%
\qt@newcmd\qurantrans@ur@mmmcmlii{اور ہم میں سے ہر ایک کے لئے ایک مقام معّین ہے\qt@no{(164)}}%
\qt@newcmd\qurantrans@ur@mmmcmliii{اور ہم اس کی بارگاہ میں صف بستہ کھڑے ہونے والے ہیں\qt@no{(165)}}%
\qt@newcmd\qurantrans@ur@mmmcmliv{اور ہم اس کی تسبیح کرنے والے ہیں\qt@no{(166)}}%
\qt@newcmd\qurantrans@ur@mmmcmlv{اگرچہ یہ لوگ یہی کہا کرتے تھے\qt@no{(167)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvi{کہ اگر ہمارے پاس بھی پہلے والوں کا تذکرہ ہوتا\qt@no{(168)}}%
\qt@newcmd\qurantrans@ur@mmmcmlvii{تو ہم بھی اللہ کے نیک اور مخلص بندے ہوتے\qt@no{(169)}}%
\qt@newcmd\qurantrans@ur@mmmcmlviii{تو پھر ان لوگوں نے کفر اختیار کرلیا تو عنقریب انہیں اس کا انجام معلوم ہوجائے گا\qt@no{(170)}}%
\qt@newcmd\qurantrans@ur@mmmcmlix{اور ہمارے پیغامبربندوں سے ہماری بات پہلے ہی طے ہوچکی ہے\qt@no{(171)}}%
\qt@newcmd\qurantrans@ur@mmmcmlx{کہ ان کی مدد بہرحال کی جائے گی\qt@no{(172)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxi{اور ہمارا لشکر بہرحال غالب آنے والا ہے\qt@no{(173)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxii{لہذا آپ تھوڑے دنوں کے لئے ان سے منہ پھیر لیں\qt@no{(174)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiii{اور ان کو دیکھتے رہیں عنقریب یہ خود اپنے انجام کو دیکھ لیں گے\qt@no{(175)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiv{کیا یہ ہمارے عذاب کے بارے میں جلدی کررہے ہیں\qt@no{(176)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxv{تو جب وہ عذاب ان کے آنگن میں نازل ہوجائے گا تو وہ ڈرائی جانے والی قوم کی بدترین صبح ہوگی\qt@no{(177)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvi{اور آپ تھوڑے دنوں ان سے منہ پھیرلیں\qt@no{(178)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvii{اور دیکھتے رہیں عنقریب یہ خود دیکھ لیں گے\qt@no{(179)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxviii{آپ کا پروردگار جو مالک عزت بھی ہے ان کے بیانات سے پاک و پاکیزہ ہے\qt@no{(180)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxix{اور ہمارا سلام تمام مرسلین پر ہے\qt@no{(181)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxx{اور ساری تعریف اس اللہ کے لئے ہے جو عالمین کا پروردگار ہے\qt@no{(182)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxi{\basmalahur ص ۤ نصیحت والے قرآن کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxii{حقیقت یہ ہے کہ یہ کفاّر غرور اور اختلاف میں پڑے ہوئے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiii{ہم نے ان سے پہلے کتنی نسلوں کو تباہ کردیا ہے پھر انہوں نے فریاد کی لیکن کوئی چھٹکارا ممکن نہیں تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiv{اور انہیں تعجب ہے کہ ان ہی میں سے کوئی ڈرانے والا کیسے آگیا اور کافروں نے صاف کہہ دیا کہ یہ تو جادوگر اور جھوٹا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxv{کیا اس نے سارے خداؤں کو جوڑ کر ایک خدا بنادیا ہے یہ تو انتہائی تعجب خیز بات ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvi{اور ان میں سے ایک گروہ یہ کہہ کر چل دیا چلو اپنے خداؤں پر قائم رہو کہ اس میں ان کی کوئی غرض پائی جاتی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvii{ہم نے تو اگلے دور کی امتوّں میں یہ باتیں نہیں سنی ہیں اور یہ کوئی خود ساختہ بات معلوم ہوتی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxviii{کیا ہم سب کے درمیان تنہا ا ن ہی پر کتاب نازل ہوگئی ہے حقیقت یہ ہے کہ انہیں ہماری کتاب میں شک ہے بلکہ اصل یہ ہے کہ ابھی انہوں نے عذاب کا مزہ ہی نہیں چکھا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxix{کیا ان کے پاس آپ کے صاحبِ عزت و عطا پروردگار کی رحمت کا کوئی خزانہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxx{یا ان کے پاس زمین و آسمان اور اس کے مابین کا اختیار ہے تو یہ سیڑھی لگا کر آسمان پر چڑھ جائیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxi{تمام گروہوں میں سے ایک گروہ یہاں بھی شکست کھانے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxii{اس سے پہلے قوم نوح علیھ السّلام قوم عاد علیھ السّلام اور میخوں والا فرعون سب گزر چکے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiii{اور ثمود, قوم لوط علیھ السّلام, جنگل والے لوگ یہ سب گروہ گزر چکے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiv{ان میں سے ہر ایک نے رسول کی تکذیب کی تو ان پر ہمارا عذاب ثابت ہوگیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxv{یہ صرف اس بات کا انتظار کررہے ہیں کہ ایک ایسی چنگھاڑ بلند ہوجائے جس سے ادنیٰ مہلت بھی نہ مل سکے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvi{اور یہ کہتے ہیں کہ پروردگار ہمارا قسمت کا لکھا ہوا روزِ حساب سے پہلے ہی ہمیں دیدے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvii{آپ ان کی باتوں پر صبر کریں اور ہمارے بندے داؤد علیھ السّلام کو یاد کریں جو صاحب طاقت بھی تھے اور بیحد رجوع کرنے والے بھی تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxviii{ہم نے ان کے لئے پہاڑوں کو لَسّخر کردیا تھا کہ ان کے ساتھ صبح و شام تسبیح پروردگار کریں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxix{اور پرندوں کو ان کے گرد جمع کردیا تھا سب ان کے فرمانبردار تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmcmxc{اور ہم نے ان کے ملک کو مضبوط بنادیا تھا اور انہیں حکمت اور صحیح فیصلہ کی قوت عطا کردی تھی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmcmxci{اور کیا آپ کے پاس ان جھگڑا کرنے والوں کی خبر آئی ہے جو محراب کی دیوار پھاند کر آگئے تھے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcii{کہ جب وہ داؤد علیھ السّلام کے سامنے حاضر ہوئے تو انہوں نے خوف محسوس کیا اور ان لوگوں نے کہا کہ آپ ڈریں نہیں ہم دو فریق ہیں جس میں ایک نے دوسرے پر ظلم کیا ہے آپ حق کے ساتھ فیصلہ کردیں اور ناانصافی نہ کریں اور ہمیں سیدھے راستہ کی ہدایت کردیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciii{یہ ہمارا بھائی ہے اس کے پاس ننانوے رَنبیاں ہیں اور میرے پاس صرف ایک ہے یہ کہتا ہے کہ وہ بھی میرے حوالے کردے اور اس بات میں سختی سے کام لیتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmcmxciv{داؤد علیھ السّلام نے کہا کہ اس نے تمہاری رَنبی کا سوال کرکے تم پر ظلم کیاہے اور بہت سے شرکائ ایسے ہی ہیں کہ ان میں سے ایک دوسرے پر ظلم کرتا ہے علاوہ ان لوگوں کے جو صاحبان هایمان و عمل صالح ہیں اور وہ بہت کم ہیں .... اور داؤد علیھ السّلام نے یہ خیال کیا کہ ہم نے ان کا امتحان لیا ہے لہٰذا انہوں نے اپنے رب سے استغفار کیا اور سجدہ میں گر پڑے اور ہماری طرف سراپا توجہ بن گئے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcv{تو ہم نے اس بات کو معاف کردیا اور ہمارے نزدیک ان کے لئے تقرب اور بہترین بازگشت ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvi{اے داؤد علیھ السّلامہم نے تم کو زمین میں اپنا جانشین بنایا ہے لہٰذا تم لوگوں کے درمیان حق کے ساتھ فیصلہ کرو اور خواہشات کا اتباع نہ کرو کہ وہ راسِ خدا سے منحرف کردیں بیشک جو لوگ راہ هخدا سے بھٹک جاتے ہیں ان کے لئے شدید عذاب ہے کہ انہوں نے روزِ حساب کو یکسر نظرانداز کردیا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvii{اور ہم نے آسمان اور زمین اور اس کے درمیان کی مخلوقات کو بیکار نہیں پیدا کیا ہے یہ تو صرف کافروں کا خیال ہے اور کافروں کے لئے جہّنم میں ویل کی منزل ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcviii{کیا ہم ایمان لانے والے اور نیک عمل کرنے والوں کو زمین میں فساد برپا کرنے والوں جیسا قرار دیدیں یا صاحبانِ تقویٰ کو فاسق و فاجر افراد جیسا قرار دیدیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmcmxcix{یہ ایک مبارک کتاب ہے جسے ہم نے آپ کی طرف نازل کیا ہے تاکہ یہ لوگ اس کی آیتوں میں غور و فکر کریں اور صاحبانِ عقل نصیحت حاصل کریں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmm{اور ہم نے داؤد علیھ السّلام کو سلیمان علیھ السّلام جیسا فرزند عطا کیا جو بہترین بندہ اور ہماری طرف رجوع کرنے والا تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmi{جب ان کے سامنے شام کے وقت بہترین اصیل گھوڑے پیش کئے گئے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmii{تو انہوں نے کہا کہ میں ذکر خدا کی بنا پر خیر کو دوست رکھتا ہوں یہاں تک کہ وہ گھوڑے دوڑتے دوڑتے نگاہوں سے اوجھل ہوگئے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmiii{تو انہوں نے کہا کہ اب انہیں واپس پلٹاؤ اس کے بعد ان کی پنڈلیوں اور گردنوں کو ملنا شروع کردیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmiv{اور ہم نے سلیمان علیھ السّلام کا امتحان لیا جب ان کی کرسی پر ایک بے جان جسم کو ڈال دیا تو پھر انہوں نے خدا کی طرف توجہ کی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmv{اور کہا کہ پروردگار مجھے معاف فرما اور ایک ایسا ملک عطا فرما جو میرے بعد کسی کے لئے سزاوار نہ ہو کہ تو بہترین عطا کرنے والا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmvi{تو ہم نے ہواؤں کو لَسخّر کردیا کہ ان ہی کے حکم سے جہاں جانا چاہتے تھے نرم رفتار سے چلتی تھیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmvii{اور شیاطین میں سے تمام معماروں اور غوطہ خوروں کو تابع بنادیا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmviii{اور ان شیاطین کو بھی جو سرکشی کی بنا پر زنجیروں میں جکڑے ہوئے تھے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmix{یہ سب میری عطا ہے اب چاہے لوگوں کو دیدو یا اپنے پاس رکھو تم سے حساب نہ ہوگا اور ان کے لئے ہمارے یہاں تقرب کا درجہ ہے اور بہترین بازگشت ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmx{یہ سب میری عطا ہے اب چاہے لوگوں کو دیدو یا اپنے پاس رکھو تم سے حساب نہ ہوگا اور ان کے لئے ہمارے یہاں تقرب کا درجہ ہے اور بہترین بازگشت ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxi{اور ہمارے بندے ایوب علیھ السّلام کو یاد کرو جب انہوں نے اپنے پروردگار کو پکارا کہ شیطان نے مجھے بڑی تکلیف اور اذیت پہنچائی ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmxii{تو ہم نے کہا کہ زمین پر پیروں کو رگڑو دیکھو یہ نہانے اور پینے کے لئے بہترین ٹھنڈا پانی ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmxiii{اور ہم نے انہیں ان کے اہل و عیال عطا کردیئے اور اتنے ہی اور بھی دیدئے یہ ہماری رحمت اور صاحبانِ عقل کے لئے عبرت و نصیحت ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmxiv{اور ایوب علیھ السّلام تم اپنے ہاتھوں میں سینکوں کا مٹھا لے کر اس سے مار دو اور قسم کی خلاف ورزی نہ کرو - ہم نے ایوب علیھ السّلامکو صابر پایا ہے - وہ بہترین بندہ اور ہماری طرف رجوع کرنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmxv{اور پیغمبر علیھ السّلام ہمارے بندے ابراہیم علیھ السّلام, اسحاق علیھ السّلام اور یعقوب علیھ السّلام کا ذکر کیجئے جو صاحبانِ قوت اور صاحبانِ بصیرت تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmxvi{ہم نے ان کو آخرت کی یاد کی صفت سے ممتاز قرار دیا تھا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmxvii{اور وہ ہمارے نزدیک منتخب اور نیک بندوں میں سے تھے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmxviii{اور اسماعیل علیھ السّلاماور الیسع علیھ السّلام اور ذوالکفل علیھ السّلام کو بھی یاد کیجئے اور یہ سب نیک بندے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmxix{یہ ایک نصیحت ہے اور صاحبانِ تقویٰ کے لئے بہترین بازگشت ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmxx{ہمیشگی کی جنتیں جن کے دروازے ان کے لئے کھلے ہوئے ہوں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmxxi{وہاں تکیہ لگائے چین سے بیٹھے ہوں گے اور طرح طرح کے میوے اور شراب طلب کریں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmxxii{اور ان کے پہلو میں نیچی نظر والی ہمسن بیبیاں ہوں گی\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiii{یہ وہ چیزیں ہیں جن کا روز قیامت کے لئے تم سے وعدہ کیا گیا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmxxiv{یہ ہمارا رزق ہے جو ختم ہونے والا نہیں ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmxxv{یہ ایک طرف ہے اور سرکشوں کے لئے بدترین بازگشت ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvi{جہّنم ہے جس میں یہ وارد ہوں گے اور وہ بدترین ٹھکانا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmxxvii{یہ ہے عذاب اس کا مزہ چکھیں گرم پانی ہے اور پیپ\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmxxviii{اور اسی قسم کی دوسری چیزیں بھی ہیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmxxix{یہ تمہاری فوج ہے اسے بھی تمہارے ہمرا ہ جہّنم میں ٹھونس دیا جائے گا خدا ان کا بھلا نہ کرے اور یہ سب جہّنم میں جلنے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmxxx{پھر مرید اپنے پیروں سے کہیں گے تمہارا بھلا نہ ہو تم نے اس عذاب کو ہمارے لئے مہیاّ کیا ہے لہٰذا یہ بدترین ٹھکانا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxi{پھر مزید کہیں گے کہ خدایا جس نے ہم کو آگے بڑھایا ہے اس کے عذاب کو جہّنم میں دوگنا کردے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxii{پھر خود ہی کہیں گے کہ ہمیں کیا ہوگیا ہے کہ ہم ان لوگوں کو نہیں دیکھتے جنہیں شریر لوگوں میں شمار کرتے تھے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiii{ہم نے ناحق ان کا مذاق اڑایا تھا یا اب ہماری نگاہیں ان کی طرف سے پلٹ گئی ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiv{یہ اہل جہنمّ کا باہمی جھگڑا ایک امر برحق ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxv{آپ کہہ دیجئے کہ میں تو صرف ڈرانے والا ہوں اور خدائے واحد و قہار کے علاوہ کوئی دوسرا خدا نہیں ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvi{وہی آسمان و زمین اور ان کی درمیانی مخلوقات کا پروردگار اور صاحبِ عزت اور بہت زیادہ بخشنے والا ہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvii{کہہ دیجئے کہ یہ قرآن بہت بڑی خبر ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxviii{تم اس سے اعراض کئے ہوئے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmxxxix{مجھے کیا علم ہوتا کہ عالم بالا میں کیا بحث ہورہی تھی\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmxl{میری طرف تو صرف یہ وحی آتی ہے کہ میں ایک کھلا ہوا عذاب الہٰی سے ڈرانے والا انسان ہوں\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmxli{انہیں یاد دلائیے جب آپ کے پروردگار نے ملائکہ سے کہا کہ میں گیلی مٹی سے ایک بشر بنانے والا ہوں\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmxlii{جب اسے درست کرلوں اور اس میں اپنی روح پھونک دوں تو تم سب سجدہ میں گر پڑنا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmxliii{تو تمام ملائکہ نے سجدہ کرلیا\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmxliv{علاوہ ابلیس کے کہ وہ اکڑ گیا اور کافروں میں ہوگیا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmxlv{تو خدا نے کہا اے ابلیس تیرے لئے کیا شے مانع ہوئی کہ تو اسے سجدہ کرے جسے میں نے اپنے دست قدرت سے بنایا ہے تو نے غرور اختیار کیا یا تو واقعا بلند لوگوں میں سے ہے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvi{اس نے کہا کہ میں ان سے بہتر ہوں تو نے مجھے آگ سے پیدا کیا ہے اور انہیں خاک سے پیدا کیا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmxlvii{ارشاد ہوا کہ یہاں سے نکل جا تو مررَود ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmxlviii{اور یقینا تیرے اوپر قیامت کے دن تک میری لعنت ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmxlix{اس نے کہا پروردگار مجھے روز قیامت تک کی مہلت بھی دیدے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmml{ارشاد ہوا کہ تجھے مہلت دیدی گئی ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmli{مگر ایک معّین وقت کے دن تک\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmlii{اس نے کہا تو پھر تیری عزّت کی قسم میں سب کو گمراہ کروں گا\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmliii{علاوہ تیرے ان بندوں کے جنہیں تو نے خالص بنالیا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmliv{ارشاد ہوا تو پھر حق یہ ہے اور میں تو حق ہی کہتا ہوں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmlv{کہ میں جہنمّ کو تجھ سے اور تیرے پیروکاروں سے بھر دوں گا\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmlvi{اور پیغمبر آپ کہہ دیجئے کہ میں اپنی تبلیغ کا کوئی اجر نہیں چاہتا اور نہ میں بناوٹ کرنے والا غلط بیان ہوں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmlvii{یہ قرآن تو عالمین کے لئے ایک نصیحت ہے\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmlviii{اور کچھ دنوں کے بعد تم سب کو اس کی حقیقت معلوم ہوجائے گی\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmlix{\basmalahur یہ صاحبِ عزت و حکمت خدا کی نازل کی ہوئی کتاب ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmlx{ہم نے آپ کی طرف اس کتاب کو حق کے ساتھ نازل کیا ہے لہٰذا آپ مکمل اخلاص کے ساتھ خدا کی عبادت کریں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmlxi{آگاہ ہوجاؤ کہ خالص بندگی صرف اللہ کے لئے ہے اور جن لوگوں نے اس کے علاوہ سرپرست بنائے ہیں یہ کہہ کر کہ ہم ان کی پرستش صرف اس لئے کرتے ہیں کہ یہ ہمیں اللہ سے قریب کردیں گے - اللہ ان کے درمیان تمام اختلافی مسائل میں فیصلہ کردے گا کہ اللہ کسی بھی جھوٹے اور ناشکری کرنے والے کو ہدایت نہیں دیتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmlxii{اور وہ اگر چاہتا کہ اپنا فرزند بنائے تو اپنی مخلوقات میں جسے چاہتا اس کا انتخاب کرلیتا وہ پاک و بے نیاز ہے اور وہی خدائے یکتا اور قہار ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiii{اس نے آسمان و زمین کو حق کے ساتھ پیدا کیا ہے وہ رات کو دن پر لپیٹ دیتا ہے اور اس نے آفتاب اور ماہتاب کو تابع بنادیا ہے سب ایک مقرّرہ مدّت تک چلتے رہیں گے آگاہ ہوجاؤ وہ سب پر غالب اور بہت بخشنے والا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmlxiv{اس نے تم سب کو ایک ہی نفس سے پیدا کیا ہے اور پھر اسی سے اس کا جوڑا قرار دیا ہے اور تمہارے لئے آٹھ قسم کے چوپائے نازل کئے ہیں. وہ تم کو تمہاری ماؤں کے شکم میں تخلیق کی مختلف منزلوں سے گزارتا ہے اور یہ سب تین تاریکیوں میں ہوتا ہے - وہی اللہ تمہارا پروردگار ہے اسی کے قبضہ میں ملک ہے اس کے علاوہ کوئی خدا نہیں ہے پھر تم کدھر پھرے جارہے ہو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmlxv{اگر تم کافر بھی ہوجاؤ گے تو خدا تم سے بے نیاز ہے اور وہ اپنے بندوں کے لئے کفر کو پسند نہیں کرتا ہے اور اگر تم اس کا شکریہ ادا کرو گے تو وہ اس بات کو پسند کرتا ہے اور کوئی شخص دوسرے کے گناہوں کا بوجھ اٹھانے والا نہیں ہے اس کے بعد تم سب کی بازگشت تمہارے پروردگار کی طرف ہے پھر وہ تمہیں بتائے گا کہ تم دنیا میں کیا کررہے تھے وہ دلوں کے حُھپے ہوئے رازوں سے بھی باخبر ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvi{اور جب انسان کو کوئی تکلیف پہنچتی ہے تو پوری توجہ کے ساتھ پروردگار کو آواز دیتا ہے پھر جب وہ اسے کوئی نعمت دے دیتا ہے تو جس بات کے لئے اس کو پکار رہا تھا اسے یکسر نظرانداز کردیتا ہے اور خدا کے لئے مثل قرار دیتا ہے تاکہ اس کے راستے سے بہکا سکے تو آپ کہہ دیجئے کہ تھوڑے دنوں اپنے کفر میں عیش کرلو اس کے بعد تو تم یقینا جہّنم والوں میں ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmlxvii{کیا وہ شخص جو رات کی گھڑیوں میں سجدہ اور قیام کی حالت میں خدا کی عبادت کرتا ہے اور آخرت کا خوف رکھتا ہے اور اپنے پروردگار کی رحمت کا امیدوار ہے .... کہہ دیجئے کہ کیا وہ لوگ جو جانتے ہیں ان کے برابر ہوجائیں گے جو نہیں جانتے ہیں - اس بات سے نصیحت صرف صاحبانِ عقل حاصل کرتے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmlxviii{کہہ دیجئے کہ اے میرے ایماندار بندو! اپنے پروردگار سے ڈرو . جو لوگ اس دار دنیا میں نیکی کرتے ہیں ان کے لئے نیکی ہے اور اللہ کی زمین بہت وسیع ہے بس صبر کرنے والے ہی وہ ہیں جن کو بے حساب اجر دیا جاتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmlxix{کہہ دیجئے کہ مجھے حکم دیا گیا ہے کہ میں اخلاص عبادت کے ساتھ اللہ کی عبادت کروں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmlxx{اور مجھے حکم دیا گیا ہے کہ میں سب سے پہلا اطاعت گزار بن جاؤں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxi{کہہ دیجئے کہ میں گناہ کروں تو مجھے بڑے سخت دن کے عذاب کا خوف ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxii{کہہ دیجئے کہ میں صرف اللہ کی عبادت کرتا ہوں اور اپنی عبادت میں مخلص ہوں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiii{اب تم جس کی چاہو عبادت کرو کہہ دیجئے کہ حقیقی خسارہ والے وہی ہیں جنہوں نے اپنے نفس اور اپنے اہل کو قیامت کے دن گھاٹے میں رکھا - آگاہ ہوجاؤ یہی کھلا ہوا خسارہ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiv{ان کے لئے اوپر سے جہنمّ کی آگ کے اوڑھنے ہوں گے اور نیچے سے بچھونے - یہی وہ بات ہے جس سے خدا اپنے بندوں کو ڈراتا ہے تو اے میرے بندو مجھ سے ڈرو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxv{اور جن لوگوں نے ظالموں سے علیحدگی اختیار کی کہ ان کی عبادت کریں اور خدا کی طرف متوجہ ہوگئے ان کے لئے ہماری طرف سے بشارت ہے لہذا پیغمبر آپ میرے بندوں کو بشارت دے دیجئے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvi{جو باتوں کو سنتے ہیں اور جو بات اچھی ہوتی ہے اس کا اتباع کرتے ہیں یہی وہ لوگ ہیں جنہیں خدا نے ہدایت دی ہے اور یہی وہ لوگ ہیں جو صاحبانِ عقل ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvii{کیا جس شخص پر کلمہ عذاب ثابت ہوجائے اور کیا جو شخص جہنمّ میں چلا ہی جائے آپ اسے نکال سکتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxviii{البتہ جن لوگوں نے اپنے پروردگار کا خوف پیدا کیا ان کے لئے جنّت کے غرفے ہیں اور ان کے غرفوں پر مزید غرفے ہیں جن کے نیچے نہریں جاری ہوں گی - یہ خدا کا وعدہ ہے اور خدا اپنے وعدہ کے خلاف نہیں کرتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxix{کیا تم نے نہیں دیکھا کہ خدا نے آسمان سے پانی نازل کیا ہے پھر اسے مختلف چشموں میں جاری کردیا ہے پھر اس کے ذریعہ مختلف رنگ کی زراعت پیدا کرتا ہے پھر وہ کھیتی سوکھ جاتی ہے تو اسے زرد رنگ میں دیکھتے ہو پھر اسے بھوسا بنادیتا ہے ان تمام باتوں میں صاحبانِ عقل کے لئے یاددہانی اور نصیحت کا سامان پایا جاتا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxx{کیا وہ شخص جس کے دل کو خدا نے اسلام کے لئے کشادہ کردیا ہے تو وہ اپنے پروردگار کی طرف سے نورانیت کا حامل ہے گمراہوں جیسا ہوسکتا ہے - افسوس ان لوگوں کے حال پر جن کے دل ذکر خدا کے لئے سخت ہوگئے ہیں تو وہ کھلی ہوئی گمراہی میں مبتلا ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxi{اللہ نے بہترین کلام اس کتاب کی شکل میں نازل کیا ہے جس کی آیتیں آپس میں ملتی جلتی ہیں اور بار بار دہرائی گئی ہیں کہ ان سے خوف خدا رکھنے والوں کے رونگٹے کھڑے ہوجاتے ہیں اس کے بعد ان کے جسم اور دل یاد خدا کے لئے نرم ہوجاتے ہیں یہی اللہ کی واقعی ہدایت ہے وہ جس کو چاہتا ہے عطا فرمادیتا ہے اور جس کو وہ گمراہی میں چھوڑ دے اس کا کوئی ہدایت کرنے والا نہیں ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxii{کیا وہ شخص جو روز هقیامت بدترین عذاب کا بچاؤ اپنے چہرہ سے کرنے والا ہے نجات پانے والے کے برابر ہوسکتا ہے اور ظالمین سے تو یہی کہا جائے گا کہ اپنے کرتوت کا مزہ چکھو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiii{اور ان کّفار سے پہلے والوں نے بھی رسولوں علیھ السّلام کو جھٹلایا تو ان پر اس طرح سے عذاب وارد ہوگیا کہ انہیں اس کا شعور بھی نہیں تھا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiv{پھر خدا نے انہیں زندگی دنیا میں ذلّت کا مزہ چکھایا اور آخرت کا عذاب تو بہرحال بہت بڑا ہے اگر انہیں معلوم ہوسکے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxv{اور ہم نے لوگوں کے لئے اس قرآن میں ہر طرح کی مثال بیان کردی ہے کہ شاید یہ عبرت اور نصیحت حاصل کرسکیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvi{یہ عربی زبان کا قرآن ہے جس میں کسی طرح کی کجی نہیں ہے شاید یہ لوگ اسی طرح تقویٰ اختیار کرلیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvii{اللہ نے اس شخص کی مثال بیان کی ہے جس میں بہت سے جھگڑا کرنے والے شرکائ ہوں اور وہ شخص جو ایک ہی شخص کے سپرد ہوجائے کیا دونوں حالات کے اعتبار سے ایک جیسے ہوسکتے ہیں ساری تعریف اللہ کے لئے ہے مگر ان کی اکثریت سمجھتی ہی نہیں ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxviii{پیغمبر آپ کو بھی موت آنے والی ہے اور یہ سب مرجانے والے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxix{اس کے بعد تم سب روز هقیامت پروردگار کی بارگاہ میں اپنے جھگڑے پیش کرو گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmxc{تو اس سے بڑا ظالم کون ہے جو خدا پر بہتان باندھے اور صداقت کے آجانے کے بعد اس کی تکذیب کرے تو کیاجہّنم میں کافرین کا ٹھکانا نہیں ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmxci{اور جو شخص صداقت کا پیغام لے کر آیا اور جس نے اس کی تصدیق کی یہی لوگ درحقیقت صاحبانِ تقویٰ اور پرہیزگار ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmxcii{ان کے لئے پروردگار کے یہاں وہ سب کچھ ہے جو وہ چاہتے ہیں اور یہی نیک عمل والوں کی جزا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmxciii{تاکہ خدا ان برائیوں کو دور کردے جو ان سے سرزد ہوئی ہیں اور ان کا اجر ان کے اعمال سے بہتر طور پر عطا کرے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmxciv{کیا خدا اپنے بندوں کے لئے کافی نہیں ہے اور یہ لوگ آپ کو اس کے علاوہ دوسروں سے ڈراتے ہیں حالانکہ جس کو خدا گمراہی میں چھوڑ دے اس کا کوئی ہدایت کرنے والا نہیں ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmxcv{اور جس کو وہ ہدایت دیدے اس کا کوئی گمراہ کرنے والا نہیں ہے کیا خدا سب سے زیادہ زبردست انتقام لینے والا نہیں ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvi{اور اگر آپ ان سے سوال کریں گے کہ زمین و آسمان کو کس نے پیدا کیا ہے تو کہیں گے کہ اللہ ...._ تو کہہ دیجئے کہ کیا تم نے ان سب کا حال دیکھا ہے جن کی عبادت کرتے ہو کہ اگر خدا نقصان پہنچانے کا ارادہ کرلے تو کیا یہ اس نقصان کو روک سکتے ہیں یا اگر وہ رحمت کا ارادہ کرلے تو کیا یہ اس رحمت کو منع کرسکتے ہیں - آپ کہہ دیجئے کہ میرے لئے میرا خدا کافی ہے اور بھروسہ کرنے والے اسی پر بھروسہ کرتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmxcvii{اور کہہ دیجئے کہ قوم والو تم اپنی جگہ پر عمل کرو اور میں اپنا عمل کررہا ہوں اس کے بعد عنقریب تمہیں سب کا حال معلوم ہوجائے گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmxcviii{کہ کس کے پاس رسوا کرنے والا عذاب آتا ہے اور کس پر ہمیشہ رہنے والا عذاب نازل ہوتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmxcix{ہم نے اس کتاب کو آپ کے پاس لوگوں کی ہدایت کے لئے حق کے ساتھ نازل کیا ہے اب جو ہدایت حاصل کرلے گا وہ اپنے فائدہ کے لئے کرے گا اور جو گمراہ ہوجائے گا وہ بھی اپنا ہی نقصان کرے گا اور آپ ان کے ذمہ دار نہیں ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmc{اللہ ہی ہے جو روحوں کو موت کے وقت اپنی طرف بلالیتا ہے اور جو نہیں مرتے ہیں ان کی روحوں کو بھی نیند کے وقت طلب کرلیتا ہے اور پھر جس کی موت کا فیصلہ کرلیتا ہے اس کی روح کو روک لیتا ہے اور دوسری روحوں کو ایک مقررہ مدّت کے لئے آزاد کردیتا ہے - اس بات میں صاحبان هفکر و نظر کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmci{کیا ان لوگوں نے خدا کو چھوڑ کر سفارش کرنے والے اختیار کرلئے ہیں تو آپ کہہ دیجئے کہ ایسا کیوں ہے چاہے یہ لوگ کوئی اختیار نہ رکھتے ہوں اور کسی طرح کی بھی عقل نہ رکھتے ہوں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcii{کہہ دیجئے کہ شفاعت کا تمام تراختیار اللہ کے ہاتھوں میں ہے اسی کے پاس زمین و آسمان کا سارا اقتدار ہے اور اس کے بعد تم بھی اسی کی بارگاہ میں پلٹائے جاؤ گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmciii{اور جب ان کے سامنے خدائے یکتا کا ذکر آتا ہے تو جن کا ایمان آخرت پر نہیں ہے ان کے دل متنفر ہوجاتے ہیں اور جب اس کے علاوہ کسی اور کا ذکر آتا ہے تو خوش ہوجاتے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmciv{اب آپ کہئے کہ اے پروردگار اے زمین و آسمان کے خلق کرنے والے اور حاضر و غائب کے جاننے والے تو ہی اپنے بندوں کے درمیان ان مسائل کا فیصلہ کرسکتا ہے جن میں یہ آپس میں اختلاف کررہے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcv{اور اگر ظلم کرنے والوں کو زمین کی تمام کائنات مل جائے اور اتنا ہی اور بھی مل جائے تو بھی یہ روزِ قیامت کے بدترین عذاب کے بدلہ میں سب دے دیں گے لیکن ان کے لئے خدا کی طرف سے وہ سب بہرحال ظاہر ہوگا جس کا یہ وہم و گمان بھی نہیں رکھتے تھے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcvi{اور ان کی ساری بدکرداریاں ان پر واضح ہوجائیں گی اور انہیں وہی بات اپنے گھیرے میں لے لے گی جس کا یہ مذاق اڑایا کرتے تھے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcvii{پھر جب انسان کو کوئی تکلیف پہنچتی ہے تو ہمیں پکارتا ہے اور اس کے بعد جب ہم کوئی نعمت دیدیتے ہیں تو کہتا ہے کہ یہ تو مجھے میرے علم کے زور پر دی گئی ہے حالانکہ یہ ایک آزمائش ہے اور اکثر لوگ اس کا علم نہیں رکھتے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcviii{ان سے پہلے والوں نے بھی یہی کہا تھا تو وہ کچھ ان کے کام نہیں آیا جسے وہ حاصل کررہے تھے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcix{بلکہ ان کے اعمال کے برے اثرات ان تک پہنچ گئے اور ان کفاّر میں سے بھی جو لوگ ظلم کرنے والے ہیں ان تک ان کے اعمال کے اِرے اثرت پہنچیں گے اور وہ خدا کو عاجز نہیں کرسکتے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcx{کیا انہیں یہ نہیں معلوم ہے کہ اللہ ہی جس کے رزق کو چاہتا ہے وسیع کردیتا ہے اور جس کے رزق کو چاہتا ہے تنگ کردیتا ہے. ان معاملات میں صاحبان ه ایمان کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcxi{پیغمبر آپ پیغام پہنچادیجئے کہ اے میرے بندو جنہوں نے اپنے نفس پر زیادتی کی ہے رحمت خدا سے مایوس نہ ہونا اللہ تمام گناہوں کا معاف کرنے والا ہے اور وہ یقینا بہت زیادہ بخشنے والا اور مہربان ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcxii{اور تم سب اپنے پروردگار کی طرف رجوع کرو اور اس کے لئے سراپا تسلیم ہوجاؤ قبل اس کے کہ تم تک عذاب آجائے تو پھر تمہاری مدد نہیں کی جاسکتی ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiii{اور تمہارے رب کی طرف سے جو بہترین قانون نازل کیا گیا ہے اس کا اتباع کرو قبل اس کے کہ تم تک اچانک عذاب آجائے اور تمہیں اس کا شعور بھی نہ ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcxiv{پھر تم میں سے کوئی نفس یہ کہنے لگے کہ ہائے افسوس کہ میں نے خدا کے حق میں بڑی کوتاہی کی ہے اور میں مذاق اڑانے والوں میں سے تھا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxv{یا یہ کہنے لگے کہ اگر خدا مجھے ہدایت دے دیتا تو میں بھی صاحبانِ تقویٰ میں سے ہوجاتا\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvi{یا عذاب کے دیکھنے کے بعد یہ کہنے لگے کہ اگر مجھے دوبارہ واپس جانے کا موقع مل جائے تو میں نیک کردار لوگوں میں سے ہوجاؤں گا\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxvii{ہاں ہاں تیرے پاس میری آیتیں آئی تھیں تو تو نے انہیں جھٹلادیا اور تکبر سے کام لیا اور کافروں میں سے ہوگیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxviii{اور تم روزِ قیامت دیکھو گے کہ جن لوگوں نے اللہ پر بہتان باندھا ہے ان کے چہرے سیاہ ہوگئے ہیں اور کیا جہّنم میں تکبر کرنے والوں کا ٹھکانا نہیں ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxix{اور خدا صاحبانِ تقویٰ کو ان کی کامیابی کے سبب نجات دے دے گاکہ کوئی برائی انہیں چھو بھی نہ سکے گی اور نہ انہیں کوئی رنج لاحق ہوگا\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxx{اللہ ہی ہر شے کا خالق ہے اور وہی ہر چیز کی نگرانی کرنے والا ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxi{زمین و آسمان کی تمام کنجیاں اسی کے پاس ہیں اور جن لوگوں نے اس کی آیتوں کا انکار کیا وہی خسارہ میں رہنے والے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxii{آپ کہہ دیجئے کہ اے جاہلو کیا تم مجھے اس بات کا حکم دیتے ہو کہ میں غیر خدا کی عبادت کرنے لگوں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiii{اور یقینا تمہاری طرف اور تم سے پہلے والوں کی طرف یہی وحی کی گئی ہے کہ اگر تم شرک اختیار کرو گے تو تمہارے تمام اعمال برباد کردیئے جائیں گے اور تمہارا شمار گھاٹے والوں میں ہوجائے گا\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiv{تم صرف اللہ کی عبادت کرو اور اس کے شکر گزار بندوں میں ہوجاؤ\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxv{اور ان لوگوں نے واقعا اللہ کی قدر نہیں کی ہے جب کہ روزِ قیامت تمام زمین اسی کی مٹھی میں ہوگی اور سارے آسمان اسی کے ہاتھ میں لپٹے ہوئے ہوں گے وہ پاک و بے نیاز ہے اور جن چیزوں کو یہ اس کا شریک بناتے ہیں ان سے بلند و بالاتر ہے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvi{اور جب صور پھونکا جائے گا تو زمین و آسمان کی تمام مخلوقات بیہوش ہوکر گر پڑیں گی علاوہ ان کے جنہیں خدا بچانا چاہے - اس کے بعد پھر دوبارہ پھونکا جائے گا تو سب کھڑے ہوکر دیکھنے لگیں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvii{اور زمین اپنے رب کے نور سے جگمگا اٹھے گی اور اعمال کی کتاب رکھ دی جائے گی اور انبیائ علیھ السّلام اور شہدائ کو لایا جائے گا اور ان کے درمیان حق و انصاف کے ساتھ فیصلہ کیا جائے گا اور کسی پر ظلم نہیں کیا جائے گا\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxviii{اور پھر ہر نفس کو اس کے اعمال کا پورا پورا بدلہ دیا جائے گا اور وہ سب کے اعمال سے پورے طور سے باخبر ہے\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxix{اور کفر اختیار کرنے والوں کو گروہ در گروہ جہّنم کی طرف ہنکایا جائے گا یہاں تک کہ اس کے سامنے پہنچ جائیں گے تو اس کے دروازے کھول دیئے جائیں گے اور اس کے خازن سوال کریں گے کیا تمہارے پاس رسول نہیں آئے تھے جو آیااُ رب کی تلاوت کرتے اور تمہیں آج کے دن کی ملاقات سے ڈراتے تو سب کہیں گے کہ بیشک رسول آئے تھے لیکن کافرین کے حق میں کلمئہ عذاب بہرحال ثابت ہوچکا ہے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxx{تو کہا جائے گا کہ اب جہّنم کے دروازوں سے داخل ہوجاؤ اور اسی میں ہمیشہ ہمیشہ رہو کہ تکبّر کرنے والوں کا بہت اِرا ٹھکانا ہوتا ہے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxi{اور جن لوگوں نے اپنے رب کا تقویٰ اختیار کیا انہیں جنّت کی طرف گروہ در گروہ لے جایا جائے گا یہاں تک کہ جب اس کے قریب پہنچیں گے اور اس کے دروازے کھول دیئے جائیں گے تو اس کے خزانہ دار کہیں گے کہ تم پر ہمارا سلام ہو تم پاک و پاکیزہ ہو لہٰذا ہمیشہ کے لئے جنت میں داخل ہوجاؤ\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxii{اور وہ کہیں گے کہ شکر خدا ہے کہ اس نے ہم سے کئے ہوئے اپنے وعدہ کو سچ کر دکھایا ہے اور ہمیں اپنی زمین کا وارث بنادیا ہے کہ جنت میں جہاں چاہیں آرام کریں اور بیشک یہ عمل کرنے والوں کا بہترین اجر ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiii{اور تم دیکھو گے کہ ملائکہ عرش الہٰی کے گرد گھیرا ڈالے ہوئے اپنے رب کی حمد کی تسبیح کررہے ہیں اور لوگوں کے درمیان حق و انصاف کے ساتھ فیصلہ کردیا جائے گا اور ہر طرف ایک ہی آواز ہوگی کہ الحمدللہ رب العالمین\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiv{\basmalahur حم ۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxv{یہ خدائے عزیز و علیم کی طرف سے نازل کی ہوئی کتاب ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvi{وہ گناہوں کا بخشنے والا, توبہ کا قبول کرنے والا, شدید عذاب کرنے والا اور صاحب هفضل و کرم ہے - اس کے علاوہ دوسرا خدا نہیں ہے اور سب کی بازگشت اسی کی طرف ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvii{اللہ کی نشانیوں میں صرف وہ جھگڑا کرتے ہیں جو کافر ہوگئے ہیں لہٰذا ان کا مختلف شہروں میں چکر لگانا تمہیں دھوکہ میں نہ ڈال دے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxviii{ان سے پہلے بھی نوح علیھ السّلام کی قوم اور اس کے بعد والے گروہوں نے رسولوں کی تکذیب کی ہے اور ہر امت نے اپنے رسول کے بارے میں یہ ارادہ کیا ہے کہ اسے گرفتار کرلیں اور باطل کا سہارا لے کر جھگڑا کیا ہے کہ حق کو اُ کھاڑ کر پھینک دیں تو ہم نے بھی انہیں اپنی گرفت میں لے لیا تو تم نے دیکھا کہ ہمارا عذاب کیسا تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxix{اور اسی طرح تمہارے پروردگار کا عذاب کافروں پر ثابت ہوچکا ہے کہ و ہ جہّنم میں جانے والے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcxl{جو فرشتے عرش الہٰی کو اٹھائے ہوئے ہیں اور جو اس کے گرد معین ہیں سب حمد خدا کی تسبیح کررہے ہیں اور اسی پر ایمان رکھتے ہیں اور صاحبانِ ایمان کے لئے استغفار کررہے ہیں کہ خدایا تیری رحمت اور تیرا علم ہر شے پر محیط ہے لہذا ان لوگوں کو بخش دے جنہوں نے توبہ کی ہے اور تیرے راستہ کا اتباع کیا ہے اور انہیںجہّنم کے عذاب سے بچالے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcxli{پروردگار انہیں اور ان کے باپ داداً ازواج اور اولاد میں سے جو نیک اور صالح افراد ہیں ان کو ہمیشہ رہنے والے باغات میں داخل فرما جن کا تونے ان سے وعدہ کیا ہے کہ بیشک تو سب پر غالب اور صاحبِ حکمت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlii{اور انہیں برائیوں سے محفوظ فرما کہ آج جن لوگوں کو تو نے برائیوں سے بچالیا گویا ان ہی پر رحم کیا ہے اور یہ بہت بڑی کامیابی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliii{بیشک جن لوگوں نے کفر اختیار کیا ان سے روزِ قیامت پکار کر کہا جائے گا کہ تم خود جس قدر اپنی جان سے بیزار ہو خدا کی ناراضگی اس سے کہیں زیادہ بڑی ہے کہ تم کو ایمان کی طرف دعوت دی جاتی تھی اور تم کفر اختیار کرلیتے تھے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcxliv{وہ لوگ کہیں گے پروردگار تو نے ہمیں دو مرتبہ موت دی اور دو مرتبہ زندگی عطا کی تو اب ہم نے اپنے گناہوں کا اقرار کرلیا ہے تو کیا اس سے بچ نکلنے کی کوئی سبیل ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlv{یہ سب اس لئے ہے کہ جب خدائے واحد کا نام لیا گیا تو تم لوگوں نے کفر اختیار کیا اور جب شرک کی بات کی گئی تو تم نے فورا مان لیا تو اب فیصلہ صرف خدائے بلند و بزرگ کے ہاتھ میں ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvi{وہی وہ ہے جو تمہیں اپنی نشانیاں دکھلاتا ہے اور تمہارے لئے آسمان سے رزق نازل کرتا ہے اور اس سے وہی نصیحت حاصل کرتا ہے جو اس کی طرف رجوع کرتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvii{لہٰذا تم خالص عبادت کے ساتھ خدا کو پکارو چاہے کافرین کو یہ کتنا ہی ناگوار کیوں نہ ہو\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlviii{وہ خدا بلند درجات کا مالک اور صاحبِ عرش ہے وہ اپنے بندوں میں سے جس پر چاہتا ہے اپنے حکم سے وحی کو نازل کرتا ہے تاکہ ملاقات کے دن سے لوگوں کو ڈرائے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcxlix{جس دن سب نکل کر سامنے آجائیں گے اور خدا پر کوئی بات مخفی نہیں رہ جائے گی - آج کس کا ملک ہے بس خدائے واحد و قہار کا ملک ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcl{آج ہرنفس کو اس کے کئے کا بدلہ دیا جائے گا اور آج کسی طرح کا ظلم نہ ہوسکے گا بیشک اللہ بہت جلد حساب کرنے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcli{اور پیغمبر انہیں آنے والے دن کے عذاب سے ڈرائیے جب دم گھٹ گھٹ کر دل منہ کے قریب آجائیں گے اور ظالمین کے لئے نہ کوئی دوست ہوگا اور نہ سفارش کرنے والا جس کی بات سن لی جائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmclii{وہ خدا نگاہوں کی خیانت کو بھی جانتا ہے اور دلوں کے حُھپے ہوئے بھیدوں سے بھی باخبر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcliii{وہ حق کے ساتھ فیصلہ کرتا ہے اور اس کو چھوڑ کر یہ جن کی عبادت کرتے ہیں وہ تو کوئی فیصلہ بھی نہیں کرسکتے ہیں بیشک اللہ سب کی سننے والا اور سب کچھ دیکھنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcliv{کیا ان لوگوں نے زمین میں سیر نہیں کی کہ دیکھتے کہ ان سے پہلے والوں کا انجام کیا ہوا ہے جو ان سے زیادہ زبردست قوت رکھنے والے تھے اور زمین میں آثار کے مالک تھے پھر خدا نے انہیں ان کے گناہوں کی گرفت میں لے لیا اور اللہ کے مقابلہ میں ان کا کوئی بچانے والا نہیں تھا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmclv{یہ سب اس لئے ہوا کہ ان کے پاس رسول کِھلی ہوئی نشانیاں لے کر آتے تھے تو انہوں نے انکار کردیا تو پھر خدا نے بھی انہیں اپنی گرفت میں لے لیا کہ وہ بہت قوت والا اور سخت عذاب کرنے والا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmclvi{اور ہم نے موسٰی علیھ السّلام کو اپنی نشانیوں اور روشن دلیل کے ساتھ بھیجا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmclvii{فرعون ًہامان اور قارون کی طرف تو ان سب نے کہہ دیا کہ یہ جادوگر اور جھوٹے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmclviii{تو پھر اس کے بعد جب وہ ہماری طرف سے حق لے کر آئے تو ان لوگوں نے کہہ دیا کہ جو ان پر ایمان لے آئیں ان کے لڑکوں کو قتل کردو اور لڑکیوں کو زندہ رکھو اور کافروں کا مکر بہرحال بھٹک جانے والا ہوتا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmclix{اور فرعون نے کہا کہ ذرا مجھے چھوڑ دو میں موسٰی علیھ السّلام کا خاتمہ کردوں اور یہ اپنے رب کو پکاریں - مجھے خوف ہے کہ کہیں یہ تمہارے دین کو بدل نہ دیں اور زمین میں کوئی فساد نہ برپا کردیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmclx{اور موسٰی علیھ السّلام نے کہا کہ میں اپنے اور تمہارے پروردگار کی پناہ حاصل کررہا ہوں ہر اس متکبر کے مقابلہ میں جس کا روز حساب پر ایمان نہیں ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmclxi{اور فرعون والوں میں سے ایک مرد مومن نے جو اپنے ایمان کو حُھپائے ہوئے تھا یہ کہا کہ کیا تم لوگ کسی شخص کو صرف اس بات پر قتل کررہے ہو کہ وہ کہتا ہے کہ میرا پروردگار اللہ ہے اور وہ تمہارے رب کی طرف سے کھلی ہوئی دلیلیں بھی لے کر آیا ہے اور اگر جھوٹا ہے تو اس کے جھوٹ کا عذاب اس کے سر ہوگا اور اگر سچا نکل آیا تو جن باتوں سے ڈرا رہا ہے وہ مصیبتیں تم پر نازل بھی ہوسکتی ہیں - بیشک اللہ کسی زیادتی کرنے والے اور جھوٹے کی رہنمائی نہیں کرتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmclxii{میری قوم والو بیشک آج تمہارے پاس حکومت ہے اور زمین پر تمہارا غلبہ ہے لیکن اگر عذاب خدا آگیا تو ہمیں اس سے کون بچائے گا فرعون نے کہا کہ میں تمہیں وہی باتیں بتارہا ہوں جو میں خود سمجھ رہا ہوں اور میں تمہیں عقلمندی کے راستے کے علاوہ اور کسی راہ کی ہدایت نہیں کررہا ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiii{اور ایمان لانے والے شخص نے کہا کہ اے قوم میں تمہارے بارے میں اس دن جیسے عذاب کا خطرہ محسوس کررہا ہوں جو دوسری قوموں کے عذاب کا دن تھا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmclxiv{قوم نوح, قوم عاد, قوم ثمود اور ان کے بعد والوں جیسا حال اور اللہ یقینا اپنے بندوں پر ظلم کرنا نہیں چاہتا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmclxv{اور اے قوم میں تمہارے بارے میں باہمی فریاد کے دن سے ڈر رہا ہوں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvi{جس دن تم سب پیٹھ پھیر کر بھاگو گے اور اللہ کے مقابلہ میں کوئی تمہارا بچانے والا نہ ہوگا اور جس کو خدا گمراہی میں چھوڑ دے اس کا کوئی ہدایت کرنے والا نہیں ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmclxvii{اور اس سے پہلے یوسف علیھ السّلام بھی تمہارے پاس آئے تھے تو بھی تم ان کے پیغام کے بارے میں شک ہی میں مبتلا رہے یہاں تک کہ جب وہ دنیا سے چلے گئے تو تم نے یہ کہنا شروع کردیا کہ خدا اس کے بعد کوئی رسول نہیں بھیجے گا - اسی طرح خدا زیادتی کرنے والے اور شکی مزاج انسانوں کو ان کی گمراہی میں چھوڑ دیتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmclxviii{جو لوگ کہ آیات الہٰی میں بحث کرتے ہیں بغیر اس کے کہ ان کے پاس خدا کی طرف سے کوئی دلیل آئے وہ اللہ اور صاحبان هایمان کے نزدیک سخت نفرت کے حقدار ہیں اور اللہ اسی طرح ہر مغرور اور سرکش انسان کے دل پر لَہر لگادیتا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmclxix{اور فرعون نے کہا کہ ہامان میرے لئے ایک قلعہ تیار کر کہ میں اس کے اسباب تک پہنچ جاؤں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmclxx{جوکہ آسمان کے راستے ہیں اور اس طرح موسٰی علیھ السّلامکے خدا کو دیکھ لوں اور میرا تو خیال یہ ہے کہ موسٰی علیھ السّلام جھوٹے ہیں اور کوئی خدا نہیں ہے ...... اور اسی طرح فرعون کے لئے اس کی بدعملی کو آراستہ کردیا گیا اور اسے راستہ سے روک دیا گیا اور فرعون کی چالوں کا انجام سوائے ہلاکت اور تباہی کے کچھ نہیں ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxi{اور جو شخص ایمان لے آیا تھا اس نے کہا کہ اے قوم والو میرا اتباع کرو تو میں تمہیں ہدایت کا راستہ دکھاسکتا ہوں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxii{قوم والو ...._ یاد رکھو کہ یہ حیات دنیا صرف چند روزہ لذت ہے اور ہمیشہ رہنے کا گھر صرف آخرت کا گھر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiii{جو بھی کوئی برائی کرے گا اسے ویسا ہی بدلہ دیا جائے گا اور جو نیک عمل کرے گا چاہے وہ مرد ہو یا عورت بشرطیکہ صاحبِ ایمان بھی ہو انہیں جنت میں داخل کیا جائے گا اور وہاں بلِ حساب رزق دیا جائے گا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiv{اور اے قوم والو آخر تمہیں کیا ہوگیا ہے کہ میں تمہیں نجات کی دعوت دے رہا ہوں اور تم مجھے جہّنم کی طرف دعوت دے رہے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxv{تمہاری دعوت یہ ہے کہ میں خدا کا انکار کردوں اور انہیں اس کا شریک بنادوں جن کا کوئی علم نہیں ہے اور میں تم کو اس خدا کی طرف دعوت دے رہا ہوں جو صاحب هعزّت اور بہت زیادہ بخشنے والا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvi{بیشک جس کی طرف تم دعوت دے رہے ہو وہ نہ دنیا میں پکارنے کے قابل ہے اور نہ آخرت میں اور ہم سب کی بازگشت بالآخر اللہ ہی کی طرف ہے اور زیادتی کرنے والے ہی دراصل جہّنم والے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvii{پھر عنقریب تم اسے یاد کرو گے جو میں تم سے کہہ رہا ہوں اور میں تو اپنے معاملات کو پروردگار کے حوالے کررہا ہوں کہ بیشک وہ تمام بندوں کے حالات کا خوب دیکھنے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxviii{تو اللہ نے اس مرد مومن کو ان لوگوں کی چالوں کے نقصانات سے بچالیا اور فرعون والوں کو بدترین عذاب نے گھیر لیا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxix{وہ جہّنم جس کے سامنے یہ ہر صبح و شام پیش کئے جاتے ہیں اور جب قیامت برپا ہوگی تو فرشتوں کو حکم ہوگا کہ فرعون والوں کو بدترین عذاب کی منزل میں داخل کردو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxx{اور اس وقت کو یاد دلاؤ جب یہ سب جہّنم کے اندر جھگڑے کریں گے اور کمزور لوگ مستکبر لوگوں سے کہیں گے کہ ہم تمہاری پیروی کرنے والے تھے تو کیا تم جہّنم کے کچھ حصّہ سے بھی ہمیں بچاسکتے ہو اور ہمارے کام آسکتے ہو\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxi{تو استکبار کرنے والے کہیں گے کہ اب ہم سب کی منزل یہی ہے کہ اللہ بندوں کے درمیان فیصلہ کرچکا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxii{اس کے بعد جہّنم میں رہنے والے جہّنم کے خازنوں سے کہیں گے کہ اپنے پروردگار سے دعا کرو کہ ایک ہی دن ہمارے عذاب میں تخفیف کردے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiii{وہ جواب دیں گے کہ کیا تمہارے پاس تمہارے رسول کھلی ہوئی نشانیاں لے کر نہیں آئے تھے وہ لوگ کہیں گے کہ بیشک آئے تھے تو جواب ملے گا پھر تم خود ہی آواز دو حالانکہ کافروں کی آواز اور فریاد بیکار ہی ثابت ہوگی\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiv{بیشک ہم اپنے رسول اور ایمان لانے والوں کی زندگانی دنیا میں بھی مدد کرتے ہیں اور اس دن بھی مدد کریں گے جب سارے گواہ اٹھ کھڑے ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxv{جس دن ظالمین کے لئے کوئی معذرت کارگر نہ ہوگی اور ان کے لئے لعنت اور بدترین گھر ہوگا\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvi{اور یقینا ہم نے موسٰی علیھ السّلامکو ہدایت عطا کی اور بنیاسرائیل کو کتاب کا وارث بنایا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvii{جو کتاب مجسمئہ ہدایت اور صاحبانِ عقل کے لئے نصیحت کا سامان تھی\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxviii{لہٰذا آپ صبر کریں کہ اللہ کا وعدہ یقینا برحق ہے اور اپنے حق میں استغفار کرتے رہیں اور صبح و شام اپنے پروردگار کی حمد کی تسبیح کرتے رہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxix{بیشک جو لوگ خدا کی طرف سے آنے والی دلیل کے بغیر خدا کی نشانیوں میں بحث کرتے ہیں ان کے دلوں میں بڑائی کے خیال کے علاوہ اور کچھ نہیں ہے اور وہ اس تک پہنچ بھی نہیں سکتے ہیں لہذا آپ خدا کی پناہ طلب کریں کہ وہی سب کی سننے والا اور سب کے حالات کا دیکھنے والا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcxc{بیشک زمین و آسمان کا پیدا کردینا لوگوں کے پیدا کردینے سے کہیں زیادہ بڑا کام ہے لیکن لوگوں کی اکثریت یہ بھی نہیں جانتی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcxci{اور یاد رکھو کہ اندھے اور بینا برابر نہیں ہوسکتے ہیں اور جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ہیں وہ بھی بدکاروں جیسے نہیں ہوسکتے ہیں مگر تم لوگ بہت کم نصیحت حاصل کرتے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcii{بیشک قیامت آنے والی ہے اور اس میں کسی شک کی گنجائش نہیں ہے لیکن لوگوں کی اکثریت اس بات پر ایمان نہیں رکھتی ہے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciii{اور تمہارے پروردگار کا ارشاد ہے کہ مجھ سے دعا کرو میں قبول کروں گا اور یقینا جو لوگ میری عبادت سے اکڑتے ہیں وہ عنقریب ذلّت کے ساتھ جہّنم میں داخل ہوں گے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcxciv{اللہ ہی وہ ہے جس نے تمہارے لئے رات کو پیدا کیا ہے تاکہ تم اس میں سکون حاصل کرسکو اور دن کو روشنی کا ذریعہ قرار دیا ہے بیشک وہ اپنے بندوں پر بہت زیادہ فضل و کرم کرنے والا ہے لیکن لوگوں کی اکثریت اس کا شکریہ ادا نہیں کرتی ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcv{وہی تمہارا پروردگار ہے جو ہر شے کا خالق ہے اور اس کے علاوہ کوئی خدا نہیں ہے تو تم کدھر بہکے جارہے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvi{اسی طرح وہ لوگ بہکائے جاتے ہیں جو اللہ کی نشانیوں کا انکار کردیتے ہیں\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvii{اللہ ہی وہ ہے جس نے تمہارے لئے زمین کو مستقر اور آسمان کو عمارت قرار دیا ہے اور تمہاری صورت کو بہترین صورت بنایا ہے اور تمہیں پاکیزہ رزق عطا کیا ہے. وہی تمہارا پروردگار ہے تو عالمین کا پالنے والا کس قدر برکتوں کا مالک ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcviii{وہ ہمیشہ زندہ رہنے والا ہے اس کے علاوہ کوئی خدا نہیں ہے لہٰذا تم لوگ اخلاص دین کے ساتھ اس کی عبادت کرو کہ ساری تعریف اسی عالمین کے پالنے والے خدا کے لئے ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcxcix{آپ کہہ دیجئے کہ مجھے اس بات سے منع کیا گیا ہے کہ میں ان کی عبادت کروں جنہیں تم خدا کو چھوڑ کر پرستش کے قابل بنائے ہوئے ہو جب کہ میرے پاس کِھلی ہوئی نشانیاں آچکی ہیں اور مجھے حکم دیا گیا ہے کہ میں رب العالمین کا اطاعت گزار بندہ رہوں\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcc{وہی خدا ہے جس نے تم کو مٹی سے پیدا کیا پھر نطفہ سے پھر جمے ہوئے خون سے پھر تم کو بچہ بناکر باہر لاتا ہے پھر زندہ رکھتا ہے کہ توانائیوں کو پہنچو پھر بوڑھے ہوجاؤ اور تم میں سے بعض کو پہلے ہی اٹھالیا جاتا ہے اور تم کو اس لئے زندہ رکھتا ہے کہ اپنی مقررہ مدّت کو پہنچ جاؤ اور شاید تمہیں عقل بھی آجائے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcci{وہی وہ ہے جو حیات بھی دیتا ہے اور موت بھی دیتا ہے پھر جب کسی بات کا فیصلہ کرلیتا ہے تو اس سے کہتا ہے کہ ہوجا اور وہ ہوجاتی ہے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmccii{کیا تم نے ان لوگوں کو نہیں دیکھا ہے جو آیات الہٰی کے بارے میں جھگڑا کرتے ہیں آخر یہ کہاں بھٹکتے چلے جارہے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcciii{جن لوگوں نے کتاب اور ان باتوں کی تکذیب کی جن کو دے کہ ہم نے پیغمبروں کو بھیجا تھا انہیں عنقریب اس کا انجام معلوم ہوجائےگا\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcciv{جب ان کی گردنوں میں طوق اور زنجیریں ڈالی جائیں گی اور انہیں کھینچا جائے گا\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmccv{گرم پانی میں اور اس کے بعد جہّنم میں جھونک دیا جائے گا\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmccvi{پھر یہ کہا جائے گا کہ اب وہ کہاں ہیں جنہیں تم شریک بنایا کرتے تھے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmccvii{خدا کو چھوڑ کر.... تو وہ لوگ جواب دیں گے کہ وہ ہم کو چھوڑ کر گم ہوگئے بلکہ ہم اس کے پہلے کسی کو نہیں پکارا کرتے تھے اور اللہ اسی طرح کافروں کو گمراہی میں چھوڑ دیتا ہے\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmccviii{یہ سب اس بات کا نتیجہ ہے کہ تم لوگ زمین میں باطل سے خوش ہوا کرتے تھے اور اکڑ کر چلا کرتے تھے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmccix{اب جہّنم کے دروازوں سے داخل ہوجاؤ اور اسی میں ہمیشہ رہو کہ اکڑنے والوں کا ٹھکانا بہت اِرا ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmccx{اب آپ صبر کریں کہ خدا کا وعدہ بالکل سچا ہے پھر یا تو ہم جن باتوں کی دھمکی دے رہے ہیں ان میں سے کچھ آپ کو دکھلادیں گے یا آپ کو پہلے ہی اٹھالیں گے تو بھی وہ سب پلٹا کر یہیں لائے جائیں گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmccxi{اور ہم نے آپ سے پہلے بھی بہت سے رسول بھیجے ہیں جن میں سے بعض کا تذکرہ آپ سے کیا ہے اور بعض کا تذکرہ بھی نہیں کیا ہے اور کسی رسول کے امکان میں یہ بات نہیں ہے کہ خدا کی اجازت کے بغیر کوئی معجزہ لے آئے پھر جب حکم خدا آگیا تو حق کے ساتھ فیصلہ کردیا گیا اور اس وقت اہل باطل ہی خسارہ میں رہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmccxii{اللہ ہی وہ ہے جس نے چوپایوں کو تمہارے لئے خلق کیا ہے جن میں سے بعض پر تم سواری کرتے ہو اور بعض کو کھانے میں استعمال کرتے ہو\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiii{اور تمہارے لئے ان میں بہت سے منافع ہیں اور اس لئے بھی کہ تم ان کے ذریعہ اپنی دلی مرادوں تک پہنچ سکو اور تمہیں ان جانوروں پر اور کشتیوں پر سوار کیا جاتا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmccxiv{اور خدا تمہیں اپنی نشانیاں دکھلاتا ہے تو تم اس کی کس کس نشانی سے انکار کرو گے\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmccxv{کیا ان لوگوں نے زمین میں سیر نہیں کی ہے کہ دیکھتے کہ ان سے پہلے والوں کا انجام کیا ہوا ہے جو ان کے مقابلہ میں اکثریت میں تھے اور زیادہ طاقتور بھی تھے اور زمین میں آثار کے مالک تھے لیکن جو کچھ بھی کمایا تھا کچھ کام نہ آیا اور مبتلائے عذاب ہوگئے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvi{پھر جب ان کے پاس رسول معجزات لے کر آئے تو اپنے علم کی بنا پر ناز کرنے لگے اور نتیجہ میں جس بات کا مذاق اُڑا رہے تھے اسی نے انہیں اپنے گھیرے میں لے لیا\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmccxvii{پھر جب انہوں نے ہمارے عذاب کو دیکھا تو کہنے لگے کہ ہم خدائے یکتا پر ایمان لائے ہیں اور جن باتوں کا شرک کیا کرتے تھے سب کا انکار کررہے ہیں\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmccxviii{تو عذاب کے دیکھنے کے بعد کوئی ایمان کام آنے والا نہیں تھا کہ یہ اللہ کا مستقل طریقہ ہے جو اس کے بندوں کے بارے میں گِزر چکا اَہے اور اسی وقت کافر خسارہ میں مبتلا ہوجاتے ہیں\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmccxix{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmccxx{یہ خدائے رحمن و رحیم کی تنزیل ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxi{اس کتاب کی آیتیں تفصیل کے ساتھ بیان کی گئی ہیں عربی زبان کا قرآن ہے اس قوم کے لئے جو سمجھنے والی ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxii{یہ قرآن بشارت دینے والا اور عذاب الہٰی سے ڈرانے والا بناکر نازل کیا گیا ہے لیکن اکثریت نے اس سے اعراض کیا ہے اور وہ کچھ سنتے ہی نہیں ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiii{اور کہتے ہیں کہ ہمارے دل جن باتوں کی تم دعوت دے رہے ہو ان کی طرف سے پردہ میں ہیں اور ہمارے کانوں میں بہراپن ہے اور ہمارے تمہارے درمیان پردہ حائل ہے لہذا تم اپنا کام کرو اور ہم اپنا کام کررہے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiv{آپ کہہ دیجئے کہ میں بھی تمہارا ہی جیسا بشر ہوں لیکن میری طرف برابر وحی آتی ہے کہ تمہارا خدا ایک ہے لہٰذا اس کے لئے استقامت کرو اور اس سے استغفارکرو اور مشرکوں کے حال پر افسوس ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxv{جو لوگ زکوِٰادا نہیں کرتے ہیں اور آخرت کا انکار کرنے والے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvi{بیشک جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے ان کے لئے منقطع نہ ہونے والا اجر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvii{آپ کہہ دیجئے کہ کیا تم لوگ اس خدا کا انکار کرتے ہو جس نے ساری زمین کو دو دن میں پیدا کردیا ہے اور اس کا مثل قرار دیتے ہوئے جب کہ وہ عالمین کا پالنے والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxviii{اور اس نے اس زمین میں اوپر سے پہاڑ قرار دے دیئے ہیںاور برکت رکھ دی ہے اور چار دن کے اندر تمام سامان معیشت کو مقرر کردیا ہے جو تمام طلبگاروں کے لئے مساوی حیثیت رکھتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxix{اس کے بعد اس نے آسمان کا رخ کیا جو بالکل دھواں تھا اور اسے اور زمین کو حکم دیا کہ بخوشی یا بہ کراہت ہماری طرف آؤ تو دونوں نے عرض کی کہ ہم اطاعت گزار بن کر حاضر ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxx{پھر ان آسمانوں کو دو دن کے اندر سات آسمان بنادیئے اور ہر آسمان میں اس کے معاملہ کی وحی کردی اور ہم نے آسمان دنیا کو چراغوں سے آراستہ کردیا ہے اور محفوظ بھی بنادیا ہے کہ یہ خدائے عزیز و علیم کی مقرر کی ہوئی تقدیر ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxi{پھر اگر یہ اعراض کریں تو کہہ دیجئے کہ ہم نے تم کو ویسی ہی بجلی کے عذاب سے ڈرایا ہے جیسی قوم عاد و ثمود پر نازل ہوئی تھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxii{جب ان کے پاس سامنے اور پیچھے سے ہمارے نمائندے آئے کہ اللہ کے علاوہ کسی کی عبادت نہ کرو تو انہوں نے کہہ دیا کہ ہمارا خدا چاہتا تو ملائکہ کو نازل کرتا ہم تمہارے پیغام کے قبول کرنے والے نہیں ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiii{پھر قوم عاد نے زمین میں ناحق بلندی اور برتری سے کام لیا اور یہ کہنا شروع کردیا کہ ہم سے زیادہ طاقت والا کون ہے .... تو کیا ان لوگوں نے یہ نہیں دیکھا کہ جس نے ان سب کو پیدا کیا ہے وہ بہرحال ان سے زیادہ طاقت رکھنے والا ہے لیکن یہ لوگ ہماری نشانیوں کا انکار کرنے والے تھے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiv{تو ہم نے بھی ان کے اوپر تیزوتند آندھی کو ان کی نحوست کے دنوں میں بھیج دیا تاکہ انہیں زندگانی دنیا میں بھی رسوائی کے عذاب کا مزہ چکھائیں اور آخرت کا عذاب تو زیادہ رسوا کن ہے اور وہاں ان کی کوئی مدد بھی نہیں کی جائے گی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxv{اور قوم ثمود کو بھی ہم نے ہدایت دی لیکن ان لوگوں نے گمراہی کو ہدایت کے مقابلہ میں زیادہ پسند کیا تو ذلّت کے عذاب کی بجلی نے انہیں اپنی گرفت میں لے لیا ان اعمال کی بنا پر جو وہ انجام دے رہے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvi{اور ہم نے ان لوگوں کو نجات دے دی جو ایمان لانے والے اور تقویٰ اختیار کرنے والے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvii{اور جس دن دشمنانِ خدا کو جہّنم کی طرف ڈھکیلا جائے گا پھر انہیں زجر و توبیخ کی جائے گی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxviii{یہاں تک کہ جب سب جہّنم کے پاس آئیں گے تو ان کے کان اور ان کی آنکھیں اور جلد سب ان کے اعمال کے بارے میں ان کے خلاف گواہی دیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxix{اور وہ اپنے اعضائ سے کہیں گے کہ تم نے ہمارے خلاف کیسے شہادت دے دی تو وہ جواب دیں گے کہ ہمیں اسی خدا نے گویا بنایا ہے جس نے سب کو گویائی عطا کی ہے اور تم کو بھی پہلے دن اسی نے پیدا کیا ہے اور اب بھی پلٹ کر اسی کی بارگاہ میں جاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxl{اور تم اس بات سے پردہ پوشی نہیں کرتے تھے کہ کہیں تمہارے خلاف تمہارے کان, تمہاری آنکھیں اور گوشت پوست گواہی نہ دے دیں بلکہ تمہارا خیال یہ تھا کہ اللہ تمہارے بہت سے اعمال سے باخبر بھی نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxli{اور یہی خیال جو تم نے اپنے پروردگار کے بارے میں قائم کیا تھا اسی نے تمہیں ہلاک کردیا ہے اور تم خسارہ والوں میں ہوگئے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlii{اب اگر یہ برداشت کریں تو بھی ان کا ٹھکانا جہّنم ہے اور اگر معذرت کرنا چاہیں تو بھی معذرت قبول نہیں کی جائے گی\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliii{اور ہم نے خود بھی ان کے لئے ہم نشین فراہم کردیئے تھے جنہوں نے اس کے پچھلے تمام امور ان کی نظروں میں آراستہ کردیئے تھے اور ان پر بھی وہی عذاب ثابت ہوگیا جو ان کے پہلے انسان اور جنّات کے گروہوں پر ثابت ہوچکا تھا کہ یہ سب کے سب خسارہ والوں میں تھے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxliv{اور کفاّر آپس میں کہتے ہیں کہ اس قرآن کو ہرگز مت سنو اور اس کی تلاوت کے وقت ہنگامہ کرو شاید اسی طرح ان پر غالب آجاؤ\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlv{تو اب ہم ان کفر کرنے والوں کو شدید عذاب کا مزہ چکھائیں گے اور انہیں ان کے اعمال کی بدترین سزادیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvi{یہ دشمنانِ خدا کی صحیح سزا جہّنم ہے جس میں ان کا ہمیشگی کا گھر ہے جو اس بات کی سزا ہے کہ یہ آیات الہیٰہ کا انکار کیا کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvii{اور کفاّر یہ فریاد کریں گے کہ پروردگار ہمیں جنّات و انسان کے ان لوگوں کو دکھلادے جنہوں نے ہم کو گمراہ کیا تھا تاکہ ہم انہیں اپنے قدموں کے نیچے قرار دیدیں اور اس طرح وہ پست لوگوں میں شامل ہوجائیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlviii{بیشک جن لوگوں نے یہ کہا کہ اللہ ہمارا رب ہے اور اسی پر جمے رہے ان پر ملائکہ یہ پیغام لے کر نازل ہوتے ہیں کہ ڈرو نہیں اور رنجیدہ بھی نہ ہو اور اس جنّت سے مسرور ہوجاؤ جس کا تم سے وعدہ کیا جارہا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccxlix{ہم زندگانی دنیا میں بھی تمہارے ساتھی تھے اور آخرت میں بھی تمہارے ساتھی ہیں یہاں جنّت میں تمہارے لئے وہ تمام چیزیں فراہم ہیں جن کے لئے تمہارا دل چاہتا ہے اور جنہیں تم طلب کرو گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccl{یہ بہت زیادہ بخشنے والے مہربان پروردگار کی طرف سے تمہاری ضیافت کا سامان ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccli{اور اس سے زیادہ بہتر بات کس کی ہوگی جو لوگوں کو اللہ کی طرف دعوت دے اور نیک عمل بھی کرے اور یہ کہے کہ میں اس کے اطاعت گزاروں میں سے ہوں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcclii{نیکی اور برائی برابر نہیں ہوسکتی لہٰذا تم برائی کا جواب بہترین طریقہ سے دو کہ اس طرح جس کے اور تمہارے درمیان عداوت ہے وہ بھی ایسا ہوجائے گا جیسے گہرا دوست ہوتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccliii{اور یہ صلاحیت ان ہی کو نصیب ہوتی ہے جو صبر کرنے والے ہوتے ہیں اور یہ بات ان ہی کو حاصل ہوتی ہے جو بڑی قسمت والے ہوتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccliv{اور جب تم میں شیطان کی طرف سے کوئی وسوسہ پیدا ہو تو اللہ کی پناہ طلب کرو کہ وہ سب کی سننے والا اور سب کا جاننے والا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcclv{اور اسی خدا کی نشانیوں میں سے رات و دن اور آفتاب و ماہتاب ہیں لہٰذا آفتاب و ماہتاب کو سجدہ نہ کرو بلکہ اس خدا کو سجدہ کرو جس نے ان سب کو پیدا کیا ہے اگر واقعا اس کے عبادت کرنے والے ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvi{پھر اگر یہ لوگ اکڑ سے کام لیں تو لیں جو لوگ پروردگار کی بارگاہ میں ہیں وہ دن رات اس کی تسبیح کررہے ہیں اور کسی وقت بھی تھکتے نہیں ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcclvii{اور اس کی نشانیوں میں سے یہ بھی ہے کہ تم زمین کو صاف اور مفِدہ دیکھ رہے ہو اور پھر جب ہم نے پانی برسا دیا تو زمین لہلہانے لگی اور اس میں نشوونما پیدا ہوگئی بیشک جس نے زمین کو زندہ کیا ہے وہی مفِدوں کا زندہ کرنے والا بھی ہے اور یقینا وہ ہر شے پر قادر ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcclviii{بیشک جو لوگ ہماری آیات میں ہیرا پھیری کرتے ہیں وہ ہم سے حُھپنے والے نہیں ہیں .سوچو کہ جو شخص جہّنم میں ڈال دیا جائے گا وہ بہتر ہے یا جو روزِ قیامت بے خوف و خطر نظر آئے .تم جو چاہو عمل کرو وہ تمہارے تمام اعمال کا دیکھنے والا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcclix{بیشک جن لوگوں نے قرآن کے آنے کے بعد اس کا انکار کردیا ان کا انجام اِرا ہے اور یہ ایک عالی مرتبہ کتاب ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcclx{جس کے قریب سامنے یا پیچھے کسی طرف سے باطل آبھی نہیں سکتا ہے کہ یہ خدائے حکیم و حمید کی نازل کی ہوئی کتاب ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxi{پیغمبر آپ سے جو کچھ بھی کہا جاتا ہے یہ سب آپ سے پہلے والے رسولوں سے کہا جاچکاُ ہے اور آپ کا پروردگار بخشنے والا بھی ہے اور دردناک عذاب کا مالک بھی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxii{اور اگر ہم اس قرآن کو عجمی زبان میں نازل کردیتے تو یہ کہتے کہ اس کی آیتیں واضح کیوں نہیں ہیں اور یہ عجمی کتاب اور عربی انسان کا ربط کیا ہے. تو آپ کہہ دیجئے کہ یہ کتاب صاحبان ه ایمان کے لئے شفا اور ہدایت ہے اور جو لوگ ایمان نہیں رکھتے ہیں ان کے کانوں میں بہرا پن ہے اور وہ ان کو نظر بھی نہیں آرہا ہے اور ان لوگوں کو بہت دور سے پکارا جائے گا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiii{اور یقینا ہم نے موسٰی کو کتاب دی تو اس میں بھی جھگڑا ڈال دیا گیا اور اگر آپ کے پروردگار کی طرف سے ایک بات پہلے سے طے نہ ہوگئی ہوتی تو اب تک ان کے درمیان فیصلہ کردیا گیا ہوتا اور یقینا یہ بڑے بے چین کردینے والے شک میں مبتلا ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiv{جو بھی نیک عمل کرے گا وہ اپنے لئے کرے گا اور جو اِرا کرے گا اس کا ذمہ دار بھی وہ خود ہی ہوگا اور آپ کا پروردگار بندوں پر ظلم کرنے والا نہیں ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxv{قیامت کا علم اسی کی طرف پلٹا دیا جاتا ہے اور تِوروں سے جو پھل نکلتے ہیں یا عورتوں کو جو حمل ہوتا ہے یا جن بچوں کو وہ پیدا کرتی ہیں یہ سب اسی کے علم کے مطابق ہوتے ہیں اور جس دن وہ پکار کر پوچھے گا کہ میرے شرکائ کہاں ہیں تو مشرکین مجبورا عرض کریں گے کہ ہم پہلے ہی بتاچکے ہیں کہ ہم میں سے کوئی ان سے واقف نہیں ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvi{اور وہ سب گم ہوجائیں گے جنہیں یہ پہلے پکارا کرتے تھے اور اب خیال ہوگا کہ کوئی چھٹکارا ممکن نہیں ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvii{انسان بھلائی کی رَعا کرتے ہوئے کبھی نہیں تھکتا ہے اور جب کوئی تکلیف اسے چھو بھی لیتی ہے تو بالکل مایوس اور بے آس ہوجاتا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxviii{اور اگر ہم اس تکلیف کے بعد پھر اسے رحمت کا مزہ چکھادیں تو فورا یہ کہہ دے گا کہ یہ تو میرا حق ہے اور مجھے تو خیال بھی نہیں ہے کہ قیامت قائم ہونے والی ہے اور اگر میں پروردگار کی طرف پلٹایا بھی گیا تو میرے لئے وہاں بھی نیکیاں ہی ہیں تو پھر ہم بھی کفار کو ضرور بتائیں گے کہ انہوں نے کیا کیا, کیا ہے اور انہیں سخت عذاب کا مزہ چکھائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxix{اور ہم جب انسان کو نعمت دیتے ہیں تو ہم سے کنارہ کش ہوجاتا ہے اور پہلو بدل کر الگ ہوجاتا ہے اور جب برائی پہنچ جاتی ہے تو خوب لمبی چوڑی رَعائیں کرنے لگتا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxx{آپ کہہ دیجئے کہ کیا تمہیں یہ خیال ہے اگر یہ قرآن خدا کی طرف سے ہے اور تم نے اس کا انکار کردیا تو اس سے زیادہ کون گمراہ ہوگا جو اس سے اتنا سخت اختلاف کرنے والا ہو\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxi{ہم عنقریب اپنی نشانیوں کو تمام اطراف عالم میں اور خود ان کے نفس کے اندر دکھلائیں گے تاکہ ان پر یہ بات واضح ہوجائے کہ وہ برحق ہے اور کیا پروردگار کے لئے یہ بات کافی نہیں ہے کہ وہ ہر شے کا گواہ اور سب کا دیکھنے والا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxii{آگاہ ہوجاؤ کہ یہ لوگ اللہ سے ملاقات کی طرف سے شک میں مبتلا ہیں اور آگاہ ہوجاؤ کہ اللہ ہر شے پر احاطہ کئے ہوئے ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiii{\basmalahur حم ۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiv{عۤسۤقۤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxv{اسی طرح خدائے عزیز و حکیم آپ کی طرف اور آپ سے پہلے والوں کی طرف وحی بھیجتا رہتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvi{زمین و آسمان میں جو کچھ بھی ہے سب اسی کی ملکیت ہے اور وہی خدائے بزرگ و برتر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvii{قریب ہے کہ آسمان اس کی ہیبت سے اوپر سے شگافتہ ہوجائیں اور ملائکہ بھی اپنے پروردگار کی حمد کی تسبیح کررہے ہیں اور زمین والوں کے حق میں استغفار کررہے ہیں آگاہ ہوجاؤ کہ خدا ہی وہ ہے جو بہت بخشنے والا اور مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxviii{اور جن لوگوں نے اس کے علاوہ سرپرست بنالئے ہیں اللہ ان سب کے حالات کا نگراں ہے اور پیغمبر آپ کسی کے ذمہ دار نہیں ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxix{اور ہم نے اسی طرح آپ کی طرف عربی زبان میں قرآن کی وحی بھیجی تاکہ آپ مکہ اور اس کے اطراف والوں کو ڈرائیں اور اس دن سے ڈرائیں جس دن سب کو جمع کیا جائے گا اور اس میں کسی شک کی گنجائش نہیں ہے اس دن ایک گروہ جنّت میں ہوگا اور ایک جہّنم میں ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxx{اور اگر خدا چاہتا تو سب کو ایک قوم بنادیتا لیکن وہ جسے چاہتا ہے اسی کو اپنی رحمت میں داخل کرتا ہے اور ظالمین کے لئے نہ کوئی سرپرست ہے اور نہ مددگار\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxi{کیا ان لوگوں نے اس کو چھوڑ کر اپنے لئے سرپرست بنائے ہیں جب کہ وہی سب کا سرپرست ہے اور وہی اَمردوں کو زندہ کرتا ہے اور وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxii{اور تم جس چیز میں بھی اختلاف کرو گے اس کا فیصلہ اللہ کے ہاتھوں میں ہے. وہی میرا پروردگار ہے اور اسی پر میرا بھروسہ ہے اور اسی کی طرف میں رجوع کرتا ہوں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiii{وہ آسمانوں اور زمین کا پیدا کرنے والا ہے اس نے تمہارے نفوس میں سے بھی جوڑا بنایا ہے اور جانوروں میں سے بھی جوڑے بنائے ہیں وہ تم کو اسی جوڑے کے ذریعہ دنیا میں پھیلا رہا ہے اس کا جیسا کوئی نہیں ہے وہ سب کی سننے والا اور ہر چیز کا دیکھنے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiv{آسمان و زمین کی تمام کنجیاں اسی کے اختیار میں ہیں وہ جس کے لئے چاہتا ہے اس کے رزق میں وسعت پیدا کردیتا ہے اور جس کے لئے چاہتا ہے تنگی پیدا کردیتا ہے وہ ہر شے کا خوب جاننے والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxv{اس نے تمہارے لئے دین میں وہ راستہ مقرر کیا ہے جس کی نصیحت نوح کو کی ہے اور جس کی وحی پیغمبر تمہاری طرف بھی کی ہے اور جس کی نصیحت ابراہیم علیھ السّلام, موسٰی علیھ السّلام اور عیسٰی علیھ السّلام کو بھی کی ہے کہ دین کو قائم کرو اور اس میں تفرقہ نہ پیدا ہونے پائے مشرکین کو وہ بات سخت گراں گزرتی ہے جس کی تم انہیں دعوت دے رہے ہو اللہ جس کو چاہتا ہے اپنی بارگاہ کے لئے چن لیتا ہے اور جو اس کی طرف رجوع کرتا ہے اسے ہدایت دے دیتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvi{اور ان لوگوں نے آپس میں تفرقہ اسی وقت پیدا کیا ہے جب ان کے پاس علم آچکا تھا اور یہ صرف آپس کی دشمنی کی بنا پر تھا اور اگر پروردگار کی طرف سے ایک بات پہلے سے ایک مدّت کے لئے طے نہ ہوگئی ہوتی تو اب تک ان کے درمیان فیصلہ ہوچکا ہوتا اور بیشک جن لوگوں کو ان کے بعد کتاب کا وارث بنایا گیا ہے وہ اس کی طرف سے سخت شک میں پڑے ہوئے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvii{لہٰذا آپ اسی کے لئے دعوت دیں اور اس طرح استقامت سے کام لیں جس طرح آپ کو حکم دیا گیا ہے اور ا ن کی خواہشات کا اتباع نہ کریں اور یہ کہیں کہ میرا ایمان اس کتاب پر ہے جو خدا نے نازل کی ہے اور مجھے حکم دیا گیا ہے کہ تمہارے درمیان انصاف کروں اللہ ہمارا اور تمہارا دونوں کا پروردگار ہے ہمارے اعمال ہمارے لئے ہیں اور تمہارے اعمال تمہارے لئے - ہمارے اور تمہارے درمیان کوئی بحث نہیں ہے اللہ ہم سب کو ایک دن جمع کرے گا اور اسی کی طرف سب کی بازگشت ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxviii{اور جو لوگ اس کے مان لئے جانے کے بعد خدا کے بارے میں جھگڑا کرتے ہیں ان کی دلیل بالکل مہمل اور لغو ہے اور ان پر اللہ کا غضب ہے اور ان کے لئے شدید قسم کا عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxix{اللہ ہی وہ ہے جس نے حق کے ساتھ کتاب اور میزان کو نازل کیا ہے اور آپ کو کیا معلوم کہ شاید قیامت قریب ہی ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmccxc{اس کی جلدی صرف وہ لوگ کرتے ہیں جن کا اس پر ایمان نہیں ہے ورنہ جو ایمان والے ہیں وہ تو اس سے خوفزدہ ہی رہتے ہیں اور یہ جانتے ہیں کہ وہ بہرحال برحق ہے ہوشیار کہ جو لوگ قیامت کے بارے میں شک کرتے ہیں وہ گمراہی میں بہت دور تک چلے گئے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmccxci{اللہ اپنے بندوں پر مہربان ہے وہ جس کو بھی چاہتا ہے رزق عطا کرتا ہے اور وہ صاحبِ قوت بھی ہے اور صاحبِ عزت بھی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcii{جو انسان آخرت کی کھیتی چاہتا ہے ہم اس کے لئے اضافہ کردیتے ہیں اور جو دنیا کی کھیتی کا طلبگار ہے اسے اسی میں سے عطا کردیتے ہیں اور پھر آخرت میں اس کا کوئی حصہ نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciii{کیا ان کے لئے ایسے شرکائ بھی ہیں جنہوں نے دین کے وہ راستے مقرّر کئے ہیں جن کی خدا نے اجازت بھی نہیں دی ہے اور اگر فیصلہ کے دن کا وعدہ نہ ہوگیا ہوتا تو اب تک ان کے درمیان فیصلہ کردیا گیا ہوتا اور یقینا ظالموں کے لئے بڑا دردناک عذاب ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmccxciv{آپ دیکھیں گے کہ ظالمین اپنے کرتوت کے عذاب سے خوفزدہ ہیں اور وہ ان پر بہرحال نازل ہونے والا ہے اور جو لوگ ایمان لے آئے اور انہوں نے نیک اعمال کئے ہیں وہ جنّت کے باغات میں رہیں گے اور ان کے لئے پروردگار کی بارگاہ میں وہ تمام چیزیں ہیں جن کے وہ خواہشمند ہوں گے اور یہ ایک بہت بڑا فضل پروردگار ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcv{یہی وہ فضلِ عظیم ہے جس کی بشارت پروردگار اپنے بندوں کو دیتا ہے جنہوں نے ایمان اختیار کیا ہے اور نیک اعمال کئے ہیں تو آپ کہہ دیجئے کہ میں تم سے اس تبلیغ رسالت کا کوئی اجر نہیں چاہتا علاوہ اس کے کہ میرے اقربا سے محبت کرو اور جو شخص بھی کوئی نیکی حاصل کرے گا ہم اس کی نیکی میں اضافہ کردیں گے کہ بیشک اللہ بہت زیادہ بخشنے والا اور قدرداں ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvi{کیا ان لوگوں کا کہنا یہ ہے کہ رسول, اللہ پر جھوٹے بہتان باندھتا ہے جب کہ خدا چاہے تو تمہارے قلب پر بھی مہر لگا سکتا ہے اور خدا تو باطل کو مٹا دیتا ہے اور حق کو اپنے کلمات کے ذریعہ ثابت اور پائیدار بنادیتا ہے یقینا وہ دلوں کے رازوں کا جاننے والا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvii{اور وہی وہ ہے جو اپنے بندوں کی توبہ کوقبول کرتا ہے اور ان کی برائیوں کو معاف کرتا ہے اور وہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcviii{اور جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے وہی دعوت الٰہٰی کو قبول کرتے ہیں اور خدا اپنے فضل و کرم سے ان کے اجر میں اضافہ کردیتا ہے اور کافرین کے لئے تو بڑا سخت عذاب رکھا گیا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccxcix{اور اگر خدا تمام بندوں کے لئے رزق کو وسیع کردیتا ہے تو یہ لوگ زمین میں بغاوت کردیتے مگر وہ اپنی مشیت کے مطابق معیّنہ مقدار میں نازل کرتا ہے کہ وہ اپنے بندوں سے خوب باخبر ہے اوران کے حالات کا دیکھنے والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmccc{وہی وہ ہے جو ان کے مایوس ہوجانے کے بعد بارش کو نازل کرتاہے اور اپنی رحمت کو منتشر کرتا ہے اور وہی قابل تعریف مالک اور سرپرست ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmccci{اور اس کی نشانیوں میں سے زمین و آسمان کی خلقت اور ان کے اندر چلنے والے تمام جاندارہیں اور وہ جب چاہے ان سب کو جمع کرلینے پر قدرت رکھنے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcccii{اور تم تک جو مصیبت بھی پہنچتی ہے وہ تمہارے ہاتھوں کی کمائی ہے اور وہ بہت سی باتوں کو معاف بھی کردیتاہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccciii{اور تم زمین میں خدا کو عاجز نہیں کرسکتے ہو اورتمہارے لئے اس کے علاوہ کوئی سرپرست اور مددگار بھی نہیں ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccciv{اور اس کی نشانیوں میں سے سمندر میں چلنے والے بادبانی جہاز بھی ہیں جو پہاڑ کی طرح بلند ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcccv{وہ اگر چاہے تو ہوا کو ساکن بنادے تو سب سطح آب پر جم کر رہ جائیں - بیشک اس حقیقت میں صبر وشکر کرنے والوں کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvi{یا وہ انہیں ان کے اعمال کی بنا پرہلاک ہی کردے اور وہ بہت سی باتوں کو معاف بھی کردیتا ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcccvii{اور ہماری آیتوں میں جھگڑا کرنے والوں کو معلوم ہوجانا چاہئے کہ ان کے لئے کوئی چھٹکارا نہیں ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcccviii{پس تم کو جو کچھ بھی دیا گیا ہے وہ زندگانی دنیا کا چین ہے اوربس اور جو کچھ اللہ کی بارگاہ میں ہے وہ خیر اورباقی رہنے والا ہے ان لوگوں کے لئے جو ایمان رکھتے ہیں اوراپنے پروردگار پربھروسہ کرتے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcccix{اوربڑے بڑے گناہوں اور فحش باتوں سے پرہیز کرتے ہیں اور جب غصّہ آجاتا ہے تو معاف کردیتے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcccx{اور جو اپنے رب کی بات کو قبول کرتے ہیں اور نماز قائم کرتے ہیں اور آپس کے معاملات میں مشورہ کرتے ہیں اور ہمارے رزق میں سے ہماری راہ میں خرچ کرتے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxi{اورجب ان پر کوئی ظلم ہوتا ہے تو اس کا بدلہ لے لیتے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxii{اور ہر برائی کابدلہ اس کے جیسا ہوتا ہے پھرجو معاف کردے اور اصلاح کردے اس کااجر اللہ کے ذمہ ہے وہ یقینا ظالموں کو دوست نہیں رکھتا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiii{اورجو شخض بھی ظلم کے بعد بدلہ لے اس کے اوپرکوئی الزام نہیں ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiv{الزام ان لوگوں پر ہے جولوگوں پر ظلم کرتے ہیں اور زمین میں ناحق زیادتیاں پھیلاتے ہیں ان ہی لوگوں کے لئے دردناک عذاب ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxv{اوریقینا جو صبر کرے اور معاف کردے تو اس کایہ عمل بڑے حوصلے کا کام ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvi{اور جس کوخدا گمراہی میں چھوڑ دے اس کے لئے اس کے بعد کوئی ولی اور سرپرست نہیں ہے اورتم دیکھو گے کہ ظالمین عذاب کو دیکھنے کے بعد یہ کہیں گے کہ کیا واپسی کا کوئی راستہ نکل سکتا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvii{اور تم انہیں دیکھو گے کہ وہ جہنمّ کے سامنے پیش کئے جائیں گے تو ذلّت سے ان کے سر جھکے ہوئے ہوں گے اور وہ کن انکھیوں سے دیکھتے بھی جائیں گے اور صاحبانِ ایمان کہیں گے کہ گھاٹے والے وہی افرادہیں جنہوں نے اپنے نفس اوراپنے اہل کو قیامت کے دن گھاٹے میں مبتلا کردیا ہے آگاہ ہوجاؤ کہ ظالموں کو بہرحال دائمی عذاب میں رہنا پڑے گا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxviii{اور ان کے لئے ایسے سرپرست بھی نہ ہوںگے جو خدا سے ہٹ کر ان کی مدد کرسکیں اور جس کو خدا گمراہی میں چھوڑ دے اس کے لئے کوئی راستہ نہیں ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxix{تم لوگ اپنے پروردگار کی بات کو قبول کرو قبل اس کے کہ وہ دن آجائے جو پلٹنے والا نہیں ہے اس دن تمہارے لئے کوئی پناہ گاہ بھی نہ ہوگی اور عذاب کا انکار کرنے کی ہمت بھی نہ ہوگی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxx{اب بھی اگر یہ لوگ اعتراض کریں تو ہم نے آپ کو ان کانگہبان بناکر نہیں بھیجا ہے آپ کا فرض صرف پیغام پہنچا دینا تھا اوربس اور ہم جب کسی انسان کو رحمت کامزہ چکھاتے ہیں تو وہ اکڑ جاتا ہے اورجب اس کے اعمال ہی کے نتیجہ میں کوئی برائی پہنچ جاتی ہے تو بہت زیادہ ناشکری کرنے والا بن جاتاہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxi{بیشک آسمان و زمین کا اختیار صرف اللہ کے ہاتھوں میں ہے وہ جوکچھ چاہتا ہے پیدا کرتا ہے جس کو چاہتا ہے بیٹیاں عطا کرتا ہے اور جس کوچاہتا ہے بیٹے عطاکرتاہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxii{یا پھر بیٹے اور بیٹیاں دونوں کوجمع کردیتا ہے اور جس کو چاہتا ہے بانجھ ہی بنا دیتا ہے یقینا وہ صاحبِ علم بھی ہے اور صاحبِ قدرت و اختیاربھی ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiii{اورکسی انسان کے لئے یہ بات نہیں ہے کہ اللہ اس سے کلام کرے مگر یہ کہ وحی کردے یا پس پردہ سے بات کر لے یا کوئی نمائندہ فرشتہ بھیج دے اور پھر وہ اس کی اجازت سے جو وہ چاہتا ہے وہ پیغام پہنچا دے کہ وہ یقینا بلند و بالا اور صاحبِ حکمت ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiv{اور اسی طرح ہم نے آپ کی طرف اپنے حکم سے روح (قرآن) کی وحی کی ہے آپ کونہیں معلوم تھا کہ کتاب کیا ہے اورایمان کن چیزوں کا نام ہے لیکن ہم نے اسے ایک نور قرار دیا ہے جس کے ذریعہ اپنے بندوں میں جسے چاہتے ہیں اسے ہدایت دے دیتے ہیں اور بیشک آپ لوگوں کو سیدھے راستہ کی ہدایت کررہے ہیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxv{اس خدا کا راستہ جس کے اختیار میں زمین و آسمان کی تمام چیزیں ہیں اوریقینا اسی کی طرف تمام اُمورکی بازگشت ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvi{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvii{اس روشن کتاب کی قسم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxviii{بیشک ہم نے اسے عربی قرآن قرار دیا ہے تاکہ تم سمجھ سکو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxix{اور یہ ہمارے پاس لوح محفوظ میں نہایت درجہ بلند اور اَپراز حکمت کتاب ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxx{اورکیا ہم تم لوگوں کو نصیحت کرنے سے صرف اس لئے کنارہ کشی اختیار کرلیں کہ تم زیادتی کرنے والے ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxi{اورہم نے تم سے پہلے والی قوموں میں بھی کتنے ہی پیغمبر بھیج دیئے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxii{اور ان میں سے کسی کے پاس کوئی نبی نہیں آیا مگر یہ کہ ان لوگوں نے ان کا مذاق اڑایا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiii{تو ہم نے ان سے زیادہ زبردست لوگوں کو تباہ و برباد کردیا اور یہ مثال جاری ہوگئی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiv{اور آپ ان سے سوال کریں گے کہ زمین و آسمان کوکس نے پیدا کیا ہے تویقینا یہی کہیں گے کہ ایک زبردست طاقت والی اور ذی علم ہستی نے خلق کیاہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxv{وہ ہی جس نے تمہارے لئے زمین کو گہوارہ بنایا ہے اور اس میں راستے قرار دیئے ہیں تاکہ تم راہ معلوم کرسکو\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvi{اور جس نے آسمان سے ایک معین مقدار میں پانی نازل کیا اورپھر ہم نے اس کے ذریعہ اَمردہ زمینوں کو زندہ بنادیا اسی طرح تم بھی زمین سے نکالے جاؤ گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvii{اور جسں نے تمام جوڑوں کو خلق کیا ہے اور تمہارے لئے کشتیوں اور جانوروں میں سواری کا سامان فراہم کیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxviii{تاکہ ان کی پشت پرسکون سے بیٹھ سکو اورپھر جب سکون سے بیٹھ جاؤ تو اپنے پروردگار کی نعمت کو یاد کرو اور کہو کہ پاک و بے نیاز ہے وہ خدا جس نے اس سواری کو ہمارے لئے م اَسخرّ کردیا ہے ورنہ ہم اس کوقابو میں لاسکنے والے نہیں تھے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxix{اور بہرحال ہم اپنے پروردگار ہی کی بارگاہ میں پلٹ کر جانے والے ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxl{اور ان لوگوں نے پروردگار کے لئے اس کے بندوں میں سے بھی ایک جزئ (اولاد) قرار دیدیا کہ انسان یقینا بڑا کھلا ہوا ناشکرا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxli{سچ بتاؤ کیا خدا نے اپنی تمام مخلوقات میں سے اپنے لئے لڑکیوں کو منتخب کیا ہے اور تمہارے لئے لڑکوں کو پسند کیا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlii{اور جب ان میں سے کسی کو اسی لڑکی کی بشارت دی جاتی ہے جو مثال انہوں نے رحمان کے لئے بیان کی ہے تو اس کا چہرہ سیاہ ہوجاتا ہے اور غصہّ کے گھونٹ پینے لگتاہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliii{کیا جس کو زیورات میں پالا جاتا ہے اور وہ جھگڑے کے وقت صحیح بات بھی نہ کرسکے (وہی خدا کی اولاد ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliv{اوران لوگوں نے ان ملائکہ کوجو رحمان کے بندے ہیںلڑکی قرار دیدیا ہے کیا یہ ان کی خلقت کے گواہ ہیں تو عنقریب ان کی گواہی لکھ لی جائے گی اور پھر اس کے بارے میں سوال کیا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlv{اوریہ کہتے ہیں کہ خدا چاہتا توہم ان کی پرستش نہ کرتے انہیں اس بات کا کوئی علم نہیں ہے - یہ صرف اندازوں سے بات کرتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvi{کیا ہم نے اس سے پہلے انہیں کوئی کتاب دی ہے جس سے یہ تمسّک کئے ہوئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvii{نہیں بلکہ ان کا کہنا صرف یہ ہے کہ ہم نے اپنے باپ داداکو ایک طریقہ پر پایا ہے اورہم ان ہی کے نقش قدم پر ہدایت پانے والے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlviii{اور اسی طرح ہم نے آپ سے پہلے کی بستی میں کوئی پیغمبر نہیں بھیجا مگر یہ کہ اس بستی کے خوشحال لوگوں نے یہ کہہ دیا کہ ہم نے اپنے باپ دادا کو ایک طریقہ پر پایا ہے اور ہم ان ہی کے نقش قدم کی پیروی کرنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlix{تو پیغمبر نے کہا کہ چاہے میں اس سے بہتر پیغام لے آؤں جس پر تم نے اپنے باپ دادا کو پایا ہے تو انہوں نے جواب دیا کہ ہم تمہارے پیغام کے ماننے والے نہیں ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcccl{پھر ہم نے ان سے بدلہ لے لیا تو اب دیکھو کہ تکذیب کرنے والوں کا کیا انجام ہوا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcccli{اور جب ابراہیم نے اپنے (مربی) باپ اور اپنی قوم سے کہا کہ میں تمہارے تمام معبودوں سے بری اور بیزار ہوں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmccclii{علاوہ اس معبود کے کہ جس نے مجھے پیدا کیا ہے کہ وہی عنقریب مجھے ہدایت دینے والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliii{اور انہوں نے اس پیغام کو اپنی نسل میں ایک کلمہ باقیہ قرار دے دیا کہ شاید وہ لوگ خدا کی طرف پلٹ آئیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcccliv{بلکہ ہم نے ان لوگوں کو اور ان کے بزرگوں کو برابر آرام دیا یہاں تک کہ ان کے پاس حق اور واضح رسول آگیا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmccclv{اور جب حق آگیا تو کہنے لگے کہ یہ تو جادو ہے اور ہم اس کے منکر ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvi{اور یہ کہنے لگے کہ آخر یہ قرآن دونوں بستیوں (مکہ و طائف) کے کسی بڑے آدمی پر کیوں نہیں نازل کیا گیا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmccclvii{تو کیا یہی لوگ رحمت پروردگار کو تقسیم کررہے ہیں حالانکہ ہم نے ہی ان کے درمیان معیشت کو زندگانی دنیا میں تقسیم کیا ہے اور بعض کو بعض سے اونچا بنایا ہے تاکہ ایک دوسرے سے کام لے سکیں اور رحمت پروردگار ان کے جمع کئے ہوئے مال و متاع سے کہیں زیادہ بہتر ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmccclviii{اور اگر ایسا نہ ہوتا کہ تمام لوگ ایک ہی قوم ہوجائیں گے تو ہم رحمٰن کا انکار کرنے والوںکے لئے ان کے گھر کی چھتیں اور سیڑھیاں جن پر یہ چڑھتے ہیں سب کو چاند ی کا بنادیتے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmccclix{اور ان کے گھر کے دروازے اور وہ تخت جن پر وہ تکیہ لگا کر بیٹھتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmccclx{اور سونے کے بھی . لیکن یہ سب صرف زندگانی دنیا کی لّذت کا سامان ہے اور آخرت پروردگار کے نزدیک صرف صاحبانِ تقویٰ کے لئے ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxi{اور جو شخص بھی اللہ کے ذکر کی طرف سے اندھا ہوجائے گا ہم اس کے لئے ایک شیطان مقرر کردیں گے جو اس کا ساتھی اور ہم نشین ہوگا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxii{اور یہ شیاطین ان لوگوں کو راستہ سے روکتے رہتے ہیں اور یہ یہی خیال کرتے ہیں کہ یہ ہدایت یافتہ ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiii{یہاں تک کہ جب ہمارے پاس آئیں گے تو کہیں گے کہ اے کاش ہمارے اور ان کے درمیان مشرق و مغرب کا فاصلہ ہوتا یہ تو بڑا بدترین ساتھی نکلا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiv{اور یہ ساری باتیں آج تمہارے کام آنے والی نہیں ہیں کہ تم سب عذاب میں برابر کے شریک ہو کہ تم نے بھی ظلم کیا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxv{پیغمبر کیا آپ بہرے کو سنا سکتے ہیں یا اندھے کو راستہ دکھاسکتے ہیں یا اسے ہدایت دے سکتے ہیں جو ضلال مبین میں مبتلا ہوجائے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvi{پھر ہم یا تو آپ کو دنیا سے اٹھالیں گے تو ہمیں تو ان سے بہرحال بدلہ لینا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvii{یا پھر عذاب آپ کو دکھا کر ہی نازل کریں گے کہ ہم اس کا بھی اختیار رکھنے والے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxviii{لہذا آپ اس حکم کو مضبوطی سے پکڑے رہیں جس کی وحی کی گئی ہے کہ یقینا آپ بالکل سیدھے راستہ پر ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxix{اور یہ قرآن آپ کے لئے اور آپ کی قوم کے لئے نصیحت کا سامان ہے اور عنقریب تم سب سے باز اَپرس کی جائے گی\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxx{اور آپ ان رسولوں سے سوال کریں جنہیں آپ سے پہلے بھیجا گیا ہے کیا ہم نے رحمٰن کے علاوہ بھی خدا قرار دیئے ہیں جن کی پرستش کی جائے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxi{اور ہم نے موسٰی علیھ السّلام کو اپنی نشانیوں کے ساتھ فرعون اور اس کے روسائ قوم کی طرف بھیجا تو انہوں نے کہا کہ میں رب العالمین کی طرف سے رسول ہوں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxii{لیکن جب ہماری نشانیوں کو پیش کیا تو وہ سب مضحکہ اڑانے لگے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiii{اور ہم انہیں جو بھی نشانی دکھلاتے تھے وہ پہلے والی نشانی سے بڑھ کر ہی ہوتی تھی اور پھر انہیں عذاب کی گرفت میں لے لیا کہ شاید اسی طرح راستہ پر واپس آجائیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiv{اور ان لوگوں نے کہا کہ اے جادوگر (موسٰی) اپنے رب سے ہمارے بارے میں اس بات کی دعا کر جس بات کا تجھ سے وعدہ کیا گیا ہے تو ہم یقینا راستہ پر آجائیں گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxv{لیکن جب ہم نے عذاب کو دور کردیا تو انہوں نے عہد کو توڑ دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvi{اور فرعون نے اپنی قوم سے پکار کر کہا اے قوم کیا یہ ملک مصر میرا نہیں ہے اور کیا یہ نہریں جو میرے قدموں کے نیچے جاری ہیں یہ سب میری نہیں ہیں پھر تمہیں کیوں نظر نہیں آرہا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvii{کیا میں اس شخص سے بہتر نہیں ہوں جو پست حیثیت کا آدمی ہے اور صاف بول بھی نہیں پاتا ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxviii{پھر کیوں اس کے اوپر سونے کے کنگن نہیں نازل کئے گئے اور کیوں اس کے ساتھ ملائکہ جمع ہوکر نہیں آئے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxix{پس فرعون نے اپنی قوم کو سبک سر بنادیا اور انہوں نے اس کی اطاعت کرلی کہ وہ سب پہلے ہی سے فاسق اور بدکار تھے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxx{پھر جب ان لوگوں نے ہمیں غضب ناک کردیا تو ہم نے ان سے بدلہ لے لیا اور پھر ان ہی سب کو اکٹھا غرق کردیا\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxi{پھر ہم نے انہیں گیا گزرا اور بعد والوں کے لئے ایک نمونہ عبرت بنادیا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxii{اور جب ابن مریم کو مثال میں پیش کیا گیا تو آپ کی قوم شور مچانے لگی\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiii{اور کہنے لگے کہ ہمارے خدا بہتر ہیں یا وہ اور لوگوں نے ان کی مثال صرف ضد میں پیش کی تھی اور یہ سب صرف جھگڑا کرنے والے تھے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiv{ورنہ عیسٰی علیھ السّلام ایک بندے تھے جن پر ہم نے نعمتیں نازل کیں اور انہیں بنی اسرائیل کے لئے اپنی قدرت کا ایک نمونہ بنادیا\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxv{اور اگر ہم چاہتے تو تمہارے بدلے ملائکہ کو زمین میں بسنے والا قرار دے دیتے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvi{اور بیشک یہ قیامت کی واضح دلیل ہے لہٰذا اس میں شک نہ کرو اور میرا اتباع کرو کہ یہی سیدھا راستہ ہے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvii{اور خبردار شیطان تمہیں راہ حق سے روک نہ دے کہ وہ تمہارا کھلا ہوا دشمن ہے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxviii{اور جب عیسٰی علیھ السّلام ان کے پاس معجزات لے کر آئے تو انہوں نے کہا کہ میں تمہارے پاس حکمت لے کر آیا ہوں اور اس لئے کہ بعض ان مسائل کی وضاحت کردوں جن میں تمہارے درمیان اختلاف ہے لہٰذا خدا سے ڈرو اور میری اطاعت کرو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxix{اللہ ہی میرا اور تمہارا پروردگار ہے اور اسی کی عبادت کرو کہ یہی صراط مستقیم ہے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxc{تو اقوام نے آپس میں اختلاف شروع کردیا افسوس ان کے حال پر ہے کہ جنہوں نے ظلم کیا کہ ان کے لئے دردناک دن کا عذاب ہے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxci{کیا یہ لوگ صرف اس بات کا انتظار کررہے ہیں کہ اچانک قیامت آجائے اور انہیں اس کا شعور بھی نہ ہوسکے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcii{آج کے دن صاحبانِ تقویٰ کے علاوہ تمام دوست ایک دوسرے کے دشمن ہوجائیں گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciii{میرے بندو آج تمہارے لئے نہ خوف ہے اور نہ تم پر حزن و ملال طاری ہوگا\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciv{یہی وہ لوگ ہیں جنہوں نے ہماری نشانیوں پر ایمان قبول کیا ہے اور ہمارے اطاعت گزار ہوگئے ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcv{اب تم سب اپنی بیویوں سمیت اعزاز و احترام کے ساتھ جنّت میں داخل ہوجاؤ\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvi{ان کے گرد سونے کی رکابیوں اور پیالیوں کا دور چلے گا اور وہاں ان کے لئے وہ تمام چیزیں ہوں گی جن کی دل میں خواہش ہو اور جو آنکھوں کو بھلی لگیں اور تم اس میں ہمیشہ رہنے والے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvii{اور یہی وہ جنّت ہے جس کا تمہیں ان اعمال کی بنا پر وارث بنایا گیا ہے جو تم انجام دیا کرتے تھے\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcviii{اس میں تمہارے لئے بہت سے میوے ہیں جن میں سے تم کھاؤ گے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcix{بیشک مجرمین عذابِ جہّنم میں ہمیشہ رہنے والے ہیں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcd{ان سے عذاب منقطع نہیں ہوگا اور وہ مایوسی کے عالم میں وہاں رہیں گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcdi{اور ہم نے ان پر کوئی ظلم نہیں کیا ہے یہ تو خود ہی اپنے اوپر ظلم کرنے والے تھے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcdii{اور وہ آواز دیں گے کہ اے مالک اگر تمہارا پروردگار ہمیںموت دے دے تو بہت اچھا ہو تو جواب ملے گا کہ تم اب یہیں رہنے والے ہو\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiii{یقینا ہم تمہارے پاس حق لے کر آئے لیکن تمہاری اکثریت حق کو ناپسند کرنے والی ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcdiv{کیا انہوں نے کسی بات کا محکم ارادہ کرلیا ہے تو ہم بھی یہ کام جانتے ہیں\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmcdv{یا ان کا خیال یہ ہے کہ ہم ان کے راز اور خفیہ باتوں کو نہیں سن سکتے ہیں تو ہم کیا ہمارے نمائندے سب کچھ لکھ رہے ہیں\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvi{آپ کہہ دیجئے کہ اگر رحمٰن کے کوئی فرزند ہوتا تو میںسب سے پہلا عبادت گزار ہوں\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmcdvii{وہ آسمان و زمین اور عرش کا مالک ان کی باتوں سے پاک اور منّزہ ہے\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmcdviii{انہیں ان کے حال پر چھوڑ دیجئے باتیں بناتے رہیں اور کھیل تماشے میں لگے رہیں یہاں تک کہ اس دن کا سامنا کریں جس کا وعدہ دیا جارہا ہے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmcdix{اور وہی وہ ہے جو آسمان میں بھی خدا ہے اور زمین میں بھی خدا ہے اور وہ صاحبِ حکمت بھی ہے اور ہر شے سے باخبر بھی ہے\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmcdx{اور بابرکت ہے وہ جس کے لئے آسمان و زمین اور اس کے مابین کا ملک ہے اور اسی کے پاس قیامت کا بھی علم ہے اور اسی کی طرف تم سب واپس کئے جاؤ گے\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxi{اور اس کے علاوہ جنہیں یہ لوگ پکارتے ہیں وہ سفارش کا بھی اختیار نہیں رکھتے ہیں...._ مگر وہ جو سمجھ بوجھ کر حق کی گواہی دینے والے ہیں\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxii{اور اگر آپ ان سے سوال کریں گے کہ خود ان کا خالق کون ہے تو کہیں گے کہ اللہ .... تو پھر یہ کدھر بہکے جارہے ہیں\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiii{اور اسی کو اس قول کا بھی علم ہے کہ خدایا یہ وہ قوم ہے جو ایمان لانے والی نہیں ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiv{لہٰذا ان سے منہ موڑ لیجئے اور سلامتی کا پیغام دے دیجئے پھر عنقریب انہیں سب کچھ معلوم ہوجائے گا\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxv{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvi{روشن کتاب کی قسم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvii{ہم نے اس قرآن کو ایک مبارک رات میں نازل کیا ہے ہم بیشک عذاب سے ڈرانے والے تھے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxviii{اس رات میں تمام حکمت و مصلحت کے امور کا فیصلہ کیا جاتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxix{یہ ہماری طرف کا حکم ہوتا ہے اور ہم ہی رسولوں کے بھیجنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxx{یہ آپ کے پروردگار کی رحمت ہے اور یقینا وہ بہت سننے والا اور جاننے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxi{وہ آسمان و زمین اور اس کے مابین کا پروردگار ہے اگر تم یقین کرنے والے ہو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxii{اس کے علاوہ کوئی خدا نہیں ہے . وہی حیات عطا کرنے والا ہے اور وہی موت دینے والا ہے - وہی تمہارا بھی پروردگار ہے اور تمہارے گزشتہ بزرگوں کا بھی پروردگار ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiii{لیکن یہ لوگ شک کے عالم میں کھیل تماشہ کررہے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiv{لہٰذا آپ اس دن کا انتظار کیجئے جب آسمان واضح قسم کا دھواں لے کر آجائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxv{جو تمام لوگوں کو ڈھانک لے گا کہ یہی دردناک عذاب ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvi{تب سب کہیں گے کہ پروردگار اس عذاب کو ہم سے دور کردے ہم ایمان لے آنے والے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvii{بھلا ان کی قسمت میں نصیحت کہاں جب کہ ان کے پاس واضح پیغام والا رسول بھی آچکا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxviii{اور انہوں نے اس سے منہ پھیرلیا اور کہا کہ یہ سکھایا پڑھایا ہوا دیوانہ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxix{خیر ہم تھوڑی دیر کے لئے عذاب کو ہٹالیتے ہیں لیکن تم پھر وہی کرنے والے ہو جو کررہے ہو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxx{ایک دن آئے گا جب ہم سخت قسم کی گرفت کریں گے کہ ہم یقینا بدلہ لینے والے بھی ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxi{اور ہم نے ان سے پہلے فرعون کی قوم کو آزمایا جب ان کے پاس ایک محترم پیغمبر آیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxii{کہ اللہ کے بندوں کو میرے حوالے کردو میں تمہارے لئے ایک امانت دار پیغمبر ہوں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiii{اور خدا کے سامنے اونچے نہ بنو میں تمہارے پاس بہت واضح دلیل لے کر آیا ہوں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiv{اور میں اپنے اور تمہارے رب کی پناہ چاہتا ہوں کہ تم مجھے سنگسار کردو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxv{اور اگر تم ایمان نہیں لاتے ہو تو مجھ سے الگ ہوجاؤ\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvi{پھر انہوں نے اپنے رب سے رَعا کی کہ یہ قوم بڑی مجرم قوم ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvii{تو ہم نے کہا کہ ہمارے بندوں کو لے کر راتوں رات چلے جاؤ کہ تمہارا پیچھا کیا جانے والا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxviii{اور دریا کو اپنے حال پر ساکن چھوڑ کر نکل جاؤ کہ یہ لشکر غرق کیا جانے والا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxix{یہ لوگ کتنے ہی باغات اور چشمے چھوڑ گئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxl{اور کتنی ہی کھیتیاں اور عمدہ مکانات چھوڑ گئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxli{اور وہ نعمتیں جن میں مزے اُڑا رہے تھےیہی انجام ہوتا ہے اور ہم نے سب کا وارث دوسری قوم کو بنادیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlii{اور وہ نعمتیں جن میں مزے اُڑا رہے تھےیہی انجام ہوتا ہے اور ہم نے سب کا وارث دوسری قوم کو بنادیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliii{پھر تو ان پر نہ آسمان رویا اور نہ زمین اور نہ انہیں مہلت ہی دی گئی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliv{اور ہم نے بنی اسرائیل کو رسوا کن عذاب سے بچالیا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlv{فرعون کے شر سے جو زیادتی کرنے والوں میں بھی سب سے اونچا تھا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvi{اور ہم نے بنی اسرائیل کو تمام عالمین میں سمجھ بوجھ کر انتخاب کیا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvii{اور انہیں ایسی نشانیاں دی ہیں جن میں کھلا ہوا امتحان پایا جاتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlviii{بیشک یہ لوگ یہی کہتے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlix{کہ یہ صرف پہلی موت ہے اور بس اس کے بعد ہم اٹھائے جانے والے نہیں ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcdl{اور اگر تم سچے ہو تو ہمارے باپ دادا کو قبروں سے اٹھا کر لے آؤ\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcdli{بھلا یہ لوگ زیادہ بہتر ہیں یا قوم تّبع اور ان سے پہلے والے افراد جنہیں ہم نے اس لئے تباہ کردیا کہ یہ سب مجرم تھے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlii{اور ہم نے زمین و آسمان اور اس کی درمیانی مخلوقات کو کھیل تماشہ کرنے کے لئے نہیں پیدا کیا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliii{ہم نے انہیں صرف حق کے ساتھ پیدا کیا ہے لیکن ان کی اکثریت اس امر سے بھی جاہل ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcdliv{بیشک فیصلہ کا دن ان سب کے اٹھائے جانے کا مقررہ وقت ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlv{جس دن کوئی دوست دوسرے دوست کے کام آنے والا نہیں ہے اور نہ ان کی کوئی مدد کی جائے گی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvi{علاوہ اس کے جس پر خدا رحم کرے کہ بیشک وہ بڑا بخشنے والا اور مہربان ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvii{بیشک آخرت میں ایک تھوہڑ کا درخت ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlviii{جو گناہگاروں کی غذا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlix{وہ پگھلے ہوئے تانبے کی مانند پیٹ میں جوش کھائے گا\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlx{جیسے گرم پانی جوش کھاتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxi{فرشتوں کو حکم ہوگا کہ اسے پکڑو اور بیچوں بیچ جہّنم تک لے جاؤ\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxii{پھر اس کے سر پر کھولتے ہوئے پانی کا عذاب انڈیل دو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiii{کہو کہ اب اپنے کئے کا مزہ چکھو کہ تم تو بڑے صاحب هعزّت اور محترم کہے جاتے تھے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiv{یہی وہ عذاب ہے جس میں تم شک پیدا کررہے تھے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxv{بیشک وہ صاحبانِ تقویٰ محفوظ مقام پر ہوں گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvi{باغات اور چشموں کے درمیان\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvii{وہ ریشم کی باریک اور موٹی پوشاک پہنے ہوئے ایک دوسرے کے سامنے بیٹھے ہوں گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxviii{ایسا ہی ہوگا اور ہم بڑی بڑی آنکھوں والی حوروں سے ان کے جوڑے لگادیں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxix{وہ وہاں ہر قسم کے میوے سکون کے ساتھ طلب کریں گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxx{اور وہاں پہلی موت کے علاوہ کسی موت کا مزہ نہیں چکھنا ہوگا اور خدا انہیں جہّنم کے عذاب سے محفوظ رکھے گا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxi{یہ سب آپ کے پروردگار کا فضل و کرم ہے اور یہی انسان کے لئے سب سے بڑی کامیابی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxii{پس ہم نے اس قرآن کو آپ کی زبان سے آسان کردیا ہے کہ شاید یہ لوگ نصیحت حاصل کرلیں\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiii{پھر آپ انتظار کریں اور یہ لوگ بھی انتظار کر ہی رہے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiv{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxv{اس کتاب کی تنزیل اس خدا کی طرف سے ہے جو صاحبِ عزّت بھی ہے اور صاحب هحکمت بھی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvi{بیشک آسمانوں اور زمینوں میں صاحبانِ هایمان کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvii{اور خود تمہاری خلقت میں بھی اور جن جانورں کو وہ پھیلاتا رہتا ہے ان میں بھی صاحبانِ یقین کے لئے بہت سی نشانیاں ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxviii{اور رات دن کی رفت و آمد میں اور جو رزق خدا نے آسمان سے نازل کیا ہے جس کے ذریعہ سے اَمردہ زمینوں کو زندہ بنایا ہے اور ہواؤں کے چلنے میں اس قوم کے لئے نشانیاں پائی جاتی ہیں جو عقل رکھنے والی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxix{یہ اللہ کی آیتیں ہیں جن کی حق کے ساتھ تلاوت کی جارہی ہے تو اللہ اور اس کی آیتوں کے بعد یہ کس بات پر ایمان لانے والے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxx{بیشک ہر جھوٹے گنہگار کے حال پر افسوس ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxi{جو تلاوت کی جانے والی آیات کو سنتا ہے اور پھر اکڑ جاتا ہے جیسے سنا ہی نہیں ہے تو اسے دردناک عذاب کی بشارت دیدیجئے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxii{اور اسے جب بھی ہماری کسی نشانی کا علم ہوتا ہے تو اس کا مذاق اڑاتا ہے بیشک یہی وہ لوگ ہیں جن کے لئے رسوا کن عذاب ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiii{ان کے پیچھے جہنّم ہے اور انہوں نے جو کچھ کمایا ہے اور جن لوگوں کو خدا کو چھوڑ کر سرپرست بنایا ہے کوئی کام آنے والا نہیں ہے اور ان کے لئے بہت بڑا عذاب ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiv{یہ قرآن ایک ہدایت ہے اور جن لوگوں نے آیااُ خدا کا انکار کیا ہے ان کے لئے سخت قسم کا دردناک عذاب ہوگا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxv{اللہ ہی نے تمہارے لئے دریا کو لَسخّر کیا ہے کہ اس کے حکم سے کشتیاں چل سکیں اور تم اس کے فضل و کرم کو تلاش کرسکو اور شاید اس کا شکریہ بھی ادا کرسکو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvi{اور اسی نے تمہارے لئے زمین و آسمان کی تمام چیزوں کو لَسّخر کردیا ہے بیشمَ اس میں غور و فکر کرنے والی قوم کے لئے نشانیاں پائی جاتی ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvii{آپ صاحبانِ ایمان سے کہہ دیں کہ وہ خدائی دنوں کی توقع نہ رکھنے والوں سے درگزر کریں تاکہ خدا قوم کو ان کے اعمال کا مکمل بدلہ دے سکے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxviii{جو نیک کام کرے گا وہ اپنے فائدہ کے لئے کرے گا اور جو برائی کرے گا وہ اپنے ہی نقصان کے لئے کرے گا اس کے بعد تم سب پروردگار کی طرف پلٹائے جاؤ گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxix{اور یقینا ہم نے بنی اسرائیل کو کتابً حکومت اور نبوت عطا کی ہے اور انہیں پاکیزہ رزق دیا ہے اور انہیں تمام عالمین پر فضیلت دی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxc{اور انہیں اپنے امر کی کھلی ہوئی نشانیاں عطا کی ہیں پھر ان لوگوں نے علم آنے کے بعد آپس کی ضد میں اختلاف کیا تو یقینا تمہارا پروردگار روزِ قیامت ان کے درمیان ان تمام باتوں کا فیصلہ کردے گا جن میں یہ اختلاف کرتے رہے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxci{پھر ہم نے آپ کو اپنے حکم کے واضح راستہ پر لگادیا لہٰذا آپ اسی کا اتباع کریں اور خبرار جاہلوں کی خواہشات کا اتباع نہ کریں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcii{یہ لوگ خدا کے مقابلہ میں ذرہ برابر کام آنے والے نہیں ہیں اور ظالمین آپس میں ایک دوسرے کے دوست ہیں تو اللہ صاحبانِ تقویٰ کا سرپرست ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciii{یہ لوگوں کے لئے روشنی کا مجموعہ اور یقین کرنے والی قوم کے لئے ہدایت اور رحمت ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciv{کیا برائی اختیار کرلینے والوں نے یہ خیال کرلیا ہے کہ ہم انہیں ایمان لانے والوں اور نیک عمل کرنے والوں کے برابر قرار دے دیں گے کہ سب کی موت و حیات ایک جیسی ہو یہ ان لوگوں نے نہایت بدترین فیصلہ کیا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcv{اور اللہ نے آسمان و زمین کو حق کے ساتھ پیدا کیا ہے اور اس لئے بھی کہ ہر نفس کو اس کے اعمال کا بدلہ دیا جاسکے اور یہاں کسی پر ظلم نہیں کیا جائے گا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvi{کیا آپ نے اس شخص کو بھی دیکھا ہے جس نے اپنی خواہش ہی کو خدا بنالیا ہے اور خدا نے اسی حالت کو دیکھ کر اسے گمراہی میں چھوڑ دیا ہے اور اس کے کان اور دل پر مہر لگادی ہے اور اس کی آنکھ پر پردے پڑے ہوئے ہیں اور خدا کے بعد کون ہدایت کرسکتا ہے کیا تم اتنا بھی غور نہیں کرتے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvii{اور یہ لوگ کہتے ہیں کہ یہ صرف زندگانی دنیا ہے اسی میں مرتے ہیں اور جیتے ہیں اور زمانہ ہی ہم کو ہلاک کردیتا ہے اور انہیں اس بات کا کوئی علم نہیں ہے کہ یہ صرف ان کے خیالات ہیں اور بس\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcviii{اور جب ان کے سامنے ہماری کھلی ہوئی آیات کی تلاوت ہوتی ہے تو ان کی دلیل صرف یہ ہوتی ہے کہ اگر تم سچے ہو تو ہمارے باپ دادا کو زندہ کرکے لے آؤ\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcix{آپ کہہ دیجئے کہ خدا ہی تم کو بھی زندہ رکھے ہے پھر ایک دن موت دے گا اور آخر میں سب کو روز قیامت جمع کرے گا اور اس میں کوئی شک نہیں ہے لیکن اکثر لوگ اس بات کو بھی نہیں سمجھتے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmd{اور اللہ ہی کے لئے زمین و آسمان کا ملک ہے اور جس دن قیامت قائم ہوگی اس دن اہل ه باطل کو واقعا خسارہ ہوگا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdi{اور آپ ہر قوم کو گھٹنے کے بل بیٹھا ہوا دیکھیں گے اور سب کو ان کے نامئہ اعمال کی طرف بلایا جائے گا کہ آج تمہیں تمہارے اعمال کا بدلہ دیا جائے گا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdii{یہ ہماری کتاب (نامئہ اعمال) ہے جو حق کے ساتھ بولتی ہے اور ہم اس میں تمہارے اعمال کو برابر لکھوا رہے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdiii{اب جو لوگ ایمان لائے اور انہوں نے نیک اعمال کئے انہیں پروردگار اپنی رحمت میں داخل کرلے گا کہ یہی سب سے نمایاں کامیابی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdiv{اور جن لوگوں نے کفر اختیار کیا تو کیا تمہارے سامنے ہماری آیات کی تلاوت نہیں ہورہی تھی لیکن تم نے اکڑ سے کام لیا اور بیشک تم ایک مجرم قوم تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdv{اور جب یہ کہا گیا کہ اللہ کا وعدہ سچا ہے اور قیامت میں کوئی شک نہیں ہے تو تم نے کہہ دیا کہ ہم تو قیامت نہیں جانتے ہیں ہم اسے ایک خیالی بات سمجھتے ہیں اور ہم اس کا یقین کرنے والے نہیں ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdvi{اور ان کے لئے ان کے اعمال کی برائیاں ثابت ہوگئیں اور انہیں اسی عذاب نے گھیر لیا جس کا وہ مذاق اڑایا کرتے تھے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdvii{اور ان سے کہا گیا کہ ہم تمہیں آج اسی طرح نظر انداز کردیں گے جس طرح تم نے آج کے دن کی ملاقات کو بھلادیا تھا اور تم سب کا انجام جہّنم ہے اور تمہارا کوئی مددگار نہیں ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdviii{یہ سب اس لئے ہے کہ تم نے آیات الہٰی کا مذاق بنایا تھا اور تمہیں زندگانی دنیا نے دھوکے میں رکھا تھا تو آج یہ لوگ عذاب سے باہرنہیں نکالے جائیں گے اور انہیں معافی مانگنے کا موقع بھی نہیں دیا جائے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdix{ساری حمد اسی خدا کے لئے ہے جو آسمان و زمین اور تمام عالمین کا پروردگار اور مالک ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdx{اسی کے لئے آسمان و زمین میں بزرگی اور کبریائی ہے اور وہی صاحبِ عزّت اور حکمت والا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdxi{\basmalahur حمۤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxii{یہ خدائے عزیز و حکیم کی نازل کی ہوئی کتاب ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiii{ہم نے آسمان و زمین اور ان کے درمیان کی تمام مخلوقات کو حق کے ساتھ اور ایک مقررہ مدّت کے ساتھ پیدا کیا ہے اور جن لوگوں نے کفر اختیار کرلیا وہ ان باتوں سے کنارہ کش ہوگئے ہیں جن سے انہیں ڈرایا گیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxiv{تو آپ کہہ دیں کہ کیا تم نے ان لوگوں کو دیکھا ہے جنہیں خدا کو چھوڑ کر پکارتے ہو ذ را مجھے بھی دکھلاؤ کہ انہوں نے زمین میں کیا پیدا کیا ہے یا ان کی آسمان میں کیا شرکت ہے - پھر اگر تم سچے ہو تو اس سے پہلے کی کوئی کتاب یا علم کا کوئی بقیہ ہمارے سامنے پیش کرو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdxv{اور اس سے زیادہ گمراہ کون ہے جو خدا کو چھوڑ کر ان کو پکارتا ہے جو قیامت تک اس کی آواز کا جواب نہیں دے سکتے ہیں اور ان کی آواز کی طرف سے غافل بھی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvi{اور جب سارے لوگ قیامت میں محشور ہوں گے تو یہ معبود ان کے دشمن ہوجائیں گے اور ان کی عبادت کا انکار کرنے لگیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxvii{اور جب ان کے سامنے ہماری روشن آیات کی تلاوت کی جاتی ہے تو یہ کفار حق کے آنے کے بعد اس کے بارے میں یہی کہتے ہیں کہ یہ کِھلا ہوا جادو ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxviii{تو کیا یہ لوگ یہ کہتے ہیں کہ رسول نے افترا کیا ہے تو آپ کہہ دیجئے کہ اگر میں نے افترا کیا ہے تو تم میرے کام آنے والے نہیں ہو اور خدا خوب جانتا ہے کہ تم اس کے بارے میں کیا کیا باتیں کرتے ہو اور میرے اور تمہارے درمیان گواہی کے لئے وہی کافی ہے اور وہی بہت بخشنے والا اور مہربان ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxix{آپ کہہ دیجئے کہ میں کوئی نئے قسم کا رسول نہیں ہوں اور مجھے نہیں معلوم کہ میرے اور تمہارے ساتھ کیا برتاؤ کیا جائے گا میں تو صرف وحی الہٰی کا اتباع کرتا ہوں اور صرف واضح طور پر عذاب الٰہی سے ڈرانے والا ہوں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxx{کہہ دیجئے کہ تمہارا کیا خیال ہے اگر یہ قرآن اللہ کی طرف سے ہے اور تم نے اس کا انکار کردیا جب کہ بنی اسرائیل کاایک گواہ ایسی ہی بات کی گواہی دے چکا ہے اور وہ ایمان بھی لایا ہے اور پھر بھی تم نے غرور سے کام لیا ہے بیشک اللہ ظالمین کی ہدایت کرنے والا نہیں ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxi{اور یہ کفار ایمان والوں سے کہتے ہیں کہ اگر یہ دین بہتر ہوتا تو یہ لوگ ہم سے آگے اس کی طرف نہ دوڑ پڑتے اور جب ان لوگوں نے خود ہدایت نہیں حاصل کی تو اب کہتے ہیں کہ یہ بہت پرانا جھوٹ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxii{اور اس سے پہلے موسٰی علیھ السّلامکی کتاب تھی جو رہنما اور رحمت تھی اور یہ کتاب عربی زبان میں سب کی تصدیق کرنے والی ہے تاکہ ظلم کرنے والوں کو عذاب الہٰی سے ڈرائے اور یہ نیک کرداروں کے لئے مجسمئہ بشارت ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiii{بیشک جن لوگوں نے اللہ کو اپنا رب کہا اور اسی پر جمے رہے ان کے لئے نہ کوئی خوف ہے اور نہ وہ رنجیدہ ہونے والے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiv{یہی لوگ درحقیقت جنّت والے ہیں اور اسی میں ہمیشہ رہنے والے ہیں کہ یہی ان کے اعمال کی حقیقی جزا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxv{اور ہم نے انسان کو اس کے ماں باپ کے ساتھ نیک برتاؤ کرنے کی نصیحت کی کہ اس کی ماں نے بڑے رنج کے ساتھ اسے شکم میں رکھا ہے اور پھر بڑی تکلیف کے ساتھ پیدا کیا ہے اور اس کے حمل اور دودھ بڑھائی کا کل زمانہ تیس مہینے کا ہے یہاں تک کہ جب وہ توانائی کو پہنچ گیا اور چالیس برس کا ہوگیا تو اس نے دعا کی کہ پروردگار مجھے توفیق دے کہ میں تیری اس نعمت کا شکریہ ادا کروں جو تو نے مجھے اور میرے والدین کو عطا کی ہے اور ایسا نیک عمل کروں کہ تو راضی ہوجائے اور میری ذریت میں بھی صلاح و تقویٰ قرار دے کہ میں تیری ہی طرف متوجہ ہوں اور تیرے فرمانبردار بندوں میں ہوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvi{یہی وہ لوگ ہیں جن کے بہترین اعمال کو ہم قبول کرتے ہیں اور ان کی برائیوں سے درگزر کرتے ہیں یہ اصحاب جنّت میں ہیں اور یہ خدا کا وہ وعدہ ہے جو ان سے برابر کیا جارہا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvii{اور جس نے اپنے ماں باپ سے یہ کہا کہ تمہارے لئے حیف ہے کہ تم مجھے اس بات سے ڈراتے ہو کہ میں دوبارہ قبر سے نکالا جاؤں گا حالانکہ مجھ سے پہلے بہت سی قومیں گزر چکی ہیں اور وہ دونوں فریاد کررہے تھے کہ یہ بڑی افسوس ناک بات ہے بیٹا ایمان لے آ - خدا کا وعدہ بالکل سچا ہے تو کہنے لگا کہ یہ سب پرانے لوگوں کے افسانے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxviii{یہی وہ لوگ ہیں جن پر عذاب ثابت ہوچکا ہے ان امّتوں میں جو انسان و جّنات میں ان سے پہلے گزر چکی ہیں کہ بیشک یہ سب گھاٹے میں رہنے والے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxix{اور ہر ایک کے لئے اس کے اعمال کے مطابق درجات ہوں گے اور یہ اس لئے کہ خدا ان کے اعمال کا پورا پورا بدلہ دیدے اور ان پر کسی طرح کا ظلم نہیں کیا جائے گا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxx{اور جس دن کفار کو جہنمّ کے سامنے پیش کیا جائے گا کہ تم نے اپنے سارے مزے دنیاہی کی زندگی میں لے لئے اور وہاں آرام کرلیا تو آج ذلّت کے عذاب کی سزادی جائے گی کہ تم روئے زمین میں بلاوجہ اکڑ رہے تھے اور اپنے پروردگار کے احکام کی نافرمانی کررہے تھے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxi{اور قوم عاد کے بھائی ہود کو یاد کیجئے کہ انہوں نے اپنی قوم کو احقاف میں ڈرایا .... اور ان کے قبل و بعد بہت سے پیغمبر علیھ السّلام گزر چکے ہیں .... کہ خبردار اللہ کے علاوہ کسی کی عبادت نہ کرو میں تمہارے بارے میں ایک بڑے سخت دن کے عذاب سے خوفزدہ ہوں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxii{ان لوگوں نے کہا کہ کیا تم اسی لئے آئے ہو کہ ہمیں ہمارے خداؤں سے منحرف کردو تو اس عذاب کو لے آؤ جس سے ہمیں ڈرا رہے ہو اگر اپنی بات میں سچے ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiii{انہوں نے کہا کہ علم تو بس خدا کے پاس ہے اور میں اسی کے پیغام کو پہنچادیتا ہوں جو میرے حوالے کیا گیا ہے لیکن میں تمہیں بہرحال جاہل قوم سمجھ رہا ہوں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiv{اس کے بعد جب ان لوگوں نے بادل کو دیکھا کہ ان کی وادیوں کی طرف چلا آرہا ہے تو کہنے لگے کہ یہ بادل ہمارے اوپر برسنے والا ہے.... حالانکہ یہ وہی عذاب ہے جس کی تمہیں جلدی تھی یہ وہی ہوا ہے جس کے اندر دردناک عذاب ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxv{یہ حکم خدا سے ہر شے کو تباہ و برباد کردے گی. نتیجہ یہ ہوا کہ سوائے مکانات کے کچھ نہ نظر آیا اور ہم اسی طرح مجرم قوم کو سزا دیا کرتے ہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvi{اور یقینا ہم نے ان کو وہ اختیارات دیئے تھے جو تم کو نہیں دیئے ہیں اور ان کے لئے کان, آنکھ, دل سب قرار دیئے تھے لیکن نہ انہیں کانوں نے کوئی فائدہ پہنچایا اور نہ آنکھوں اور دلوں نے کہ وہ آیات الٰہی کا انکار کرنے والے افراد تھے اور انہیں عذاب نے گھیر لیا جس کا وہ مذاق اڑایا کرتے تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvii{اور یقینا ہم نے تمہارے گرد بہت سی بستیوں کو تباہ کردیا ہے اور اپنی نشانیوں کو پلٹ پلٹ کر دکھلایا ہے کہ شاید یہ حق کی طرف واپس آجائیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxviii{تو وہ لوگ ان کے کام کیوں نہیں آئے جن کو انہوں نے خدا کو چھوڑ کر وسیلہ تقرب کے طور پر خدا بنالیا تھا بلکہ وہ تو غائب ہی ہوگئے اور یہ ان لوگوں کا وہ جھوٹ اور افترا ہے جو وہ برابر تیار کیا کرتے تھے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxix{اور جب ہم نے جنات میں سے ایک گروہ کو آپ کی طرف متوجہ کیا کہ قرآن سنیں تو جب وہ حاضر ہوئے تو آپس میں کہنے لگے کہ خاموشی سے سنو پھر جب تلاوت تمام ہوگئی تو فورا پلٹ کر اپنی قوم کی طرف ڈرانے والے بن کر آگئے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdxl{کہنے لگے کہ اے قوم والو ہم نے ایک کتاب کو صَنا ہے جو موسٰی علیھ السّلام کے بعد نازل ہوئی ہے یہ اپنے پہلے والی کتابوں کی تصدیق کرنے والی ہے اور حق و انصاف اور سیدھے راستہ کی طرف ہدایت کرنے والی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdxli{قوم والو اللہ کی طرف دعوت دینے والے کی آواز پر لبیک کہو اور اس پر ایمان لے آؤ تاکہ اللہ تمہارے گناہوں کو بخش دے اور تمہیں دردناک عذاب سے پناہ دے دے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlii{اور جو بھی داعی الٰہیۤ کی آواز پر لبیک نہیں کہے گا وہ روئے زمین پر خدا کو عاجز نہیں کرسکتا ہے اور اس کے لئے خدا کے علاوہ کوئی سرپرست بھی نہیں ہے بیشک یہ لوگ کھلی ہوئی گمراہی میں مبتلا ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliii{کیا انہوں نے نہیں دیکھا کہ جس خدا نے آسمان و زمین کو پیدا کیا ہے اور وہ ان کی تخلیق سے عاجز نہیں تھا وہ اس بات پر بھی قادر ہے کہ مفِدوں کو زندہ کردے کہ یقینا وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdxliv{اور جس دن یہ کفاّر جہّنم کے سامنے پیش کئے جائیں گے کہ کیا یہ حق نہیں ہے تو سب کہیں گے کہ بیشک پروردگار کی قسم یہ سب حق ہے تو ارشاد ہوگا کہ اب عذاب کا مزہ چکھو کہ تم پہلے اس کا انکار کررہے تھے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlv{پیغمبر آپ اسی طرح صبر کریں جس طرح پہلے کے صاحبان ه عزم رسولوں نے صبر کیا ہے اور عذاب کے لئے جلدی نہ کریں یہ لوگ جس دن بھی اس عذاب کو دیکھیں گے جس سے ڈرایا جارہا ہے تو ایسا محسوس کریں گے جیسے دنیا میں ایک دن کی ایک گھڑی ہی ٹہرے ہیں یہ قرآن اتمام حجت ہے اور کیا فاسقوں کے علاوہ کسی اور قوم کو ہلاک کیا جائے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvi{\basmalahur جن لوگوں نے کفر کیا اور لوگوں کو راسِ خدا سے روکا خدا نے ان کے اعمال کو برباد کردیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvii{اور جن لوگوں نے ایمان اختیار کیا اور نیک اعمال کئے اور جو کچھ محمد پر نازل کیا گیا ہے اور پروردگار کی طرف سے برحق بھی ہے اس پر ایمان لے آئے تو خدا نے ان کی برائیوں کو دور کردیا اور ان کے حالات کی اصلاح کردی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlviii{یہ اس لئے کہ کفار نے باطل کا اتباع کیا ہے اور صاحبانِ ایمان نے اپنے پروردگار کی طرف سے آنے والے حق کا اتباع کیا ہے اور خدا اسی طرح لوگوں کے لئے مثالیں بیان کرتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdxlix{پس جب کفار سے مقابلہ ہو تو ان کی گردنیں اڑادو یہاں تک کہ جب زخموں سے چور ہوجائیں تو ان کی مشکیں باندھ لو پھر اس کے بعد چاہے احسان کرکے چھوڑ دیا جائے یا فدیہ لے لیا جائے یہاں تک کہ جنگ اپنے ہتھیار رکھ دے - یہ یاد رکھنا اور اگر خدا چاہتا تو خود ہی ان سے بدلہ لے لیتا لیکن وہ ایک کو دوسرے کے ذریعہ آزمانا چاہتا ہے اور جو لوگ اس کی راہ میں قتل ہوئے وہ ان کے اعمال کو ضائع نہیں کرسکتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdl{وہ عنقریب انہیں منزل تک پہنچادے گا اور ان کی حالت سنوار دے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdli{وہ انہیں اس جنّت میں داخل کرے گا جو انہیں پہلے سے پہنچوا چکا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdlii{ایمان والو اگر تم اللہ کی مدد کرو گے تو اللہ بھی تمہاری مدد کرے گا اور تمہیں ثابت قدم بنادے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdliii{اور جن لوگوں نے کفر اختیار کیا ان کے واسطے ڈگمگاہٹ ہے اور ان کے اعمال برباد ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdliv{یہ اس لئے کہ انہوں نے خدا کے نازل کئے ہوئے احکام کو برا سمجھا تو خدا نے بھی ان کے اعمال کو ضائع کردیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdlv{تو کیا ان لوگوں نے زمین میں سیر نہیں کی ہے کہ دیکھتے کہ ان سے پہلے والوں کا کیا انجام ہوا ہے بیشک اللہ نے انہیں تباہ و برباد کردیا ہے اور کفاّر کے لئے بالکل ایسی ہی سزا مقرر ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvi{یہ سب اس لئے ہے کہ اللہ صاحبانِ ایمان کا مولا اور سرپرست ہے اور کافروں کا کوئی پرسانِ حال نہیں ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdlvii{بیشک جو لوگ ایمان لائے اور انہوں نے نیک اعمال انجام دیئے خدا انہیں ایسے باغات میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی اور جن لوگوں نے کفر اختیار کیا وہ مزے کررہے ہیں اور اسی طرح کھارہے ہیں جس طرح جانور کھاتے ہیں اور ان کا آخری ٹھکانا جہّنم ہی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdlviii{اور کتنی ہی بستیاں تھیں جو تمہاری اس بستی سے کہیں زیادہ طاقتور تھیں جس نے تمہیں نکال دیا ہے جب ہم نے انہیں ہلاک کردیا تو کوئی مدد کرنے والا بھی نہ پیدا ہوا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdlix{تو کیا جس کے پاس پروردگار کی طرف سے کھلی ہوئی دلیل موجود ہے وہ اس کے مثل ہوسکتاہے جس کے لئے اس کے بدترین اعمال سنوار دیئے گئے ہیں اور پھر ان لوگوں نے اپنی خواہشات کا اتباع کرلیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdlx{اس جنّت کی صفت جس کا صاحبانِ تقویٰ سے وعدہ کیا گیا ہے یہ ہے کہ اس میں ایسے پانی کی نہریں ہیں جس میں کسی طرح کی بو نہیں ہے اور کچھ نہریں دودھ کی بھی ہیں جن کا مزہ بدلتا ہی نہیں ہے اور کچھ نہریں شراب کی بھی ہیں جن میں پینے والوں کے لئے لذّت ہے اور کچھ نہریں صاف و شفاف شہد کی ہیں اور ان کے لئے ہر طرح کے میوے بھی ہیں اور پروردگار کی طرف سے مغفرت بھی ہے تو کیا یہ متقی افراد ان کے جیسے ہوسکتے ہیں جو ہمیشہ جہّنم میں رہنے والے ہیں اور جنہیں گرما گرم پانی پلایا جائے گا جس سے آنتیں ٹکڑے ٹکڑے ہوجائیں گی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxi{اور ان میں سے کچھ افراد ایسے بھی ہیں جو آپ کی باتیں بظاہر غور سے سنتے ہیں اس کے بعد جب آپ کے پاس سے باہر نکلتے ہیں تو جن لوگوں کو علم دیا گیا ہے ان سے کہتے ہیں کہ انہوں نے ابھی کیا کہا تھا یہی وہ لوگ ہیں جن کے دلوں پر خدا نے مہر لگادی ہے اور انہوں نے اپنی خواہشات کا اتباع کرلیا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxii{اور جن لوگوں نے ہدایت حاصل کرلی خدا نے ان کی ہدایت میں اضافہ کردیا اور ان کو مزید تقویٰ عنایت فرما دیا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiii{پھر کیا یہ لوگ قیامت کا انتظار کررہے ہیں کہ وہ اچانک ان کے پاس آجائے جب کہ اس کی علامتیں ظاہر ہوگئی ہیں تو اگر وہ آبھی گئی تو یہ کیا نصیحت حاصل کریں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiv{تو یہ سمجھ لو کہ اللہ کے علاوہ کوئی خدا نہیں ہے اور اپنے اور ایماندار مردوں اور عورتوں کے لئے استغفار کرتے رہو کہ اللہ تمہارے چلنے پھرنے اور ٹہرنے سے خوب باخبر ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxv{اور جو لوگ ایمان لے آئے ہیں وہ یہ کہتے ہیں کہ آخر جہاد کے بارے میں سورہ کیوں نہیں نازل ہوتا اور جب سورہ نازل ہوگیا اور اس میں جہاد کا ذکر کردیا گیا تو آپ نے دیکھا کہ جن کے دلوں میں مرض تھا وہ آپ کی طرف اس طرح دیکھتے رہ گئے جیسے موت کی سی غشی طاری ہوگئی ہو تو ان کے واسطے ویل اور افسوس ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvi{ان کے حق میں بہترین بات اطاعت اور نیک گفتگو ہے پھر جب جنگ کا معاملہ طے ہوجائے تو اگر خدا سے اپنے کئے وعدہ پر قائم رہیں تو ان کے حق میں بہت بہتر ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvii{تو کیا تم سے کچھ بعید ہے کہ تم صاحبِ اقتدار بن جاؤ تو زمین میں فساد برپا کرو اور قرابتداروں سے قطع تعلقات کرلو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxviii{یہی وہ لوگ ہیں جن پر خدا نے لعنت کی ہے اور ان کے کانوں کو بہرا کردیا ہے اور ان کی آنکھوں کو اندھا بنادیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxix{تو کیا یہ لوگ قرآن میں ذرا بھی غور نہیں کرتے ہیں یا ان کے دلوں پر قفل پڑے ہوئے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxx{بیشک جو لوگ ہدایت کے واضح ہوجانے کے بعد الٹے پاؤں پلٹ گئے شیطان نے ان کی خواہشات کو آراستہ کردیا ہے اور انہیں خوب ڈھیل دے دی ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxi{یہ اس لئے کہ ان لوگوں نے خدا کی نازل کی ہوئی باتوں کو ناپسند کرنے والوں سے یہ کہا کہ ہم بعض مسائل میں تمہاری ہی اطاعت کریں گے اور اللہ ان کی راز کی باتوں سے خوب باخبر ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxii{پھر اس وقت کیا ہوگا جب ملائکہ انہیں دنیا سے اٹھائیں گے اور ان کے چہروں اور پشت پر مسلسل مارتے جائیں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiii{یہ اس لئے کہ انہوں نے ان باتوں کا اتباع کیا ہے جو خدا کو ناراض کرنے والی ہیں اور اس کی مرضی کو ناپسند کیا ہے تو خدا نے بھی ان کے اعمال کو برباد کرکے رکھ دیا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiv{کیا جن لوگوں کے دلوں میں بیماری پائی جاتی ہے ان کا خیال یہ ہے کہ خدا ان کے دلوں کے کینوں کو باہر نہیں لائے گا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxv{اور ہم چاہتے تو انہیں دکھلا دیتے اور آپ چہرہ کے آثار ہی سے پہچان لیتے اور ان کی گفتگو کے انداز سے تو بہرحال پہچان ہی لیں گے اور اللہ تم سب کے اعمال سے خوب باخبر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvi{اور ہم یقینا تم سب کا امتحان لیں گے تاکہ یہ دیکھیں کہ تم میں جہاد کرنے والے اور صبر کرنے والے کون لوگ ہیں اور اس طرح تمہارے حالات کو باقاعدہ جانچ لیں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvii{بیشک جن لوگوں نے کفر اختیار کرلیا اور لوگوں کو خدا کی راہ سے روکا اور ہدایت کے واضح ہوجانے کے بعد بھی پیغمبر سے جھگڑا کیا وہ اللہ کو کوئی نقصان نہیں پہنچاسکتے ہیں اور اللہ عنقریب ان کے اعمال کو بالکل برباد کردے گا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxviii{ایمان والو اللہ کی اطاعت کرو اور رسول کی اطاعت کرو اور خبردار اپنے اعمال کو برباد نہ کرو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxix{بیشک جن لوگوں نے کفر اختیار کیا اور خدا کی راہ میں رکاوٹ ڈالی اور پھر حالت کفر ہی میں مرگئے تو خدا انہیں ہرگز معاف نہیں کرے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxx{لہٰذا تم ہمت نہ ہارو اور دشمن کو صلح کی دعوت نہ دو اور تم سربلند ہو اور اللہ تمہارے ساتھ ہے اور وہ ہرگز تمہارے اعمال کے ثواب کو کم نہیں کرے گا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxi{یہ زندگانی دنیا تو صرف ایک کھیل تماشہ ہے اور اگر تم نے ایمان اور تقویٰ اختیار کرلیا تو خدا تمہیں مکمل اجر عطا کرے گا اور تم سے تمہارا مال طلب نہیں کرے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxii{وہ اگر طلب بھی کرے اور اصرار بھی کرے تو تم بخل ہی کرو گے اور خدا تمہارے کینوں کو خود ہی ظاہر کردے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiii{ہاں ہاں تم وہی لوگ ہو جنہیں راہ خدا میں خرچ کرنے کے لئے بلایا جاتا ہے تو تم میں سے بعض لوگ بخل کرنے لگتے ہیں اور جو لوگ بخل کرتے ہیں وہ اپنے ہی حق میں بخل کرتے ہیں اور خدا سب سے بے نیاز ہے تم ہی سب اس کے فقیر اور محتاج ہو اور اگر تم منہ پھیر لو گے تو وہ تمہارے بدلے دوسری قوم کو لے آئے گا جو اس کے بعد تم جیسے نہ ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiv{\basmalahur بیشک ہم نے آپ کو کھلی ہوئی فتح عطا کی ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxv{تاکہ خدا آپ کے اگلے پچھلے تمام الزامات کو ختم کردے اور آپ پر اپنی نعمت کو تمام کردے اور آپ کو سیدھے راستہ کی ہدایت د ے د ے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvi{اور زبردست طریقہ سے آپ کی مدد کرے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvii{وہی خدا ہے جس نے مومنین کے دلوں میں سکون نازل کیا ہے تاکہ ان کے ایمان میں مزید اضافہ ہوجائے اور اللہ ہی کے لئے زمین و آسمان کے سارے لشکر ہیں اور وہی تمام باتوں کا جاننے والا اور صاحبِ حکمت ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxviii{تاکہ مومن مرد اور مومنہ عورتوں کو ان جنتوں میں داخل کردے جن کے نیچے نہریں جاری ہیں وہ ان ہی میں ہمیشہ رہیں اور ان کی برائیوں کو ان سے دور کردے اور یہی اللہ کے نزدیک عظیم ترین کامیابی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxix{اور منافق مرد, منافق عورتیں اور مشرک مرد و عورت جو خدا کے بارے میں برے برے خیالات رکھتے ہیں ان سب پر عذاب نازل کرے ان کے سر عذاب کی گردش ہے اور ان پر اللہ کا غضب ہے خدا نے ان پر لعنت کی ہے اور ان کے لئے جہّنم کو مہیاّ کیا ہے جو بدترین انجام ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdxc{اور اللہ ہی کے لئے زمین و آسمان کے سارے لشکر ہیں اور وہ صاحبِ عزت بھی ہے اور صاحبِ حکمت بھی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdxci{پیغمبر ہم نے آپ کو گواہی دینے والا بشارت دینے والا اور عذاب الٰہٰی سے ڈرانے والا بناکر بھیجا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcii{تاکہ تم سب اللہ اور اس کے رسول پر ایمان لے آؤ اور اس کی مدد کرو اور اس کا احترام کرو اور صبح و شام اللہ کی تسبیح کرتے رہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciii{بیشک جو لوگ آپ کی بیعت کرتے ہیں وہ درحقیقت اللہ کی بیعت کرتے ہیں اور ان کے ہاتھوں کے اوپر اللہ ہی کا ہاتھ ہے اب اس کے بعد جو بیعت کو توڑ دیتا ہے وہ اپنے ہی خلاف اقدام کرتا ہے اور جو عہد الٰہٰی کو پورا کرتا ہے خدا عنقریب اسی کو اجر عظیم عطا کرے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdxciv{عنقریب یہ پیچھے رہ جانے والے گنوار آپ سے کہیں گے کہ ہمارے اموال اور اولاد نے مصروف کرلیا تھا لہٰذا آپ ہمارے حق میں استغفار کردیں. یہ اپنی زبان سے وہ کہہ رہے ہیں جو یقینا ان کے دل میں نہیں ہے تو آپ کہہ دیجئے کہ اگر خدا تمہیں نقصان پہنچانا چاہے یا فائدہ ہی پہنچانا چاہے تو کون ہے جو اس کے مقابلہ میں تمہارے امور کا اختیار رکھتا ہے .حقیقت یہ ہے کہ اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcv{اصل میں تمہارا خیال یہ تھا کہ رسول اور صاحبانِ ایمان اب اپنے گھر والوں تک پلٹ کر نہیں آسکتے ہیں اور اس بات کو تمہارے دلوں میں خوب سجا دیا گیا تھا اور تم نے بدگمانی سے کام لیا اور تم ہلاک ہوجانے والی قوم ہو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvi{اور جو بھی خدا و رسول پر ایمان نہ لائے گا ہم نے ایسے کافرین کے لئے جہّنم کا انتظام کر رکھا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvii{اور اللہ ہی کے لئے زمین و آسمان کا ملک ہے وہ جس کو چاہتا ہے بخش دیتا ہے اور جس پر چاہتا ہے عذاب کرتا ہے اور اللہ بہت بخشنے والا مہربان ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcviii{عنقریب یہ پیچھے رہ جانے والے تم سے کہیں گے جب تم مال غنیمت لینے کے لئے جانے لگو گے کہ اجازت دو ہم بھی تمہارے ساتھ چلے چلیں یہ چاہتے ہیں کہ اللہ کے کلام کو تبدیل کر دیں تو تم کہہ دو کہ تم لو گ ہمارے ساتھ نہیں آسکتے ہو اللہ نے یہ بات پہلے سے طے کردی ہے پھر یہ کہیں گے کہ تم لوگ ہم سے حسد رکھتے ہو حالانکہ حقیقت یہ ہے کہ یہ لوگ بات کو بہت کم سمجھ پاتے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdxcix{آپ ان پیچھے رہ جانے والوں سے کہہ دیں کہ عنقریب تمہیں ایک ایسی قوم کی طرف بلایا جائے گا جو انتہائی سخت جنگجو قوم ہوگی کہ تم ان سے جنگ ہی کرتے رہو گے یا وہ مسلمان ہوجائیں گے تو اگر تم خدا کی اطاعت کرو گے تو وہ تمہیں بہترین اجر عنایت کرے گا اور اگر پھر منہ پھیر لو گے جس طرح پہلے کیا تھا تو تمہیں دردناک عذاب کے ذریعہ سزا دے گا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdc{اندھے آدمی کے لئے کوئی گناہ نہیں ہے اور لنگڑے آدمی کے لئے بھی کوئی گناہ نہیں ہے اورمریض کی بھی کوئی ذمہ داری نہیں ہے اور جو اللہ اور اس کے رسول کی اطاعت کرے گا خدا اس کو ایسی جنتوں میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی اور جو روگردانی کرے گا وہ اسے دردناک عذاب کی سزا دے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdci{یقینا خدا صاحبانِ ایمان سے اس وقت راضی ہوگیا جب وہ درخت کے نیچے آپ کی بیعت کررہے تھے پھر اس نے وہ سب کچھ دیکھ لیا جو ان کے دلوں میں تھا تو ان پر سکون نازل کردیا اور انہیں اس کے عوض قریبی فتح عنایت کردی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcii{اور بہت سے منافع بھی دے دیئے جنہیں وہ حاصل کریں گے اور اللہ ہر ایک پر غالب آنے والا اور صاحب هحکمت ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdciii{اس نے تم سے بہت سے فوائد کا وعدہ کیا ہے جنہیں تم حاصل کرو گے پھر اس غنیمت هخیبر کو فورا عطا کردیا اور لوگوں کے ہاتھوں کو تم سے روک دیا اور تاکہ یہ صاحبانِ ایمان کے لئے ایک قدرت کی نشانی بنے اور وہ تمہیں سیدھے راستہ کی ہدایت دے دے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdciv{اور دوسری غنیمتیں جن پر تم قادر نہیں ہوسکے خدا ان پر بھی حاوی ہے اور خدا تو ہر شے پر قدرت رکھنے والا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcv{اور اگر یہ کفاّر تم سے جنگ کرتے تو یقینا منہ پھیر کر بھاگ جاتے اور پھر انہیں کوئی سرپرست اور مددگار نصیب نہ ہوتا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvi{یہ اللہ کی ایک سنّت ہے جو پہلے بھی گزر چکی ہے اور تم اللہ کے طریقہ میں ہرگز کوئی تبدیلی نہیں پاؤ گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcvii{وہی خدا ہے جس نے کفاّر کے ہاتھوں کو تم سے اور تمہارے ہاتھوں کو ان سے سرحد مکہ کے اندر تمہارے فتح پاجانے کے بعد بھی روک دیا اور اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcviii{یہی وہ لوگ ہیں جنہوں نے کفر اختیار کیا اور تم کو مسجد الحرام میں داخل ہونے سے روک دیا اور قربانی کے جانوروں کو روک دیا کہ وہ اپنی منزل پر پہنچنے سے رکے رہے اور اگر صاحبِ ایمان مرد اور باایمان عورتیں نہ ہوتیں جن کو تم نہیں جانتے تھے اور نادانستگی میں انہیں بھی پامال کر ڈالنے کا خطرہ تھا اور اس طرح تمہیں لاعلمی کی وجہ سے نقصان پہنچ جاتا تو تمہیں روکا بھی نہ جاتا - روکا اس لئے تاکہ خدا جسے چاہے اسے اپنی رحمت میں داخل کرلے کہ یہ لوگ الگ ہوجاتے تو ہم کفّار کو دردناک عذاب میں مبتلا کردیتے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcix{یہ اس وقت کی بات ہے جب کفار نے اپنے دلوں میں زمانہ جاہلیت جیسی ضد قرار دے لی تھی کہ تم کو مکہ میں داخل نہ ہونے دیں گے تو اللہ نے اپنے رسول اور صاحبانِ ایمان پر سکون نازل کردیا اور انہیں کلمہ تقویٰ پر قائم رکھا اور وہ اسی کے حقدار اور اہل بھی تھے اور اللہ تو ہر شے کا جاننے والا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcx{بیشک خدا نے اپنے رسول کو بالکل سچا خوب دکھلایا تھا کہ خدا نے چاہا تو تم لوگ مسجد الحرام میں امن و سکون کے ساتھ سر کے بال منڈا کر اور تھوڑے سے بال کاٹ کر داخل ہوگے اور تمہیں کسی طرح کا خوف نہ ہوگا تو اسے وہ بھی معلوم تھا جو تمہیں نہیں معلوم تھا تو اس نے فتح مکہّ سے پہلے ایک قریبی فتح قرار دے دی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxi{وہی وہ خدا ہے جس نے اپنے رسول کو ہدایت اور دین حق کے ساتھ بھیجا تاکہ اسے تمام ادیان عالم پر غالب بنائے اور گواہی کے لئے بس خدا ہی کافی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxii{محمد(ص) اللہ کے رسول ہیں اور جو لوگ ان کے ساتھ ہیں وہ کفار کے لئے سخت ترین اور آپس میںانتہائی رحمدل ہیں تم انہیں دیکھوگے کہ بارگاہ ِاحدیّت میںسر خم کئے ہوئے سجدہ ریز ہیںاور اپنے پروردگارسے فضل وکرم اور اس کی خوشنودی کے طلب گار ہیں ،کثرتِ سجود کی بنا پر ان کے چہروں پر سجدہ کے نشانات پائے جاتے ہیںیہی ان کی مثال تورےت میں ہے اور یہی ان کی صفت انجیل میں ہے جیسے کوئی کھیتی ہو جو پہلے سوئی نکالے پھر اسے مضبوط بنائے پھر وہ موٹی ہو جائے اور پھر اپنے پیروں پر کھڑی ہو جائے کہ کاشتکاروں کو خوش کرنے لگے تاکہ ان کے ذریعہ کفار کو جلایا جائے اور اللہ نے صاحبانِ ایمان وعمل صالح سے مغفرت اور عظیم اجر کا وعدہ کیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiii{\basmalahur ایمان والو خبردار خدا و ر رسول کے سامنے اپنی بات کو آگے نہ بڑھاؤ اور اللہ سے ڈرو بیشک اللہ ہر بات کا سننے والا اور جاننے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiv{ایمان والو خبردار اپنی آواز کو نبی کی آواز پر بلند نہ کرنا اور ان سے اس طرح بلند آواز میں بات بھی نہ کرنا جس طرح آپس میں ایک دوسرے کو پکارتے ہو کہیں ایسا نہ ہو کہ تمہارے اعمال برباد ہوجائیں اور تمہیں اس کا شعور بھی نہ ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxv{بیشک جو لوگ رسول اللہ کے سامنے اپنی آواز کو دھیما رکھتے ہیں یہی وہ لوگ ہیں جن کے دلوں کو خدا نے تقویٰ کے لئے آزمالیا ہے اور ان ہی کے لئے مغفرت اور اجر عظیم ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvi{بیشک جو لوگ آپ کو حجروں کے پیچھے سے پکارتے ہیں ان کی اکثریت کچھ نہیں سمجھتی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvii{اور اگر یہ اتنا صبر کرلیتے کہ آپ نکل کر باہر آجاتے تو یہ ان کے حق میں زیادہ بہتر ہوتا اور اللہ بہت بخشنے والا اور مہربان ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxviii{ایمان والو اگر کوئی فاسق کوئی خبر لے کر آئے تو اس کی تحقیق کرو ایسا نہ ہو کہ کسی قوم تک ناواقفیت میں پہنچ جاؤ اور اس کے بعد اپنے اقدام پر شرمندہ ہونا پڑے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxix{اور یاد رکھو کہ تمہارے درمیان خدا کا رسول موجود ہے یہ اگر بہت سی باتوں میں تمہاری بات مان لیتا تو تم زحمت میں پڑ جاتے لیکن خدا نے تمہارے لئے ایمان کو محبوب بنادیا ہے اور اسے تمہارے دلوں میں آراستہ کردیا ہے اور کفر, فسق اور معصیت کو تمہارے لئے ناپسندیدہ قرار دے دیا ہے اور درحقیقت یہی لوگ ہدایت یافتہ ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxx{یہ اللہ کا فضل اور اس کی نعمت ہے اور اللہ سب کچھ جاننے والا بھی ہے اور صاحب هحکمت بھی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxi{اور اگر مومنین کے دو گروہ آپس میں جھگڑا کریں تو تم سب ان کے درمیان صلح کراؤ اس کے بعد اگر ایک دوسرے پر ظلم کرے تو سب مل کر اس سے جنگ کرو جو زیادتی کرنے والا گروہ ہے یہاں تک کہ وہ بھی حکم خدا کی طرف واپس آجائے پھر اگر پلٹ آئے تو عدل کے ساتھ اصلاح کردو اور انصاف سے کام لو کہ خدا انصاف کرنے والوں کو دوست رکھتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxii{مومنین آپس میں بالکل بھائی بھائی ہیں لہٰذا اپنے بھائیوں کے درمیان اصلاح کرو اور اللہ سے ڈرتے رہو کہ شاید تم پر رحم کیا جائے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiii{ایمان والو خبردار کوئی قوم دوسری قوم کا مذاق نہ اڑائے کہ شاید وہ اس سے بہتر ہو اور عورتوں کی بھی کوئی جماعت دوسری جماعت کا مسخرہ نہ کرے کہ شاید وہی عورتیں ان سے بہتر ہوں اور آپس میں ایک دوسرے کو طعنے بھی نہ دینا اور اِرے اِرے القاب سے یاد بھی نہ کرنا کہ ایمان کے بعد بدکاریً کا نام ہی بہت اِرا ہے اور جو شخص بھی توبہ نہ کرے تو سمجھو کہ یہی لوگ درحقیقت ظالمین ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiv{ایمان والو اکثر گمانوں سے اجتناب کرو کہ بعض گمان گناہ کا درجہ رکھتے ہیں اور خبردار ایک دوسرے کے عیب تلاش نہ کرو اور ایک دوسرے کی غیبت بھی نہ کرو کہ کیا تم میں سے کوئی اس بات کو پسند کرے گا کہ اپنے مفِدہ بھائی کا گوشت کھائے یقینا تم اسے اِرا سمجھو گے تو اللہ سے ڈرو کہ بیشک اللہ بہت بڑا توبہ کا قبول کرنے والا اور مہربان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxv{انسانو ہم نے تم کو ایک مرد اور ایک عورت سے پیدا کیا ہے اور پھر تم میں شاخیں اور قبیلے قرار دیئے ہیں تاکہ آپس میں ایک دوسرے کو پہچان سکو بیشک تم میں سے خدا کے نزدیک زیادہ محترم وہی ہے جو زیادہ پرہیزگارہے اور اللہ ہر شے کا جاننے والا اور ہر بات سے باخبر ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvi{یہ بدوعرب کہتے ہیں کہ ہم ایمان لے آئے ہیں تو آپ کہہ دیجئے کہ تم ایمان نہیں لائے بلکہ یہ کہو کہ اسلام لائے ہیں کہ ابھی ایمان تمہارے دلوں میں داخل نہیں ہوا ہے اور اگر تم اللہ اور رسول کی اطاعت کرو گے تو وہ تمہارے اعمال میں سے کچھ بھی کم نہیں کرے گا کہ وہ بڑا غفور اور رحیم ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvii{صاحبانِ ایمان صرف وہ لوگ ہیں جو اللہ اور اس کے رسول پر ایمان لے آئے اور پھر کبھی شک نہیں کیا اور اس کی راہ میں اپنے مال اور اپنی جان سے جہاد بھی کیا درحقیقت یہی لوگ اپنے دعویٰ ایمان میں سچےّ ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxviii{آپ کہہ دیجئے کہ کیا تم خدا کو اپنا دین سکھارہے ہو جب کہ وہ آسمان اور زمین کی ہر شے سے باخبر ہے اور وہ کائنات کی ہر چیز کا جاننے والا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxix{یہ لوگ آپ پر احسان جتاتے ہیں کہ اسلام لے آئے ہیں تو آپ کہہ دیجئے کہ ہمارے اوپراپنے اسلام کا احسان نہ رکھو یہ خدا کا احسان ہے کہ اس نے تم کو ایمان لانے کی ہدایت دے دی ہے اگر تم واقعا دعوائے ایمان میں سچے ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxx{بیشک اللہ آسمان و زمین کے ہر غیب کا جاننے والا اور وہ تمہارے تمام اعمال کا بھی دیکھنے والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxi{\basmalahur قۤ - قرآن مجید کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxii{لیکن ان کفاّر کو تعجب ہے کہ ان ہی میں سے کوئی شخص پیغمبر بن کر آگیا اس لئے ان کا کہنا یہ ہے کہ یہ بات بالکل عجیب ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiii{کیا جب ہم مرکر خاک ہوجائیں گے تو دوبارہ واپس ہوں گے یہ بڑی بعید بات ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiv{ہم جانتے ہیں کہ زمین ان کے جسموں میں سے کس قدر کم کردیتی ہے اور ہمارے پاس ایک محفوظ کتاب موجود ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxv{حقیقت یہ ہے کہ ان لوگوں نے حق کے آنے کے بعد اس کا انکار کردیا ہے تو وہ ایک بے چینی کی بات میں مبتلا ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvi{کیا ان لوگوں نے اپنے اوپر آسمان کی طرف نہیں دیکھا ہے کہ ہم نے اسے کس طرح بنایا ہے اور پھر آراستہ بھی کردیا ہے اور اس میں کہیں شگاف بھی نہیں ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvii{اور زمین کو فرش کردیا ہے اور اس میں پہاڑ ڈال دیئے ہیں اور ہر طرح کی خوبصورت چیزیں اُگادی ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxviii{یہ خدا کی طرف رجوع کرنے والے ہر بندہ کے لئے سامان نصیحت اور وجہ بصیرت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxix{اور ہم نے آسمان سے بابرکت پانی نازل کیا ہے پھر اس سے باغات اور کھیتی کا غلہ اُگایا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxl{اور لمبی لمبی کھجوریں اُگائی ہیں جن کے بور آپس میں گتھے ہوئے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxli{یہ سب ہمارے بندوں کے لئے رزق کا سامان ہے اور ہم نے اسی پانی سے اَمردہ زمینوں کو زندہ کیا ہے اور اسی طرح تمہیں بھی زمین سے نکالیں گے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlii{ان سے پہلے قوم نوح اصحاب رس اور ثمود نے بھی تکذیب کی تھی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliii{اور قوم عاد, فرعون اور برادرانِ لوط نے بھی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliv{اور اصحاب ایکہ اور قوم تبع نے بھی اور ان سب نے رسولوں کی تکذیب کی تو ہمارا وعدہ پورا ہوگیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlv{تو کیا ہم پہلی خلقت سے عاجز تھے ہرگز نہیں - تو پھر حقیقت یہ ہے کہ یہ لوگ نئی خلقت کی طرف سے شبہ میں پڑے ہوئے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvi{اور ہم نے ہی انسان کو پیدا کیا ہے اور ہمیں معلوم ہے کہ اس کا نفس کیا کیا وسوسے پیدا کرتا ہے اور ہم اس سے رگ گردن سے زیادہ قریب ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvii{جب کہ دو لکھنے والے اس کی حرکتوں کو لکھ لیتے ہیں جو داہنے اور بائیں بیٹھے ہوئے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlviii{وہ کوئی بات منہ سے نہیں نکالتا ہے مگر یہ کہ ایک نگہبان اس کے پاس موجود رہتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlix{اور موت کی بیہوشی یقینا طاری ہوگی کہ یہی وہ بات ہے جس سے تو بھاگا کرتا تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcl{اور پھر صور پھونکا جائے گا کہ یہ عذاب کے وعدہ کا دن ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcli{اور ہر نفس کو اس انداز سے آنا ہوگا کہ اس کے ساتھ ہنکانے والے اور گواہی دینے والے فرشتے بھی ہوں گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdclii{یقینا تم اس کی طرف سے غفلت میں تھے تو ہم نے تمہارے پردوں کو اُٹھادیاہے اور اب تمہاری نگاہ بہت تیز ہوگئی ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliii{اور اس کا ساتھی فرشتہ کہے گا کہ یہ اس کا عمل میرے پاس تیار موجود ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcliv{حکم ہوگا کہ تم دونوں ہر ناشکرے سرکش کو جہنمّ میں ڈال دو\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdclv{جو خیر سے روکنے والا حد سے تجاوز کرنے والا اور شبہات پیدا کرنے والا تھا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvi{جس نے اللہ کے ساتھ دوسرے خدا بنادیئے تھے تم دونوں اس کو شدید عذاب میں ڈال دو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdclvii{پھر اس کا ساتھی شیطان کہے گا کہ خدایا میں نے اس کو گمراہ نہیں کیا ہے یہ خود ہی گمراہی میں بہت دور تک چلا گیا تھا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdclviii{ارشاد ہوگا کہ میرے پاس جھگڑا مت کرو میں پہلے ہی عذاب کی خبر دے چکا ہوں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdclix{میرے پاس بات میں تبدیلی نہیں ہوتی ہے اور نہ میں بندوں پر ظلم کرنے والا ہوں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdclx{جس دن ہم جہّنم سے کہیں گے کہ تو بھر گیا تو وہ کہے گا کہ کیا کچھ اور مل سکتا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxi{اور جنّت کو صاحبانِ تقویٰ سے قریب تر کردیا جائے گا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxii{یہ وہ جگہ ہے جس کا وعدہ ہر خدا کی طرف رجوع کرنے والے اور نفس کی حفاظت کرنے والے سے کیا جاتا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiii{جو شخص بھی رحمان سے پبُ غیب ڈرتا ہے اور اس کی بارگاہ میں رجوع کرنے والے دل کی ساتھ حاضر ہوتا ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiv{تم سب سلامتی کے ساتھی جنّت میں داخل ہوجاؤ کہ یہ ہمیشگی کا دن ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxv{وہاں ان کے لئے جو کچھ بھی چاہیں گے سب حاضر رہے گا اور ہمارے پاس مزید بھی ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvi{اور ان سے پہلے ہم نے کتنی ہی قوموں کو ہلاک کردیا ہے جو ان سے کہیں زیادہ طاقتور تھیں تو انہوں نے تمام شہروں کو چھان مارا تھا لیکن موت سے چھٹکارا کہاں ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvii{اس واقعہ میں نصیحت کا سامان موجود ہے اس انسان کے لئے جس کے پاس دل ہو یا جو حضور قلب کے ساتھ بات سنتا ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxviii{اور ہم نے آسمان و زمین اور ان کے درمیان کی مخلوقات کو چھ دن میں پیدا کیا ہے اور ہمیں اس سلسلہ میں کوئی تھکن چھو بھی نہیں سکی ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxix{لہٰذا آپ ان کی باتوں پر صبر کریں اور طلوع آفتاب سے پہلے اور غروب آفتاب سے پہلے اپنے رب کی تسبیح کیا کریں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxx{اور رات کے ایک حصہ میں بھی اس کی تسبیح کریں اور سجدوں کے بعد بھی اس کی تسبیح کیا کریں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxi{اور اس دن کو غور سے سنو جس دن قدرت کا منادی اسرافیل قریب ہی کی جگہ سے آواز دے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxii{جس دن صدائے آسمان کو سب بخوبی سن لیں گے اور وہی دن قبروں سے نکلنے کا دن ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiii{بیشک ہم ہی موت و حیات دینے والے ہیں اور ہماری ہی طرف سب کی بازگشت ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiv{اسی دن زمین ان لوگوں کی طرف سے شق ہوجائے گی اور یہ تیزی سے نکل کھڑے ہوں گے کہ یہ حشر ہمارے لئے بہت آسان ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxv{ہمیں خوب معلوم ہے کہ یہ لوگ کیا کررہے ہیں اور آپ ان پر جبر کرنے والے نہیں ہیں آپ قرآن کے ذریعہ ان لوگوں کو نصیحت کرتے رہیں جو عذاب سے ڈرنے والے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvi{\basmalahur ان ہواؤں کی قسم جو بادلوں کو منتشر کرنے والی ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvii{بھر بادل کا بوجھ اٹھانے والی ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxviii{پھر دھیرے دھیرے چلنے والی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxix{پھر ایک امر کی تقسیم کرنے والی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxx{تم سے جس بات کا وعدہ کیا گیا ہے وہ سچی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxi{اور جزا و سزا بہرحال واقع ہونے والی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxii{اور مختلف راستوں والے آسمان کی قسم\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiii{کہ تم لوگ مختلف باتوں میں پڑے ہوئے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiv{حق سے وہی گمراہ کیا جاسکتا ہے جو بہکایا جاچکا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxv{بیشک اٹکل پچو لگانے والے مارے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvi{جو اپنی غفلت میں بھولے پڑے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvii{یہ پوچھتے ہیں کہ آخر قیامت کا دن کب آئے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxviii{تو یہ وہی دن ہے جس دن انہیں جہّنم کی آگ پر تپایا جائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxix{کہ اب اپنا عذاب چکھو اور یہی وہ عذاب ہے جس کی تم جلدی مچائے ہوئے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxc{بیشک متقی افراد باغات اور چشموں کے درمیان ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxci{جو کچھ ان کا پروردگار عطا کرنے والا ہے اسے وصول کررہے ہوں گے کہ یہ لوگ پہلے سے نیک کردار تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcii{یہ رات کے وقت بہت کم سوتے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciii{اور سحر کے وقت اللہ کی بارگاہ میں استغفار کیا کرتے تھے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciv{اور ان کے اموال میں مانگنے والے اور نہ مانگنے والے محروم افراد کے لئے ایک حق تھا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcv{اور زمین میں یقین کرنے والوں کے لئے بہت سی نشانیاں پائی جاتی ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvi{اور خود تمہارے اندر بھی - کیا تم نہیں دیکھ رہے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvii{اور آسمان میں تمہارا رزق ہے اور جن باتوں کا تم سے وعدہ کیا گیا ہے سب کچھ موجود ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcviii{آسمان و زمین کے مالک کی قسم یہ قرآن بالکل برحق ہے جس طرح تم خو دباتیں کررہے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcix{کیا تمہارے پاس ابراہیم علیھ السّلام کے محترم مہمانوں کا ذکر پہنچا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcc{جب وہ ان کے پاس وارد ہوئے اور سلام کیا تو ابراہیم علیھ السّلامنے جواب سلام دیتے ہوئے کہا کہ تم تو انجانی قوم معلوم ہوتے ہو\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcci{پھر اپنے گھر جاکر ایک موٹا تازہ بچھڑا تیار کرکے لے آئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccii{پھر ان کی طرف بڑھادیا اور کہا کیا آپ لوگ نہیں کھاتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciii{پھر اپنے نفس میں خوف کا احساس کیا تو ان لوگوں نے کہا کہ آپ ڈریں نہیں اور پھر انہیں ایک دانشمند فرزند کی بشارت دیدی\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcciv{یہ سن کر ان کی زوجہ شور مچاتی ہوئی آئیں اور انہوں نے منہ پیٹ لیا کہ میں بڑھیا بانجھ (یہ کیا بات ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccv{ان لوگوں نے کہا یہ ایسا ہی ہوگا یہ تمہارے پروردگار کا ارشاد ہے وہ بڑی حکمت والا اور ہر چیز کا جاننے والا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvi{ابراہیم علیھ السّلام نے کہا کہ اے فرشتو تمہیں کیا مہم درپیش ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccvii{انہوں نے کہا کہ ہمیں ایک مجرم قوم کی طرف بھیجا گیا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccviii{تاکہ ان کے اوپر مٹی کے کھرنجے دار پتھر برسائیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccix{جن پر پروردگار کی طرف سے حد سے گزر جانے والوں کے لئے نشانی لگی ہوئی ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccx{پھر ہم نے اس بستی کے تمام مومنین کو باہر نکال لیا\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxi{اور وہاں مسلمانوں کے ایک گھر کے علاوہ کسی کو پایا بھی نہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxii{اور وہاں ان لوگوں کے لئے ایک نشانی بھی چھوڑ دی جو دردناک عذاب سے ڈرنے والے ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiii{اور موسٰی علیھ السّلام کے واقعہ میں بھی ہماری نشانیاں ہیں جب ہم نے ان کو فرعون کی طرف کھلی ہوئی دلیل دے کر بھیجا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiv{تو اس نے لشکر کے دِم پر منہ موڑ لیا اور کہا کہ یہ جادوگر یا دیوانہ ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxv{تو ہم نے اسے اور اس کی فوج کو گرفت میں لے کر دریا میں ڈال دیا اور وہ قابل ملامت تھا ہی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvi{اور قوم عاد میں بھی ایک نشانی ہے جب ہم نے ان کی طرف بانجھ ہوا کو چلا دیا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvii{کہ جس چیز کے پاس سے گزر جاتی تھی اسے بوسیدہ ہڈی کی طرح ریزہ ریزہ کردیتی تھی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxviii{اور قوم ثمود میں بھی ایک نشانی ہے جب ان سے کہا گیا کہ تھوڑے دنوں مزے کرلو\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxix{تو ان لوگوں نے حکم خدا کی نافرمانی کی تو انہیں بجلی نے اپنی گرفت میں لے لیا اور وہ دیکھتے ہی رہ گئے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxx{پھر نہ وہ اٹھنے کے قابل تھے اور نہ مدد طلب کرنے کے لائق تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxi{اور ان سے پہلے قوم نوح تھی کہ وہ تو سب ہی فاسق اور بدکار تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxii{اور آسمان کو ہم نے اپنی طاقت سے بنایا ہے اور ہم ہی اسے وسعت دینے والے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiii{اور زمین کو ہم نے فرش کیا ہے تو ہم بہترین ہموار کرنے والے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiv{اور ہر شے میں سے ہم نے جوڑا بنایا ہے کہ شاید تم نصیحت حاصل کرسکو\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxv{لہذا اب خدا کی طرف دوڑ پڑو کہ میں کھلا ہوا ڈرانے والا ہوں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvi{اور خبردار اس کے ساتھ کسی دوسرے کو خدا نہ بنانا کہ میں تمہارے لئے واضح طور پر ڈرانے والا ہوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvii{اسی طرح ان سے پہلے کسی قوم کے پاس کوئی رسول نہیں آیا مگر یہ کہ ان لوگوں نے یہ کہہ دیا کہ یہ جادوگر ہے یا دیوانہ\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxviii{کیا انہوں نے ایک دوسرے کو اسی بات کی وصیت کی ہے - نہیں بلکہ یہ سب کے سب سرکش ہیں\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxix{لہٰذا آپ ان سے منہ موڑ لیں پھر آپ پر کوئی الزام نہیں ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxx{اور یاد دہانی بہرحال کراتے رہے کہ یاد دہانی صاحبانِ ایمان کے حق میں مفید ہوتی ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxi{اور میں نے جنات اور انسانوں کو صرف اپنی عبادت کے لئے پیدا کیا ہے(\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxii{میں ان سے نہ رزق کا طلبگار ہوں اور نہ یہ چاہتا ہوں کہ یہ مجھے کچھ کھلائیں\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiii{بیشک رزق دینے والا, صاحبِ قوت اور زبردست صرف علیھ السّلام اللہ ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiv{پھر ان ظالمین کے لئے بھی ویسے ہی نتائج ہیں جیسے ان کے اصحاب کے لئے تھے لہذا یہ جلدی نہ کریں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxv{پھر کفار کے لئے اس دن ویل اور عذاب ہے جس دن کا ان سے وعدہ کیا جارہا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvi{\basmalahur طور کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvii{اور لکھی ہوئی کتاب کی قسم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxviii{جو کشادہ اوراق میں ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxix{اور بیت معمور کی قسم\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxl{اور بلند چھت (آسمان) کی قسم\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxli{اور بھڑکتے ہوئے سمندر کی قسم\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlii{یقینا تمہارے رب کا عذاب واقع ہونے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliii{اور اس کا کوئی دفع کرنے والا نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliv{جس دن آسمان باقاعدہ چکر کھانے لگیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlv{اور پہاڑ باقاعدہ حرکت میں آجائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvi{پھر جھٹلانے والوں کے لئے عذاب اور بربادی ہی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvii{جو محلات میں پڑے کھیل تماشہ کررہے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlviii{جس دن انہیں بھرپور طریقہ سے جہّنم میں ڈھکیل دیا جائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlix{یہی وہ جہّنم کی آگ ہے جس کی تم تکذیب کیا کرتے تھے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccl{آیا یہ جادو ہے یا تمہیں کچھ سجھائی نہیں دے رہا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccli{اب اس میں چلے جاؤ پھر چاہے صبر کرو یا نہ کرو سب برابر ہے یہ تمہارے ان اعمال کی سزادی جارہی ہے جو تم انجام دیا کرتے تھے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclii{بیشک صاحبانِ تقویٰ باغات اور نعمتوں کے درمیان رہیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliii{جو خدا عنایت کرے گا اس میں خوش حال رہیں گے اور خدا انہیں جہّنم کے عذاب سے محفوظ رکھے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccliv{اب یہیں آرام سے کھاؤ پیو ان اعمال کی بنا پر جو تم نے انجام دئیے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclv{وہ برابر سے بچھے ہوئے تختوں پر تکیہ لگائے بیٹھے ہوں گے اور ہم ان کا جوڑا کشادہ چشم حوروں کو قرار دیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvi{اور جو لوگ ایمان لائے اور ان کی اولاد نے بھی ایمان میں ان کا اتباع کیا تو ہم ان کی ذریت کو بھی ان ہی سے ملادیں گے اور کسی کے عمل میں سے ذرہ برابر بھی کم نہیں کریں گے کہ ہر شخص اپنے اعمال کا گروی ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvii{اور ہم جس طرح کے میوے یا گوشت وہ چاہیں گے اس سے بڑھ کر ان کی امداد کریں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclviii{وہ آپس میں جام شراب پر جھگڑا کریں گے لیکن وہاں کوئی لغویت اور گناہ نہ ہوگا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclix{اور ان کے گرد وہ نوجوان لڑکے چکر لگاتے ہوں گے جو پوشیدہ اور محتاط موتیوں جیسے حسین و جمیل ہوں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclx{اور پھر ایک دوسرے کی طرف رخ کرکے سوال جواب کریں گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxi{کہیں گے کہ ہم تو اپنے گھر میں خدا سے بہت ڈرتے تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxii{تو خدا نے ہم پر یہ احسان کیا اور ہمیں جہّنم کی زہریلی ہوا سے بچالیا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiii{ہم اس سے پہلے بھی اسی سے دعائیں کیا کرتے تھے کہ وہ یقینا وہ بڑا احسان کرنے والا اور مہربان ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiv{لہذا آپ لوگوں کو نصیحت کرتے رہیں - خدا کے فضل سے آپ نہ کاہن ہیں اور نہ مجنون\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxv{کیا یہ لوگ یہ کہتے ہیں کہ یہ شاعر ہے اور ہم اس کے بارے میں حوادث زمانہ کا انتظار کررہے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvi{تو آپ کہہ دیجئے کہ بیشک تم انتظار کرو میں بھی تمہارے ساتھ انتظار کرنے والوں میں ہوں\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvii{کیا ان کی عقلیں یہ باتیں بتاتی ہیں یا یہ واقعا سرکش قوم ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxviii{یا یہ کہتے ہیں کہ نبی نے قرآن گڑھ لیا ہے اور حقیقت یہ ہے کہ یہ ایمان لانے والے ا نہیں ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxix{اگر یہ اپنی بات میں سچے ہیں تو یہ بھی ایسا ہی کوئی کلام لے آئیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxx{کیا یہ بغیر کسی چیز کے ازخود پیدا ہوگئے ہیں یا یہ خود ہی پیدا کرنے والے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxi{یا انہوں نے آسمان و زمین کو پیدا کردیا ہے - حقیقت یہ ہے کہ یہ یقین کرنے والے نہیں ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxii{یا ان کے پاس پروردگار کے خزانے ہیں یہی لوگ حاکم ہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiii{یا ان کے پاس کوئی سیڑھی ہے جس کے ذریعہ آسمان کی باتیں سن لیا کرتے ہیں تو ان کا سننے والا کوئی واضح ثبوت لے آئے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiv{یا خدا کے لئے لڑکیاں ہیں اور تمہارے لئے لڑکے ہیں\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxv{یا تم ان سے کوئی اجر رسالت مانگتے ہو کہ یہ اس کے بوجھ کے نیچے دبے جارہے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvi{یا ان کے پاس غیب کا علم ہے کہ یہ اسے لکھ رہے ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvii{یا یہ کوئی مکاری کرنا چاہتے ہیں تو یاد رکھو کہ کفار خود اپنی چال میں پھنس جانے والے ہیں\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxviii{یا ان کے لئے خدا کے علاوہ کوئی دوسرا خدا ہے جب کہ خدا ان کے شرک سے پاک و پاکیزہ ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxix{اور یہ اگر آسمان کے ٹکڑوں کو گرتا ہوا بھی دیکھ لیں گے تو بھی کہیں گے یہ تو تہ بہ تہ بادل ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxx{تو انہیں ان کے حال پر چھوڑ دیجئے یہاں تک کہ وہ دن دیکھ لیں جس دن بیہوش ہوجائیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxi{جس دن ان کی کوئی چال کام نہ آئے گی اور نہ کوئی مدد کرنے والا ہوگا\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxii{اور جن لوگوں نے ظلم کیا ہے ان کے لئے اس کے علاوہ بھی عذاب ہے لیکن ان کی اکثریت اس سے بے خبر ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiii{آپ اپنے پروردگار کے حکم کے لئے صبر کریں آپ ہماری نگاہ کے سامنے ہیں اور ہمیشہ قیام کرتے وقت اپنے پروردگار کی تسبیح کرتے رہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiv{اور رات کے ایک حصّہ میں اور ستاروں کے غروب ہونے کے بعد بھی تسبیحِ پروردگار کرتے رہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxv{\basmalahur قسم ہے ستارہ کی جب وہ ٹوٹا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvi{تمہارا ساتھی نہ گمراہ ہوا ہے اور نہ بہکا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvii{اور وہ اپنی خواہش سے کلام بھی نہیں کرتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxviii{اس کا کلام وہی وحی ہے جو مسلسل نازل ہوتی رہتی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxix{اسے نہایت طاقت والے نے تعلیم دی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxc{وہ صاحبِ حسن و جمال جو سیدھا کھڑا ہوا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxci{جب کہ وہ بلند ترین افق پر تھا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcii{پھر وہ قریب ہوا اور آگے بڑھا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciii{یہاں تک کہ دو کمان یا اس سے کم کا فاصلہ رہ گیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciv{پھر خدا نے اپنے بندہ کی طرف جس راز کی بات چاہی وحی کردی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcv{دل نے اس بات کو جھٹلایا نہیں جس کو آنکھوں نے دیکھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvi{کیا تم اس سے اس بات کے بارے میں جھگڑا کررہے ہو جو وہ دیکھ رہا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvii{اور اس نے تو اسے ایک بار اور بھی دیکھا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcviii{سدرِالمنتہیٰ کے نزدیک\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcix{جس کے پاس جنت الماویٰ بھی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccc{جب سدرہ پر چھا رہا تھا جو کچھ کہ چھا رہا تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccci{اس وقت اس کی آنکھ نہ بہکی اور نہ حد سے آگے بڑھی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccii{اس نے اپنے پروردگار کی بڑی بڑی نشانیان دیکھی ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciii{کیا تم لوگوں نے لات اور عذٰی کو دیکھا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccciv{اور منات جو ان کا تیسرا ہے اسے بھی دیکھا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccv{تو کیا تمہارے لئے لڑکے ہیں اور اس کے لئے لڑکیاں ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvi{یہ انتہائی ناانصافی کی تقسیم ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvii{یہ سب وہ نام ہیں جو تم نے اور تمہارے باپ دادا نے طے کرلئے ہیں خدا نے ان کے بارے میں کوئی دلیل نازل نہیں کی ہے - درحقیقت یہ لوگ صرف اپنے گمانوں کا اتباع کررہے ہیں اور جو کچھ ان کا دل چاہتا ہے اور یقینا ان کے پروردگار کی طرف سے ان کے پاس ہدایت آچکی ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccviii{کیا انسان کو وہ سب مل سکتا ہے جس کی آرزو کرے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccix{بس اللہ ہی کے لئے دنیا اور آخرت سب کچھ ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccx{اور آسمانوں میں کتنے ہی فرشتے ہیں جن کی سفارش کسی کے کام نہیں آسکتی ہے جب تک خدا .... جس کے بارے میں چاہے اور اسے پسند کرے .... اجازت نہ دے دے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxi{بیشک جو لوگ آخرت پر ایمان نہیں رکھتے ہیں وہ ملائکہ کے نام لڑکیوں جیسے رکھتے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxii{حالانکہ ان کے پاس اس سلسلہ میں کوئی علم نہیں ہے یہ صرف وہم و گمان کے پیچھے چلے جارہے ہیں اور گمان حق کے بارے میں کوئی فائدہ نہیں پہنچا سکتا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiii{لہذا جو شخص بھی ہمارے ذکر سے منہ پھیرے اور زندگانی دنیا کے علاوہ کچھ نہ چاہے آپ بھی اس سے کنارہ کش ہوجائیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiv{یہی ان کے علم کی انتہا ہے اور بیشک آپ کا پروردگار خوب جانتا ہے کہ کون اس کے راستہ سے بہک گیا ہے اور کون ہدایت کے راستہ پر ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxv{اوراللہ ہی کے لئے زمین و آسمان کے کل اختیارات ہیں تاکہ وہ بدعمل افراد کو ان کے اعمال کی سزادے سکے اور نیک عمل کرنے والوں کو ان کے اعمال کا اچھا بدلہ دے سکے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvi{جو لوگ گناہانِ کبیرہ اور فحش باتوں سے پرہیز کرتے ہیں (گناہان صغیرہ کے علاوہ) بیشک آپ کا پروردگار ان کے لئے بہت وسیع مغفرت والا ہے وہ اس وقت بھی تم سب کے حالات سے خوب واقف تھا جب اس نے تمہیں خاک سے پیدا کیا تھا اور اس وقت بھی جب تم ماں کے شکم میں جنین کی منزل میں تھے لہذا اپنے نفس کو زیادہ پاکیزہ قرار نہ دو وہ متقی افراد کو خوب پہچانتا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvii{کیا آپ نے اسے بھی دیکھا ہے جس نے منہ پھیر لیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxviii{اور تھوڑا سا راسِ خدا میں دے کر بند کردیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxix{کیا اس کے پاس علم غیب ہے جس کے ذریعے وہ دیکھ رہا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxx{یا اسے اس بات کی خبر ہی نہیں ہے جو موسٰی علیھ السّلام کے صحیفوں میں تھی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxi{یا ابراہیم علیھ السّلام کے صحیفوں میں تھی جنہوں نے پورا پورا حق ادا کیا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxii{کوئی شخص بھی دوسرے کا بوجھ اٹھانے والا نہیں ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiii{اور انسان کے لئے صرف اتنا ہی ہے جتنی اس نے کوشش کی ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiv{اور اس کی کوشش عنقریب اس کے سامنے پیش کردی جائے گی\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxv{اس کے بعد اسے پورا بدلہ دیا جائے گا\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvi{اور بیشک سب کی آخری منزل پروردگار کی بارگاہ ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvii{اور یہ کہ اسی نے ہنسایا بھی ہے اور ----- فِلایا بھی ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxviii{اور وہی موت و حیات کا دینے والا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxix{اور اسی نے نر اور مادہ کا جوڑا پیدا کیا ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxx{اس نطفہ سے جو رحم میں ڈالا جاتا ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxi{اور اسی کے ذمہ دوسری زندگی بھی ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxii{اور اسی نے مالدار بنایا ہے اور سرمایہ عطا کیا ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiii{اور وہی ستارہ شعریٰ کا مالک ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiv{اور اسی نے پہلے قوم عاد کو ہلاک کیا ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxv{اور قوم ثمود کو بھی پھر کسی کو باقی نہیں چھوڑا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvi{اور قوم نوح کو ان سے پہلے .کہ وہ لوگ بڑے ظالم اور سرکش تھے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvii{اور اسی نے قوم لوط کی اُلٹی بستیوں کو پٹک دیا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxviii{پھر ان کو ڈھانک لیا جس چیز نے کہ ڈھانک لیا\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxix{اب تم اپنے پروردگار کی کس نعمت پر شک کررہے ہو\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxl{بیشک یہ پیغمبر بھی اگلے ڈرانے والوں میں سے ایک ڈرانے والا ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxli{دیکھو قیامت قریب آگئی ہے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlii{اللہ کے علاوہ کوئی اس کا ٹالنے والا نہیں ہے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliii{کیا تم اس بات سے تعجب کررہے ہو\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliv{اور پھر ہنستے ہو اور روتے نہیں ہو\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlv{اور تم بالکل غافل ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvi{( اب سے غنیمت ہے) کہ اللہ کے لئے سجدہ کرو اور اس کی عبادت کرو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvii{\basmalahur قیامت قریب آگئی اور چاند کے دو ٹکڑے ہوگئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlviii{اور یہ کوئی بھی نشانی دیکھتے ہیں تو منہ پھیر لیتے ہیں اور کہتے ہیں کہ یہ ایک مسلسل جادو ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlix{اور انہوں نے تکذیب کی اور اپنی خواہشات کا اتباع کیا اور ہر بات کی ایک منزل ہوا کرتی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccl{یقینا ان کے پاس اتنی خبریں آچکی ہیں جن میں تنبیہ کا سامان موجود ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccli{انتہائی درجہ کی حکمت کی باتیں ہیں لیکن انہیں ڈرانے والی باتیں کوئی فائدہ نہیں پہنچاتیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclii{لہذا آپ ان سے منہ پھیر لیں جسن دن ایک بلانے والا (اسرافیل) انہیں ایک ناپسندہ امر کی طرف بلائے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliii{یہ نظریں جھکائے ہوئے قبروں سے اس طرح نکلیں گے جس طرح ٹڈیاں پھیلی ہوئی ہوں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliv{سب کسی بلانے والے کی طرف سر اٹھائے بھاگے چلے جارہے ہوں گے اور کفار یہ کہہ رہے ہوں گے کہ آج کا دن بڑا سخت دن ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclv{ان سے پہلے قوم نوح نے بھی تکذیب کی تھی کہ انہوں نے ہمارے بندے کو جھٹلایا اور کہہ دیا کہ یہ دیوانہ ہے بلکہ اسے جھڑکا بھی گیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvi{تو اس نے اپنے پروردگار سے دعا کی کہ میں مغلوب ہوگیا ہوں میری مدد فرما\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvii{تو ہم نے ایک موسلا دھار بارش کے ساتھ آسمان کے دروازے کھول دیئے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclviii{اور زمین سے بھی چشمے جاری کردیئے اور پھر دونوں پانی ایک خاص مقررہ مقصد کے لئے باہم مل گئے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclix{اور ہم نے نوح علیھ السّلامکو تختوں اور کیلوں والی کشتی میں سوار کرلیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclx{جو ہماری نگاہ کے سامنے چل رہی تھی اور یہ اس بندے کی جزا تھی جس کا انکار کیا گیا تھا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxi{اور ہم نے اسے ایک نشانی بناکر چھوڑ دیا ہے تو کیا کوئی ہے جو نصیحت حاصل کرے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxii{پھر ہمارا عذاب اور ڈرانا کیسا ثابت ہوا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiii{اور ہم نے قرآن کو نصیحت کے لئے آسان کردیا ہے تو کیا کوئی نصیحت حاصل کرنے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiv{اور قوم عاد نے بھی تکذیب کی تو ہمارا عذاب اور ڈرانا کیسا رہا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxv{ہم نے ان کی اوپر تیز و تند آندھی بھیج دی ایک مسلسل نحوست والے منحوس دن میں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvi{جو لوگوں کو جگہ سے یوں اُٹھالیتی تھی جیسے اکھڑے ہوئے کھجور کے تنے ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvii{پھر دیکھو ہمارا ذاب اور ڈرانا کیسا ثابت ہوا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxviii{اور ہم نے قرآن کو نصیحت کے لئے آسان کردیا ہے تو کیا کوئی نصیحت حاصل کرنے والا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxix{اور ثمود نے بھی پیغمبروں علیھ السّلام کو جھٹلایا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxx{اور کہہ دیا کہ کیا ہم اپنے ہی میں سے ایک شخص کا اتباع کرلیں اس طرح تو ہم گمراہی اور دیوانگی کا شکار ہوجائیں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxi{کیا ہم سب کے درمیان ذکر صرف اسی پر نازل ہوا ہے درحقیقت یہ جھوٹا ہے اور بڑائی کا طلبگار ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxii{تو عنقریب کل ہی انہیں معلوم ہوجائے گا جھوٹا اور متکبر کون ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiii{ہم ان کے امتحان کے لئے ایک اونٹنی بھیجنے والے ہیں لہذا تم اس کا انتظار کرو اور صبر سے کام لو\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiv{اور انہیں باخبر کردو کہ پانی ان کے درمیان تقسیم ہوگا اور ہر ایک کو اپنی باری پر حاضر ہونا چاہئے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxv{تو ان لوگوں نے اپنے ساتھی کو آواز دی اور اس نے اونٹنی کو پکڑ کر اس کی کونچیں کاٹ دیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvi{پھر سب نے دیکھا کہ ہمارا عذاب اور ڈرانا کیسا ثابت ہوا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvii{ہم نے ان کے اوپر ایک چنگھاڑ کو بھیج دیا تو یہ سب کے سب باڑے کے بھوسے کی طرح ہوگئے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxviii{اور ہم نے قرآن کو نصیحت کے لئے آسان کردیا ہے تو کیا کوئی نصیحت حاصل کرنے والا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxix{اور قوم لوط نے بھی پیغمبروں علیھ السّلام کو جھٹلایا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxx{تو ہم نے ان کے اوپر پتھر برسائے صرف لوط کی آل کے علاوہ کہ ان کو سحر کے ہنگام ہی بچالیا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxi{یہ ہماری ایک نعمت تھی اور اسی طرح ہم شکر گزار بندوں کو جزادیتے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxii{اور لوط نے انہیں ہماری گرفت سے ڈرایا لیکن ان لوگوں نے ڈرانے ہی میں شک کیا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiii{اور ان سے مہمان کے بارے میں ناجائز مطالبات کرنے لگے تو ہم نے ان کی آنکھوں کو اندھا کردیا کہ اب عذاب اور ڈرانے کا مزہ چکھو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiv{اور ان کے اوپر صبح سویرے نہ ٹلنے والا عذاب نازل ہوگیا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxv{کہ اب ہمارے عذاب اور ڈرانے کا مزہ چکھو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvi{اور ہم نے قرآن کو نصیحت کے لئے آسان کردیا ہے تو کیا کوئی نصیحت حاصل کرنے والا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvii{اور فرعون والوں تک بھی پیغمبر علیھ السّلام آئے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxviii{تو انہوں نے ہماری ساری نشانیوں کا انکار کردیا تو ہم نے بھی ایک زبردست صاحب هاقتدار کی طرح انہیں اپنی گرفت میں لے لیا\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxix{تو کیا تمہارے کفار ان سب سے بہتر ہیں یا ان کے لئے کتابوں میں کوئی معافی نامہ لکھ دیا گیا ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxc{یا ان کا کہنا یہ ہے کہ ہمارے پاس بڑی جماعت ہے جو ایک دوسرے کی مدد کرنے والی ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxci{عنقریب یہ جماعت شکست کھاجائے گی اور سب پیٹھ پھیر کر بھاگ جائیں گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcii{بلکہ ان کا موعد قیامت کا ہے اور قیامت انتہائی سخت اور تلخ حقیقت ہے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciii{بیشک مجرمین گمراہی اور دیوانگی میں مبتلا ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciv{قیامت کے دن یہ آگ پر منہ کے بل کھینچے جائیں گے کہ اب جہنمّ کا مزہ چکھو\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcv{بیشک ہم نے ہر شے کو ایک اندازہ کے مطابق پیدا کیا ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvi{اور ہمارا حکم پلک جھپکنے کی طرح کی ایک بات ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvii{اور ہم نے تمہارے ساتھیوں کو پہلے ہی ہلاک کردیا ہے تو کیا کوئی نصیحت حاصل کرنے والا ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcviii{اور ان لوگوں نے جو کچھ بھی کیا ہے سب نامہ اعمال میں محفوظ ہے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcix{اور ہر چھوٹا اور بڑا عمل اس میں درج کردیا گیا ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcm{بیشک صاحبان هتقویٰ باغات اور نہروں کے درمیان ہوں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmi{اس پاکیزہ مقام پر جو صاحبِ اقتدار بادشاہ کی بارگاہ میں ہے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmii{\basmalahur وہ خدا بڑا مہربان ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiii{اس نے قرآن کی تعلیم دی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmiv{انسان کو پیدا کیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmv{اور اسے بیان سکھایا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvi{آفتاب و ماہتاب سب اسی کے مقرر کردہ حساب کے ساتھ چل رہے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmvii{اور بوٹیاں بیلیں اور درخت سب اسی کا سجدہ کررہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmviii{اس نے آسمان کو بلند کیا ہے اور انصاف کی ترازو قائم کی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmix{تاکہ تم لوگ وزن میں حد سے تجاوز نہ کرو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmx{اور انصاف کے ساتھ وزن کو قائم کرو اور تولنے میں کم نہ تولو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxi{اور اسی نے زمین کو انسانوں کے لئے وضع کیا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxii{اس میں میوے ہیں اور وہ کھجوریں ہیں جن کے خوشوں پر غلاف چڑھے ہوئے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiii{وہ دانے ہیں جن کے ساتھ بھس ہوتا ہے اور خوشبودار پھول بھی ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiv{اب تم دونوں اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxv{اس نے انسان کو ٹھیکرے کی طرح کھنکھناتی ہوئی مٹی سے پیدا کیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvi{اور جنات کو آگ کے شعلوں سے پیدا کیا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvii{تو تم دونوں اپنے پروردگار کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxviii{وہ چاند اور سورج دونوں کے مشرق اور مغرب کا مالک ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxix{پھر تم دونوں اپنی رب کی کن کن نعمتوں کو جھٹلاؤ گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxx{اس نے دو دریا بہائے ہیں جو آپس میں مل جاتے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxi{ان کے درمیان حد فا صلِ ہے کہ ایک دوسرے پر زیادتی نہیں کرسکتے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxii{تو تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiii{ان دونوں دریاؤں سے موتی اور مونگے برآمد ہوتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiv{تو تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxv{اسی کے وہ جہاز بھی ہیں جو دریا میں پہاڑوں کی طرح کھڑے رہتے ہیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvi{تو تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvii{جو بھی روئے زمین پر ہے سب فنا ہوجانے والے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxviii{صرف تمہاری رب کی ذات جو صاحبِ جلال و اکرام ہے وہی باقی رہنے والی ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxix{تو تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxx{آسمان و زمین میں جو بھی ہے سب اسی سے سوال کرتے ہیں اور وہ ہر روز ایک نئی شان والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxi{کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxii{اے دونوں گروہو ہم عنقریب ہی تمہاری طرف متوجہ ہوں گے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiii{تو تم اپنے پروردگار کی کس کس نعمت کا انکار کرو گے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiv{اے گروہ جن و انس اگر تم میں قدرت ہو کہ آسمان و زمین کے اطرف سے باہر نکل جاؤ تو نکل جاؤ مگر یاد رکھو کہ تم قوت اور غلبہ کے بغیر نہیں نکل سکتے ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxv{تو تم اپنے پروردگار کی کس کس نعمت کا انکار کرو گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvi{تمہارے اوپر آگ کا سبز شعلہ اور دھواں چھوڑ دیا جائے گا تو تم دونوں کسی طرح نہیں روک سکتے ہو\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvii{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxviii{پھر جب آسمان پھٹ کر تیل کی طرح سرخ ہوجائے گا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxix{تو تم اپنے پروردگار کی کس کس نعمت کا انکار کرو گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxl{پھر اس دن کسی انسان یا جن سے اس کے گناہ کے بارے میں سوال نہیں کیا جائے گا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxli{تو پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlii{مجرم افراد تو اپنی نشانی ہی سے پہچان لئے جائیں گے پھر پیشانی اور پیروں سے پکڑ لئے جائیں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliii{تو تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliv{یہی وہ جہنّم ہے جس کا مجرمین انکار کررہے تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlv{اب اس کے اور کھولتے ہوئے پانی کے درمیان چکر لگاتے پھریں گے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvi{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvii{اور جو شخص بھی اپنے رب کی بارگاہ میں کھڑے ہونے سے ڈرتا ہے اس کے لئے دو دو باغات ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlviii{پھر تم اپنے پروردگار کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlix{اور دونوں باغات درختوں کی ٹہنیوں سے ہرے بھرے میوؤں سے لدے ہوں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmcml{پھر تم اپنے رب کی کس کس نعمت کو جھٹلاؤ گے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmcmli{ان دونوں میں دو چشمے بھی جاری ہوں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlii{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliii{ان دونوں میں ہر میوے کے جوڑے ہوں گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmcmliv{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlv{یہ لوگ ان فرشوں پر تکیہ لگائے بیٹھے ہوں گے جن کے استراطلس کے ہوں گے اور دونوں باغات کے میوے انتہائی قریب سے حاصل کرلیں گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvi{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvii{ان جنتوں میں محدود نگاہ والی حوریں ہوں گی جن کو انسان اور جنات میں سے کسی نے پہلے چھوا بھی نہ ہوگا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlviii{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlix{وہ حوریں اس طرح کی ہوں گی جیسے سرخ یاقوت اور مونگے\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlx{پھر تم اپنے پروردگار کی کس کس نعمت کا انکار کرو گے\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxi{کیا احسان کا بدلہ احسان کے علاوہ کچھ اور بھی ہوسکتا ہے\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxii{تو تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiii{اور ان دونوں کے علاوہ دو باغات اور ہوں گے\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiv{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxv{دونوں نہایت درجہ سرسبز و شاداب ہوں گے\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvi{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvii{ان دونوں باغات میں بھی دو جوش مارتے ہوئے چشمے ہوں گے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxviii{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxix{ان دونوں باغات میں میوے, کھجوریں اور انار ہوں گے\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxx{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxi{ان جنتوں میں نیک سیرت اور خوب صورت عورتیں ہوں گی\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxii{شپھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiii{وہ حوریں ہیں جو خیموں کے اندر چھپی بیٹھی ہوں گی\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiv{تو تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxv{انہیں ان سے پہلے کسی انسان یا جن نے ہاتھ تک نہ لگایا ہوگا\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvi{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvii{وہ لوگ سبز قالینوں اور بہترین مسندوں پر ٹیک لگائے بیٹھے ہوں گے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxviii{پھر تم اپنے رب کی کس کس نعمت کا انکار کرو گے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxix{بڑا بابرکت ہے آپ کے پروردگار کا نام جو صاحب جلال بھی ہے اور صاحبِ اکرام بھی ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxx{\basmalahur جب قیامت برپا ہوگی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxi{اور اس کے قائم ہونے میں ذرا بھی جھوٹ نہیں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxii{وہ الٹ پلٹ کر دینے والی ہوگی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiii{جب زمین کو زبردست جھٹکے لگیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiv{اور پہاڑ بالکل چور چور ہوجائیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxv{پھر ذرات بن کر منتشر ہوجائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvi{اور تم تین گروہ ہوجاؤ گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvii{پھر داہنے ہاتھ والے اور کیا کہنا داہنے ہاتھ والوں کا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxviii{اور بائیں ہاتھ والے اور کیا پوچھنا ہے بائیں ہاتھ والوں کا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxix{اور سبقت کرنے والے تو سبقت کرنے والے ہی ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxc{وہی اللہ کی بارگاہ کے مقرب ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxci{نعمتوں بھری جنتوں میں ہوں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcii{بہت سے لوگ اگلے لوگوں میں سے ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciii{اور کچھ آخر دور کے ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciv{موتی اور یاقوت سے جڑے ہوئے تختوں پر\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcv{ایک دوسرے کے سامنے تکیہ لگائے بیٹھے ہوں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvi{ان کے گرد ہمیشہ نوجوان رہنے والے بچے گردش کررہے ہوں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvii{پیالے اور ٹونٹی وار کنٹر اور شراب کے جام لئے ہوئے ہوں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcviii{جس سے نہ درد سر پیدا ہوگا اور نہ ہوش و حواس گم ہوں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcix{اور ان کی پسند کے میوے لئے ہوں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmm{اور ان پرندوں کا گوشت جس کی انہیں خواہش ہوگی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmi{اور کشادہ چشم حوریں ہوں گی\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmii{جیسے سربستہ ہوتی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmiii{یہ سب درحقیقت ان کے اعمال کی جزا اور اس کا انعام ہوگا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmiv{وہاں نہ کوئی لغویات سنیں گے اور نہ گناہ کی باتیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmv{صرف ہر طرف سلام ہی سلام ہوگا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmvi{اور داہنی طرف والے اصحاب ... کیا کہنا ان اصحاب یمین کا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmvii{بے کانٹے کی بیر\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmviii{لدے گتھے ہوئے کیلے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmix{پھیلے ہوئے سائے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmx{جھرنے سے گرتے ہوئے پانی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmxi{کثیر تعداد کے میوؤں کے درمیان ہوں گے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmxii{جن کا سلسلہ نہ ختم ہوگا اور نہ ان پر کوئی روک ٹوک ہوگی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiii{اور اونچے قسم کے گدے ہوں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmxiv{بیشک ان حوروں کو ہم نے ایجاد کیا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmxv{تو انہیں نت نئی بنایا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvi{یہ کنواریاں اور آپس میں ہمجولیاں ہوں گی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmxvii{یہ سب اصحاب یمین کے لئے ہیں\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmxviii{جن کا ایک گروہ پہلے لوگوں کا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmxix{اور ایک گروہ آخری لوگوں کا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmxx{اور بائیں ہاتھ والے تو ان کا کیا پوچھنا ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxi{گرم گرم ہوا کھولتا ہوا پانی\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxii{کالے سیاہ دھوئیں کا سایہ\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiii{جو نہ ٹھنڈا ہو اور نہ اچھا لگے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiv{یہ وہی لوگ ہیں جو پہلے بہت آرام کی زندگی گزار رہے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxv{اور بڑے بڑے گناہوں پر اصرار کررہے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvi{اور کہتے تھے کہ کیا جب ہم مرجائیں گے اور خاک اور ہڈی ہوجائیں گے تو ہمیں دوبارہ اٹھایا جائے گا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvii{کیا ہمارے باپ دادا بھی اٹھائے جائیں گے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxviii{آپ کہہ دیجئے کہ اولین و آخرین سب کے سب\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxix{ایک مقرر دن کی وعدہ گاہ پر جمع کئے جائیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxx{اس کے بعد تم اے گمراہو اور جھٹلانے والوں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxi{تھوہڑ کے درخت کے کھانے والے ہو گے\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxii{پھر اس سے اپنے پیٹ بھرو گے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiii{پھر اس پر کھولتا ہوا پانی پیو گے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiv{پھر اس طرح پیو گے جس طرح پیاسے اونٹ پیتے ہیں\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxv{یہ قیامت کے دن ان کی مہمانداری کا سامان ہوگا\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvi{ہم نے تم کو پیدا کیا ہے تو دوبارہ پیدا کرنے کی تصدیق کیوں نہیں کرتے\qt@no{(57)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvii{کیا تم نے اس نطفہ کو دیکھا ہے جو رحم میں ڈالتے ہو\qt@no{(58)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxviii{اسے تم پیدا کرتے ہو یا ہم پیدا کرنے والے ہیں\qt@no{(59)}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxix{ہم نے تمہارے درمیان موت کو مقدر کردیا ہے اور ہم اس بات سے عاجز نہیں ہیں\qt@no{(60)}}%
\qt@newcmd\qurantrans@ur@mmmmmxl{کہ تم جیسے اور لوگ پیدا کردیں اور تمہیں اس عالم میں دوبارہ ایجاد کردیں جسے تم جانتے بھی نہیں ہو\qt@no{(61)}}%
\qt@newcmd\qurantrans@ur@mmmmmxli{اور تم پہلی خلقت کو تو جانتے ہو تو پھر اس میں غور کیوں نہیں کرتے ہو\qt@no{(62)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlii{اس دا نہ کو بھی دیکھا ہے جو تم زمین میں بوتے ہو\qt@no{(63)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliii{اسے تم اگاتے ہو یا ہم اگانے والے ہیں\qt@no{(64)}}%
\qt@newcmd\qurantrans@ur@mmmmmxliv{اگر ہم چاہیں تو اسے چور چور بنادیں تو تم باتیں ہی بناتے رہ جاؤ\qt@no{(65)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlv{کہ ہم تو بڑے گھاٹے میں رہے\qt@no{(66)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvi{بلکہ ہم تو محروم ہی رہ گئے\qt@no{(67)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvii{کیا تم نے اس پانی کو دیکھا ہے جس کو تم پیتے ہو\qt@no{(68)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlviii{اسے تم نے بادل سے برسایا ہے یا اس کے برسانے والے ہم ہیں\qt@no{(69)}}%
\qt@newcmd\qurantrans@ur@mmmmmxlix{اگر ہم چاہتے تو اسے کھارا بنادیتے تو پھر تم ہمارا شکریہ کیوں نہیں ادا کرتے ہو\qt@no{(70)}}%
\qt@newcmd\qurantrans@ur@mmmmml{کیا تم نے اس آگ کو دیکھا ہے جسے لکڑی سے نکالتے ہو\qt@no{(71)}}%
\qt@newcmd\qurantrans@ur@mmmmmli{اس کے درخت کو تم نے پیدا کیا ہے یا ہم اس کے پیدا کرنے والے ہیں\qt@no{(72)}}%
\qt@newcmd\qurantrans@ur@mmmmmlii{ہم نے اسے یاد دہانی کا ذریعہ اور مسافروں کے لئے نفع کا سامان قرار دیا ہے\qt@no{(73)}}%
\qt@newcmd\qurantrans@ur@mmmmmliii{اب آپ اپنے عظیم پروردگار کے نام کی تسبیح کریں\qt@no{(74)}}%
\qt@newcmd\qurantrans@ur@mmmmmliv{اور میں تو تاروں کے منازل کی قسم کھاکر کہتا ہوں\qt@no{(75)}}%
\qt@newcmd\qurantrans@ur@mmmmmlv{اور تم جانتے ہو کہ یہ قسم بہت بڑی قسم ہے\qt@no{(76)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvi{یہ بڑا محترم قرآن ہے\qt@no{(77)}}%
\qt@newcmd\qurantrans@ur@mmmmmlvii{جسے ایک پوشیدہ کتاب میں رکھا گیا ہے\qt@no{(78)}}%
\qt@newcmd\qurantrans@ur@mmmmmlviii{اسے پاک و پاکیزہ افراد کے علاوہ کوئی چھو بھی نہیں سکتا ہے\qt@no{(79)}}%
\qt@newcmd\qurantrans@ur@mmmmmlix{یہ رب العالمین کی طرف سے نازل کیا گیا ہے\qt@no{(80)}}%
\qt@newcmd\qurantrans@ur@mmmmmlx{تو کیا تم لوگ اس کلام سے انکار کرتے ہو\qt@no{(81)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxi{اور تم نے اپنی روزی یہی قرار دے رکھی ہے کہ اس کا انکار کرتے رہو\qt@no{(82)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxii{پھر ایسا کیوں نہیں ہوتا کہ جب جان گلے تک پہنچ جائے\qt@no{(83)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiii{اور تم اس وقت دیکھتے ہی رہ جاؤ\qt@no{(84)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiv{اور ہم تمہاری نسبت مرنے والے سے قریب ہیں مگر تم دیکھ نہیں سکتے ہو\qt@no{(85)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxv{پس اگر تم کسی کے دباؤ میں نہیں ہو اور بالکل آزاد ہو\qt@no{(86)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvi{تو اس روح کو کیوں نہیں پلٹا دیتے ہو اگر اپنی بات میں سچے ہو\qt@no{(87)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvii{پھر اگر مرنے والا مقربین میں سے ہے\qt@no{(88)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxviii{تو اس کے لئے آسائش, خوشبو دار پھول اور نعمتوں کے باغات ہیں\qt@no{(89)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxix{اور اگر اصحاب یمین میں سے ہے\qt@no{(90)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxx{تو اصحاب یمین کی طرف سے تمہارے لئے سلام ہے\qt@no{(91)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxi{اور اگر جھٹلانے والوں اور گمراہوں میں سے ہے\qt@no{(92)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxii{تو کھولتے ہوئے پانی کی مہمانی ہے\qt@no{(93)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiii{اور جہنّم میں جھونک دینے کی سزا ہے\qt@no{(94)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiv{یہی وہ بات ہے جو بالکل برحق اور یقینی ہے\qt@no{(95)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxv{لہذا اپنے عظیم پروردگار کے نام کی تسبیح کرتے رہو\qt@no{(96)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvi{\basmalahur محو تسبیح پروردگار ہے ہر وہ چیز جو زمین و آسمان میں ہے اور وہ پروردگار صاحبِ عزت بھی ہے اور صاحبِ حکمت بھی ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvii{آسمان و زمین کا کل اختیار اسی کے پاس ہے اور وہی حیات و موت کا دینے والا ہے اور ہر شے پر اختیار رکھنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxviii{وہی اوّل ہے وہی آخر وہی ظاہر ہے وہی باطن اور وہی ہر شے کا جاننے والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxix{وہی وہ ہے جس نے زمین و آسمان کو چھ دن میں پیدا کیا ہے اور پھر عرش پر اپنا اقتدار قائم کیا ہے وہ ہر اس چیز کو جانتا ہے جو زمین میں داخل ہوتی ہے یا زمین سے خارج ہوتی ہے اور جو چیز آسمان سے نازل ہوتی ہے اور آسمان کی طرف بلند ہوتی ہے اور وہ تمہارے ساتھ ہے تم جہاں بھی رہو اور وہ تمہارے اعمال کا دیکھنے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxx{آسمان و زمین کا ملک اسی کے لئے ہے اور تمام امور کی بازگشت اسی کی طرف ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxi{وہ رات کو دن میں اور دن کو رات میں داخل کرتا ہے اور وہ سینوں کے رازوں سے بھی باخبر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxii{تم لوگ اللہ و رسول پر ایمان لے آؤ اور اس مال میں سے خرچ کرو جس میں اس نے تمہیں اپنا نائب قرار دیا ہے - تم میں سے جو لوگ ایمان لائے اور انہوں نے راسِ خدا میں خرچ کیا ان کے لئے اجر عظیم ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiii{اور تمہیں کیا ہوگیا ہے کہ تم خدا پر ایمان نہیں لاتے ہو جب کہ رسو ل تمہیں دعوت دے رہا ہے کہ اپنے پروردگار پر ایمان لے آؤ اور خدا تم سے اس بات کا عہد بھی شلے چکا ہے اگر تم اعتبار کرنے والے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiv{وہی وہ ہے جو اپنے بندے پر کھلی ہوئی نشانیاں نازل کرتا ہے تاکہ تمہیں تاریکیوں سے نور کی طرف نکال کرلے آئے اور اللہ تمہارے حال پر یقینا مہربان و رحم کرنے والا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxv{اور تمہیں کیا ہوگیا ہے کہ تم راہ هخدا میں خرچ نہیں کرتے ہو جب کہ آسمان و زمین کی وراثت اسی کے لئے ہے اور تم میں سے فتح سے پہلے انفاق کرنے والا اور جہاد کرنے والا اس کے جیسا نہیں ہوسکتا ہے جو فتح کے بعد انفاق اور جہاد کرے - پہلے جہاد کرنے والے کا درجہ بہت بلند ہے اگرچہ خدا نے سب سے نیکی کا وعدہ کیا ہے اور وہ تمہارے جملہ اعمال سے باخبر ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvi{کون ہے جو اللہ کو قرض حسنہ دے کہ وہ اس کو دوگنا کردے اور اس کے لئے باعزّت اجر بھی ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvii{اس دن تم باایمان مرد اور باایمان عورتوں کو دیکھو گے کہ ان کا نور هایمان ان کے آگے آگے اور داہنی طرف چل رہا ہے اور ان سے کہا جارہا ہے کہ آج تمہاری بشارت کا سامان وہ باغات ہیں جن کے نیچے نہریں جاری ہیں اور تم ہمیشہ ان ہی میں رہنے والے ہو اور یہی سب سے بڑی کامیابی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxviii{اس دن منافق مرد اور منافق عورتیں صاحبان هایمان سے کہیں گے کہ ذرا ہماری طرف بھی نظر مرحمت کرو کہ ہم تمہارے نور سے استفادہ کریں تو ان سے کہا جائے گا کہ اپنے پیچھے کی طرف پلٹ جاؤ اور اپنے شیاطین سے نور کی التماس کرو اس کے بعد ان کے درمیان ایک دیوار حائل کردی جائے گی جس کے اندر کی طرف رحمت ہوگی اور باہر کی طرف عذاب ہوگا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxix{اور منافقین ایمان والوں سے پکار کر کہیں گے کہ کیا ہم تمہارے ساتھ نہیں تھے تو وہ کہیں گے بیشک مگر تم نے اپنے کو بلاؤں میں مبتلا کردیا اور ہمارے لئے مصائب کے منتظر رہے اور تم نے رسالت میں شک کیا اور تمہیں تمناؤں نے دھوکہ میں ڈالے رکھا یہاں تک کہ حکم خدا آگیا اور تمہیں دھوکہ باز شیطان نے دھوکہ دیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmxc{تو آج نہ تم سے کوئی فدیہ لیا جائے گا اور نہ کفار سے تم سب کا ٹھکانا جہنمّ ہے وہی تم سب کا صاحب هاختیار ہے اور تمہارا بدترین انجام ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmxci{کیا صاحبانِ ایمان کے لئے ابھی وہ وقت نہیں آیا ہے کہ ان کے دل ذکر خدا اور اس کی طرف سے نازل ہونے والے حق کے لئے نرم ہوجائیں اور وہ ان اہل کتاب کی طرح نہ ہوجائیں جنہیں کتاب دی گئی تو ایک عرصہ گزرنے کے بعد ان کے دل سخت ہوگئے اور ان کی اکثریت بدکار ہوگئی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcii{یاد رکھو کہ خدا مردہ زمینوں کا زندہ کرنے والا ہے اور ہم نے تمام نشانیوں کو واضح کرکے بیان کردیا ہے تاکہ تم عقل سے کام لے سکو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciii{بیشک خیرات کرنے والے مرد اور خیرات کرنے والی عورتیں اور جنہوں نے راسِ خدا میں اخلاص کے ساتھ مال خرچ کیا ہے ان کا اجر دوگنا کردیا جائے گا اور ان کے لئے بڑا باعزّت اجر ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmxciv{اور جو لوگ اللہ اور رسول پر ایمان لائے وہی خدا کے نزدیک صدیق اور شہید کا درجہ رکھتے ہیں اور ا ن ہی کے لئے ان کا اجر اور نور ہے اور جنہوں نے کفر اختیار کرلیا اور ہماری آیات کی تکذیب کردی وہی دراصل اصحاب جہنّم ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcv{یاد رکھو کہ زندگی دنیا صرف ایک کھیل, تماشہ, آرائش, باہمی تفاخراور اموال و اولاد کی کثرت کا مقابلہ ہے اور بس جیسے کوئی بارش ہو جس کی قوت نامیہ کسان کو خوش کردے اور اس کے بعد وہ کھیتی خشک ہوجائے پھر تم اسے زرد دیکھو اور آخر میں وہ ریزہ ریزہ ہوجائے اور آخرت میں شدید عذاب بھی ہے اور مغفرت اور رضائے الۤہیبھی ہے اور زندگانی دنیا تو بس ایک دھوکہ کا سرمایہ ہے اور کچھ نہیں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvi{تم سب اپنے پروردگار کی مغفرت اور اس جّنت کی طرف سبقت کرو جس کی وسعت زمین و آسمان کے برابر ہے اور جسے ان لوگوں کے لئے مہیاّ کیا گیا ہے جو خدا اور رسول پر ایمان لائے ہیں یہی درحقیقت فضل خدا ہے جسے چاہتا ہے عطا کردیتا ہے اور اللہ تو بہت بڑے فضل کا مالک ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvii{زمین میں کوئی بھی مصیبت وارد ہوتی ہے یا تمہارے نفس پر نازل ہوتی ہے تو نفس کے پیدا ہونے کے پہلے سے وہ کتاب الۤہی میں مقدر ہوچکی ہے اور یہ خدا کے لئے بہت آسان شے ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcviii{یہ تقدیر اس لئے ہے کہ جو تمہارے ہاتھ سے نکل جائے اس کا افسوس نہ کرو اور جو مل جائے اس پر غرور نہ کرو کہ اللہ اکڑنے والے مغرور افراد کو پسند نہیں کرتا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmxcix{جو خود بھی بخل کرتے ہیں اور دوسروں کو بھی بخل کا حکم دیتے ہیں اور جو بھی خدا سے روگردانی کرے گا اسے معلوم رہے کہ خدا سب سے بے نیاز اور قابلِ حمد و ستائش ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmc{بیشک ہم نے اپنے رسولوں کو واضح دلائل کے ساتھ بھیجا ہے اور ان کے ساتھ کتاب اور میزان کو نازل کیا ہے تاکہ لوگ انصاف کے ساتھ قیام کریں اور ہم نے لوہے کو بھی نازل کیا ہے جس میں شدید جنگ کا سامان اور بہت سے دوسرے منافع بھی ہیں اور اس لئے کہ خدا یہ دیکھے کہ کون ہے جو بغیر دیکھے اس کی اور اس کے رسول کی مدد کرتا ہے اور یقینا اللہ بڑا صاحبِ قوت اور صاحبِ عزت ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmci{اور ہم نے نوح علیھ السّلام اور ابراہیم علیھ السّلام کو بھیجا اور ان کی اولاد میں کتاب اور نبوت قرار دی تو ان میں سے کچھ ہدایت یافتہ تھے اور بہت سے فاسق اور بدکار تھے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcii{پھر ہم نے ان ہی کے نقش قدم پر دوسرے رسول بھیجے اور ان کے پیچھے عیسٰی علیھ السّلام بن مریم علیھ السّلام کو بھیجا اور انہیں انجیل عطا کردی اور ان کا اتباع کرنے والوں کے دلوں میں مہربانی اور محبت قرار دے دی اور جس رہبانیت کو ان لوگوں نے ازخود ایجاد کرلیا تھا اور اس سے رضائے خدا کے طلبگار تھے اسے ہم نے ان کے اوپر فرض نہیں قرار دیا تھا اور انہوں نے خود بھی اس کی مکمل پاسداری نہیں کی تو ہم نے ان میں سے واقعا ایمان لانے والوں کو اجر عطا کردیا اور ان میں سے بہت سے تو بالکل فاسق اور بدکردار تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmciii{ایمان والو اللہ سے ڈرو اور رسول پر واقعی ایمان لے آؤ تاکہ خدا تمہیں اپنی رحمت کے دہرے حّصے عطا کردے اور تمہارے لئے ایسا نور قرار دے دے جس کی روشنی میں چل سکو اور تمہیں بخش دے اور اللہ بہت زیادہ بخشنے والا اور مہربان ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmciv{تاکہ اہلِ کتاب کو معلوم ہوجائے کہ وہ فضل خدا کے بارے میں کوئی اختیار نہیں رکھتے ہیں اور فضل تمام تر خدا کے ہاتھ میں ہے وہ جسے چاہتا ہے عطا کردیتا ہے اور وہ بہت بڑے فضل کا مالک ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcv{\basmalahur بیشک اللہ نے اس عورت کی بات سن لی جو تم سے اپنے شوہر کے بارے میں بحث کررہی تھی اور اللہ سے فریاد کررہی تھی اور اللہ تم دونوں کی باتیں سن رہا تھا کہ وہ سب کچھ سننے والا اور دیکھنے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvi{جو لوگ اپنی عورتوں سے ظہار کرتے ہیں ان کی عورتیں ان کی مائیں نہیں ہیں - مائیں تو صرف وہ عورتیں ہیں جنہوں نے پیدا کیا ہے .اور یہ لوگ یقینا بہت بفِی اور جھوٹی بات کہتے ہیں اور اللہ بہت معاف کرنے والا اور بخشنے والا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcvii{جو لوگ تم میں سے اپنی عورتوں سے ظہار کریں اور پھر اپنی بات سے پلٹنا چاہیں انہیں چاہئے کہ عورت کو ہاتھ لگانے سے پہلے ایک غلام آزاد کریں کہ یہ خدا کی طرف سے تمہارے لئے نصیحت ہے اور خدا تمہارے اعمال سے خوب باخبر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcviii{پھر کسی شخص کے لئے غلام ممکن نہ ہو تو آپس میں ایک دوسرے کو مس کرنے سے پہلے دو مہینے کے مسلسل روزے رکھے پھر یہ بھی ممکن نہ ہو تو ساٹھ مسکینوں کو کھانا کھلائے یہ اس لئے تاکہ تم خدا و رسول پر صحیح ایمان رکھو اور یہ اللہ کے مقرر کردہ حدود ہیں اور کافروں کے لئے بڑا دردناک عذاب ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcix{بیشک جو لوگ خدا و رسول سے دشمنی کرتے ہیں وہ ویسے ہی ذلیل ہوں گے جیسے ان سے پہلے والے ذلیل ہوئے ہیں اور ہم نے کھلی ہوئی نشانیاں نازل کردی ہیں اور کافروں کے لئے رسوا کن عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcx{جس دن خدا سب کو زندہ کرے گا اور انہیں ان کے اعمال سے باخبر کرے گا جسے اس نے محفوظ کر رکھا ہے اور ان لوگوں نے خود اِھلادیا ہے اور اللہ ہر شے کی نگرانی کرنے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxi{کیا تم نہیں دیکھتے ہو کہ اللہ زمین و آسمان کی ہر شے سے باخبر ہے .کہیں بھی تین آدمیوں کے درمیان راز کی بات نہیں ہوتی ہے مگر یہ کہ وہ ان کا چوتھا ہوتا ہے اور پانچ کی راز داری ہوتی ہے تو وہ ان کا چھٹا ہوتا ہے اور کم و بیش بھی کوئی رازداری ہوتی ہے تو وہ ان کے ساتھ ضرور رہتا ہے چاہے وہ کہیں بھی رہیں اس کے بعد روز هقیامت انہیں باخبر کرے گا کہ انہوں نے کیا کیا ہے کہ بیشک وہ ہر شے کا جاننے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxii{کیا تم نے ان لوگوں کو نہیں دیکھا جنہیں راز کی باتوں سے منع کیا گیا لیکن وہ پھر بھی ایسی باتیں کرتے ہیں اور گناہ اور ظلم اور رسول کی نافرمانی کے ساتھ راز کی باتیں کرتے ہیں اور جب تمہارے پاس آتے ہیں تو اس طرح مخاطب کرتے ہیں جس طرح خدا نے انہیں نہیں سکھایا ہے اور اپنے دل ہی دل میں کہتے ہیں کہ ہم غلطی پر ہیں تو خدا ہماری باتوں پر عذاب کیوں نہیں نازل کرتا - حالانکہ ان کے لئے جہنّم ہی کافی ہے جس میں انہیں جلنا ہے اور وہ بدترین انجام ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiii{ایمان والو جب بھی راز کی باتیں کرو تو خبردار گناہ اور تعدی اور رسول کی نافرمانی کے ساتھ نہ کرنا بلکہ نیکی اور تقویٰ کے ساتھ باتیں کرنا اور اللہ سے ڈرتے رہنا کہ بالآخر اسی کی طرف پلٹ کر جانا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiv{یہ رازداری شیطان کی طرف سے صاحبانِ ایمان کو دکھ پہنچانے کے لئے ہوتی ہے حالانکہ وہ انہیں نقصان نہیں پہنچا سکتا ہے جب تک خدا اجازت نہ د ے دے اور صاحبانِ ایمان کا بھروسہ صرف اللہ پر ہوتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxv{ایمان والو جب تم سے مجلس میں وسعت پیدا کرنے کے لئے کہا جائے تو دوسروں کو جگہ دیدو تاکہ خدا تمہیں جنّت میں وسعت دے سکے اور جب تم سے کہا جائے کہ اُٹھ جاؤ تو اُٹھ جاؤ کہ خدا صاحبان هایمان اور جن کو علم دیا گیا ہے ان کے درجات کو بلند کرنا چاہتا ہے اور اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvi{ایمان والو جب بھی رسول سے کوئی راز کی بات کرو تو پہلے صدقہ نکال دو کہ یہی تمہارے حق میں بہتری اور پاکیزگی کی بات ہے پھر اگر صدقہ ممکن نہ ہو تو خدا بہت بخشنے والا اور مہربان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvii{کیا تم اس بات سے ڈر گئے ہو کہ اپنی رازدارانہ باتوں سے پہلے خیرات نکال دو اب جب کہ تم نے ایسا نہیں کیا ہے اور خدا نے تمہاری توبہ قبول کرلی ہے تو اب نماز قائم کرو اور زکوِٰ ادا کرو اور اللہ و رسول کی اطاعت کرو کہ اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxviii{کیا تم نے ان لوگوں کو نہیں دیکھا ہے جنہوں نے اس قوم سے دوستی کرلی ہے جس پر خدا نے عذاب نازل کیا ہے یہ نہ تم میں سے ہیں اور نہ ان میں سے اور یہ جھوٹی قسمیں کھاتے ہیں اور خود بھی اپنے جھوٹ سے باخبر ہیں\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxix{اللرُ نے ان کے لئے سخت عذاب مہّیا کر رکھا ہے کہ یہ بہت بفِے اعمال کررہے تھے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxx{انہوں نے اپنی قسموں کو سپر بنالیا ہے اور راہ هخدا میں رکاوٹ ڈال رہے ہیں تو ان کے لئے رسوا کرنے والا عذاب ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxi{اللرُ کے مقابلہ میں ان کا مال اور ان کی اولاد کوئی کام آنے والا نہیں ہے یہ سب جہنّمی ہیں اور وہیں ہمیشہ رہنے والے ہیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxii{جس دن خدا ان سب کو دوبارہ زندہ کرے گا اور یہ اس سے بھی ایسی ہی قسمیں کھائیں گے جیسی تم سے کھاتے ہیں اور ان کا خیال ہوگا کہ ان کے پاس کوئی بات ہے حالانکہ یہ بالکل جھوٹے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiii{ان پر شیطان غالب آگیا ہے اور اس نے انہیں ذکر خدا سے غافل کردیا ہے آگاہ ہوجاؤ کہ یہ شیطان کا گروہ ہیں اور شیطان کا گروہ بہرحال خسارہ میں رہنے والا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiv{بیشک جو لوگ خدا و رسول سے دشمنی کرتے ہیں ان کا شمار ذلیل ترین لوگوں میں ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxv{اللرُنے یہ لکھ دیا ہے کہ میں اور میرے رسول غالب آنے والے ہیں بیشک اللہ صاحبِ قوت اور صاحب هعزت ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvi{آپ کبھی نہ دیکھیں گے کہ جو قوم اللہ اور روزِ آخرت پر ایمان رکھنے والی ہے وہ ان لوگوں سے دوستی کررہی ہے جو اللہ اور اس کے رسول سے دشمنی کرنے والے ہیں چاہے وہ ان کے باپ دادا یا اولاد یا برادران یا عشیرہ اور قبیلہ والے ہی کیوں نہ ہوں - اللرُنے صاحبان هایمان کے دلوں میں ایمان لکھ دیا ہے اور ان کی اپنی خاص روح کے ذریعہ تائید کی ہے اور وہ انہیں ان جنّتوں میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی اور وہ ا ن ہی میں ہمیشہ رہنے والے ہوں گے - خدا ان سے راضی ہوگا اور وہ خدا سے راضی ہوں گے یہی لوگ اللہ کا گروہ ہیں اور آگاہ ہوجاؤ کہ اللہ کا گروہ ہی نجات پانے والا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvii{\basmalahur اللہ ہی کے لئے محہُ تسبیح ہے جو کچھ بھی زمین و آسمان میں ہے اور وہی صاحب هعزت اور صاحب هحکمت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxviii{وہی وہ ہے جس نے اہل کتاب کے کافروں کو پہلے ہی حشر میں ان کے وطن سے نکال باہر کیا تم تو اس کا تصور بھی نہیں کررہے تھے کہ یہ نکل سکیں گے اور ان کا بھی یہی خیال تھا کہ ان کے قلعے انہیں خدا سے بچالیں گے لیکن خدا ایسے رخ سے پیش آیا جس کا انہیں وہم و گمان بھی نہیں تھا اور ان کے دلوں میں رعب پیدا کردیا کہ وہ اپنے گھروں کو خود اپنے ہاتھوں سے اور صاحبان هایمان کے ہاتھوں سے اجاڑنے لگے تو صاحبانِ نظر عبرت حاصل کرو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxix{اور اگر خدا نے ان کے حق میں جلاوطنی نہ لکھ دی ہوتی تو ان پر دنیا ہی میں عذاب نازل کردیتا اور آخرت میں تو جہنّم کا عذاب طے ہی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxx{یہ اس لئے کہ انہوں نے اللہ اور رسول سے اختلاف کیا اور جو خدا سے اختلاف کرے اس کے حق میں خدا سخت عذاب کرنے والا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxi{مسلمانو تم نے جو بھی کھجور کی شاخ کاٹی ہے یا اسے اس کی جڑوں پر رہنے دیا ہے یہ سب خدا کی اجازت سے ہوا ہے اور اس لئے تاکہ خدا فاسقین کو فِسوا کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxii{اور خدا نے جو کچھ ان کی طرف سے مال غنیمت اپنے رسول کو دلوایا ہے جس کے لئے تم نے گھوڑے یا اونٹ کے ذریعہ کوئی دوڑ دھوپ نہیں کی ہے.... لیکن اللہ اپنے رسولوں کو غلبہ عنایت کرتا ہے اور وہ ہر شے پر قدرت رکھنے والا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiii{تو کچھ بھی اللہ نے اہل قریہ کی طرف سے اپنے رسول کو دلوایا ہے وہ سب اللہ ,رسول اور رسول کے قرابتدار, ایتام, مساکین اور مسافران غربت زدہ کے لئے ہے تاکہ سارا مال صرف مالداروں کے درمیان گھوم پھر کر نہ رہ جائے اور جو کچھ بھی رسول تمہیں دیدے اسے لے لو اور جس چیز سے منع کردے اس سے رک جاؤ اور اللہ سے ڈرو کہ اللہ سخت عذاب کرنے والا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiv{یہ مال ان مہاجر فقرائ کے لئے بھی ہے جنہیں ان کے گھروں اور اموال سے نکال باہر کردیا گیا ہے اور وہ صرف خدا کے فضل اور اس کی مرضی کے طلبگار ہیں اور خدا و رسول کی مدد کرنے والے ہیں کہ یہی لوگ دعوائے ایمان میں سچے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxv{اور جن لوگوں نے دارالہجرت اور ایمان کو ان سے پہلے اختیار کیا تھا وہ ہجرت کرنے والوں کو دوست رکھتے ہیں اور جو کچھ انہیں دیا گیا ہے اپنے دلوں میں اس کی طرف سے کوئی ضرورت نہیں محسوس کرتے ہیں اور اپنے نفس پر دوسروں کو مقدم کرتے ہیں چاہے انہیں کتنی ہی ضرورت کیوں نہ ہو.... اور جسے بھی اس کیے نفس کی حرص سے بچالیا جائے وہی لوگ نجات پانے والے ہیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvi{اور جو لوگ ان کے بعد آئے اور ان کا کہنا یہ ہے کہ خدایا ہمیں معاف کردے اور ہمارے ان بھائیوں کو بھی جنہوں نے ایمان میں ہم پر سبقت کی ہے اور ہمارے دلوں میں صاحبانِ ایمان کے لئے کسی طرح کا کینہ نہ قرار دینا کہ تو بڑا مہربان اور رحم کرنے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvii{کیا تم نے منافقین کا حال نہیں دیکھا ہے کہ یہ اپنے اہل کتاب کافر بھائیوں سے کہتے ہیں کہ اگر تمہیں نکال دیا گیا تو ہم بھی تمہارے ساتھ نکل چلیں گے اور تمہارے بارے میں کسی کی اطاعت نہ کریں گے اور اگر تم سے جنگ کی گئی تو بھی ہم تمہاری مدد کریں گے اور خدا گواہ ہے کہ یہ سب بالکل جھوٹے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxviii{وہ اگر نکال بھی دیئے گئے تو یہ ان کے ساتھ نہ نکلیں گے اور اگر ان سے جنگ کی گئی تو یہ ہرگز ان کی مدد نہ کریں گے اور اگر مدد بھی کریں گے تو پیٹھ پھیر کر بھاگ جائیں گے پھر ان کی کوئی مدد کرنے والا نہ ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxix{مسلمانو تم ان کے دلوں میں اللہ سے بھی زیادہ خوف رکھتے ہو یہ اس لئے کہ یہ قوم سمجھدار نہیں ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxl{یہ کبھی تم سے اجتماعی طور پر جنگ نہ کریں گے مگر یہ کہ محفوظ بستیوں میں ہوں یا دیواروں کے پیچھے ہوں ان کی دھاک آپس میں بہت ہے اور تم یہ خیال کرتے ہو کہ یہ سب متحد ہیں ہرگز نہیں ان کے دلوں میں سخت تفرقہ ہے اور یہ اس لئے کہ اس قوم کے پاس عقل نہیں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxli{جس طرح کہ ابھی حال میں ان سے پہلے والوں کا حشر ہوا ہے کہ انہوں نے اپنے کام کے وبال کامزہ چکھ لیا ہے اور پھر ان کے لئے دردناک عذاب بھی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlii{ان کی مثال شیطان جیسی ہے کہ اس نے انسان سے کہا کہ کفر اختیار کرلے اور جب وہ کافر ہوگیا تو کہنے لگا کہ میں تجھ سے بیزار ہوں میں تو عالمین کے پروردگار سے ڈرتا ہوں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliii{تو ان دونوں کا انجام یہ ہے کہ دونوں جہنّم میں ہمیشہ ہمیشہ رہنے والے ہیں اور یہی ظالمین کی واقعی سزا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliv{ایمان والو اللہ سے ڈرو اور ہر شخص یہ دیکھے کہ اس نے کل کے لئے کیا بھیج دیا ہے اور اللہ سے ڈرتے رہو کہ وہ یقینا تمہارے اعمال سے باخبر ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlv{اور خبردار ان لوگوں کی طرح نہ ہوجانا جنہوں نے خدا کو اِھلادیا تو خدا نے خود ان کے نفس کو بھی اِھلا دیا اور وہ سب واقعی فاسق اور بدکار ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvi{اصحاب جنّت اور اصحاب جہنمّ ایک جیسے نہیں ہوسکتے, اصحاب جنّت وہی ہیں جو کامیاب ہونے والے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvii{ہم اگر اس قرآن کو کسی پہاڑ پر نازل کردیتے تو تم دیکھتے کہ پہاڑ خورِ خدا سے لرزاں اور ٹکڑے ٹکڑے ہوا جارہا ہے اور ہم ان مثالوں کو انسانوں کے لئے اس لئے بیان کرتے ہیں کہ شاید وہ کچھ غور و فکر کرسکیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlviii{وہ خدا وہ ہے جس کے علاوہ کوئی خدا نہیں ہے اور وہ حاضر و غائب سب کا جاننے والا عظیم اور دائمی رحمتوں کا مالک ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlix{وہ اللہ وہ ہے جس کے علاوہ کوئی خدا نہیں ہے وہ بادشاہ, پاکیزہ صفات, بے عیب, امان دینے والا, نگرانی کرنے والا, صاحبِ عزت, زبردست اور کبریائی کا مالک ہے - وہ ان تمام باتوں سے پاک و پاکیزہ ہے جو مشرکین کیا کرتے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcl{وہ ایسا خدا ہے جو پیدا کرنے والا, ایجاد کرنے والا اور صورتیں بنانے والا ہے اس کے لئے بہترین نام ہیں زمین و آسمان کا ہر ذرّہ اسی کے لئے محہُ تسبیح ہے اور وہ صاحبِ عزت و حکمت ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcli{\basmalahur ایمان والو خبردار میرے اور اپنے دشمنوں کو دوست مت بنانا کہ تم ان کی طرف دوستی کی پیش کش کرو جب کہ انہوں نے اس حق کا انکار کردیا ہے جو تمہارے پاس آچکا ہے اور وہ رسول کو اور تم کو صرف اس بات پر نکال رہے ہیں کہ تم اپنے پروردگار (اللرُ) پر ایمان رکھتے ہو .... اگر تم واقعا ہماری راہ میں جہاد اور ہماری مرضی کی تلاش میں گھر سے نکلے ہو تو ان سے خفیہ دوستی کس طرح کررہے ہو جب کہ میں تمہارے ظاہر و باطن سب کو جانتا ہوں اور جو بھی تم میں سے ایسا اقدام کرے گا وہ یقینا سیدھے راستہ سے بہک گیا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclii{یہ اگر تمہیں پاجائیں گے تو تمہارے دشمن ثابت ہوں گے اور تمہاری طرف برائی کے ارادے سے ہاتھ اور زبان سے اقدام کریں گے اور یہ چاہیں گے کہ تم بھی کافر ہوجاؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliii{یقینا تمہارے قرابتدار اور تمہاری اولاد روزِ قیامت کام آنے والی نہیں ہے اس دن خدا تمہارے درمیان فیصلہ کردے گا اور وہ تمہارے اعمال سے خوب باخبرہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcliv{تمہارے لئے بہترین نمونہ عمل ابراہیم علیھ السّلام اور ان کے ساتھیوں میں ہے جب انہوں نے اپنی قوم سے کہہ دیا کہ ہم تم سے اور تمہارے معبودوں سے بیزار ہیں - ہم نے تمہارا انکار کردیا ہے اور ہمارے تمہارے درمیان بغض اور عداوت بالکل واضح ہے یہاں تک کہ تم خدائے وحدہ لاشریک پر ایمان لے آؤ علاوہ ابراہیم علیھ السّلام کے اس قول کے جو انہوں نے اپنے مربّی باپ سے کہہ دیا تھا کہ میں تمہارے لئے استغفار ضرور کروں گا لیکن میں پروردگار کی طرف سے کوئی اختیار نہیں رکھتا ہوں. خدایا میں نے تیرے اوپر بھروسہ کیا ہے اور تیری ہی طرف رجوع کیا ہے اور تیری ہی طرف بازگشت بھی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclv{خدایا مجھے کفاّر کے لئے فتنہ و بلا نہ قرار دینا اور مجھے بخش دینا کہ تو ہی صاحب هعزت اور صاحبِ حکمت ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvi{بیشک تمہارے لئے ان لوگوں میں بہترین نمونہ عمل ہے اس شخص کے لئے جو اللہ اور روزِ آخرت کا امیدوار ہے اور جو انحراف کرے گا خدا اس سے بے نیاز اور قابل حمد و ثنا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclvii{قریب ہے کہ خدا تمہارے اور جن سے تم نے دشمنی کی ہے ان کے درمیان دوستی قرار دے دے کہ وہ صاحب هقدرت ہے اور بہت بڑا بخشنے والا اور مہربان ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclviii{وہ تمہیں ان لوگوں کے بارے میں جنہوں نے تم سے دین کے معاملہ میں جنگ نہیں کی ہے اور تمہیں وطن سے نہیں نکالا ہے اس بات سے نہیں روکتا ہے کہ تم ان کے ساتھ نیکی اور انصاف کرو کہ خدا انصاف کرنے والوں کو دوست رکھتا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclix{وہ تمہیں صرف ان لوگوں سے روکتا ہے جنہوں نے تم سے دین میں جنگ کی ہے اور تمہیں وطن سے نکال باہر کیا ہے اور تمہارے نکالنے پر دشمنوں کی مدد کی ہے کہ ان سے دوستی کرو اور جو ان سے دوستی کرے گا وہ یقینا ظالم ہوگا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclx{~ ایمان والو جب تمہارے پاس ہجرت کرنے والی مومن عورتیں آئیں تو پہلے ان کا امتحان کرو کہ اللہ ان کے ایمان کو خوب جانتا ہے پھر اگر تم بھی دیکھو کہ یہ مومنہ ہیں توخبردار انہیں کفاّر کی طرف واپس نہ کرنا - نہ وہ ان کے لئے حلال ہیں اور نہ یہ ان کے لئے حلال ہیں اور جو خرچہ کفاّر نے مہر کا دیا ہے وہ انہیں واپس کردو اور تمہارے لئے کوئی حرج نہیں ہے کہ تم ان کی اجرت (مہر) دینے کے بعد ان سے نکاح کرلو اور خبردار کافر عورتوں کی عصمت پکڑ کر نہ رکھو اور جو تم نے خرچ کیا ہے وہ کفار سے لے لو اور جو انہوں نے خرچ کیا ہے وہ تم سے لے لیں کہ یہی حکم خدا ہے جس کا فیصلہ خدا نے تمہارے درمیان کیا ہے اور وہ بڑا صاحب ه علم و حکمت ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxi{اور اگر تمہاری کوئی بیوی کفاّر کی طرف چلی جائے اور پھر تم ان کو سزا دو تو جن کی بیوی چلی گئی ہے ان کا خرچ مال غنیمت میں سے دے دو اور اس اللہ سے بہرحال ڈرتے رہو جس پر ایمان رکھنے والے ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxii{پیغمبر اگر ایمان لانے والی عورتیں آپ کے پاس اس امر پر بیعت کرنے کے لئے آئیں کہ کسی کو خدا کا شریک نہیں بنائیں گی اور چوری نہیں کریں گی - زنا نہیں کریں گی - اولاد کو قتل نہیں کریں گی اور اپنے ہاتھ پاؤں کے سامنے سے کوئی بہتان (لڑکا) لے کر نہیں آئیں گی اور کسی نیکی میں آپ کی مخالفت نہیں کریں گی تو آپ ان سے بیعت کا معاملہ کرلیں اور ان کے حق میں استغفار کریں کہ خدا بڑا بخشنے والا اور مہربان ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiii{ایمان والو خبردار اس قوم سے ہرگز دوستی نہ کرنا جس پر خدا نے غضب نازل کیا ہے کہ وہ آخرت سے اسی طرح مایوس ہوں گے جس طرح کفاّر قبر والوں سے مایوس ہوجاتے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiv{\basmalahur زمین و آسمان کا ہر ذرہ اللہ کی تسبیح میں مشغول ہے اور وہی صاحبِ عزت اور صاحب هحکمت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxv{ایمان والو آخر وہ بات کیوں کہتے ہو جس پر عمل نہیں کرتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvi{اللرُکے نزدیک یہ سخت ناراضگی کا سبب ہے کہ تم وہ کہو جس پر عمل نہیں کرتے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvii{بیشک اللہ ان لوگوں کو دوست رکھتا ہے جو اس کی راہ میں اس طرح صف باندھ کر جہاد کرتے ہیں جس طرح سیسہ پلائی ہوئی دیواریں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxviii{اور اس وقت کو یاد کرو جب موسٰی علیھ السّلامنے اپنی قوم سے کہا کہ قوم والو مجھے کیوں اذیت دے رہے ہو تمہیں تو معلوم ہے کہ میں تمہاری طرف اللہ کا رسول علیھ السّلام ہوں پھر جب وہ لوگ ٹیڑھے ہوگئے تو خدا نے بھی ان کے دلوں کو ٹیڑھا ہی کردیا کہ اللہ بدکار قوم کی ہدایت نہیں کرتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxix{اور اس وقت کو یاد کرو جب عیسٰی علیھ السّلام بن مریم علیھ السّلام نے کہا کہ اے بنیآآ اسرائیل میں تمہاری طرف اللہ کا رسول ہوں اپنے پہلے کی کتاب توریت کی تصدیق کرنے والا اور اپنے بعد کے لئے ایک رسول کی بشارت دینے والا ہوں جس کا نام احمد ہے لیکن پھر بھی جب وہ معجزات لے کر آئے تو لوگوں نے کہہ دیا کہ یہ تو کِھلا ہوا جادو ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxx{اور اس سے بڑا ظالم کون ہوگا جو خدا پر جھوٹ الزام لگائے جب کہ اسے اسلام کی دعوت دی جارہی ہو اور اللہ کبھی ظالم قوم کی ہدایت نہیں کرتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxi{یہ لوگ چاہتے ہیں کہ نور خدا کو اپنے منہ سے بجھادیں اور اللہ اپنے نور کو مکمل کرنے والا ہے چاہے یہ بات کفار کو کتنی ہی ناگوار کیوں نہ ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxii{وہی خدا وہ ہے جس نے اپنے رسول کو ہدایت اور دین حق کے ساتھ بھیجا ہے تاکہ اسے تمام ادیان پر غالب بنائے چاہے یہ بات مشرکین کو کتنی ہی ناگوار کیوں نہ ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiii{ایمان والو کیا میں تمہیں ایک ایسی تجارت کی طرف رہنمائی کروں جو تمہیں دردناک عذاب سے بچالے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiv{اللرُ اور اس کے رسول پر ایمان لے آؤ اور راسِ خدا میں اپنے جان و مال سے جہاد کرو کہ یہی تمہارے حق میں سب سے بہتر ہے اگر تم جاننے والے ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxv{وہ تمہارے گناہوں کو بھی بخش دے گا اور تمہیں ان جنتوں میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی اور اس ہمیشہ رہنے والی جنّت میں پاکیزہ مکانات ہوں گے اور یہی بہت بڑی کامیابی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvi{اور ایک چیز اور بھی جسے تم پسند کرتے ہو.... اللرُ کی طرف سے مدد اور قریبی فتح اور آپ مومنین کو بشارت دے دیجئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvii{ایمان والو اللہ کے مددگار بن جاؤ جس طرح عیسٰی بن مریم علیھ السّلام نے اپنے حواریین سے کہا تھا کہ اللہ کی راہ میں میرا مددگار کون ہے تو حواریین نے کہا کہ ہم اللہ کے ناصر ہیں لیکن پھربنی اسرائیل میں سے ایک گروہ ایمان لے آیا اور ایک گروہ کافر ہوگیا تو ہم نے صاحبان هایمان کی دشمن کے مقابلہ میں مدد کردی تو وہ غالب آکر رہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxviii{\basmalahur زمین و آسمان کا ہر ذرہ اس خدا کی تسبیح کررہا ہے جو بادشاہ پاکیزہ صفات, اور صاحب هعزت اور صاحب هحکمت ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxix{اس خدا نے مکہ والوں میں ایک رسول بھیجا ہے جو ان ہی میں سے تھا کہ ان کے سامنے آیات کی تلاوت کرے ,ان کے نفوس کو پاکیزہ بنائے اور انہیں کتاب و حکمت کی تعلیم دے اگرچہ یہ لوگ بڑی کھلی ہوئی گمراہی میں مبتلا تھے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxx{اور ان میں سے ان لوگوں کی طرف بھی جو ابھی ان سے ملحق نہیں ہوئے ہیں اور وہ صاحبِ عزت بھی ہے اور صاحب هحکمت بھی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxi{یہ ایک فضل هخدا ہے وہ جسے چاہتا ہے عطا کردیتا ہے اور وہ بڑے عظیم فضل کا مالک ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxii{ان لوگوں کی مثال جن پر توریت کا بار رکھا گیا اور وہ اسے اُٹھا نہ سکے اس گدھے کی مثال ہے جو کتابوں کا بوجھ اٹھائے ہوئے ہو یہ بدترین مثال ان لوگوں کی ہے جنہوں نے آیات الۤہی کی تکذیب کی ہے اور خدا کسی ظالم قوم کی ہدایت نہیں کرتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiii{آپ کہہ دیجئے کہ یہودیو اگر تمہارا خیال یہ ہے کہ تمام انسانوں میں تم ہی اللہ کے دوست ہو تو اگر اپنے دعویٰ میں سچے ہو تو موت کی تمناّکرو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiv{اور یہ ہر گز موت کی تمنا ّنہیں کریں گے کہ ان کے ہاتھوں نے پہلے بہت کچھ کر رکھا ہے اور اللہ ظالمین کے حالات کو خوب جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxv{آپ کہہ دیجئے کہ تم جس موت سے فرار کررہے ہو وہ خود تم سے ملاقات کرنے والی ہے اس کے بعد تم اس کی بارگاہ میں پلٹائے جاؤ گے جو حاضر و غائب سب کا جاننے والا ہے اور وہ تمہیں باخبر کرے گا کہ تم وار دنیا میں کیا کررہے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvi{ایمان والو جب تمہیں جمعہ کے دن نماز کے لئے پکارا جائے تو ذکر خدا کی طرف دوڑ پڑو اور کاروبار بند کردو کہ یہی تمہارے حق میں بہتر ہے اگر تم جاننے والے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvii{پھر جب نماز تمام ہوجائے تو زمین میں منتشر ہوجاؤ اور فضل خدا کو تلاش کرو اور خدا کو بہت یاد کرو کہ شاید اسی طرح تمہیں نجات حاصل ہوجائے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxviii{اور اے پیغمبر یہ لوگ جب تجارت یا لہو و لعب کو دیکھتے ہیں تو اس کی طرف دوڑ پڑتے ہیں اور آپ کو تنہا کھڑا چھوڑ دیتے ہیں آپ ان سے کہہ دیجئے کہ خدا کے پاس جو کچھ بھی ہے وہ اس کھیل اور تجارت سے بہرحال بہتر ہے اور وہ بہترین رزق دینے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxix{\basmalahur پیغمبر یہ منافقین آپ کے پاس آتے ہیں تو کہتے ہیں کہ ہم گواہی دیتے ہیں کہ آپ اللہ کے رسول ہیں اور اللہ بھی جانتا ہے کہ آپ اس کے رسول ہیںلیکن اللہ گواہی دیتا ہے کہ یہ منافقین اپنے دعویٰ میں جھوٹے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxc{انہوں نے اپنی قسموں کو سپر بنالیا ہے اور لوگوں کو راسِ خدا سے روک رہے ہیں یہ ان کے بدترین اعمال ہیں جو یہ انجام دے رہے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxci{یہ اس لئے ہے کہ یہ پہلے ایمان لائے پھر کافر ہوگئے تو ان کے دلوں پر مہر لگادی گئی تو اب کچھ نہیں سمجھ رہے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcii{اور جب آپ انہیں دیکھیں گے تو ان کے جسم بہت اچھے لگیں گے اور بات کریں گے تو اس طرح کہ آپ سننے لگیں لیکن حقیقت میں یہ ایسے ہیں جیسے دیوار سے لگائی ہوئی سوکھی لکڑیاں کہ یہ ہر چیخ کو اپنے ہی خلاف سمجھتے ہیں اور یہ واقعا دشمن ہیں ان سے ہوشیار رہئے خدا انہیں غارت کرے یہ کہاں بہکے چلے جارہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciii{اور جب ان سے کہا جاتا ہے کہ آؤ رسول اللہ تمہارے حق میں استغفار کریں گے تو سر پھرا لیتے ہیں اور تم دیکھو گے کہ استکبار کی بنا پر منہ بھی موڑ لیتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciv{ان کے لئے سب برابر ہے چاہے آپ استغفار کریں یا نہ کریں خدا انہیں بخشنے والا نہیں ہے کہ یقینا اللہ بدکار قوم کی ہدایت نہیں کرتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcv{یہی وہ لوگ ہیں جو کہتے ہیں کہ رسول اللہ کے ساتھیوں پر کچھ خرچ نہ کرو تاکہ یہ لوگ منتشر ہوجائیں حالانکہ آسمان و زمین کے سارے خزانے اللہ ہی کے لئے ہیں اور یہ منافقین اس بات کو نہیں سمجھ رہے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvi{یہ لوگ کہتے ہیں کہ اگر ہم مدینہ واپس آگئے تو ہم صاحبان هعزت ان ذلیل افراد کو نکال باہر کریں گے حالانکہ ساری عزت اللہ , رسول اور صاحبان هایمان کے لئے ہے اور یہ منافقین یہ جانتے بھی نہیں ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvii{ایمان والو خبردار تمہارے اموال اور تمہاری اولاد تمہیں یاد خدا سے غافل نہ کردے کہ جو ایسا کرے گا وہ یقینا خسارہ والوں میں شمار ہوگا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcviii{اور جو رزق ہم نے عطا کیا ہے اس میں سے ہماری راہ میں خرچ کرو قبل اس کے کہ تم میں سے کسی کو موت آجائے اور وہ یہ کہے کہ خدایا ہمیں تھوڑے دنوں کی مہلت کیوں نہیں دے دیتا ہے کہ ہم خیرات نکالیں اور نیک بندوں میں شامل ہوجائیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcix{اور ہرگز خدا کسی کی اجل کے آجانے کے بعد اس میں تاخیر نہیں کرتا ہے اور وہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcc{\basmalahur زمین و آسمان کا ہر ذرہ خدا کی تسبیح کررہا ہے کہ اسی کے لئے ملک ہے اور اسی کے لئے حمد ہے اور وہی ہر شے پر قدرت رکھنے والا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcci{اسی نے تم سب کو پیدا کیا ہے پھر تم میں سے کچھ مومن ہیں اور کچھ کافر اور اللہ تمہارے اعمال کو خوب دیکھ رہا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccii{اسی نے آسمان و زمین کو حق کے ساتھ پیدا کیا ہے اور تمہاری صورت کو بھی انتہائی حسن بنایا ہے اور پھر اسی کی طرف سب کی بازگشت بھی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciii{وہ زمین و آسمان کی ہر شے سے باخبر ہے اور ان تمام چیزوں کو جانتا ہے جن کا تم اظہار کرتے ہو یا جنہیں تم چھپاتے ہو اور وہ سینوں کے رازوں سے بھی باخبر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcciv{کیا تمہارے پاس پہلے کفر اختیار کرنے والوں کی خبر نہیں آئی ہے کہ انہوں نے اپنے کام کے وبال کا مزہ چکھ لیا اور ان کے لئے دردناک عذاب ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccv{یہ اس لئے کہ ان کے پاس رسول کِھلی ہوئی نشانیاں لے کر آتے تھے تو انہوں نے صاف کہہ دیا کہ کیا بشر ہماری ہدایت کرے گا اور یہ کہہ کر انکار کردیا اور منہ پھیر لیا تو خدا بھی ان سے بے نیاز ہے اور وہ قابلِ تعریف غنی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvi{ان کفاّر کا خیال یہ ہے کہ انہیں دوبارہ نہیں اٹھایا جائے گا تو کہہ دیجئے کہ میرے پروردگار کی قسم تمہیں دوبارہ زندہ کیا جائے گا اور پھر بتایا جائے گا کہ تم نے کیا کیا, کیا ہے اور یہ کام خدا کے لئے بہت آسان ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccvii{لہذا خدا اور رسول اور اس نور پر ایمان لے آؤ جسے ہم نے نازل کیا ہے کہ اللہ تمہارے اعمال سے خوب باخبر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccviii{وہ قیامت کے دن تم سب کو جمع کرے گا اور وہی ہارجیت کا دن ہوگا اور جو اللہ پر ایمان رکھے گا اور نیک اعمال کرے گا خدا اس کی برائیوں کو دور کردے گا اور اسے ان باغات میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی وہ ان ہی میں ہمیشہ ہمیشہ رہیں گے اور یہی سب سے بڑی کامیابی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccix{اور جن لوگوں نے کفر اختیار کیا اور ہماری آیات کو جھٹلایا وہ اصحاب جہنّم ہیں اور وہیں ہمیشہ رہنے والے ہیں اور یہ ان کا بدترین انجام ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccx{کوئی مصیبت نازل نہیں ہوتی ہے مگر خدا کی اجازت سے اور جو صاحبِ ایمان ہوتا ہے خدا اس کے دل کی ہدایت کردیتا ہے اور خدا ہر شے کا خوب جاننے والا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxi{اور تم لوگ خدا کی اطاعت کرو اور رسول کی اطاعت کرو پھر اگر انحراف کرو گے تو رسول کی ذمہ داری واضح طور پر پیغام پہچادینے کے علاوہ کچھ نہیں ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxii{اللرُ ہی وہ ہے جس کے علاوہ کوئی خدا نہیں ہے اور تمام صاحبانِ ایمان کو اسی پر بھروسہ کرنا چاہئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiii{ایمان والو - تمہا---ری بیویوں اور تمہاری اولاد میں سے بعض تمہارے دشمن ہیں لہذا ان سے ہوشیار رہو اور اگر انہیں معاف کردو اور ان سے درگزر کرو اور انہیں بخش دو تو اللہ بھی بہت بخشنے والا اور مہربان ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiv{تمہارے اموال اور تمہاری اولاد تمہارے لئے صرف امتحان کا ذریعہ ہیں اور اجر عظیم صرف اللہ کے پاس ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxv{لہذا جہاں تک ممکن ہو اللہ سے ڈرو اور اس کی بات سنو اور اطاعت کرو اور راسِ خدا میں خرچ کرو کہ اس میں تمہارے لئے خیر ہے اور جو اپنے ہی نفس کے بخل سے محفوظ ہوجائے وہی لوگ فلاح اور نجات پانے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvi{اگر تم اللہ کو قرض حسنہ دو گے تو وہ اسے دوگنا بنادے گا اور تمہیں معاف بھی کردے گا کہ وہ بڑا قدر داں اور برداشت کرنے والا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvii{وہ حاضر و غائب کا جاننے والا اور صاحب هعزت و حکمت ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxviii{\basmalahur اے پیغمبر ! جب تم لوگ عورتوں کو طلاق دو تو انہیں عدت کے حساب سے طلاق دو اور پھر عدت کا حساب رکھو اور اللہ سے ڈرتے رہو کہ وہ تمہارا پروردگار ہے اور خبردار انہیں ان کے گھروں سے مت نکالنا اور نہ وہ خود نکلیں جب تک کوئی کِھلا ہوا گناہ نہ کریں - یہ خدائی حدود ہیں اور جو خدائی حدود سے تجاوز کرے گا اس نے اپنے ہی نفس پر ظلم کیا ہے تمہیں نہیں معلوم کہ شاید خدا اس کے بعد کوئی نئی بات ایجاد کردے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxix{پھر جب وہ اپنی مدت کو پورا کرلیں تو انہیں نیکی کے ساتھ روک لو یا نیکی ہی کے ساتھ رخصت کردو اور طلاق کے لئے اپنے میں سے دو عادل افراد کو گواہ بناؤ اور گواہی کو صرف خدا کے لئے قائم کرو نصیحت ان لوگوں کو کی جارہی ہے جو خدا اور روز هآخرت پر ایمان رکھتے ہیں اور جو بھی اللہ سے ڈرتا ہے اللہ اس کے لئے نجات کی راہ پیدا کردیتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxx{اور اسے ایسی جگہ سے رزق دیتا ہے جس کا خیال بھی نہیں ہوتا ہے اور جو خدا پر بھروسہ کرے گا خدا اس کے لئے کافی ہے بیشک خدا اپنے حکم کا پہنچانے والا ہے اس نے ہر شے کے لئے ایک مقدار معین کردی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxi{اور تمہاری عورتوں میں جو حیض سے مایوس ہوچکی ہیں اگر ان کے یائسہ ہونے میں شک ہو تو ان کا عدہ تین مہینے ہے اور اسی طرح وہ عورتیں جن کے یہاں حیض نہیں آتا ہے اور حاملہ عورتوں کا عدہ وضع حمل تک ہے اور جو خدا سے ڈرتا ہے خدا اس کے امر میں آسانی پیدا کردیتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxii{یہ حکم خدا ہے جسے تمہاری طرف اس نے نازل کیا ہے اور جو خدا سے ڈرتا ہے خدا اس کی برائیوں کو دور کردیتا ہے اور اس کے اجر میں اضافہ کردیتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiii{اور ان مطلقات کو سکونت دو جیسی طاقت تم رکھتے ہو اور انہیں اذیت مت دو کہ اس طرح ان پر تنگی کرو اور اگر حاملہ ہوں تو ان پر اس وقت تک انفاق کرو جب تک وضع حمل نہ ہوجائے پھر اگر وہ تمہارے بچوں کو دودھ پلائیں تو انہیں ان کی اجرت دو اور اسے آپس میں نیکی کے ساتھ طے کرو اور اگر آپس میں کشاکش ہوجائے تو دوسری عورت کو دودھ پلانے کا موقع دو\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiv{صاحبِ وسعت کو چاہئے کہ اپنی وسعت کے مطابق خرچ کرے اور جس کے رزق میں تنگی ہے وہ اسی میں سے خرچ کرے جو خدا نے اسے دیا ہے کہ خدا کسی نفس کو اس سے زیادہ تکلیف نہیں دیتا ہے جتنا اسے عطا کیا گیا ہے عنقریب خدا تنگی کے بعد وسعت عطا کردے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxv{اور کتنی ہی بستیاں ہیں جنہوں نے حکم خدا و رسول کی نافرمانی کی تو ہم نے ان کا شدید محاسبہ کرلیا اور انہیں بدترین عذاب میں متبلا کردیا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvi{پھر انہوں نے اپنے کام کے وبال کا مزہ چکھ لیا اور آخری انجام خسارہ ہی قرار پایا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvii{اللرُ نے ان کے لئے شدید قسم کا عذاب مہیّا کر رکھا ہے لہذا ایمان والو اور عقل والو اللہ سے ڈرو کہ اس نے تمہاری طرف اپنے ذکر کو نازل کیا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxviii{وہ رسول جو اللہ کی واضح آیات کی تلاوت کرتا ہے کہ ایمان اور نیک عمل کرنے والوں کو تاریکیوں سے نکال کر نور کی طرف لے آئے اور جو خدا پر ایمان رکھے گا اور نیک عمل کرے گا خدا اسے ان جنتوں میں داخل کرے گا جن کے نیچے نہریں جاری ہوں گی وہ ان ہی میں ہمیشہ رہنے والے ہیں اور اللہ نے انہیں یہ بہترین رزق عطا کیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxix{اللرُہی وہ ہے جس نے ساتوں آسمانوں کو پیدا کیا ہے اور زمینوں میں بھی ویسی ہی زمینیں بنائی ہیں اس کے احکام ان کے درمیان نازل ہوتے رہتے ہیں تاکہ تمہیں یہ معلوم رہے کہ وہ ہر شے پر قادر ہے اور اس کا علم تمام اشیائ کو محیط ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxx{\basmalahur پیغمبر آپ اس شے کو کیوں ترک کررہے ہیں جس کو خدا نے آپ کے لئے حلال کیا ہے کیا آپ ازواج کی مرضی کے خواہشمند ہیں اور اللہ بہت بخشنے والا اور مہربان ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxi{خدا نے فرض قرار دیا ہے کہ اپنی قسم کو کفارہ دے کر ختم کردیجئے اور اللہ آپ کا مولا ہے اور وہ ہر چیز کا جاننے والا اور صاحبِ حکمت ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxii{اور جب نبی نے اپنی بعض ازواج سے راز کی بات بتائی اور اس نے دوسری کو باخبر کردیا اور خدا نے نبی پر ظاہر کردیا تو نبی نے بعض باتوں کو اسے بتایا اور بعض سے اعراض کیا پھر جب اسے باخبر کیا تو اس نے پوچھا کہ آپ کو کس نے بتایا ہے تو آپ نے کہا کہ خدائے علیم و خبیرنے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiii{اب تم دونوں توبہ کرو کہ تمہارے دلوں میں کجی پیدا ہوگئی ہے ورنہ اگر اس کے خلاف اتفاق کرو گی تو یاد رکھو کہ اللہ اس کا سرپرست ہے اور جبریل اور نیک مومنین اور ملائکہ سب اس کے مددگار ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiv{وہ اگر تمہیں طلاق بھی دے دے گا تو خدا تمہارے بدلے اسے تم سے بہتر بیویاں عطا کردے گا مسلمہ, مومنہ, فرمانبردار, توبہ کرنے والی, عبادت گزار, روزہ رکھنے والی, کنواری اور غیر کنواری سب\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxv{ایمان والو اپنے نفس اور اپنے اہل کو اس آگ سے بچاؤ جس کا ایندھن انسان اور پتھر ہوں گے جس پر وہ ملائکہ معین ہوں گے جو سخت مزاج اور تندوتیز ہیں اور خدا کے حکم کی مخالفت نہیں کرتے ہیں اور جو حکم دیا جاتا ہے اسی پر عمل کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvi{اور اے کفر اختیار کرنے والو آج کوئی عذر پیش نہ کرو کہ آج تمہیں تمہارے اعمال کی سزا دی جائے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvii{ایمان والو خلوص دل کے ساتھ توبہ کرو عنقریب تمہارا پروردگار تمہاری برائیوں کو مٹا دے گا اور تمہیں ان جنتوں میں داخل کردے گا جن کے نیچے نہریں جاری ہوں گی اس دن خدا اپنے نبی اور صاحبانِ ایمان کو رسوا نہیں ہونے دے گا ان کا نور ان کے آگے آگے اور داہنی طرف چل رہا ہوگا اور وہ کہیں گے کہ خدایا ہمارے لئے ہمارے نور کو مکمل کردے اور ہمیں بخش دے کہ تو یقینا ہر شے پر قدرت رکھنے والا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxviii{پیغمبر آپ کفر اور منافقین سے جہاد کریں اور ان پر سختی کریں اور ان کا ٹھکانا جہنّم ہے اور وہی بدترین انجام ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxix{خدا نے کفر اختیار کرنے والوں کے لئے زوجہ نوح اور زوجہ لوط کی مثال بیان کی ہے کہ یہ دونوں ہمارے نیک بندوں کی زوجیت میں تھیں لیکن ان سے خیانت کی تو اس زوجیت نے خدا کی بارگاہ میں کوئی فائدہ نہیں پہنچایا اور ان سے کہہ دیا گیا کہ تم بھی تمام جہنمّ میں داخل ہونے والوں کے ساتھ داخل ہوجاؤ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxl{اور خدا نے ایمان والوں کے لئے فرعون کی زوجہ کی مثال بیان کی ہے کہ اس نے دعا کی کہ پروردگار میرے لئے جنّت میں ایک گھر بنادے اور مجھے فرعون اور اس کے کاروبار سے نجات دلادے اور اس پوری ظالم قوم سے نجات عطا کردے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxli{اور مریم بنت عمران علیھ السّلام کی مثال جس نے اپنی عفت کی حفاظت کی تو ہم نے اس میں اپنی روح پھونک دی اور اس نے اپنے رب کے کلمات اور کتابوں کی تصدیق کی اور وہ ہمارے فرمانبردار بندوں میں سے تھی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlii{\basmalahur بابرکت ہے وہ ذات جس کے ہاتھوں میں سارا ملک ہے اور وہ ہر شے پر قادر و مختار ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliii{اس نے موت و حیات کو اس لئے پیدا کیا ہے تاکہ تمہاری آزمائش کرے کہ تم میں حَسن عمل کے اعتبار سے سب سے بہتر کون ہے اور وہ صاحب هعزّت بھی ہے اور بخشنے والا بھی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliv{اسی نے سات آسمان تہ بہ تہ پیدا کئے ہیں اور تم رحمان کی خلقت میں کسی طرح کا فرق نہ دیکھو گے پھر دوبارہ نگاہ اٹھا کر دیکھو کہیں کوئی شگاف نظر آتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlv{اس کے بعد بار بار نگاہ ڈالو دیکھو نگاہ تھک کر پلٹ آئے گی لیکن کوئی عیب نظر نہ آئے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvi{ہم نے آسمان دنیا کو چراغوں سے مزین کیا ہے اور انہیں شیاطین کو سنگسار کرنے کا ذریعہ بنادیا ہے اور ان کے لئے جہنمّ کا عذاب الگ مہیّا کر رکھا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvii{اور جن لوگوں نے اپنے پروردگار کا انکار کیا ہے ان کے لئے جہنمّ کا عذاب ہے اور وہی بدترین انجام ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlviii{جب بھی وہ اس میں ڈالے جائیں گے اس کی چیخ سنیں گے اور وہ جوش مار رہا ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlix{بلکہ قریب ہوگا کہ جوش کی شدت سے پھٹ پڑے جب بھی اس میں کسی گروہ کو ڈالا جائے گا تو اس کے داروغہ ان سے پوچھیں گے کہ کیا تمہارے پاس کوئی ڈرانے والا نہیں آیا تھا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccl{تو وہ کہیں گے کہ آیا تو تھا لیکن ہم نے اسے جھٹلادیا اور یہ کہہ دیا کہ اللہ نے کچھ بھی نازل نہیں کیا ہے تم لوگ خود بہت بڑی گمراہی میں مبتلا ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccli{اور پھر کہیں گے کہ اگر ہم بات سن لیتے اور سمجھتے ہوتے تو آج جہنّم والوں میں نہ ہوتے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclii{تو انہوں نے خود اپنے گناہ کا اقرار کرلیا تو اب جہنم ّوالوںکے لئے تو رحمت خدا سے دوری ہی دوری ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliii{بیشک جو لوگ بغیر دیکھے اپنے پروردگار کا خوف رکھتے ہیں ان کے لئے مغفرت اور اجر عظیم ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccliv{اور تم لوگ اپنی باتوں کو آہستہ کہو یا بلند آواز سے خدا تو سینوں کی رازوں کو بھی جانتا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclv{اور کیا پیدا کرنے والا نہیں جانتا ہے جب کہ وہ لطیف بھی ہے اور خبیر بھی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvi{اسی نے تمہارے لئے زمین کو نرم بنادیا ہے کہ اس کے اطراف میں چلو اور رزق خدا تلاش کرو پھر اسی کی طرف قبروں سے اٹھ کر جانا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvii{کیا تم آسمان میں حکومت کرنے والے کی طرف سے مطمئن ہوگئے کہ وہ تم کو زمین میں دھنسا دے اور وہ تمہیں گردش ہی دیتی رہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclviii{یا تم اس کی طرف سے اس بات سے محفوظ ہوگئے کہ وہ تمہاے اوپر پتھروں کی بارش کردے پھر تمہیں بہت جلد معلوم ہوجائے گا کہ میرا ڈرانا کیسا ہوتا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclix{اور ان سے پہلے والوں نے بھی تکذیب کی ہے تو دیکھو کہ ان کا انجام کتنا بھیانک ہوا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclx{کیا ان لوگوں نے اپنے اوپر ان پرندوں کو نہیں دیکھا ہے جو پر پھیلا دیتے ہیں اور سمیٹ لیتے ہیں کہ انہیں اس فضا میں اللہ کے علاوہ کوئی نہیں سنبھال سکتا کہ وہی ہر شے کی نگرانی کرنے والا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxi{کیا یہ جو تمہاری فوج بنا ہوا ہے خدا کے مقابلہ میں تمہاری مدد کرسکتا ہے - بیشک کفار صرف دھوکہ میں پڑے ہوئے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxii{یا یہ تم کو روزی دے سکتا ہے اگر خدا اپنی روزی کو روک لے - حقیقت یہ ہے کہ یہ لوگ نافرمانی اور نفرت میں غرق ہوگئے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiii{کیا وہ شخص جو منہ کے بل چلتا ہے وہ زیادہ ہدایت یافتہ ہے یا جو سیدھے سیدھے صراظُ مستقیم پر چل رہا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiv{آپ کہہ دیجئے کہ خدا ہی نے تمہیں پیدا کیا ہے اور اسی نے تمہارے لئے کان آنکھ اور دل قرار دیئے ہیں مگر تم بہت کم شکریہ ادا کرنے والے ہو\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxv{کہہ دیجئے کہ وہی وہ ہے جس نے زمین میں تمہیں پھیلا دیا ہے اور اسی کی طرف تمہیں جمع کرکے لے جایا جائے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvi{اور یہ لوگ کہتے ہیں کہ اگر تم لوگ سچے ہو تو یہ وعدہ کب پورا ہوگا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvii{آپ کہہ دیجئے کہ علم اللہ کے پاس ہے اور میں تو صرف واضح طور پر ڈرانے والا ہوں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxviii{پھر جب اس قیامت کے عذاب کو قریب دیکھیں گے تو کافروں کے چہرے بگڑ جائیں گے اور ان سے کہا جائے گا کہ یہی وہ عذاب ہے جس کے تم خواستگار تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxix{آپ کہہ دیجئے کہ تمہارا کیا خیال ہے کہ خدا مجھے اور میرے ساتھیوں کو ہلاک کردے یا ہم پر رحم کرے تو ان کافروں کا دردناک عذاب سے بچانے والا کون ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxx{کہہ دیجئے کہ وہی خدائے رحمان ہے جس پر ہم ایمان لائے ہیں اور اسی پر ہمارا بھروسہ ہے پھر عنقریب تمہیں معلوم ہوجائے گا کہ کِھلی ہوئی گمراہی میں کون ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxi{کہہ دیجئے کہ تمہارا کیا خیال ہے اگر تمہارا سارا پانی زمین کے اندر جذب ہوجائے تو تمہارے لئے چشمہ کا پانی بہا کر کون لائے گا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxii{\basmalahur نۤ, قلم اور اس چیز کی قسم جو یہ لکھ رہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiii{آپ اپنے پروردگار کی نعمت کے طفیل مجنون نہیں ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiv{اور آپ کے لئے کبھی نہ ختم ہونے والا اجر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxv{اور آپ بلند ترین اخلاق کے درجہ پر ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvi{عنقریب آپ بھی دیکھیں گے اور وہ بھی دیکھ لیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvii{کہ دیوانہ کون ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxviii{آپ کا پروردگار بہتر جانتا ہے کہ کون اس کے راستہ سے بہک گیا ہے اور کون ہدایت یافتہ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxix{لہذا آپ جھٹلانے والوں کی اطاعت نہ کریں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxx{یہ چاہتے ہیں کہ آپ ذرا نرم ہوجائیں تو یہ بھی نرم ہوجائیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxi{اور خبردار آپ کسی بھی مسلسل قسم کھانے والے ذلیل\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxii{عیب جو اور اعلٰی درجہ کے چغلخور\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiii{مال میں بیحد بخل کرنے والے, تجاوز گناہگار\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiv{بدمزاج اور اس کے بعد بدنسل کی اطاعت نہ کریں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxv{صرف اس بات پر کہ یہ صاحب همال و اولاد ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvi{جب اس کے سامنے آیات هالۤہیہ کی تلاوت کی جاتی ہے تو کہہ دیتا ہے کہ یہ سب اگلے لوگوں کی داستانیں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvii{ہم عنقریب اس کی ناک پر نشان لگادیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxviii{ہم نے ان کو اسی طرح آزمایا ہے جس طرح باغ والوں کو آزمایا تھا جب انہوں نے قسم کھائی تھی کہ صبح کو پھل توڑ لیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxix{اور انشائ اللہ نہیں کہیں گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxc{تو خدا کی طرف سے راتوں رات ایک بلا نے چکر لگایا جب یہ سب سورہے تھے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxci{اور سارا باغ جل کر کالی رات جیسا ہوگیا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcii{پھر صبح کو ایک نے دوسرے کو آواز دی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciii{کہ پھل توڑنا ہے تو اپنے اپنے کھیت کی طرف چلو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciv{پھر سب گئے اس عالم میں کہ آپس میں راز دارانہ باتیں کررہے تھے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcv{کہ خبردار آج باغ میں کوئی مسکین داخل نہ ہونے پائے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvi{اور روک تھام کا بندوبست کرکے صبح سویرے پہنچ گئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvii{اب جو باغ کو دیکھا تو کہنے لگے کہ ہم تو بہک گئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcviii{بلکہ بالکل سے محروم ہوگئے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcix{تو ان کے منصف مزاج نے کہا کہ میں نے نہ کہا تھا کہ تم لوگ تسبیح پروردگار کیوں نہیں کرتے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccc{کہنے لگے کہ ہمارا رب پاک و بے نیاز ہے اور ہم واقعا ظالم تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmccci{پھر ایک نے دوسرے کو ملامت کرنا شروع کردی\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccii{کہنے لگے کہ افسوس ہم بالکل سرکش تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciii{شائد ہمارا پروردگار ہمیں اس سے بہتر دے دے کہ ہم اس کی طرف رغبت کرنے والے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccciv{اسی طرح عذاب نازل ہوتا ہے اور آخرت کا عذاب تو اس سے بڑا ہے اگر انہیں علم ہو\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccv{بیشک صاحبانِ تقویٰ کے لئے پروردگار کے یہاں نعمتوں کی جنّت ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvi{کیا ہم اطاعت گزار وں کو مجرموں جیسا بنا دیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvii{تمہیں کیا ہو گیا ہے کیسا فیصلہ کر رہے ہو\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccviii{یا تمہاری کوئی کتاب ہے جس میں یہ سب پڑھا کرتے ہو\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccix{کہ وہاں تمہاری پسند کی ساری چیزیں حاضر ملیں گی\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccx{یا تم نے ہم سے روزِ قیامت تک کی قسمیں لے رکھی ہیں کہ تمہیں وہ سب کچھ ملے گا جس کا تم فیصلہ کرو گے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxi{ان سے پوچھئے کہ ان سب باتوں کا ذمہ دار کون ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxii{یا ان کے لئے شرکائ ہیں تو اگر یہ سچے ہیں تو اپنے شرکائ کو لے آئیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiii{جس دن پنڈلی کھول دی جائے گی اور انہیں سجدوں کی دعوت دی جائے گی اور یہ سجدہ بھی نہ کرسکیں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiv{ان کی نگاہیں شرم سے جھکی ہوں گی ذلّت ان پر چھائی ہوگی اور انہیں اس وقت بھی سجدوں کی دعوت دی جارہی تھی جب یہ بالکل صحیح و سالم تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxv{تو اب مجھے اور اس بات کے جھٹلانے والوں کو چھوڑ دو ہم عنقریب انہیں اس طرح گرفتار کریں گے کہ انہیں اندازہ بھی نہ ہوگا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvi{اور ہم تو اس لئے ڈھیل دے رہے ہیں کہ ہماری تدبیر مضبوط ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvii{کیا آپ ان سے مزدوری مانگ رہے ہیں جو یہ اس کے تاوان کے بوجھ سے دبے جارہے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxviii{یا ان کے پاس کوئی غیب ہے جسے یہ لکھ رہے ہیں\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxix{اب آپ اپنے پروردگار کے حکم کے لئے صبر کریں اور صاحب هحوت جیسے نہ ہوجائیں جب انہوں نے نہایت غصّہ کے عالم میں آواز دی تھی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxx{کہ اگر انہیں نعمت پروردگار نے سنبھال نہ لیا ہوتا تو انہیں چٹیل میدان میں برے حالوں میں چھوڑ دیا جاتا\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxi{پھر ان کے رب نے انہیں منتخب کرکے نیک کرداروں میں قرار دے دیا\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxii{اور یہ کفاّر قرآن کو سنتے ہیں تو ایسا لگتا ہے کہ عنقریب آپ کو نظروں سے پھسلادیں گے اور یہ کہتے ہیں کہ یہ تو دیوانے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiii{حالانکہ یہ قرآن عالمین کے لئے نصیحت ہے اور بس\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiv{\basmalahur یقینا پیش آنے والی قیامت\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxv{اور کیسی پیش آنے والی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvi{اور تم کیا جانو کہ یہ یقینا پیش آنے والی شے کیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvii{قوم ثمود و عاد نے اس کھڑ کھڑانے والی کا انکار کیا تھا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxviii{تو ثمود ایک چنگھاڑ کے ذریعہ ہلاک کردیئے گئے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxix{اور عاد کو انتہائی تیز و تند آندھی سے برباد کردیا گیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxx{جسے ان کے اوپر سات رات اور آٹھ دن کے لئے مسلسل مسخّرکردیا گیا تو تم دیکھتے ہو کہ قوم بالکل مفِدہ پڑی ہوئی ہے جیسے کھوکھلے کھجور کے درخت کے تنے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxi{تو کیا تم ان کا کوئی باقی رہنے والا حصہّ دیکھ رہے ہو\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxii{اور فرعون اور اس سے پہلے اور الٹی بستیوں والے سب نے غلطیوں کا ارتکاب کیا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiii{کہ پروردگار کے نمائندہ کی نافرمانی کی تو پروردگار نے انہیں بڑی سختی سے پکڑ لیا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiv{ہم نے تم کو اس وقت کشتی میں اٹھالیا تھا جب پانی سر سے چڑھ رہا تھا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxv{تاکہ اسے تمہارے لئے نصیحت بنائیں اور محفوظ رکھنے والے کان سن لیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvi{پھر جب صور میں پہلی مرتبہ پھونکا جائے گا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvii{اور زمین اور پہاڑوں کو اکھاڑ کر ٹکرا کر ریزہ ریزہ کردیا جائے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxviii{تو اس دن قیامت واقع ہوجائے گی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxix{اور آسمان شق ہوکر بالکل پھس پھسے ہوجائیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxl{اور فرشتے اس کے اطراف پر ہوں گے اور عرش الہٰی کو اس دن آٹھ فرشتے اٹھائے ہوں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxli{اس دن تم کو منظر عام پر لایا جائے گا اور تمہاری کوئی بات پوشیدہ نہ رہے گی\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlii{پھر جس کو نامئہ اعمال داہنے ہاتھ میں دیا جائے گا وہ سب سے کہے گا کہ ذرا میرا نامئہ اعمال تو پڑھو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliii{مجھے پہلے ہی معلوم تھا کہ میرا حساب مجھے ملنے والا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliv{پھر وہ پسندیدہ زندگی میں ہوگا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlv{بلند ترین باغات میں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvi{اس کے میوے قریب قریب ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvii{اب آرام سے کھاؤ پیو کہ تم نے گزشتہ دنوں میں ان نعمتوں کا انتظام کیا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlviii{لیکن جس کو نامئہ اعمال بائیں ہاتھ میں دیا جائے گا وہ کہے گا اے کاش یہ نامہ اعمال مجھے نہ دیا جاتا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlix{اور مجھے اپنا حساب نہ معلوم ہوتا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccl{اے کاش اس موت ہی نے میرا فیصلہ کردیا ہوتا\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccli{میرا مال بھی میرے کام نہ آیا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclii{اور میری حکومت بھی برباد ہوگئی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliii{اب اسے پکڑو اور گرفتار کرلو\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliv{پھر اسے جہنم ّمیں جھونک دو\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclv{پھر ایک ستر گز کی رسی میں اسے جکڑ لو\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvi{یہ خدائے عظیم پر ایمان نہیں رکھتا تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvii{اور لوگوں کو مسکینوں کو کھلانے پر آمادہ نہیں کرتا تھا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclviii{تو آج اس کا یہاں کوئی غمخوار نہیں ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclix{اور نہ پیپ کے علاوہ کوئی غذا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclx{جسے گنہگاروں کے علاوہ کوئی نہیں کھاسکتا\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxi{میں اس کی بھی قسم کھاتا ہوں جسے تم دیکھ رہے ہو\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxii{اور اس کی بھی جس کو نہیں دیکھ رہے ہو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiii{کہ یہ ایک محترم فرشتے کا بیان ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiv{اور یہ کسی شاعر کا قول نہیں ہے ہاں تم بہت کم ایمان لاتے ہو\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxv{اور یہ کسی کاہن کا کلام نہیںہے جس پر تم بہت کم غور کرتے ہو\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvi{یہ رب العالمین کا نازل کردہ ہے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvii{اور اگر یہ پیغمبر ہماری طرف سے کوئی بات گڑھ لیتا\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxviii{تو ہم اس کے ہاتھ کو پکڑ لیتے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxix{اور پھر اس کی گردن اڑادیتے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxx{پھر تم میں سے کوئی مجھے روکنے والا نہ ہوتا\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxi{اور یہ قرآن صاحبانِ تقویٰ کے لئے نصیحت ہے\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxii{اور ہم جانتے ہیں کہ تم میں سے جھٹلانے والے بھی ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiii{اور یہ کافرین کے لئے باعث هحسرت ہے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiv{اور یہ بالکل یقینی چیز ہے\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxv{لہذا آپ اپنے عظیم پروردگار کے نام کی تسبیح کریں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvi{\basmalahur ایک مانگنے والے نے واقع ہونے والے عذاب کا سوال کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvii{جس کا کافروں کے حق میں کوئی دفع کرنے والا نہیں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxviii{یہ بلندیوں والے خدا کی طرف سے ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxix{جس کی طرف فرشتے اور روح الامین بلند ہوتے ہیں اس ایک دن میں جس کی مقدار پچاس ہزار سال کے برابر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxx{لہذا آپ بہترین صبر سے کام لیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxi{یہ لوگ اسے دور سمجھ رہے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxii{اور ہم اسے قریب ہی دیکھ رہے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiii{جس دن آسمان پگھلے ہوئے تانبے کے مانند ہوجائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiv{اور پہاڑ دھنکے ہوئے اون جیسے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxv{اور کوئی ہمدرد کسی ہمدرد کا پرسانِ حال نہ ہوگا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvi{وہ سب ایک دوسرے کو دکھائے جائیں گے تو مجرم چاہے گا کہ کاش آج کے دن کے عذاب کے بدلے اس کی اولاد کو لے لیا جائے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvii{اوربیوی اور بھائی کو\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxviii{اور اس کنبہ کو جس میں وہ رہتا تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxix{اور روئے زمین کی ساری مخلوقات کو اور اسے نجات دے دی جائے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxc{ہرگز نہیں یہ آتش جہنمّ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxci{کھال اتار دینے والی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcii{ان سب کو آواز دے رہی ہے جو منہ پھیر کر جانے والے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciii{اور جنہوں نے مال جمع کرکے بند کر رکھا تھا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciv{بیشک انسان بڑا لالچی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcv{جب تکلیف پہنچ جاتی ہے تو فریادی بن جاتا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvi{اور جب مال مل جاتا ہے تو بخیل ہو جاتا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvii{علاوہ ان نمازیوں کے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcviii{جو اپنی نمازوں کی پابندی کرنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcix{اور جن کے اموال میں ایک مقررہ حق معین ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcd{مانگنے والے کے لئے اور نہ مانگنے والے کے لئے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdi{اور جو لوگ روز قیامت کی تصدیق کرنے والے ہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdii{اور جو اپنے پروردگار کے عذاب سے ڈرنے والے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiii{بیشک عذاب پروردگار بے خوف رہنے والی چیز نہیں ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiv{اور جو اپنی شرمگاہوں کی حفاظت کرنے والے ہیں\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdv{علاوہ اپنی بیویوں اور کنیزوں کے کہ اس پر ملامت نہیں کی جاتی ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvi{پھر جو اس کے علاوہ کا خواہشمند ہو وہ حد سے گزر جانے والا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvii{اور جو اپنی امانتوں اور عہد کا خیال رکھنے والے ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdviii{اور جو اپنی گواہیوں پر قائم رہنے والے ہیں\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdix{اور جو اپنی نمازوں کا خیال رکھنے والے ہیں\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdx{یہی لوگ جنّت میں باعزّت طریقہ سے رہنے والے ہیں\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxi{پھر ان کافروں کو کیا ہوگیا ہے کہ آپ کی طرف بھاگے چلے آرہے ہیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxii{داہیں بائیں سے گروہ در گروہ\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiii{کیا ان میں سے ہر ایک کی طمع یہ ہے کہ اسے جنت النعیم میں داخل کردیا جائے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiv{ہرگز نہیں انہیں تو معلوم ہے کہ ہم نے انہیں کس چیز سے پیدا کیا ہے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxv{میں تمام مشرق و مغرب کے پروردگار کی قسم کھا کر کہتا ہوں کہ ہم قدرت رکھنے والے ہیں\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvi{اس بات پر کہ ان کے بدلے ان سے بہتر افراد لے آئیں اور ہم عاجز نہیں ہیں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvii{لہذا انہیں چھوڑ دیجئے یہ اپنے باطل میں ڈوبے رہیں اور کھیل تماشہ کرتے رہیں یہاں تک کہ اس دن سے ملاقات کریں جس کا وعدہ کیا گیا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxviii{جس دن یہ سب قبروں سے تیزی کے ساتھ نکلیں گے جس طرح کسی پرچم کی طرف بھاگے جارہے ہوں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxix{ان کی نگاہیں جھکی ہوں گی اور ذلت ان پر چھائی ہوگی اور یہی وہ دن ہوگا جس کا ان سے وعدہ کیا گیا ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxx{\basmalahur بیشک ہم نے نوح کو ان کی قوم کی طرف بھیجا کہ اپنی قوم کو دردناک عذاب کے آنے سے پہلے ڈراؤ\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxi{انہوں نے کہا اے قوم میں تمہارے لئے واضح طور پر ڈرانے والا ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxii{کہ اللہ کی عبادت کرو اس سے ڈرو اور میری اطاعت کرو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiii{وہ تمہارے گناہوں کو بخش دے گا اور تمہیں ایک مقررہ وقت تک باقی رکھے گا اللہ کا مقررہ وقت جب آجائے گا تو وہ ٹالا نہیں جاسکتا ہے اگر تم کچھ جانتے ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiv{انہوں نے کہا پروردگار میں نے اپنی قوم کو دن میں بھی بلایا اور رات میں بھی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxv{پھر بھی میری دعوت کا کوئی اثر سوائے اس کے نہ ہوا کہ انہوں نے فرار اختیار کیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvi{اور میں نے جب بھی انہیں دعوت دی کہ تو انہیں معاف کردے تو انہوں نے اپنی انگلیوں کو کانوں میں رکھ لیا اور اپنے کپڑے اوڑھ لئے اور اپنی بات پر اڑ گئے اور شدت سے اکڑے رہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvii{پھر میں نے ان کو علی الاعلان دعوت دی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxviii{پھر میں نے اعلان بھی کیا اور خفیہ طور سے بھی دعوت دی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxix{اور کہا کہ اپنے پروردگار سے استغفار کرو کہ وہ بہت زیادہ بخشنے والا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxx{وہ تم پر موسلا دھار پانی برسائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxi{اور اموال و اولاد کے ذریعہ تمہاری مدد کرے گا اور تمہارے لئے باغات اور نہریں قرار دے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxii{آخر تمہیں کیا ہوگیا ہے کہ تم خدا کی عظمت کا خیال نہیں کرتے ہو\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiii{جب کہ اسی نے تمہیں مختلف انداز میں پیدا کیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiv{کیا تم نے نہیں دیکھا کہ خدا نے کس طرح تہ بہ تہ سات آسمان بنائے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxv{اور قمر کو ان میں روشنی اور سورج کو روشن چراغ بنایا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvi{اور اللہ ہی نے تم کو زمین سے پیدا کیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvii{پھر تمہیں اسی میں لے جائے گا اور پھر نئی شکل میں نکالے گا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxviii{اور اللہ ہی نے تمہارے لئے زمین کو فرش بنادیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxix{تاکہ تم اس میں مختلف کشادہ راستوں پر چلو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxl{اور نوح نے کہا کہ پروردگار ان لوگوں نے میری نافرمانی کی ہے اور اس کا اتباع کرلیا ہے جو مال و اولاد میں سوائے گھاٹے کے کچھ نہیں دے سکتا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxli{اور ان لوگوں نے بہت بڑا مکر کیا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlii{اور لوگوں سے کہا ہے کہ خبردار اپنے خداؤں کو مت چھوڑ دینا اور ود, سواع, یغوث, یعوق, نسر کو نظرانداز نہ کردینا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliii{انہوں نے بہت سوں کو گمراہ کردیا ہے اب تو ظالموں کے لئے ہلاکت کے علاوہ کوئی اضافہ نہ کرنا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliv{یہ سب اپنی غلطیوں کی بنا پر غرق کئے گئے ہیں اور پھر جہنم ّمیں داخل کردیئے گئے ہیں اور خدا کے علاوہ انہیں کوئی مددگار نہیں ملا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlv{اور نوح نے کہا کہ پروردگار اس زمین پر کافروں میں سے کسی بسنے والے کو نہ چھوڑنا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvi{کہ تو انہیں چھوڑ دے گا تو تیرے بندوں کو گمراہ کریں گے اور فاجر و کافر کے علاوہ کوئی اولاد بھی نہ پیدا کریں گے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvii{پروردگار مجھے اور میرے والدین کو اور جو ایمان کے ساتھ میرے گھر میں داخل ہوجائیں اور تمام مومنین و مومنات کو بخش دے اور ظالموں کے لئے ہلاکت کے علاوہ کسی شے میں اضافہ نہ کرنا\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlviii{\basmalahur پیغمبر آپ کہہ دیجئے کہ میری طرف یہ وحی کی گئی ہے کہ جنوں کی ایک جماعت نے کان لگا کر قرآن کو سنا تو کہنے لگے کہ ہم نے ایک بڑا عجیب قرآن سنا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlix{جو نیکی کی ہدایت کرتا ہے تو ہم تو اس پر ایمان لے آئے ہیں اور کسی کو اپنے رب کا شریک نہ بنائیں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdl{اور ہمارے رب کی شان بہت بلند ہے اس نے کسی کو اپنی بیوی بنایا ہے نہ بیٹا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdli{اور ہمارے بیوقوف لوگ طرح طرح کی بے ربط باتیں کررہے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlii{اور ہمارا خیال تو یہی تھا کہ انسان اور جناّت خدا کے خلاف جھوٹ نہ بولیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliii{اور یہ کہ انسانوں میں سے کچھ لوگ جناّت کے بعض لوگوں کی پناہ ڈھونڈ رہے تھے تو انہوں نے گرفتاری میں اور اضافہ کردیا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliv{اور یہ کہ تمہاری طرح ان کا بھی خیال تھا کہ خدا کسی کو دوبارہ نہیں زندہ کرے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlv{اور ہم نے آسمان کو دیکھا تو اسے سخت قسم کے نگہبانوں اور شعلوں سے بھرا ہوا پایا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvi{اور ہم پہلے بعض مقامات پر بیٹھ کر باتیں سن لیا کرتے تھے لیکن اب کوئی سننا چاہے گا تو اپنے لئے شعلوں کو تیار پائے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvii{اور ہمیں نہیں معلوم کہ اہل زمین کے لئے اس سے برائی مقصود ہے یا نیکی کا ارادہ کیا گیا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlviii{اور ہم میں سے بعض نیک کردار ہیں اور بعض کے علاوہ ہیں اور ہم طرح طرح کے گروہ ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlix{اور ہمارا خیال ہے کہ ہم زمین میں خدا کو عاجز نہیں کرسکتے اور نہ بھاگ کر اسے اپنی گرفت سے عاجز کرسکتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlx{اور ہم نے ہدایت کو سنا تو ہم تو ایمان لے آئے اب جو بھی اپنے پروردگار پر ایمان لائے گا اسے نہ خسارہ کا خوف ہوگا اور نہ ظلم و زیادتی کا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxi{اور ہم میں سے بعض اطاعت گزار ہیں اور بعض نافرمان اور جو اطاعت گزار ہوگا اس نے ہدایت کی راہ پالی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxii{اور نافرمان تو جہنمّ کے کندے ہوگئے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiii{اور اگر یہ لوگ سب ہدایت کے راستے پر ہوتے تو ہم انہیں وافر پانی سے سیراب کرتے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiv{تاکہ ان کا امتحان لے سکیں اور جو بھی اپنے رب کے ذکر سے اعراض کرے گا اسے سخت عذاب کے راستے پر چلنا پڑے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxv{اور مساجد سب اللہ کے لئے ہیں لہذا اس کے علاوہ کسی کی عبادت نہ کرنا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvi{اور یہ کہ جب بندہ خدا عبادت کے لئے کھڑا ہوا تو قریب تھا کہ لوگ اس کے گرد ہجوم کرکے گر پڑتے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvii{پیغمبرآپ کہہ دیجئے کہ میں صرف اپنے پروردگار کی عبادت کرتا ہوں اور کسی کو اس کا شریک نہیں بناتا ہوں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxviii{کہہ دیجئے کہ میں تمہارے لئے کسی نقصان کا اختیار رکھتا ہوں اور نہ فائدہ کا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxix{کہہ دیجئے کہ اللہ کے مقابلہ میں میرا بھی بچانے والا کوئی نہیں ہے اور نہ میں کوئی پناہ گاہ پاتا ہوں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxx{مگر یہ کہ اپنے رب کے احکام اور پیغام کو پہنچادوں اور جو اللہ و رسول کی نافرمانی کرے گا اس کے لئے جہنم ّہے اور وہ اسی میں ہمیشہ رہنے والا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxi{یہاں تک کہ جب ان لوگوں نے اس عذاب کو دیکھ لیا جس کا وعدہ کیا گیا تھا تو انہیں معلوم ہوجائے گا کہ کس کے مددگار کمزور اور کس کی تعداد کمتر ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxii{کہہ دیجئے کہ مجھے نہیں معلوم کہ وہ وعدہ قریب ہی ہے یا ابھی خدا کوئی اور مدّت بھی قرار دے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiii{وہ عالم الغیب ہے اور اپنے غیب پر کسی کو بھی مطلع نہیں کرتا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiv{مگر جس رسول کو پسند کرلے تو اس کے آگے پیچھے نگہبان فرشتے مقرر کردیتا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxv{تاکہ وہ دیکھ لے کہ انہوں نے اپنے رب کے پیغامات کو پہنچادیا ہے اور وہ جس کے پاس جو کچھ بھی ہے اس پر حاوی ہے اور سب کے اعداد کا حساب رکھنے والا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvi{\basmalahur اے میرے چادر لپیٹنے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvii{رات کو اٹھو مگر ذرا کم\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxviii{آدھی رات یا اس سے بھی کچھ کم کر دو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxix{یا کچھ زیادہ کردو اور قرآن کو ٹھہر ٹھہر کر باقاعدہ پڑھو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxx{ہم عنقریب تمہارے اوپر ایک سنگین حکم نازل کرنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxi{بیشک رات کا اُٹھنا نفس کی پامالی کے لئے بہترین ذریعہ اور ذکر کا بہترین وقت ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxii{یقینا آپ کے لئے دن میں بہت سے مشغولیات ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiii{اور آپ اپنے رب کے نام کا ذکر کریں اور اسی کے ہو رہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiv{وہ مشرق و مغرب کا مالک ہے اور اس کے علاوہ کوئی خدا نہیں ہے لہذا آپ اسی کو اپنا نگراں بنالیں\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxv{اور یہ لوگ جو کچھ بھی کہہ رہے ہیں اس پر صبر کریں اور انہیں خوبصورتی کے ساتھ اپنے سے الگ کردیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvi{اور ہمیں اور ان دولت مند جھٹلانے والوں کو چھوڑ دیں اور انہیں تھوڑی مہلت دے دیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvii{ہمارے پاس ان کے لئے بیڑیاں اور بھڑکتی ہوئی آگ ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxviii{اور گلے میں پھنس جانے والا کھانا اور دردناک عذاب ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxix{جس دن زمین اور پہاڑ لرزہ میں آجائیں گے اور پہاڑ ریت کا ایک ٹیلہ بن جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxc{بیشک ہم نے تم لوگوں کی طرف تمہارا گواہ بناکر ایک رسول بھیجا ہے جس طرح فرعون کی طرف رسول بھیجا تھا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxci{تو فرعون نے اس رسول کی نافرمانی کی تو ہم نے اسے سخت گرفت میں لے لیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcii{پھر تم بھی کفر اختیار کرو گے تو اس دن سے کس طرح بچو گے جو بچوں کو بوڑھا بنادے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciii{جس دن آسمان پھٹ پڑے گا اور یہ وعدہ بہرحال پورا ہونے والا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciv{یہ درحقیقت عبرت و نصیحت کی باتیں ہیں اور جس کا جی چاہے اپنے پروردگار کے راستے کو اختیار کرلے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcv{آپ کا پروردگار جانتا ہے کہ دو تہائی رات کے قریب یا نصف شب یا ایک تہائی رات قیام کرتے ہیں اور آپ کے ساتھ ایک گروہ اور بھی ہے اور اللہ د ن و رات کا صحیح اندازہ رکھتا ہے وہ جانتا ہے کہ تم لوگ اس کا صحیح احصاءنہ کر سکوگے تو اس نے تمہارے اوپر مہربانی کر دی ہے اب جس قدر قرآن ممکن ہو اتنا پڑھ لو کہ وہ جانتا ہے کہ عنقریب تم میں سے بعض مریض ہوجائےں گے اور بعض رزق خدا کو تلاش کرنے کے لئے سفر میں چلے جائےں گے اور بعض راہِ خدا میں جہاد کریں گے تو جس قدر ممکن ہو تلاوت کرو اور نماز قائم کرو اور زکوٰة ادا کرو اور اللہ کو قرض حسنہ دو اور پھر جو کچھ بھی اپنے نفس کے واسطے نیکی پیشگی پھیج دو گے اسے خدا کی بارگاہ میں حاضر پاﺅگے ،بہتر اور اجر کے اعتبار سے عظیم تر۔اور اللہ سے استغفار کرو کہ وہ بہت زیادہ بخشنے والا اور مہربا ن ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvi{\basmalahur اے میرے کپڑا اوڑھنے والے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvii{اٹھو اور لوگوں کو ڈراؤ\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcviii{اور اپنے رب کی بزرگی کا اعلان کرو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcix{اور اپنے لباس کو پاکیزہ رکھو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmd{اور برائیوں سے پرہیز کرو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdi{اور اس طرح احسان نہ کرو کہ زیادہ کے طلب گار بن جاؤ\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdii{اور اپنے رب کی خاطر صبر کرو\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiii{پھر جب صور پھونکا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdiv{تو وہ دن انتہائی مشکل دن ہوگا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdv{کافروں کے واسطے تو ہر گز آسان نہ ہوگا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvi{اب مجھے اور اس شخص کو چھوڑ دو جس کو میں نے اکیلا پیدا کیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdvii{اور اس کے لئے کثیر مال قرار دیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdviii{اور نگاہ کے سامنے رہنے والے بیٹے قرار دیئے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdix{اور ہر طرح کے سامان میں وسعت دے دی ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdx{اور پھر بھی چاہتا ہے کہ اور اضافہ کردوں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxi{ہرگز نہیں یہ ہماری نشانیوں کا سخت دشمن تھا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxii{تو ہم عنقریب اسے سخت عذاب میں گرفتار کریں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiii{اس نے فکر کی اور اندازہ لگایا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiv{تو اسی میں مارا گیا کہ کیسا اندازہ لگایا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxv{پھر اسی میں اور تباہ ہوگیا کہ کیسا اندازہ لگایا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvi{پھر غور کیا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvii{پھر تیوری چڑھا کر منہ بسور لیا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxviii{پھر منہ پھیر کر چلا گیا اور اکڑ گیا\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxix{اور آخر میں کہنے لگا کہ یہ تو ایک جادو ہے جو پرانے زمانے سے چلا آرہا ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxx{یہ تو صرف انسان کا کلام ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxi{ہم عنقریب اسے جہنمّ واصل کردیں گے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxii{اور تم کیا جانو کہ جہنمّ کیا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiii{وہ کسی کو چھوڑنے والا اور باقی رکھنے والا نہیںہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiv{بدن کو جلا کر سیاہ کردینے والا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxv{اس پر انیس فرشتے معین ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvi{اور ہم نے جہنمّ کا نگہبان صرف فرشتوں کو قرار دیا ہے اور ان کی تعداد کو کفار کی آزمائش کا ذریعہ بنادیا ہے کہ اہل کتاب کو یقین حاصل ہوجائے اور ایمان والوں کے ایمان میں اضافہ ہوجائے اور اہل کتاب یا صاحبانِ ایمان اس کے بارے میں کسی طرح کا شک نہ کریں اور جن کے دلوں میں مرض ہے اور کفار یہ کہنے لگیں کہ آخر اس مثال کا مقصد کیا ہے اللہ اسی طرح جس کو چاہتا ہے گمراہی میں چھوڑ دیتا ہے اور جس کو چاہتا ہے ہدایت دے دیتا ہے اور اس کے لشکروں کو اس کے علاوہ کوئی نہیں جانتا ہے یہ تو صرف لوگوں کی نصیحت کا ایک ذریعہ ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvii{ہوشیار ہمیں چاند کی قسم\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxviii{اور جاتی ہوئی رات کی قسم\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxix{اور روشن صبح کی قسم\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxx{یہ جہنمّ بڑی چیزوں میں سے ایک چیز ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxi{لوگوں کے ڈرانے کا ذریعہ\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxii{ان کے لئے جو آگے پیچھے ہٹنا چاہیں\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiii{ہر نفس اپنے اعمال میں گرفتار ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiv{علاوہ اصحاب یمین کے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxv{وہ جنتوں میں رہ کر آپس میں سوال کررہے ہوں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvi{مجرمین کے بارے میں\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvii{آخر تمہیں کس چیز نے جہنمّ میں پہنچادیا ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxviii{وہ کہیں گے کہ ہم نماز گزار نہیں تھے\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxix{اور مسکین کو کھانا نہیں کھلایا کرتے تھے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxl{لوگوں کے بفِے کاموں میں شامل ہوجایا کرتے تھے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxli{اور روزِ قیامت کی تکذیب کیا کرتے تھے\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlii{یہاں تک کہ ہمیں موت آگئی\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliii{تو انہیں سفارش کرنے والوں کی سفارش بھی کوئی فائدہ نہ پہنچائے گی\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliv{آخر انہیں کیا ہوگیا ہے کہ یہ نصیحت سے منہ موڑے ہوئے ہیں\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlv{گویا بھڑکے ہوئے گدھے ہیں\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvi{جو شیر سے بھاگ رہے ہیں\qt@no{(51)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvii{حقیقتا ان میں ہر آدمی اس بات کا خواہش مند ہے کہ اسے کِھلی ہوئی کتابیں عطا کردی جائیں\qt@no{(52)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlviii{ہرگز نہیں ہوسکتا اصل یہ ہے کہ انہیں آخرت کا خوف ہی نہیں ہے\qt@no{(53)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlix{ہاں ہاں بیشک یہ سراسر نصیحت ہے\qt@no{(54)}}%
\qt@newcmd\qurantrans@ur@mmmmmdl{اب جس کا جی چاہے اسے یاد رکھے\qt@no{(55)}}%
\qt@newcmd\qurantrans@ur@mmmmmdli{اور یہ اسے یاد نہ کریں گے مگر یہ کہ اللہ ہی چاہے کہ وہی ڈرانے کا اہل اور مغفرت کا مالک ہے\qt@no{(56)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlii{\basmalahur میں روزِ قیامت کی قسم کھاتا ہوں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliii{اور برائیوں پر ملامت کرنے والے نفس کی قسم کھاتا ہوں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdliv{کیا یہ انسان یہ خیال کرتا ہے کہ ہم اس کی ہڈیوں کو جمع نہ کرسکیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlv{یقینا ہم اس بات پر قادر ہیں کہ اس کی انگلیوں کے پور تک درست کرسکیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvi{بلکہ انسان یہ چاہتا ہے کہ اپنے سامنے برائی کرتا چلا جائے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvii{وہ یہ پوچھتا ہے کہ یہ قیامت کب آنے والی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlviii{تو جب آنکھیں چکا چوند ہوجائیں گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlix{اور چاند کو گہن لگ جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlx{اور یہ چاند سورج اکٹھا کردیئے جائیں گے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxi{اس دن انسان کہے گا کہ اب بھاگنے کا راستہ کدھر ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxii{ہرگز نہیں اب کوئی ٹھکانہ نہیں ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiii{اب سب کا مرکز تمہارے پروردگار کی طرف ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiv{اس دن انسان کو بتایا جائے گا کہ اس نے پہلے اور بعد کیا کیا اعمال کئے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxv{بلکہ انسان خود بھی اپنے نفس کے حالات سے خوب باخبر ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvi{چاہے وہ کتنے ہی عذر کیوں نہ پیش کرے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvii{دیکھئے آپ قرآن کی تلاوت میں عجلت کے ساتھ زبان کو حرکت نہ دیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxviii{یہ ہماری ذمہ داری ہے کہ ہم اسے جمع کریں اور پڑھوائیں\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxix{پھر جب ہم پڑھوادیں تو آپ اس کی تلاوت کو دہرائیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxx{پھر اس کے بعد اس کی وضاحت کرنا بھی ہماری ہی ذمہ داری ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxi{نہیں بلکہ تم لوگ دنیا کو دوست رکھتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxii{اور آخرت کو نظر انداز کئے ہوئے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiii{اس دن بعض چہرے شاداب ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiv{اپنے پروردگار کی نعمتوں پر نظر رکھے ہوئے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxv{اور بعض چہرے افسردہ ہوں گے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvi{جنہیں یہ خیال ہوگا کہ کب کمر توڑ مصیبت وارد ہوجائے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvii{ہوشیار جب جان گردن تک پہنچ جائے گی\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxviii{اور کہا جائے گا کہ اب کون جھاڑ پھونک کرنے والا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxix{اور مرنے والے کو خیال ہوگا کہ اب سب سے جدائی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxx{اور پنڈلی پنڈلی سے لپٹ جائے گی\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxi{آج سب کو پروردگار کی طرف لے جایا جائے گا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxii{اس نے نہ کلام خدا کی تصدیق کی اور نہ نماز پڑھی\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiii{بلکہ تکذیب کی اور منہ پھیر لیا\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiv{پھر اپنے اہل کی طرف اکڑتا ہوا گیا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxv{افسوس ہے تیرے حال پر بہت افسوس ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvi{حیف ہے اور صد حیف ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvii{کیا انسان کا خیال یہ ہے کہ اسے اسی طرح آزاد چھوڑ دیا جائے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxviii{کیا وہ اس منی کا قطرہ نہیں تھا جسے رحم میں ڈالا جاتا ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxix{پھر علقہ بنا پھر اسے خلق کرکے برابر کیا\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxc{پھر اس سے عورت اور مرد کا جوڑا تیار کیا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxci{کیا وہ خدا اس بات پر قادر نہیں ہے کہ مفِدوں کو دوبارہ زندہ کرسکے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcii{\basmalahur یقینا انسان پر ایک ایسا وقت بھی آیا ہے کہ جب وہ کوئی قابل ذکر شے نہیں تھا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciii{یقینا ہم نے انسان کو ایک ملے جلے نطفہ سے پیدا کیا ہے تاکہ اس کا امتحان لیں اور پھر اسے سماعت اور بصارت والا بنادیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciv{یقینا ہم نے اسے راستہ کی ہدایت دے دی ہے چاہے وہ شکر گزار ہوجائے یا کفران نعمت کرنے والا ہوجائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcv{بیشک ہم نے کافرین کے لئے زنجیریں - طوق اور بھڑکتے ہوئے شعلوں کا انتظام کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvi{بیشک ہمارے نیک بندے اس پیالہ سے پئیں گے جس میں شراب کے ساتھ کافور کی آمیزش ہوگی\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvii{یہ ایک چشمہ ہے جس سے اللہ کے نیک بندے پئیں گے اور جدھر چاہیں گے بہاکر لے جائیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcviii{یہ بندے نذر کو پورا کرتے ہیں اور اس دن سے ڈرتے ہیں جس کی سختی ہر طرف پھیلی ہوئی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcix{یہ اس کی محبت میں مسکینً یتیم اور اسیر کو کھانا کھلاتے ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdc{ہم صرف اللہ کی مرضی کی خاطر تمہیں کھلاتے ہیں ورنہ نہ تم سے کوئی بدلہ چاہتے ہیں نہ شکریہ\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdci{ہم اپنے پروردگار سے اس دن کے بارے میں ڈرتے ہیں جس دن چہرے بگڑ جائیں گے اور ان پر ہوائیاں اڑنے لگیں گی\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcii{تو خدا نے انہیں اس دن کی سختی سے بچالیا اور تازگی اور سرور عطا کردیا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciii{اور انہیں ان کے صبر کے عوض جنّت اور حریر جنّت عطا کرے گا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdciv{جہاں وہ تختوں پر تکیہ لگائے بیٹھے ہوں گے نہ آفتاب کی گرمی دیکھیں گے اور نہ سردی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcv{ان کے سروں پر قریب ترین سایہ ہوگا اور میوے بالکل ان کے اختیار میں کردیئے جائیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvi{ان کے گرد چاندی کے پیالے اور شیشے کے ساغروں کی گردش ہوگی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvii{یہ ساغر بھی چاندی ہی کے ہوں گے جنہیں یہ لوگ اپنے پیمانہ کے مطابق بنالیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcviii{یہ وہاں ایسے پیالے سے سیراب کئے جائیں گے جس میں زنجبیل کی آمیزش ہوگی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcix{جو جنّت کا ایک چشمہ ہے جسے سلسبیل کہا جاتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcx{اور ان کے گرد ہمیشہ نوجوان رہنے والے بچے گردش کررہے ہوں گے کہ تم انہیں دیکھو گے تو بکھرے ہوئے موتی معلوم ہوں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxi{اور پھر دوبارہ دیکھو گے تو نعمتیں اور ایک ملک کبیر نظر آئے گا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxii{ان کے اوپر کریب کے سبز لباس اور ریشم کے حلّے ہوں گے اور انہیں چاندی کے کنگن پہنائے جائیں گے اور انہیں ان کا پروردگار پاکیزہ شراب سے سیراب کرے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiii{یہ سب تمہاری جزا ہے اور تمہاری سعی قابل قبول ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiv{ہم نے آپ پر قرآن تدریجا نازل کیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxv{لہذا آپ حکم اَ خدا کی خاطر صبر کریں اور کسی گنہگار یا کافر کی بات میں نہ آجائیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvi{اور صبح و شام اپنے پروردگار کے نام کی تسبیح کرتے رہیں\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvii{اور رات کے ایک حصہ میں اس کا سجدہ کریں اور بڑی رات تک اس کی تسبیح کرتے رہیں\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxviii{یہ لوگ صرف دنیا کی نعمتوں کو پسند کرتے ہیں اور اپنے پیچھے ایک بڑے سنگین دن کو چھوڑے ہوئے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxix{ہم نے ان کو پیدا کیا ہے اور ان کے اعضائ کو مضبوط بنایا ہے اور جب چاہیں گے تو انہیں بدل کر ان کے جیسے دوسرے افراد لے آئیں گے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxx{یہ ایک نصیحت کا سامان ہے اب جس کا جی چاہے اپنے پروردگار کے راستہ کو اختیار کرلے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxi{اور تم لوگ تو صرف وہی چاہتے ہو جو پروردگار چاہتا ہے بیشک اللہ ہر چیز کا جاننے والا اور صاحبِ حکمت ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxii{وہ جسے چاہتا ہے اپنی رحمت میں داخل کرلیتا ہے اور اس نے ظالمین کے لئے دردناک عذاب مہیاّ کررکھا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiii{\basmalahur ان کی قسم جنہیں تسلسل کے ساتھ بھیجا گیا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiv{پھر تیز رفتاری سے چلنے والی ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxv{اور قسم ہے ان کی جو اشیائ کو منتشر کرنے والی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvi{پھر انہیں آپس میں جدا کرنے والی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvii{پھر ذ کر کو نازل کرنے والی ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxviii{تاکہ عذر تمام ہو یا خوف پیدا کرایا جائے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxix{جس چیز کا تم سے وعدہ کیا گیا ہے وہ بہرحال واقع ہونے والی ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxx{پھر جب ستاروں کی چمک ختم ہوجائے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxi{اور آسمانوں میں شگاف پیدا ہوجائے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxii{اور جب پہاڑ اُڑنے لگیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiii{اور جب سارے پیغمبر علیھ السّلام ایک وقت میں جمع کرلئے جائیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiv{بھلا کس دن کے لئے ان باتوں میں تاخیر کی گئی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxv{فیصلہ کے دن کے لئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvi{اور آپ کیاجانیں کہ فیصلہ کا دن کیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvii{اس دن جھٹلانے والوں کے لئے جہنمّ ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxviii{کیا ہم نے ان کے پہلے والوں کو ہلاک نہیں کردیا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxix{پھر دوسرے لوگوں کو بھی ان ہی کے پیچھے لگادیں گے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxl{ہم مجرموں کے ساتھ اسی طرح کا برتاؤ کرتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxli{اور آج کے دن جھٹلانے والوں کے لئے بربادی ہی بربادی ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlii{کیا ہم نے تم کو ایک حقیر پانی سے نہیں پیدا کیا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliii{پھر اسے ایک محفوظ مقام پر قرار دیا ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliv{ایک معین مقدار تک\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlv{پھر ہم نے اس کی مقدار معین کی ہے تو ہم بہترین مقدار مقرر کرنے والے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvi{آج کے دن جھٹلانے والوں کے لئے بربادی ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvii{کیا ہم نے زمین کو ایک جمع کرنے والا ظرف نہیں بنایا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlviii{جس میں زندہ مفِدہ سب کو جمع کریں گے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlix{اور اس میں اونچے اونچے پہاڑ قرار دئے ہیں اور تمہیں شیریں پانی سے سیراب کیا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcl{آج جھٹلانے والوں کے لئے بربادی اور تباہی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcli{جاؤ اس طرف جس کی تکذیب کیا کرتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclii{جاؤ اس دھوئیں کے سایہ کی طرف جس کے تین گوشے ہیں\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliii{نہ ٹھنڈک ہے اور نہ جہنمّ کی لپٹ سے بچانے والا سہارا\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliv{وہ ایسے انگارے پھینک رہا ہے جیسے کوئی محل\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclv{جیسے زرد رنگ کے اونٹ\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvi{آج کے دن جھٹلانے والوں کے لئے بربادی اور جہنمّ ہے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvii{آج کے دن یہ لوگ بات بھی نہ کرسکیں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclviii{اور نہ انہیں اس بات کی اجازت ہوگی کہ عذر پیش کرسکیں\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclix{آج کے دن جھٹلانے والوں کے لئے جہنم ّہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclx{یہ فیصلہ کا دن ہے جس میں ہم نے تم کو اور تمام پہلے والوں کو اکٹھا کیا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxi{اب اگر تمہارے پاس کوئی چال ہو تو ہم سے استعمال کرو\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxii{آج تکذیب کرنے والوں کے لئے جہنم ّہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiii{بیشک متقین گھنی چھاؤں اور چشموں کے درمیان ہوں گے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiv{اور ان کی خواہش کے مطابق میوے ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxv{اب اطمینان سے کھاؤ پیو ان اعمال کی بنا پر جو تم نے انجام دیئے ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvi{ہم اسی طرح نیک عمل کرنے والوں کو بدلہ دیتے ہیں\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvii{آج جھٹلانے والوں کے لئے جہنم ہے\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxviii{تم لوگ تھوڑے دنوں کھاؤ اور آرام کرلو کہ تم مجرم ہو\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxix{آج کے دن تکذیب کرنے والوں کے لئے ویل ہے\qt@no{(47)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxx{اور جب ان سے کہا جاتا ہے کہ رکوع کرو تو نہیں کرتے ہیں\qt@no{(48)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxi{تو آج کے دن جھٹلانے والوں کے لئے جہنم ہے\qt@no{(49)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxii{آخر یہ لوگ اس کے بعد کس بات پر ایمان لے آئیں گے\qt@no{(50)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiii{\basmalahur یہ لوگ آپس میں کس چیز کے بارے میں سوال کررہے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiv{بہت بڑی خبر کے بارے میں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxv{جس کے بارے میں ان میں اختلاف ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvi{کچھ نہیں عنقریب انہیں معلوم ہوجائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvii{اور خوب معلوم ہوجائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxviii{کیا ہم نے زمین کا فرش نہیں بنایا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxix{اورپہاڑوں کی میخیں نہیں نصب کی ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxx{اور ہم ہی نے تم کوجوڑا بنایا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxi{اور تمہاری نیند کو آرام کا سامان قرار دیا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxii{اور رات کو پردہ پوش بنایا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiii{اور دن کو وقت معاش قراردیا ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiv{اور تمہارے سروں پر سات مضبوط آسمان بنائے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxv{اور ایک بھڑکتا ہوا چراغ بنایا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvi{اور بادلوں میں سے موسلا دھار پانی برسایا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvii{تاکہ اس کے ذریعہ دانے اور گھاس برآمدکریں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxviii{اور گھنے گھنے باغات پیداکریں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxix{بیشک فیصلہ کا دن معین ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxc{جس دن صورپھونکا جائے گا اور تم سب فوج در فوج آؤ گے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxci{اورآسمان کے راستے کھول دیئے جائیں گے اور دروازے بن جائیں گے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcii{اورپہاڑوں کو جگہ سے حرکت دے دی جائے گی اوروہ ریت جیسے ہوجائیں گے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciii{بیشک جہنم ان کی گھات میں ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciv{وہ سرکشوں کا آخری ٹھکانا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcv{اس میں وہ مدتوں رہیں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvi{نہ ٹھنڈک کا مزہ چکھ سکیں گے اور نہ کسی پینے کی چیز کا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvii{علاوہ کھولتے پانی اورپیپ کے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcviii{یہ ان کے اعمال کامکمل بدلہ ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcix{یہ لوگ حساب و کتاب کی امید ہی نہیں رکھتے تھے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcc{اورانہوں نے ہماری آیات کی باقاعدہ تکذیب کی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcci{اور ہم نے ہر شے کو اپنی کتاب میں جمع کرلیا ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccii{اب تم اپنے اعمال کا مزہ چکھو اورہم عذاب کے علاوہ کوئی اضافہ نہیں کرسکتے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciii{بیشک صاحبانِ تقویٰ کے لئے کامیابی کی منزل ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciv{باغات ہیں اورانگور\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccv{نوخیز دوشیزائیں ہیں اورسب ہمسن\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvi{اور چھلکتے ہوئے پیمانے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvii{وہاں نہ کوئی لغو بات سنیں گے نہ گناہ\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccviii{یہ تمہارے رب کی طرف سے حساب کی ہوئی عطا ہے اور تمہارے اعمال کی جزا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccix{وہ آسمان و زمین اوران کے مابین کاپروردگار رحمٰن ہے جس کے سامنے کسی کو بات کرنے کا یارا نہیں ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccx{جس دن روح القدس اورملائکہ صف بستہ کھڑے ہوں گے اورکوئی بات بھی نہ کرسکے گا علاوہ اس کے جسے رحمٰن اجازت دے دے اور ٹھیک ٹھیک بات کرے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxi{یہی برحق دن ہے تو جس کا جی چاہے اپنے رب کی طرف ٹھکانا بنالے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxii{ہم نے تم کو ایک قریبی عذاب سے ڈرایا ہے جس دن انسان اپنے کئے دھرے کو دیکھے گا اورکافرکہے گا کہ اے کاش میں خاک ہوگیا ہوتا\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiii{\basmalahur قسم ہے ان کی جو ڈوب کر کھینچ لینے والے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiv{اور آسانی سے کھول دینے والے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxv{اور فضا میں پیرنے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvi{پھر تیز رفتاری سے سبقت کرنے والے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvii{پھر امور کا انتظام کرنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxviii{جس دن زمین کو جھٹکا دیا جائے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxix{اور اس کے بعد دوسرا جھٹکا لگے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxx{اس دن دل لرز جائیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxi{آنکھیں خوف سے جھکیِ ہوں گی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxii{یہ کفاّر کہتے ہیں کہ کیا ہم پلٹ کر پھر اس دنیا میں بھیجے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiii{کیا جب ہم کھوکھلی ہڈیاں ہوجائیں گے تب\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiv{یہ تو بڑے گھاٹے والی واپسی ہوگی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxv{یہ قیامت تو بس ایک چیخ ہوگی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvi{جس کے بعد سب میدان هحشر میں نظر آئیں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvii{کیا تمہارے پاس موسٰی کی خبر آئی ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxviii{جب ان کے رب نے انہیں طویٰ کی مقدس وادی میں آواز دی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxix{فرعون کی طرف جاؤ وہ سرکش ہوگیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxx{اس سے کہو کیا یہ ممکن ہے تو پاکیزہ کردار ہوجائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxi{اور میں تجھے تیرے رب کی طرف ہدایت کروں اور تیرے دل میں خوف پیدا ہوجائے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxii{پھر انہوں نے اسے عظیم نشانی دکھلائی\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiii{تو اس نے انکار کردیا اور نافرمانی کی\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiv{پھر منہ پھیر کر دوڑ دھوپ میں لگ گیا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxv{پھر سب کو جمع کیا اور آواز دی\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvi{اور کہا کہ میں تمہارا رب اعلیٰ ہوں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvii{تو خدا نے اسے دنیا و آخرت دونو ںکے عذاب کی گرفت میں لے لیا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxviii{اس واقعہ میں خوف خدا رکھنے والوں کے لئے عبرت کا سامان ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxix{کیا تمہاری خلقت آسمان بنانے سے زیادہ مشکل کام ہے کہ اس نے آسمان کو بنایا ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxl{اس کی چھت کو بلند کیا اور پھر برابر کردیا ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxli{اس کی رات کو تاریک بنایا ہے اور دن کی روشنی نکال دی ہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlii{اس کے بعد زمین کا فرش بچھایا ہے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliii{اس میں سے پانی اور چارہ نکالا ہے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliv{اور پہاڑوں کو گاڑ دیا ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlv{یہ سب تمہارے اور جانوروں کے لئے ایک سرمایہ ہے\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvi{پھر جب بڑی مصیبت آجائے گی\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvii{جس دن انسان یاد کرے گا کہ اس نے کیا کیا ہے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlviii{اور جہنم کو دیکھنے والوں کے لئے نمایاں کردیا جائے گا\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlix{پھر جس نے سرکشی کی ہے\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccl{اور زندگانی دنیا کو اختیار کیا ہے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccli{جہنم ّاس کا ٹھکانا ہوگا\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclii{اور جس نے رب کی بارگاہ میں حاضری کا خوف پیدا کیا ہے اور اپنے نفس کو خواہشات سے روکا ہے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliii{تو جنّت اس کا ٹھکانا اور مرکز ہے\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliv{پیغمبر لوگ آپ سے قیامت کے بارے میں پوچھتے ہیں کہ اس کا ٹھکانا کب ہے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclv{آپ اس کی یاد کے بارے میں کس منزل پر ہیں\qt@no{(43)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvi{اس کے علم کی ا نتہائ آپ کے پروردگار کی طرف ہے\qt@no{(44)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvii{آپ تو صرف اس کا خوف رکھنے والوں کو اس سے ڈرانے والے ہیں\qt@no{(45)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclviii{گویا جب وہ لوگ اسے دیکھیں گے تو ایسا معلوم ہوگاجیسے ایک شام یا ایک صبح دنیامیں ٹھہرے ہیں\qt@no{(46)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclix{\basmalahur اس نے منھ بسو رلیا اور پیٹھ پھیرلی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclx{کہ ان کے پاس ایک نابیناآگیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxi{اور تمھیں کیا معلوم شاید وہ پاکیزہ نفس ہوجاتا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxii{یا نصیحت حاصل کرلیتا تو وہ نصیحت ا س کے کام آجاتی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiii{لیکن جو مستغنی بن بیٹھا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiv{آپ اس کی فکر میں لگے ہوئے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxv{حالانکہ آپ پر کوئی ذمہ داری نہیں ہے اگر وہ پاکیزہ نہ بھی بنے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvi{لیکن جو آپ کے پاس دوڑ کر آیاہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvii{اور وہ خوف خدا بھی رکھتاہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxviii{آپ اس سے بے رخی کرتے ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxix{دیکھئے یہ قرآن ایک نصیحت ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxx{جس کا جی چاہے قبول کرلے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxi{یہ باعزّت صحیفوں میں ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxii{جو بلند و بالا اور پاکیزہ ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiii{ایسے لکھنے والوں کے ہاتھوں میں ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiv{جو محترم اور نیک کردار ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxv{انسان اس بات سے مارا گیا کہ کس قدر ناشکرا ہوگیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvi{آخر اسے کس چیز سے پیدا کیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvii{اسے نطفہ سے پیدا کیا ہے پھر اس کا اندازہ مقرر کیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxviii{پھر اس کے لئے راستہ کو آسان کیا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxix{پھر اسے موت دے کر دفنا دیا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxx{پھر جب چاہا دوبارہ زندہ کرکے اُٹھا لیا\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxi{ہرگز نہیں اس نے حکم خدا کو بالکل پورا نہیں کیا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxii{ذرا انسان اپنے کھانے کی طرف تو نگاہ کرے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiii{بے شک ہم نے پانی برسایا ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiv{پھر ہم نے زمین کو شگافتہ کیا ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxv{پھر ہم نے اس میں سے دانے پیدا کئے ہیں\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvi{اور انگور اور ترکادیاں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvii{اور زیتون اور کھجور\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxviii{اور گھنے گھنے باغ\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxix{اور میوے اور چارہ\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxc{یہ سب تمہارے اور تمہارے جانوروں کے لئے سرمایہ حیات ہے\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxci{پھر جب کان کے پردے پھاڑنے والی قیامت آجائے گی\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcii{جس دن انسان اپنے بھائی سے فرار کرے گا\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciii{اور ماں باپ سے بھی\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciv{اور بیوی اور اولاد سے بھی\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcv{اس دن ہر آدمی کی ایک خاص فکر ہوگی جو اس کے لئے کافی ہوگی\qt@no{(37)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvi{اس دن کچھ چہرے روشن ہوں گے\qt@no{(38)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvii{مسکراتے ہوئے کھلے ہوئے\qt@no{(39)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcviii{اور کچھ چہرے غبار آلود ہوں گے\qt@no{(40)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcix{ان پر ذلّت چھائی ہوئی ہوگی\qt@no{(41)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccc{یہی لوگ حقیقتا کافر اور فاجر ہوں گے\qt@no{(42)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccci{\basmalahur جب چادر آفتاب کو لپیٹ دیا جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccii{جب تارے گر پڑیں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciii{جب پہاڑ حرکت میں آجائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciv{جب عنقریب جننے والی اونٹنیاں معطل کردی جائیں گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccv{جب جانوروں کو اکٹھا کیا جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvi{جب دریا بھڑک اٹھیں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvii{جب روحوں کو جسموں سے جوڑ دیا جائے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccviii{اور جب زندہ درگور لڑکیوں کے بارے میں سوال کیا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccix{کہ انہیں کس گناہ میں مارا گیا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccx{اور جب نامہ اعمال منتشر کردیئے جائیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxi{اور جب آسمان کا چھلکا اُتار دیا جائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxii{اور جب جہنمّ کی آگ بھڑکا دی جائے گی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiii{اور جب جنّت قریب تر کردی جائے گی\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiv{تب ہر نفس کو معلوم ہوگا کہ اس نے کیا حاضر کیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxv{تو میں ان ستاروں کی قسم کھاتا ہوں جو پلٹ جانے والے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvi{چلنے والے اورحُھپ جانے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvii{اور رات کی قسم جب ختم ہونے کو آئے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxviii{اور صبح کی قسم جب سانس لینے لگے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxix{بے شک یہ ایک معزز فرشتے کا بیان ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxx{وہ صاحبِ قوت ہے اور صاحبِ عرش کی بارگاہ کا مکین ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxi{وہ وہاں قابل اطاعت اور پھر امانت دار ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxii{اور تمہارا ساتھی پیغمبر دیوانہ نہیں ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiii{اور اس نے فرشتہ کو بلند اُفق پر دیکھا ہے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiv{اور وہ غیب کے بارے میں بخیل نہیں ہے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxv{اور یہ قرآن کسی شیطان رجیم کا قول نہیں ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvi{تو تم کدھر چلے جارہے ہو\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvii{یہ صرف عالمین کے لئے ایک نصیحت کا سامان ہے\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxviii{جو تم میں سے سیدھا ہونا چاہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxix{اور تم لوگ کچھ نہیں چاہ سکتے مگریہ کہ عالمین کا پروردگار خدا چاہے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxx{\basmalahur جب آسمان شگافتہ ہوجائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxi{اور جب ستارے بکھر جائیں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxii{اور جب دریا بہہ کر ایک دوسرے سے مل جائیں گے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiii{اور جب قبروں کو اُبھار دیا جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiv{تب ہر نفس کو معلوم ہوگا کہ کیا مقدم کیا ہے اور کیا موخر کیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxv{اے انسان تجھے رب کریم کے بارے میں کس شے نے دھوکہ میں رکھا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvi{اس نے تجھے پیدا کیا ہے اور پھر برابر کرکے متوازن بنایا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvii{اس نے جس صورت میں چاہاہے تیرے اجزائ کی ترکیب کی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxviii{مگر تم لوگ جزا کا انکار کرتے ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxix{اور یقینا تمہارے سروں پر نگہبان مقرر ہیں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxl{جو باعزّت لکھنے والے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxli{وہ تمہارے اعمال کو خوب جانتے ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlii{بے شک نیک لوگ نعمتوں میں ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliii{اور بدکار افراد جہنم ّمیں ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliv{وہ روز جزا اسی میں جھونک دیئے جائیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlv{اور وہ اس سے بچ کر نہ جاسکیں گے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvi{اور تم کیا جانو کہ جزا کا دن کیا شے ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvii{پھر تمہیں کیا معلوم کہ جزا کا دن کیسا ہوتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlviii{اس دن کوئی کسی کے بارے میں کوئی اختیار نہ رکھتا ہوگا اور سارا اختیار اللہ کے ہاتھوں میں ہوگا\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlix{\basmalahur ویل ہے ان کے لئے جو ناپ تول میں کمی کرنے والے ہیں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccl{یہ جب لوگوں سے ناپ کرلیتے ہیں تو پورا مال لے لیتے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccli{اور جب ان کے لئے ناپتے یا تولتے ہیں تو کم کردیتے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclii{کیا انہیں یہ خیال نہیں ہے کہ یہ ایک روز دوبارہ اٹھائے جانے والے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliii{بڑے سخت دن میں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliv{جس دن سب رب العالمین کی بارگاہ میں حاضر ہوں گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclv{یاد رکھو کہ بدکاروں کا نامہ اعمال سجین میں ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvi{اور تم کیا جو کہ سجین کیا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvii{ایک لکھا ہوا دفتر ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclviii{آج کے دن ان جھٹلانے والوں کے لئے بربادی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclix{جو لوگ روز جزا کا انکار کرتے ہیں\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclx{اور اس کا انکار صرف وہی کرتے ہیں جو حد سے گزر جانے والے گنہگار ہیں\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxi{جب ان کے سامنے آیات کی تلاوت کی جاتی ہے تو کہتے ہیں کہ یہ تو پرانے افسانے ہیں\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxii{نہیں نہیں بلکہ ان کے دلوں پر ان کے اعمال کا زنگ لگ گیا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiii{یاد رکھو انہیں روز قیامت پروردگار کی رحمت سے محجوب کردیا جائے گا\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiv{پھر اس کے بعد یہ جہنمّ میں جھونکے جانے والے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxv{پھر ان سے کہا جائے گا کہ یہی وہ ہے جس کا تم انکار رہے تھے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvi{یاد رکھو کہ نیک کردار افراد کا نامہ اعمال علیین میں ہوگا\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvii{اور تم کیا جانو کہ علیین کیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxviii{ایک لکھا ہوا دفتر ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxix{جس کے گواہ ملائکہ مقربین ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxx{بے شک نیک لوگ نعمتوں میں ہوں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxi{تختوں پر بیٹھے ہوئے نظارے کررہے ہوں گے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxii{تم ان کے چہروں پر نعمت کی شادابی کا مشاہدہ کروگے\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiii{انہیں سربمہر خالص شراب سے سیراب کیا جائے گا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiv{جس کی مہر مشک کی ہوگی اور ایسی چیزوں میں شوق کرنے والوں کو آپس میں سبقت اور رغبت کرنی چاہئے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxv{اس شراب میں تسنیم کے پانی کی آمیزش ہوگی\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvi{یہ ایک چشمہ ہے جس سے مقرب بارگاہ بندے پانی پیتے ہیں\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvii{بے شک یہ مجرمین صاحبانِ ایمان کا مذاق اُڑایا کرتے تھے\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxviii{اور جب وہ ان کے پاس سے گزرتے تھے تو اشارے کنائے کرتے تھے\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxix{اور جب اپنے اہل کی طرف پلٹ کر آتے تھے تو خوش وخرم ہوتے تھے\qt@no{(31)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxx{اور جب مومنین کو دیکھتے تو کہتے تھے کہ یہ سب اصلی گمراہ ہیں\qt@no{(32)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxi{حالانکہ انہیں ان کا نگراں بنا کر نہیں بھیجا گیا تھا\qt@no{(33)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxii{تو آج ایمان لانے والے بھی کفاّر کا مضحکہ اُڑائیں گے\qt@no{(34)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiii{تختوں پر بیٹھے ہوئے دیکھ رہے ہوں گے\qt@no{(35)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiv{اب تو کفار کو ان کے اعمال کا پورا پورا بدلہ مل رہا ہے\qt@no{(36)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxv{\basmalahur جب آسمان پھٹ جائے گا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvi{اور اپنے پروردگار کا حکم بجا لائے گا اور یہ ضروری بھی ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvii{اور جب زمین برابر کرکے پھیلا دی جائے گی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxviii{اور وہ اپنے ذخیرے پھینک کر خالی ہوجائے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxix{اور اپنے پروردگار کا حکم بجا لائے گی اور یہ ضروری بھی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxc{اے انسان تو اپنے پروردگار کی طرف جانے کی کوشش کررہا ہے تو ایک دن اس کا سامنا کرے گا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxci{پھر جس کو نامہ اعمال داہنے ہاتھ میں دیا جائے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcii{اس کا حساب آسان ہوگا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciii{اور وہ اپنے اہل کی طرف خوشی خوشی واپس آئے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciv{اور جس کو نامہ اعمال پشت کی طرف سے دیا جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcv{وہ عنقریب موت کی دعا کرے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvi{اور جہنمّ کی آگ میں داخل ہوگا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvii{یہ پہلے اپنے اہل و عیال میں بہت خوش تھا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcviii{اور اس کا خیال تھا کہ پلٹ کر خدا کی طرف نہیں جائے گا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcix{ہاں اس کا پروردگار خوب دیکھنے والا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcm{میں شفق کی قسم کھا کر کہتا ہوں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmi{اور رات اورجن چیزوں کو وہ ڈھانک لیتی ہے ان کی قسم\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmii{اور چاند کی قسم جب وہ پورا ہوجائے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiii{کہ تم ایک مصیبت کے بعد دوسری مصیبت میں مبتلا ہوگے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiv{پھر انہیں کیا ہوگیا ہے کہ ایمان نہیں لے آتے ہیں\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmv{اور جب ان کے سامنے قرآن پڑھا جاتا ہے تو سجدہ نہیں کرتے ہیں\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvi{بلکہ کفاّر تو تکذیب بھی کرتے ہیں\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvii{اور اللہ خوب جانتا ہے جو یہ اپنے دلوں میں چھپائے ہوئے ہیں\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmviii{اب آپ انہیں دردناک عذاب کی بشارت دے دیں\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmix{علاوہ صاحبانِ ایمان و عمل صالح کے کہ ان کے لئے نہ ختم ہونے والا اجر و ثواب ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmx{\basmalahur برجوں والے آسمان کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxi{اور اس دن کی قسم جس کا وعدہ دیا گیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxii{اور گواہ اور جس کی گواہی دی جائے گی اس کی قسم\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiii{اصحاب اخدود ہلاک کردیئے گئے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiv{آگ سے بھری ہوئی خندقوں والے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxv{جن میں آگ بھرے بیٹھے ہوئے تھے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvi{اور وہ مومنین کے ساتھ جو سلوک کررہے تھے خود ہی اس کے گواہ بھی ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvii{اور انہوں نے ان سے صرف اس بات کا بدلہ لیا ہے کہ وہ خدائے عزیز و حمید پر ایمان لائے تھے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxviii{وہ خدا جس کے اختیار میں آسمان و زمین کا سارا ملک ہے اور وہ ہر شے کا گواہ اور نگراں بھی ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxix{بے شک جن لوگوں نے ایماندار مردوں اور عورتوں کو ستایا اور پھر توبہ نہ کی ان کے لئے جہنمّ کا عذاب ہے اور ان کے لئے جلنے کا عذاب بھی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxx{بے شک جو لوگ ایمان لے آئے اور انہوں نے نیک اعمال کئے ان کے لئے وہ جنتیں ہیں جن کے نیچے نہریں جاری ہوں گی اور یہ بہت بڑی کامیابی ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxi{بے شک آپ کے پروردگار کی پکڑ بہت سخت ہوتی ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxii{وہی پیدا کرنے والا اور دوبارہ ایجاد کرنے والا ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiii{وہی بہت بخشنے والا اور محبت کرنے والا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiv{وہ صاحبِ عرش مجید ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxv{جو چاہتا ہے کرسکتا ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvi{کیا تمہارے پاس لشکروں کی خبر آئی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvii{فرعون اور قوم ثمود کی خبر\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxviii{مگر کفاّر تو صرف جھٹلانے میں پڑے ہوئے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxix{اور اللہ ان کو پیچھے سے گھیرے ہوئے ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxx{یقینا یہ بزرگ و برتر قرآن ہے\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxi{جو لوح محفوظ میں محفوظ کیا گیا ہے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxii{\basmalahur آسمان اور رات کو آنے والے کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiii{اور تم کیا جانو کہ طارق کیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiv{یہ ایک چمکتا ہوا ستارہ ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxv{کوئی نفس ایسا نہیں ہے جس کے اوپر نگراں نہ معین کیا گیا ہو\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvi{پھر انسان دیکھے کہ اسے کس چیز سے پیدا کیا گیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvii{وہ ایک اُچھلتے ہوئے پانی سے پیدا کیا گیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxviii{جو پیٹھ اور سینہ کی ہڈیوں کے درمیان سے نکلتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxix{یقینا وہ خدا انسان کے دوبارہ پیدا کرنے پر بھی قادر ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxl{z جس دن رازوں کو آزمایا جائے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxli{تو پھر نہ کسی کے پاس قوت ہوگی اور نہ مددگار\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlii{قسم ہے چکر کھانے والے آسمان کی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliii{اور شگافتہ ہونے والی زمین کی\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliv{بے شک یہ قول فیصل ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlv{اور مذاق نہیں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvi{یہ لوگ اپنا مکر کررہے ہیں\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvii{اور ہم اپنی تدبیر کررہے ہیں\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlviii{تو کافروں کو چھوڑ دو اور انہیں تھوڑی سی مہلت دے دو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlix{\basmalahur اپنے بلند ترین رب کے نام کی تسبیح کرو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcml{جس نے پیدا کیا ہے اور درست بنایا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmli{جس نے تقدیر معین کی ہے اور پھر ہدایت دی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlii{جس نے چارہ بنایا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliii{پھر اسے خشک کرکے سیاہ رنگ کا کوڑا بنادیاہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliv{ہم عنقریب تمہیں اس طرح پڑھائیں گے کہ بھول نہ سکوگے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlv{مگر یہ کہ خدا ہی چاہے کہ وہ ہر ظاہر اور مخفی رہنے والی چیز کو جانتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvi{اور ہم تم کو آسان راستہ کی توفیق دیں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvii{لہذا لوگوں کوسمجھاؤ اگر سمجھانے کا فائدہ ہو\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlviii{عنقریب خوف خدا رکھنے والا سمجھ جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlix{اور بدبخت اس سے کنارہ کشی کرے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlx{جو بہت بڑی آگ میں جلنے والا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxi{پھر نہ اس میں زندگی ہے نہ موت\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxii{بے شک پاکیزہ رہنے والا کامیاب ہوگیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiii{جس نے اپنے رب کے نام کی تسبیح کی اور پھر نماز پڑھی\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiv{لیکن تم لوگ زندگانی دنیا کو مقدم رکھتے ہو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxv{جب کہ آخرت بہتر اور ہمیشہ رہنے والی ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvi{یہ بات تمام پہلے صحیفوں میں بھی موجود ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvii{ابراہیم علیہ السّلام کے صحیفوں میں بھی اور موسٰی علیہ السّلام کے صحیفوں میں بھی\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxviii{\basmalahur کیا تمہیں ڈھانپ لینے والی قیامت کی بات معلوم ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxix{اس دن بہت سے چہرے ذلیل اور رسوا ہوں گے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxx{محنت کرنے والے تھکے ہوئے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxi{دہکتی ہوئی آگ میں داخل ہوں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxii{انہیں کھولتے ہوئے پانی کے چشمہ سے سیراب کیا جائے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiii{ان کے لئے کوئی کھانا سوائے خادار جھاڑی کے نہ ہوگا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiv{جو نہ موٹائی پیدا کرسکے اور نہ بھوک کے کام آسکے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxv{اور کچھ چہرے تر و تازہ ہوں گے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvi{اپنی محنت و ریاضت سے خوش\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvii{بلند ترین جنت میں\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxviii{جہاں کوئی لغو آواز نہ سنائی دے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxix{وہاں چشمے جاری ہوں گے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxx{وہاں اونچے اونچے تخت ہوں گے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxi{اور اطراف میں رکھے ہوئے پیالے ہوں گے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxii{اور قطار سے لگے ہوئے گاؤ تکیے ہوں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiii{اور بچھی ہوئی بہترین مسندیں ہوں گی\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiv{کیا یہ لوگ اونٹ کی طرف نہیں دیکھتے ہیں کہ اسے کس طرح پیدا کیا گیا ہے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxv{اور آسمان کو کس طرح بلند کیا گیا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvi{اور پہاڑ کو کس طرح نصب کیا گیا ہے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvii{اور زمین کو کس طرح بچھایا گیا ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxviii{لہذا تم نصیحت کرتے رہو کہ تم صرف نصیحت کرنے والے ہو\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxix{تم ان پر مسلط اور ان کے ذمہ دار نہیں ہو\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxc{مگر جو منھ پھیر لے اور کافر ہوجائے\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxci{تو خدا اسے بہت بڑے عذاب میں مبتلا کرے گا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcii{پھر ہماری ہی طرف ان سب کی بازگشت ہے\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciii{اور ہمارے ہی ذمہ ان سب کا حساب ہے\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciv{\basmalahur قسم ہے فجر کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcv{اور دس راتوں کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvi{اور جفت و طاق کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvii{اور رات کی جب وہ جانے لگے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcviii{بے شک ان چیزوں میں قسم ہے صاحبِ عقل کے لئے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcix{کیا تم نے نہیں دیکھا کہ تمہارے رب نے قوم عاد کے ساتھ کیا کیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmm{ستون والے ارم والے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmi{جس کا مثل دوسرے شہروں میں نہیں پیدا ہوا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmii{اور ثمود کے ساتھ جو وادی میں پتھر تراش کر مکان بناتے تھے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiii{اور میخوں والے فرعون کے ساتھ\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmiv{جن لوگوں نے شہروں میں سرکشی پھیلائی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmv{اور خوب فساد کیا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvi{تو پھر خدا نے ان پر عذاب کے کوڑے برسادیئے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmvii{بے شک تمہارا پروردگار ظالموں کی تاک میں ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmviii{لیکن انسان کا حال یہ ہے کہ جب خدا نے اس کو اس طرح آزمایا کہ عزّت اور نعمت دے دی تو کہنے لگا کہ میرے رب نے مجھے باعزّت بنایا ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmix{اور جب آزمائش کے لئے روزی کو تنگ کردیا تو کہنے لگا کہ میرے پروردگار نے میری توہین کی ہے\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmx{ایسا ہرگز نہیں ہے بلکہ تم یتیموں کا احترام نہیں کرتے ہو\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxi{اور لوگوں کو م مسکینوں کے کھانے پر آمادہ نہیں کرتے ہو\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxii{اور میراث کے مال کو اکٹھا کرکے حلال و حرام سب کھا جاتے ہو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiii{اور مال دنیا کو بہت دوست رکھتے ہو\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiv{یاد رکھو کہ جب زمین کو ریزہ ریزہ کردیا جائے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxv{اور تمہارے پروردگار کا حکم اور فرشتے صف در صف آجائیں گے\qt@no{(22)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvi{اور جہنمّ کو اس دن سامنے لایا جائے گا تو انسان کو ہوش آجائے گا لیکن اس دن ہوش آنے کا کیا فائدہ\qt@no{(23)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvii{انسان کہے گا کہ کاش میں نے اپنی اس زندگی کے لئے کچھ پہلے بھیج دیا ہوتا\qt@no{(24)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxviii{تو اس دن خدا ویسا عذاب کرے گا جو کسی نے نہ کیا ہوگا\qt@no{(25)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxix{اور نہ اس طرح کسی نے گرفتار کیا ہوگا\qt@no{(26)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxx{اے نفس مطمئن\qt@no{(27)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxi{اپنے رب کی طرف پلٹ آ اس عالم میں کہ تواس سے راضی ہے اور وہ تجھ سے راضی ہے\qt@no{(28)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxii{پھر میرے بندوں میں شامل ہوجا\qt@no{(29)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiii{اور میری جنت میں داخل ہوجا\qt@no{(30)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiv{\basmalahur میں اس شہر کی قسم کھاتا ہوں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxv{اور تم اسی شہر میں تو رہتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvi{اور تمہارے باپ آدم علیھ السّلام اور ان کی اولاد کی قسم\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvii{ہم نے انسان کو مشقت میں رہنے والا بنایا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxviii{کیا اس کا خیال یہ ہے کہ اس پر کوئی قابو نہ پاسکے گا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxix{کہ وہ کہتا ہے کہ میں نے بے تحاشہ صرف کیا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxx{کیا اس کا خیال ہے کہ اس کو کسی نے نہیں دیکھا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxi{کیا ہم نے اس کے لئے دو آنکھیں نہیں قرار دی ہیں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxii{اور زبان اور دو ہونٹ بھی\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiii{اور ہم نے اسے دونوں راستوں کی ہدایت دی ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiv{پھر وہ گھاٹی پر سے کیوں نہیں گزرا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxv{اورتم کیا جانو یہ گھاٹی کیا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvi{کسی گردن کا آزاد کرانا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvii{یا بھوک کے دن میں کھانا کھلانا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxviii{کسی قرابتدار یتیم کو\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxix{یا خاکسار مسکین کو\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxl{پھر وہ ان لوگوں میں شامل ہوجاتا جو ایمان لائے اور انہوں نے صبر اور مرحمت کی ایک دوسرے کو نصیحت کی\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxli{یہی لوگ خو ش نصیبی والے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlii{اور جن لوگوں نے ہماری آیات سے انکار کیا ہے وہ بد بختی والے ہیں\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliii{انہیں آگ میں ڈال کر اسے ہر طرف سے بند کردیا جائے گا\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliv{\basmalahur آفتاب اور اس کی روشنی کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlv{اور چاند کی قسم جب وہ اس کے پیچھے چلے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvi{اور دن کی قسم جب وہ روشنی بخشے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvii{اور رات کی قسم جب وہ اسے ڈھانک لے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlviii{اور آسمان کی قسم اور جس نے اسے بنایا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlix{اور زمین کی قسم اور جس نے اسے بچھایا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmml{اور نفس کی قسم اور جس نے اسے درست کیاہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmli{پھر بدی اور تقویٰ کی ہدایت دی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlii{بے شک وہ کامیاب ہوگیا جس نے نفس کو پاکیزہ بنالیا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliii{اور وہ نامراد ہوگیا جس نے اسے آلودہ کردیا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmliv{ثمود نے اپنی سرکشی کی بنا پر رسول کی تذکیب کی\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlv{جب ان کا بدبخت اٹھ کھڑا ہوا\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvi{تو خدا کے رسول نے کہا کہ خدا کی اونٹنی اور اس کی سیرابی کا خیال رکھنا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvii{تو ان لوگوں نے اس کی تکذیب کی اور اس کی کونچیں کاٹ ڈالیں تو خدا نے ان کے گناہ کے سبب ان پر عذاب نازل کردیا اور انہیں بالکل برابر کردیا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlviii{اور اسے اس کے انجام کا کوئی خوف نہیں ہے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlix{\basmalahur رات کی قسم جب وہ دن کو ڈھانپ لے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlx{اور دن کی قسم جب وہ چمک جائے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxi{اور اس کی قسم جس نے مرد اور عورت کو پیدا کیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxii{بے شک تمہاری کوششیں مختلف قسم کی ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiii{پھر جس نے مال عطا کیا اور تقویٰ اختیار کیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiv{اور نیکی کی تصدیق کی\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxv{تو اس کے لئے ہم آسانی کا انتظام کردیں گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvi{اور جس نے بخل کیا اور لاپروائی برتی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvii{اور نیکی کو جھٹلایا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxviii{اس کے لئے سختی کی راہ ہموار کردیں گے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxix{اور اس کا مال کچھ کام نہ آئے گا جب وہ ہلاک ہوجائے گا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxx{بے شک ہدایت کی ذمہ داری ہمارے اوپر ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxi{اور دنیا و آخرت کا اختیار ہمارے ہاتھوں میں ہے\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxii{تو ہم نے تمہیں بھڑکتی ہوئی آگ سے ڈرایا\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiii{جس میں کوئی نہ جائے گا سوائے بدبخت شخص کے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiv{جس نے جھٹلایا اور منھ پھیرلیا\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxv{اور اس سے عنقریب صاحبِ تقویٰ کو محفوظ رکھا جائے گا\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvi{جو اپنے مال کو دے کر پاکیزگی کا اہتمام کرتا ہے\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvii{جب کہ اس کے پاس کسی کا کوئی احسان نہیں ہے جس کی جزا دی جائے\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxviii{سوائے یہ کہ وہ خدائے بزرگ کی مرضی کا طلبگار ہے\qt@no{(20)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxix{اور عنقریب وہ راضی ہوجائے گا\qt@no{(21)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxx{\basmalahur قسم ہے ایک پہر چڑھے دن کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxi{اور قسم ہے رات کی جب وہ چیزوں کی پردہ پوشی کرے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxii{تمہارے پروردگار نے نہ تم کو چھو ڑا ہے اور نہ تم سے ناراض ہوا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiii{اور آخرت تمہارے لئے دنیا سے کہیں زیادہ بہتر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiv{اور عنقریب تمہارا پروردگار تمہیں اس قدر عطا کردے گا کہ خوش ہوجاؤ\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxv{کیا اس نے تم کو یتیم پاکر پناہ نہیں دی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvi{اور کیا تم کو گم گشتہ پاکر منزل تک نہیں پہنچایا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvii{اور تم کو تنگ دست پاکر غنی نہیں بنایا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxviii{لہذا اب تم یتیم پر قہر نہ کرنا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxix{اور سائل کوجھڑک مت دینا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxc{اور اپنے پروردگار کی نعمتوں کو برابر بیان کرتے رہنا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxci{\basmalahur کیا ہم نے آپ کے سینہ کو کشادہ نہیں کیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcii{اور کیا آپ کے بوجھ کو اتار نہیں لیا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciii{جس نے آپ کی کمر کو توڑ دیا تھا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciv{اور آپ کے ذکر کو بلند کردیا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcv{ہاں زحمت کے ساتھ آسانی بھی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvi{بے شک تکلیف کے ساتھ سہولت بھی ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvii{لہذا جب آپ فارغ ہوجائیں تو نصب کردیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcviii{اور اپنے رب کی طرف رخ کریں\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcix{\basmalahur قسم ہے انجیر اور زیتون کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmc{اور طورسینین کی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmci{اور اس امن والے شہر کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcii{ہم نے انسان کو بہترین ساخت میں پیدا کیا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciii{پھر ہم نے اس کو پست ترین حالت کی طرف پلٹا دیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmciv{علاوہ ان لوگوں کے جو ایمان لائے اور انہوں نے نیک اعمال انجام دیئے تو ان کے لئے نہ ختم ہونے والا اجر ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcv{پھر تم کو روز جزا کے بارے میں کون جھٹلا سکتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvi{کیا خدا سب سے بڑا حاکم اور فیصلہ کرنے والا نہیں ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvii{\basmalahur اس خدا کا نام لے کر پڑھو جس نے پیدا کیا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcviii{اس نے انسان کو جمے ہوئے خون سے پیدا کیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcix{پڑھو اور تمہارا پروردگار بڑا کریم ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcx{جس نے قلم کے ذریعے تعلیم دی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxi{اور انسان کو وہ سب کچھ بتادیا ہے جو اسے نہیں معلوم تھا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxii{بے شک انسان سرکشی کرتا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiii{کہ اپنے کو بے نیاز خیال کرتا ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiv{بے شک آپ کے رب کی طرف واپسی ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxv{کیا تم نے اس شخص کو دیکھا ہے جو منع کرتا ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvi{بندئہ خدا کو جب وہ نماز پڑھتا ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvii{کیا تم نے دیکھا کہ اگر وہ بندہ ہدایت پر ہو\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxviii{یا تقویٰ کا حکم دے تو روکنا کیسا ہے\qt@no{(12)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxix{کیا تم نے دیکھا کہ اگر اس کافر نے جھٹلایا اور منھ پھیر لیا\qt@no{(13)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxx{تو کیا تمہیں نہیں معلوم کہ اللہ دیکھ رہا ہے\qt@no{(14)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxi{یاد رکھو اگر وہ روکنے سے باز نہ آیا تو ہم پیشانی کے بال پکڑ کر گھسیٹیں گے\qt@no{(15)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxii{جھوٹے اور خطا کار کی پیشانی کے بال\qt@no{(16)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiii{پھر وہ اپنے ہم نشینوں کو بلائے\qt@no{(17)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiv{ہم بھی اپنے جلاد فرشتوں کوبلاتے ہیں\qt@no{(18)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxv{دیکھو تم ہرگز اس کی اطاعت نہ کرنا اور سجدہ کرکے قرب خدا حاصل کرو\qt@no{(19)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvi{\basmalahur بے شک ہم نے اسے شب قدر میں نازل کیا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvii{اور آپ کیا جانیں یہ شب قدر کیا چیز ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxviii{شب قدر ہزار مہینوں سے بہتر ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxix{اس میں ملائکہ اور روح القدس اسُن خدا کے ساتھ تمام امور کو لے کر نازل ہوتے ہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxx{یہ رات طلوع فجر تک سلامتی ہی سلامتی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxi{\basmalahur اہل کتاب کے کفاّر اور دیگر مشرکین اپنے کفر سے الگ ہونے والے نہیں تھے جب تک کہ ان کے پاس کِھلی دلیل نہ آجاتی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxii{اللہ کی طرف کا نمائندہ جو پاکیزہ صحفیوں کی تلاوت کرے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiii{جن میں قیمتی اور مضبوط باتیں لکھی ہوئی ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiv{اور یہ اہل کتاب متفرق نہیں ہوئے مگر اس وقت جب ان کے پاس کِھلی ہوئی دلیل آگئی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxv{اور انہیں صرف اس بات کا حکم دیا گیا تھا کہ خدا کی عبادت کریں اور اس عبادت کو اسی کے لئے خالص رکھیں اور نماز قائم کریں اور زکوٰہ ادا کریں اور یہی سچاّ اور مستحکم دین ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvi{بے شک اہل کتاب میں جن لوگوں نے کفر اختیار کیا ہے اور دیگر مشرکین سب جہنمّ میں ہمیشہ رہنے والے ہیں اور یہی بدترین خلائق ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvii{اور بے شک جو لوگ ایمان لائے ہیں اور انہوں نے نیک اعمال کئے ہیں وہ بہترین خلائق ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxviii{پروردگار کے یہاں ان کی جزائ وہ باغات ہیں جن کے نیچے نہریں جاری ہوں گی وہ انہی میں ہمیشہ رہنے والے ہیں خدا ان سے راضی ہے اور وہ اس سے راضی ہیں اور یہ سب اس کے لئے ہے جس کے دل میں خوف خدا ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxix{\basmalahur جب زمین زوروں کے ساتھ زلزلہ میں آجائے گی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxl{اور وہ سارے خزانے نکال ڈالے گی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxli{اور انسان کہے گا کہ اسے کیا ہو گیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlii{اس دن وہ اپنی خبریںبیان کرے گی\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliii{کہ تمہارے پروردگار نے اسے اشارہ کیا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliv{اس روز سارے انسان گروہ در گروہ قبروں سے نکلیں گے تاکہ اپنے اعمال کو دیکھ سکیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlv{پھر جس شخص نے ذرہ برابر نیکی کی ہے وہ اسے دیکھے گا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvi{اور جس نے ذرہ برابر برائی کی ہے وہ اسے دیکھے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvii{\basmalahur فراٹے بھرتے ہوئے تیز رفتار گھوڑوں کی قسم\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlviii{جوٹا پ مار کر چنگاریاں اُڑانے والے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlix{پھر صبحدم حملہ کرنے والے ہیں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcl{پھر غبار جنگ اڑانے والے نہیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcli{اور دشمن کی جمعیت میں در آنے والے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclii{بے شک انسان اپنے پروردگار کے لئے بڑا ناشکرا ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliii{اور وہ خود بھی اس بات کا گواہ ہے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliv{اور وہ مال کی محبت میں بہت سخت ہے\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclv{کیا اسے نہیں معلوم ہے کہ جب مفِدوں کو قبروں سے نکالا جائے گا\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvi{اور دل کے رازوں کو ظاہر کردیا جائے گا\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvii{تو ان کا پروردگار اس دن کے حالات سے خوب باخبر ہوگا\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclviii{\basmalahur کھڑکھڑانے والی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclix{اور کیسی کھڑکھڑانے والی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclx{اور تمہیں کیا معلوم کہ وہ کیسی کھڑکھڑانے والی ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxi{جس دن لوگ بکھرے ہوئے پتنگوں کی مانند ہوجائیں گے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxii{اور پہاڑ دھنکی ہوئی روئی کی طرح اُڑنے لگیں گے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiii{تو اس دن جس کی نیکیوں کا پلّہ بھاری ہوگا\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiv{وہ پسندیدہ عیش میں ہوگا\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxv{اور جس کا پلہّ ہلکا ہوگا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvi{اس کا مرکز ہاویہ ہے\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvii{اور تم کیا جانو کہ ہاویہ کیا مصیبت ہے\qt@no{(10)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxviii{یہ ایک دہکی ہوئی آگ ہے\qt@no{(11)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxix{\basmalahur تمہیں باہمی مقابلہ کثرت مال و اولاد نے غافل بنادیا\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxx{یہاں تک کہ تم نے قبروں سے ملاقات کرلی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxi{دیکھو تمہیں عنقریب معلوم ہوجائے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxii{اور پھر خوب معلوم ہوجائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiii{دیکھو اگر تمہیں یقینی علم ہوجاتا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiv{کہ تم جہنمّ کو ضرور دیکھو گے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxv{پھر اسے اپنی آنکھوں دیکھے یقین کی طرح دیکھو گے\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvi{اور پھر تم سے اس دن نعمت کے بارے میں سوال کیا جائے گا\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvii{\basmalahur قسم ہے عصر کی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxviii{بے شک انسان خسارہ میں ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxix{علاوہ ان لوگوں کے جو ایمان لائے اور انہوں نے نیک اعمال کئے اور ایک دوسرے کو حق اور صبر کی وصیت و نصیحت کی\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxx{\basmalahur تباہی اور بربادی ہے ہر طعنہ زن اور چغلخور کے لئے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxi{جس نے مال کو جمع کیا اور خوب اس کا حساب رکھا\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxii{اس کا خیال تھا کہ یہ مال اسے ہمیشہ باقی رکھے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiii{ہرگز نہیں اسے یقینا حطمہ میں ڈال دیا جائے گا\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiv{اور تم کیا جانو کہ حطمہ کیا شے ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxv{یہ اللہ کی بھڑکائی ہوئی آگ ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvi{جو دلوں تک چڑھ سسجائے گی\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvii{وہ آگ ان کے اوپر گھیر دی جائے گی\qt@no{(8)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxviii{لمبے لمبے ستونوں کے ساتھ\qt@no{(9)}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxix{\basmalahur کیا تم نے نہیں دیکھا کہ تمہارے رب نے ہاتھی والوں کے ساتھ کیا برتاؤ کیاہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxc{کیا ان کی چال کو بے کار نہیں کردیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxci{اور ان پر اڑتی ہوئی ابابیل کو بھیج دیا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcii{جو انہیں کھرنجوں کی کنکریاں ماررہی تھیں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciii{پھر انہوں نے ان سب کو چبائے ہوئے بھوسے کے مانند بنادیا\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciv{\basmalahur قریش کے انس و الفت کی خاطر\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcv{جو انہیں سردی اور گرمی کے سفرسے ہے ابرہہ کو ہلاک کردیا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvi{لہذا انہیں چاہئے کہ اس گھر کے مالک کی عبادت کریں\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvii{جس نے انہیں بھوک میں سیر کیا ہے اور خوف سے محفوظ بنایا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcviii{\basmalahur کیا تم نے اس شخص کو دیکھا ہے جوقیامت کو جھٹلاتا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcix{یہ وہی ہے جو یتیم کو دھکےّ دیتا ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcc{اور کسی کو مسکین کے کھانے کے لئے تیار نہیں کرتا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcci{تو تباہی ہے ان نمازیوں کے لئے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccii{جو اپنی نمازوں سے غافل رہتے ہیں\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciii{دکھانے کے لئے عمل کرتے ہیں\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciv{اور معمولی ظروف بھی عاریت پر دینے سے انکار کردتے ہیں\qt@no{(7)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccv{\basmalahur بے شک ہم نے آپ کو کوثر عطا کیا ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvi{لہذا آپ اپنے رب کے لئے نماز پڑھیں اور قربانی دیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvii{یقینا آپ کا دشمن بے اولاد رہے گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccviii{\basmalahur آپ کہہ دیجئے کہ اے کافرو\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccix{میں ان خداؤں کی عبادت نہیں کرسکتا جن کی تم پوجا کرتے ہو\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccx{اور نہ تم میرے خدا کی عبادت کرنے والے ہو\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxi{اور نہ میں تمہارے معبودوں کو پوجا کرنے ولا ہوں\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxii{اور نہ تم میرے معبود کے عبادت گزار ہو\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiii{تمہارے لئے تمہارا دین ہے اور میرے لئے میرا دین ہے\qt@no{(6)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiv{\basmalahur جب خدا کی مدد اور فتح کی منزل آجائے گی\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxv{اور آپ دیکھیں گے کہ لوگ دین خدا میں فوج در فوج داخل ہورہے ہیں\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvi{تو اپنے رب کی حمد کی تسبیح کریں او راس سے استغفار کریں کہ وہ بہت زیادہ توبہ قبول کرنے والا ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvii{\basmalahur ابو لہب کے ہاتھ ٹوٹ جائیں اور وہ ہلاک ہوجائے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxviii{نہ اس کا مال ہی اس کے کام آیا اور نہ اس کا کمایا ہوا سامان ہی\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxix{وہ عنقریب بھڑکتی ہوئی آگ میں داخل ہو گا\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxx{اور اس کی بیوی جو لکڑی ڈھونے والی ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxi{اس کی گردن میں بٹی ہوئی رسی بندھی ہوئی ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxii{\basmalahur اے رسول کہہ دیجئے کہ وہ اللہ ایک ہے\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiii{اللہ برحق اور بے نیاز ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiv{اس کی نہ کوئی اولاد ہے اور نہ والد\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxv{اور نہ اس کا کوئی کفو اور ہمسر ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvi{\basmalahur کہہ دیجئے کہ میں صبح کے مالک کی پناہ چاہتا ہوں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvii{تمام مخلوقات کے شر سے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxviii{اور اندھیری رات کے شر سے جب اس کا اندھیرا چھا جائے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxix{اور گنڈوں پر پھونکنے والیوں کے شر سے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxx{اور ہرحسد کرنے والے کے شر سے جب بھی وہ حسد کرے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxi{\basmalahur اے رسول کہہ دیجئے کہ میں انسانوں کے پروردگار کی پناہ چاہتا ہوں\qt@no{(1)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxii{جو تمام لوگوں کا مالک اور بادشاہ ہے\qt@no{(2)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiii{سارے انسانوں کا معبود ہے\qt@no{(3)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiv{شیطانی وسواس کے شر سے جو نام خدا سن کر پیچھے ہٹ جاتا ہے\qt@no{(4)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxv{اور جو لوگوں کے دلوں میں وسوسے پیدا کراتا ہے\qt@no{(5)}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxvi{وہ جنات میں سے ہو یا انسانوں میں سے\qt@no{(6)}}%
%% End of file `qurantext-uriii.translation.def'.
